# We have to override the new %%install behavior because, well... the kernel is special.
%global __spec_install_pre %{___build_pre}

# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
%define _binary_payload w3T.xzdio

%global distro_build 553

# Sign the x86_64 kernel for secure boot authentication
%ifarch x86_64 aarch64 s390x ppc64le
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.xz/'
%endif

# define buildid .local

%define specversion 4.18.0
%define pkgrelease 553.50.1.el8_10

# allow pkg_release to have configurable %%{?dist} tag
%define specrelease 553.50.1%{?dist}

%define pkg_release %{specrelease}%{?buildid}

# libexec dir is not used by the linker, so the shared object there
# should not be exported to RPM provides
%global __provides_exclude_from ^%{_libexecdir}/kselftests

# What parts do we want to build? These are the kernels that are built IF the
# architecture allows it. All should default to 1 (enabled) and be flipped to
# 0 (disabled) by later arch-specific checks.

%define _with_kabidupchk 1
# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# realtime
# rhel doesn't incorporate PREEMPT_RT patches, but rhel-rt builds use base
# kernel spec as a template.
%define with_realtime 0
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# Want to build a the vsdo directories installed
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-abi-stablelists
%define with_kernel_abi_stablelists %{?_without_kernel_abi_stablelists: 0} %{?!_without_kernel_abi_stablelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# The kernel tarball/base version
%define kversion 4.18

%define with_gcov %{?_with_gcov:1}%{?!_with_gcov:0}

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_stablelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%if %{with_realtime}
# The preempt RT patch level
%global rttag %%RTTAG%%
# realtimeN
%global rtbuild %%RTBUILD%%
%define with_doc 0
%define with_headers 0
%define with_cross_headers 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_zfcpdump 0
%define with_kabichk  0
%define with_kernel_abi_stablelists 0
%define with_bpf_samples 0
%define with_kabidw_base 0
%define with_ipaclones 0
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

# selftests require bpftool to be built
%if %{with_selftests}
%define with_bpftool 1
%endif

%ifnarch noarch
%define with_kernel_abi_stablelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define doc_build_fail true
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_selftests 0
%define with_debug 0
%define all_arch_configs %{name}-%{version}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs %{name}-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define all_arch_configs %{name}-%{version}-ppc64le*.config
%define kcflags -O3
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs %{name}-%{version}-s390x.config
%define kernel_image arch/s390/boot/bzImage
%define vmlinux_decompressor arch/s390/boot/compressed/vmlinux
%endif

%ifarch aarch64
%define all_arch_configs %{name}-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target Image.gz
%define kernel_image arch/arm64/boot/Image.gz
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%define nobuildarches i386 i686

%ifarch %nobuildarches
%define with_up 0
%define with_debug 0
%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%define cpupowerarchs x86_64 ppc64le aarch64


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel%{?variant}
Group: System Environment/Kernel
License: GPLv2 and Redistributable, no modification permitted
URL: http://www.kernel.org/
Version: %{specversion}
Release: %{pkg_release}
Summary: The Linux kernel, based on version %{version}, heavily modified with backports
%if %{with_realtime}
ExclusiveArch: x86_64
%else
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch i386 i686 x86_64 s390x aarch64 ppc64le
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: %{name}-core-uname-r = %{KVERREL}%{?variant}
Requires: %{name}-modules-uname-r = %{KVERREL}%{?variant}
%if %{with_realtime}
Requires: rt-setup
%endif
%endif


#
# List the packages used during the kernel build
#
BuildRequires: kmod, patch, bash, coreutils, tar, git, which
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, python3-devel
BuildRequires: net-tools, hostname, bc, bison, flex, elfutils-devel, dwarves
%ifnarch %nobuildarches noarch
BuildRequires: bpftool
%endif
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel
BuildRequires: java-devel
BuildRequires: libbpf-devel
BuildRequires: libbabeltrace-devel
BuildRequires: libtraceevent-devel
%ifnarch s390x
BuildRequires: numactl-devel
%endif
%ifarch aarch64
BuildRequires: opencsd-devel >= 1.0.0-2
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_selftests}
BuildRequires: libcap-devel libcap-ng-devel clang llvm numactl-devel rsync libmnl-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
%global _find_debuginfo_opts -r
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl openssl-devel
%if %{signkernel}
%ifarch x86_64 aarch64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

Source0: linux-%{specversion}-%{pkgrelease}.tar.xz

Source9: x509.genkey

# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

Source10: redhatsecurebootca3.cer
Source11: centossecurebootca2.cer
Source12: centossecureboot201.cer
Source13: redhatsecureboot501.cer
Source14: redhatsecureboot302.cer
Source15: redhatsecureboot303.cer
Source16: redhatsecurebootca7.cer
%if 0%{?centos}
%define secureboot_ca_0  %{SOURCE11}
%define secureboot_key_0 %{SOURCE12}
%define pesign_name_0 centossecureboot201
%else

%ifarch x86_64 aarch64
%define secureboot_ca_0 %{SOURCE10}
%define secureboot_key_0 %{SOURCE13}
%define pesign_name_0 redhatsecureboot501
%endif

%ifarch s390x
%define secureboot_ca_0 %{SOURCE10}
%define secureboot_key_0 %{SOURCE14}
%define pesign_name_0 redhatsecureboot302
%endif

%ifarch ppc64le
%define secureboot_ca_0 %{SOURCE16}
%define secureboot_key_0 %{SOURCE15}
%define pesign_name_0 redhatsecureboot701
%endif
%endif

Source17: mod-blacklist.sh
Source18: mod-sign.sh
Source19: mod-extra.list
Source80: parallel_xz.sh
Source90: filter-x86_64.sh
Source93: filter-aarch64.sh
Source96: filter-ppc64le.sh
Source97: filter-s390x.sh
Source99: filter-modules.sh
%define modsign_cmd %{SOURCE18}

Source20: %{name}-aarch64.config
Source21: %{name}-aarch64-debug.config
Source32: %{name}-ppc64le.config
Source33: %{name}-ppc64le-debug.config
Source36: %{name}-s390x.config
Source37: %{name}-s390x-debug.config
Source38: %{name}-s390x-zfcpdump.config
Source39: %{name}-x86_64.config
Source40: %{name}-x86_64-debug.config
Source41: generate_all_configs.sh

Source42: process_configs.sh
Source43: generate_bls_conf.sh

Source44: mod-internal.list

Source100: rheldup3.x509
Source101: rhelkpatch1.x509

%if %{with_kabichk}
Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-stablelists-%{specversion}-%{distro_build}.tar.bz2
Source301: kernel-kabi-dw-%{specversion}-%{distro_build}.tar.bz2
%endif

%if %{with_realtime}
Source400: mod-kvm.list
%endif

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config
Source2002: kvm_stat.logrotate

# CI gating config
Source4000: gating.yaml
# rpminspect config
Source4001: rpminspect.yaml

## Patches needed for building this package

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/%{name}-%{KVERREL}-root

%description
This is the package which provides the Linux %{name} for Red Hat Enterprise
Linux. It is based on upstream Linux at version %{version} and maintains kABI
compatibility of a set of approved symbols, however it is heavily modified with
backports and fixes pulled from newer upstream Linux %{name} releases. This means
this is not a %{version} kernel anymore: it includes several components which come
from newer upstream linux versions, while maintaining a well tested and stable
core. Some of the components/backports that may be pulled in are: changes like
updates to the core kernel (eg.: scheduler, cgroups, memory management, security
fixes and features), updates to block layer, supported filesystems, major driver
updates for supported hardware in Red Hat Enterprise Linux, enhancements for
enterprise customers, etc.

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: %{name} = %{specversion}-%{pkg_release}\
Provides: %{name}-%{_target_cpu} = %{specversion}-%{pkg_release}%{?1:+%{1}}\
Provides: kernel-drm-nouveau = 16\
Provides: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20200619-99.git3890db36\
%ifnarch s390x\
Requires(pre): ((grub2 >= 2.02-99) if grub2)\
Requires(pre): ((grub2-efi >= 2.02-99) if grub2-efi)\
%endif\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
Conflicts: kexec-tools < 2.0.20-8\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%if "0%{?variant}"
Obsoletes: kernel-headers < %{specversion}-%{pkg_release}
Provides: kernel-headers = %{specversion}-%{pkg_release}
%endif
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
Group: Development/System
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
Requires: bzip2
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
Group: Development/Libraries
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}

# with_perf
%endif

%if %{with_tools}
%package -n %{name}-tools
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: %{name}-tools-libs = %{version}-%{release}
%ifarch i686 x86_64
BuildRequires: libnl3-devel
%endif
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n %{name}-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n %{name}-tools-libs
Summary: Libraries for the %{name}-tools
Group: Development/System
License: GPLv2
%description -n %{name}-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n %{name}-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Requires: %{name}-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: %{name}-tools-libs = %{version}-%{release}
Provides: %{name}-tools-devel
%description -n %{name}-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n %{name}-tools-debuginfo
Summary: Debug information for package %{name}-tools
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n %{name}-tools-debuginfo
This package provides debug information for package %{name}-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|.*%%{_bindir}/intel-speed-select(\.debug)?|.*%%{_bindir}/page_owner_sort(\.debug)?|.*%%{_bindir}/slabinfo(\.debug)?|.*%%{_sbindir}/intel_sdsi(\.debug)?|XXX' -o %{name}-tools-debuginfo.list}

# with_tools
%endif

%if !%{with_realtime}
%if %{with_bpftool}

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
License: GPLv2
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

# with_bpftool
%endif
%endif

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
License: GPLv2
Requires: binutils, bpftool, iproute-tc, nmap-ncat, python3
%if %{with_realtime}
Conflicts: kernel-selftests-internal
%else
Conflicts: kernel-rt-selftests-internal
%endif
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

# with_selftests
%endif

%if %{with_gcov}
%package gcov
Summary: gcov graph and source files for coverage data collection.
Group: Development/System
%description gcov
kernel-gcov includes the gcov graph and source files for gcov coverage collection.
%endif

%package -n %{name}-abi-stablelists
Summary: The Red Hat Enterprise Linux kernel ABI symbol stablelists
Group: System Environment/Kernel
AutoReqProv: no
Obsoletes: %{name}-abi-whitelists < %{specversion}-%{pkg_release}
Provides: %{name}-abi-whitelists
%description -n %{name}-abi-stablelists
The kABI package contains information pertaining to the Red Hat Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the Red Hat Enterprise
Linux kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-devel-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-devel-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Recommends: gcc flex bison openssl-devel make\
Requires: perl-interpreter\
Recommends: elfutils-libelf-devel\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-internal = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat internal usage.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package <subpackage> <pretty-name>
#
%define kernel_modules_extra_package() \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-extra = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package <subpackage> <pretty-name>
#
%define kernel_modules_package() \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-modules-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-modules = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
group: system environment/kernel\
Requires: %{name}-%{1}-core-uname-r = %{KVERREL}%{?variant}+%{1}\
Requires: %{name}-%{1}-modules-uname-r = %{KVERREL}%{?variant}+%{1}\
%if %{with_realtime}\
Requires: rt-setup\
%endif\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

%if %{with_realtime}
#
# this macro creates a kernel-rt-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package %{name}%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: %{name}%{?1:-%{1}} = %{version}-%{release}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n %{name}%{?1:-%{1}}-kvm\
This package provides KVM modules for package %{name}%{?1:-%{1}}.\
%{nil}
%endif

#
# This macro creates a %%{name}-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
Provides: %{name}-%{?1:%{1}-}core-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
%{expand:%%kernel_reqprovconf}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%if %{with_realtime} \
%{expand:%%kernel_kvm_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif \
%{nil}

# Now, each variant package.

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
# with_zfcpdump
%endif

%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME%%%%%{?variant}}.spec ; then
    if [ "${patch:0:8}" != "patch-4." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n %{name}-%{specversion}-%{pkgrelease} -c
mv linux-%{specversion}-%{pkgrelease} linux-%{KVERREL}

cd linux-%{KVERREL}

ApplyOptionalPatch linux-kernel-test.patch

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

%if %{with_realtime}
# remove the localversion-rt file since it screws around with
# the uname output
if [ -f localversion-rt ]; then
   rm -f localversion-rt
fi
%endif

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Do not use "ambiguous" python shebangs. RHEL 8 now has a new script
# (/usr/lib/rpm/redhat/brp-mangle-shebangs), which forces us to specify a
# "non-ambiguous" python shebang for scripts we ship in buildroot. This
# script throws an error like below:
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i %{__python3} -p -n \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	tools/perf/tests/attr.py \
	tools/perf/scripts/python/stat-cpi.py \
	tools/perf/scripts/python/sched-migration.py \
	Documentation

%define make make %{?cross_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE41} .
VERSION=%{version} NAME=%{name} ./generate_all_configs.sh

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  ${RPM_OPT_FLAGS}
%define build_hostldflags %{__global_ldflags}
%endif

# enable GCOV kernel config options if gcov is on
%if %{with_gcov}
for i in *.config
do
  sed -i 's/# CONFIG_GCOV_KERNEL is not set/CONFIG_GCOV_KERNEL=y\nCONFIG_GCOV_PROFILE_ALL=y\n/' $i
done
%endif

# Add DUP and kpatch certificates to system trusted keys for RHEL
%if 0%{?rhel}
%if %{signkernel}%{signmodules}
openssl x509 -inform der -in %{SOURCE100} -out rheldup3.pem
openssl x509 -inform der -in %{SOURCE101} -out rhelkpatch1.pem
cat rheldup3.pem rhelkpatch1.pem > ../certs/rhel.pem
%ifarch ppc64le
openssl x509 -inform der -in %{secureboot_ca_0} -out secureboot.pem
cat secureboot.pem >> ../certs/rhel.pem
%endif
for i in *.config; do
  sed -i 's@CONFIG_SYSTEM_TRUSTED_KEYS=""@CONFIG_SYSTEM_TRUSTED_KEYS="certs/rhel.pem"@' $i
done
%endif
%endif

cp %{SOURCE42} .
./process_configs.sh -w -c %{name} %{specversion} %{?cross_opts}

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -exec rm -f {} \; >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

InitBuildVars() {
    # Initialize the kernel .config file and create some variables that are
    # needed for the actual build process.

    Flavour=$1
    Flav=${Flavour:++${Flavour}}

    # Pick the right kernel config file
    Config=%{name}-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flav}

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flav}

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}${Flav}/" Makefile

    %{make} -s %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp %{SOURCE9} certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    if [ "$Flavour" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$4
    DoVDSO=$3
    Flav=${Flavour:++${Flavour}}
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Flavour" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    InitBuildVars $Flavour

    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    %{make} -s ARCH=$Arch oldnoconfig >/dev/null
    %{make} -s ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} -s ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch aarch64
    %{make} -s ARCH=$Arch V=1 dtbs dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f | xargs rm -f
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    # Sign the image if we're using EFI
    # aarch64 kernels are gziped EFI images
    KernelExtension=${KernelImage##*.}
    if [ "$KernelExtension" == "gz" ]; then
        SignImage=${KernelImage%.*}
    else
        SignImage=$KernelImage
    fi

    %ifarch x86_64 aarch64
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name_0}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ $DoModules -eq 1 ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    if [ "$KernelExtension" == "gz" ]; then
        gzip -f9 $SignImage
    fi
    # signkernel
    %endif

    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} -s %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    if [ $DoVDSO -ne 0 ]; then
        %{make} -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ ! -s ldconfig-kernel.conf ]; then
          echo > ldconfig-kernel.conf "\
    # Placeholder file, no vDSO hwcap entries used in this kernel."
        fi
        %{__install} -D -m 444 ldconfig-kernel.conf \
            $RPM_BUILD_ROOT/etc/ld.so.conf.d/%{name}-$KernelVer.conf
        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Flavour" != "zfcpdump" -a "$Flavour" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Flavour:+.${Flavour}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Flavour" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py

    # Files for 'make scripts' to succeed with kernel-devel.
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/security/selinux/include
    cp -a --parents security/selinux/include/classmap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents security/selinux/include/initial_sid_to_string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/include/tools
    cp -a --parents tools/include/tools/be_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%ifarch x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h

    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    if [ -n "%{vmlinux_decompressor}" ]; then
	    eu-readelf -n  %{vmlinux_decompressor} | grep "Build ID" | awk '{print $NF}' > vmlinux.decompressor.id
	    # Without build-id the build will fail. But for s390 the build-id
	    # wasn't added before 5.11. In case it is missing prefer not
	    # packaging the debuginfo over a build failure.
	    if [ -s vmlinux.decompressor.id ]; then
		    cp vmlinux.decompressor.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.decompressor.id
		    cp %{vmlinux_decompressor} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux.decompressor
	    fi
    fi
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'
%if %{with_realtime}
    collect_modules_list kvm \
      'kvm_init|kvmgt_init'
%endif

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    # remove files that will be auto generated by depmod at rpm -i time
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
        rm -f modules.{alias*,builtin.bin,dep*,*map,symbols*,devname,softdep}
    popd

    # Identify modules in the kernel-modules-extras package
    %{SOURCE17} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE19}
    # Identify modules in the kernel-modules-internal package
    %{SOURCE17} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE44} internal
%if %{with_realtime}
    # Identify modules in the kernel-rt-kvm package
    %{SOURCE17} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE400} kvm
%endif

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into kernel-modules-extra in the file lists
    xargs rm -rf < mod-extra.list
    # don't include anything going int kernel-modules-internal in the file lists
    xargs rm -rf < mod-internal.list
%if %{with_realtime}
    # don't include anything going into kernel-rt-kvm in the file lists
    xargs rm -rf < mod-kvm.list
%endif

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	cp $RPM_SOURCE_DIR/filter-*.sh .
	%{SOURCE99} modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

    # remove files that will be auto generated by depmod at rpm -i time
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
        rm -f modules.{alias*,builtin.bin,dep*,*map,symbols*,devname,softdep}
    popd

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    cp -r restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../%{name}${Flavour:+-${Flavour}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../%{name}${Flavour:+-${Flavour}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../%{name}${Flavour:+-${Flavour}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-extra.list >> ../%{name}${Flavour:+-${Flavour}}-modules-extra.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-internal.list >> ../%{name}${Flavour:+-${Flavour}}-modules-internal.list
%if %{with_realtime}
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-kvm.list >> ../%{name}${Flavour:+-${Flavour}}-kvm.list
%endif

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list
    rm -f $RPM_BUILD_ROOT/mod-extra.list
    rm -f $RPM_BUILD_ROOT/mod-internal.list
%if %{with_realtime}
    rm -f $RPM_BUILD_ROOT/mod-kvm.list
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
	# Save the signing keys so we can sign the modules in __modsign_install_post
	cp certs/signing_key.pem certs/signing_key.pem.sign${Flav}
	cp certs/signing_key.x509 certs/signing_key.x509.sign${Flav}
    fi
%endif

%if %{with_cross}
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build M=scripts clean
    sed -i 's/REBUILD_SCRIPTS_FOR_CROSS:=0/REBUILD_SCRIPTS_FOR_CROSS:=1/' $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # Generate vmlinux.h and put it to kernel-devel path
    bpftool btf dump file vmlinux format c > $RPM_BUILD_ROOT/$DevelDir/vmlinux.h

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -exec rm -f {} \;

    # build a BLS config for this kernel
    %{SOURCE43} "$KernelVer" "$RPM_BUILD_ROOT" "%{?variant}"

    # Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
    install -m 0644 %{secureboot_ca_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ $DoModules -eq 1 ]; then
	if [ -x /usr/bin/rpm-sign ]; then
	    install -m 0644 %{secureboot_key_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
	else
	    install -m 0644 certs/signing_key.x509.sign${Flav} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
	    openssl x509 -in certs/signing_key.pem.sign${Flav} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
	    chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
	fi
    fi
    %endif

%if %{with_ipaclones}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Flavour" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{with_vdso_install} debug
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{with_vdso_install} zfcpdump
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{with_vdso_install}
%endif

%ifnarch noarch i686
%if !%{with_debug} && !%{with_zfcpdump} && !%{with_up}
# If only building the user space tools, then initialize the build environment
# and some variables so that the various userspace tools can be built.
InitBuildVars
%endif
%endif

%ifarch aarch64
%global perf_build_extra_opts CORESIGHT=1
%endif
%global perf_make \
  make EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 LIBBPF_DYNAMIC=1 LIBTRACEEVENT_DYNAMIC=1 %{?perf_build_extra_opts} prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
%endif

%global tools_make \
  %{make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" V=1

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{tools_make}
   popd
   pushd tools/power/x86/intel-speed-select
   %{make} CFLAGS+="-D_GNU_SOURCE -Iinclude -I/usr/include/libnl3"
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make}
   popd
%endif
%endif
pushd tools/thermal/tmon/
%{tools_make}
popd
pushd tools/iio/
%{tools_make}
popd
pushd tools/gpio/
%{tools_make}
popd
# build VM tools
pushd tools/vm/
%{tools_make} slabinfo page_owner_sort
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%global bpftool_make \
  make EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT VMLINUX_H="${RPM_VMLINUX_H}" V=1
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%endif

%if %{with_selftests}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{make} %{?_smp_mflags} headers_install
%{make} %{?_smp_mflags} ARCH=$Arch V=1 samples/bpf/

# Prevent bpf selftests to build bpftool repeatedly:
export BPFTOOL=$(pwd)/tools/bpf/bpftool/bpftool

pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} %{?_smp_mflags} ARCH=$Arch V=1 TARGETS="bpf mm livepatch net net/forwarding net/mptcp netfilter tc-testing" FORCE_TARGETS=1 INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests VMLINUX_H="${RPM_VMLINUX_H}" install

# 'make install' for bpf is broken and upstream refuses to fix it.
# Install the needed files manually.
for dir in bpf bpf/no_alu32 bpf/progs; do
	mkdir -p %{buildroot}%{_libexecdir}/kselftests/$dir
	find $dir -maxdepth 1 -type f \( -executable -o -name '*.py' -o -name settings -o \
		-name 'btf_dump_test_case_*.c' -o -name '*.ko' -o \
		-name '*.o' -exec sh -c 'readelf -h "{}" | grep -q "^  Machine:.*BPF"' \; \) -print0 | \
	xargs -0 cp -t %{buildroot}%{_libexecdir}/kselftests/$dir
done
popd
export -n BPFTOOL
%endif

%if %{with_doc}
# Make the HTML pages.
make htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "flavour" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that flavour.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump flavour as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_debug}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | %{SOURCE80} %{?_smp_mflags}; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# with_doc
%endif

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

%endif

%if %{with_cross_headers}
HDR_ARCH_LIST='arm64 powerpc s390 x86'
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers
%{make} ARCH=%{hdrarch} HDR_ARCH_LIST="$HDR_ARCH_LIST" INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers headers_install_all

find $RPM_BUILD_ROOT/usr/tmp-headers/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
mv $RPM_BUILD_ROOT/usr/tmp-headers/include/arch-${arch}/asm $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
cp -a $RPM_BUILD_ROOT/usr/tmp-headers/include/asm-generic $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/.
done

# Remove the rest of the architectures
rm -rf $RPM_BUILD_ROOT/usr/tmp-headers/include/arch*
rm -rf $RPM_BUILD_ROOT/usr/tmp-headers/include/asm-*

# Copy the rest of the headers over
for arch in $HDR_ARCH_LIST ; do
cp -a $RPM_BUILD_ROOT/usr/tmp-headers/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/.
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_stablelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
# with_kernel_abi_stablelists
%endif

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/examples/perf
# remove the stray header file that somehow got packaged in examples
rm -rf %{buildroot}/usr/lib/include/perf/bpf/bpf.h

# remove perf-bpf examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man

# remove any tracevent files, eg. its plugins still gets built and installed,
# even if we build against system's libtracevent during perf build (by setting
# LIBTRACEEVENT_DYNAMIC=1 above in perf_make macro). Those files should already
# ship with libtraceevent package.
rm -rf %{buildroot}%{_libdir}/traceevent
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make} CFLAGS+="-D_GNU_SOURCE -Iinclude -I/usr/include/libnl3" DESTDIR=%{buildroot} install
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} DESTDIR=%{buildroot} install
   popd
%endif
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
install -m644 -D %{SOURCE2002} %{buildroot}%{_sysconfdir}/logrotate.d/kvm_stat
pushd tools/kvm/kvm_stat
make INSTALL_ROOT=%{buildroot} install-tools
make INSTALL_ROOT=%{buildroot} install-man
install -m644 -D kvm_stat.service %{buildroot}%{_unitdir}/kvm_stat.service
popd
# install VM tools
pushd tools/vm/
install -m755 slabinfo %{buildroot}%{_bindir}/slabinfo
install -m755 page_owner_sort %{buildroot}%{_bindir}/page_owner_sort
popd
%endif

# We don't call InitBuildVars in install section so $DevelDir
# variable is not defined. Using the $DevelDir definition
# directly.
if [ -f /usr/src/kernels/%{KVERREL}/vmlinux.h ]; then
  RPM_VMLINUX_H=/usr/src/kernels/%{KVERREL}/vmlinux.h
fi

%if !%{with_realtime}
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
# bpf-helpers.7 manpage has been moved under samples
# a01d935b2e09 ("tools/bpf: Remove bpf-helpers from bpftool docs")
pushd tools/testing/selftests/bpf
make -f Makefile.docs DESTDIR=$RPM_BUILD_ROOT mandir=%{_mandir} docs-install
popd
%endif
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install mm selftests
pushd tools/testing/selftests/mm
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install drivers/net/netdevsim selftests
pushd tools/testing/selftests/drivers/net/netdevsim
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install net/mptcp selftests
pushd tools/testing/selftests/net/mptcp
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
# install netfilter selftests
pushd tools/testing/selftests/netfilter
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
popd
%endif

# We have to do the headers checksum calculation after the tools install because
# these might end up installing their own set of headers on top of kernel's
%if %{with_headers}
# compute a content hash to export as Provides: kernel-headers-checksum
HEADERS_CHKSUM=$(export LC_ALL=C; find $RPM_BUILD_ROOT/usr/include -type f -name "*.h" \
			! -path $RPM_BUILD_ROOT/usr/include/linux/version.h | \
		 sort | xargs cat | sha1sum - | cut -f 1 -d ' ');
# export the checksum via usr/include/linux/version.h, so the dynamic
# find-provides can grab the hash to update it accordingly
echo "#define KERNEL_HEADERS_CHECKSUM \"$HEADERS_CHKSUM\"" >> $RPM_BUILD_ROOT/usr/include/linux/version.h
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%if %{with_tools}

%post -n %{name}-tools
%systemd_post cpupower.service

%preun -n %{name}-tools
%systemd_preun cpupower.service

%postun -n %{name}-tools
%systemd_postun cpupower.service

%post -n %{name}-tools-libs
/sbin/ldconfig

%postun -n %{name}-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f\
     done)\
fi\
%if %{with_cross}\
    echo "Building scripts"\
    env --unset=ARCH make -C /usr/src/kernels/%{KVERREL}%{?1:+%{1}} prepare_after_cross\
%endif\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

%if %{with_realtime}
#
# This macro defines a %%post script for a kernel*-kvm package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_kvm_post [<subpackage>]
#
%define kernel_kvm_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}
%endif

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
if [ ! -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}} ]; then\
	mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
	touch %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
fi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%posttrans %{?1:%{1}-}modules}\
if [ -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}} ]; then\
	rm -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
	echo "Running: dracut -f --kver %{KVERREL}%{?1:+%{1}}"\
	dracut -f --kver "%{KVERREL}%{?1:+%{1}}" || exit $?\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1:%{1}-}core}\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
rm -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}}\
/bin/kernel-install add %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
touch %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1:%{1}-}core}\
/bin/kernel-install remove %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
%{nil}

%kernel_variant_preun
%kernel_variant_post -r kernel-smp
%if %{with_realtime}
%kernel_kvm_post
%endif

%kernel_variant_preun debug
%kernel_variant_post -v debug
%if %{with_realtime}
%kernel_kvm_post debug
%endif

%if %{with_zfcpdump}
%kernel_variant_preun zfcpdump
%kernel_variant_post -v zfcpdump
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%exclude %{_includedir}/cpufreq.h
%endif

%if %{with_cross_headers}
%files cross-headers
%defattr(-,root,root)
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_stablelists}
%files -n kernel-abi-stablelists
%defattr(-,root,root,-)
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}
%endif

%if %{with_perf}
%files -n perf
%defattr(-,root,root)
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%defattr(-,root,root)
%{python3_sitearch}/*

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo
%defattr(-,root,root)

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo
%defattr(-,root,root)
%endif
# with_perf
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%defattr(-,root,root)
%files -n %{name}-tools -f cpupower.lang
%{_bindir}/cpupower
%{_datadir}/bash-completion/completions/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%{_bindir}/intel-speed-select
%{_sbindir}/intel_sdsi
%endif
# !cpupowerarchs
%else
%files -n %{name}-tools
%defattr(-,root,root)
# cpupowerarchs
%endif
%{_bindir}/tmon
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat
%{_unitdir}/kvm_stat.service
%config(noreplace) %{_sysconfdir}/logrotate.d/kvm_stat
%{_bindir}/page_owner_sort
%{_bindir}/slabinfo

%if %{with_debuginfo}
%files -f %{name}-tools-debuginfo.list -n %{name}-tools-debuginfo
%defattr(-,root,root)
%endif

%ifarch %{cpupowerarchs}
%files -n %{name}-tools-libs
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.1

%files -n %{name}-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif
# with_tools
%endif

%if !%{with_realtime}
%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz
%{_mandir}/man7/bpf-helpers.7.gz
%{_mandir}/man8/bpftool-net.8.gz
%{_mandir}/man8/bpftool-feature.8.gz
%{_mandir}/man8/bpftool-btf.8.gz
%{_mandir}/man8/bpftool-gen.8.gz
%{_mandir}/man8/bpftool-struct_ops.8.gz
%{_mandir}/man8/bpftool-iter.8.gz
%{_mandir}/man8/bpftool-link.8.gz
%{_mandir}/man2/bpf-syscall.2.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%ifnarch %nobuildarches noarch
%files
%defattr(-,root,root)
%endif

%if %{with_gcov}
%ifarch x86_64 s390x ppc64le aarch64
%files gcov
%defattr(-,root,root)
%{_builddir}
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage> <without_modules>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files -f %{name}-%{?3:%{3}-}core.list %{?3:%{3}-}core}\
%defattr(-,root,root)\
%{!?_licensedir:%global license %%doc}\
%license linux-%{KVERREL}/COPYING-%{version}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost %attr(0600, root, root) /boot/System.map-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
%ghost %attr(0600, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/bls.conf\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
/etc/ld.so.conf.d/%{name}-%{KVERREL}%{?3:+%{3}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.*\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%defattr(-,root,root)\
%{expand:%%files %{?3:%{3}-}devel}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%defattr(-,root,root)\
%config(noreplace) /etc/modprobe.d/*-blacklist.conf\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules-internal.list %{?3:%{3}-}modules-internal}\
%if %{with_realtime}\
%{expand:%%files -f %{name}-%{?3:%{3}-}kvm.list %{?3:%{3}-}kvm}\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%defattr(-,root,root)\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%defattr(-,root,root)\
%endif\
%endif\
%{nil}

%kernel_variant_files  %{with_vdso_install} %{with_up}
%kernel_variant_files  %{with_vdso_install} %{with_debug} debug
%kernel_variant_files  %{with_vdso_install} %{with_zfcpdump} zfcpdump 1

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Thu Apr 10 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.50.1.el8_10]
- perf debug: Set debug_peo_args and redirect_to_stderr variable to correct values in perf_quiet_option() (Michael Petlan) [RHEL-82119]
- ALSA: usb-audio: Fix out of bounds reads when finding clock sources (Jarod Wilson) [RHEL-86737] {CVE-2024-53150}
- scsi: storvsc: Set correct data length for sending SCSI command without payload (Cathy Avery) [RHEL-83052]
- ice: fold ice_ptp_read_time into ice_ptp_gettimex64 (Michal Schmidt) [RHEL-85852]
- ice: avoid the PTP hardware semaphore in gettimex64 path (Michal Schmidt) [RHEL-85852]
- ice: add ice_adapter for shared data across PFs on the same NIC (Michal Schmidt) [RHEL-85852]

* Thu Apr 03 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.49.1.el8_10]
- net/mlx5: Fix error path in multi-packet WQE transmit (CKI Backport Bot) [RHEL-84244]
- redhat: drop Y issues from changelog (Jan Stancek)
- md/md-bitmap: fix writing non bitmap changes local to RHEL (Nigel Croxon) [RHEL-80673]
- md/md-bitmap: fix writing non bitmap pages (Nigel Croxon) [RHEL-80673]
- md-bitmap: use %%pD to print the file name in md_bitmap_file_kick (Nigel Croxon) [RHEL-80673]
- md-bitmap: initialize variables at declaration time in md_bitmap_file_unmap (Nigel Croxon) [RHEL-80673]
- md-bitmap: set BITMAP_WRITE_ERROR in write_sb_page (Nigel Croxon) [RHEL-80673]
- raid1: update discard granularity when adding new disk (Nigel Croxon) [RHEL-71499]
- x86/xen: remove hypercall page (Vitaly Kuznetsov) [RHEL-70666] {CVE-2024-53241}
- x86/xen: use new hypercall functions instead of hypercall page (Vitaly Kuznetsov) [RHEL-70666] {CVE-2024-53241}

* Thu Mar 27 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.48.1.el8_10]
- rhel-8.10: gate kernel on kernel-qe tests results not cki ones (Bruno Goncalves)
- gfs2: skip if we cannot defer delete (Andreas Gruenbacher) [RHEL-76208]
- gfs2: remove redundant warnings (Andreas Gruenbacher) [RHEL-76208]
- gfs2: minor evict fix (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Prevent inode creation race (2) (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Fix additional unlikely request cancelation race (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Fix request cancelation bug (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Check for empty queue in run_queue (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Remove more dead code in add_to_queue (Andreas Gruenbacher) [RHEL-76208]
- gfs2: remove dead code in add_to_queue (Su Hui) [RHEL-76208]
- gfs2: Remove LM_FLAG_PRIORITY flag (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Replace GIF_DEFER_DELETE with GLF_DEFER_DELETE (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Add GLF_PENDING_REPLY flag (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Remove and replace gfs2_glock_queue_work (Andreas Gruenbacher) [RHEL-76208]
- gfs2: do_xmote fixes (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Clear flags when withdraw prevents xmote (Bob Peterson) [RHEL-76208]
- gfs2: fix a deadlock on withdraw-during-mount (Bob Peterson) [RHEL-76208]
- gfs2: gfs2_evict_inode clarification (Andreas Gruenbacher) [RHEL-76208]
- gfs2: Remove misleading comments in gfs2_evict_inode (Andreas Gruenbacher) [RHEL-76208]

* Thu Mar 20 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.47.1.el8_10]
- nfs: don't invalidate dentries on transient errors (Scott Mayhew) [RHEL-78136]
- ethtool: runtime-resume netdev parent before ethtool ioctl ops (John J Coleman) [RHEL-78156]
- bpf: Use raw_spinlock_t in ringbuf (Viktor Malik) [RHEL-79911] {CVE-2024-50138}

* Thu Mar 13 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.46.1.el8_10]
- s390/pci: Fix handling of isolated VFs (Mete Durlu) [RHEL-81934]
- s390/pci: Pull search for parent PF out of zpci_iov_setup_virtfn() (Mete Durlu) [RHEL-81934]
- s390/pci: Fix SR-IOV for PFs initially in standby (Mete Durlu) [RHEL-81934]
- x86/mm: Fix VDSO and VVAR placement on 5-level paging machines (Herton R. Krzesinski) [RHEL-62832]
- arm64: cacheinfo: Avoid out-of-bounds write to cacheinfo array (CKI Backport Bot) [RHEL-82720] {CVE-2025-21785}
- nouveau/fence: handle cross device fences properly (Dave Airlie) [RHEL-80085]

* Thu Mar 06 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.45.1.el8_10]
- gve: trigger RX NAPI instead of TX NAPI in gve_xsk_wakeup (Joshua Washington) [RHEL-73269]
- gve: process XSK TX descriptors as part of RX NAPI (Joshua Washington) [RHEL-73269]
- gve: guard XSK operations on the existence of queues (Joshua Washington) [RHEL-73269]
- gve: guard XDP xmit NDO on existence of xdp queues (Joshua Washington) [RHEL-73269]
- gve: Fix an edge case for TSO skb validity check (Joshua Washington) [RHEL-73269]
- gve: Fix XDP TX completion handling when counters overflow (Joshua Washington) [RHEL-73269]
- gve: Clear napi->skb before dev_kfree_skb_any() (Joshua Washington) [RHEL-73269] {CVE-2024-40937}
- gve: ignore nonrelevant GSO type bits when processing TSO headers (Joshua Washington) [RHEL-73269]
- can: bcm: Fix UAF in bcm_proc_show() (CKI Backport Bot) [RHEL-80733] {CVE-2023-52922}
- gfs2: glock holder GL_NOPID fix (Andreas Gruenbacher) [RHEL-80694]
- gfs2: Decode missing glock flags in tracepoints (Andreas Gruenbacher) [RHEL-80694]
- net/smc: support ipv4 mapped ipv6 addr client for smc-r v2 (Mete Durlu) [RHEL-79810]
- net: smc: fix spurious error message from __sock_release() (Mete Durlu) [RHEL-79812]

* Wed Mar 05 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.44.1.el8_10]
- HID: core: zero-initialize the report buffer (CKI Backport Bot) [RHEL-81825] {CVE-2024-50302}
- ALSA: usb-audio: Fix a DMA to stack memory bug (Jaroslav Kysela) [RHEL-81786]
- ALSA: usb-audio: Fix for sampling rates support for Mbox3 (Jaroslav Kysela) [RHEL-81786]
- ALSA: usb-audio: Fix potential out-of-bound accesses for Extigy and Mbox devices (Jaroslav Kysela) [RHEL-81786] {CVE-2024-53197}
- ALSA: usb-audio: Add sampling rates support for Mbox3 (Jaroslav Kysela) [RHEL-81786]

* Thu Feb 27 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.43.1.el8_10]
- s390/module: fix loading modules with a lot of relocations (Mete Durlu) [RHEL-78999]
- s390/module: Use s390_kernel_write() for late relocations (Mete Durlu) [RHEL-78999]
- locking/atomic: Make test_and_*_bit() ordered on failure (Herton R. Krzesinski) [RHEL-69894]
- pps: Fix a use-after-free (Michal Schmidt) [RHEL-77971]
- KVM: s390: Change virtual to physical address access in diag 0x258 handler (Thomas Huth) [RHEL-68323 RHEL-65229]
- KVM: s390: gaccess: Check if guest address is in memslot (Thomas Huth) [RHEL-68323 RHEL-65229]
- KVM: s390: Fix SORTL and DFLTCC instruction format error in __insn32_query (Thomas Huth) [RHEL-68323 RHEL-65229]
- s390/uv: Panic for set and remove shared access UVC errors (Thomas Huth) [RHEL-68323 RHEL-65229]
- KVM: s390: vsie: Use virt_to_phys for crypto control block (Thomas Huth) [RHEL-68323 RHEL-65229]
- KVM: s390: vsie: Use virt_to_phys for facility control block (Thomas Huth) [RHEL-68323 RHEL-65229]
- scsi: megaraid_sas: Fix for a potential deadlock (Tomas Henzl) [RHEL-21984] {CVE-2024-57807}
- net/mlx5: Reload auxiliary devices in pci error handlers (Benjamin Poirier) [RHEL-78756]
- net/mlx5: Suspend auxiliary devices only in case of PCI device suspend (Benjamin Poirier) [RHEL-78756]

* Thu Feb 20 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.42.1.el8_10]
- net: skb: exclude the single page frag cache for too small alloc (Paolo Abeni) [RHEL-66261]
- NFSD: Reset cb_seq_status after NFS4ERR_DELAY (Olga Kornievskaia) [RHEL-79458]
- mm: vmscan: account for free pages to prevent infinite Loop in throttle_direct_reclaim() (Seiji Nishikawa) [RHEL-64950]
- scsi: st: Don't set pos_unknown just after device recognition (John Meneghini) [RHEL-78415]
- ovl: fix use inode directly in rcu-walk mode (Miklos Szeredi) [RHEL-76161]
- RDMA/cxgb4: Fix RDMA_CM_EVENT_UNREACHABLE error for iWARP (Kamal Heib) [RHEL-75826]

* Fri Feb 14 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.41.1.el8_10]
- virtio-net: correctly enable callback during start_xmit (Laurent Vivier) [RHEL-72886]
- dm snapshot: fix lockup in dm_exception_table_exit (Benjamin Marzinski) [RHEL-76230 RHEL-34599]

* Thu Feb 06 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.40.1.el8_10]
- media: uvcvideo: Skip parsing frames of type UVC_VS_UNDEFINED in uvc_parse_format (Desnes Nunes) [RHEL-69571] {CVE-2024-53104}

* Fri Jan 31 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.39.1.el8_10]
- gfs2: Truncate address space when flipping GFS2_DIF_JDATA flag (Andreas Gruenbacher) [RHEL-73915]

* Thu Jan 23 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.38.1.el8_10]
- net: usb: lan78xx: add Allied Telesis AT29M2-AF (Jose Ignacio Tornos Martinez) [RHEL-70891]
- s390/pci: Allow allocation of more than 1 MSI interrupt (Mete Durlu) [RHEL-74385]
- s390/pci: Refactor arch_setup_msi_irqs() (Mete Durlu) [RHEL-74385]
- s390/pci: Fix leak of struct zpci_dev when zpci_add_device() fails (Mete Durlu) [RHEL-71451]
- s390/pci: Ignore RID for isolated VFs (Mete Durlu) [RHEL-71451]
- s390/pci: Use topology ID for multi-function devices (Mete Durlu) [RHEL-71451]
- s390/pci: Sort PCI functions prior to creating virtual busses (Mete Durlu) [RHEL-71451]
- s390/iucv: MSG_PEEK causes memory leak in iucv_sock_destruct() (Mete Durlu) [RHEL-74387]
- s390/pci: Handle PCI error codes other than 0x3a (Mete Durlu) [RHEL-74383]

* Fri Jan 17 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.37.1.el8_10]
- arm64/sve: Discard stale CPU state when handling SVE traps (Mark Salter) [RHEL-71535] {CVE-2024-50275}
- scsi: core: Handle devices which return an unusually large VPD page count (Ewan D. Milne) [RHEL-34275]
- scsi: core: Fix unremoved procfs host directory regression (Ewan D. Milne) [RHEL-34275]
- scsi: core: Consult supported VPD page list prior to fetching page (Ewan D. Milne) [RHEL-34275]
- NFSv4: Fix dropped lock for racing OPEN and delegation return (Benjamin Coddington) [RHEL-73889]

* Thu Jan 09 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.36.1.el8_10]
- cpufreq: intel_pstate: Support Emerald Rapids OOB mode (David Arcari) [RHEL-59649]
- scsi: st: New session only when Unit Attention for new tape (John Meneghini) [RHEL-28790]
- scsi: st: Add MTIOCGET and MTLOAD to ioctls allowed after device reset (John Meneghini) [RHEL-28790]
- scsi: st: Don't modify unknown block number in MTIOCGET (John Meneghini) [RHEL-28790]
- Reapply "scsi: st: Add third party poweron reset handling" (John Meneghini) [RHEL-28790]

* Thu Jan 02 2025 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.35.1.el8_10]
- samples: pktgen: allow to specify destination port (Hangbin Liu) [RHEL-56480]
- samples: pktgen: add some helper functions for port parsing (Hangbin Liu) [RHEL-56480]
- scsi: storvsc: Do not flag MAINTENANCE_IN return of SRB_STATUS_DATA_OVERRUN as an error (Cathy Avery) [RHEL-71396]
- scsi: storvsc: Handle additional SRB status values (Cathy Avery) [RHEL-71396]

* Thu Dec 12 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.34.1.el8_10]
- mptcp: cope racing subflow creation in mptcp_rcv_space_adjust (Davide Caratti) [RHEL-69667] {CVE-2024-53122}
- NFS: nfs_async_write_reschedule_io must not recurse into the writeback code (Benjamin Coddington) [RHEL-68647]
- xfs: fix sparse inode limits on runt AG (Pavel Reichl) [RHEL-62924]
- KVM: SVM: Get source vCPUs from source VM for SEV-ES intrahost migration (Maxim Levitsky) [RHEL-67974]
- x86/cpu/intel: Detect TME keyid bits before setting MTRR mask registers (Vitaly Kuznetsov) [RHEL-65362]
- dlm: fix recovery of middle conversions (Alexander Aring) [RHEL-64860]
- i40e: fix race condition by adding filter's intermediate sync state (Michal Schmidt) [RHEL-68271] {CVE-2024-53088}
- i40e: fix i40e_count_filters() to count only active/new filters (Michal Schmidt) [RHEL-68271] {CVE-2024-53088}

* Fri Dec 06 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.33.1.el8_10]
- Revert "scsi: lpfc: Fix mbuf pool resource detected as busy at driver unload" This patch is dependent on the mbox refactor patch that was not added to rh8. (Dick Kennedy) [RHEL-64073]
- drm/i915: Fix HPD polling, reenabling the output poll work as needed (Lyude Paul) [RHEL-62796]
- drm: Add an HPD poll helper to reschedule the poll work (Lyude Paul) [RHEL-62796]

* Fri Nov 29 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.32.1.el8_10]
- irqchip/gic-v4: Correctly deal with set_affinity on lazily-mapped VPEs (Charles Mirabile) [RHEL-66965] {CVE-2024-50192}
- irqchip/gic-v4: Don't allow a VMOVP on a dying VPE (Charles Mirabile) [RHEL-66965] {CVE-2024-50192}
- blk-rq-qos: fix crash on rq_qos_wait vs. rq_qos_wake_function race (Ming Lei) [RHEL-65158] {CVE-2024-50082}
- gfs2: fix double destroy_workqueue error (Andreas Gruenbacher) [RHEL-62869]
- Revert "GFS2: Don't add all glocks to the lru" (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Use list_move_tail instead of list_del/list_add_tail (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Revise glock reference counting model (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Switch to a per-filesystem glock workqueue (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Report when glocks cannot be freed for a long time (Andreas Gruenbacher) [RHEL-62869]
- gfs2: gfs2_glock_get cleanup (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Invert the GLF_INITIAL flag (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Rename handle_callback to request_demote (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Rename GLF_FROZEN to GLF_HAVE_FROZEN_REPLY (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Rename GLF_REPLY_PENDING to GLF_HAVE_REPLY (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Rename GLF_FREEING to GLF_UNLOCKED (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Remove useless return statement in run_queue (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Remove unnecessary function prototype (Andreas Gruenbacher) [RHEL-62869]
- gfs2: finish_xmote cleanup (Andreas Gruenbacher) [RHEL-62869]
- gfs2: Replace gfs2_glock_queue_put with gfs2_glock_put_async (Andreas Gruenbacher) [RHEL-62869]
- KVM: selftests: memslot_perf_test: increase guest sync timeout (Maxim Levitsky) [RHEL-19080]
- vsock/virtio: Initialization of the dangling pointer occurring in vsk->trans (Jon Maloy) [RHEL-68025] {CVE-2024-50264}
- md/raid5: Wait sync io to finish before changing group cnt (Nigel Croxon) [RHEL-58585]

* Fri Nov 22 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.31.1.el8_10]
- xfrm: fix one more kernel-infoleak in algo dumping (Sabrina Dubroca) [RHEL-65955] {CVE-2024-50110}
- netfilter: nf_reject_ipv6: fix potential crash in nf_send_reset6() (Florian Westphal) [RHEL-66862] {CVE-2024-50256}
- netfilter: nf_reject: Fix build warning when CONFIG_BRIDGE_NETFILTER=n (Florian Westphal) [RHEL-66862]
- netfilter: nf_reject_ipv6: fix nf_reject_ip6_tcphdr_put() (Florian Westphal) [RHEL-66862]
- cifs: fix return of uninitialized rc in dfs_cache_update_tgthint() (Paulo Alcantara) [RHEL-7988]
- cifs: handle cache lookup errors different than -ENOENT (Paulo Alcantara) [RHEL-7988]
- cifs: don't take exclusive lock for updating target hints (Paulo Alcantara) [RHEL-7988]
- cifs: avoid re-lookups in dfs_cache_find() (Paulo Alcantara) [RHEL-7988]
- cifs: fix potential deadlock in cache_refresh_path() (Paulo Alcantara) [RHEL-7988]
- cifs: don't refresh cached referrals from unactive mounts (Paulo Alcantara) [RHEL-7988]
- cifs: return ENOENT for DFS lookup_cache_entry() (Paulo Alcantara) [RHEL-7988]
- selinux,smack: don't bypass permissions check in inode_setsecctx hook (Ondrej Mosnacek) [RHEL-66104] {CVE-2024-46695}
- gfs2: Prevent inode creation race (Andreas Gruenbacher) [RHEL-67823]
- gfs2: Only defer deletes when we have an iopen glock (Andreas Gruenbacher) [RHEL-67823]
- arm64: probes: Remove broken LDR (literal) uprobe support (Mark Salter) [RHEL-66042] {CVE-2024-50099}
- net: avoid potential underflow in qdisc_pkt_len_init() with UFO (Davide Caratti) [RHEL-65399] {CVE-2024-49949}
- xfrm: validate new SA's prefixlen using SA family when sel.family is unset (Sabrina Dubroca) [RHEL-66457] {CVE-2024-50142}

* Fri Nov 15 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.30.1.el8_10]
- media: edia: dvbdev: fix a use-after-free (Kate Hsuan) [RHEL-35763] {CVE-2024-27043}
- blk-mq: fix missing blk_account_io_done() in error path (Ming Lei) [RHEL-61200]
- rbd: don't assume rbd_is_lock_owner() for exclusive mappings (Ilya Dryomov) [RHEL-52684]
- rbd: don't assume RBD_LOCK_STATE_LOCKED for exclusive mappings (Ilya Dryomov) [RHEL-52684]
- rbd: rename RBD_LOCK_STATE_RELEASING and releasing_wait (Ilya Dryomov) [RHEL-52684]
- smb: client: use actual path when queryfs (Paulo Alcantara) [RHEL-60363]
- cifs: Fix uninitialized memory reads for oparms.mode (Paulo Alcantara) [RHEL-60363]
- cifs: Fix uninitialized memory read for smb311 posix symlink create (Paulo Alcantara) [RHEL-60363]
- cifs: convert the path to utf16 in smb2_query_info_compound (Paulo Alcantara) [RHEL-60363]
- autofs: fix thinko in validate_dev_ioctl() (Ian Kent) [RHEL-62168]
- autofs: add per dentry expire timeout (Ian Kent) [RHEL-62168]
- bpf: Add BPF_PROG_TYPE_CGROUP_SKB attach type enforcement in BPF_LINK_CREATE (Viktor Malik) [RHEL-44167] {CVE-2024-38564}

* Thu Nov 07 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.29.1.el8_10]
- Bluetooth: l2cap: fix null-ptr-deref in l2cap_chan_timeout (cki-backport-bot) [RHEL-36372] {CVE-2024-27399}
- mptcp: pm: Fix uaf in __timer_delete_sync (Guillaume Nault) [RHEL-60614] {CVE-2024-46858}
- cifs: fix dfs link failover in cifs_tree_connect() (Paulo Alcantara) [RHEL-8002]

* Thu Oct 31 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.28.1.el8_10]
- s390/mm: Add cond_resched() to cmm_alloc/free_pages() (Mete Durlu) [RHEL-61702]
- smb: client: fix deadlock in smb2_find_smb_tcon() (Paulo Alcantara) [RHEL-61400]
- smb: client: fix potential deadlock when releasing mids (Paulo Alcantara) [RHEL-61400]
- cifs: remove useless DeleteMidQEntry() (Paulo Alcantara) [RHEL-61400]
- Bluetooth: af_bluetooth: Fix deadlock (CKI Backport Bot) [RHEL-58991]
- gitlab-ci: provide consistent kcidb_tree_name (Michael Hofmann)
- x86/mm/ident_map: Use gbpages only where full GB page should be mapped. (Nico Pache) [RHEL-26709]
- audit: Send netlink ACK before setting connection in auditd_set (Richard Guy Briggs) [RHEL-14004]
- KVM: selftests: x86: Fix test failure on arch lbr capable platforms (Maxim Levitsky) [RHEL-23999]
- raid1: fix use-after-free for original bio in raid1_write_request() (Nigel Croxon) [RHEL-55263]

* Thu Oct 17 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.27.1.el8_10]
- lib/generic-radix-tree.c: Fix rare race in __genradix_ptr_alloc() (Waiman Long) [RHEL-62139] {CVE-2024-47668}
- bonding: fix xfrm real_dev null pointer dereference (Hangbin Liu) [RHEL-57239] {CVE-2024-44989}
- bonding: fix null pointer deref in bond_ipsec_offload_ok (Hangbin Liu) [RHEL-57233] {CVE-2024-44990}
- bpf: Fix overrunning reservations in ringbuf (Viktor Malik) [RHEL-49414] {CVE-2024-41009}
- xprtrdma: fix pointer derefs in error cases of rpcrdma_ep_create (CKI Backport Bot) [RHEL-49309] {CVE-2022-48773}
- tty: tty_io: update timestamps on all device nodes (Aristeu Rozanski) [RHEL-55257]
- tty: use 64-bit timstamp (Aristeu Rozanski) [RHEL-55257]
- ELF: fix kernel.randomize_va_space double read (Rafael Aquini) [RHEL-60669] {CVE-2024-46826}
- xfrm: set dst dev to blackhole_netdev instead of loopback_dev in ifdown (Xin Long) [RHEL-58100]
- loopback: fix lockdep splat (Xin Long) [RHEL-58100]
- blackhole_netdev: use blackhole_netdev to invalidate dst entries (Xin Long) [RHEL-58100]
- loopback: create blackhole net device similar to loopack. (Xin Long) [RHEL-58100]

* Wed Oct 09 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.26.1.el8_10]
- nouveau: lock the client object tree. (Abdiel Janulgue) [RHEL-35118] {CVE-2024-27062}
- cifs: fix deadlock between reconnect and lease break (Paulo Alcantara) [RHEL-58037]
- ACPI: PAD: fix crash in exit_round_robin() (Mark Langsdorf) [RHEL-56156]
- gfs2: Randomize GLF_VERIFY_DELETE work delay (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Use mod_delayed_work in gfs2_queue_try_to_evict (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Update to the evict / remote delete documentation (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Clean up delete work processing (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Return enum evict_behavior from gfs2_upgrade_iopen_glock (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Rename dinode_demise to evict_behavior (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Rename GIF_{DEFERRED -> DEFER}_DELETE (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Faster gfs2_upgrade_iopen_glock wakeups (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Fix unlinked inode cleanup (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Initialize gl_no_formal_ino earlier (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Rename GLF_VERIFY_EVICT to GLF_VERIFY_DELETE (Andreas Gruenbacher) [RHEL-35757]
- gfs2: make timeout values more explicit (Wolfram Sang) [RHEL-35757]
- gfs2: Simplify function gfs2_upgrade_iopen_glock (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Rename SDF_DEACTIVATING to SDF_KILL (Andreas Gruenbacher) [RHEL-35757]
- gfs2: Cease delete work during unmount (Bob Peterson) [RHEL-35757]
- gfs2: Improve gfs2_upgrade_iopen_glock comment (Andreas Gruenbacher) [RHEL-35757]
- gfs2: nit: gfs2_drop_inode shouldn't return bool (Bob Peterson) [RHEL-35757]
- dmaengine: fix NULL pointer in channel unregistration function (Jerry Snitselaar) [RHEL-28867] {CVE-2023-52492}
- dma-direct: Leak pages on dma_set_decrypted() failure (Jerry Snitselaar) [RHEL-37335] {CVE-2024-35939}
- nfsd: fix delegation_blocked() to block correctly for at least 30 seconds (Olga Kornievskaia) [RHEL-41075]
- NFSv4: Always ask for type with READDIR (Benjamin Coddington) [RHEL-39397]
- cifs: get rid of unneeded conditional in cifs_get_num_sgs() (Paulo Alcantara) [RHEL-60251]
- cifs: Get rid of unneeded conditional in the smb2_get_aead_req() (Paulo Alcantara) [RHEL-60251]
- cifs: Remove duplicated include in cifsglob.h (Paulo Alcantara) [RHEL-60251]
- cifs: fix oops during encryption (Paulo Alcantara) [RHEL-60251]

* Wed Oct 02 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.25.1.el8_10]
- cifs: modefromsids must add an ACE for authenticated users (Paulo Alcantara) [RHEL-56052]
- cifs: do not use uninitialized data in the owner/group sid (Paulo Alcantara) [RHEL-56052]
- cifs: fix set of group SID via NTSD xattrs (Paulo Alcantara) [RHEL-56052]
- smb3: correct smb3 ACL security descriptor (Paulo Alcantara) [RHEL-56052]
- smb3: fix possible access to uninitialized pointer to DACL (Paulo Alcantara) [RHEL-56052]
- cifs: remove two cases where rc is set unnecessarily in sid_to_id (Paulo Alcantara) [RHEL-56052]
- cifs: Fix chmod with modefromsid when an older ACE already exists. (Paulo Alcantara) [RHEL-56052]
- cifs: update new ACE pointer after populate_new_aces. (Paulo Alcantara) [RHEL-56052]
- cifs: If a corrupted DACL is returned by the server, bail out. (Paulo Alcantara) [RHEL-56052]
- cifs: cleanup a few le16 vs. le32 uses in cifsacl.c (Paulo Alcantara) [RHEL-56052]
- cifs: Change SIDs in ACEs while transferring file ownership. (Paulo Alcantara) [RHEL-56052]
- cifs: Retain old ACEs when converting between mode bits and ACL. (Paulo Alcantara) [RHEL-56052]
- cifs: Fix cifsacl ACE mask for group and others. (Paulo Alcantara) [RHEL-56052]
- Add SMB 2 support for getting and setting SACLs (Paulo Alcantara) [RHEL-56052]
- SMB3: Add support for getting and setting SACLs (Paulo Alcantara) [RHEL-56052]
- cifs: Enable sticky bit with cifsacl mount option. (Paulo Alcantara) [RHEL-56052]
- cifs: Fix unix perm bits to cifsacl conversion for "other" bits. (Paulo Alcantara) [RHEL-56052]
- drm/i915/gt: Fix potential UAF by revoke of fence registers (Mika Penttilä) [RHEL-53633] {CVE-2024-41092}
- scsi: lpfc: Validate hdwq pointers before dereferencing in reset/errata paths (Dick Kennedy) [RHEL-27224]
- kobject_uevent: Fix OOB access within zap_modalias_env() (Rafael Aquini) [RHEL-55000] {CVE-2024-42292}
- gfs2: Fix NULL pointer dereference in gfs2_log_flush (Andrew Price) [RHEL-51553] {CVE-2024-42079}
- of: module: add buffer overflow check in of_modalias() (Charles Mirabile) [RHEL-44267] {CVE-2024-38541}

* Wed Sep 25 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.24.1.el8_10]
- cifs: do not set WorkstationName in NTLMSSP auth blob (Paulo Alcantara) [RHEL-56729]
- padata: Fix possible divide-by-0 panic in padata_mt_helper() (Steve Best) [RHEL-56162] {CVE-2024-43889}
- i40e: Fix wrong check for I40E_TXR_FLAGS_WB_ON_ITR (CKI Backport Bot) [RHEL-57000]
- sctp: Fix null-ptr-deref in reuseport_add_sock(). (Xin Long) [RHEL-56234] {CVE-2024-44935}
- net/mlx5e: Fix netif state handling (Michal Schmidt) [RHEL-43864] {CVE-2024-38608}
- net/mlx5e: Add wrapping for auxiliary_driver ops and remove unused args (Michal Schmidt) [RHEL-43864] {CVE-2024-38608}
- r8169: Fix possible ring buffer corruption on fragmented Tx packets. (cki-backport-bot) [RHEL-44031] {CVE-2024-38586}
- netfilter: flowtable: initialise extack before use (Florian Westphal) [RHEL-58542] {CVE-2024-45018}
- memcg: protect concurrent access to mem_cgroup_idr (Rafael Aquini) [RHEL-56252] {CVE-2024-43892}
- memcontrol: ensure memcg acquired by id is properly set up (Rafael Aquini) [RHEL-56252] {CVE-2024-43892}
- mm: memcontrol: fix cannot alloc the maximum memcg ID (Rafael Aquini) [RHEL-56252] {CVE-2024-43892}
- mm/memcg: minor cleanup for MEM_CGROUP_ID_MAX (Rafael Aquini) [RHEL-56252] {CVE-2024-43892}
- ice: Add netif_device_attach/detach into PF reset flow (CKI Backport Bot) [RHEL-23676]

* Thu Sep 19 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.23.1.el8_10]
- ethtool: check device is present when getting link settings (Jamie Bainbridge) [RHEL-57002]
- netfilter: nft_set_pipapo: do not free live element (Phil Sutter) [RHEL-34221] {CVE-2024-26924}
- netfilter: nf_tables: missing iterator type in lookup walk (Phil Sutter) [RHEL-35033] {CVE-2024-27017}
- netfilter: nft_set_pipapo: walk over current view on netlink dump (Phil Sutter) [RHEL-35033] {CVE-2024-27017}
- netfilter: nftables: add helper function to flush set elements (Phil Sutter) [RHEL-35033] {CVE-2024-27017}
- netfilter: nf_tables: prefer nft_chain_validate (Phil Sutter) [RHEL-51040] {CVE-2024-41042}
- netfilter: nf_tables: fully validate NFT_DATA_VALUE on store to data registers (Phil Sutter) [RHEL-51516] {CVE-2024-42070}
- netfilter: nf_tables: Fix potential data-race in __nft_flowtable_type_get() (Phil Sutter) [RHEL-43003] {CVE-2024-35898}
- netfilter: ipset: Fix suspicious rcu_dereference_protected() (Phil Sutter) [RHEL-47606] {CVE-2024-39503}
- netfilter: ipset: Fix race between namespace cleanup and gc in the list:set type (Phil Sutter) [RHEL-47606] {CVE-2024-39503}
- netfilter: ipset: Add list flush to cancel_gc (Phil Sutter) [RHEL-47606] {CVE-2024-39503}
- netfilter: nf_conntrack_h323: Add protection for bmp length out of range (Phil Sutter) [RHEL-42680] {CVE-2024-26851}
- netfilter: bridge: replace physindev with physinif in nf_bridge_info (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- netfilter: propagate net to nf_bridge_get_physindev (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- netfilter: nfnetlink_log: use proper helper for fetching physinif (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- netfilter: nf_queue: remove excess nf_bridge variable (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- dev/parport: fix the array out-of-bounds risk (Steve Best) [RHEL-54985] {CVE-2024-42301}
- KVM: Always flush async #PF workqueue when vCPU is being destroyed (Sean Christopherson) [RHEL-35100] {CVE-2024-26976}
- bnxt_re: avoid shift undefined behavior in bnxt_qplib_alloc_init_hwq (Kamal Heib) [RHEL-44279] {CVE-2024-38540}
- tipc: Return non-zero value from tipc_udp_addr2str() on error (Xin Long) [RHEL-55069] {CVE-2024-42284}
- Bluetooth: Fix TOCTOU in HCI debugfs implementation (CKI Backport Bot) [RHEL-26831] {CVE-2024-24857}
- drm/i915/dpt: Make DPT object unshrinkable (CKI Backport Bot) [RHEL-47856] {CVE-2024-40924}
- tipc: force a dst refcount before doing decryption (Xin Long) [RHEL-48363] {CVE-2024-40983}
- block: initialize integrity buffer to zero before writing it to media (Ming Lei) [RHEL-54763] {CVE-2024-43854}
- gso: do not skip outer ip header in case of ipip and net_failover (CKI Backport Bot) [RHEL-55790] {CVE-2022-48936}
- drm/amdgpu: avoid using null object of framebuffer (CKI Backport Bot) [RHEL-51405] {CVE-2024-41093}
- ipv6: prevent possible NULL deref in fib6_nh_init() (Guillaume Nault) [RHEL-48170] {CVE-2024-40961}
- mlxsw: spectrum_acl_erp: Fix object nesting warning (CKI Backport Bot) [RHEL-55568] {CVE-2024-43880}
- ibmvnic: Add tx check to prevent skb leak (CKI Backport Bot) [RHEL-51249] {CVE-2024-41066}
- ibmvnic: rename local variable index to bufidx (CKI Backport Bot) [RHEL-51249] {CVE-2024-41066}
- netfilter: bridge: replace physindev with physinif in nf_bridge_info (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- netfilter: propagate net to nf_bridge_get_physindev (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- netfilter: nfnetlink_log: use proper helper for fetching physinif (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- netfilter: nf_queue: remove excess nf_bridge variable (Florian Westphal) [RHEL-37038 RHEL-37039] {CVE-2024-35839}
- USB: serial: mos7840: fix crash on resume (CKI Backport Bot) [RHEL-53680] {CVE-2024-42244}
- ACPICA: Revert "ACPICA: avoid Info: mapping multiple BARs. Your kernel is fine." (CKI Backport Bot) [RHEL-48381] {CVE-2024-40984}

* Wed Sep 11 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.22.1.el8_10]
- wifi: mac80211: Avoid address calculations via out of bounds array indexing (Michal Schmidt) [RHEL-51278] {CVE-2024-41071}

* Wed Sep 04 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.21.1.el8_10]
- s390/dasd: fix error recovery leading to data corruption on ESE devices (Mete Durlu) [RHEL-55874]
- protect the fetch of ->fd[fd] in do_dup2() from mispredictions (CKI Backport Bot) [RHEL-55123] {CVE-2024-42265}
- net: openvswitch: fix overwriting ct original tuple for ICMPv6 (cki-backport-bot) [RHEL-44207] {CVE-2024-38558}
- mlxsw: thermal: Fix out-of-bounds memory accesses (CKI Backport Bot) [RHEL-38375] {CVE-2021-47441}
- USB: class: cdc-wdm: Fix CPU lockup caused by excessive log messages (CKI Backport Bot) [RHEL-47552] {CVE-2024-40904}
- ipvs: properly dereference pe in ip_vs_add_service (Phil Sutter) [RHEL-54903] {CVE-2024-42322}
- net, sunrpc: Remap EPERM in case of connection failure in xs_tcp_setup_socket (CKI Backport Bot) [RHEL-53702] {CVE-2024-42246}
- drm/amdgpu: change vm->task_info handling (Michel Dänzer) [RHEL-49379] {CVE-2024-41008}
- drm/amdgpu: Fix signedness bug in sdma_v4_0_process_trap_irq() (Michel Dänzer) [RHEL-45036] {CVE-2024-39471}
- drm/amdgpu: add error handle to avoid out-of-bounds (Michel Dänzer) [RHEL-45036] {CVE-2024-39471}
- drm/amdgpu: Using uninitialized value *size when calling amdgpu_vce_cs_reloc (Michel Dänzer) [RHEL-52845] {CVE-2024-42228}

* Thu Aug 29 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.20.1.el8_10]
- KVM: arm64: Disassociate vcpus from redistributor region on teardown (Shaoqin Huang) [RHEL-48417] {CVE-2024-40989}
- devres: Fix memory leakage caused by driver API devm_free_percpu() (CKI Backport Bot) [RHEL-55597] {CVE-2024-43871}
- phy: ti: phy-omap-usb2: Fix NULL pointer dereference for SRP (Izabela Bakollari) [RHEL-26680] {CVE-2024-26600}
- nvmet-fc: avoid deadlock on delete association path (Maurizio Lombardi) [RHEL-31618] {CVE-2024-26769}
- nvmet-fc: release reference on target port (Maurizio Lombardi) [RHEL-31618] {CVE-2024-26769}
- ACPI: LPIT: Avoid u32 multiplication overflow (Mark Langsdorf) [RHEL-37062] {CVE-2023-52683}
- sched/deadline: Fix task_struct reference leak (Phil Auld) [RHEL-50904] {CVE-2024-41023}
- nfsd: fix crash on LOCKT on reexported NFSv3 (Benjamin Coddington) [RHEL-31515]
- mlxsw: spectrum_acl_tcam: Fix NULL pointer dereference in error path (CKI Backport Bot) [RHEL-26570] {CVE-2024-26595}
- mlxsw: spectrum_acl_tcam: Move devlink param to TCAM code (Ivan Vecera) [RHEL-26570] {CVE-2024-26595}
- ACPI: extlog: fix NULL pointer dereference check (Mark Langsdorf) [RHEL-29110] {CVE-2023-52605}
- ACPI: processor_idle: Fix memory leak in acpi_processor_power_exit() (Mark Langsdorf) [RHEL-33198] {CVE-2024-26894}
- mm: prevent derefencing NULL ptr in pfn_section_valid() (Audra Mitchell) [RHEL-51132] {CVE-2024-41055}
- mm, kmsan: fix infinite recursion due to RCU critical section (Audra Mitchell) [RHEL-51132] {CVE-2024-41055}
- cipso: make cipso_v4_skbuff_delattr() fully remove the CIPSO options (Ondrej Mosnacek) [RHEL-30904]
- cipso: fix total option length computation (Ondrej Mosnacek) [RHEL-30904]
- ext4: do not create EA inode under buffer lock (Carlos Maiolino) [RHEL-48271] {CVE-2024-40972}
- ext4: fold quota accounting into ext4_xattr_inode_lookup_create() (Carlos Maiolino) [RHEL-48271] {CVE-2024-40972}
- ext4: check the return value of ext4_xattr_inode_dec_ref() (Carlos Maiolino) [RHEL-48271] {CVE-2024-40972}
- ext4: fix uninitialized ratelimit_state->lock access in __ext4_fill_super() (Carlos Maiolino) [RHEL-48507] {CVE-2024-40998}
- ext4: remove duplicate definition of ext4_xattr_ibody_inline_set() (Carlos Maiolino) [RHEL-48271] {CVE-2024-40972}

* Thu Aug 22 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.19.1.el8_10]
- drm/i915/vma: Fix UAF on destroy against retire race (Mika Penttilä) [RHEL-35222] {CVE-2024-26939}
- RHEL-48620 (Kenneth Yin) [RHEL-48620]
- net: ice: Fix potential NULL pointer dereference in ice_bridge_setlink() (CKI Backport Bot) [RHEL-42721] {CVE-2024-26855}
- net: usb: asix: do not force pause frames support (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: asix: fix "can't send until first packet is send" issue (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: asix: fix modprobe "sysfs: cannot create duplicate filename" (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: asix: add proper error handling of usb read errors (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- asix: fix wrong return value in asix_check_host_enable() (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- asix: fix uninit-value in asix_mdio_read() (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: fix boolconv.cocci warnings (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: do not call phy_disconnect() for ax88178 (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: move embedded PHY detection as early as possible (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: asix: fix uninit value bugs (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: add missing stop (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: suspend PHY on driver probe (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: manage PHY PM from MAC (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: Fix less than zero comparison of a u16 (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: Fix less than zero comparison of a u16 (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: add error handling for asix_mdio_* functions (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: ax88772: add phylib support (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- net: usb: asix: refactor asix_read_phy_addr() and handle errors on return (Ken Cox) [RHEL-28108] {CVE-2021-47101}
- SUNRPC: always free ctxt when freeing deferred request (Jay Shin) [RHEL-40936]
- SUNRPC: double free xprt_ctxt while still in use (Jay Shin) [RHEL-40936]
- SUNRPC: Remove svc_rqst::rq_xprt_hlen (Jay Shin) [RHEL-40936]
- SUNRPC: Remove dead code in svc_tcp_release_rqst() (Jay Shin) [RHEL-40936]
- x86/bugs: Extend VMware Retbleed workaround to Nehalem & earlier CPUs (Waiman Long) [RHEL-48646]
- wifi: iwlwifi: read txq->read_ptr under lock (Jose Ignacio Tornos Martinez) [RHEL-39797] {CVE-2024-36922}
- scsi: bnx2fc: Remove spin_lock_bh while releasing resources after upload (John Meneghini) [RHEL-39908] {CVE-2024-36919}
- nbd: always initialize struct msghdr completely (Ming Lei) [RHEL-29498] {CVE-2024-26638}
- block: don't call rq_qos_ops->done_bio if the bio isn't tracked (Ming Lei) [RHEL-42151] {CVE-2021-47412}
- nvmet: fix a possible leak when destroy a ctrl during qp establishment (Maurizio Lombardi) [RHEL-52013] {CVE-2024-42152}
- ipv6: prevent NULL dereference in ip6_output() (Sabrina Dubroca) [RHEL-39912] {CVE-2024-36901}
- ppp: reject claimed-as-LCP but actually malformed packets (Guillaume Nault) [RHEL-51052] {CVE-2024-41044}
- leds: trigger: Unregister sysfs attributes before calling deactivate() (CKI Backport Bot) [RHEL-54834] {CVE-2024-43830}
- crypto: bcm - Fix pointer arithmetic (cki-backport-bot) [RHEL-44108] {CVE-2024-38579}
- scsi: qedf: Ensure the copied buf is NUL terminated (John Meneghini) [RHEL-44195] {CVE-2024-38559}
- x86/bhi: Avoid warning in #DB handler due to BHI mitigation (Waiman Long) [RHEL-53657] {CVE-2024-42240}
- scsi: mpt3sas: Avoid test/set_bit() operating in non-allocated memory (CKI Backport Bot) [RHEL-47529] {CVE-2024-40901}
- ipv6: fib6_rules: avoid possible NULL dereference in fib6_rule_action() (CKI Backport Bot) [RHEL-39843] {CVE-2024-36902}
- net: usb: ax88179_178a: improve link status logs (Jose Ignacio Tornos Martinez) [RHEL-45167]
- net: usb: ax88179_178a: improve reset check (Jose Ignacio Tornos Martinez) [RHEL-45167]
- net: usb: ax88179_178a: fix link status when link is set to down/up (Jose Ignacio Tornos Martinez) [RHEL-45167]
- net: usb: ax88179_178a: avoid writing the mac address before first reading (Jose Ignacio Tornos Martinez) [RHEL-45167]
- KVM: arm64: vgic-v2: Check for non-NULL vCPU in vgic_v2_parse_attr() (Shaoqin Huang) [RHEL-40837] {CVE-2024-36953}
- KVM: arm64: vgic-v2: Use cpuid from userspace as vcpu_id (Shaoqin Huang) [RHEL-40837] {CVE-2024-36953}
- media: cec: cec-api: add locking in cec_release() (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: avoid confusing "transmit timed out" message (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: avoid recursive cec_claim_log_addrs (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: cec-adap: always cancel work in cec_transmit_msg_fh (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: remove length check of Timer Status (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: count low-drive, error and arb-lost conditions (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: add note about *_from_edid() function usage in drm (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: add adap_unconfigured() callback (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: add adap_nb_transmit_canceled() callback (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: don't set last_initiator if tx in progress (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: disable adapter in cec_devnode_unregister (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: core: not all messages were passed on when monitoring (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: add support for Absolute Volume Control (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: log when claiming LA fails unexpectedly (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: drop activate_cnt, use state info instead (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: reconfigure if the PA changes during configuration (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: fix is_configuring state (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: stop trying LAs on CEC_TX_STATUS_TIMEOUT (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: don't unconfigure if already unconfigured (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: add optional adap_configured callback (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: add xfer_timeout_ms field (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: use call_op and check for !unregistered (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-pin: fix interrupt en/disable handling (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-pin: drop unused 'enabled' field from struct cec_pin (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-pin: fix off-by-one SFT check (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-pin: rename timer overrun variables (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: correctly pass on reply results (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: abort if the current transmit was canceled (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: call enable_adap on s_log_addrs (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: media/cec.h: document cec_adapter fields (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: fix a deadlock situation (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: safely unhook lists in cec_data (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: copy sequence field for the reply (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: fix trivial style warnings (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: add 'unregistered' checks (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec-adap.c: don't use flush_scheduled_work() (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: Use fallthrough pseudo-keyword (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: remove unused waitq and phys_addrs fields (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: silence shift wrapping warning in __cec_s_log_addrs() (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- media: cec: move the core to a separate directory (Kate Hsuan) [RHEL-22559] {CVE-2024-23848}
- net/iucv: Avoid explicit cpumask var allocation on stack (CKI Backport Bot) [RHEL-51631] {CVE-2024-42094}
- scsi: lpfc: Handle mailbox timeouts in lpfc_get_sfp_info (Dick Kennedy) [RHEL-40400]
- KVM: selftests: Make hyperv_clock require TSC based system clocksource (Vitaly Kuznetsov) [RHEL-19027]
- KVM: selftests: Run clocksource dependent tests with hyperv_clocksource_tsc_page too (Vitaly Kuznetsov) [RHEL-19027]
- KVM: selftests: Use generic sys_clocksource_is_tsc() in vmx_nested_tsc_scaling_test (Vitaly Kuznetsov) [RHEL-19027]
- KVM: selftests: Generalize check_clocksource() from kvm_clock_test (Vitaly Kuznetsov) [RHEL-19027]
- firmware: cs_dsp: Return error if block header overflows file (CKI Backport Bot) [RHEL-53646] {CVE-2024-42238}
- firmware: cs_dsp: Validate payload length before processing block (CKI Backport Bot) [RHEL-53638] {CVE-2024-42237}
- mm, slub: fix potential memoryleak in kmem_cache_open() (Waiman Long) [RHEL-38404] {CVE-2021-47466}
- slub: don't panic for memcg kmem cache creation failure (Waiman Long) [RHEL-38404] {CVE-2021-47466}
- wifi: ath11k: fix htt pktlog locking (Jose Ignacio Tornos Martinez) [RHEL-38317] {CVE-2023-52800}
- wifi: ath11k: fix dfs radar event locking (Jose Ignacio Tornos Martinez) [RHEL-38165] {CVE-2023-52798}
- lib/generic-radix-tree.c: Don't overflow in peek() (Waiman Long) [RHEL-37737] {CVE-2021-47432}
- include/linux/generic-radix-tree.h: replace kernel.h with the necessary inclusions (Waiman Long) [RHEL-37737] {CVE-2021-47432}
- EDAC/i10nm: Skip the absent memory controllers (Aristeu Rozanski) [RHEL-43236]
- scsi: libfc: Fix potential NULL pointer dereference in fc_lport_ptp_setup() (John Meneghini) [RHEL-38197] {CVE-2023-52809}
- gfs2: Fix potential glock use-after-free on unmount (Andreas Gruenbacher) [RHEL-44149] {CVE-2024-38570}
- gfs2: simplify gdlm_put_lock with out_free label (Andreas Gruenbacher) [RHEL-44149] {CVE-2024-38570}
- gfs2: Remove ill-placed consistency check (Andreas Gruenbacher) [RHEL-44149] {CVE-2024-38570}
- nvme-fc: do not wait in vain when unloading module (Ewan D. Milne) [RHEL-33083] {CVE-2024-26846}
- HID: hid-thrustmaster: fix OOB read in thrustmaster_interrupts (CKI Backport Bot) [RHEL-49698] {CVE-2022-48866}
- scsi: qedf: Set qed_slowpath_params to zero before use (John Meneghini) [RHEL-9797]
- scsi: qedf: Wait for stag work during unload (John Meneghini) [RHEL-9797]
- scsi: qedf: Don't process stag work during unload and recovery (John Meneghini) [RHEL-9797]
- Revert "mm/writeback: fix possible divide-by-zero in wb_dirty_limits(), again" (Audra Mitchell) [RHEL-42625] {CVE-2024-26720}
- mm: avoid overflows in dirty throttling logic (Audra Mitchell) [RHEL-51840] {CVE-2024-42131}
- mm/writeback: fix possible divide-by-zero in wb_dirty_limits(), again (Audra Mitchell) [RHEL-42625] {CVE-2024-26720}
- ACPI: fix NULL pointer dereference (Mark Langsdorf) [RHEL-37897] {CVE-2021-47289}

* Fri Aug 16 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.18.1.el8_10]
- scsi: mpi3mr: Avoid memcpy field-spanning write WARNING (Ewan D. Milne) [RHEL-39805] {CVE-2024-36920}
- tun: limit printing rate when illegal packet received by tun dev (Jon Maloy) [RHEL-35046] {CVE-2024-27013}
- drm/amdgpu/debugfs: fix error code when smc register accessors are NULL (Michel Dänzer) [RHEL-38210] {CVE-2023-52817}
- drm/amdgpu: Fix a null pointer access when the smc_rreg pointer is NULL (Michel Dänzer) [RHEL-38210] {CVE-2023-52817}
- drm/amdgpu/mes: fix use-after-free issue (Michel Dänzer) [RHEL-44043] {CVE-2024-38581}
- drm/amdgpu: Fix the null pointer when load rlc firmware (Michel Dänzer) [RHEL-30603] {CVE-2024-26649}
- drm/amdgpu: Fix potential out-of-bounds access in 'amdgpu_discovery_reg_base_init()' (Michel Dänzer) [RHEL-35160] {CVE-2024-27042}
- net/sched: Fix UAF when resolving a clash (Xin Long) [RHEL-51014] {CVE-2024-41040}
- tcp_metrics: validate source addr length (Guillaume Nault) [RHEL-52025] {CVE-2024-42154}
- NFSv4/pnfs: Fix a use-after-free bug in open (Benjamin Coddington) [RHEL-35508]
- NFSv4: Don't hold the layoutget locks across multiple RPC calls (Benjamin Coddington) [RHEL-35508]
- scsi: qedf: Make qedf_execute_tmf() non-preemptible (John Meneghini) [RHEL-51799] {CVE-2024-42124}
- Input: elantech - fix stack out of bound access in elantech_change_report_id() (CKI Backport Bot) [RHEL-41938] {CVE-2021-47097}
- HID: logitech-hidpp: Fix kernel crash on receiver USB disconnect (CKI Backport Bot) [RHEL-28982] {CVE-2023-52478}
- drm/radeon: fix UBSAN warning in kv_dpm.c (CKI Backport Bot) [RHEL-48399] {CVE-2024-40988}
- usb: core: Don't hold the device lock while sleeping in do_proc_control() (Desnes Nunes) [RHEL-43646] {CVE-2021-47582}
- USB: core: Make do_proc_control() and do_proc_bulk() killable (Desnes Nunes) [RHEL-43646] {CVE-2021-47582}
- scsi: qedi: Fix crash while reading debugfs attribute (CKI Backport Bot) [RHEL-48327] {CVE-2024-40978}
- wifi: mt76: mt7921s: fix potential hung tasks during chip recovery (CKI Backport Bot) [RHEL-48309] {CVE-2024-40977}
- net: tcp: accept old ack during closing (Jamie Bainbridge) [RHEL-52433]
- wifi: iwlwifi: mvm: don't read past the mfuart notifcation (CKI Backport Bot) [RHEL-48016] {CVE-2024-40941}
- net/iucv: fix use after free in iucv_sock_close() (Mete Durlu) [RHEL-53988]
- wifi: iwlwifi: mvm: check n_ssids before accessing the ssids (CKI Backport Bot) [RHEL-47908] {CVE-2024-40929}
- Input: aiptek - properly check endpoint type (Benjamin Tissoires) [RHEL-48963] {CVE-2022-48836}
- Input: aiptek - use descriptors of current altsetting (Benjamin Tissoires) [RHEL-48963] {CVE-2022-48836}
- Input: aiptek - fix endpoint sanity check (Benjamin Tissoires) [RHEL-48963] {CVE-2022-48836}
- usb: xhci: prevent potential failure in handle_tx_event() for Transfer events without TRB (CKI Backport Bot) [RHEL-52373] {CVE-2024-42226}
- wifi: mt76: replace skb_put with skb_put_zero (CKI Backport Bot) [RHEL-52366] {CVE-2024-42225}
- wifi: mac80211: Fix deadlock in ieee80211_sta_ps_deliver_wakeup() (CKI Backport Bot) [RHEL-47776] {CVE-2024-40912}
- wifi: cfg80211: Lock wiphy in cfg80211_get_station (CKI Backport Bot) [RHEL-47758] {CVE-2024-40911}
- VMCI: Use struct_size() in kmalloc() (Steve Best) [RHEL-37325] {CVE-2024-35944}
- VMCI: Fix possible memcpy() run-time warning in vmci_datagram_invoke_guest_handler() (Steve Best) [RHEL-37325] {CVE-2024-35944}
- VMCI: Fix memcpy() run-time warning in dg_dispatch_as_host() (Steve Best) [RHEL-37325] {CVE-2024-35944}
- wifi: cfg80211: restrict NL80211_ATTR_TXQ_QUANTUM values (Jose Ignacio Tornos Martinez) [RHEL-51761] {CVE-2024-42114}
- usb: atm: cxacru: fix endpoint checking in cxacru_bind() (CKI Backport Bot) [RHEL-51442] {CVE-2024-41097}
- nfs: handle error of rpc_proc_register() in init_nfs_fs() (Scott Mayhew) [RHEL-39904] {CVE-2024-36939}
- drm/radeon: check bo_va->bo is non-NULL before using it (CKI Backport Bot) [RHEL-51184] {CVE-2024-41060}
- udp: Set SOCK_RCU_FREE earlier in udp_lib_get_port(). (CKI Backport Bot) [RHEL-51027] {CVE-2024-41041}
- USB: core: Fix duplicate endpoint bug by clearing reserved bits in the descriptor (CKI Backport Bot) [RHEL-50961] {CVE-2024-41035}
- tcp: Fix shift-out-of-bounds in dctcp_update_alpha(). (CKI Backport Bot) [RHEL-44408] {CVE-2024-37356}
- tcp: avoid too many retransmit packets (Florian Westphal) [RHEL-48627] {CVE-2024-41007}
- tcp: use signed arithmetic in tcp_rtx_probe0_timed_out() (Florian Westphal) [RHEL-48627]
- net: tcp: fix unexcepted socket die when snd_wnd is 0 (Florian Westphal) [RHEL-48627]
- tcp: refactor tcp_retransmit_timer() (Florian Westphal) [RHEL-48627]
- tcp: exit if nothing to retransmit on RTO timeout (Florian Westphal) [RHEL-48627]
- netfilter: nf_tables: Reject tables of unsupported family (Florian Westphal) [RHEL-21418] {CVE-2023-6040}

* Wed Aug 07 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.17.1.el8_10]
- kyber: fix out of bounds access when preempted (Ming Lei) [RHEL-27258] {CVE-2021-46984}
- vfs: don't mod negative dentry count when on shrinker list (Brian Foster) [RHEL-35874]
- fs/dcache: Re-use value stored to dentry->d_flags instead of re-reading (Brian Foster) [RHEL-35874]
- fbmem: Do not delete the mode that is still in use (CKI Backport Bot) [RHEL-37796] {CVE-2021-47338}
- netpoll: Fix race condition in netpoll_owner_active (CKI Backport Bot) [RHEL-49361] {CVE-2024-41005}
- firmware: arm_scpi: Fix string overflow in SCPI genpd driver (Mark Salter) [RHEL-43702] {CVE-2021-47609}
- ipv6: prevent possible NULL dereference in rt6_probe() (Guillaume Nault) [RHEL-48149] {CVE-2024-40960}
- HID: i2c-hid-of: fix NULL-deref on failed power up (CKI Backport Bot) [RHEL-31598] {CVE-2024-26717}
- cpufreq: amd-pstate: fix memory leak on CPU EPP exit (CKI Backport Bot) [RHEL-48489] {CVE-2024-40997}
- x86/mm/pat: fix VM_PAT handling in COW mappings (Chris von Recklinghausen) [RHEL-37258] {CVE-2024-35877}
- PCI/PM: Drain runtime-idle callbacks before driver removal (Myron Stowe) [RHEL-42937] {CVE-2024-35809}
- PCI: Drop pci_device_remove() test of pci_dev->driver (Myron Stowe) [RHEL-42937] {CVE-2024-35809}
- drm/radeon: check the alloc_workqueue return value in radeon_crtc_init() (Mika Penttilä) [RHEL-26909] {CVE-2023-52470}
- USB: core: Fix hang in usb_kill_urb by adding memory barriers (Desnes Nunes) [RHEL-43979] {CVE-2022-48760}
- cifs: fix bad fids sent over wire (Paulo Alcantara) [RHEL-52517]
- smb3: add additional null check in SMB311_posix_mkdir (Paulo Alcantara) [RHEL-52517]
- smb3: add additional null check in SMB2_tcon (Paulo Alcantara) [RHEL-52517]
- smb3: add additional null check in SMB2_open (Paulo Alcantara) [RHEL-52517]
- smb3: add additional null check in SMB2_ioctl (Paulo Alcantara) [RHEL-52517]
- selftests: forwarding: devlink_lib: Wait for udev events after reloading (Mark Langsdorf) [RHEL-47642] {CVE-2024-39501}
- drivers: core: synchronize really_probe() and dev_uevent() (Mark Langsdorf) [RHEL-47642] {CVE-2024-39501}
- udp: do not accept non-tunnel GSO skbs landing in a tunnel (Xin Long) [RHEL-42997] {CVE-2024-35884}
- filelock: Remove locks reliably when fcntl/close race is detected (Bill O'Donnell) [RHEL-50170] {CVE-2024-41012}
- Input: add bounds checking to input_set_capability() (Benjamin Tissoires) [RHEL-21413] {CVE-2022-48619}
- xfrm6: check ip6_dst_idev() return value in xfrm6_get_saddr() (CKI Backport Bot) [RHEL-48130] {CVE-2024-40959}
- blk-cgroup: fix list corruption from reorder of WRITE ->lqueued (Ming Lei) [RHEL-33695]
- blk-cgroup: fix list corruption from resetting io stat (Ming Lei) [RHEL-33695]
- net: do not leave a dangling sk pointer, when socket creation fails (CKI Backport Bot) [RHEL-48060] {CVE-2024-40954}
- perf/x86/lbr: Filter vsyscall addresses (Michael Petlan) [RHEL-28991] {CVE-2023-52476}
- vmci: prevent speculation leaks by sanitizing event in event_deliver() (CKI Backport Bot) [RHEL-47678] {CVE-2024-39499}
- serial: core: fix transmit-buffer reset and memleak (Steve Best) [RHEL-38731] {CVE-2021-47527}
- powerpc/pseries: Whitelist dtl slub object for copying to userspace (Mamatha Inamdar) [RHEL-51236] {CVE-2024-41065}
- powerpc/eeh: avoid possible crash when edev->pdev changes (Mamatha Inamdar) [RHEL-51220] {CVE-2024-41064}
- x86: stop playing stack games in profile_pc() (Steve Best) [RHEL-51643] {CVE-2024-42096}
- mptcp: ensure snd_una is properly initialized on connect (Florian Westphal) [RHEL-47933 RHEL-47934] {CVE-2024-40931}
- liquidio: Adjust a NULL pointer handling path in lio_vf_rep_copy_packet (CKI Backport Bot) [RHEL-47492] {CVE-2024-39506}
- tun: add missing verification for short frame (Patrick Talbert) [RHEL-50194] {CVE-2024-41091}
- tap: add missing verification for short frame (Patrick Talbert) [RHEL-50279] {CVE-2024-41090}
- usb-storage: alauda: Check whether the media is initialized (Desnes Nunes) [RHEL-43708] {CVE-2024-38619}
- usb-storage: alauda: Fix uninit-value in alauda_check_media() (Desnes Nunes) [RHEL-43708] {CVE-2024-38619}
- hwmon: (w83793) Fix NULL pointer dereference by removing unnecessary structure field (Steve Best) [RHEL-37723] {CVE-2021-47384}
- block: fix that util can be greater than 100%% (Ming Lei) [RHEL-23074]
- block: support to account io_ticks precisely (Ming Lei) [RHEL-23074]
- watchdog: Fix possible use-after-free by calling del_timer_sync() (Steve Best) [RHEL-38795] {CVE-2021-47321}
- hwmon: (w83792d) Fix NULL pointer dereference by removing unnecessary structure field (Steve Best) [RHEL-37719] {CVE-2021-47385}
- mlxsw: spectrum: Protect driver from buggy firmware (CKI Backport Bot) [RHEL-42245] {CVE-2021-47560}
- mlxsw: Verify the accessed index doesn't exceed the array length (CKI Backport Bot) [RHEL-42245] {CVE-2021-47560}
- dm: call the resume method on internal suspend (Benjamin Marzinski) [RHEL-41835] {CVE-2024-26880}
- tty: Fix out-of-bound vmalloc access in imageblit (Steve Best) [RHEL-37727] {CVE-2021-47383}
- hwmon: (w83791d) Fix NULL pointer dereference by removing unnecessary structure field (Steve Best) [RHEL-37715] {CVE-2021-47386}
- hwmon: (mlxreg-fan) Return non-zero value when fan current state is enforced from sysfs (Steve Best) [RHEL-37710] {CVE-2021-47393}
- nvmem: Fix shift-out-of-bound (UBSAN) with byte size cells (Steve Best) [RHEL-38436] {CVE-2021-47497}
- driver core: auxiliary bus: Fix memory leak when driver_register() fail (Steve Best) [RHEL-37901] {CVE-2021-47287}
- phylib: fix potential use-after-free (cki-backport-bot) [RHEL-43764] {CVE-2022-48754}
- ptp: Fix possible memory leak in ptp_clock_register() (Hangbin Liu) [RHEL-38424] {CVE-2021-47455}
- NFSv4: Fix memory leak in nfs4_set_security_label (CKI Backport Bot) [RHEL-51315] {CVE-2024-41076}
- pinctrl: fix deadlock in create_pinctrl() when handling -EPROBE_DEFER (CKI Backport Bot) [RHEL-51618] {CVE-2024-42090}
- ftruncate: pass a signed offset (CKI Backport Bot) [RHEL-51598] {CVE-2024-42084}
- af_unix: Fix garbage collector racing against connect() (Felix Maurer) [RHEL-34225] {CVE-2024-26923}
- virtio-net: Add validation for used length (Laurent Vivier) [RHEL-42080] {CVE-2021-47352}
- net: fix possible store tearing in neigh_periodic_work() (Antoine Tenart) [RHEL-42359] {CVE-2023-52522}
- tunnels: fix out of bounds access when building IPv6 PMTU error (Antoine Tenart) [RHEL-41823] {CVE-2024-26665}
- vt_ioctl: fix array_index_nospec in vt_setactivate (John W. Linville) [RHEL-49141] {CVE-2022-48804}
- Input: synaptics-rmi4 - fix use after free in rmi_unregister_function() (CKI Backport Bot) [RHEL-38302] {CVE-2023-52840}
- netns: Make get_net_ns() handle zero refcount net (Antoine Tenart) [RHEL-48105] {CVE-2024-40958}
- tracing: Ensure visibility when inserting an element into tracing_map (Michael Petlan) [RHEL-30457] {CVE-2024-26645}
- KVM: s390: fix LPSWEY handling (CKI Backport Bot) [RHEL-50072]
- firmware: cs_dsp: Use strnlen() on name fields in V1 wmfw files (CKI Backport Bot) [RHEL-51144] {CVE-2024-41056}
- SUNRPC: Fix a race to wake a sync task (Benjamin Coddington) [RHEL-11843]
- firmware: cs_dsp: Fix overflow checking of wmfw header (CKI Backport Bot) [RHEL-50999] {CVE-2024-41039}
- firmware: cs_dsp: Prevent buffer overrun when processing V2 alg headers (CKI Backport Bot) [RHEL-50987] {CVE-2024-41038}
- net/sched: act_api: fix possible infinite loop in tcf_idr_check_alloc() (Xin Long) [RHEL-48471] {CVE-2024-40995}
- net: fix out-of-bounds access in ops_init (Xin Long) [RHEL-43185] {CVE-2024-36883}
- x86/mce/therm_throt: Undo thermal polling properly on CPU offline (Steve Best) [RHEL-45310]
- x86/mce/therm_throt: Do not access uninitialized therm_work (Steve Best) [RHEL-45310]
- x86/mce/therm_throt: Mark throttle_active_work() as __maybe_unused (Steve Best) [RHEL-45310]
- x86/mce/therm_throt: Mask out read-only and reserved MSR bits (Steve Best) [RHEL-45310]
- x86/mce/therm_throt: Optimize notifications of thermal throttle (Steve Best) [RHEL-45310]
- jiffies: add utility function to calculate delta in ms (Steve Best) [RHEL-45310]
- x86/mce: Lower throttling MCE messages' priority to warning (Steve Best) [RHEL-45310]
- dmaengine: idxd: Fix oops during rmmod on single-CPU platforms (Eder Zulian) [RHEL-37361] {CVE-2024-35989}
- xfs: don't walk off the end of a directory data block (CKI Backport Bot) [RHEL-50879] {CVE-2024-41013}
- xfs: add bounds checking to xlog_recover_process_data (CKI Backport Bot) [RHEL-50856] {CVE-2024-41014}
- dm-crypt: limit the size of encryption requests (Benjamin Marzinski) [RHEL-29330]
- netfilter: flowtable: remove nf_ct_l4proto_find() call (Florian Westphal) [RHEL-49589]

* Thu Aug 01 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.16.1.el8_10]
- x86/bhi: Fix incorrect CLEAR_BRANCH_HISTORY position in entry_INT80_compat (Waiman Long) [RHEL-50648]

* Fri Jul 26 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.15.1.el8_10]
- Revert "scsi: st: Add third party poweron reset handling" (John Meneghini) [RHEL-44613]
- ionic: fix use after netif_napi_del() (CKI Backport Bot) [RHEL-47624] {CVE-2024-39502}
- ionic: clean interrupt before enabling queue to avoid credit race (CKI Backport Bot) [RHEL-47624] {CVE-2024-39502}
- net/sunrpc: fix reference count leaks in rpc_sysfs_xprt_state_change (CKI Backport Bot) [RHEL-49321] {CVE-2021-47624}
- xhci: Handle TD clearing for multiple streams case (CKI Backport Bot) [RHEL-47882] {CVE-2024-40927}
- net: openvswitch: Fix Use-After-Free in ovs_ct_exit (cki-backport-bot) [RHEL-36362] {CVE-2024-27395}
- net: bridge: mst: fix suspicious rcu usage in br_mst_set_state (Ivan Vecera) [RHEL-43721] {CVE-2024-36979}
- net: bridge: mst: pass vlan group directly to br_mst_vlan_set_state (Ivan Vecera) [RHEL-43721] {CVE-2024-36979}
- net: bridge: mst: fix vlan use-after-free (cki-backport-bot) [RHEL-43721] {CVE-2024-36979}
- irqchip/gic-v3-its: Prevent double free on error (Charles Mirabile) [RHEL-37022] {CVE-2024-35847}
- irqchip/gic-v3-its: Fix potential VPE leak on error (Charles Mirabile) [RHEL-37744] {CVE-2021-47373}
- i2c: mlxbf: prevent stack overflow in mlxbf_i2c_smbus_start_transaction() (Charles Mirabile) [RHEL-34735] {CVE-2022-48632}
- iommu/dma: fix zeroing of bounce buffer padding used by untrusted devices (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- swiotlb: remove alloc_size argument to swiotlb_tbl_map_single() (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- swiotlb: fix swiotlb_bounce() to do partial sync's correctly (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- swiotlb: extend buffer pre-padding to alloc_align_mask if necessary (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- swiotlb: Reinstate page-alignment for mappings >= PAGE_SIZE (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- swiotlb: Fix alignment checks when both allocation and DMA masks are present (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- swiotlb: Fix double-allocation of slots due to broken alignment handling (Eder Zulian) [RHEL-36954] {CVE-2024-35814}
- genirq/cpuhotplug, x86/vector: Prevent vector leak during CPU offline (cki-backport-bot) [RHEL-44441] {CVE-2024-31076}

* Thu Jul 25 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.14.1.el8_10]
- s390/qeth: Fix kernel panic after setting hsuid (Mete Durlu) [RHEL-49754]
- perf/core: Protect event sibling list locking against interrupt inversion (Daniel Vacek) [RHEL-31798]
- vt: fix unicode buffer corruption when deleting characters (Steve Best) [RHEL-36936] {CVE-2024-35823}
- cifs: translate network errors on send to -ECONNABORTED (Paulo Alcantara) [RHEL-36754]
- xfs: don't block in busy flushing when freeing extents (Brian Foster) [RHEL-7984]
- xfs: allow extent free intents to be retried (Brian Foster) [RHEL-7984]
- xfs: pass alloc flags through to xfs_extent_busy_flush() (Brian Foster) [RHEL-7984]
- xfs: use deferred frees for btree block freeing (Brian Foster) [RHEL-7984]
- xfs: fix bounds check in xfs_defer_agfl_block() (Brian Foster) [RHEL-7984]
- xfs: validate block number being freed before adding to xefi (Brian Foster) [RHEL-7984]
- xfs: rename xfs_bmap_add_free to xfs_free_extent_later (Brian Foster) [RHEL-7984]
- usb: typec: altmodes/displayport: create sysfs nodes as driver's default device attribute group (Desnes Nunes) [RHEL-36803] {CVE-2024-35790}
- stm class: Fix a double free in stm_register_device() (Steve Best) [RHEL-44514] {CVE-2024-38627}
- s390/qeth: Fix potential loss of L3-IP@ in case of network issues (Mete Durlu) [RHEL-49755]
- tls: fix missing memory barrier in tls_init (cki-backport-bot) [RHEL-44471] {CVE-2024-36489}
- xfs: fix log recovery buffer allocation for the legacy h_size fixup (Bill O'Donnell) [RHEL-46473] {CVE-2024-39472}
- fs/proc: do_task_stat: use sig->stats_lock to gather the threads/children stats (Brian Foster) [RHEL-31562] {CVE-2024-26686}
- fs/proc: do_task_stat: move thread_group_cputime_adjusted() outside of lock_task_sighand() (Brian Foster) [RHEL-31562] {CVE-2024-26686}
- fs/proc: do_task_stat: use __for_each_thread() (Brian Foster) [RHEL-31562] {CVE-2024-26686}
- exit: Use the correct exit_code in /proc/<pid>/stat (Brian Foster) [RHEL-31562] {CVE-2024-26686}
- scsi: ibmvfc: Remove BUG_ON in the case of an empty event pool (Ewan D. Milne) [RHEL-38283] {CVE-2023-52811}
- scsi: qla2xxx: Fix double free of fcport (Ewan D. Milne) [RHEL-39549] {CVE-2024-26929}
- scsi: qla2xxx: Fix double free of the ha->vp_map pointer (Ewan D. Milne) [RHEL-39549] {CVE-2024-26930}
- scsi: qla2xxx: Fix command flush on cable pull (Ewan D. Milne) [RHEL-39549] {CVE-2024-26931}

* Fri Jul 19 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.13.1.el8_10]
- redhat: remove handling of deleted rhdocs/ directory from genspec.sh (Denys Vlasenko)
- x86/bugs: Fix BHI retpoline check (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Replace CONFIG_SPECTRE_BHI_{ON,OFF} with CONFIG_MITIGATION_SPECTRE_BHI (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Remove CONFIG_BHI_MITIGATION_AUTO and spectre_bhi=auto (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Clarify that syscall hardening isn't a BHI mitigation (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Fix BHI handling of RRSBA (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Rename various 'ia32_cap' variables to 'x86_arch_cap_msr' (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Cache the value of MSR_IA32_ARCH_CAPABILITIES (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Fix BHI documentation (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Fix return type of spectre_bhi_state() (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Make CONFIG_SPECTRE_BHI_ON the default (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bhi: Mitigate KVM by default (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bhi: Add BHI mitigation knob (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bhi: Enumerate Branch History Injection (BHI) bug (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bhi: Define SPEC_CTRL_BHI_DIS_S (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bhi: Add support for clearing branch history at syscall entry (Waiman Long) [RHEL-28202] {CVE-2024-2201}
- x86/bugs: Change commas to semicolons in 'spectre_v2' sysfs file (Waiman Long) [RHEL-28202]
- perf/x86/amd/lbr: Use freeze based on availability (Waiman Long) [RHEL-28202]
- Documentation/kernel-parameters: Add spec_rstack_overflow to mitigations=off (Waiman Long) [RHEL-28202]
- KVM: x86: Advertise CPUID.(EAX=7,ECX=2):EDX[5:0] to userspace (Waiman Long) [RHEL-28202]
- x86/bugs: Reset speculation control settings on init (Waiman Long) [RHEL-28202]
- KVM: x86: Update KVM-only leaf handling to allow for 100%% KVM-only leafs (Waiman Long) [RHEL-28202]
- KVM: x86: Hide IA32_PLATFORM_DCA_CAP[31:0] from the guest (Waiman Long) [RHEL-28202]
- mptcp: ensure snd_nxt is properly initialized on connect (Davide Caratti) [RHEL-39865] {CVE-2024-36889}
- powerpc/pseries: Enforce hcall result buffer validity and size (Mamatha Inamdar) [RHEL-48291] {CVE-2024-40974}
- wifi: mac80211: fix potential key use-after-free (Jose Ignacio Tornos Martinez) [RHEL-28007] {CVE-2023-52530}
- cppc_cpufreq: Fix possible null pointer dereference (Mark Langsdorf) [RHEL-44137] {CVE-2024-38573}
- net/sched: act_mirred: use the backlog for mirred ingress (Davide Caratti) [RHEL-31718] {CVE-2024-26740}
- vfio/pci: Lock external INTx masking ops (Alex Williamson) [RHEL-31922] {CVE-2024-26810}
- net: sched: sch_multiq: fix possible OOB write in multiq_tune() (Davide Caratti) [RHEL-43464] {CVE-2024-36978}
- tcp: fix tcp_init_transfer() to not reset icsk_ca_initialized (Guillaume Nault) [RHEL-37850] {CVE-2021-47304}
- pstore/ram: Fix crash when setting number of cpus to an odd number (Lenny Szubowicz) [RHEL-29471] {CVE-2023-52619}
- drm/vmwgfx: fix a memleak in vmw_gmrid_man_get_node (Jocelyn Falempe) [RHEL-37101] {CVE-2023-52662}
- drm/vmwgfx: Fix the lifetime of the bo cursor memory (Jocelyn Falempe) [RHEL-36962] {CVE-2024-35810}
- drm/vmwgfx: Create debugfs ttm_resource_manager entry only if needed (Jocelyn Falempe) [RHEL-34987] {CVE-2024-26940}
- drm/vmwgfx: Unmap the surface before resetting it on a plane state (Jocelyn Falempe) [RHEL-35217] {CVE-2023-52648}
- drm/vmwgfx: Fix invalid reads in fence signaled events (Jocelyn Falempe) [RHEL-40010] {CVE-2024-36960}
- block: Fix wrong offset in bio_truncate() (Ming Lei) [RHEL-43782] {CVE-2022-48747}
- bonding: Fix out-of-bounds read in bond_option_arp_ip_targets_set() (CKI Backport Bot) [RHEL-46913] {CVE-2024-39487}
- net: fix __dst_negative_advice() race (Xin Long) [RHEL-41183] {CVE-2024-36971}
- igc: avoid returning frame twice in XDP_REDIRECT (Corinna Vinschen) [RHEL-33264] {CVE-2024-26853}
- mac802154: fix llsec key resources release in mac802154_llsec_key_del (Steve Best) [RHEL-34967] {CVE-2024-26961}
- cpufreq: exit() callback is optional (Mark Langsdorf) [RHEL-43840] {CVE-2024-38615}
- cifs: prevent infinite recursion in CIFSGetDFSRefer() (Paulo Alcantara) [RHEL-34672]
- cifs: lock chan_lock outside match_session (Paulo Alcantara) [RHEL-34672]
- smb3: workaround negprot bug in some Samba servers (Paulo Alcantara) [RHEL-34672]
- smb3: use netname when available on secondary channels (Paulo Alcantara) [RHEL-34672]
- smb3: fix empty netname context on secondary channels (Paulo Alcantara) [RHEL-34672]
- cifs: populate empty hostnames for extra channels (Paulo Alcantara) [RHEL-34672]
- cifs: always iterate smb sessions using primary channel (Paulo Alcantara) [RHEL-34672]
- cifs: Fix connections leak when tlink setup failed (Paulo Alcantara) [RHEL-34672]
- cifs: Fix memory leak when build ntlmssp negotiate blob failed (Paulo Alcantara) [RHEL-34672]
- cifs: always initialize struct msghdr smb_msg completely (Paulo Alcantara) [RHEL-34672]
- cifs: don't send down the destination address to sendmsg for a SOCK_STREAM (Paulo Alcantara) [RHEL-34672]
- cifs: revalidate mapping when doing direct writes (Paulo Alcantara) [RHEL-34672]
- cifs: skip extra NULL byte in filenames (Paulo Alcantara) [RHEL-34672]
- cifs: list_for_each() -> list_for_each_entry() (Paulo Alcantara) [RHEL-34672]
- smb2: small refactor in smb2_check_message() (Paulo Alcantara) [RHEL-34672]
- cifs: Fix crash on unload of cifs_arc4.ko (Paulo Alcantara) [RHEL-34672]
- cifs: remove check of list iterator against head past the loop body (Paulo Alcantara) [RHEL-34672]
- cifs: fix reconnect on smb3 mount types (Paulo Alcantara) [RHEL-34672]
- cifs: fix uninitialized pointer in error case in dfs_cache_get_tgt_share (Paulo Alcantara) [RHEL-34672]
- cifs: skip trailing separators of prefix paths (Paulo Alcantara) [RHEL-34672]
- cifs: fix ntlmssp on old servers (Paulo Alcantara) [RHEL-34672]
- cifs: fix NULL ptr dereference in refresh_mounts() (Paulo Alcantara) [RHEL-34672]
- cifs: do not skip link targets when an I/O fails (Paulo Alcantara) [RHEL-34672]
- cifs: fix confusing unneeded warning message on smb2.1 and earlier (Paulo Alcantara) [RHEL-34672]
- smb3: fix snapshot mount option (Paulo Alcantara) [RHEL-34672]
- cifs: fix workstation_name for multiuser mounts (Paulo Alcantara) [RHEL-34672]
- cifs: alloc_path_with_tree_prefix: do not append sep. if the path is empty (Paulo Alcantara) [RHEL-34672]
- cifs: free ntlmsspblob allocated in negotiate (Paulo Alcantara) [RHEL-34672]
- cifs: avoid use of dstaddr as key for fscache client cookie (Paulo Alcantara) [RHEL-34672]
- cifs: add server conn_id to fscache client cookie (Paulo Alcantara) [RHEL-34672]
- cifs: fix missed refcounting of ipc tcon (Paulo Alcantara) [RHEL-34672]
- smb2: clarify rc initialization in smb2_reconnect (Paulo Alcantara) [RHEL-34672]
- cifs: populate server_hostname for extra channels (Paulo Alcantara) [RHEL-34672]
- cifs: nosharesock should be set on new server (Paulo Alcantara) [RHEL-34672]
- cifs: introduce cifs_ses_mark_for_reconnect() helper (Paulo Alcantara) [RHEL-34672]
- cifs: protect srv_count with cifs_tcp_ses_lock (Paulo Alcantara) [RHEL-34672]
- cifs: move debug print out of spinlock (Paulo Alcantara) [RHEL-34672]
- cifs: do not duplicate fscache cookie for secondary channels (Paulo Alcantara) [RHEL-34672]
- cifs: connect individual channel servers to primary channel server (Paulo Alcantara) [RHEL-34672]
- cifs: protect session channel fields with chan_lock (Paulo Alcantara) [RHEL-34672]
- cifs: do not negotiate session if session already exists (Paulo Alcantara) [RHEL-34672]
- smb3: do not setup the fscache_super_cookie until fsinfo initialized (Paulo Alcantara) [RHEL-34672]
- cifs: fix potential use-after-free bugs (Paulo Alcantara) [RHEL-34672]
- cifs: release lock earlier in dequeue_mid error case (Paulo Alcantara) [RHEL-34672]
- smb3: remove trivial dfs compile warning (Paulo Alcantara) [RHEL-34672]
- cifs: support nested dfs links over reconnect (Paulo Alcantara) [RHEL-34672]
- cifs: for compound requests, use open handle if possible (Paulo Alcantara) [RHEL-34672]
- cifs: split out dfs code from cifs_reconnect() (Paulo Alcantara) [RHEL-34672]
- cifs: convert list_for_each to entry variant (Paulo Alcantara) [RHEL-34672]
- cifs: introduce new helper for cifs_reconnect() (Paulo Alcantara) [RHEL-34672]
- cifs: fix print of hdr_flags in dfscache_proc_show() (Paulo Alcantara) [RHEL-34672]
- cifs: send workstation name during ntlmssp session setup (Paulo Alcantara) [RHEL-34672]
- cifs: nosharesock should not share socket with future sessions (Paulo Alcantara) [RHEL-34672]
- smb3: add dynamic trace points for socket connection (Paulo Alcantara) [RHEL-34672]
- cifs: Move SMB2_Create definitions to the shared area (Paulo Alcantara) [RHEL-34672]
- cifs: Move more definitions into the shared area (Paulo Alcantara) [RHEL-34672]
- cifs: move NEGOTIATE_PROTOCOL definitions out into the common area (Paulo Alcantara) [RHEL-34672]
- cifs: Create a new shared file holding smb2 pdu definitions (Paulo Alcantara) [RHEL-34672]
- cifs: fix incorrect check for null pointer in header_assemble (Paulo Alcantara) [RHEL-34672]
- smb3: correct server pointer dereferencing check to be more consistent (Paulo Alcantara) [RHEL-34672]
- cifs: Deal with some warnings from W=1 (Paulo Alcantara) [RHEL-34672]
- cifs: fix a sign extension bug (Paulo Alcantara) [RHEL-34672]
- cifs: fix incorrect kernel doc comments (Paulo Alcantara) [RHEL-34672]
- cifs: remove pathname for file from SPDX header (Paulo Alcantara) [RHEL-34672]
- cifs: move SMB FSCTL definitions to common code (Paulo Alcantara) [RHEL-34672]
- cifs: rename cifs_common to smbfs_common (Paulo Alcantara) [RHEL-34672]
- cifs: update FSCTL definitions (Paulo Alcantara) [RHEL-34672]
- cifs: cifs_md4 convert to SPDX identifier (Paulo Alcantara) [RHEL-34672]
- cifs: create a MD4 module and switch cifs.ko to use it (Paulo Alcantara) [RHEL-34672]
- cifs: fork arc4 and create a separate module for it for cifs and other users (Paulo Alcantara) [RHEL-34672]
- smb3: fix posix extensions mount option (Paulo Alcantara) [RHEL-34672]
- cifs: fix wrong release in sess_alloc_buffer() failed path (Paulo Alcantara) [RHEL-34672]
- CIFS: Fix a potencially linear read overflow (Paulo Alcantara) [RHEL-34672]
- cifs: use the correct max-length for dentry_path_raw() (Paulo Alcantara) [RHEL-34672]
- cifs: create sd context must be a multiple of 8 (Paulo Alcantara) [RHEL-34672]
- cifs: do not share tcp sessions of dfs connections (Paulo Alcantara) [RHEL-34672]
- cifs: added WARN_ON for all the count decrements (Paulo Alcantara) [RHEL-34672]
- cifs: fix missing null session check in mount (Paulo Alcantara) [RHEL-34672]
- cifs: handle reconnect of tcon when there is no cached dfs referral (Paulo Alcantara) [RHEL-34672]
- cifs: fix the out of range assignment to bit fields in parse_server_interfaces (Paulo Alcantara) [RHEL-34672]
- smb3: fix typo in header file (Paulo Alcantara) [RHEL-34672]
- SMB3.1.1: Add support for negotiating signing algorithm (Paulo Alcantara) [RHEL-34672]
- cifs: prevent NULL deref in cifs_compose_mount_options() (Paulo Alcantara) [RHEL-34672]
- cifs: fix NULL dereference in smb2_check_message() (Paulo Alcantara) [RHEL-34672]
- smbdirect: missing rc checks while waiting for rdma events (Paulo Alcantara) [RHEL-34672]
- cifs: Avoid field over-reading memcpy() (Paulo Alcantara) [RHEL-34672]
- smb311: remove dead code for non compounded posix query info (Paulo Alcantara) [RHEL-34672]
- cifs: fix SMB1 error path in cifs_get_file_info_unix (Paulo Alcantara) [RHEL-34672]
- smb3: fix uninitialized value for port in witness protocol move (Paulo Alcantara) [RHEL-34672]
- cifs: fix unneeded null check (Paulo Alcantara) [RHEL-34672]
- cifs: use SPDX-Licence-Identifier (Paulo Alcantara) [RHEL-34672]
- cifs: convert list_for_each to entry variant in cifs_debug.c (Paulo Alcantara) [RHEL-34672]
- cifs: convert list_for_each to entry variant in smb2misc.c (Paulo Alcantara) [RHEL-34672]
- cifs: missed ref-counting smb session in find (Paulo Alcantara) [RHEL-34672]
- cifs: do not share tcp servers with dfs mounts (Paulo Alcantara) [RHEL-34672]
- cifs: set a minimum of 2 minutes for refreshing dfs cache (Paulo Alcantara) [RHEL-34672]
- cifs: Remove unused inline function is_sysvol_or_netlogon() (Paulo Alcantara) [RHEL-34672]
- cifs: remove duplicated prototype (Paulo Alcantara) [RHEL-34672]
- cifs: fix ipv6 formating in cifs_ses_add_channel (Paulo Alcantara) [RHEL-34672]
- cifs: fix string declarations and assignments in tracepoints (Paulo Alcantara) [RHEL-34672]
- cifs: fix memory leak in smb2_copychunk_range (Paulo Alcantara) [RHEL-34672]
- SMB3: incorrect file id in requests compounded with open (Paulo Alcantara) [RHEL-34672]
- smb3: if max_channels set to more than one channel request multichannel (Paulo Alcantara) [RHEL-34672]
- smb3: do not attempt multichannel to server which does not support it (Paulo Alcantara) [RHEL-34672]
- smb3: when mounting with multichannel include it in requested capabilities (Paulo Alcantara) [RHEL-34672]
- cifs: simplify SWN code with dummy funcs instead of ifdefs (Paulo Alcantara) [RHEL-34672]
- cifs: log mount errors using cifs_errorf() (Paulo Alcantara) [RHEL-34672]
- cifs: switch build_path_from_dentry() to using dentry_path_raw() (Paulo Alcantara) [RHEL-34672]
- cifs: fix out-of-bound memory access when calling smb3_notify() at mount point (Paulo Alcantara) [RHEL-34672]
- cifs: allocate buffer in the caller of build_path_from_dentry() (Paulo Alcantara) [RHEL-34672]
- cifs: make build_path_from_dentry() return const char * (Paulo Alcantara) [RHEL-34672]
- cifs: remove old dead code (Paulo Alcantara) [RHEL-34672]
- fs: cifs: Remove repeated struct declaration (Paulo Alcantara) [RHEL-34672]
- cifs: have cifs_fattr_to_inode() refuse to change type on live inode (Paulo Alcantara) [RHEL-34672]
- cifs: have ->mkdir() handle race with another client sanely (Paulo Alcantara) [RHEL-34672]
- do_cifs_create(): don't set ->i_mode of something we had not created (Paulo Alcantara) [RHEL-34672]
- cifs: Silently ignore unknown oplock break handle (Paulo Alcantara) [RHEL-34672]
- cifs: change noisy error message to FYI (Paulo Alcantara) [RHEL-34672]
- cifs: print MIDs in decimal notation (Paulo Alcantara) [RHEL-34672]
- cifs: minor simplification to smb2_is_network_name_deleted (Paulo Alcantara) [RHEL-34672]
- TCON Reconnect during STATUS_NETWORK_NAME_DELETED (Paulo Alcantara) [RHEL-34672]
- cifs: clarify hostname vs ip address in /proc/fs/cifs/DebugData (Paulo Alcantara) [RHEL-34672]
- cifs: change confusing field serverName (to ip_addr) (Paulo Alcantara) [RHEL-34672]
- cifs: Reformat DebugData and index connections by conn_id. (Paulo Alcantara) [RHEL-34672]
- cifs: Identify a connection by a conn_id. (Paulo Alcantara) [RHEL-34672]
- smb3: negotiate current dialect (SMB3.1.1) when version 3 or greater requested (Paulo Alcantara) [RHEL-34672]
- smb3: Fix out-of-bounds bug in SMB2_negotiate() (Paulo Alcantara) [RHEL-34672]
- fs/cifs: Simplify bool comparison. (Paulo Alcantara) [RHEL-34672]
- fs/cifs: Assign boolean values to a bool variable (Paulo Alcantara) [RHEL-34672]
- cifs: Avoid error pointer dereference (Paulo Alcantara) [RHEL-34672]
- cifs: Re-indent cifs_swn_reconnect() (Paulo Alcantara) [RHEL-34672]
- cifs: Unlock on errors in cifs_swn_reconnect() (Paulo Alcantara) [RHEL-34672]
- cifs: Delete a stray unlock in cifs_swn_reconnect() (Paulo Alcantara) [RHEL-34672]
- cifs: Tracepoints and logs for tracing credit changes. (Paulo Alcantara) [RHEL-34672]
- cifs: Fix some error pointers handling detected by static checker (Paulo Alcantara) [RHEL-34672]
- smb3: remind users that witness protocol is experimental (Paulo Alcantara) [RHEL-34672]
- SMB3.1.1: do not log warning message if server doesn't populate salt (Paulo Alcantara) [RHEL-34672]
- SMB3.1.1: update comments clarifying SPNEGO info in negprot response (Paulo Alcantara) [RHEL-34672]
- SMB3.1.1: remove confusing mount warning when no SPNEGO info on negprot rsp (Paulo Alcantara) [RHEL-34672]
- SMB3: avoid confusing warning message on mount to Azure (Paulo Alcantara) [RHEL-34672]
- md/raid5: fix deadlock that raid5d() wait for itself to clear MD_SB_CHANGE_PENDING (Nigel Croxon) [RHEL-46662] {CVE-2024-39476}
- net: fix information leakage in /proc/net/ptype (Hangbin Liu) [RHEL-44000] {CVE-2022-48757}
- usb: typec: ucsi: Limit read size on v1.2 (Desnes Nunes) [RHEL-37286] {CVE-2024-35924}
- minmax: relax check to allow comparison between unsigned arguments and signed constants (Desnes Nunes) [RHEL-37286]
- minmax: allow comparisons of 'int' against 'unsigned char/short' (Desnes Nunes) [RHEL-37286]
- minmax: allow min()/max()/clamp() if the arguments have the same signedness. (Desnes Nunes) [RHEL-37286]
- minmax: add umin(a, b) and umax(a, b) (Desnes Nunes) [RHEL-37286]
- minmax: fix header inclusions (Desnes Nunes) [RHEL-37286]
- minmax: clamp more efficiently by avoiding extra comparison (Desnes Nunes) [RHEL-37286]
- minmax: sanity check constant bounds when clamping (Desnes Nunes) [RHEL-37286]
- tracing: Define the is_signed_type() macro once (Desnes Nunes) [RHEL-37286]
- linux/bits.h: fix compilation error with GENMASK (Desnes Nunes) [RHEL-37286]
- x86/apic: Mask IOAPIC entries when disabling the local APIC (Lenny Szubowicz) [RHEL-18077]
- userfaultfd: fix a race between writeprotect and exit_mmap() (Rafael Aquini) [RHEL-38410] {CVE-2021-47461}
- mm: khugepaged: skip huge page collapse for special files (Waiman Long) [RHEL-38446] {CVE-2021-47491}
- cachefiles: fix memory leak in cachefiles_add_cache() (Andrey Albershteyn) [RHEL-33109] {CVE-2024-26840}
- drm/amd/display: Implement bounds check for stream encoder creation in DCN301 (Michel Dänzer) [RHEL-31429] {CVE-2024-26660}
- net/mlx5: Discard command completions in internal error (Kamal Heib) [RHEL-44231] {CVE-2024-38555}
- drm: Don't unref the same fb many times by mistake due to deadlock handling (CKI Backport Bot) [RHEL-29011] {CVE-2023-52486}
- md: fix resync softlockup when bitmap size is less than array size (Nigel Croxon) [RHEL-43942] {CVE-2024-38598}
- rtnetlink: Correct nested IFLA_VF_VLAN_LIST attribute validation (Davide Caratti) [RHEL-39712] {CVE-2024-36017}
- netfilter: nf_tables: discard table flag update with pending basechain deletion (Phil Sutter) [RHEL-37205] {CVE-2024-35897}
- netfilter: nf_tables: reject table flag and netdev basechain updates (Phil Sutter) [RHEL-37205]
- scsi: lpfc: Release hbalock before calling lpfc_worker_wake_up() (Ewan D. Milne) [RHEL-40172] {CVE-2024-36924}
- scsi: lpfc: Move NPIV's transport unregistration to after resource clean up (Ewan D. Milne) [RHEL-40172] {CVE-2024-36952}
- netfilter: nf_tables: fix memleak in map from abort path (Phil Sutter) [RHEL-35052] {CVE-2024-27011}
- netfilter: nf_tables: reject new basechain after table flag update (Phil Sutter) [RHEL-37193] {CVE-2024-35900}
- netfilter: nf_tables: flush pending destroy work before exit_net release (Phil Sutter) [RHEL-37197] {CVE-2024-35899}
- netfilter: complete validation of user input (Phil Sutter) [RHEL-37210]
- netfilter: validate user input for expected length (Phil Sutter) [RHEL-37210] {CVE-2024-35896}
- netfilter: tproxy: bail out if IP has been disabled on the device (Phil Sutter) [RHEL-44363] {CVE-2024-36270}
- netfilter: nfnetlink_queue: acquire rcu_read_lock() in instance_destroy_rcu() (Phil Sutter) [RHEL-44532] {CVE-2024-36286}
- netfilter: nf_tables: do not compare internal table flags on updates (Phil Sutter) [RHEL-35114] {CVE-2024-27065}
- netfilter: nf_tables: Fix potential data-race in __nft_obj_type_get() (Phil Sutter) [RHEL-35028] {CVE-2024-27019}
- netfilter: nf_tables: Fix potential data-race in __nft_expr_type_get() (Phil Sutter) [RHEL-35024] {CVE-2024-27020}
- netfilter: nf_tables: __nft_expr_type_get() selects specific family type (Phil Sutter) [RHEL-35024]
- netfilter: conntrack: serialize hash resizes and cleanups (Phil Sutter) [RHEL-37703] {CVE-2021-47408}
- netfilter: nf_tables: release mutex after nft_gc_seq_end from abort path (Phil Sutter) [RHEL-34217] {CVE-2024-26925}
- netfilter: nf_tables: release batch on table validation from abort path (Phil Sutter) [RHEL-34217]
- ipvlan: add ipvlan_route_v6_outbound() helper (Davide Caratti) [RHEL-38319] {CVE-2023-52796}

* Wed Jul 10 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.12.1.el8_10]
- net: bridge: xmit: make sure we have at least eth header len bytes (cki-backport-bot) [RHEL-44291] {CVE-2024-38538}
- drivers/amd/pm: fix a use-after-free in kv_parse_power_table (Michel Dänzer) [RHEL-26893] {CVE-2023-52469}
- SUNRPC: Fix a suspicious RCU usage warning (Scott Mayhew) [RHEL-30503] {CVE-2023-52623}
- ice: Fix some null pointer dereference issues in ice_ptp.c (Petr Oros) [RHEL-26901] {CVE-2023-52471}
- xfs: fix internal error from AGFL exhaustion (Pavel Reichl) [RHEL-45581]
- sched/psi: Fix use-after-free in ep_remove_wait_queue() (Phil Auld) [RHEL-38117] {CVE-2023-52707}
- wait: add wake_up_pollfree() (Phil Auld) [RHEL-38117]
- net/ipv6: avoid possible UAF in ip6_route_mpath_notify() (Hangbin Liu) [RHEL-33269] {CVE-2024-26852}
- net: bridge: switchdev: Skip MDB replays of deferred events on offload (Ivan Vecera) [RHEL-33117] {CVE-2024-26837}
- ext4: avoid allocating blocks from corrupted group in ext4_mb_find_by_goal() (Pavel Reichl) [RHEL-31700] {CVE-2024-26772}
- ext4: avoid allocating blocks from corrupted group in ext4_mb_try_best_found() (Pavel Reichl) [RHEL-31688] {CVE-2024-26773}
- ext4: fix double-free of blocks due to wrong extents moved_len (Pavel Reichl) [RHEL-31612] {CVE-2024-26704}
- vxlan: Pull inner IP header in vxlan_xmit_one(). (Guillaume Nault) [RHEL-31389]
- geneve: Fix incorrect inner network header offset when innerprotoinherit is set (Guillaume Nault) [RHEL-31389]
- vxlan: Pull inner IP header in vxlan_rcv(). (Guillaume Nault) [RHEL-31389]
- geneve: fix header validation in geneve[6]_xmit_skb (Guillaume Nault) [RHEL-31389]
- geneve: make sure to pull inner header in geneve_rx() (Guillaume Nault) [RHEL-31389]
- net: geneve: modify IP header check in geneve6_xmit_skb and geneve_xmit_skb (Guillaume Nault) [RHEL-31389]
- net: geneve: check skb is large enough for IPv4/IPv6 header (Guillaume Nault) [RHEL-31389]
- net/smc: fix neighbour and rtable leak in smc_ib_find_route() (Tobias Huschle) [RHEL-39744] {CVE-2024-36945}
- igb: Fix string truncation warnings in igb_set_fw_version (Corinna Vinschen) [RHEL-38452] {CVE-2024-36010}
- bonding: stop the device in bond_setup_by_slave() (Hangbin Liu) [RHEL-38327] {CVE-2023-52784}
- i40e: fix vf may be used uninitialized in this function warning (Kamal Heib) [RHEL-39702] {CVE-2024-36020}
- powerpc/64: Fix the definition of the fixmap area (Mamatha Inamdar) [RHEL-27191] {CVE-2021-47018}
- powerpc/mm/hash64: Add a variable to track the end of IO mapping (Mamatha Inamdar) [RHEL-27191] {CVE-2021-47018}
- nsh: Restore skb->{protocol,data,mac_header} for outer header in nsh_gso_segment(). (Xin Long) [RHEL-39770] {CVE-2024-36933}
- net: nsh: Use correct mac_offset to unwind gso skb in nsh_gso_segment() (Xin Long) [RHEL-39770]
- net: core: reject skb_copy(_expand) for fraglist GSO skbs (Xin Long) [RHEL-39779] {CVE-2024-36929}
- tcp: properly terminate timers for kernel sockets (Guillaume Nault) [RHEL-37171] {CVE-2024-35910}
- net: relax socket state check at accept time. (Florian Westphal) [RHEL-39831]
- tcp: defer shutdown(SEND_SHUTDOWN) for TCP_SYN_RECV sockets (Florian Westphal) [RHEL-39831] {CVE-2024-36905}
- tcp: remove redundant check on tskb (Florian Westphal) [RHEL-39831]
- drm/ast: Fix soft lockup (cki-backport-bot) [RHEL-37438] {CVE-2024-35952}
- null_blk: Fix return value of nullb_device_power_store() (Ming Lei) [RHEL-39341]
- null_blk: fix null-ptr-dereference while configuring 'power' and 'submit_queues' (Ming Lei) [RHEL-39341]
- null_blk: fix return value from null_add_dev() (Ming Lei) [RHEL-39341]

* Wed Jul 03 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.11.1.el8_10]
- x86/bugs: Reverse instruction order of CLEAR_CPU_BUFFERS (Waiman Long) [RHEL-42121]
- Revert "x86/bugs: Use fixed addressing for VERW operand" (Waiman Long) [RHEL-42121]
- KVM/x86: Export RFDS_NO and RFDS_CLEAR to guests (Waiman Long) [RHEL-42121]
- x86/rfds: Mitigate Register File Data Sampling (RFDS) (Waiman Long) [RHEL-42121]
- Documentation/hw-vuln: Add documentation for RFDS (Waiman Long) [RHEL-42121]
- x86/mmio: Disable KVM mitigation when X86_FEATURE_CLEAR_CPU_BUF is set (Waiman Long) [RHEL-42121]
- x86/bugs: Use fixed addressing for VERW operand (Waiman Long) [RHEL-42121]
- KVM/VMX: Use BT+JNC, i.e. EFLAGS.CF to select VMRESUME vs. VMLAUNCH (Waiman Long) [RHEL-42121]
- x86/bugs: Use ALTERNATIVE() instead of mds_user_clear static key (Waiman Long) [RHEL-42121]
- x86/entry_32: Add VERW just before userspace transition (Waiman Long) [RHEL-42121]
- x86/entry_64: Add VERW just before userspace transition (Waiman Long) [RHEL-42121]
- x86/bugs: Add asm helpers for executing VERW (Waiman Long) [RHEL-42121]
- x86/cpu: Fix Gracemont uarch (Waiman Long) [RHEL-42121]
- Documentation/hw-vuln: Unify filename specification in index (Waiman Long) [RHEL-42121]
- KVM: VMX: Access @flags as a 32-bit value in __vmx_vcpu_run() (Waiman Long) [RHEL-42121]
- x86/asm: Add _ASM_RIP() macro for x86-64 (%%rip) suffix (Waiman Long) [RHEL-42121]
- x86/asm: Have the __ASM_FORM macros handle commas in arguments (Waiman Long) [RHEL-42121]
- x86/asm: Allow to pass macros to __ASM_FORM() (Waiman Long) [RHEL-42121]
- wifi: iwlwifi: mvm: guard against invalid STA ID on removal (Jose Ignacio Tornos Martinez) [RHEL-39801] {CVE-2024-36921}
- ipv6: Fix potential uninit-value access in __ip6_make_skb() (Antoine Tenart) [RHEL-39784]
- ipv4: Fix uninit-value access in __ip_make_skb() (Antoine Tenart) [RHEL-39784] {CVE-2024-36927}
- perf mmap: Lazily initialize zstd streams to save memory when not using it (Michael Petlan) [RHEL-34876]
- perf tools: Fix spelling mistake "commpressor" -> "compressor" (Michael Petlan) [RHEL-34876]
- perf record: Introduce data transferred and compressed stats (Michael Petlan) [RHEL-34876]
- perf record: Introduce compressor at mmap buffer object (Michael Petlan) [RHEL-34876]
- perf record: Introduce bytes written stats (Michael Petlan) [RHEL-34876]
- perf record: Introduce data file at mmap buffer object (Michael Petlan) [RHEL-34876]
- perf record: Start threads in the beginning of trace streaming (Alexey Bayduraev) [RHEL-34876]
- perf record: Stop threads in the end of trace streaming (Michael Petlan) [RHEL-34876]
- perf record: Introduce thread local variable (Michael Petlan) [RHEL-34876]
- perf record: Introduce function to propagate control commands (Michael Petlan) [RHEL-34876]
- perf record: Introduce thread specific data array (Michael Petlan) [RHEL-34876]
- tools lib: Introduce fdarray duplicate function (Michael Petlan) [RHEL-34876]
- perf record: Introduce thread affinity and mmap masks (Michael Petlan) [RHEL-34876]
- gfs2: Be more careful with the quota sync generation (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Get rid of some unnecessary quota locking (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Add some missing quota locking (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Fold qd_fish into gfs2_quota_sync (Andreas Gruenbacher) [RHEL-40901]
- gfs2: quota need_sync cleanup (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Fix and clean up function do_qc (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Revert "Add quota_change type" (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Revert "ignore negated quota changes" (Andreas Gruenbacher) [RHEL-40901]
- gfs2: qd_check_sync cleanups (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Check quota consistency on mount (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Minor gfs2_quota_init error path cleanup (Andreas Gruenbacher) [RHEL-40901]
- gfs2: fix kernel BUG in gfs2_quota_cleanup (Edward Adam Davis) [RHEL-40901]
- gfs2: Clean up quota.c:print_message (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Clean up gfs2_alloc_parms initializers (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Two quota=account mode fixes (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Remove useless assignment (Bob Peterson) [RHEL-40901]
- gfs2: simplify slot_get (Bob Peterson) [RHEL-40901]
- gfs2: Simplify qd2offset (Bob Peterson) [RHEL-40901]
- gfs2: Remove quota allocation info from quota file (Bob Peterson) [RHEL-40901]
- gfs2: use constant for array size (Bob Peterson) [RHEL-40901]
- gfs2: Set qd_sync_gen in do_sync (Bob Peterson) [RHEL-40901]
- gfs2: Remove useless err set (Bob Peterson) [RHEL-40901]
- gfs2: Small gfs2_quota_lock cleanup (Bob Peterson) [RHEL-40901]
- gfs2: move qdsb_put and reduce redundancy (Bob Peterson) [RHEL-40901]
- gfs2: Don't try to sync non-changes (Bob Peterson) [RHEL-40901]
- gfs2: Simplify function need_sync (Bob Peterson) [RHEL-40901]
- gfs2: remove unneeded pg_oflow variable (Bob Peterson) [RHEL-40901]
- gfs2: remove unneeded variable done (Bob Peterson) [RHEL-40901]
- gfs2: pass sdp to gfs2_write_buf_to_page (Bob Peterson) [RHEL-40901]
- gfs2: pass sdp in to gfs2_write_disk_quota (Bob Peterson) [RHEL-40901]
- gfs2: Pass sdp to gfs2_adjust_quota (Bob Peterson) [RHEL-40901]
- gfs2: remove dead code for quota writes (Bob Peterson) [RHEL-40901]
- gfs2: Use qd_sbd more consequently (Bob Peterson) [RHEL-40901]
- gfs2: replace 'found' with dedicated list iterator variable (Jakob Koschel) [RHEL-40901]
- gfs2: Some whitespace cleanups (Andreas Gruenbacher) [RHEL-40901]
- gfs2: Fix gfs2_qa_get imbalance in gfs2_quota_hold (Bob Peterson) [RHEL-40901]
- af_unix: Fix data races in unix_release_sock/unix_stream_sendmsg (Guillaume Nault) [RHEL-43961] {CVE-2024-38596}
- af_unix: Fix data-races around sk->sk_shutdown. (Guillaume Nault) [RHEL-43961] {CVE-2024-38596}
- af_unix: Fix data races around sk->sk_shutdown. (Guillaume Nault) [RHEL-43961] {CVE-2024-38596}
- perf/core: Fix event sibling list locking (Daniel Vacek) [RHEL-31798]
- media: bttv: fix use after free error due to btv->timeout timer (Kate Hsuan) [RHEL-38256] {CVE-2023-52847}
- arp: Prevent overflow in arp_req_get(). (Antoine Tenart) [RHEL-31706] {CVE-2024-26733}
- Bluetooth: btusb: Add a new PID/VID 0489/e0c8 for MT7921 (David Marlin) [RHEL-10263]
- mm: swap: fix race between free_swap_and_cache() and swapoff() (Waiman Long) [RHEL-34971] {CVE-2024-26960}
- swap: comments get_swap_device() with usage rule (Waiman Long) [RHEL-34971] {CVE-2024-26960}
- mm/swapfile.c: __swap_entry_free() always free 1 entry (Waiman Long) [RHEL-34971] {CVE-2024-26960}
- mm/swapfile.c: call free_swap_slot() in __swap_entry_free() (Waiman Long) [RHEL-34971] {CVE-2024-26960}
- mm/swapfile.c: use __try_to_reclaim_swap() in free_swap_and_cache() (Waiman Long) [RHEL-34971] {CVE-2024-26960}
- net: amd-xgbe: Fix skb data length underflow (Ken Cox) [RHEL-43788] {CVE-2022-48743}
- ovl: fix warning in ovl_create_real() (cki-backport-bot) [RHEL-43652] {CVE-2021-47579}
- net/sched: initialize noop_qdisc owner (Davide Caratti) [RHEL-35056]
- net/sched: Fix mirred deadlock on device recursion (Davide Caratti) [RHEL-35056] {CVE-2024-27010}
- ext4: fix mb_cache_entry's e_refcnt leak in ext4_xattr_block_cache_find() (Pavel Reichl) [RHEL-45029] {CVE-2024-39276}
- ethernet: hisilicon: hns: hns_dsaf_misc: fix a possible array overflow in hns_dsaf_ge_srst_by_port() (Ken Cox) [RHEL-38713] {CVE-2021-47548}
- ipvlan: Dont Use skb->sk in ipvlan_process_v{4,6}_outbound (Hangbin Liu) [RHEL-44396] {CVE-2024-33621}
- mlxsw: spectrum_acl_tcam: Fix stack corruption (Ivan Vecera) [RHEL-26462] {CVE-2024-26586}
- inet: inet_defrag: prevent sk release while still in use (Antoine Tenart) [RHEL-33398] {CVE-2024-26921}
- skb_expand_head() adjust skb->truesize incorrectly (Antoine Tenart) [RHEL-33398]
- nvmet: fix ns enable/disable possible hang (Ming Lei) [RHEL-43547]

* Fri Jun 28 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.10.1.el8_10]
- SUNRPC: Fix RPC client cleaned up the freed pipefs dentries (Scott Mayhew) [RHEL-38264] {CVE-2023-52803}
- scsi: qla2xxx: Fix off by one in qla_edif_app_getstats() (Ewan D. Milne) [RHEL-39717] {CVE-2024-36025}
- tcp: add sanity checks to rx zerocopy (Guillaume Nault) [RHEL-29494] {CVE-2024-26640}
- SUNRPC: fix some memleaks in gssx_dec_option_array (Scott Mayhew) [RHEL-35209] {CVE-2024-27388}
- wifi: nl80211: don't free NULL coalescing rule (Jose Ignacio Tornos Martinez) [RHEL-39752] {CVE-2024-36941}
- nfs: fix UAF in direct writes (Scott Mayhew) [RHEL-34975] {CVE-2024-26958}
- NFSv4.2: fix nfs4_listxattr kernel BUG at mm/usercopy.c:102 (Scott Mayhew) [RHEL-33228] {CVE-2024-26870}
- drm/amd/pm: Fix error of MACO flag setting code (Michel Dänzer) [RHEL-15928]
- scsi: aacraid: fix io hangs and improve performance (John Meneghini) [RHEL-23913]
- block: prevent division by zero in blk_rq_stat_sum() (Ming Lei) [RHEL-37279] {CVE-2024-35925}
- block: fix overflow in blk_ioctl_discard() (Ming Lei) [RHEL-39811] {CVE-2024-36917}
- virtio-blk: fix implicit overflow on virtio_max_dma_size (Ming Lei) [RHEL-38131] {CVE-2023-52762}
- nbd: null check for nla_nest_start (Ming Lei) [RHEL-35176] {CVE-2024-27025}
- isdn: mISDN: netjet: Fix crash in nj_probe: (Ken Cox) [RHEL-38444] {CVE-2021-47284}
- isdn: mISDN: Fix sleeping function called from invalid context (Ken Cox) [RHEL-38400] {CVE-2021-47468}
- net/smc: avoid data corruption caused by decline (Tobias Huschle) [RHEL-38234] {CVE-2023-52775}
- ubi: Check for too small LEB size in VTBL code (David Arcari) [RHEL-25092] {CVE-2024-25739}
- i2c: core: Fix atomic xfer check for non-preempt config (Steve Best) [RHEL-38313] {CVE-2023-52791}
- i2c: core: Run atomic i2c xfer when !preemptible (Steve Best) [RHEL-38313] {CVE-2023-52791}
- firewire: ohci: mask bus reset interrupts between ISR and bottom half (Steve Best) [RHEL-39902] {CVE-2024-36950}
- ipv6: init the accept_queue's spinlocks in inet6_create (Guillaume Nault) [RHEL-28899] {CVE-2024-26614}
- tcp: make sure init the accept_queue's spinlocks once (Guillaume Nault) [RHEL-28899] {CVE-2024-26614}
- tty: n_gsm: fix possible out-of-bounds in gsm0_receive() (Steve Best) [RHEL-39352] {CVE-2024-36016}
- mlxsw: spectrum_acl_tcam: Fix incorrect list API usage (Ivan Vecera) [RHEL-37484] {CVE-2024-36006}
- pwm: Fix double shift bug (Steve Best) [RHEL-38278] {CVE-2023-52756}
- mmc: sdio: fix possible resource leaks in some error paths (Steve Best) [RHEL-38149] {CVE-2023-52730}
- of: unittest: Fix compile in the non-dynamic case (Steve Best) [RHEL-37070] {CVE-2023-52679}
- of: unittest: Fix of_count_phandle_with_args() expected value message (Steve Best) [RHEL-37070] {CVE-2023-52679}
- of: Fix double free in of_parse_phandle_with_args_map (Steve Best) [RHEL-37070] {CVE-2023-52679}
- pinctrl: core: delete incorrect free in pinctrl_enable() (Steve Best) [RHEL-39756] {CVE-2024-36940}
- pinctrl: core: fix possible memory leak in pinctrl_enable() (Steve Best) [RHEL-39756] {CVE-2024-36940}
- media: gspca: cpia1: shift-out-of-bounds in set_flicker (Desnes Nunes) [RHEL-38331] {CVE-2023-52764}
- tipc: fix a possible memleak in tipc_buf_append (Xin Long) [RHEL-39881] {CVE-2024-36954}
- cifs: fix mid leak during reconnection after timeout threshold (Paulo Alcantara) [RHEL-36222]
- cifs: Fix use-after-free in rdata->read_into_pages() (Paulo Alcantara) [RHEL-36222]
- cifs: Fix pages leak when writedata alloc failed in cifs_write_from_iter() (Paulo Alcantara) [RHEL-36222]
- cifs: Fix pages array leak when writedata alloc failed in cifs_writedata_alloc() (Paulo Alcantara) [RHEL-36222]
- cifs: destage dirty pages before re-reading them for cache=none (Paulo Alcantara) [RHEL-36222]
- cifs: destage any unwritten data to the server before calling copychunk_write (Paulo Alcantara) [RHEL-36222]
- Adjust cifssb maximum read size (Paulo Alcantara) [RHEL-36222]
- cifs: make locking consistent around the server session status (Paulo Alcantara) [RHEL-36222]
- cifs: fix credit accounting for extra channel (Paulo Alcantara) [RHEL-36222]
- smb3: prevent races updating CurrentMid (Paulo Alcantara) [RHEL-36222]
- cifs: fix missing spinlock around update to ses->status (Paulo Alcantara) [RHEL-36222]
- cifs: use echo_interval even when connection not ready. (Paulo Alcantara) [RHEL-36222]
- cifs: detect dead connections only when echoes are enabled. (Paulo Alcantara) [RHEL-36222]
- cifs: Fix preauth hash corruption (Paulo Alcantara) [RHEL-36222]
- cifs: do not send close in compound create+close requests (Paulo Alcantara) [RHEL-36222]
- cifs: ask for more credit on async read/write code paths (Paulo Alcantara) [RHEL-36222]
- cifs: use discard iterator to discard unneeded network data more efficiently (Paulo Alcantara) [RHEL-36222]
- cifs: Fix in error types returned for out-of-credit situations. (Paulo Alcantara) [RHEL-36222]
- smb3: fix crediting for compounding when only one request in flight (Paulo Alcantara) [RHEL-36222]
- cifs: New optype for session operations. (Paulo Alcantara) [RHEL-36222]
- mm/gup: do not return 0 from pin_user_pages_fast() for bad args (Paulo Alcantara) [RHEL-36222]
- wifi: brcmfmac: pcie: handle randbuf allocation failure (Jose Ignacio Tornos Martinez) [RHEL-44124] {CVE-2024-38575}
- tcp: Use refcount_inc_not_zero() in tcp_twsk_unique(). (Guillaume Nault) [RHEL-39835] {CVE-2024-36904}
- wifi: mac80211: don't return unset power in ieee80211_get_tx_power() (Jose Ignacio Tornos Martinez) [RHEL-38159] {CVE-2023-52832}
- wifi: ath11k: fix gtk offload status event locking (Jose Ignacio Tornos Martinez) [RHEL-38155] {CVE-2023-52777}
- net: ieee802154: fix null deref in parse dev addr (Steve Best) [RHEL-38012] {CVE-2021-47257}
- mm/hugetlb: fix missing hugetlb_lock for resv uncharge (Rafael Aquini) [RHEL-37465] {CVE-2024-36000}
- x86/xen: Add some null pointer checking to smp.c (Vitaly Kuznetsov) [RHEL-33258] {CVE-2024-26908}
- x86/xen: Fix memory leak in xen_smp_intr_init{_pv}() (Vitaly Kuznetsov) [RHEL-33258] {CVE-2024-26908}
- wifi: cfg80211: check A-MSDU format more carefully (Jose Ignacio Tornos Martinez) [RHEL-37343] {CVE-2024-35937}
- wifi: rtw89: fix null pointer access when abort scan (Jose Ignacio Tornos Martinez) [RHEL-37355] {CVE-2024-35946}
- atl1c: Work around the DMA RX overflow issue (Ken Cox) [RHEL-38287] {CVE-2023-52834}
- wifi: ath11k: decrease MHI channel buffer length to 8KB (Jose Ignacio Tornos Martinez) [RHEL-37339] {CVE-2024-35938}
- wifi: iwlwifi: mvm: rfi: fix potential response leaks (Jose Ignacio Tornos Martinez) [RHEL-37163] {CVE-2024-35912}
- USB: core: Fix access violation during port device removal (Desnes Nunes) [RHEL-39853] {CVE-2024-36896}
- scsi: lpfc: Fix possible memory leak in lpfc_rcv_padisc() (Ewan D. Milne) [RHEL-37123] {CVE-2024-35930}
- netfilter: nf_tables: honor table dormant flag from netdev release event path (Phil Sutter) [RHEL-37450] {CVE-2024-36005}
- wifi: iwlwifi: mvm: don't set the MFP flag for the GTK (Jose Ignacio Tornos Martinez) [RHEL-36898] {CVE-2024-27434}
- wifi: iwlwifi: mvm: Fix key flags for IGTK on AP interface (Jose Ignacio Tornos Martinez) [RHEL-36898] {CVE-2024-27434}
- misc: lis3lv02d_i2c: Fix regulators getting en-/dis-abled twice on suspend/resume (Steve Best) [RHEL-36932] {CVE-2024-35824}

* Fri Jun 21 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.9.1.el8_10]
- x86/mce: Make sure to grab mce_sysfs_mutex in set_bank() (Steve Best) [RHEL-37262] {CVE-2024-35876}
- net/sched: flower: Fix chain template offload (Xin Long) [RHEL-31313] {CVE-2024-26669}
- SUNRPC: fix a memleak in gss_import_v2_context (Scott Mayhew) [RHEL-35195] {CVE-2023-52653}
- efivarfs: force RO when remounting if SetVariable is not supported (Pavel Reichl) [RHEL-26564] {CVE-2023-52463}
- dmaengine: idxd: add a write() method for applications to submit work (Jerry Snitselaar) [RHEL-35826] {CVE-2024-21823}
- dmaengine: idxd: add a new security check to deal with a hardware erratum (Jerry Snitselaar) [RHEL-35826] {CVE-2024-21823}
- VFIO: Add the SPR_DSA and SPR_IAX devices to the denylist (Jerry Snitselaar) [RHEL-35826] {CVE-2024-21823}
- quota: Fix potential NULL pointer dereference (Pavel Reichl) [RHEL-33219] {CVE-2024-26878}
- locking/lockdep: Fix overflow in presentation of average lock-time (Čestmír Kalina) [RHEL-17678]
- blk-cgroup: Properly propagate the iostat update up the hierarchy (Ming Lei) [RHEL-40939]
- proc: Use new_inode not new_inode_pseudo (Ian Kent) [RHEL-40167]
- stmmac: Clear variable when destroying workqueue (Izabela Bakollari) [RHEL-31822] {CVE-2024-26802}
- powerpc/pseries/memhp: Fix access beyond end of drmem array (Mamatha Inamdar) [RHEL-26495] {CVE-2023-52451}
- platform/x86: wmi: Fix opening of char device (David Arcari) [RHEL-38258] {CVE-2023-52864}
- Revert "net/mlx5: Block entering switchdev mode with ns inconsistency" (Kamal Heib) [RHEL-36908] {CVE-2023-52658}
- hv_netvsc: Register VF in netvsc_probe if NET_DEVICE_REGISTER missed (Cathy Avery) [RHEL-39074]
- hv_netvsc: Fix race condition between netvsc_probe and netvsc_remove (Cathy Avery) [RHEL-39074]
- hv_netvsc: Calculate correct ring size when PAGE_SIZE is not 4 Kbytes (Cathy Avery) [RHEL-39074]
- hv_netvsc: remove duplicated including of slab.h (Cathy Avery) [RHEL-39074]
- hv_netvsc: rndis_filter needs to select NLS (Cathy Avery) [RHEL-39074]
- hv_netvsc: Mark VF as slave before exposing it to user-mode (Cathy Avery) [RHEL-39074]
- hv_netvsc: Fix race of register_netdevice_notifier and VF register (Cathy Avery) [RHEL-39074]
- hv_netvsc: fix race of netvsc and VF register_netdevice (Cathy Avery) [RHEL-39074]
- hv_netvsc: fix netvsc_send_completion to avoid multiple message length checks (Cathy Avery) [RHEL-39074]
- hv_netvsc: Allocate rx indirection table size dynamically (Cathy Avery) [RHEL-39074]
- net: hv_netvsc: Fix a warning triggered by memcpy in rndis_filter (Cathy Avery) [RHEL-39074]
- gfs2: Fix lru_count accounting (Andreas Gruenbacher) [RHEL-32941]
- gfs2: Fix "Make glock lru list scanning safer" (Andreas Gruenbacher) [RHEL-32941]
- gfs2: Fix "ignore unlock failures after withdraw" (Andreas Gruenbacher) [RHEL-32941]
- gfs2: Don't set GLF_LOCK in gfs2_dispose_glock_lru (Andreas Gruenbacher) [RHEL-32941]
- gfs2: Don't forget to complete delayed withdraw (Andreas Gruenbacher) [RHEL-32941]
- gfs2: Delay withdraw from atomic context (Andreas Gruenbacher) [RHEL-32941]
- gfs2: trivial clean up of gfs2_ail_error (Andreas Gruenbacher) [RHEL-32941]
- ext4: fix corruption during on-line resize (Carlos Maiolino) [RHEL-36974] {CVE-2024-35807}
- ext4: correct offset of gdb backup in non meta_bg group to update_backups (Carlos Maiolino) [RHEL-36974]
- ext4: avoid online resizing failures due to oversized flex bg (Carlos Maiolino) [RHEL-30507] {CVE-2023-52622}
- ext4: use time_is_before_jiffies() instead of open coding it (Carlos Maiolino) [RHEL-30507]
- ext4: unify the type of flexbg_size to unsigned int (Carlos Maiolino) [RHEL-30507]
- ext4: remove unnecessary check from alloc_flex_gd() (Carlos Maiolino) [RHEL-30507]
- tracing: Do no increment trace_clock_global() by one (Jerome Marchand) [RHEL-27107] {CVE-2021-46939}
- tracing: Restructure trace_clock_global() to never block (Jerome Marchand) [RHEL-27107] {CVE-2021-46939}
- net/sched: act_skbmod: prevent kernel-infoleak (Xin Long) [RHEL-37220] {CVE-2024-35893}
- tipc: Change nla_policy for bearer-related names to NLA_NUL_STRING (Xin Long) [RHEL-38307] {CVE-2023-52845}
- redhat: remove the merge subtrees script (Derek Barbosa)
- redhat: rhdocs: delete .get_maintainer.conf (Derek Barbosa)
- redhat: rhdocs: Remove the rhdocs directory (Derek Barbosa)
- dyndbg: fix old BUG_ON in >control parser (Waiman Long) [RHEL-37111] {CVE-2024-35947}
- dyndbg: let query-modname override actual module name (Waiman Long) [RHEL-37111]
- dyndbg: make dyndbg a known cli param (Waiman Long) [RHEL-37111]
- lan78xx: Fix exception on link speed change (Jamie Bainbridge) [RHEL-33437]
- net: usb: lan78xx: don't modify phy_device state concurrently (Jamie Bainbridge) [RHEL-33437]
- efi: runtime: Fix potential overflow of soft-reserved region size (Lenny Szubowicz) [RHEL-33096] {CVE-2024-26843}
- perf/arm-cmn: Fail DTC counter allocation correctly (Michael Petlan) [RHEL-23841]
- perf/arm-cmn: Rework DTC counters (again) (Michael Petlan) [RHEL-23841]
- perf/arm-cmn: Fix DTC domain detection (Michael Petlan) [RHEL-23841]
- perf/arm-cmn: Revamp model detection (Michael Petlan) [RHEL-23841]
- perf/arm-cmn: Fix port detection for CMN-700 (Michael Petlan) [RHEL-23841]
- perf/arm-cmn: Move overlapping wp_combine field (Michael Petlan) [RHEL-23841]
- Partially revert "perf/arm-cmn: Optimise DTC counter accesses" (Michael Petlan) [RHEL-23841]
- drivers/perf: Compile with gnu99 standard (Michael Petlan) [RHEL-23841]
- x86/fpu: Keep xfd_state in sync with MSR_IA32_XFD (Steve Best) [RHEL-36994] {CVE-2024-35801}
- watchdog: softdog: Add options 'soft_reboot_cmd' and 'soft_active_on_boot' (Waiman Long) [RHEL-19723]
- tipc: fix UAF in error path (Xin Long) [RHEL-34278] {CVE-2024-36886}

* Fri Jun 14 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.8.1.el8_10]
- udf: Fix NULL pointer dereference in udf_symlink function (Pavel Reichl) [RHEL-37769] {CVE-2021-47353}
- net: ti: fix UAF in tlan_remove_one (Jose Ignacio Tornos Martinez) [RHEL-38940] {CVE-2021-47310}
- ARM: footbridge: fix PCI interrupt mapping (Myron Stowe) [RHEL-26971] {CVE-2021-46909}
- i40e: Do not use WQ_MEM_RECLAIM flag for workqueue (Kamal Heib) [RHEL-37454] {CVE-2024-36004}
- net/mlx5e: Fix mlx5e_priv_init() cleanup flow (Kamal Heib) [RHEL-37424] {CVE-2024-35959}
- net/mlx5: Properly link new fs rules into the tree (Kamal Heib) [RHEL-37420] {CVE-2024-35960}
- net/mlx5e: fix a potential double-free in fs_any_create_groups (Kamal Heib) [RHEL-37091] {CVE-2023-52667}
- net: ena: Fix incorrect descriptor free behavior (Kamal Heib) [RHEL-37428] {CVE-2024-35958}
- mISDN: hfcpci: Fix use-after-free bug in hfcpci_softirq (Jose Ignacio Tornos Martinez) [RHEL-37763] {CVE-2021-47356}
- mISDN: fix possible use-after-free in HFC_cleanup() (Jose Ignacio Tornos Martinez) [RHEL-37763] {CVE-2021-47356}
- crypto: qat - Fix ADF_DEV_RESET_SYNC memory leak (Vladis Dronov) [RHEL-35106] {CVE-2024-26974}
- crypto: qat - implement dh fallback for primes > 4K (Vladis Dronov) [RHEL-35106]
- crypto: qat - avoid division by zero (Vladis Dronov) [RHEL-35106]
- crypto: qat - resolve race condition during AER recovery (Vladis Dronov) [RHEL-35106] {CVE-2024-26974}
- crypto: qat - use kcalloc_node() instead of kzalloc_node() (Vladis Dronov) [RHEL-35106]
- [rt] Enable CONFIG_DRM_MGAG200_DISABLE_WRITECOMBINE (Jocelyn Falempe) [RHEL-36172]
- drm/mgag200: Add an option to disable Write-Combine (Jocelyn Falempe) [RHEL-36172]
- drm/mgag200: Fix caching setup for remapped video memory (Jocelyn Falempe) [RHEL-36172]
- Revert "drm/mgag200: Add a workaround for low-latency" (Jocelyn Falempe) [RHEL-36172]
- mptcp: fix data re-injection from stale subflow (Davide Caratti) [RHEL-33133] {CVE-2024-26826}
- ipv6: sr: fix incorrect unregister order (Hangbin Liu) [RHEL-31730]
- ipv6: sr: fix possible use-after-free and null-ptr-deref (Hangbin Liu) [RHEL-31730] {CVE-2024-26735}
- net/bnx2x: Prevent access to a freed page in page_pool (Michal Schmidt) [RHEL-14195 RHEL-33243] {CVE-2024-26859}
- bnx2x: new flag for track HW resource allocation (Michal Schmidt) [RHEL-14195 RHEL-33243]
- bnx2x: fix page fault following EEH recovery (Michal Schmidt) [RHEL-14195 RHEL-33243]
- x86: KVM: SVM: always update the x2avic msr interception (Maxim Levitsky) [RHEL-15495] {CVE-2023-5090}
- EDAC/thunderx: Fix possible out-of-bounds string access (Aristeu Rozanski) [RHEL-26573] {CVE-2023-52464}

* Thu Jun 06 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.7.1.el8_10]
- net: qcom/emac: fix UAF in emac_remove (Ken Cox) [RHEL-37834] {CVE-2021-47311}
- perf/core: Bail out early if the request AUX area is out of bound (Michael Petlan) [RHEL-38268] {CVE-2023-52835}
- crypto: pcrypt - Fix hungtask for PADATA_RESET (Herbert Xu) [RHEL-38171] {CVE-2023-52813}
- drm/amdgpu: fix use-after-free bug (Jocelyn Falempe) [RHEL-31240] {CVE-2024-26656}
- mlxsw: spectrum_acl_tcam: Fix possible use-after-free during rehash (Ivan Vecera) [RHEL-37008] {CVE-2024-35854}
- mlxsw: spectrum_acl_tcam: Fix possible use-after-free during activity update (Ivan Vecera) [RHEL-37004] {CVE-2024-35855}
- mlxsw: spectrum_acl_tcam: Fix memory leak during rehash (Ivan Vecera) [RHEL-37012] {CVE-2024-35853}
- mlxsw: spectrum_acl_tcam: Fix memory leak when canceling rehash work (Ivan Vecera) [RHEL-37016] {CVE-2024-35852}
- mlxsw: spectrum_acl_tcam: Fix warning during rehash (Ivan Vecera) [RHEL-37480] {CVE-2024-36007}
- can: peak_pci: peak_pci_remove(): fix UAF (Jose Ignacio Tornos Martinez) [RHEL-38419] {CVE-2021-47456}
- usbnet: fix error return code in usbnet_probe() (Jose Ignacio Tornos Martinez) [RHEL-38440] {CVE-2021-47495}
- usbnet: sanity check for maxpacket (Jose Ignacio Tornos Martinez) [RHEL-38440] {CVE-2021-47495}
- net/mlx5e: fix a double-free in arfs_create_groups (Kamal Heib) [RHEL-36920] {CVE-2024-35835}
- can: dev: can_put_echo_skb(): don't crash kernel if can_priv::echo_skb is accessed out of bounds (Jose Ignacio Tornos Martinez) [RHEL-38220] {CVE-2023-52878}
- net: cdc_eem: fix tx fixup skb leak (Jose Ignacio Tornos Martinez) [RHEL-38080] {CVE-2021-47236}
- net/usb: kalmia: Don't pass act_len in usb_bulk_msg error path (Jose Ignacio Tornos Martinez) [RHEL-38113] {CVE-2023-52703}
- usb: typec: tcpm: Fix NULL pointer dereference in tcpm_pd_svdm() (Desnes Nunes) [RHEL-38248] {CVE-2023-52877}
- usb: config: fix iteration issue in 'usb_get_bos_descriptor()' (Desnes Nunes) [RHEL-38240] {CVE-2023-52781}
- gro: fix ownership transfer (Xin Long) [RHEL-37226] {CVE-2024-35890}
- tipc: fix kernel warning when sending SYN message (Xin Long) [RHEL-38109] {CVE-2023-52700}
- erspan: make sure erspan_base_hdr is present in skb->head (Xin Long) [RHEL-37230] {CVE-2024-35888}
- scsi: mpi3mr: Use proper format specifier in mpi3mr_sas_port_add() (Bryan Gurney) [RHEL-17366]
- scsi: mpi3mr: Sanitise num_phys (Bryan Gurney) [RHEL-17366]
- netfilter: nf_tables: use timestamp to check for set element timeout (Phil Sutter) [RHEL-38023] {CVE-2024-27397}
- net/ipv6: SKB symmetric hash should incorporate transport ports (Sabrina Dubroca) [RHEL-32061]
- crypto: s390/aes - Fix buffer overread in CTR mode (Herbert Xu) [RHEL-37089] {CVE-2023-52669}
- net: Save and restore msg_namelen in sock_sendmsg (Jamie Bainbridge) [RHEL-35893]
- net: prevent address rewrite in kernel_bind() (Jamie Bainbridge) [RHEL-35893]
- net: prevent rewrite of msg_name in sock_sendmsg() (Jamie Bainbridge) [RHEL-35893]
- net: replace calls to sock->ops->connect() with kernel_connect() (Jamie Bainbridge) [RHEL-35893]
- net: Avoid address overwrite in kernel_connect (Jamie Bainbridge) [RHEL-35893]
- wifi: iwlwifi: dbg-tlv: ensure NUL termination (Jose Ignacio Tornos Martinez) [RHEL-37026] {CVE-2024-35845}
- wifi: mac80211: fix potential sta-link leak (Jose Ignacio Tornos Martinez) [RHEL-36916] {CVE-2024-35838}
- wifi: nl80211: reject iftype change with mesh ID change (Jose Ignacio Tornos Martinez) [RHEL-36884] {CVE-2024-27410}
- wifi: mac80211: check/clear fast rx for non-4addr sta VLAN changes (Jose Ignacio Tornos Martinez) [RHEL-36807] {CVE-2024-35789}
- Bluetooth: Avoid potential use-after-free in hci_error_reset (David Marlin) [RHEL-31826] {CVE-2024-26801}
- tls: disable async encrypt/decrypt (Sabrina Dubroca) [RHEL-26362 RHEL-26409 RHEL-26420] {CVE-2024-26584 CVE-2024-26583 CVE-2024-26585}
- Squashfs: check the inode number is not the invalid value of zero (Phillip Lougher) [RHEL-35096] {CVE-2024-26982}
- ipc/mqueue, msg, sem: avoid relying on a stack reference past its expiry (Rafael Aquini) [RHEL-27782] {CVE-2021-47069}
- ipc/msg.c: update and document memory barriers (Rafael Aquini) [RHEL-27782] {CVE-2021-47069}
- ipc/sem.c: document and update memory barriers (Rafael Aquini) [RHEL-27782] {CVE-2021-47069}
- ipc/mqueue.c: update/document memory barriers (Rafael Aquini) [RHEL-27782] {CVE-2021-47069}
- ipc/mqueue.c: remove duplicated code (Rafael Aquini) [RHEL-27782] {CVE-2021-47069}
- net/mlx5e: Fix operation precedence bug in port timestamping napi_poll context (Kamal Heib) [RHEL-30582] {CVE-2023-52626}
- Revert "ACPI: bus: Rework system-level device notification handling" (Prarit Bhargava) [RHEL-21486]
- hwrng: core - Fix page fault dead lock on mmap-ed hwrng (Prarit Bhargava) [RHEL-29485] {CVE-2023-52615}

* Wed May 29 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.6.1.el8_10]
- powerpc/powernv: Add a null pointer check in opal_event_init() (Mamatha Inamdar) [RHEL-37058] {CVE-2023-52686}
- crypto: rsa - add a check for allocation failure (Vladis Dronov) [RHEL-35361]
- crypto: rsa - allow only odd e and restrict value in FIPS mode (Vladis Dronov) [RHEL-35361]
- KEYS: use kfree_sensitive with key (Vladis Dronov) [RHEL-35361]
- lib/mpi: Extend the MPI library (only mpi_*_bit() part) (Vladis Dronov) [RHEL-35361]
- net: ip_tunnel: prevent perpetual headroom growth (Felix Maurer) [RHEL-31814] {CVE-2024-26804}
- s390/cpum_cf: make crypto counters upward compatible across machine types (Tobias Huschle) [RHEL-36048]
- RDMA/mlx5: Fix fortify source warning while accessing Eth segment (Kamal Heib) [RHEL-33162] {CVE-2024-26907}
- ovl: fix leaked dentry (Miklos Szeredi) [RHEL-27306] {CVE-2021-46972}
- x86/mm: Disallow vsyscall page read for copy_from_kernel_nofault() (Rafael Aquini) [RHEL-33166] {CVE-2024-26906}
- x86/mm: Move is_vsyscall_vaddr() into asm/vsyscall.h (Rafael Aquini) [RHEL-33166] {CVE-2024-26906}
- x86/mm/vsyscall: Consider vsyscall page part of user address space (Rafael Aquini) [RHEL-33166] {CVE-2024-26906}
- x86/mm: Add vsyscall address helper (Rafael Aquini) [RHEL-33166] {CVE-2024-26906}
- mm/swap: fix race when skipping swapcache (Rafael Aquini) [RHEL-31644] {CVE-2024-26759}
- swap: fix do_swap_page() race with swapoff (Rafael Aquini) [RHEL-31644] {CVE-2024-26759}
- mm/swapfile: use percpu_ref to serialize against concurrent swapoff (Rafael Aquini) [RHEL-31644] {CVE-2024-26759}
- mm/damon/vaddr-test: fix memory leak in damon_do_test_apply_three_regions() (Rafael Aquini) [RHEL-29294] {CVE-2023-52560}
- ipv6: fix race condition between ipv6_get_ifaddr and ipv6_del_addr (Jiri Benc) [RHEL-29783]
- block: null_blk: Fix handling of fake timeout request (Ming Lei) [RHEL-8130]
- null_blk: fix poll request timeout handling (Ming Lei) [RHEL-8130]
- block: null_blk: end timed out poll request (Ming Lei) [RHEL-8130]
- block: null_blk: only set set->nr_maps as 3 if active poll_queues is > 0 (Ming Lei) [RHEL-8130]
- null_blk: allow zero poll queues (Ming Lei) [RHEL-8130]
- null_blk: Fix handling of submit_queues and poll_queues attributes (Ming Lei) [RHEL-8130]
- null_blk: poll queue support (Ming Lei) [RHEL-8130]
- null_blk: fix command timeout completion handling (Ming Lei) [RHEL-8130]
- platform/x86: dell-smbios-wmi: Fix oops on rmmod dell_smbios (Prarit Bhargava) [RHEL-27790] {CVE-2021-47073}
- Bluetooth: avoid memcmp() out of bounds warning (David Marlin) [RHEL-3017] {CVE-2020-26555}
- Bluetooth: hci_event: Fix coding style (David Marlin) [RHEL-3017] {CVE-2020-26555}
- Bluetooth: hci_event: Fix using memcmp when comparing keys (David Marlin) [RHEL-3017] {CVE-2020-26555}
- Bluetooth: Reject connection with the device which has same BD_ADDR (David Marlin) [RHEL-3017] {CVE-2020-26555}
- Bluetooth: hci_event: Ignore NULL link key (David Marlin) [RHEL-3017] {CVE-2020-26555}
- ppp_async: limit MRU to 64K (Guillaume Nault) [RHEL-31353] {CVE-2024-26675}
- powerpc/imc-pmu: Add a null pointer check in update_events_in_group() (Mamatha Inamdar) [RHEL-37078] {CVE-2023-52675}
- tcp: do not accept ACK of bytes we never sent (Xin Long) [RHEL-21952]

* Mon May 20 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.5.1.el8_10]
- tools/power/turbostat: Fix uncore frequency file string (David Arcari) [RHEL-29238]
- tools/power turbostat: Expand probe_intel_uncore_frequency() (David Arcari) [RHEL-29238]
- uio: Fix use-after-free in uio_open (Ricardo Robaina) [RHEL-26232] {CVE-2023-52439}
- net:emac/emac-mac: Fix a use after free in emac_mac_tx_buf_send (Ken Cox) [RHEL-27316] {CVE-2021-47013}
- keys: Fix linking a duplicate key to a keyring's assoc_array (David Howells) [RHEL-30772]
- keys: Hoist locking out of __key_link_begin() (David Howells) [RHEL-30772]
- keys: Break bits out of key_unlink() (David Howells) [RHEL-30772]
- keys: Change keyring_serialise_link_sem to a mutex (David Howells) [RHEL-30772]
- wifi: brcm80211: handle pmk_op allocation failure (Jose Ignacio Tornos Martinez) [RHEL-35150] {CVE-2024-27048}
- wifi: rtl8xxxu: add cancel_work_sync() for c2hcmd_work (Jose Ignacio Tornos Martinez) [RHEL-35140] {CVE-2024-27052}
- wifi: iwlwifi: mvm: ensure offloading TID queue exists (Jose Ignacio Tornos Martinez) [RHEL-35130] {CVE-2024-27056}
- wifi: mt76: mt7921e: fix use-after-free in free_irq() (Jose Ignacio Tornos Martinez) [RHEL-34866] {CVE-2024-26892}
- wifi: ath9k: delay all of ath9k_wmi_event_tasklet() until init is complete (Jose Ignacio Tornos Martinez) [RHEL-34189] {CVE-2024-26897}
- wifi: iwlwifi: mvm: fix a crash when we run out of stations (Jose Ignacio Tornos Martinez) [RHEL-31547] {CVE-2024-26693}
- wifi: iwlwifi: fix double-free bug (Jose Ignacio Tornos Martinez) [RHEL-31543] {CVE-2024-26694}
- wifi: ath9k: Fix potential array-index-out-of-bounds read in ath9k_htc_txstatus() (Jose Ignacio Tornos Martinez) [RHEL-29089] {CVE-2023-52594}
- wifi: rt2x00: restart beacon queue when hardware reset (Jose Ignacio Tornos Martinez) [RHEL-29093] {CVE-2023-52595}
- wifi: iwlwifi: fix a memory corruption (Jose Ignacio Tornos Martinez) [RHEL-28903] {CVE-2024-26610}

* Wed May 15 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-553.4.1.el8_10]
- cpuhotplug: Fix kABI breakage caused by CPUHP_AP_HYPERV_ONLINE (Vitaly Kuznetsov) [RHEL-36117]
- net/mlx5e: Prevent deadlock while disabling aRFS (Kamal Heib) [RHEL-35041] {CVE-2024-27014}
- x86/tsc: Defer marking TSC unstable to a worker (Wander Lairson Costa) [RHEL-32676]
- x86/smpboot: Make TSC synchronization function call based (Wander Lairson Costa) [RHEL-32676]
- net: usb: fix possible use-after-free in smsc75xx_bind (Jose Ignacio Tornos Martinez) [RHEL-30311] {CVE-2021-47171}
- net: usb: fix memory leak in smsc75xx_bind (Jose Ignacio Tornos Martinez) [RHEL-30311] {CVE-2021-47171}

* Sat May 11 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-552.3.1.el8_10]
- netfilter: nf_tables: mark set as dead when unbinding anonymous set with timeout (Phil Sutter) [RHEL-30076] {CVE-2024-26643}
- netfilter: nf_tables: disallow anonymous set with timeout flag (Phil Sutter) [RHEL-30080] {CVE-2024-26642}
- selftests/bpf: Fix pyperf180 compilation failure with clang18 (Artem Savkov) [RHEL-35576]
- md/raid5: fix atomicity violation in raid5_cache_count (Nigel Croxon) [RHEL-27930] {CVE-2024-23307}
- usb: ulpi: Fix debugfs directory leak (Desnes Nunes) [RHEL-33287] {CVE-2024-26919}
- powerpc/pseries: Fix potential memleak in papr_get_attr() (Mamatha Inamdar) [RHEL-35213] {CVE-2022-48669}
- USB: usb-storage: Prevent divide-by-0 error in isd200_ata_command (Desnes Nunes) [RHEL-35122] {CVE-2024-27059}
- NFSv4: fairly test all delegations on a SEQ4_ revocation (Benjamin Coddington) [RHEL-34912]
- USB: core: Fix deadlock in usb_deauthorize_interface() (Desnes Nunes) [RHEL-35002] {CVE-2024-26934}
- usb: xhci: Add error handling in xhci_map_urb_for_dma (Desnes Nunes) [RHEL-34958] {CVE-2024-26964}
- fs: sysfs: Fix reference leak in sysfs_break_active_protection() (Ewan D. Milne) [RHEL-35076] {CVE-2024-26993}
- xhci: handle isoc Babble and Buffer Overrun events properly (Desnes Nunes) [RHEL-31297] {CVE-2024-26659}
- xhci: process isoc TD properly when there was a transaction error mid TD. (Desnes Nunes) [RHEL-31297] {CVE-2024-26659}
- USB: core: Fix deadlock in port "disable" sysfs attribute (Desnes Nunes) [RHEL-35006] {CVE-2024-26933}
- USB: core: Add hub_get() and hub_put() routines (Desnes Nunes) [RHEL-35006] {CVE-2024-26933}
- netfilter: ipset: Missing gc cancellations fixed (Phil Sutter) [RHEL-30521]
- netfilter: ipset: fix performance regression in swap operation (Phil Sutter) [RHEL-30521]
- netfilter: ipset: Fix "INFO: rcu detected stall in hash_xxx" reports (Phil Sutter) [RHEL-30521]
- netfilter: ipset: fix race condition between swap/destroy and kernel side add/del/test (Phil Sutter) [RHEL-30521]
- x86/apic/x2apic: Fix a NULL pointer deref when handling a dying cpu (David Arcari) [RHEL-32516]
- x86/coco: Disable 32-bit emulation by default on TDX and SEV (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}
- x86: Make IA32_EMULATION boot time configurable (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}
- x86/entry: Make IA32 syscalls' availability depend on ia32_enabled() (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}
- x86/elf: Make loading of 32bit processes depend on ia32_enabled() (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}
- x86/entry: Rename ignore_sysret() (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}
- x86/cpu: Don't write CSTAR MSR on Intel CPUs (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}
- x86: Introduce ia32_enabled() (Vitaly Kuznetsov) [RHEL-25087] {CVE-2024-25744}

* Mon May 06 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-552.2.1.el8_10]
- s390/ptrace: handle setting of fpc register correctly (Tobias Huschle) [RHEL-29106] {CVE-2023-52598}
- net/smc: fix illegal rmb_desc access in SMC-D connection dump (Tobias Huschle) [RHEL-27746] {CVE-2024-26615}
- wifi: mac80211: fix race condition on enabling fast-xmit (Jose Ignacio Tornos Martinez) [RHEL-31664] {CVE-2024-26779}
- powerpc/fadump: make is_kdump_kernel() return false when fadump is active (Mamatha Inamdar) [RHEL-24401]
- vmcore: remove dependency with is_kdump_kernel() for exporting vmcore (Mamatha Inamdar) [RHEL-24401]
- mtd: require write permissions for locking and badblock ioctls (Prarit Bhargava) [RHEL-27585] {CVE-2021-47055}
- mtd: properly check all write ioctls for permissions (Prarit Bhargava) [RHEL-27585] {CVE-2021-47055}
- pid: take a reference when initializing `cad_pid` (Waiman Long) [RHEL-29420] {CVE-2021-47118}
- i2c: i801: Don't generate an interrupt on bus reset (Prarit Bhargava) [RHEL-30325] {CVE-2021-47153}
- RDMA/srpt: Do not register event handler until srpt device is fully setup (Kamal Heib) [RHEL-33224] {CVE-2024-26872}
- ceph: switch to corrected encoding of max_xattr_size in mdsmap (Xiubo Li) [RHEL-26723]
- ceph: switch to use cap_delay_lock for the unlink delay list (Xiubo Li) [RHEL-32870]
- ceph: pass ino# instead of old_dentry if it's disconnected (Xiubo Li) [RHEL-32870]
- fat: fix uninitialized field in nostale filehandles (Andrey Albershteyn) [RHEL-33186 RHEL-35108] {CVE-2024-26973}
- do_sys_name_to_handle(): use kzalloc() to fix kernel-infoleak (Andrey Albershteyn) [RHEL-33186] {CVE-2024-26901}
- idpf: limit the support to GCP only (Michal Schmidt) [RHEL-15652]
- redhat/configs: enable CONFIG_IDPF (Michal Schmidt) [RHEL-15652]
- idpf: remove the use of ETHTOOL_RING_USE_TCP_DATA_SPLIT (Michal Schmidt) [RHEL-15652]
- idpf: workaround for unavailable skb page recycling (Michal Schmidt) [RHEL-15652]
- idpf: always allocate a full page (Michal Schmidt) [RHEL-15652]
- idpf: remove page pool stats code (Michal Schmidt) [RHEL-15652]
- idpf: add minimal macros for __free(kfree) to work (Michal Schmidt) [RHEL-15652]
- idpf: fixup include paths for RHEL 8 (Michal Schmidt) [RHEL-15652]
- idpf: fix kernel panic on unknown packet types (Michal Schmidt) [RHEL-15652]
- idpf: disable local BH when scheduling napi for marker packets (Michal Schmidt) [RHEL-15652]
- idpf: remove dealloc vector msg err in idpf_intr_rel (Michal Schmidt) [RHEL-15652]
- idpf: fix minor controlq issues (Michal Schmidt) [RHEL-15652]
- idpf: prevent deinit uninitialized virtchnl core (Michal Schmidt) [RHEL-15652]
- idpf: cleanup virtchnl cruft (Michal Schmidt) [RHEL-15652]
- idpf: refactor idpf_recv_mb_msg (Michal Schmidt) [RHEL-15652]
- idpf: add async_handler for MAC filter messages (Michal Schmidt) [RHEL-15652]
- idpf: refactor remaining virtchnl messages (Michal Schmidt) [RHEL-15652]
- idpf: refactor queue related virtchnl messages (Michal Schmidt) [RHEL-15652]
- idpf: refactor vport virtchnl messages (Michal Schmidt) [RHEL-15652]
- idpf: implement virtchnl transaction manager (Michal Schmidt) [RHEL-15652]
- idpf: add idpf_virtchnl.h (Michal Schmidt) [RHEL-15652]
- idpf: avoid compiler padding in virtchnl2_ptype struct (Michal Schmidt) [RHEL-15652]
- idpf: distinguish vports by the dev_port attribute (Michal Schmidt) [RHEL-15652]
- idpf: avoid compiler introduced padding in virtchnl2_rss_key struct (Michal Schmidt) [RHEL-15652]
- idpf: fix corrupted frames and skb leaks in singleq mode (Michal Schmidt) [RHEL-15652]
- idpf: refactor some missing field get/prep conversions (Michal Schmidt) [RHEL-15652]
- idpf: add get/set for Ethtool's header split ringparam (Michal Schmidt) [RHEL-15652]
- idpf: fix potential use-after-free in idpf_tso() (Michal Schmidt) [RHEL-15652]
- idpf: cancel mailbox work in error path (Michal Schmidt) [RHEL-15652]
- idpf: set scheduling mode for completion queue (Michal Schmidt) [RHEL-15652]
- idpf: add SRIOV support and other ndo_ops (Michal Schmidt) [RHEL-15652]
- idpf: add ethtool callbacks (Michal Schmidt) [RHEL-15652]
- idpf: add singleq start_xmit and napi poll (Michal Schmidt) [RHEL-15652]
- idpf: add RX splitq napi poll support (Michal Schmidt) [RHEL-15652]
- idpf: add TX splitq napi poll support (Michal Schmidt) [RHEL-15652]
- idpf: add splitq start_xmit (Michal Schmidt) [RHEL-15652]
- idpf: initialize interrupts and enable vport (Michal Schmidt) [RHEL-15652]
- idpf: configure resources for RX queues (Michal Schmidt) [RHEL-15652]
- idpf: configure resources for TX queues (Michal Schmidt) [RHEL-15652]
- idpf: add ptypes and MAC filter support (Michal Schmidt) [RHEL-15652]
- idpf: add create vport and netdev configuration (Michal Schmidt) [RHEL-15652]
- idpf: add core init and interrupt request (Michal Schmidt) [RHEL-15652]
- idpf: add controlq init and reset checks (Michal Schmidt) [RHEL-15652]
- idpf: add module register and probe functionality (Michal Schmidt) [RHEL-15652]
- virtchnl: add virtchnl version 2 ops (Michal Schmidt) [RHEL-15652]
- net: netdev_queue: netdev_txq_completed_mb(): fix wake condition (Michal Schmidt) [RHEL-15652]
- net: piggy back on the memory barrier in bql when waking queues (Michal Schmidt) [RHEL-15652]
- net: provide macros for commonly copied lockless queue stop/wake code (Michal Schmidt) [RHEL-15652]

* Fri Apr 26 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-552.1.1.el8_10]
- redhat: set DIST to el8_10 and ZSTREAM to yes for 8.10 (Denys Vlasenko)
- tty: tty_buffer: Fix the softlockup issue in flush_to_ldisc (Prarit Bhargava) [RHEL-32590] {CVE-2021-47185}
- net: mana: Fix Rx DMA datasize and skb_over_panic (Cathy Avery) [RHEL-32579]
- RDMA/srpt: Support specifying the srpt_service_guid parameter (Kamal Heib) [RHEL-31710] {CVE-2024-26744}
- RDMA/qedr: Fix qedr_create_user_qp error flow (Kamal Heib) [RHEL-31714] {CVE-2024-26743}
- hwmon: (coretemp) Fix out-of-bounds memory access (David Arcari) [RHEL-31305] {CVE-2024-26664}
- RDMA/irdma: Fix KASAN issue with tasklet (Kamal Heib) [RHEL-15776]
- net: bridge: use DEV_STATS_INC() (Ivan Vecera) [RHEL-27989] {CVE-2023-52578}
- net: Fix unwanted sign extension in netdev_stats_to_stats64() (Ivan Vecera) [RHEL-27989] {CVE-2023-52578}
- net: add atomic_long_t to net_device_stats fields (Ivan Vecera) [RHEL-27989] {CVE-2023-52578}
- net/sched: act_ct: fix skb leak and crash on ooo frags (Xin Long) [RHEL-29467] {CVE-2023-52610}
- net: usb: smsc75xx: Fix uninit-value access in __smsc75xx_read_reg (Jose Ignacio Tornos Martinez) [RHEL-28015] {CVE-2023-52528}
- RDMA/core: Fix uninit-value access in ib_get_eth_speed() (Kamal Heib) [RHEL-30130]
- RDMA/core: Get IB width and speed from netdev (Kamal Heib) [RHEL-30130]
- cpufreq: intel_pstate: Add Emerald Rapids support in no-HWP mode (Prarit Bhargava) [RHEL-29444]
- powerpc/mm: Fix null-pointer dereference in pgtable_cache_add (Mamatha Inamdar) [RHEL-29118] {CVE-2023-52607}
- powerpc/lib: Validate size for vector operations (Mamatha Inamdar) [RHEL-29114] {CVE-2023-52606}
- usb: hub: Guard against accesses to uninitialized BOS descriptors (Desnes Nunes) [RHEL-28986] {CVE-2023-52477}
- media: uvcvideo: Fix OOB read (Desnes Nunes) [RHEL-27940] {CVE-2023-52565}
- media: pvrusb2: fix use after free on context disconnection (Desnes Nunes) [RHEL-26498] {CVE-2023-52445}
- i2c: i801: Fix block process call transactions (Prarit Bhargava) [RHEL-26478] {CVE-2024-26593}
- overlay: disable EVM (Coiby Xu) [RHEL-19863]
- evm: add support to disable EVM on unsupported filesystems (Coiby Xu) [RHEL-19863]
- evm: don't copy up 'security.evm' xattr (Coiby Xu) [RHEL-19863]
- net: ena: Remove ena_select_queue (Kamal Heib) [RHEL-14286]
- media: dvbdev: Fix memory leak in dvb_media_device_free() (Prarit Bhargava) [RHEL-27254] {CVE-2020-36777}
- gfs2: Fix invalid metadata access in punch_hole (Andrew Price) [RHEL-28784]
- i2c: Fix a potential use after free (Prarit Bhargava) [RHEL-26849] {CVE-2019-25162}
- i2c: validate user data in compat ioctl (Prarit Bhargava) [RHEL-27022] {CVE-2021-46934}
- platform/x86: think-lmi: Fix reference leak (Prarit Bhargava) [RHEL-28030] {CVE-2023-52520}
- vhost: use kzalloc() instead of kmalloc() followed by memset() (Jon Maloy) [RHEL-21505] {CVE-2024-0340}
- RDMA/siw: Fix connection failure handling (Kamal Heib) [RHEL-28042] {CVE-2023-52513}
- vt: fix memory overlapping when deleting chars in the buffer (Waiman Long) [RHEL-27778 RHEL-27779] {CVE-2022-48627}
- x86/fpu: Stop relying on userspace for info to fault in xsave buffer (Steve Best) [RHEL-26669] {CVE-2024-26603}
- mptcp: fix double-free on socket dismantle (Davide Caratti) [RHEL-22773] {CVE-2024-26782}
- crypto: akcipher - Disable signing and decryption (Herbert Xu) [RHEL-17114] {CVE-2023-6240}
- crypto: akcipher - default implementations for request callbacks (Herbert Xu) [RHEL-17114] {CVE-2023-6240}
- crypto: testmgr - split akcipher tests by a key type (Herbert Xu) [RHEL-17114] {CVE-2023-6240}
- workqueue: Warn when a rescuer could not be created (Waiman Long) [RHEL-22136]
- RDMA/cma: Avoid GID lookups on iWARP devices (Benjamin Coddington) [RHEL-12456]
- RDMA/cma: Deduplicate error flow in cma_validate_port() (Benjamin Coddington) [RHEL-12456]
- RDMA/core: Set gid_attr.ndev for iWARP devices (Benjamin Coddington) [RHEL-12456]
- RDMA/siw: Fabricate a GID on tun and loopback devices (Benjamin Coddington) [RHEL-12456]

* Sun Apr 07 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-552.el8]
- i40e: Enforce software interrupt during busy-poll exit (Ivan Vecera) [RHEL-26248]
- i40e: Remove _t suffix from enum type names (Ivan Vecera) [RHEL-26248]

* Fri Apr 05 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-551.el8]
- x86/sev: Harden #VC instruction emulation somewhat (Vitaly Kuznetsov) [RHEL-30040] {CVE-2024-25743 CVE-2024-25742}
- i40e: Fix VF MAC filter removal (Ivan Vecera) [RHEL-22992]
- i40e: Do not allow untrusted VF to remove administratively set MAC (Ivan Vecera) [RHEL-22992]

* Sun Mar 31 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-550.el8]
- mm/sparsemem: fix race in accessing memory_section->usage (Waiman Long) [RHEL-28875 RHEL-28876] {CVE-2023-52489}
- mm: use __pfn_to_section() instead of open coding it (Waiman Long) [RHEL-28875] {CVE-2023-52489}

* Thu Mar 28 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-549.el8]
- dm-integrity: align the outgoing bio in integrity_recheck (Benjamin Marzinski) [RHEL-29678]
- dm-integrity: fix a memory leak when rechecking the data (Benjamin Marzinski) [RHEL-29678]
- RDMA/mana_ib: Add CQ interrupt support for RAW QP (Maxim Levitsky) [RHEL-23934]
- RDMA/mana_ib: query device capabilities (Maxim Levitsky) [RHEL-23934]
- RDMA/mana_ib: register RDMA device with GDMA (Maxim Levitsky) [RHEL-23934]
- net: mana: add msix index sharing between EQs (Maxim Levitsky) [RHEL-23934]
- net: mana: Fix spelling mistake "enforecement" -> "enforcement" (Maxim Levitsky) [RHEL-23934]
- net :mana :Add remaining GDMA stats for MANA to ethtool (Maxim Levitsky) [RHEL-23934]
- net: mana: Fix oversized sge0 for GSO packets (Maxim Levitsky) [RHEL-23934]
- net: mana: Fix TX CQE error handling (Maxim Levitsky) [RHEL-23934]
- net: mana: Add gdma stats to ethtool output for mana (Maxim Levitsky) [RHEL-23934]
- net: mana: Fix MANA VF unload when hardware is unresponsive (Maxim Levitsky) [RHEL-23934]
- net: mana: Configure hwc timeout from hardware (Maxim Levitsky) [RHEL-23934]
- RDMA/mana_ib: Use v2 version of cfg_rx_steer_req to enable RX coalescing (Maxim Levitsky) [RHEL-23934]

* Sun Mar 24 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-548.el8]
- gitlab-ci: enable arm64/s390x/ppc64le debug builds (Michael Hofmann)
- arm64: Add missing bits of AmpereOne Spectre-BHB mitigation (Mark Salter) [RHEL-29005]
- [rt] enable CONFIG_DRM_MGAG200_IOBURST_WORKAROUND (Jocelyn Falempe) [RHEL-13214]
- drm/mgag200: Add a workaround for low-latency (Jocelyn Falempe) [RHEL-13214]

* Tue Mar 19 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-547.el8]
- x86/efistub: Avoid placing the kernel below LOAD_PHYSICAL_ADDR (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Give up if memory attribute protocol returns an error (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Increase section and file alignment to 4k/512 (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Split off PE/COFF .data section (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Drop PE/COFF .reloc section (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Construct PE/COFF .text section from assembler (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Derive file size from _edata symbol (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed: Remove, discard, or assert for unwanted sections (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Check that there are no run-time relocations (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Discard .discard.unreachable for arch/x86/boot/compressed/vmlinux (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Define setup size in linker script (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Set EFI handover offset directly in header asm (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Drop references to startup_64 (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Drop redundant code setting the root device (Lenny Szubowicz) [RHEL-2505]
- x86/build: Declutter the build output (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Omit compression buffer from PE/COFF image memory footprint (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Mark global variables as static (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Remove extra headroom for setup block (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Remove the 'bugger off' message (Lenny Szubowicz) [RHEL-2505]
- x86/efi: Drop alignment flags from PE section headers (Lenny Szubowicz) [RHEL-2505]
- efi: Put Linux specific magic number in the DOS header (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Fix the missing KASLR_FLAG bit in boot_params->hdr.loadflags (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Avoid physical KASLR on older Dell systems (Lenny Szubowicz) [RHEL-2505]
- x86/boot: efistub: Assign global boot_params variable (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Rename conflicting 'boot_params' pointer to 'boot_params_ptr' (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Avoid legacy decompressor when doing EFI boot (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Perform SNP feature test while running in the firmware (Lenny Szubowicz) [RHEL-2505]
- x86/sev: Do not try to parse for the CC blob on non-AMD hardware (Lenny Szubowicz) [RHEL-2505]
- efi/libstub: Add limit argument to efi_random_alloc() (Lenny Szubowicz) [RHEL-2505]
- arm64: efi: Limit allocations to 48-bit addressable physical region (Lenny Szubowicz) [RHEL-2505]
- efi: libstub: use EFI_LOADER_CODE region when moving the kernel in memory (Lenny Szubowicz) [RHEL-2505]
- arm64: efi: kaslr: Fix occasional random alloc (and boot) failure (Lenny Szubowicz) [RHEL-2505]
- efi/libstub/random: Increase random alloc granularity (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Factor out kernel decompression and relocation (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Move global symbol references to C code (Lenny Szubowicz) [RHEL-2505]
- decompress: Use 8 byte alignment (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Prefer EFI memory attributes protocol over DXE services (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Perform 4/5 level paging switch from the stub (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Merge trampoline cleanup with switching code (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Pass pgtable address to trampoline directly (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Only call the trampoline when changing paging levels (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Call trampoline directly from C code (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Avoid the need for a stack in the 32-bit trampoline (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Use standard calling convention for trampoline (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Call trampoline as a normal function (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed/64: Remove .bss/.pgtable from bzImage (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Remove run-time relocations from .head.text code (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Assign paging related global variables earlier (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Store boot_params pointer in callee save register (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Clear BSS in EFI handover protocol entrypoint (Lenny Szubowicz) [RHEL-2505]
- x86/head_64: Store boot_params pointer in callee save register (Lenny Szubowicz) [RHEL-2505]
- x86/decompressor: Don't rely on upper 32 bits of GPRs being preserved (Lenny Szubowicz) [RHEL-2505]
- x86/head/64: Switch to KERNEL_CS as soon as new GDT is installed (Lenny Szubowicz) [RHEL-2505]
- efi/libstub: Add memory attribute protocol definitions (Lenny Szubowicz) [RHEL-2505]
- efi/x86: libstub: remove unused variable (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Robustify calling startup_{32,64}() from the decompressor code (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Simplify and clean up handover entry code (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Branch straight to kernel entry point from C code (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Avoid using code32_start (Lenny Szubowicz) [RHEL-2505]
- efi/libstub/x86: Use Exit() boot service to exit the stub on errors (Lenny Szubowicz) [RHEL-2505]
- efi: x86: Wipe setup_data on pure EFI boot (Lenny Szubowicz) [RHEL-2505]
- efi: x86: Fix config name for setting the NX-compatibility flag in the PE header (Lenny Szubowicz) [RHEL-2505]
- efi: x86: Set the NX-compatibility flag in the PE header (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Add kernel preferred address to PE header (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Use symbolic constants in PE header instead of bare numbers (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Drop redundant .bss section (Lenny Szubowicz) [RHEL-2505]
- efi/x86: add headroom to decompressor BSS to account for setup block (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Remove run-time relocations from head_{32,64}.S (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed: Fix debug_puthex() parameter type (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed/64: Use 32-bit (zero-extended) MOV for z_output_len (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Use unsigned comparison for addresses (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Micro-optimize GDT loading instructions (Lenny Szubowicz) [RHEL-2505]
- x86/boot: GDT limit value should be size - 1 (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Remove GDT setup from efi_main (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Clear direction and interrupt flags in startup_64 (Lenny Szubowicz) [RHEL-2505]
- efi/x86: Don't depend on firmware GDT layout (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Remove KEEP_SEGMENTS support (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Handle malformed SRAT tables during early ACPI parsing (Lenny Szubowicz) [RHEL-2505]
- efi/libstub/x86: Use mandatory 16-byte stack alignment in mixed mode (Lenny Szubowicz) [RHEL-2505]
- efi/libstub/x86: Avoid globals to store context during mixed mode calls (Lenny Szubowicz) [RHEL-2505]
- x86/efistub: Disable paging at mixed mode entry (Lenny Szubowicz) [RHEL-2505]
- x86: efi/random: Invoke EFI_RNG_PROTOCOL to seed the UEFI RNG table (Lenny Szubowicz) [RHEL-2505]
- x86/asm: Make some functions local (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Annotate data appropriately (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Annotate local functions (Lenny Szubowicz) [RHEL-2505]
- x86/asm: Make more symbols local (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed/64: Fix missing initialization in find_trampoline_placement() (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed/64: Fix boot on machines with broken E820 table (Lenny Szubowicz) [RHEL-2505]
- x86, boot: Remove multiple copy of static function sanitize_boot_params() (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed/64: Remove unused variable (Lenny Szubowicz) [RHEL-2505]
- x86/boot/compressed/64: Explain paging_prepare()'s return value (Lenny Szubowicz) [RHEL-2505]
- x86/boot: Save several bytes in decompressor (Lenny Szubowicz) [RHEL-2505]
- fs,hugetlb: fix NULL pointer dereference in hugetlbs_fill_super (Audra Mitchell) [RHEL-20614] {CVE-2024-0841}
- net/gve: update check for little-endianness in gve kconfig (Joshua Washington) [RHEL-29030]

* Fri Mar 15 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-546.el8]
- sched/membarrier: reduce the ability to hammer on sys_membarrier (Wander Lairson Costa) [RHEL-23430] {CVE-2024-26602}
- NFS: Set the stable writes flag when initialising the super block (Benjamin Coddington) [RHEL-25266]
- smb: client: fix OOB in receive_encrypted_standard() (Scott Mayhew) [RHEL-21685] {CVE-2024-0565}
- scsi: core: Move scsi_host_busy() out of host lock if it is for per-command (Ming Lei) [RHEL-23942]
- scsi: core: Move scsi_host_busy() out of host lock for waking up EH handler (Ming Lei) [RHEL-23942]
- gfs2: Fix kernel NULL pointer dereference in gfs2_rgrp_dump (Andrew Price) [RHEL-26501] {CVE-2023-52448}
- smb: client: fix parsing of SMB3.1.1 POSIX create context (Paulo Alcantara) [RHEL-26241] {CVE-2023-52434}
- smb: client: fix potential OOBs in smb2_parse_contexts() (Paulo Alcantara) [RHEL-26241] {CVE-2023-52434}
- smb3: Replace smb2pdu 1-element arrays with flex-arrays (Jay Shin) [RHEL-22143]
- cifs: Replace remaining 1-element arrays (Jay Shin) [RHEL-22143]
- cifs: Convert struct fealist away from 1-element array (Jay Shin) [RHEL-22143]
- cifs: remove unneeded 2bytes of padding from smb2 tree connect (Jay Shin) [RHEL-22143]
- cifs: Replace zero-length arrays with flexible-array members (Jay Shin) [RHEL-22143]
- cifs: Replace a couple of one-element arrays with flexible-array members (Jay Shin) [RHEL-22143]
- cifs: fix FILE_BOTH_DIRECTORY_INFO definition (Jay Shin) [RHEL-22143]
- nfsd: use locks_inode_context helper (Jeffrey Layton) [RHEL-27441]
- nfs: use locks_inode_context helper (Jeffrey Layton) [RHEL-27441]
- lockd: use locks_inode_context helper (Jeffrey Layton) [RHEL-27441]
- cifs: use locks_inode_context helper (Jeffrey Layton) [RHEL-27441]
- ceph: use locks_inode_context helper (Jeffrey Layton) [RHEL-27441]
- filelock: add a new locks_inode_context accessor function (Jeffrey Layton) [RHEL-27441]
- dm-integrity, dm-verity: reduce stack usage for recheck (Benjamin Marzinski) [RHEL-27849]
- dm-crypt: recheck the integrity tag after a failure (Benjamin Marzinski) [RHEL-27849]
- dm-crypt: don't modify the data when using authenticated encryption (Benjamin Marzinski) [RHEL-27849]
- dm-verity: recheck the hash after a failure (Benjamin Marzinski) [RHEL-27849]
- dm-integrity: recheck the integrity tag after a failure (Benjamin Marzinski) [RHEL-27849]

* Wed Mar 13 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-545.el8]
- tracing/timerlat: Move hrtimer_init to timerlat_fd open() (John Kacur) [RHEL-26667]
- tracing/perf: Fix double put of trace event when init fails (Michael Petlan) [RHEL-19537]
- ipvlan: Add handling of NETDEV_UP events (Hangbin Liu) [RHEL-19098]
- ceph: add ceph_cap_unlink_work to fire check_caps() immediately (Xiubo Li) [RHEL-21760]
- ceph: always queue a writeback when revoking the Fb caps (Xiubo Li) [RHEL-21760]
- ceph: always check dir caps asynchronously (Xiubo Li) [RHEL-21760]
- nfs: fix redundant readdir request after get eof (Benjamin Coddington) [RHEL-7780]
- NFSv4.1: fixup use EXCHGID4_FLAG_USE_PNFS_DS for DS server (Scott Mayhew) [RHEL-7994]
- NFSv4.1: fix pnfs MDS=DS session trunking (Scott Mayhew) [RHEL-7994]
- NFSv4.1: fix zero value filehandle in post open getattr (Scott Mayhew) [RHEL-7994]
- NFSv4.1: use EXCHGID4_FLAG_USE_PNFS_DS for DS server (Scott Mayhew) [RHEL-7994]

* Thu Feb 22 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-544.el8]
- ext4: fix kernel BUG in 'ext4_write_inline_data_end()' (Carlos Maiolino) [RHEL-23386] {CVE-2021-33631}
- i2c: designware: Disable TX_EMPTY irq while waiting for block length byte (Charles Mirabile) [RHEL-24019]
- scsi: smartpqi: Fix disable_managed_interrupts (Tomas Henzl) [RHEL-25747]
- hwmon: (k10temp) Check range scale when CUR_TEMP register is read-write (Steve Best) [RHEL-26167]
- gitlab-ci: do not show (results can be ignored) for rt pipelines (Michael Hofmann)

* Wed Feb 21 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-543.el8]
- perf symbols: Symbol lookup with kcore can fail if multiple segments match stext (Charles Mirabile) [RHEL-23760]
- perf/arm-cmn: Move overlapping wp_combine field (Charles Mirabile) [RHEL-23757]
- drm/amd: Fix detection of _PR3 on the PCIe root port (Michel Dänzer) [RHEL-14572]
- xfs: avoid AGI->AGF->inode-buffer deadlocks (Thiago Becker) [RHEL-7914]
- dm-crypt, dm-verity: disable tasklets (Benjamin Marzinski) [RHEL-22232]
- dm verity: initialize fec io before freeing it (Benjamin Marzinski) [RHEL-22232]
- dm-verity: don't use blocking calls from tasklets (Benjamin Marzinski) [RHEL-22232]
- char: misc: Increase the maximum number of dynamic misc devices to 1048448 (Charles Mirabile) [RHEL-23758]
- char: misc: remove usage of list iterator past the loop body (Charles Mirabile) [RHEL-23758]
- char: misc: increase DYNAMIC_MINORS value (Charles Mirabile) [RHEL-23758]
- char: misc: Move EXPORT_SYMBOL immediately next to the functions/varibles (Charles Mirabile) [RHEL-23758]
- clocksource/drivers/arm_arch_timer: Force inlining of erratum_set_next_event_generic() (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Fix handling of ARM erratum 858921 (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Remove arch_timer_rate1 (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Fix CNTPCT_LO and CNTVCT_LO value (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Disable timer before programming CVAL (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Fix XGene-1 TVAL register math error (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: limit XGene-1 workaround (Mark Salter) [RHEL-19605]
- clocksource/drivers/arch_arm_timer: Move workaround synchronisation around (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Fix masking for high freq counters (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Drop unnecessary ISB on CVAL programming (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Remove any trace of the TVAL programming interface (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Work around broken CVAL implementations (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Advertise 56bit timer to the core code (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Move MMIO timer programming over to CVAL (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Fix MMIO base address vs callback ordering issue (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Add __ro_after_init and __init (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Move drop _tval from erratum function names (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Move system register timer programming over to CVAL (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Extend write side of timer register accessors to u64 (Mark Salter) [RHEL-19605]
- clocksource/drivers/arm_arch_timer: Drop CNT*_TVAL read accessors (Mark Salter) [RHEL-19605]
- clocksource/arm_arch_timer: Add build-time guards for unhandled register accesses (Mark Salter) [RHEL-19605]

* Mon Feb 19 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-542.el8]
- netfilter: nf_tables: reject QUEUE/DROP verdict parameters (Florian Westphal) [RHEL-23506] {CVE-2024-1086}
- drm/virtio: Set segment size for virtio_gpu device (Sebastian Ott) [RHEL-15465]
- xfs: run blockgc on freeze to avoid inode inactivation deadlock (Brian Foster) [RHEL-11344]
- RDMA/irdma: Report the correct link speed (Kamal Heib) [RHEL-23967]
- scsi: core: Increase max device queue_depth to 4096 (Ming Lei) [RHEL-11725]
- smsc95xx: fix stalled rx after link change (Izabela Bakollari) [RHEL-22312]
- ovl: remove privs in ovl_fallocate() (Miklos Szeredi) [RHEL-17933]
- ovl: remove privs in ovl_copyfile() (Miklos Szeredi) [RHEL-17933]
- Bluetooth: Add more enc key size check (David Marlin) [RHEL-19666] {CVE-2023-24023}
- Bluetooth: Normalize HCI_OP_READ_ENC_KEY_SIZE cmdcmplt (David Marlin) [RHEL-19666] {CVE-2023-24023}
- IB: Use capital "OR" for multiple licenses in SPDX (Izabela Bakollari) [RHEL-10238]
- RDMA/rdmavt: Delete unnecessary NULL check (Izabela Bakollari) [RHEL-10238]
- IB/rdmavt: Fix target union member for rvt_post_one_wr() (Izabela Bakollari) [RHEL-10238]
- selftests/mm: cow: print ksft header before printing anything else (Nico Pache) [RHEL-5623]
- selftests/mm/kugepaged: restore thp settings at exit (Nico Pache) [RHEL-5623]
- selftests: line buffer test program's stdout (Nico Pache) [RHEL-5623]
- selftests/kselftest/runner.sh: Pass optional command parameters in environment (Nico Pache) [RHEL-5623]
- selftests/kselftest/runner/run_one(): allow running non-executable files (Nico Pache) [RHEL-5623]
- selftests: allow runners to override the timeout (Nico Pache) [RHEL-5623]
- selftests: mm: fix map_hugetlb failure on 64K page size systems (Nico Pache) [RHEL-5623]
- redhat: Fix build for kselftests mm (Nico Pache) [RHEL-5623]
- selftests: anon_cow: skip broken test (Nico Pache) [RHEL-5623]
- mm/gup_test: free memory allocated via kvcalloc() using kvfree() (Nico Pache) [RHEL-5623]
- selftests/mm: prevent duplicate runs caused by TEST_GEN_PROGS (Nico Pache) [RHEL-5623]
- selftests: mm: add a test for mutually aligned moves > PMD size (Nico Pache) [RHEL-5623]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Nico Pache) [RHEL-5623]
- selftests: mm: fix failure case when new remap region was not found (Nico Pache) [RHEL-5623]
- selftests/mm: fix WARNING comparing pointer to 0 (Nico Pache) [RHEL-5623]
- selftests/mm: run all tests from run_vmtests.sh (Nico Pache) [RHEL-5623]
- selftests/mm: optionally pass duration to transhuge-stress (Nico Pache) [RHEL-5623]
- selftests/mm: make migration test robust to failure (Nico Pache) [RHEL-5623]
- selftests/mm: va_high_addr_switch should skip unsupported arm64 configs (Nico Pache) [RHEL-5623]
- selftests/mm: fix thuge-gen test bugs (Nico Pache) [RHEL-5623]
- selftests/mm: skip soft-dirty tests on arm64 (Nico Pache) [RHEL-5623]
- selftests/mm: add gup test matrix in run_vmtests.sh (Nico Pache) [RHEL-5623]
- selftests/mm: add -a to run_vmtests.sh (Nico Pache) [RHEL-5623]
- selftests/mm: give scripts execute permission (Nico Pache) [RHEL-5623]
- selftests: mm: remove duplicate unneeded defines (Nico Pache) [RHEL-5623]
- Documentation: kselftest: "make headers" is a prerequisite (Nico Pache) [RHEL-5623]
- selftests/mm: fix build failures due to missing MADV_COLLAPSE (Nico Pache) [RHEL-5623]
- selftests/mm: fix a "possibly uninitialized" warning in pkey-x86.h (Nico Pache) [RHEL-5623]
- selftests/mm: .gitignore: add mkdirty, va_high_addr_switch (Nico Pache) [RHEL-5623]
- selftests/mm: fix invocation of tests that are run via shell scripts (Nico Pache) [RHEL-5623]
- selftests/mm: fix "warning: expression which evaluates to zero..." in mlock2-tests.c (Nico Pache) [RHEL-5623]
- selftests/mm: fix unused variable warnings in hugetlb-madvise.c, migration.c (Nico Pache) [RHEL-5623]
- selftests/mm: fix cross compilation with LLVM (Nico Pache) [RHEL-5623]
- selftests/mm: run hugetlb testcases of va switch (Nico Pache) [RHEL-5623]
- selftests/mm: configure nr_hugepages for arm64 (Nico Pache) [RHEL-5623]
- selftests/mm: add platform independent in code comments (Nico Pache) [RHEL-5623]
- selftests/mm: rename va_128TBswitch to va_high_addr_switch (Nico Pache) [RHEL-5623]
- selftests/mm: add support for arm64 platform on va switch (Nico Pache) [RHEL-5623]
- selftests/mm: use PM_* macros in vm_utils.h (Nico Pache) [RHEL-5623]
- selftests/mm: merge default_huge_page_size() into one (Nico Pache) [RHEL-5623]
- selftests/mm: link vm_util.c always (Nico Pache) [RHEL-5623]
- selftests/mm: use TEST_GEN_PROGS where proper (Nico Pache) [RHEL-5623]
- selftests/mm: merge util.h into vm_util.h (Nico Pache) [RHEL-5623]
- selftests/mm: dump a summary in run_vmtests.sh (Nico Pache) [RHEL-5623]
- selftests/mm: set overcommit_policy as OVERCOMMIT_ALWAYS (Nico Pache) [RHEL-5623]
- selftests/mm: change NR_CHUNKS_HIGH for aarch64 (Nico Pache) [RHEL-5623]
- selftests/mm: change MAP_CHUNK_SIZE (Nico Pache) [RHEL-5623]
- selftests: vm: enable cross-compilation (Nico Pache) [RHEL-5623]
- selftests/vm: rename selftests/vm to selftests/mm (Nico Pache) [RHEL-5623]
- selftests: vm: Fix incorrect kernel headers search path (Nico Pache) [RHEL-5623]
- selftests/vm: cow: fix compile warning on 32bit (Nico Pache) [RHEL-5623]
- mm/gup_test: fix PIN_LONGTERM_TEST_READ with highmem (Nico Pache) [RHEL-5623]
- mm/pagewalk: don't trigger test_walk() in walk_page_vma() (Nico Pache) [RHEL-5623]
- selftests/vm: enable running select groups of tests (Nico Pache) [RHEL-5623]
- selftests/vm: anon_cow: add R/O longterm tests via gup_test (Nico Pache) [RHEL-5623]
- mm/gup_test: start/stop/read functionality for PIN LONGTERM test (Nico Pache) [RHEL-5623]
- selftests/vm: anon_cow: add liburing test cases (Nico Pache) [RHEL-5623]
- selftests/vm: anon_cow: hugetlb tests (Nico Pache) [RHEL-5623]
- selftests/vm: anon_cow: THP tests (Nico Pache) [RHEL-5623]
- selftests/vm: factor out pagemap_is_populated() into vm_util (Nico Pache) [RHEL-5623]
- selftests/vm: anon_cow: test COW handling of anonymous memory (Nico Pache) [RHEL-5623]
- selftests/vm: add local_config.h and local_config.mk to .gitignore (Nico Pache) [RHEL-5623]
- selftest: vm: remove deleted local_config.* from .gitignore (Nico Pache) [RHEL-5623]
- Kselftests: remove support of libhugetlbfs from kselftests (Nico Pache) [RHEL-5623]
- selftests/vm: use top_srcdir instead of recomputing relative paths (Nico Pache) [RHEL-5623]
- selftests/vm: skip 128TBswitch on unsupported arch (Nico Pache) [RHEL-5623]
- selftests/vm: fix va_128TBswitch.sh permissions (Nico Pache) [RHEL-5623]
- selftests/vm: add protection_keys tests to run_vmtests (Nico Pache) [RHEL-5623]
- selftests/vm: only run 128TBswitch with 5-level paging (Nico Pache) [RHEL-5623]
- userfaultfd: selftests: infinite loop in faulting_process (Nico Pache) [RHEL-5623]
- userfaultfd/selftests: Fix typo in comment (Nico Pache) [RHEL-5623]
- selftests: vm: Fix resource leak when return error (Nico Pache) [RHEL-5623]
- selftests: vm: add the "settings" file with timeout variable (Nico Pache) [RHEL-5623]
- selftests: vm: add "test_hmm.sh" to TEST_FILES (Nico Pache) [RHEL-5623]
- selftests: vm: check numa_available() before operating "merge_across_nodes" in ksm_tests (Nico Pache) [RHEL-5623]
- selftests: vm: add migration to the .gitignore (Nico Pache) [RHEL-5623]
- selftests/vm/pkeys: fix typo in comment (Nico Pache) [RHEL-5623]
- userfaultfd/selftests: use swap() instead of open coding it (Nico Pache) [RHEL-5623]
- selftests: vm: fix shellcheck warnings in run_vmtests.sh (Nico Pache) [RHEL-5623]
- selftests: vm: refactor run_vmtests.sh to reduce boilerplate (Nico Pache) [RHEL-5623]
- selftests: vm: add test for Soft-Dirty PTE bit (Nico Pache) [RHEL-5623]
- selftests: vm: bring common functions to a new file (Nico Pache) [RHEL-5623]
- mm: add selftests for migration entries (Nico Pache) [RHEL-5623]
- selftest/vm: add skip support to mremap_test (Nico Pache) [RHEL-5623]
- selftest/vm: support xfail in mremap_test (Nico Pache) [RHEL-5623]
- selftest/vm: verify remap destination address in mremap_test (Nico Pache) [RHEL-5623]
- selftest/vm: verify mmap addr in mremap_test (Nico Pache) [RHEL-5623]
- selftests: kselftest framework: provide "finished" helper (Nico Pache) [RHEL-5623]
- selftest/vm: add helpers to detect PAGE_SIZE and PAGE_SHIFT (Nico Pache) [RHEL-5623]
- selftest/vm: add util.h and and move helper functions there (Nico Pache) [RHEL-5623]
- selftests: vm: remove dependecy from internal kernel macros (Nico Pache) [RHEL-5623]
- selftests: vm: Add the uapi headers include variable (Nico Pache) [RHEL-5623]
- selftests/vm/transhuge-stress: Support file-backed PMD folios (Nico Pache) [RHEL-5623]
- selftests, x86: fix how check_cc.sh is being invoked (Nico Pache) [RHEL-5623]
- selftests: vm: fix clang build error multiple output files (Nico Pache) [RHEL-5623]
- kselftest/vm: fix tests build with old libc (Nico Pache) [RHEL-5623]
- selftest/vm: fix map_fixed_noreplace test failure (Nico Pache) [RHEL-5623]
- kselftest/vm: revert "tools/testing/selftests/vm/userfaultfd.c: use swap() to make code cleaner" (Nico Pache) [RHEL-5623]
- selftests/vm: make charge_reserved_hugetlb.sh work with existing cgroup setting (Nico Pache) [RHEL-5623]
- tools/testing/selftests/vm/userfaultfd.c: use swap() to make code cleaner (Nico Pache) [RHEL-5623]
- selftests/vm: remove ARRAY_SIZE define from individual tests (Nico Pache) [RHEL-5623]
- selftests: vm: add KSM huge pages merging time test (Nico Pache) [RHEL-5623]
- selftest/vm: fix ksm selftest to run with different NUMA topologies (Nico Pache) [RHEL-5623]
- selftests/vm/transhuge-stress: fix ram size thinko (Nico Pache) [RHEL-5623]
- selftests: vm: add COW time test for KSM pages (Nico Pache) [RHEL-5623]
- selftests: vm: add KSM merging time test (Nico Pache) [RHEL-5623]
- mm: KSM: fix data type (Nico Pache) [RHEL-5623]
- selftests: vm: add KSM merging across nodes test (Nico Pache) [RHEL-5623]
- selftests: vm: add KSM zero page merging test (Nico Pache) [RHEL-5623]
- selftests: vm: add KSM unmerge test (Nico Pache) [RHEL-5623]
- selftests: vm: add KSM merge test (Nico Pache) [RHEL-5623]
- selftests: Fix spelling mistake "cann't" -> "cannot" (Nico Pache) [RHEL-5623]
- selftests/vm: use kselftest skip code for skipped tests (Nico Pache) [RHEL-5623]
- selftest/mremap_test: avoid crash with static build (Nico Pache) [RHEL-5623]
- selftest/mremap_test: update the test to handle pagesize other than 4K (Nico Pache) [RHEL-5623]
- selftests/vm/pkeys: exercise x86 XSAVE init state (Nico Pache) [RHEL-5623]
- selftests/vm/pkeys: refill shadow register after implicit kernel write (Nico Pache) [RHEL-5623]
- selftests/vm/pkeys: handle negative sys_pkey_alloc() return code (Nico Pache) [RHEL-5623]
- vm/test_vmalloc.sh: adapt for updated driver interface (Nico Pache) [RHEL-5623]
- tool: selftests: fix spelling typo of 'writting' (Nico Pache) [RHEL-5623]
- userfaultfd/selftests: hint the test runner on required privilege (Nico Pache) [RHEL-5623]
- userfaultfd/selftests: fix retval check for userfaultfd_open() (Nico Pache) [RHEL-5623]
- userfaultfd/selftests: always dump something in modes (Nico Pache) [RHEL-5623]
- userfaultfd: selftests: make __{s,u}64 format specifiers portable (Nico Pache) [RHEL-5623]
- tools: Avoid comma separated statements (Nico Pache) [RHEL-5623]
- kselftests: vm: add mremap tests (Nico Pache) [RHEL-5623]
- Revert "selftests/vm: enable running select groups of tests" (Nico Pache) [RHEL-5623]

* Fri Feb 16 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-541.el8]
- cgroup/rstat: Optimize cgroup_rstat_updated_list() (Waiman Long) [RHEL-18154]
- cgroup/rstat: Reduce cpu_lock hold time in cgroup_rstat_flush_locked() (Waiman Long) [RHEL-18154]
- cgroup: use irqsave in cgroup_rstat_flush_locked(). (Waiman Long) [RHEL-18154]
- cgroup: fix spelling mistakes (Waiman Long) [RHEL-18154]
- s390/ipl: add missing intersection check to ipl_report handling (Tobias Huschle) [RHEL-24612]
- drm/amdgpu: Fix potential fence use-after-free v2 (Michel Dänzer) [RHEL-22504] {CVE-2023-51042}
- sched/fair: Don't balance task to its current running CPU (Luis Claudio R. Goncalves) [RHEL-8854]
- md: partially revert "md/raid6: use valid sector values to determine if an I/O should wait on the reshape" (Benjamin Marzinski) [RHEL-24518]
- blk-mq: fix IO hang from sbitmap wakeup race (Ming Lei) [RHEL-21289]
- sfc: introduce shutdown entry point in efx pci driver (Izabela Bakollari) [RHEL-11016]
- KVM: arm64: vgic-its: Avoid potential UAF in LPI translation cache (Sebastian Ott) [RHEL-5178]
- efi: libstub: ensure allocated memory to be executable (Lenny Szubowicz) [RHEL-24852]
- efi: libstub: declare DXE services table (Lenny Szubowicz) [RHEL-24852]
- efi/libstub/x86: Avoid overflowing code32_start on PE entry (Lenny Szubowicz) [RHEL-24852]
- RDMA/efa: Fix wrong resources deallocation order (Izabela Bakollari) [RHEL-18229]
- RDMA/efa: Add RDMA write HW statistics counters (Izabela Bakollari) [RHEL-18229]
- RDMA/efa: Fix unsupported page sizes in device (Izabela Bakollari) [RHEL-18229]
- RDMA/efa: Add rdma write capability to device caps (Izabela Bakollari) [RHEL-18229]
- RDMA/efa: Add data polling capability feature bit (Izabela Bakollari) [RHEL-18229]
- APEI: GHES: correctly return NULL for ghes_get_devices() (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Make ghes_edac a proper module (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Prepare to make ghes_edac a proper module (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Add a notifier for reporting memory errors (Aristeu Rozanski) [RHEL-1603]
- efi/cper: Export several helpers for ghes_edac to use (Aristeu Rozanski) [RHEL-1603]
- ACPI: APEI: rename ghes_init() with an "acpi_" prefix (Aristeu Rozanski) [RHEL-1603]
- ACPI: APEI: explicit init of HEST and GHES in apci_init() (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Clear scanned data on unload (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Fix NULL pointer dereference in ghes_edac_register() (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Scan the system once on driver init (Aristeu Rozanski) [RHEL-1603]
- EDAC/ghes: Remove unused members of struct ghes_edac_pvt, rename it to ghes_pvt (Aristeu Rozanski) [RHEL-1603]
- EDAC: Introduce an mci_for_each_dimm() iterator (Aristeu Rozanski) [RHEL-1603]
- EDAC: Remove EDAC_DIMM_OFF() macro (Aristeu Rozanski) [RHEL-1603]
- r8169: add handling DASH when DASH is disabled (Izabela Bakollari) [RHEL-6505]
- r8169: remove rtl_wol_shutdown_quirk() (Izabela Bakollari) [RHEL-6505]
- r8169: improve driver unload and system shutdown behavior on DASH-enabled systems (Izabela Bakollari) [RHEL-6505]
- r8169: fix dmar pte write access is not set error (Izabela Bakollari) [RHEL-6505]
- r8169: move rtl_wol_enable_rx() and rtl_prepare_power_down() (Izabela Bakollari) [RHEL-6505]
- r8169: prevent potential deadlock in rtl8169_close (Izabela Bakollari) [RHEL-6505]
- r8169: fix deadlock on RTL8125 in jumbo mtu mode (Izabela Bakollari) [RHEL-6505]
- r8169: fix network lost after resume on DASH systems (Izabela Bakollari) [RHEL-6505]
- r8169: respect userspace disabling IFF_MULTICAST (Izabela Bakollari) [RHEL-6505]
- r8169: fix the KCSAN reported data race in rtl_rx while reading desc->opts1 (Izabela Bakollari) [RHEL-6505]
- r8169: fix the KCSAN reported data-race in rtl_tx while reading TxDescArray[entry].opts1 (Izabela Bakollari) [RHEL-6505]
- r8169: fix the KCSAN reported data-race in rtl_tx() while reading tp->cur_tx (Izabela Bakollari) [RHEL-6505]
- r8169: fix rare issue with broken rx after link-down on RTL8125 (Izabela Bakollari) [RHEL-6505]
- r8169: check for PCI read error in probe (Izabela Bakollari) [RHEL-6505]
- r8169: fix RTL8168H and RTL8107E rx crc error (Izabela Bakollari) [RHEL-6505]
- r8169: reset bus if NIC isn't accessible after tx timeout (Izabela Bakollari) [RHEL-6505]
- r8169: disable ASPM in case of tx timeout (Izabela Bakollari) [RHEL-6505]
- r8169: use tp_to_dev instead of open code (Izabela Bakollari) [RHEL-6505]
- r8169: add rtl_disable_rxdvgate() (Izabela Bakollari) [RHEL-6505]
- r8169: remove not needed net_ratelimit() check (Izabela Bakollari) [RHEL-6505]
- r8169: remove useless PCI region size check (Izabela Bakollari) [RHEL-6505]
- Bluetooth: hci_sync: Fix not processing all entries on cmd_sync_work (David Marlin) [RHEL-23781]
- Bluetooth: hci_core: Fix unbalanced unlock in set_device_flags() (David Marlin) [RHEL-23781]
- Bluetooth: Fix not checking MGMT cmd pending queue (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Fix not using conn_timeout (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Fix hci_update_accept_list_sync (David Marlin) [RHEL-23781]
- Bluetooth: assign len after null check (David Marlin) [RHEL-23781]
- Bluetooth: Fix bt_skb_sendmmsg not allocating partial chunks (David Marlin) [RHEL-23781]
- Bluetooth: fix data races in smp_unregister(), smp_del_chan() (David Marlin) [RHEL-23781]
- Bluetooth: hci_core: Fix leaking sent_cmd skb (David Marlin) [RHEL-23781]
- Bluetooth: hci_sock: fix endian bug in hci_sock_setsockopt() (David Marlin) [RHEL-23781]
- Bluetooth: L2CAP: uninitialized variables in l2cap_sock_setsockopt() (David Marlin) [RHEL-23781]
- Bluetooth: btqca: sequential validation (David Marlin) [RHEL-23781]
- Bluetooth: hci_event: Rework hci_inquiry_result_with_rssi_evt (David Marlin) [RHEL-23781]
- Bluetooth: btbcm: disable read tx power for MacBook Air 8,1 and 8,2 (David Marlin) [RHEL-23781]
- Bluetooth: hci_qca: Fix NULL vs IS_ERR_OR_NULL check in qca_serdev_probe (David Marlin) [RHEL-23781]
- Bluetooth: hci_bcm: Check for error irq (David Marlin) [RHEL-23781]
- Bluetooth: MGMT: Fix spelling mistake "simultanous" -> "simultaneous" (David Marlin) [RHEL-23781]
- Bluetooth: vhci: Set HCI_QUIRK_VALID_LE_STATES (David Marlin) [RHEL-23781]
- Bluetooth: MGMT: Fix LE simultaneous roles UUID if not supported (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Add check simultaneous roles support (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Wait for proper events when connecting LE (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Add support for waiting specific LE subevents (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Add hci_le_create_conn_sync (David Marlin) [RHEL-23781]
- Bluetooth: hci_event: Use skb_pull_data when processing inquiry results (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Push sync command cancellation to workqueue (David Marlin) [RHEL-23781]
- Bluetooth: hci_qca: Stop IBS timer during BT OFF (David Marlin) [RHEL-23781]
- Bluetooth: btintel: Add missing quirks and msft ext for legacy bootloader (David Marlin) [RHEL-23781]
- Bluetooth: L2CAP: Fix using wrong mode (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Fix not always pausing advertising when necessary (David Marlin) [RHEL-23781]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_CONNECTED (David Marlin) [RHEL-23781]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_FOUND (David Marlin) [RHEL-23781]
- Bluetooth: mgmt: Introduce mgmt_alloc_skb and mgmt_send_event_skb (David Marlin) [RHEL-23781]
- Bluetooth: btusb: Return error code when getting patch status failed (David Marlin) [RHEL-23781]
- Bluetooth: btusb: Handle download_firmware failure cases (David Marlin) [RHEL-23781]
- Bluetooth: msft: Fix compilation when CONFIG_BT_MSFTEXT is not set (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Set Privacy Mode when updating the resolving list (David Marlin) [RHEL-23781]
- Bluetooth: Introduce HCI_CONN_FLAG_DEVICE_PRIVACY device flag (David Marlin) [RHEL-23781]
- Bluetooth: btusb: Add support for queuing during polling interval (David Marlin) [RHEL-23781]
- Bluetooth: hci_core: Rework hci_conn_params flags (David Marlin) [RHEL-23781]
- Bluetooth: MGMT: Use hci_dev_test_and_{set,clear}_flag (David Marlin) [RHEL-23781]
- Bluetooth: btbcm: disable read tx power for some Macs with the T2 Security chip (David Marlin) [RHEL-23781]
- Bluetooth: add quirk disabling LE Read Transmit Power (David Marlin) [RHEL-23781]
- Bluetooth: hci_event: Use of a function table to handle Command Status (David Marlin) [RHEL-23781]
- Bluetooth: hci_event: Use of a function table to handle Command Complete (David Marlin) [RHEL-23781]
- Bluetooth: hci_event: Use of a function table to handle LE subevents (David Marlin) [RHEL-23781]
- Bluetooth: hci_event: Use of a function table to handle HCI events (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse LE Direct Advertising Report event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse LE Ext Advertising Report event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse LE Advertising Report event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse LE Metaevents (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse Extended Inquiry Result event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result with RSSI event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse Number of Complete Packets event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse Command Complete event (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Use skb_pull_data to parse BR/EDR events (David Marlin) [RHEL-23781]
- Bluetooth: btusb: Cancel sync commands for certain URB errors (David Marlin) [RHEL-23781]
- Bluetooth: hci_core: Cancel sync command if sending a frame failed (David Marlin) [RHEL-23781]
- Bluetooth: Add hci_cmd_sync_cancel to public API (David Marlin) [RHEL-23781]
- Bluetooth: Reset more state when cancelling a sync command (David Marlin) [RHEL-23781]
- Bluetooth: Limit duration of Remote Name Resolve (David Marlin) [RHEL-23781]
- Bluetooth: Send device found event on name resolve failure (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Fix definition of hci_rp_delete_stored_link_key (David Marlin) [RHEL-23781]
- Bluetooth: HCI: Fix definition of hci_rp_read_stored_link_key (David Marlin) [RHEL-23781]
- Bluetooth: refactor malicious adv data check (David Marlin) [RHEL-23781]
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek RTL8852AE (David Marlin) [RHEL-23781]
- Bluetooth: btusb: enable Mediatek to support AOSP extension (David Marlin) [RHEL-23781]
- Bluetooth: Attempt to clear HCI_LE_ADV on adv set terminated error event (David Marlin) [RHEL-23781]
- Bluetooth: Ignore HCI_ERROR_CANCELLED_BY_HOST on adv set terminated event (David Marlin) [RHEL-23781]
- Bluetooth: hci_request: Remove bg_scan_update work (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_CONNECTABLE to use cmd_sync (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_DISCOVERABLE to use cmd_sync (David Marlin) [RHEL-23781]
- Bluetooth: btmrvl_main: repair a non-kernel-doc comment (David Marlin) [RHEL-23781]
- Bluetooth: Don't initialize msft/aosp when using user channel (David Marlin) [RHEL-23781]
- Bluetooth: fix uninitialized variables notify_evt (David Marlin) [RHEL-23781]
- Bluetooth: stop proccessing malicious adv data (David Marlin) [RHEL-23781]
- Bluetooth: hci_h4: Fix padding calculation error within h4_recv_buf() (David Marlin) [RHEL-23781]
- Bluetooth: aosp: Support AOSP Bluetooth Quality Report (David Marlin) [RHEL-23781]
- Bluetooth: Add struct of reading AOSP vendor capabilities (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Fix not setting adv set duration (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Fix missing static warnings (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Rework hci_suspend_notifier (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Rework init stages (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SSP (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert adv_expire (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_ADVERTISING (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_PHY_CONFIGURATION (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LOCAL_NAME (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_EXT_DATA (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_DATA (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LE (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CLOCK_INFO (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_SECURE_CONN (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CONN_INFO (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Enable synch'd set_bredr (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_FAST_CONNECTABLE (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_OP_START_DISCOVERY (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Convert MGMT_SET_POWERED (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Rework background scan (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Enable advertising when LL privacy is enabled (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 3 (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 2 (David Marlin) [RHEL-23781]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 1 (David Marlin) [RHEL-23781]
- Bluetooth: Add helper for serialized HCI command execution (David Marlin) [RHEL-23781]
- Bluetooth: Fix removing adv when processing cmd complete (David Marlin) [RHEL-23781]
- Bluetooth: hci_bcm: Remove duplicated entry in OF table (David Marlin) [RHEL-23781]
- Bluetooth: bfusb: fix division by zero in send path (David Marlin) [RHEL-23781]
- Bluetooth: cmtp: fix possible panic when cmtp_init_sockets() fails (David Marlin) [RHEL-23781]
- Bluetooth: vhci: Fix checking of msft_opcode (David Marlin) [RHEL-23781]
- Bluetooth: btsdio: Do not bind to non-removable BCM4345 and BCM43455 (David Marlin) [RHEL-23781]
- Bluetooth: vhci: Add support for setting msft_opcode and aosp_capable (David Marlin) [RHEL-23781]
- Bluetooth: btusb: fix memory leak in btusb_mtk_submit_wmt_recv_urb() (David Marlin) [RHEL-23781]
- Bluetooth: Fix memory leak of hci device (David Marlin) [RHEL-23781]
- Bluetooth: btintel: Fix bdaddress comparison with garbage value (David Marlin) [RHEL-23781]
- Bluetooth: Fix debugfs entry leak in hci_register_dev() (David Marlin) [RHEL-23781]
- Bluetooth: L2CAP: Fix not initializing sk_peer_pid (David Marlin) [RHEL-23781]
- Bluetooth: hci_sock: purge socket queues in the destruct() callback (David Marlin) [RHEL-23781]
- Bluetooth: mgmt: Fix Experimental Feature Changed event (David Marlin) [RHEL-23781]
- Bluetooth: hci_vhci: Fix to set the force_wakeup value (David Marlin) [RHEL-23781]
- Bluetooth: Read codec capabilities only if supported (David Marlin) [RHEL-23781]
- Bluetooth: Fix handling of SUSPEND_DISCONNECTING (David Marlin) [RHEL-23781]
- Bluetooth: hci_vhci: Fix calling hci_{suspend,resume}_dev (David Marlin) [RHEL-23781]
- skbuff: introduce skb_pull_data (David Marlin) [RHEL-23781]
- Bluetooth: defer cleanup of resources in hci_unregister_dev() (David Marlin) [RHEL-23781]
- serial: core: return early on unsupported ioctls (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- lib/hexdump: make print_hex_dump_bytes() a nop on !DEBUG builds (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix race condition in status line change on dead connections (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- Revert "tty: n_gsm: fix UAF in gsm_cleanup_mux" (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix the UAF caused by race condition in gsm_cleanup_mux (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix UAF in gsm_cleanup_mux (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: add parameter negotiation support (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: add parameters used with parameter negotiation (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: introduce macro for minimal unit size (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: name the debug bits (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: introduce gsm_control_command() function (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: replace use of gsm_read_ea() with gsm_read_ea_val() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: name gsm tty device minors (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: initialize more members at gsm_alloc_mux() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: add sanity check for gsm->receive in gsm_receive_buf() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix flow control handling in tx path (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix resource allocation order in gsm_activate_mux() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix deadlock and link starvation in outgoing data path (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix race condition in gsmld_write() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix non flow control frames during mux flow off (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix missing timer to handle stalled links (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong queuing behavior in gsm_dlci_data_output() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix tty registration before control channel open (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix user open not possible at responder until initiator open (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Debug output allocation must use GFP_ATOMIC (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Fix packet data hex dump output (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix buffer over-read in gsm_dlci_data() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix sometimes uninitialized warning in gsm_dlci_modem_output() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix software flow control handling (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix invalid use of MSC in advanced option (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix broken virtual tty handling (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix missing update of modem controls after DLCI open (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix reset fifo race condition (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix missing tty wakeup in convergence layer type 2 (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong signal octets encoding in MSC (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong command frame length field encoding (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong command retry handling (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix missing explicit ldisc flush (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong DLCI release order (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix insufficient txframe size (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix frame reception handling (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong signal octet encoding in convergence layer type 2 (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix mux cleanup after unregister tty device (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix decoupled mux resource (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix restart handling via CLD command (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix deadlock in gsmtty_open() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong modem processing in convergence layer type 2 (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix wrong tty control line for flow control (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix NULL pointer access due to DLCI release (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix encoding of command/response bit (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: fix SW flow control encoding/handling (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove tty parameter from mxser_receive_chars_new() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: don't throttle manually (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: make mxser_port::ldisc_stop_rx a bool (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Don't ignore write return value in gsmld_output() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: clean up indenting in gsm_queue() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Save dlci address open status when config requester (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Modify gsmtty driver register method when config requester (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Delete gsmtty open SABM frame when config requester (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Modify CR,PF bit printk info when config requester (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Modify CR,PF bit when config requester (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: stop using alloc_tty_driver (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: don't store semi-state into tty drivers (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- hvsi: don't panic on tty_register_driver failure (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- amiserial: switch rs_table to a single state (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- amiserial: expand "custom" (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- amiserial: use memset to zero serial_state (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- amiserial: remove serial_* strings (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: drop mxser_port::custom_divisor (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: drop mxser_port::baud_base (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove unused mxser_port::stop_rx (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: don't allocate MXSER_PORTS + 1 (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove cnt from mxser_receive_chars (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_GETMSTATUS ioctl (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_GETDATACOUNT ioctl (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_CHKPORTENABLE ioctl (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_ASPP_LSTATUS ioctl (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_ASPP_MON and friends (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_SET_BAUD_METHOD ioctl (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove MOXA_GET_MAJOR deprecated ioctl (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: drop unused MOXA_DIAGNOSE macro (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: drop UART_MCR_AFE and UART_LSR_SPECIAL defines (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove else from LSR bits checks (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: extract mxser_receive_chars_old (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: extract mxser_receive_chars_new (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: simplify mxser_interrupt and drop mxser_board::vector_mask (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: extract port ISR (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: cleanup LSR handling in mxser_receive_chars (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: remove nonsense from ISR (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: drop constant board::uart_type (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: introduce enum mxser_must_hwid (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: rename mxser_board::chip_flag to must_hwid (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: rename CheckIsMoxaMust to mxser_get_must_hwid (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: cleanup Gpci_uart_info struct (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: integrate mxser.h into .c (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: drop ISA support (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: use goto-failpaths in gsm_init (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: mxser: drop low-latency workaround (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: check error while registering tty devices (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: mxser: fix TIOCSSERIAL jiffies conversions (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm, remove duplicates of parameters (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: do not check tty_unregister_driver's return value (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: nozomi, remove init/exit messages (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty_port: drop last traces of low_latency (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Demote obvious abuse of kernel-doc and supply other missing docss (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm, eliminate indirection for gsm->{output,error}() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Fix bogus i++ in gsm_data_kick (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Remove unnecessary test in gsm_print_packet() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Fix waking up upper tty layer when room available (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Fix SOF skipping (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Improve debug output (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: switch constipated to bool (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: switch throttled to bool (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: switch dead to bool (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: introduce enum gsm_dlci_mode (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: introduce enum gsm_dlci_state (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: drop unneeded gsm_dlci->fifo field (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Replace zero-length array with flexible-array member (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: avoid recursive locking with async port hangup (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: add helpers to convert mux-num to/from tty-base (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- docs: serial: move it to the driver-api (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- docs: serial: convert docs to ReST and rename to *.rst (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Mark expected switch fall-throughs (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- n_gsm: Constify u8 and unsigned char usage (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty: n_gsm: Add copy_config() and gsm_config() to prepare for serdev (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- mxser: switch to ->[sg]et_serial() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- amiserial: switch to ->[sg]et_serial() (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}
- tty/serial_core: add ISO7816 infrastructure (Wander Lairson Costa) [RHEL-19955] {CVE-2023-6546}

* Fri Feb 09 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-540.el8]
- mm/readahead: reintroduce legacy madvise_willneed behavior to force_page_cache_readahead (Rafael Aquini) [RHEL-22476]
- PCI: Disable ATS for specific Intel IPU E2000 devices (Myron Stowe) [RHEL-21011]
- PCI: Extract ATS disabling to a helper function (Myron Stowe) [RHEL-21011]
- HID: intel-ish-hid: ipc: Disable and reenable ACPI GPE bit (Tony Camuso) [RHEL-14732]
- HID: intel-ish-hid: ipc: Add Arrow Lake PCI device ID (Tony Camuso) [RHEL-14732]
- HID: intel-ish-hid: Fix kernel panic during warm reset (Tony Camuso) [RHEL-14732]
- net: usb: ax88179_178a: avoid failed operations when device is disconnected (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: avoid two consecutive device resets (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: fix failed operations during ax88179_reset (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: Bind only to vendor-specific interface (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: wol optimizations (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: move priv to driver_priv (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: restore state on resume (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: clean up pm calls (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: remove redundant init code (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: make drivers set the TSO limit not the GSO limit (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: add Allied Telesis AT-UMCs (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: add TSO feature (Jose Ignacio Tornos Martinez) [RHEL-17561]
- ethernet: constify references to netdev->dev_addr in drivers (Jose Ignacio Tornos Martinez) [RHEL-17561]
- net: usb: ax88179_178a: initialize local variables before use (Jose Ignacio Tornos Martinez) [RHEL-17561]
- gve: Remove dependency on 4k page size. (Joshua Washington) [RHEL-22210]
- gve: Add page size register to the register_page_list command. (Joshua Washington) [RHEL-22210]
- gve: Remove obsolete checks that rely on page size. (Joshua Washington) [RHEL-22210]
- gve: Deprecate adminq_pfn for pci revision 0x1. (Joshua Washington) [RHEL-22210]
- gve: Perform adminq allocations through a dma_pool. (Joshua Washington) [RHEL-22210]
- gve: add gve_features_check() (Joshua Washington) [RHEL-22210]
- gve: Fixes for napi_poll when budget is 0 (Joshua Washington) [RHEL-22210]
- gve: Do not fully free QPL pages on prefill errors (Joshua Washington) [RHEL-22210]
- gve: Use size_add() in call to struct_size() (Joshua Washington) [RHEL-22210]
- gve: fix frag_list chaining (Joshua Washington) [RHEL-22210]
- gve: RX path for DQO-QPL (Joshua Washington) [RHEL-22210 RHEL-9878]
- gve: Tx path for DQO-QPL (Joshua Washington) [RHEL-22210 RHEL-9878]
- gve: Control path for DQO-QPL (Joshua Washington) [RHEL-22210 RHEL-9878]
- gve: trivial spell fix Recive to Receive (Joshua Washington) [RHEL-22210]
- gve: unify driver name usage (Joshua Washington) [RHEL-22210]
- gve: Set default duplex configuration to full (Joshua Washington) [RHEL-22210]
- gve: Remove the code of clearing PBA bit (Joshua Washington) [RHEL-22210]
- gve: Secure enough bytes in the first TX desc for all TCP pkts (Joshua Washington) [RHEL-22210]
- gve: Cache link_speed value from device (Joshua Washington) [RHEL-22210]
- gve: Add AF_XDP zero-copy support for GQI-QPL format (Joshua Washington) [RHEL-22210]
- gve: Add XDP REDIRECT support for GQI-QPL format (Joshua Washington) [RHEL-22210]
- gve: Add XDP DROP and TX support for GQI-QPL format (Joshua Washington) [RHEL-22210]
- gve: Changes to add new TX queues (Joshua Washington) [RHEL-22210]
- gve: XDP support GQI-QPL: helper function changes (Joshua Washington) [RHEL-22210]
- gve: Fix gve interrupt names (Joshua Washington) [RHEL-22210]
- gve: Handle alternate miss completions (Joshua Washington) [RHEL-22210]
- gve: Adding a new AdminQ command to verify driver (Joshua Washington) [RHEL-22210]
- gve: Fix error return code in gve_prefill_rx_pages() (Joshua Washington) [RHEL-22210]
- gve: Reduce alloc and copy costs in the GQ rx path (Joshua Washington) [RHEL-22210]
- google/gve:fix repeated words in comments (Joshua Washington) [RHEL-22210]
- gve: Fix spelling mistake "droping" -> "dropping" (Joshua Washington) [RHEL-22210]
- gve: enhance no queue page list detection (Joshua Washington) [RHEL-22210]
- net: Google gve: Remove dma_wmb() before ringing doorbell (Joshua Washington) [RHEL-22210]

* Mon Feb 05 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-539.el8]
- tcp: Dump bound-only sockets in inet_diag. (Guillaume Nault) [RHEL-6113]
- rh_messages.h: update driver and device lists (Scott Weaver) [RHEL-22126]
- vmstat: allow_direct_reclaim should use zone_page_state_snapshot (Marcelo Tosatti) [RHEL-22138]
- rbd: don't move requests to the running list on errors (Ilya Dryomov) [RHEL-21941]
- drm/vmwgfx: Fix possible null pointer derefence with invalid contexts (Jocelyn Falempe) [RHEL-3179] {CVE-2022-38096}
- atm: Fix Use-After-Free in do_vcc_ioctl (Guillaume Nault) [RHEL-21179] {CVE-2023-51780}
- perf/x86/intel/uncore: Factor out topology_gidnid_map() (Michael Petlan) [RHEL-22189]
- perf/x86/intel/uncore: Fix NULL pointer dereference issue in upi_fill_topology() (Michael Petlan) [RHEL-22189]
- KVM: x86: Constrain guest-supported xfeatures only at KVM_GET_XSAVE{2} (Bandan Das) [RHEL-7558]
- x86/fpu: Allow caller to constrain xfeatures when copying to uabi buffer (Bandan Das) [RHEL-7558]
- Bluetooth: Fix double free in hci_conn_cleanup (David Marlin) [RHEL-2555] {CVE-2023-28464}
- Bluetooth: hci_sysfs: Fix attempting to call device_add multiple times (David Marlin) [RHEL-2555]
- kobject: Fix slab-out-of-bounds in fill_kobj_path() (Waiman Long) [RHEL-20926] {CVE-2023-45863}
- kobject: modify kobject_get_path() to take a const * (Waiman Long) [RHEL-20926] {CVE-2023-45863}
- kobject: Remove docstring reference to kset (Waiman Long) [RHEL-20926] {CVE-2023-45863}
- EDAC/amd64: Add support for AMD family 1Ah models 00h-1Fh and 40h-4Fh (Aristeu Rozanski) [RHEL-10031]
- amd64: allow F0 and F6 registers to be missing (Aristeu Rozanski) [RHEL-10031]
- hwmon: (k10temp) Add thermal support for AMD Family 1Ah-based models (Aristeu Rozanski) [RHEL-10031]
- x86/amd_nb: Add PCI IDs for AMD Family 1Ah-based models (Aristeu Rozanski) [RHEL-10031]
- nvmet-tcp: Fix the H2C expected PDU len calculation (Maurizio Lombardi) [RHEL-19155 RHEL-19161 RHEL-19167] {CVE-2023-6536 CVE-2023-6535 CVE-2023-6356}
- nvmet-tcp: remove boilerplate code (Maurizio Lombardi) [RHEL-19155 RHEL-19161 RHEL-19167] {CVE-2023-6536 CVE-2023-6535 CVE-2023-6356}
- nvmet-tcp: fix a crash in nvmet_req_complete() (Maurizio Lombardi) [RHEL-19155 RHEL-19161 RHEL-19167] {CVE-2023-6536 CVE-2023-6535 CVE-2023-6356}
- nvmet-tcp: Fix a kernel panic when host sends an invalid H2C PDU length (Maurizio Lombardi) [RHEL-19155 RHEL-19161 RHEL-19167] {CVE-2023-6536 CVE-2023-6535 CVE-2023-6356}
- ipv6: Remove extra counter pull before gc (Davide Caratti) [RHEL-21457] {CVE-2023-52340}
- ipv6: remove max_size check inline with ipv4 (Davide Caratti) [RHEL-21457] {CVE-2023-52340}
- net/dst: use a smaller percpu_counter batch for dst entries accounting (Davide Caratti) [RHEL-21457] {CVE-2023-52340}
- net: add a route cache full diagnostic message (Davide Caratti) [RHEL-21457] {CVE-2023-52340}
- x86/sev: Use the GHCB protocol when available for SNP CPUID requests (Bandan Das) [RHEL-16382]
- x86/sev: Do not handle #VC for DR7 read/write (Bandan Das) [RHEL-16382]
- Revert "x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV" (Bandan Das) [RHEL-16382]
- x86/alternatives: Add cond_resched() to text_poke_bp_batch() (Waiman Long) [RHEL-15221]
- x86/alternative: Fix race in try_get_desc() (Waiman Long) [RHEL-15221]
- x86/alternatives: Mark text_poke_loc_init() static (Waiman Long) [RHEL-15221]
- x86/int3: Ensure that poke_int3_handler() is not traced (Waiman Long) [RHEL-15221]
- tools/mm: filter out timestamps for correct collation (Audra Mitchell) [RHEL-3821]
- tools/vm/page_owner_sort.c: support sorting pid and time (Audra Mitchell) [RHEL-3821]
- tools/vm/page_owner_sort.c: filter out unneeded line (Audra Mitchell) [RHEL-3821]
- tools/vm/page_owner: use page_owner_sort in the use example (Audra Mitchell) [RHEL-3821]
- mm/page_owner: remove free_ts from page_owner output (Audra Mitchell) [RHEL-3821]
- xfs: up(ic_sema) if flushing data device fails (Andrey Albershteyn) [RHEL-8464]
- xfs: reserve less log space when recovering log intent items (Andrey Albershteyn) [RHEL-8464]
- xfs: fix an agbno overflow in __xfs_getfsmap_datadev (Andrey Albershteyn) [RHEL-8464]
- xfs: fix agf_fllast when repairing an empty AGFL (Andrey Albershteyn) [RHEL-8464]
- xfs: fix dqiterate thinko (Andrey Albershteyn) [RHEL-8464]
- xfs: fix uninit warning in xfs_growfs_data (Andrey Albershteyn) [RHEL-8464]
- xfs: fix xfs_btree_query_range callers to initialize btree rec fully (Andrey Albershteyn) [RHEL-8464]
- xfs: validate fsmap offsets specified in the query keys (Andrey Albershteyn) [RHEL-8464]
- xfs: fix logdev fsmap query result filtering (Andrey Albershteyn) [RHEL-8464]
- xfs: clean up the rtbitmap fsmap backend (Andrey Albershteyn) [RHEL-8464]
- xfs: fix integer overflows in the fsmap rtbitmap and logdev backends (Andrey Albershteyn) [RHEL-8464]
- xfs: fix interval filtering in multi-step fsmap queries (Andrey Albershteyn) [RHEL-8464]
- xfs: don't reverse order of items in bulk AIL insertion (Andrey Albershteyn) [RHEL-8464]
- xfs: fix ag count overflow during growfs (Andrey Albershteyn) [RHEL-8464]
- xfs: don't deplete the reserve pool when trying to shrink the fs (Andrey Albershteyn) [RHEL-8464]
- xfs: fix agf/agfl verification on v4 filesystems (Andrey Albershteyn) [RHEL-8464]
- xfs: set bnobt/cntbt numrecs correctly when formatting new AGs (Andrey Albershteyn) [RHEL-8464]
- xfs: fix rm_offset flag handling in rmap keys (Andrey Albershteyn) [RHEL-8464]
- xfs: make kobj_type structures constant (Andrey Albershteyn) [RHEL-8464]
- xfs: allow setting full range of panic tags (Andrey Albershteyn) [RHEL-8464]
- xfs: shut up -Wuninitialized in xfsaild_push (Andrey Albershteyn) [RHEL-8464]
- xfs: use memcpy, not strncpy, to format the attr prefix during listxattr (Andrey Albershteyn) [RHEL-8464]
- xfs: initialize the check_owner object fully (Andrey Albershteyn) [RHEL-8464]
- xfs: fix uninitialized list head in struct xfs_refcount_recovery (Andrey Albershteyn) [RHEL-8464]
- xfs: increase rename inode reservation (Andrey Albershteyn) [RHEL-8464]
- xfs: remove xfs_setattr_time() declaration (Andrey Albershteyn) [RHEL-8464]
- xfs: Fix false ENOSPC when performing direct write on a delalloc extent in cow fork (Andrey Albershteyn) [RHEL-8464]
- xfs: check return codes when flushing block devices (Andrey Albershteyn) [RHEL-8464]
- xfs: reduce the number of atomic when locking a buffer after lookup (Andrey Albershteyn) [RHEL-8464]
- xfs: convert btree buffer log flags to unsigned. (Andrey Albershteyn) [RHEL-8464]
- xfs: shutdown in intent recovery has non-intent items in the AIL (Andrey Albershteyn) [RHEL-8464]
- xfs: aborting inodes on shutdown may need buffer lock (Andrey Albershteyn) [RHEL-8464]
- xfs: only bother with sync_filesystem during readonly remount (Andrey Albershteyn) [RHEL-8464]
- xfs: kill the XFS_IOC_{ALLOC,FREE}SP* ioctls (Andrey Albershteyn) [RHEL-8464] {CVE-2021-4155}
- xfs: prevent a WARN_ONCE() in xfs_ioc_attr_list() (Andrey Albershteyn) [RHEL-8464]
- xfs: only run COW extent recovery when there are no live extents (Andrey Albershteyn) [RHEL-8464]
- xfs: move recovery needed state updates to xfs_log_mount_finish (Andrey Albershteyn) [RHEL-8464]
- xfs: clear log incompat feature bits when the log is idle (Andrey Albershteyn) [RHEL-8464]
- xfs: allow setting and clearing of log incompat feature flags (Andrey Albershteyn) [RHEL-8464]
- xfs: remove all COW fork extents when remounting readonly (Andrey Albershteyn) [RHEL-8464]
- xfs: replace snprintf in show functions with sysfs_emit (Andrey Albershteyn) [RHEL-8464]
- xfs: reduce the size of nr_ops for refcount btree cursors (Andrey Albershteyn) [RHEL-8464]
- xfs: rework attr2 feature and mount options (Andrey Albershteyn) [RHEL-8464]
- xfs: sb verifier doesn't handle uncached sb buffer (Andrey Albershteyn) [RHEL-8464]
- xfs: standardize inode number formatting in ftrace output (Andrey Albershteyn) [RHEL-8464]
- xfs: make fsmap backend function key parameters const (Andrey Albershteyn) [RHEL-8464]
- xfs: remove kmem_alloc_io() (Andrey Albershteyn) [RHEL-8464]
- mm: Add kvrealloc() (Andrey Albershteyn) [RHEL-8464]
- xfs: remove kmem_realloc() (Andrey Albershteyn) [RHEL-8464]
- xfs: fix silly whitespace problems with kernel libxfs (Andrey Albershteyn) [RHEL-8464]
- xfs: deprecate BMV_IF_NO_DMAPI_READ flag (Andrey Albershteyn) [RHEL-8464]

* Wed Jan 31 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-538.el8]
- ida: Fix crash in ida_free when the bitmap is empty (Wander Lairson Costa) [RHEL-19681] {CVE-2023-6915}
- mm: create a new system state and fix core_kernel_text() (Joel Savitz) [RHEL-5227]
- redhat: rewrite genlog and support Y- tags (Jan Stancek)
- Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d" (Nigel Croxon) [RHEL-22698]
- Revert "x86/fpu/xstate: Fix PKRU covert channel" (Steve Best) [RHEL-22192]
- net: tls, update curr on splice as well (Sabrina Dubroca) [RHEL-19065] {CVE-2024-0646}
- smb: client: fix OOB in smbCalcSize() (Scott Mayhew) [RHEL-18990] {CVE-2023-6606}
- smb: client: fix potential OOB in smb2_dump_detail() (Scott Mayhew) [RHEL-19144] {CVE-2023-6610}
- smb: client: fix potential OOB in cifs_dump_detail() (Scott Mayhew) [RHEL-19144] {CVE-2023-6610}
- ovl: skip stale entries in merge dir cache iteration (Miklos Szeredi) [RHEL-18076]
- ovl: invalidate readdir cache on changes to dir with origin (Miklos Szeredi) [RHEL-18076]
- ipv6: avoid atomic fragment on GSO packets (Hangbin Liu) [RHEL-22149]
- ipv6: fix potential NULL deref in fib6_add() (Hangbin Liu) [RHEL-22149]
- lockdep: Fix block chain corruption (Joel Savitz) [RHEL-5227]
- futex: Don't include process MM in futex key on no-MMU (Joel Savitz) [RHEL-5227]
- locking/rtmutex: Fix task->pi_waiters integrity (Joel Savitz) [RHEL-5227]
- locking/rwsem: Add __always_inline annotation to __down_read_common() and inlined callers (Joel Savitz) [RHEL-5227]
- locking/rwsem: Disable preemption in all down_write*() and up_write() code paths (Joel Savitz) [RHEL-5227]
- mm: make generic arch_is_kernel_initmem_freed() do what it says (Joel Savitz) [RHEL-5227]

* Wed Jan 24 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-537.el8]
- cgroup/cpuset: Inherit parent's load balance state in v2 (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Free DL BW in case can_attach() fails (Waiman Long) [RHEL-12873]
- sched/deadline: Create DL BW alloc, free & check overflow interface (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Iterate only if DEADLINE tasks are present (Waiman Long) [RHEL-12873]
- sched/cpuset: Keep track of SCHED_DEADLINE task in cpusets (Waiman Long) [RHEL-12873]
- sched/cpuset: Bring back cpuset_mutex (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Rename functions dealing with DEADLINE accounting (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Skip task update if hotplug doesn't affect current cpuset (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Fix wrong check in update_parent_subparts_cpumask() (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Optimize cpuset_attach() on v2 (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Skip spread flags update on v2 (Waiman Long) [RHEL-12873]
- kselftest/cgroup: Add cpuset v2 partition root state test (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Update description of cpuset.cpus.partition in cgroup-v2.rst (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Make partition invalid if cpumask change violates exclusivity rule (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Relocate a code block in validate_change() (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Show invalid partition reason string (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Add a new isolated cpus.partition type (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Relax constraints to partition & cpus changes (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Allow no-task partition to have empty cpuset.cpus.effective (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Miscellaneous cleanups & add helper functions (Waiman Long) [RHEL-12873]
- cgroup: cleanup comments (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Avoid memory migration when nodemasks match (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Enable memory migration for cpuset v2 (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Enable event notification when partition state changes (Waiman Long) [RHEL-12873]
- doc/admin-guide/cgroup-v2: use tables (Waiman Long) [RHEL-12873]
- docs/admin-guide: cgroup-v2: fix cgroup.type rendering (Waiman Long) [RHEL-12873]
- docs: fix memory.low description in cgroup-v2.rst (Waiman Long) [RHEL-12873]
- cgroup/cpuset: Revert "Reduce cpuset_rwsem writer latency" (Waiman Long) [RHEL-12873]
- selftests/bpf: Workaround verification failure for fexit_bpf2bpf/func_replace_return_code (Artem Savkov) [RHEL-17256]
- mISDN: fix use-after-free bugs in l1oip timer handlers (Ricardo Robaina) [RHEL-2553 RHEL-2690] {CVE-2022-3565}
- firmware: dmi-sysfs: make pr_info messages rate limited (Prarit Bhargava) [RHEL-21096]
- xfs: short circuit xfs_growfs_data_private() if delta is zero (Andrey Albershteyn) [RHEL-19431]
- net-sysfs: add check for netdevice being present to speed_show (Michal Schmidt) [RHEL-16007]
- drm/mgag200: Fix gamma lut not initialized for G200ER, G200EV, G200SE (Jocelyn Falempe) [RHEL-21054]
- netfilter: nf_tables: bail out on mismatching dynset and set expressions (Florian Westphal) [RHEL-19014] {CVE-2023-6622}
- netfilter: nft_set_pipapo: skip inactive elements during set walk (Florian Westphal) [RHEL-19721] {CVE-2023-6817}
- ipv4: igmp: fix refcnt uaf issue when receiving igmp query packet (Hangbin Liu) [RHEL-19794] {CVE-2023-6932}
- s390/paes: fix PKEY_TYPE_EP11_AES handling for secure keyblobs (Tobias Huschle) [RHEL-22160]
- s390/dasd: protect device queue against concurrent access (Tobias Huschle) [RHEL-22161]
- s390/cmma: fix handling of swapper_pg_dir and invalid_pg_dir (Tobias Huschle) [RHEL-16317]
- s390/cmma: fix detection of DAT pages (Tobias Huschle) [RHEL-16317]
- s390/mm: add missing arch_set_page_dat() call to gmap allocations (Tobias Huschle) [RHEL-16317]
- s390/mm: add missing arch_set_page_dat() call to vmem_crst_alloc() (Tobias Huschle) [RHEL-16317]
- s390/cmma: fix initial kernel address space page table walk (Tobias Huschle) [RHEL-16317]
- s390/vfio-ap: do not reset queue removed from host config (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: reset queues associated with adapter for queue unbound from driver (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: reset queues filtered from the guest's AP config (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: let on_scan_complete() callback filter matrix and update guest's APCB (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: loop over the shadow APCB when filtering guest's AP configuration (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: always filter entire AP matrix (Cédric Le Goater) [RHEL-19575]
- KVM: s390: vsie: Fix STFLE interpretive execution identification (Cédric Le Goater) [RHEL-19575]
- KVM: s390: vsie: fix race during shadow creation (Cédric Le Goater) [RHEL-19575]
- KVM: s390: fix cc for successful PQAP (Cédric Le Goater) [RHEL-19575]
- KVM: s390: fix setting of fpc register (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: fix sysfs status attribute for AP queue devices (Cédric Le Goater) [RHEL-19575]
- s390/vfio-ap: unpin pages on gisc registration failure (Cédric Le Goater) [RHEL-19575]
- iommu/iova: Manage the depot list size (Jerry Snitselaar) [RHEL-10100]
- iommu/iova: Make the rcache depot scale better (Jerry Snitselaar) [RHEL-10100]
- iommu/iova: Optimize iova_magazine_alloc() (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove two WARN_ON in domain_context_mapping_one() (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Handle the failure case of dmar_reenable_qi() (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove BUG_ON in dmar_insert_dev_scope() (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove a useless BUG_ON(dev->is_virtfn) (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove BUG_ON in map/unmap() (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove BUG_ON when domain->pgd is NULL (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove BUG_ON in handling iotlb cache invalidation (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove BUG_ON on checking valid pfn range (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Make size of operands same in bitwise operations (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Do not use GFP_ATOMIC when not needed (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Remove PASID supervisor request support (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Use non-privileged mode for all PASIDs (Jerry Snitselaar) [RHEL-10100]
- iommu: Optimise PCI SAC address trick (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Use page mode macros in fetch_pte() (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Allocate IOMMU irqs using numa locality info (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Allocate page table using numa locality info (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Add a length limitation for the ivrs_acpihid command-line parameter (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Fix ill-formed ivrs_ioapic, ivrs_hpet and ivrs_acpihid options (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Do not allocate io_pgtable_ops for passthrough domain (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Fix error handling for pdev_pri_ats_enable() (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Fix compile error for unused function (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Improving Interrupt Remapping Table Invalidation (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Do not Invalidate IRT when IRTE caching is disabled (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Introduce Disable IRTE Caching Support (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Change macro for IOMMU control register bit shift to decimal value (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Remove the unused struct amd_ir_data.ref (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Switch amd_iommu_update_ga() to use modify_irte_ga() (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Handle GALog overflows (Jerry Snitselaar) [RHEL-10025]
- iommu/amd: Process all IVHDs before enabling IOMMU features (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Introduce global variable for storing common EFR and EFR2 (Jerry Snitselaar) [RHEL-10100]
- iommu/amd: Introduce Support for Extended Feature 2 Register (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Avoid memory allocation in iommu_suspend() (Jerry Snitselaar) [RHEL-10100]
- iommu/vt-d: Fix to flush cache of PASID directory table (Jerry Snitselaar) [RHEL-10100]
- of/address: Return an error when no valid dma-ranges are found (Jerry Snitselaar) [RHEL-10100]
- iommu/arm-smmu-qcom: Fix mask extraction for bootloader programmed SMRs (Jerry Snitselaar) [RHEL-10100]
- iommu/arm-smmu-qcom: Read back stream mappings (Jerry Snitselaar) [RHEL-10100]
- of: Fix "dma-ranges" handling for bus controllers (Jerry Snitselaar) [RHEL-10100]
- swiotlb: move slot allocation explanation comment where it belongs (Jerry Snitselaar) [RHEL-10100]
- swiotlb: fix debugfs reporting of reserved memory pools (Jerry Snitselaar) [RHEL-10100]
- iommu: fix MAX_ORDER usage in __iommu_dma_alloc_pages() (Jerry Snitselaar) [RHEL-1261]
- swiotlb: use the calculated number of areas (Jerry Snitselaar) [RHEL-1261]
- swiotlb: relocate PageHighMem test away from rmem_swiotlb_setup (Jerry Snitselaar) [RHEL-1261]
- swiotlb: reduce the number of areas to match actual memory pool size (Jerry Snitselaar) [RHEL-1261]
- swiotlb: always set the number of areas before allocating the pool (Jerry Snitselaar) [RHEL-1261]
- swiotlb: clean up some coding style and minor issues (Jerry Snitselaar) [RHEL-1261]
- iommu/amd: Fix DTE_IRQ_PHYS_ADDR_MASK macro (Jerry Snitselaar) [RHEL-1261]
- iommu/amd/iommu_v2: Clear pasid state in free path (Jerry Snitselaar) [RHEL-14152]
- iommu/amd/iommu_v2: Fix pasid_state refcount dec hit 0 warning on pasid unbind (Jerry Snitselaar) [RHEL-14152]
- iommu/amd: Don't block updates to GATag if guest mode is on (Jerry Snitselaar) [RHEL-1261]
- iommu/amd: Fix domain flush size when syncing iotlb (Jerry Snitselaar) [RHEL-1261]
- iommu/amd: Fix "Guest Virtual APIC Table Root Pointer" configuration in IRTE (Jerry Snitselaar) [RHEL-1261]
- iommu: Fix error unwind in iommu_group_alloc() (Jerry Snitselaar) [RHEL-1261]
- net/mlx5e: Fix error code in mlx5e_tc_action_miss_mapping_get() (Amir Tzin) [RHEL-924]
- net/mlx5: Fix fw tracer first block check (Amir Tzin) [RHEL-924]
- net/mlx5e: fix a potential double-free in fs_udp_create_groups (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix slab-out-of-bounds in mlx5_query_nic_vport_mac_list() (Amir Tzin) [RHEL-924]
- net/mlx5e: fix double free of encap_header (Amir Tzin) [RHEL-924]
- Revert "net/mlx5e: fix double free of encap_header" (Amir Tzin) [RHEL-924]
- Revert "net/mlx5e: fix double free of encap_header in update funcs" (Amir Tzin) [RHEL-924]
- net/mlx5e: fix double free of encap_header in update funcs (Amir Tzin) [RHEL-924]
- net/mlx5e: fix double free of encap_header (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix error codes in alloc_branch_attr() (Amir Tzin) [RHEL-924]
- net/mlx5e: Track xmit submission to PTP WQ after populating metadata map (Amir Tzin) [RHEL-924]
- net/mlx5e: Avoid referencing skb after free-ing in drop path of mlx5e_sq_xmit_wqe (Amir Tzin) [RHEL-924]
- net/mlx5e: Correct snprintf truncation handling for fw_version buffer used by representors (Amir Tzin) [RHEL-924]
- net/mlx5e: Correct snprintf truncation handling for fw_version buffer (Amir Tzin) [RHEL-924]
- net/mlx5: Fix a NULL vs IS_ERR() check (Amir Tzin) [RHEL-924]
- net/mlx5e: Check netdev pointer before checking its net ns (Amir Tzin) [RHEL-924]
- net/mlx5e: TC, Don't offload post action rule if not supported (Amir Tzin) [RHEL-924]
- net/mlx5e: Remove a useless function call (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix possible deadlock on mlx5e_tx_timeout_work (Amir Tzin) [RHEL-924]
- net/mlx5: Increase size of irq name buffer (Amir Tzin) [RHEL-924]
- net/mlx5e: Update doorbell for port timestamping CQ before the software counter (Amir Tzin) [RHEL-924]
- net/mlx5e: Add recovery flow for tx devlink health reporter for unhealthy PTP SQ (Amir Tzin) [RHEL-924]
- net/mlx5e: Make tx_port_ts logic resilient to out-of-order CQEs (Amir Tzin) [RHEL-924]
- net/mlx5e: Check return value of snprintf writing to fw_version buffer for representors (Amir Tzin) [RHEL-924]
- net/mlx5e: Check return value of snprintf writing to fw_version buffer (Amir Tzin) [RHEL-924]
- net/mlx5e: Reduce the size of icosq_str (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix pedit endianness (Amir Tzin) [RHEL-924]
- net/mlx5: Decouple PHC .adjtime and .adjphase implementations (Amir Tzin) [RHEL-924]
- IB/mlx5: Fix init stage error handling to avoid double free of same QP and UAF (Amir Tzin) [RHEL-924]
- IB/mlx5: Fix rdma counter binding for RAW QP (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix VF representors reporting zero counters to "ip -s" command (Amir Tzin) [RHEL-13397 RHEL-924]
- net/mlx5e: Don't offload internal port if filter device is out device (Amir Tzin) [RHEL-924]
- net/mlx5e: XDP, Fix XDP_REDIRECT mpwqe page fragment leaks on shutdown (Amir Tzin) [RHEL-924]
- net/mlx5: Handle fw tracer change ownership event based on MTRC (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, fix peer entry ageing in LAG mode (Amir Tzin) [RHEL-924]
- net/mlx5: E-switch, register event handler before arming the event (Amir Tzin) [RHEL-924]
- net/mlx5e: Again mutually exclude RX-FCS and RX-port-timestamp (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Fix NULL string error (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Fix mutex unlocking on error flow for steering anchor creation (Amir Tzin) [RHEL-924]
- net/mlx5: Free IRQ rmap and notifier on kernel shutdown (Amir Tzin) [RHEL-924]
- net/mlx5: Free irqs only on shutdown callback (Amir Tzin) [RHEL-924]
- net/mlx5: Improve naming of pci function vectors (Amir Tzin) [RHEL-924]
- net/mlx5e: Clear mirred devices array if the rule is split (Amir Tzin) [RHEL-924]
- net/mlx5: Dynamic cyclecounter shift calculation for PTP free running clock (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Fix trailing */ formatting in block comment (Amir Tzin) [RHEL-924]
- net/mlx5: Use RMW accessors for changing LNKCTL (Amir Tzin) [RHEL-924]
- net/mlx5: DR, Fix code indentation (Amir Tzin) [RHEL-924]
- net/mlx5: Fix error message in mlx5_sf_dev_state_change_handler() (Amir Tzin) [RHEL-924]
- net/mlx5e: Add capability check for vnic counters (Amir Tzin) [RHEL-924]
- net/mlx5e: Expose catastrophic steering error counters (Amir Tzin) [RHEL-924]
- net/mlx5: Skip clock update work when device is in error state (Amir Tzin) [RHEL-924]
- net/mlx5: LAG, Check correct bucket when modifying LAG (Amir Tzin) [RHEL-924]
- net/mlx5e: Unoffload post act rule when handling FIB events (Amir Tzin) [RHEL-924]
- net/mlx5: Allow 0 for total host VFs (Amir Tzin) [RHEL-924]
- net/mlx5: DR, Fix wrong allocation of modify hdr pattern (Amir Tzin) [RHEL-924]
- net/mlx5e: TC, Fix internal port memory leak (Amir Tzin) [RHEL-924]
- net/mlx5: Fix typo reminder -> remainder (Amir Tzin) [RHEL-924]
- net/mlx5: fs_core: Skip the FTs in the same FS_TYPE_PRIO_CHAINS fs_prio (Amir Tzin) [RHEL-924]
- net/mlx5: fs_core: Make find_closest_ft more generic (Amir Tzin) [RHEL-924]
- net/mlx5e: kTLS, Fix protection domain in use syndrome when devlink reload (Amir Tzin) [RHEL-924]
- net/mlx5e: Move representor neigh cleanup to profile cleanup_tx (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix crash moving to switchdev mode when ntuple offload is set (Amir Tzin) [RHEL-13501 RHEL-924]
- net/mlx5e: Don't hold encap tbl lock if there is no encap action (Amir Tzin) [RHEL-924]
- net/mlx5e: fix return value check in mlx5e_ipsec_remove_trailer() (Amir Tzin) [RHEL-924]
- net/mlx5: fix potential memory leak in mlx5e_init_rep_rx (Amir Tzin) [RHEL-924]
- net/mlx5: DR, fix memory leak in mlx5dr_cmd_create_reformat_ctx (Amir Tzin) [RHEL-924]
- net/mlx5e: Check for NOT_READY flag state after locking (Amir Tzin) [RHEL-924]
- net/mlx5: Register a unique thermal zone per device (Amir Tzin) [RHEL-924]
- net/mlx5e: fix memory leak in mlx5e_ptp_open (Amir Tzin) [RHEL-924]
- net/mlx5e: fix memory leak in mlx5e_fs_tt_redirect_any_create (Amir Tzin) [RHEL-924]
- net/mlx5e: fix double free in mlx5e_destroy_flow_table (Amir Tzin) [RHEL-924]
- net/mlx5: Fix reserved at offset in hca_cap register (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Fix Q-counters query in LAG mode (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Remove vport Q-counters dependency on normal Q-counters (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Fix Q-counters per vport allocation (Amir Tzin) [RHEL-924]
- net/mlx5: Drain health before unregistering devlink (Amir Tzin) [RHEL-924]
- net/mlx5: E-switch, Devcom, sync devcom events and devcom comp register (Amir Tzin) [RHEL-924]
- eth: mlx5: avoid iterator use outside of a loop (Amir Tzin) [RHEL-924]
- net/mlx5: Update op_mode to op_mod for port selection (Amir Tzin) [RHEL-924]
- net/mlx5: E-Switch, Remove redundant dev arg from mlx5_esw_vport_alloc() (Amir Tzin) [RHEL-924]
- Documentation: net/mlx5: Wrap notes in admonition blocks (Amir Tzin) [RHEL-924]
- Documentation: net/mlx5: Use bullet and definition lists for vnic counters description (Amir Tzin) [RHEL-924]
- Documentation: net/mlx5: Wrap vnic reporter devlink commands in code blocks (Amir Tzin) [RHEL-924]
- net/mlx5e: Add vnic devlink health reporter to representors (Amir Tzin) [RHEL-14659 RHEL-924]
- net/mlx5: Add vnic devlink health reporter to PFs/VFs (Amir Tzin) [RHEL-14659 RHEL-924]
- Revert "net/mlx5: Expose vnic diagnostic counters for eswitch managed vports" (Amir Tzin) [RHEL-14659 RHEL-924]
- Revert "net/mlx5: Expose steering dropped packets counter" (Amir Tzin) [RHEL-14659 RHEL-924]
- net/mlx5: Create a new profile for SFs (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, add tracepoints for multicast (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, implement mdb offload (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, support multicast VLAN pop (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, add per-port multicast replication tables (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, snoop igmp/mld packets (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, extract code to lookup parent bridge of port (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, move additional data structures to priv header (Amir Tzin) [RHEL-924]
- net/mlx5: Bridge, increase bridge tables sizes (Amir Tzin) [RHEL-924]
- net/mlx5: Add mlx5_ifc definitions for bridge multicast support (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix SQ SW state layout in SQ devlink health diagnostics (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix RQ SW state layout in RQ devlink health diagnostics (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Remove unused num_alloc_xa_entries variable (Amir Tzin) [RHEL-924]
- net/mlx5e: Rename misleading skb_pc/cc references in ptp code (Amir Tzin) [RHEL-924]
- net/mlx5: Update cyclecounter shift value to improve ptp free running mode precision (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Expand switchdev Q-counters to expose representor statistics (Amir Tzin) [RHEL-924]
- net/mlx5: Introduce other vport query for Q-counters (Amir Tzin) [RHEL-924]
- net/mlx5e: Fix build break on 32bit (Amir Tzin) [RHEL-924]
- net/mlx5: Set out of order (ooo) by default (Amir Tzin) [RHEL-924]
- RDMA/mlx5: Disable out-of-order in integrity enabled QPs (Amir Tzin) [RHEL-924]
- net/mlx5: Expose bits for enabling out-of-order by default (Amir Tzin) [RHEL-924]
- net/mlx5e: TC, Add support for VxLAN GBP encap/decap flows offload (Amir Tzin) [RHEL-897 RHEL-924]
- net/mlx5e: Add helper for encap_info_equal for tunnels with options (Amir Tzin) [RHEL-897 RHEL-924]
- net/mlx5e: Remove redundant include statement and adjust code to upstream. (Amir Tzin) [RHEL-924]
- net/mlx5e: Enable TC offload for egress MACVLAN over bond (Amir Tzin) [RHEL-924]
- net/mlx5e: Enable TC offload for ingress MACVLAN over bond (Amir Tzin) [RHEL-924]
- net/mlx5e: TC, Extract indr setup block checks to function (Amir Tzin) [RHEL-924]
- net/mlx5e: Add XSK RQ state flag for RQ devlink health diagnostics (Amir Tzin) [RHEL-924]
- net/mlx5e: Expose SQ SW state as part of SQ health diagnostics (Amir Tzin) [RHEL-924]
- net/mlx5e: Stringify RQ SW state in RQ devlink health diagnostics (Amir Tzin) [RHEL-924]
- net/mlx5e: Rename RQ/SQ adaptive moderation state flag (Amir Tzin) [RHEL-924]
- net/mlx5e: Utilize the entire fifo (Amir Tzin) [RHEL-924]
- net/mlx5: Implement thermal zone (Amir Tzin) [RHEL-924]
- net/mlx5: Stop waiting for PCI up if teardown was triggered (Amir Tzin) [RHEL-924]
- net/mlx5: remove redundant clear_bit (Amir Tzin) [RHEL-924]

* Thu Jan 18 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-536.el8]
- libbpf: Add LIBBPF_DEPRECATED_SINCE macro for scheduling API deprecations (Artem Savkov) [RHEL-10697]
- drm/amdgpu/sdma5.2: add begin/end_use ring callbacks (Michel Dänzer) [RHEL-19603]
- audit: fix possible soft lockup in __audit_inode_child() (Ricardo Robaina) [RHEL-9128]
- audit: correct audit_filter_inodes() definition (Ricardo Robaina) [RHEL-9128]
- usb: typec: ucsi: Use GET_CAPABILITY attributes data to set power supply scope (Desnes Nunes) [RHEL-14574]
- perf: Fix perf_event_validate_size() lockdep splat (Michael Petlan) [RHEL-17968]
- perf: Fix perf_event_validate_size() (Michael Petlan) [RHEL-17968] {CVE-2023-6931}
- Bluetooth: af_bluetooth: Fix Use-After-Free in bt_sock_recvmsg (Ricardo Robaina) [RHEL-20743] {CVE-2023-51779}
- md/raid1-10: limit the number of plugged bio (Nigel Croxon) [RHEL-19121]
- md/raid1-10: don't handle pluged bio by daemon thread (Nigel Croxon) [RHEL-19121]
- md/md-bitmap: add a new helper to unplug bitmap asynchrously (Nigel Croxon) [RHEL-19121]
- md/raid1-10: submit write io directly if bitmap is not enabled (Nigel Croxon) [RHEL-19121]
- md/raid1-10: factor out a helper to submit normal write (Nigel Croxon) [RHEL-19121]
- md/raid1-10: factor out a helper to add bio to plug (Nigel Croxon) [RHEL-19121]
- selftests/bpf: Workaround verification failure for fexit_bpf2bpf/func_replace_return_code (Felix Maurer) [RHEL-15938]
- bpf, sockmap: Reject sk_msg egress redirects to non-TCP sockets (Felix Maurer) [RHEL-15506]
- bpf, sockmap: Fix map type error in sock_map_del_link (Felix Maurer) [RHEL-15506]
- xsk: fix refcount underflow in error path (Felix Maurer) [RHEL-15506]
- bpf, cpumap: Make sure kthread is running before map update returns (Felix Maurer) [RHEL-15506]
- bpf: cpumap: Fix memory leak in cpu_map_update_elem (Felix Maurer) [RHEL-15506]
- page_pool: fix inconsistency for page_pool_ring_[un]lock() (Felix Maurer) [RHEL-15506]
- net: page_pool: use in_softirq() instead (Felix Maurer) [RHEL-15506]
- xsk: Fix unaligned descriptor validation (Felix Maurer) [RHEL-15506]
- Revert "x86/hyperv: fix logical processor creation" (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: fix logical processor creation (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Move the code in ivm.c around to avoid unnecessary ifdef's (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Remove hv_isolation_type_en_snp (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Use TDX GHCI to access some MSRs in a TDX VM with the paravisor (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: vmbus: Bring the post_msg_page back for TDX VMs with the paravisor (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Introduce a global variable hyperv_paravisor_present (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Add missing 'inline' to hv_snp_boot_ap() stub (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Mark hv_ghcb_terminate() as noreturn (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: vmbus: Support >64 VPs for a fully enlightened TDX/SNP VM (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Fix serial console interrupts for fully enlightened TDX guests (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: vmbus: Support fully enlightened TDX guests (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Support hypercalls for fully enlightened TDX guests (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Add hv_isolation_type_tdx() to detect TDX guests (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Fix undefined reference to isolation_type_en_snp without CONFIG_HYPERV (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Add hyperv-specific handling for VMMCALL under SEV-ES (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Add smp support for SEV-SNP guest (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: implement and use hv_smp_prepare_cpus (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Add VTL specific structs and hypercalls (Vitaly Kuznetsov) [RHEL-10110]
- clocksource: hyper-v: Mark hyperv tsc page unencrypted in sev-snp enlightened guest (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Use vmmcall to implement Hyper-V hypercall in sev-snp enlightened guest (Vitaly Kuznetsov) [RHEL-10110]
- drivers: hv: Mark percpu hvcall input arg page unencrypted in SEV-SNP enlightened guest (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: vmbus: Remove the per-CPU post_msg_page (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Mark Hyper-V vp assist page unencrypted in SEV-SNP enlightened guest (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Set Virtual Trust Level in VMBus init message (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Add sev-snp enlightened guest static key (Vitaly Kuznetsov) [RHEL-10110]
- x86/tdx: Do not corrupt frame-pointer in __tdx_hypercall() (Vitaly Kuznetsov) [RHEL-10110]
- x86/tdx: Expand __tdx_hypercall() to handle more arguments (Vitaly Kuznetsov) [RHEL-10110]
- x86/tdx: Refactor __tdx_hypercall() to allow pass down more arguments (Vitaly Kuznetsov) [RHEL-10110]
- x86/tdx: Add more registers to struct tdx_hypercall_args (Vitaly Kuznetsov) [RHEL-10110]
- x86/tdx: Fix typo in comment in __tdx_hypercall() (Vitaly Kuznetsov) [RHEL-10110]
- arm64/hyperv: Use CPUHP_AP_HYPERV_ONLINE state to fix CPU online sequencing (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Fix hyperv_pcpu_input_arg handling when CPUs go online/offline (Vitaly Kuznetsov) [RHEL-10110]
- PCI: hv: Replace retarget_msi_interrupt_params with hyperv_pcpu_input_arg (Vitaly Kuznetsov) [RHEL-10110]
- PCI: hv: Enable PCI pass-thru devices in Confidential VMs (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: Don't remap addresses that are above shared_gpa_boundary (Vitaly Kuznetsov) [RHEL-10110]
- hv_netvsc: Remove second mapping of send and recv buffers (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: vmbus: Remove second way of mapping ring buffers (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: vmbus: Remove second mapping of VMBus monitor pages (Vitaly Kuznetsov) [RHEL-10110]
- swiotlb: Remove bounce buffer remapping for Hyper-V (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Change vTOM handling to use standard coco mechanisms (Vitaly Kuznetsov) [RHEL-10110]
- init: Call mem_encrypt_init() after Hyper-V hypercall init is done (Vitaly Kuznetsov) [RHEL-10110]
- x86/mm: Handle decryption/re-encryption of bss_decrypted consistently (Vitaly Kuznetsov) [RHEL-10110]
- Drivers: hv: Explicitly request decrypted in vmap_pfn() calls (Vitaly Kuznetsov) [RHEL-10110]
- x86/hyperv: Reorder code to facilitate future work (Vitaly Kuznetsov) [RHEL-10110]
- x86/ioremap: Add hypervisor callback for private MMIO mapping in coco VM (Vitaly Kuznetsov) [RHEL-10110]
- x86/sev: Add SEV-SNP guest feature negotiation support (Vitaly Kuznetsov) [RHEL-10110]
- ALSA: update configuration for RHEL 8.10 (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdmi-codec: fix missing report for jack initial status (Jaroslav Kysela) [RHEL-13726]
- ALSA: pcm: fix out-of-bounds in snd_pcm_state_names (Jaroslav Kysela) [RHEL-13726]
- ALSA: cs35l41: Fix for old systems which do not support command (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Remove unnecessary boolean state variable firmware_running (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Add Pioneer DJM-450 mixer controls (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Enable headset on Lenovo M90 Gen5 (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: fix speakers on XPS 9530 (2023) (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Apply quirk for ASUS UM3504DA (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add supported ALC257 for ChromeOS (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Headset Mic VREF to 100%% (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda - Fix speaker and headset mic pin config for CHUWI CoreBook XPro (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirks for HP Laptops (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirks for ASUS 2024 Zenbooks (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Enable Mute LED on HP 255 G10 (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Enable Mute LED on HP 255 G8 (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - Add Dell ALC295 to pin fall back table (Jaroslav Kysela) [RHEL-13726]
- ALSA: info: Fix potential deadlock at disconnection (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: ASUS UM5302LA: Added quirks for cs35L41/10431A83 on i2c bus (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add support dual speaker for Dell (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8540: Add self recovery to improve capture quility (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdmi-codec: register hpd callback on component probe (Jaroslav Kysela) [RHEL-13726]
- ASoC: dapm: fix clock get name (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Add ASRock X670E Taichi to denylist (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS UX7602ZM (Jaroslav Kysela) [RHEL-13726]
- ASoC: da7219: Improve system suspend and resume handling (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt712-sdca: fix speaker route missing issue (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Fix missing error code in cs35l41_smart_amp() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: mark cs35l41_verify_id() static (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Add missing check with firmware version control (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Remap Level Meter values (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Allow passing any output to line_out_remap() (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Add support for reading firmware version (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Rename Gen 3 config sets (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Rename scarlett_gen2 to scarlett2 (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Detect CSPL errors when sending CSPL commands (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Check CSPL state after loading firmware (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Do not unload firmware before reset in system suspend (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Force a software reset after hardware reset (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Run boot process during resume callbacks (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Assert Reset prior to de-asserting in probe and system resume (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Assert reset before system suspend (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Use reset label to get GPIO for HP Zbook Fury 17 G9 (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: Skylake: Fix mem leak when parsing UUIDs fails (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: add quirk flag to enable native DSD for McIntosh devices (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt298: remove redundant assignment to d_len_code (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: sof-pci-dev: Fix community key quirk detection (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Stop processing CODECs when enough are found (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: intel-dsp-config: Fix JSL Chromebook quirk detection (Jaroslav Kysela) [RHEL-13726]
- ASoC: da7213: Add new kcontrol for tonegen (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - Fixed ASUS platform headset Mic issue (Jaroslav Kysela) [RHEL-13726]
- ASoC: da7219: Correct the process of setting up Gnd switch in AAD (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15s-fq5xxx (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG GU603ZV (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5650: fix the wrong result of key button (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt715: reorder the argument in error log (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt715-sdca: reorder the argument in error log (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw_rt712_sdca: construct cards->components by name_prefix (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: add rt713 support (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt713 rt1316 config (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi-intel-rpl-match: add rt711-l0-rt1316-l12 support (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: update HP Omen match (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l42: Fix missing include of gpio/consumer.h (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: core: Ensure sof_ops_free() is still called when probe never ran. (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Add Focusrite Clarett 2Pre and 4Pre USB support (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Fix microphone sound on Nexigo webcam. (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Change model for Intel RVP board (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Fix microphone sound on Opencomm2 Headset (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Cleanup and fix double free in firmware request (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682: Fix regulator enable/disable sequence (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdmi-codec: Fix broken channel map reporting (Jaroslav Kysela) [RHEL-13726]
- ASoC: core: Do not call link_exit() on uninitialized rtd objects (Jaroslav Kysela) [RHEL-13726]
- ASoC: core: Print component name when printing log (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82YM (Jaroslav Kysela) [RHEL-13726]
- ALSA: aloop: Add control element for getting the access mode (Jaroslav Kysela) [RHEL-13726]
- ALSA: aloop: Add support for the non-interleaved access mode (Jaroslav Kysela) [RHEL-13726]
- ALSA: intel8x0m: fix name of SIS7013 sound chip in comment (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: fix for firmware reload failure after playback (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Add Focusrite Clarett+ 2Pre and 4Pre support (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-generic-dmaengine-pcm: Fix function name in comment (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Add read-only ALSA control for forced mute (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Support mute notifications for CS35L41 HDA (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Support ACPI Notification framework via component binding (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Add notification support into component binding (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - ALC287 merge RTK codec with CS CS35L41 AMP (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdac_hda: fix HDA patch loader support (Jaroslav Kysela) [RHEL-13726]
- soundwire: bus: Make IRQ handling conditionally built (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm.c: Make sure DAI parameters cleared if the DAI becomes inactive (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add support for SKU 0B14 (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: fix Dell SKU 0B34 (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdac_hda: add HDA patch loader support (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - ALC287 Realtek I2S speaker platform support (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: scarlett_gen2: Fix another -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Use size_add() in call to struct_size() (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: MTL: Reduce the DSP init timeout (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: core: Only call sof_ops_free() on remove if the probe was successful (Jaroslav Kysela) [RHEL-13726]
- ALSA: riptide: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13726]
- ALSA: cs4231: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13726]
- ALSA: ad1848: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: generic: Check potential mixer name string truncation (Jaroslav Kysela) [RHEL-13726]
- ALSA: cmipci: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: firewire: Fix -Wformat-truncation warning for MIDI stream names (Jaroslav Kysela) [RHEL-13726]
- ALSA: firewire: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13726]
- ALSA: xen: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: opti9x: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: es1688: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: cs4236: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: sscape: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: caiaq: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: scarlett_gen2: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13726]
- ASoC: imx-audmix: Fix return error with devm_clk_get() (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdaudio.c: Add missing check for devm_kstrdup (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Add correct product series name to messages (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Add support for Clarett 8Pre USB (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Move USB IDs out from device_info struct (Jaroslav Kysela) [RHEL-13726]
- ALSA: scarlett2: Default mixer driver to enabled (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: fix wrong sizeof argument (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: sof-audio: Fix DSP core put imbalance on widget setup failure (Jaroslav Kysela) [RHEL-13726]
- firmware: cirrus: cs_dsp: Only log list of algorithms in debug build (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l42: Avoid stale SoundWire ATTACH after hard reset (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l42: Don't rely on GPIOD_OUT_LOW to set RESET initially low (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l42: Ensure a reset pulse meets minimum pulse width. (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: mixer: Remove temporary string use in parse_clock_source_unit (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Splitting the UX3402 into two separate models (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: intel-sdw-acpi: Use u8 type for link index (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Only cancel jack-detect work on suspend if active (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Fix IRQ not being free-ed for HDA jack detect mode (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Enable the IRQ on resume after configuring jack-detect (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Do not disable/enable IRQ twice on suspend/resume (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Fix sleep in atomic context (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Revert "Fix sleep in atomic context" (Jaroslav Kysela) [RHEL-13726]
- ALSA: core: Use dev_name of card_dev as debugfs directory name (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - Fixed two speaker platform (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82QF and 82UG (Jaroslav Kysela) [RHEL-13726]
- Add DMI ID for MSI Bravo 15 B7ED (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm: Shrink stack frame for __soc_pcm_hw_params (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Consistently use dev_err_probe() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Undo runtime PM changes at driver exit time (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Fix unbalanced pm_runtime_get() (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Make use of dev_err_probe() (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Undo runtime PM changes at driver exit time (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Verify PM runtime resume errors in IRQ handler (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Fix broken shared boost activation (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Handle mdsync_up reg write errors (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Handle mdsync_down reg write errors (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Disable power save for solving pop issue on Lenovo ThinkCentre M70q (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82TL (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - ALC287 I2S speaker platform support (Jaroslav Kysela) [RHEL-13726]
- regmap: debugfs: Fix a erroneous check after snprintf() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/cirrus: Fix broken audio on hardware with two CS42L42 codecs. (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5645: NULL pointer access when removing jack (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Add DMI entries to support Victus by HP Gaming Laptop 15-fb0xxx (8A3E) (Jaroslav Kysela) [RHEL-13726]
- ALSA: pcm: Fix missing fixup call in compat hw_refine ioctl (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Don't try to submit URBs after disconnection (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-core.c: Do not error if a DAI link component is not found (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for mute LEDs on HP ENVY x360 15-eu0xxx (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82SJ (Jaroslav Kysela) [RHEL-13726]
- ALSA: ymfpci: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Override the _DSD for HP Zbook Fury 17 G9 to correct boost type (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for HP Victus 16-d1xxx to enable mute LED (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs35l41: Correct amp_gain_tlv values (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: clear dsp to host interrupt status (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: clear panic mask status when panic occurs (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: add conditional check for acp_clkmux_sel register (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: remove redundant clock mux selection register write (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: enable ACP external global interrupt (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: remove unused sha dma interrupt code (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: Fix possible error value of *rac97 (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Add module parameter to ignore the CPC value (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Modify the reference output valid_bits for copier (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Fix pipeline params at the output of copier (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Fix the output reference params for SRC (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Modify pipeline params based on SRC output format (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Fix init call orders for UAC1 (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: fix typos (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Add VivoBook Pro 15 to quirks list for acp6x (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: Add kcontrols and widgets per-codec in common code (Jaroslav Kysela) [RHEL-13726]
- ALSA: aoa: Fix typos in PCM fix patch (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5645: improve the depop sequences of CBJ detection (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682s: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5668: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5665: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Convert to just use GPIO descriptors (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: change cs35l41_prop_model to static (Jaroslav Kysela) [RHEL-13726]
- ALSA: core: Drop snd_device_initialize() (Jaroslav Kysela) [RHEL-13726]
- ALSA: seq: Create device with snd_device_alloc() (Jaroslav Kysela) [RHEL-13726]
- ALSA: timer: Create device with snd_device_alloc() (Jaroslav Kysela) [RHEL-13726]
- ALSA: compress: Don't embed device (Jaroslav Kysela) [RHEL-13726]
- ALSA: rawmidi: Don't embed device (Jaroslav Kysela) [RHEL-13726]
- ALSA: hwdep: Don't embed device (Jaroslav Kysela) [RHEL-13726]
- ALSA: pcm: Don't embed device (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Don't embed ctl_dev (Jaroslav Kysela) [RHEL-13726]
- ALSA: core: Introduce snd_device_alloc() (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-pcm: fix possible null pointer deference (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Fix the loop check in cs35l41_add_dsd_properties (Jaroslav Kysela) [RHEL-13726]
- firmware: cs_dsp: Fix new control name check (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Support systems with missing _DSD properties (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: intel-dsp-cfg: Add Chromebook quirk to ADL/RPL (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - Remodified 3k pull low procedure (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: topology: Add a token for dropping widget name in kcontrol name (Jaroslav Kysela) [RHEL-13726]
- ASoC: dapm: Add a flag for not having widget name in kcontrol name (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: Refactor code for HDA stream creation (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: add support for Dell SKU0C87 devices (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt715: Drop GPIO includes (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682-sdw: Drop GPIO includes (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5660: Drop GPIO includes (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5659: Drop legacy GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5645: Drop legacy GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5514: Drop GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5514-spi: Drop GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1308: Drop GPIO includes (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1305: Drop GPIO includes (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1019: Drop GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1016: Drop GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1015p: Drop legacy GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1015: Drop GPIO include (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1011: Drop GPIO includes (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-jack: calling snd_soc_jack_report causes a null pointer access (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/cs8409: Support new Dell Dolphin Variants (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1308-sdw: fix random louder sound (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc3: Use devm_kmemdup to replace devm_kmalloc + memcpy (Jaroslav Kysela) [RHEL-13726]
- ASoC: tas5805m: Use devm_kmemdup to replace devm_kmalloc + memcpy (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt715: Add software reset in io init (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: Initialize chip in hda_sdw_check_wakeen_irq() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Switch Dell Oasis models to use SPI (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirks for HP G11 Laptops (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Update the basecfg for copier earlier (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Simplify get_slave_info (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Allow different devices on the same link (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Support multiple groups on the same link (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Device loop should not always start at adr_index (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Move range check of codec_conf into inner loop (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Update DLC index each time one is added (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Pull device loop up into create_sdw_dailink (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Add helper to create a single codec DLC (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof-sdw: Move check for valid group id to get_dailink_info (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Check link mask validity in get_dailink_info (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Remove duplicate NULL check on adr_link (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Printk's should end with a newline (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: intel: hda: Clean up link DMA for IPC3 during stop (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof-sdw-cs42142: fix for codec button mapping (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-mlink: add sublink to dev_dbg() log (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: IPC4: clarify 'pipeline_ids' usage and logs (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: add abstraction for SoundWire wake-ups (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai-ops: only allocate/release streams for first CPU DAI (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: restore gateway config length (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4: avoid uninitialized default instance 0 (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: fix u16/32 confusion in LSDIID (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-mlink: fix off-by-one error (Jaroslav Kysela) [RHEL-13726]
- ALSA: info: Remove unused function declarations (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Fix incorrect use of sizeof in sof_ipc3_do_rx_work() (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp3x-rt5682-max9836: Configure jack as not detecting Line Out (Jaroslav Kysela) [RHEL-13726]
- soundwire: bus: Allow SoundWire peripherals to register IRQ handlers (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-acpi: Add missing kernel doc (Jaroslav Kysela) [RHEL-13726]
- soundWire: intel_auxdevice: resume 'sdw-master' on startup and system resume (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel_auxdevice: enable pm_runtime earlier on startup (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Add support for Mythware XA001AU capture and playback interfaces. (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_da7219_max98373: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: kbl_da7219_max98927: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: kbl_da7219_max98357a: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: bytcr_wm5102: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: bxt_da7219_max98357a: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs: da7219: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp3x-rt5682-max9836: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp-rt5645: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp-da7219-max98357a: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13726]
- ASoC: max98373-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: max98363: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1318-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1316-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1308-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt715-sdca: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt715: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt712-sdca-dmic: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1712-sdca: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt700: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt711-sdca: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt711: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682-sdw: make regmap cache-only in probe (Jaroslav Kysela) [RHEL-13726]
- ASoC: SoundWire codecs: make regmap cache-only in probe (Jaroslav Kysela) [RHEL-13726]
- ASoC: SoundWire codecs: return error status in probe (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/i915: extend connectivity check to cover Intel ARL (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: intel-dsp-cfg: use common include for MeteorLake (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: add HD Audio PCI ID for Intel Arrow Lake-S (Jaroslav Kysela) [RHEL-13726]
- PCI: add ArrowLake-S PCI ID for Intel HDAudio subsystem. (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Print amp configuration after bind (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: set variables dev_attr_vendor_id to static (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5665: add missed regulator_bulk_disable (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Remove unused function declaration (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Move group_generated logic (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Merge codec_conf_alloc into dailink_info (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Clean up DAI link counting (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Allow direct specification of CODEC name (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: break earlier when a adr link contains different codecs (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Move amp_num initialisation to mc_probe (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Remove redundant parameters in dai creation (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Minor tidy up of mc_probe (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Constify parameter to find_codec_part_info (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Simplify find_codec_info_acpi (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Remove some extra line breaks (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Rename codec_idx to codec_dlc_index (Jaroslav Kysela) [RHEL-13726]
- ASoC: intel: sof_sdw: Use consistent variable naming for links (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add support for SKU 0AFE (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: rename link_id to be_id (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: allow mockup amplifier to provide feedback (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: reorder SoundWire codecs in Kconfig (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw at link 0 in RPL match table (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp5x-mach:add checks to avoid static analysis warnings (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: atom: remove static analysis false positive (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: bdw_rt286: add checks to avoid static analysis warnings (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: topology: simplify code to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc3: add checks to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: sof-client-probes-ipc4: add checks to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Deprecate invalid enums in IPC3 (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc3: update dai_link_fixup for SOF_DAI_MEDIATEK_AFE (Jaroslav Kysela) [RHEL-13726]
- ASoC: 88pm860x: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13726]
- ASoC: fsl_micfil: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13726]
- ALSA: bcd2000: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13726]
- ALSA: xen-front: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Support ASUS G713PV laptop (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Update for native DSD support quirks (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt1316: fix key tone missing (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l51: change cs42l51_of_match to static (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc3-dtrace: Switch to memdup_user_nul() helper (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/relatek: Enable Mute LED on HP 250 G8 (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Add quirk for Microsoft Modern Wireless Headset (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Ensure amp is only unmuted during playback (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Add device_link between HDA and cs35l41_hda (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Rework System Suspend to ensure correct call separation (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Use pre and post playback hooks (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: hda_component: Add pre and post playback hooks to hda_component (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Move Play and Pause into separate functions (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Ensure we pass up any errors during system suspend. (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Ensure we correctly re-sync regmap before system suspending. (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Check mailbox status of pause command after firmware load (Jaroslav Kysela) [RHEL-13726]
- ALSA: cs35l41: Poll for Power Up/Down rather than waiting a fixed delay (Jaroslav Kysela) [RHEL-13726]
- ALSA: cs35l41: Use mbox command to enable speaker output for external boost (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: add HDMI codec ID for Intel LNL (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/hdmi: keep codec entries in numerical order (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Fix missing header dependencies (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt712-sdca: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt711-sdca: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt711: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682-sdw: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13726]
- ASoC: wm8960: Add DAC filter characteristics selection (Jaroslav Kysela) [RHEL-13726]
- ALSA: ice1712: Use the standard snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13726]
- ALSA: ca0106: Use the standard snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: Use the standard snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13726]
- ALSA: vmaster: Add snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: cmipci: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: via82xx: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: maestro3: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: ice1712: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: es1968: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: cs46xx: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: ca0106: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Introduce snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add support for DELL Oasis 13/14/16 laptops (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Fix generic fixup definition for cs35l41 amp (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8821: Add DMI quirk mechanism for active-high jack-detect (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: fix SND_SOC_AMD_ACP_PCI depdenencies (Jaroslav Kysela) [RHEL-13726]
- ASoc: codecs: ES8316: Fix DMIC config (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 15s-eq2xxx (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for Clevo NS70AU (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: Go back and simplify with snd_ctl_find_id() (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Take lock in snd_ctl_find_id() and snd_ctl_find_numid() (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Introduce unlocked version for snd_ctl_find_*() helpers (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Make snd_ctl_find_id() argument const (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Add lockdep warning to internal functions (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Take controls_rwsem lock in snd_ctl_remove() (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Take card->controls_rwsem in snd_ctl_rename() (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: delete unnecessary NULL check (Jaroslav Kysela) [RHEL-13726]
- ASoC: da7219: Check for failure reading AAD IRQ events (Jaroslav Kysela) [RHEL-13726]
- ASoC: da7219: Flush pending AAD IRQ when suspending (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sst: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: Skylake: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ALSA: intel-dsp-config: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: Skylake: Use global PCI match macro (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/i915: Use global PCI match macro (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Use global PCI match macro (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Add controller matching macros (Jaroslav Kysela) [RHEL-13726]
- ALSA: Remove unused Broxton PCI ID (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Remove unused Broxton PCI ID (Jaroslav Kysela) [RHEL-13726]
- PCI: Add Intel Audio DSP devices to pci_ids.h (Jaroslav Kysela) [RHEL-13726]
- PCI: Sort Intel PCI IDs by number (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: ES8326: Update jact detection function (Jaroslav Kysela) [RHEL-13726]
- ASOC: codecs: ES8326: Add calibration support for version_b (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: ES8326: Fix power-up sequence (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: ES8326: Change Volatile Reg function (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: ES8326: Change Hp_detect register names (Jaroslav Kysela) [RHEL-13726]
- tools include UAPI: Sync the sound/asound.h copy with the kernel sources (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: ES8326: Add es8326_mute function (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l51: fix driver to properly autoload with automatic module loading (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-dai: don't call PCM audio ops if the stream is not supported (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek - remove 3k pull low procedure (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: clean up some inconsistent indentings (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Fix the issue of speaker noise (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: Add new dmi entries to config entry (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: Add acpi machine id's for vangogh platform (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: Add machine driver support for max98388 codec (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: Add machine driver support for nau8821 codec (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc3-dtrace: uninitialized data in dfsentry_trace_filter_write() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG GZ301V (Jaroslav Kysela) [RHEL-13726]
- ALSA: jack: Fix mutex call in snd_jack_report() (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: vangogh: Use dmi_first_match() for DMI quirk handling (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: vangogh: Make use of DRV_NAME (Jaroslav Kysela) [RHEL-13726]
- ASoC: core: suppress probe deferral errors (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: suppress probe deferral errors (Jaroslav Kysela) [RHEL-13726]
- soundwire: fix enumeration completion (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5645: add the system level suspend-resume callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5645: check return value after reading device id (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5645: implement set_jack callback (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Whitespace fix (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG G614Jx (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Amend G634 quirk to enable rear speakers (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG GA402X (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG GX650P (Jaroslav Kysela) [RHEL-13726]
- ALSA: pcm: Fix potential data race at PCM memory allocation helpers (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: fix a possible null-pointer dereference due to data race in snd_hdac_regmap_sync() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirks for Unis H3C Desktop B760 & Q760 (Jaroslav Kysela) [RHEL-13726]
- ASoC: stac9766: fix build errors with REGMAP_AC97 (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5677: Sort headers alphabetically (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5677: Use device_get_match_data() (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5677: Use agnostic irq_domain_create_linear() (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5677: Refactor GPIO support code (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: refactor PSP smn_read (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: add revision check for sending sha dma completion command (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: es8316: Add support for S24_3LE format (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: es8316: Add support for 24 MHz MCLK (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5640: Fix sleep in atomic context (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for Clevo NPx0SNx (Jaroslav Kysela) [RHEL-13726]
- soundwire: amd: Fix a check for errors in probe() (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: add pm ops support for rembrandt platform (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: move pdm macros to common header file (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: store the pdm stream channel mask (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: export config_acp_dma() and config_pte_for_stream() symbols (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: store xfer_resolution of the stream (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: add pm ops support for acp pci driver (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: store platform device reference created in pci probe call (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: remove the redundant acp enable/disable interrupts functions (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: add acp i2s master clock generation for rembrandt platform (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: refactor the acp init and de-init sequence (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: fix for invalid dai id handling in acp_get_byte_count() (Jaroslav Kysela) [RHEL-13726]
- ASoC: hdmi-codec: fix channel info for compressed formats (Jaroslav Kysela) [RHEL-13726]
- ALSA: pcm: fix ELD constraints for (E)AC3, DTS(-HD) and MLP formats (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: update pm_runtime enable sequence (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-dapm.h: Convert macros to return a compound literal (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: remove acp poweroff function (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: acp: clear pdm dma interrupt mask (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirks for ROG ALLY CS35l41 audio (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs43130: Fix numerator/denominator mixup (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG GV601V (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-core.c: cleanup soc_dai_link_sanity_check() (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-core.c: initialize dlc on snd_soc_get_dai_id() (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add quirk for ASUS ROG G634Z (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-compress: Fix deadlock in soc_compr_open_fe (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5677: Add MODULE_FIRMWARE macro (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: wm0010: Add MODULE_FIRMWARE macros (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: mtl: setup primary core info on MeteorLake platform (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: pm: Remove duplicated code in sof_suspend (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4: Switch to use the sof_debug:bit11 to dump message payload (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc3: Dump IPC message payload (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Add new sof_debug flag to request message payload dump (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: core: Free the firmware trace before calling snd_sof_shutdown() (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: sof-audio: test virtual widget in sof_walk_widgets_in_order (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: sof-audio: add is_virtual_widget helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_rt5682: Add mtl support RT1019P speaker (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_rt5682: reorder quirk table (Jaroslav Kysela) [RHEL-13726]
- soundwire: stream: Make master_list ordered to prevent deadlocks (Jaroslav Kysela) [RHEL-13726]
- soundwire: bus: Prevent lockdep asserts when stream has multiple buses (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: Fix possible NULL dereference in snd_ac97_mixer (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Add quirk flag for HEM devices to enable native DSD playback (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: Add support for IPC with a reply_size set to zero (Jaroslav Kysela) [RHEL-13726]
- ALSA: timer: minimize open-coded access to hw.resolution (Jaroslav Kysela) [RHEL-13726]
- ALSA: usb-audio: Fix broken resume due to UAC3 power state (Jaroslav Kysela) [RHEL-13726]
- ALSA: seq: oss: Fix racy open/close of MIDI devices (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-ssm4567: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-rt5682: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-rt298: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-rt286: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-rt274: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-nau8825: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-max98927: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-max98373: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-max98357a: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-hdaudio: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-dmic: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: avs-da7219: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13726]
- ASoC: max98363: Remove cache defaults for volatile registers (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Add a quirk for Compaq N14JP6 (Jaroslav Kysela) [RHEL-13726]
- ASoC: audio-graph-card2-custom-sample: add missing CPU:Codec = 1:N sample (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Refactor rx function for fuzzing (Jaroslav Kysela) [RHEL-13726]
- ASoC: max98088: clean up some inconsistent indenting (Jaroslav Kysela) [RHEL-13726]
- ASoC: remove old trigger ordering method (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: use use new trigger ordering method (Jaroslav Kysela) [RHEL-13726]
- ASoC: add new trigger ordering method (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/intel: Workaround for WALLCLK register for loongson controller (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Workaround for SDnCTL register on loongson (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Using polling mode for loongson controller by default (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: Add Loongson LS7A HD-Audio support (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add dai_link_codec_ch_map (Jaroslav Kysela) [RHEL-13726]
- ASoC: add N cpus to M codecs dai link support (Jaroslav Kysela) [RHEL-13726]
- soundwire: debugfs: Add missing SCP registers (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-pcm: remove kernel parameter init (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: fix SoundWire/HDaudio mutual exclusion (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda/realtek: Delete cs35l41 component master during free (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Fix endian conversions (Jaroslav Kysela) [RHEL-13726]
- ALSA: hda: cs35l41: Clean up Firmware Load Controls (Jaroslav Kysela) [RHEL-13726]
- ALSA: control: Keep the previous numid at snd_ctl_rename_id() (Jaroslav Kysela) [RHEL-13726]
- firmware: cs_dsp: Log correct region name in bin error messages (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda: add helper to extract SoundWire link count (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: mtl: prepare for code reuse (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: add DMA config TLV to IPC data (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: introduce DMA config TLV (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: extend ALH-specific data structure (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: add get_hlink callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: add calc_stream_format callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: add codec_dai_set_stream callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: add error checks to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: add Rex CS42l42 and MAX98363 SoundWire entries (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: Add support for Rex soundwire (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: Add support for MAX98363 codec (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: Modify maxim helper functions and structure names (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: Rename sof_sdw_max98373.c file to sof_sdw_maxim.c (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: Add helper function for cs42l42 codec (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: Sof_ssp_amp: Correcting author name. (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: ADL: Moving amp only boards into end of the table. (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: ADL: Enable HDMI-In capture feature support for non-I2S codec boards. (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof-sdw: add Dell SKU 0B34 (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: add tables for Dell SKU 0B34 (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add quick for Dell SKU 0BDA (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: add table for RPL Dell SKU 0BDA (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: increase sdw pin index for each sdw link (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add rt713 support (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt712 ID (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi-intel-tgl-match: add rt712 ID (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add rt712 support (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: make rt711_sdca be generic (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: rename SOF_RT711_JDSRC to SOF_JACK_JDSRC (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: test SOF_JACK_JDSRC in _exit (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add multi dailink support for a codec (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sdw_sof: append dai_type and remove codec_type (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add codec_info pointer (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: use predefine dailink id (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add dai info (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add missing exit callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG (Jaroslav Kysela) [RHEL-13726]
- soundwire: stream: Remove unnecessary gotos (Jaroslav Kysela) [RHEL-13726]
- soundwire: stream: Invert logic on runtime alloc flags (Jaroslav Kysela) [RHEL-13726]
- soundwire: stream: Remove unneeded checks for NULL bus (Jaroslav Kysela) [RHEL-13726]
- soundwire: bandwidth allocation: Remove pointless variable (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8825: Update output control for NAU8825C (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8825: Update the calculation of FLL for NAU8825C (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8825: Add registers patch for NAU8825C (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc.h: remove snd_soc_compr_ops :: trigger (Jaroslav Kysela) [RHEL-13726]
- ASoC: add snd_soc_get_stream_cpu() (Jaroslav Kysela) [RHEL-13726]
- firmware: cs_dsp: Log that a bin file was loaded (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8825: Add the management of headset detection for power saving (Jaroslav Kysela) [RHEL-13726]
- ASoC: es8316: Do not set rate constraints for unsupported MCLKs (Jaroslav Kysela) [RHEL-13726]
- ASoC: es8316: Increment max value for ALC Capture Target Volume control (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: vangogh: Add check for acp config flags in vangogh platform (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm.c: tidyup playback/capture_only at soc_get_playback_capture() (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm.c: use temporary variable at soc_get_playback_capture() (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm.c: cleanup soc_get_playback_capture() error (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm.c: use dai_link on soc_get_playback_capture() (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-pcm.c: indicate error if stream has no playback no capture (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: HDA: Limit the number of dai drivers for nocodec mode (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: topology: Use partial match for connecting DAI link and DAI widget (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: Allow partial matching when finding DAI link (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l42: Add PLL ratio table values (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: tgl: unify core_put on IPC3 & IPC4 path (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: mtl: add core_get & put support on MeterLake platforms (Jaroslav Kysela) [RHEL-13726]
- ASoC: nau8825: Add pre-charge actions for input (Jaroslav Kysela) [RHEL-13726]
- ALSA: rawmidi: Pass rawmidi directly to snd_rawmidi_kernel_open() (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: amd: Add pci revision id check (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-loader/topology: Query the CPC value from manifest (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Do not use the CPC value from topology (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Rename sof_ipc4_update_pipeline_mem_usage() to be generic (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-loader: Save a pointer to fm_config in sof_ipc4_fw_module (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-loader: Drop unused bss_size from struct sof_ipc4_fw_module (Jaroslav Kysela) [RHEL-13726]
- ASoC: stm32: sai: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5682s: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: rt5659: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs53l30: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: cs42l51: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: adau1761: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13726]
- ALSA: mixart: Replace one-element arrays with simple object declarations (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: Remove redundant log (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: Remove redundant log (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: Do not split message string on multiple lines (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: Remove redundant logs (Jaroslav Kysela) [RHEL-13726]
- ASoC: topology: Log control load errors in soc_tplg_control_load() (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: Fix locking in hda_ipc4_pre_trigger() (Jaroslav Kysela) [RHEL-13726]
- soundwire: amd: Improve error message in remove callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt715: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt715-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt712-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt712-sdca-dmic: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt711: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt711-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt700: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt5682: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt1318: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt1316: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- ASoC: codecs: rt1308: do not store status in state container (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel_bus_common: update error log (Jaroslav Kysela) [RHEL-13726]
- soundwire: cadence: revisit parity injection (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel/cadence: update hardware reset sequence (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel_bus_common: enable interrupts last (Jaroslav Kysela) [RHEL-13726]
- soundwire: debugfs: fix unbalanced pm_runtime_put() (Jaroslav Kysela) [RHEL-13726]
- ALSA: compat_ioctl: use correct snd_ctl_elem_type_t type (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Fix an unsigned comparison which can never be negative (Jaroslav Kysela) [RHEL-13726]
- soundwire: qcom: drop unused struct qcom_swrm_ctrl members (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-pcm: reset all pipelines during FE DAI hw_free (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai-ops: Split the get_hext_stream() op for IPC4 (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Modify input audio format selection logic (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: New helper to check if all output formats are the same (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Modify the output format selection logic (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Add a new helper function to get the valid bits (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Handle output format special case (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Rename sof_ipc4_init_audio_fmt() (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Move the call to init output format (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Add a helper function for output format selection (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Handle input/output audio format special case (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel: read AC timing control register before updating it (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel: use substream for .free callback (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel: remove .free callback implementation (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel: use substream for .trigger callback (Jaroslav Kysela) [RHEL-13726]
- soundwire: intel: remove .trigger callback implementation (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF/soundwire: re-add substream in params_stream structure (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: remove mutual exclusion between NOCODEC and HDA_LINK (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: use HDA_LINK instead of HDA_AUDIO_CODEC (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: mark functions as __maybe_unused (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: move hda_dai_prepare() code (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: Kconfig: move selection of PROBE_WORK_QUEUE (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: clarify initialization when HDA_AUDIO_CODEC is not used (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: fix DAI number mismatch (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: remove use of cpu_dai->component drvdata (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Intel: hda-dai: simplify .prepare callback (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: add tables for LunarLake (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add new mapping for HP Spectre x360 (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: start set codec init function with an adr index (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: soc-acpi: add support for MTL SDCA boards (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: add quirk for MTL RVP (Jaroslav Kysela) [RHEL-13726]
- ASoC: Intel: sof_sdw: remove SOF_SDW_TGL_HDMI for MeteorLake devices (Jaroslav Kysela) [RHEL-13726]
- ASoC: wm_adsp: Update to use new component control notify helepr (Jaroslav Kysela) [RHEL-13726]
- ASoC: ak4118: Update to use new component control notify helper (Jaroslav Kysela) [RHEL-13726]
- ASoC: soc-component: Add notify control helper function (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: ipc4-topology: Use set_get_data() to send LARGE_CONFIG message (Jaroslav Kysela) [RHEL-13726]
- ASoC: SOF: Simplify the calculation of variables (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: yc: Add MECHREVO Jiaolong Series MRID6 into DMI table (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: simplify tone control switch DSP code (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: apply channel delay hack to all E-MU cards (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: simplify snd_emu10k1_audigy_dsp_convert_32_to_2x16() (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: fix+optimize E-MU stereo capture DSP code (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: roll up loops in DSP setup code for Audigy (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: make tone control switch mono (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: don't create regular S/PDIF controls for E-MU cards (Jaroslav Kysela) [RHEL-13726]
- ASoC: sof: Improve sof_ipc4_bytes_ext_put function (Jaroslav Kysela) [RHEL-13726]
- ASoC: sof: Improve sof_ipc3_bytes_ext_put function (Jaroslav Kysela) [RHEL-13726]
- ALSA: uapi: pcm: control the filling of the silence samples for drain (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: remove now superfluous mixer locking (Jaroslav Kysela) [RHEL-13726]
- ALSA: core: update comment on snd_card.controls_rwsem (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: fix locking in snd_emu1010_fpga_link_dst_src_write() (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: use the right lock in snd_emu10k1_shared_spdif_put() (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: remove pointless locks from /proc code (Jaroslav Kysela) [RHEL-13726]
- ALSA: emu10k1: remove pointless locks from timer code (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: ps: refactor acp power on and reset functions. (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: ps: remove the register read and write wrappers. (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: ps: Update copyright notice (Jaroslav Kysela) [RHEL-13726]
- soundwire: bus: Don't filter slave alerts (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: Define dummy functions for snd_ac97_suspend() and resume() (Jaroslav Kysela) [RHEL-13726]
- ALSA: ac97: Remove redundant driver match function (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: ps: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [RHEL-13726]
- ASoC: amd: ps: Adjust the gain for PDM DMIC (Jaroslav Kysela) [RHEL-13726]
- PCI: Add Loongson vendor ID (Jaroslav Kysela) [RHEL-13726]

* Sun Jan 14 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-535.el8]
- VMCI: Use threaded irqs instead of tasklets (Ani Sinha) [RHEL-17673]
- arm64: kdump: simplify the reservation behaviour of crashkernel=,high (Pingfan Liu) [RHEL-8989]
- blk-mq: don't count completed flush data request as inflight in case of quiesce (Ming Lei) [RHEL-18055]
- md/raid6: use valid sector values to determine if an I/O should wait on the reshape (Nigel Croxon) [RHEL-17287]
- powerpc/hv-gpci: Add return value check in affinity_domain_via_partition_show function (Mamatha Inamdar) [RHEL-20259]
- powerpc/pseries/vas: Migration suspend waits for no in-progress open windows (Mamatha Inamdar) [RHEL-20243]
- fuse: fix deadlock between atomic O_TRUNC and page invalidation (Miklos Szeredi) [RHEL-7989]
- fuse: truncate pagecache on atomic_o_trunc (Miklos Szeredi) [RHEL-7989]
- blk-mq: use quiesced elevator switch when reinitializing queues (Ming Lei) [RHEL-19944]
- lib/group_cpus.c: avoid acquiring cpu hotplug lock in group_cpus_evenly (Ming Lei) [RHEL-8128]
- netdev: replace napi_reschedule with napi_schedule (Ivan Vecera) [RHEL-19714]
- netdev: make napi_schedule return bool on NAPI successful schedule (Ivan Vecera) [RHEL-19714]
- netdev: replace simple napi_schedule_prep/__napi_schedule to napi_schedule (Ivan Vecera) [RHEL-19714]
- x86/topology: Use total_cpus for max logical packages calculation (Frank Ramsay) [RHEL-17893]
- x86/fpu/xstate: Fix PKRU covert channel (Dean Nelson) [RHEL-16175]
- x86/fpu: Invalidate FPU state correctly on exec() (Dean Nelson) [RHEL-16175]
- x86/fpu/xstate: Prevent false-positive warning in __copy_xstate_uabi_buf() (Dean Nelson) [RHEL-16175]
- x86/fpu: Emulate XRSTOR's behavior if the xfeatures PKRU bit is not set (Dean Nelson) [RHEL-16175]
- x86/fpu: Allow PKRU to be (once again) written by ptrace. (Dean Nelson) [RHEL-16175]
- x86/fpu: Add a pkru argument to copy_uabi_to_xstate() (Dean Nelson) [RHEL-16175]
- x86/fpu: Add a pkru argument to copy_uabi_from_kernel_to_xstate(). (Dean Nelson) [RHEL-16175]
- x86/fpu: Take task_struct* in copy_sigframe_from_user_to_xstate() (Dean Nelson) [RHEL-16175]
- x86/fpu/xstate: Fix XSTATE_WARN_ON() to emit relevant diagnostics (Dean Nelson) [RHEL-16175]
- x86/fpu: Cleanup variable shadowing (Dean Nelson) [RHEL-16175]
- x86/fpu: Remove redundant XCOMP_BV initialization (Dean Nelson) [RHEL-16175]
- x86/ptrace: Fix xfpregs_set()'s incorrect xmm clearing (Dean Nelson) [RHEL-16175]
- x86/fpu: Remove duplicate copy_fpstate_to_sigframe() prototype (Dean Nelson) [RHEL-16175]
- x86/fpu/signal: Initialize sw_bytes in save_xstate_epilog() (Dean Nelson) [RHEL-16175]
- scsi: mpi3mr: Fetch correct device dev handle for status reply descriptor (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Block PEL Enable Command on Controller Reset and Unrecoverable State (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Clean up block devices post controller reset (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Refresh sdev queue depth after controller reset (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: driver version upgrade to 8.5.0.0.50 (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Add support for status reply descriptor (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Increase maximum number of PHYs to 64 from 32 (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Add PCI checks where SAS5116 diverges from SAS4116 (Tomas Henzl) [RHEL-17365]
- scsi: mpi3mr: Add support for SAS5116 PCI IDs (Tomas Henzl) [RHEL-17365]
- scsi: scsi_debug: Remove dead code (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Abort commands from scsi_debug_device_reset() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Fix missing error code in scsi_debug_init() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop sdebug_queue (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Only allow sdebug_max_queue be modified when no shosts (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Use scsi_host_busy() in delay_store() and ndelay_store() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Use blk_mq_tagset_busy_iter() in stop_all_queued() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Use blk_mq_tagset_busy_iter() in sdebug_blk_mq_poll() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Dynamically allocate sdebug_queued_cmd (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Use scsi_block_requests() to block queues (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Protect block_unblock_all_queues() with mutex (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Change shost list lock to a mutex (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Don't iter all shosts in clear_luns_changed_on_target() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Fix check for sdev queue full (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Remove redundant driver match function (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Add poll mode deferred completions to statistics (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Get command abort feature working again (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop sdebug_dev_info.num_in_q (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop check for num_in_q exceeding queue depth (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop scsi_debug_host_reset() device NULL pointer check (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop scsi_debug_bus_reset() NULL pointer checks (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop scsi_debug_target_reset() NULL pointer checks (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop scsi_debug_device_reset() NULL pointer checks (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Drop scsi_debug_abort() NULL pointer checks (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Stop setting devip->sdbg_host twice (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Don't hold driver host struct pointer in host->hostdata[] (Ming Lei) [RHEL-16241]
- scsi: core: Introduce {init,exit}_cmd_priv() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Fix possible UAF in sdebug_add_host_helper() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Fix sdebug_blk_mq_poll() in_use_bm bitmap use (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Fix qc_lock use in sdebug_blk_mq_poll() (Ming Lei) [RHEL-16241]
- scsi: scsi_debug: Refine sdebug_blk_mq_poll() (Ming Lei) [RHEL-16241]
- ice: fix theoretical out-of-bounds access in ethtool link modes (Petr Oros) [RHEL-15678]
- ice: restore timestamp configuration after device reset (Petr Oros) [RHEL-15678]
- ice: unify logic for programming PFINT_TSYN_MSK (Petr Oros) [RHEL-15678]
- ice: remove ptp_tx ring parameter flag (Petr Oros) [RHEL-15678]
- ice: Fix VF-VF direction matching in drop rule in switchdev (Petr Oros) [RHEL-15678]
- ice: Fix VF-VF filter rules in switchdev mode (Petr Oros) [RHEL-15678]
- ice: Fix safe mode when DDP is missing (Petr Oros) [RHEL-15678]
- ice: fix over-shifted variable (Petr Oros) [RHEL-15678]
- ice: Remove the FW shared parameters (Petr Oros) [RHEL-15678]
- ice: PTP: add clock domain number to auxiliary interface (Petr Oros) [RHEL-15678]
- ice: Use PTP auxbus for all PHYs restart in E822 (Petr Oros) [RHEL-15678]
- ice: Auxbus devices & driver for E822 TS (Petr Oros) [RHEL-15678]
- ice: introduce ice_pf_src_tmr_owned (Petr Oros) [RHEL-15678]
- ice: fix pin assignment for E810-T without SMA control (Petr Oros) [RHEL-15678]
- ice: remove ICE_F_PTP_EXTTS feature flag (Petr Oros) [RHEL-15678]
- ice: PTP: move quad value check inside ice_fill_phy_msg_e822 (Petr Oros) [RHEL-15678]
- ice: PTP: Rename macros used for PHY/QUAD port definitions (Petr Oros) [RHEL-15678]
- ice: PTP: Clean up timestamp registers correctly (Petr Oros) [RHEL-15678]
- ice: introduce hw->phy_model for handling PTP PHY differences (Petr Oros) [RHEL-15678]
- ice: Support cross-timestamping for E823 devices (Petr Oros) [RHEL-15678]
- ice: retry acquiring hardware semaphore during cross-timestamp request (Petr Oros) [RHEL-15678]
- ice: prefix clock timer command enumeration values with ICE_PTP (Petr Oros) [RHEL-15678]
- ice: avoid executing commands on other ports when driving sync (Petr Oros) [RHEL-15678]
- ice: fix receive buffer size miscalculation (Petr Oros) [RHEL-15678]
- ice: split ice_aq_wait_for_event() func into two (Petr Oros) [RHEL-15678]
- ice: embed &ice_rq_event_info event into struct ice_aq_task (Petr Oros) [RHEL-15678]
- ice: ice_aq_check_events: fix off-by-one check when filling buffer (Petr Oros) [RHEL-15678]
- ice: Remove redundant VSI configuration in eswitch setup (Petr Oros) [RHEL-15678]
- ice: move E810T functions to before device agnostic ones (Petr Oros) [RHEL-15678]
- ice: refactor ice_vsi_is_vlan_pruning_ena (Petr Oros) [RHEL-15678]
- ice: refactor ice_ptp_hw to make functions static (Petr Oros) [RHEL-15678]
- ice: refactor ice_sched to make functions static (Petr Oros) [RHEL-15678]
- ice: refactor ice_vf_lib to make functions static (Petr Oros) [RHEL-15678]
- ice: refactor ice_lib to make functions static (Petr Oros) [RHEL-15678]
- ice: refactor ice_ddp to make functions static (Petr Oros) [RHEL-15678]
- ice: remove unused methods (Petr Oros) [RHEL-15678]
- ice: Block switchdev mode when ADQ is active and vice versa (Petr Oros) [RHEL-15678]
- ice: clean up __ice_aq_get_set_rss_lut() (Petr Oros) [RHEL-15678]
- ice: add FW load wait (Petr Oros) [RHEL-15678]
- ice: Add get C827 PHY index function (Petr Oros) [RHEL-15678]
- ice: Rename enum ice_pkt_flags values (Petr Oros) [RHEL-15678]
- ice: Add direction metadata (Petr Oros) [RHEL-15678]
- ice: Fix RDMA VSI removal during queue rebuild (Petr Oros) [RHEL-15678]
- ice: Correctly initialize queue context values (Petr Oros) [RHEL-15678]
- ice: Fix memory management in ice_ethtool_fdir.c (Petr Oros) [RHEL-15678]
- ice: Implement basic eswitch bridge setup (Petr Oros) [RHEL-15678]
- ice: Unset src prune on uplink VSI (Petr Oros) [RHEL-15678]
- ice: Disable vlan pruning for uplink VSI (Petr Oros) [RHEL-15678]
- ice: Prohibit rx mode change in switchdev mode (Petr Oros) [RHEL-15678]
- ice: Skip adv rules removal upon switchdev release (Petr Oros) [RHEL-15678]
- ice: use ice_down_up() where applicable (Petr Oros) [RHEL-15678]
- ice: Remove managed memory usage in ice_get_fw_log_cfg() (Petr Oros) [RHEL-15678]
- ice: clean up freeing SR-IOV VFs (Petr Oros) [RHEL-15678]
- ice: reduce initial wait for control queue messages (Petr Oros) [RHEL-15678]
- ice: remove unnecessary check for old MAC == new MAC (Petr Oros) [RHEL-15678]
- ice: do not re-enable miscellaneous interrupt until thread_fn completes (Petr Oros) [RHEL-15678]
- ice: trigger PFINT_OICR_TSYN_TX interrupt instead of polling (Petr Oros) [RHEL-15678]
- ice: introduce ICE_TX_TSTAMP_WORK enumeration (Petr Oros) [RHEL-15678]
- ice: always return IRQ_WAKE_THREAD in ice_misc_intr() (Petr Oros) [RHEL-15678]
- ice: handle extts in the miscellaneous interrupt thread (Petr Oros) [RHEL-15678]
- ice: use src VSI instead of src MAC in slow-path (Petr Oros) [RHEL-15678]
- ice: allow matching on meta data (Petr Oros) [RHEL-15678]
- ice: specify field names in ice_prot_ext init (Petr Oros) [RHEL-15678]
- ice: remove redundant Rx field from rule info (Petr Oros) [RHEL-15678]
- ice: define meta data to match in switch (Petr Oros) [RHEL-15678]
- ice: refactor PHY type to ethtool link mode (Petr Oros) [RHEL-15678]
- ice: update ICE_PHY_TYPE_HIGH_MAX_INDEX (Petr Oros) [RHEL-15678]
- ice: call ice_is_malicious_vf() from ice_vc_process_vf_msg() (Petr Oros) [RHEL-15678]
- ice: move ice_is_malicious_vf() to ice_virtchnl.c (Petr Oros) [RHEL-15678]
- ice: print message if ice_mbx_vf_state_handler returns an error (Petr Oros) [RHEL-15678]
- ice: pass mbxdata to ice_is_malicious_vf() (Petr Oros) [RHEL-15678]
- ice: remove unnecessary &array[0] and just use array (Petr Oros) [RHEL-15678]
- ice: always report VF overflowing mailbox even without PF VSI (Petr Oros) [RHEL-15678]
- ice: declare ice_vc_process_vf_msg in ice_virtchnl.h (Petr Oros) [RHEL-15678]
- ice: initialize mailbox snapshot earlier in PF init (Petr Oros) [RHEL-15678]
- ice: merge ice_mbx_report_malvf with ice_mbx_vf_state_handler (Petr Oros) [RHEL-15678]
- ice: remove ice_mbx_deinit_snapshot (Petr Oros) [RHEL-15678]
- ice: move VF overflow message count into struct ice_mbx_vf_info (Petr Oros) [RHEL-15678]
- ice: track malicious VFs in new ice_mbx_vf_info structure (Petr Oros) [RHEL-15678]
- ice: convert ice_mbx_clear_malvf to void and use WARN (Petr Oros) [RHEL-15678]
- ice: re-order ice_mbx_reset_snapshot function (Petr Oros) [RHEL-15678]

* Sat Jan 06 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-534.el8]
- nfsd: lock_rename() needs both directories to live on the same fs (Jeffrey Layton) [RHEL-19591]
- HID: check empty report_list in hid_validate_values() (Desnes Nunes) [RHEL-19237 RHEL-19260] {CVE-2023-1073}
- ceph: do not print the whole xattr value if it's too long (Xiubo Li) [RHEL-16411]
- libceph: fix potential use-after-free on linger ping and resends (Jay Shin) [RHEL-20390]
- ceph: fix incorrect revoked caps assert in ceph_fill_file_size() (Xiubo Li) [RHEL-8003]
- ceph: silence smatch warning in reconnect_caps_cb() (Xiubo Li) [RHEL-16410]
- ceph: fix potential use-after-free bug when trimming caps (Xiubo Li) [RHEL-16410]
- ceph: don't let check_caps skip sending responses for revoke msgs (Xiubo Li) [RHEL-16412]
- ceph: issue a cap release immediately if no cap exists (Xiubo Li) [RHEL-16412]
- ceph: trigger to flush the buffer when making snapshot (Xiubo Li) [RHEL-16412]
- ceph: force updating the msg pointer in non-split case (Xiubo Li) [RHEL-16412]
- ceph: flush cap releases when the session is flushed (Xiubo Li) [RHEL-16412]
- ceph: reorder fields in 'struct ceph_snapid_map' (Xiubo Li) [RHEL-16412]
- ceph: voluntarily drop Xx caps for requests those touch parent mtime (Xiubo Li) [RHEL-16412]
- redhat/configs: Remove multi-buffer SHA configs (Štěpán Horáček) [RHEL-14477]
- crypto: tcrypt - remove all multibuffer ahash tests (Štěpán Horáček) [RHEL-14477]
- crypto: hash - Remove unused async iterators (Štěpán Horáček) [RHEL-14477]
- crypto: x86 - remove SHA multibuffer routines and mcryptd (Štěpán Horáček) [RHEL-14477]
- fs: group frequently accessed fields of struct super_block together (Miklos Szeredi) [RHEL-12504]
- fanotify: add API to attach/detach super block mark (Miklos Szeredi) [RHEL-12504]
- fsnotify: send path type events to group with super block marks (Miklos Szeredi) [RHEL-12504]
- fsnotify: add super block object type (Miklos Szeredi) [RHEL-12504]
- netfilter: nf_tables: set backend .flush always succeeds (Florian Westphal) [RHEL-1722]
- netfilter: nft_set_pipapo: no need to call pipapo_deactivate() from flush (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix memleak when more than 255 elements expired (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: disable toggling dormant table state more than once (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix table flag updates (Florian Westphal) [RHEL-1722]
- netfilter: nftables: update table flags from the commit phase (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: disallow element removal on anonymous sets (Florian Westphal) [RHEL-1722]
- netfilter: nft_set_hash: try later when GC hits EAGAIN on iteration (Florian Westphal) [RHEL-1722]
- netfilter: nft_set_pipapo: stop GC iteration if GC transaction allocation fails (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix nft_trans type confusion (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: defer gc run if previous batch is still pending (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix out of memory error handling (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: use correct lock to protect gc_list (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: GC transaction race with abort path (Florian Westphal) [RHEL-1722]
- netfilter: nft_dynset: disallow object maps (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: GC transaction race with netns dismantle (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix GC transaction races with netns and netlink event exit path (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: don't fail inserts if duplicate has expired (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix kdoc warnings after gc rework (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix false-positive lockdep splat (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: remove busy mark and gc batch API (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: adapt set backend to use GC transaction API (Florian Westphal) [RHEL-1722] {CVE-2023-4244}
- netfilter: nf_tables: GC transaction API to avoid race with control plane (Florian Westphal) [RHEL-1722] {CVE-2023-4244}
- netfilter: nftables: rename set element data activation/deactivation functions (Florian Westphal) [RHEL-1722]
- netfilter: nft_set_rbtree: skip elements in transaction from garbage collection (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: don't skip expired elements during walk (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: fix spurious set element insertion failure (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: report use refcount overflow (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: add nft_chain_add() (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: disallow timeout for anonymous sets (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: disallow updates of anonymous sets (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: disallow element updates of bound anonymous sets (Florian Westphal) [RHEL-1722]
- netfilter: nft_set_pipapo: .walk does not deal with generations (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: integrate pipapo into commit protocol (Florian Westphal) [RHEL-1722]
- netfilter: nf_tables: honor NLM_F_CREATE and NLM_F_EXCL in event notification (Florian Westphal) [RHEL-1722]
- netfilter: nftables: add catch-all set element support (Florian Westphal) [RHEL-1722]

* Tue Jan 02 2024 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-533.el8]
- netlink: support extack in dump ->start() (Hangbin Liu) [RHEL-17272]
- audit: don't WARN_ON_ONCE(!current->mm) in audit_exe_compare() (Artem Savkov) [RHEL-16009]
- audit: don't take task_lock() in audit_exe_compare() code path (Artem Savkov) [RHEL-16009]
- IB/ipoib: Fix mcast list locking (Daniel Vacek) [RHEL-19244]
- RDMA/IPoIB: Fix error code return in ipoib_mcast_join (Daniel Vacek) [RHEL-19244]
- ipvlan: Fix a reference count leak warning in ipvlan_ns_exit() (Davide Caratti) [RHEL-14290]
- ipvlan: Fix return value of ipvlan_queue_xmit() (Davide Caratti) [RHEL-14290]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_fp_int_cmd_read() directly (Oleksandr Natalenko) [2228079]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_debug_cmd_read() directly (Oleksandr Natalenko) [2228079]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_stop_io_on_error_cmd_read() directly (Oleksandr Natalenko) [2228079]
- xen/blkfront: fix memory allocation flags in blkfront_setup_indirect() (Vitaly Kuznetsov) [RHEL-15958]
- xen-blkfront: switch kcalloc to kvcalloc for large array allocation (Vitaly Kuznetsov) [RHEL-15958]
- xen-blkfront: fix kernel panic with negotiate_mq error path (Vitaly Kuznetsov) [RHEL-15958]
- tracing/timerlat: Add user-space interface (Chris White) [RHEL-15142]
- tracing/osnoise: Skip running osnoise if all instances are off (Chris White) [RHEL-15142]
- tracing/osnoise: Switch from PF_NO_SETAFFINITY to migrate_disable (Chris White) [RHEL-15142]
- tracing/timerlat: Always wakeup the timerlat thread (Chris White) [RHEL-15142]
- tracing/osnoise: Fix notify new tracing_max_latency (Chris White) [RHEL-15142]
- tracing/timerlat: Notify new max thread latency (Chris White) [RHEL-15142]
- trace/osnoise: make use of the helper function kthread_run_on_cpu() (Chris White) [RHEL-15142]
- kthread: add the helper function kthread_run_on_cpu() (Chris White) [RHEL-15142]
- iavf: Fix iavf_shutdown to call iavf_remove instead iavf_close (Michal Schmidt) [RHEL-15675]
- iavf: Handle ntuple on/off based on new state machines for flow director (Michal Schmidt) [RHEL-15675]
- iavf: Introduce new state machines for flow director (Michal Schmidt) [RHEL-15675]
- iavf: validate tx_coalesce_usecs even if rx_coalesce_usecs is zero (Michal Schmidt) [RHEL-15675]
- iavf: delete the iavf client interface (Michal Schmidt) [RHEL-15675]
- iavf: add a common function for undoing the interrupt scheme (Michal Schmidt) [RHEL-15675]
- iavf: use unregister_netdev (Michal Schmidt) [RHEL-15675]
- iavf: rely on netdev's own registered state (Michal Schmidt) [RHEL-15675]
- iavf: fix the waiting time for initial reset (Michal Schmidt) [RHEL-15675]
- iavf: in iavf_down, don't queue watchdog_task if comms failed (Michal Schmidt) [RHEL-15675]
- iavf: simplify mutex_trylock+sleep loops (Michal Schmidt) [RHEL-15675]
- iavf: fix comments about old bit locks (Michal Schmidt) [RHEL-15675]
- iavf: in iavf_down, disable queues when removing the driver (Michal Schmidt) [RHEL-15675]
- iavf: initialize waitqueues before starting watchdog_task (Michal Schmidt) [RHEL-15675]
- iavf: delete unused iavf_mac_info fields (Michal Schmidt) [RHEL-15675]
- iavf: fix format warnings (Michal Schmidt) [RHEL-15675]
- iavf: fix string truncation warnings (Michal Schmidt) [RHEL-15675]
- iavf: remove "inline" functions from iavf_txrx.c (Michal Schmidt) [RHEL-15675]
- iavf: do not process adminq tasks when __IAVF_IN_REMOVE_TASK is set (Michal Schmidt) [RHEL-15675]
- iavf: Fix promiscuous mode configuration flow messages (Michal Schmidt) [RHEL-15675]
- iavf: fix FDIR rule fields masks validation (Michal Schmidt) [RHEL-15675]
- iavf: fix potential races for FDIR filters (Michal Schmidt) [RHEL-15675]
- iavf: check for removal state before IAVF_FLAG_PF_COMMS_FAILED (Michal Schmidt) [RHEL-15675]
- iavf: fix potential deadlock on allocation failure (Michal Schmidt) [RHEL-15675]
- iavf: Remove unnecessary aer.h include (Michal Schmidt) [RHEL-15675]
- iavf: Remove redundant pci_enable_pcie_error_reporting() (Michal Schmidt) [RHEL-15675]

* Thu Dec 21 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-532.el8]
- devres: handle zero size in devm_kmalloc() (Mark Langsdorf) [RHEL-1025 RHEL-14039]
- cpufreq: ACPI: Prevent a warning when another frequency driver is loaded (Mark Langsdorf) [RHEL-1025]
- cpufreq: drivers with target_index() must set freq_table (Mark Langsdorf) [RHEL-1025]
- cpufreq: warn about invalid vals to scaling_max/min_freq interfaces (Mark Langsdorf) [RHEL-1025]
- ACPI: cpufreq: Use platform devices to load ACPI PPC and PCC drivers (Mark Langsdorf) [RHEL-1025]
- cpufreq: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1025]
- kbuild, cpufreq: remove MODULE_LICENSE in non-modules (Mark Langsdorf) [RHEL-1025]
- cpufreq: Add __init annotation to module init funcs (Mark Langsdorf) [RHEL-1025]
- cpufreq: intel_pstate: Add Tigerlake support in no-HWP mode (Mark Langsdorf) [RHEL-1025]
- netfilter: nfnetlink_osf: avoid OOB read (Phil Sutter) [RHEL-12299] {CVE-2023-39189}
- crypto: qat - add NULL pointer check (Vladis Dronov) [RHEL-19124]
- crypto: qat - fix mutex ordering in adf_rl (Vladis Dronov) [RHEL-19124]
- crypto: qat - fix error path in add_update_sla() (Vladis Dronov) [RHEL-19124]
- crypto: qat - add sysfs_added flag for rate limiting (Vladis Dronov) [RHEL-19124]
- crypto: qat - add sysfs_added flag for ras (Vladis Dronov) [RHEL-19124]
- x86/speculation: Provide a debugfs file to dump SPEC_CTRL MSRs (Waiman Long) [RHEL-16845]
- x86/idle: Disable IBRS entering mwait idle and enable it on wakeup (Waiman Long) [RHEL-16845]
- intel_idle: Add ibrs_off module parameter to force-disable IBRS (Waiman Long) [RHEL-16845]
- intel_idle: Use __update_spec_ctrl() in intel_idle_ibrs() (Waiman Long) [RHEL-16845]
- x86/idle: Disable IBRS when CPU is offline to improve single-threaded performance (Waiman Long) [RHEL-16845]
- x86/speculation: Add __update_spec_ctrl() helper (Waiman Long) [RHEL-16845]
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_IBRS (Waiman Long) [RHEL-16845]
- igb: Fix potential memory leak in igb_add_ethtool_nfc_entry (Corinna Vinschen) [RHEL-15681]
- igb: Fix an end of loop test (Corinna Vinschen) [RHEL-15681]
- igb: replace deprecated strncpy with strscpy (Corinna Vinschen) [RHEL-15681]
- intel: fix format warnings (Corinna Vinschen) [RHEL-15681]
- intel: fix string truncation warnings (Corinna Vinschen) [RHEL-15681]
- ethernet/intel: Use list_for_each_entry() helper (Corinna Vinschen) [RHEL-15681]
- igb: clean up in all error paths when enabling SR-IOV (Corinna Vinschen) [RHEL-15681]
- igb: Change IGB_MIN to allow set rx/tx value between 64 and 80 (Corinna Vinschen) [RHEL-15681]
- igb: disable virtualization features on 82580 (Corinna Vinschen) [RHEL-15681]
- igb: Avoid starting unnecessary workqueues (Corinna Vinschen) [RHEL-15681]
- igb: Fix igb_down hung on surprise removal (Corinna Vinschen) [RHEL-15681]
- igb: Enable SR-IOV after reinit (Corinna Vinschen) [RHEL-15681]
- bpf: Mark PTR_TO_FUNC register initially with zero offset (Viktor Malik) [RHEL-8477 RHEL-8926] {CVE-2021-4204}
- bpf: Fix out of bounds access for ringbuf helpers (Viktor Malik) [RHEL-8477 RHEL-8926] {CVE-2021-4204}
- bpf: Generally fix helper register offset check (Viktor Malik) [RHEL-8477 RHEL-8926] {CVE-2021-4204}
- bpf: Generalize check_ctx_reg for reuse with other types (Viktor Malik) [RHEL-8477 RHEL-8926] {CVE-2021-4204}
- bpf: Check PTR_TO_MEM | MEM_RDONLY in check_helper_mem_access (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Fix crash due to out of bounds access into reg2btf_ids. (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Add MEM_RDONLY for helper args that are pointers to rdonly mem. (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Make per_cpu_ptr return rdonly PTR_TO_MEM. (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Convert PTR_TO_MEM_OR_NULL to composable types. (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Introduce MEM_RDONLY flag (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Replace PTR_TO_XXX_OR_NULL with PTR_TO_XXX | PTR_MAYBE_NULL (Viktor Malik) [RHEL-8473 RHEL-8476 RHEL-8925 RHEL-9037] {CVE-2022-0500 CVE-2022-23222}
- bpf: Replace RET_XXX_OR_NULL with RET_XXX | PTR_MAYBE_NULL (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Replace ARG_XXX_OR_NULL with ARG_XXX | PTR_MAYBE_NULL (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- bpf: Introduce composable reg, ret and arg types. (Viktor Malik) [RHEL-8473 RHEL-9037] {CVE-2022-0500}
- ipmi: Explicitly include correct DT includes (Tony Camuso) [RHEL-14570]
- ipmi_si: fix -Wvoid-pointer-to-enum-cast warning (Tony Camuso) [RHEL-14570]
- ipmi: fix potential deadlock on &kcs_bmc->lock (Tony Camuso) [RHEL-14570]
- ipmi_si: fix a memleak in try_smi_init() (Tony Camuso) [RHEL-14570]
- ipmi: Change request_module to request_module_nowait (Tony Camuso) [RHEL-14570]
- ipmi:ssif: Fix a memory leak when scanning for an adapter (Tony Camuso) [RHEL-14570]
- ipmi:ssif: Add check for kstrdup (Tony Camuso) [RHEL-14570]
- ipmi_watchdog: Fix read syscall not responding to signals during sleep (Tony Camuso) [RHEL-14570]
- ipmi:ssif: Drop if blocks with always false condition (Tony Camuso) [RHEL-14570]
- ipmi: fix SSIF not responding under certain cond. (Tony Camuso) [RHEL-14570]
- ipmi:ssif: Add send_retries increment (Tony Camuso) [RHEL-14570]
- char:ipmi:Fix spelling mistake "asychronously" -> "asynchronously" (Tony Camuso) [RHEL-14570]
- ipmi: simplify sysctl registration (Tony Camuso) [RHEL-14570]
- ipmi: ASPEED_BT_IPMI_BMC: select REGMAP_MMIO instead of depending on it (Tony Camuso) [RHEL-14570]
- bnxt_en: fix free-runnig PHC mode (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- eth: bnxt: handle invalid Tx completions more gracefully (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- eth: bnxt: take the bit to set as argument of bnxt_queue_sp_work() (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- eth: bnxt: move and rename reset helpers (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt: don't handle XDP in netpoll (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Implement .set_port / .unset_port UDP tunnel callbacks (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Prevent kernel panic when receiving unexpected PHC_UPDATE event (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Skip firmware fatal error recovery if chip is not accessible (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Query default VLAN before VNIC setup on a VF (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Don't issue AP reset during ethtool's reset operation (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Fix bnxt_hwrm_update_rss_hash_cfg() (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Do not initialize PTP on older P3/P4 chips (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Add missing 200G link speed reporting (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Fix typo in PCI id to device description string mapping (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Fix reporting of test result in ethtool selftest (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt: Enforce PTP software freq adjustments only when in non-RTC mode (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt: Defer PTP initialization to after querying function caps (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt: Change fw_cap to u64 to accommodate more capability bits (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt: avoid overflow in bnxt_get_nvram_directory() (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: reset PHC frequency in free-running mode (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Avoid order-5 memory allocation for TPA data (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- ptp: bnxt: convert .adjfreq to .adjfine (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- bnxt_en: Add a non-real time mode to access NIC clock (Ken Cox) [RHEL-10233 RHEL-11006 RHEL-4238]
- igc: Fix ambiguity in the ethtool advertising (Corinna Vinschen) [RHEL-15680]
- igc: replace deprecated strncpy with strscpy (Corinna Vinschen) [RHEL-15680]
- intel: fix format warnings (Corinna Vinschen) [RHEL-15680]
- igc: Expose tx-usecs coalesce setting to user (Corinna Vinschen) [RHEL-15680]
- igc: Fix infinite initialization loop with early XDP redirect (Corinna Vinschen) [RHEL-15680]
- igc: Change IGC_MIN to allow set rx/tx value between 64 and 80 (Corinna Vinschen) [RHEL-15680]
- igc: Decrease PTM short interval from 10 us to 1 us (Corinna Vinschen) [RHEL-15680]
- igc: Add support for multiple in-flight TX timestamps (Corinna Vinschen) [RHEL-15680]
- igc: Fix the typo in the PTM Control macro (Corinna Vinschen) [RHEL-15680]
- igc: Add lock to safeguard global Qbv variables (Corinna Vinschen) [RHEL-15680]
- eth: add missing xdp.h includes in drivers (Corinna Vinschen) [RHEL-15680]
- igc: Fix Kernel Panic during ndo_tx_timeout callback (Corinna Vinschen) [RHEL-15680]
- igc: Prevent garbled TX queue with XDP ZEROCOPY (Corinna Vinschen) [RHEL-15680]
- igc: Fix inserting of empty frame for launchtime (Corinna Vinschen) [RHEL-15680]
- igc: Fix launchtime before start of cycle (Corinna Vinschen) [RHEL-15680]
- igc: No strict mode in pure launchtime/CBS offload (Corinna Vinschen) [RHEL-15680]
- igc: Handle already enabled taprio offload for basetime 0 (Corinna Vinschen) [RHEL-15680]
- igc: Do not enable taprio offload for invalid arguments (Corinna Vinschen) [RHEL-15680]
- igc: Rename qbv_enable to taprio_offload_enable (Corinna Vinschen) [RHEL-15680]
- igc: Handle PPS start time programming for past time values (Corinna Vinschen) [RHEL-15680]
- igc: Include the length/type field and VLAN tag in queueMaxSDU (Corinna Vinschen) [RHEL-15680]
- igc: set TP bit in 'supported' and 'advertising' fields of ethtool_link_ksettings (Corinna Vinschen) [RHEL-15680]
- igc: Fix TX Hang issue when QBV Gate is closed (Corinna Vinschen) [RHEL-15680]
- igc: Remove delay during TX ring configuration (Corinna Vinschen) [RHEL-15680]
- igc: Add condition for qbv_config_change_errors counter (Corinna Vinschen) [RHEL-15680]
- igc: Work around HW bug causing missing timestamps (Corinna Vinschen) [RHEL-15680]
- igc: Retrieve TX timestamp during interrupt handling (Corinna Vinschen) [RHEL-15680]
- igc: Check if hardware TX timestamping is enabled earlier (Corinna Vinschen) [RHEL-15680]
- igc: Fix race condition in PTP tx code (Corinna Vinschen) [RHEL-15680]
- igc: Remove unnecessary aer.h include (Corinna Vinschen) [RHEL-15680]
- igc: Clean up and optimize watchdog task (Corinna Vinschen) [RHEL-15680]
- igc: offload queue max SDU from tc-taprio (Corinna Vinschen) [RHEL-15680]
- igc: Add qbv_config_change_errors counter (Corinna Vinschen) [RHEL-15680]

* Sat Dec 16 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-531.el8]
- s390/pci: fix iommu bitmap allocation (Tobias Huschle) [RHEL-18202]
- net/smc: Fix pos miscalculation in statistics (Tobias Huschle) [RHEL-18203]
- ibmveth: Remove condition to recompute TCP header checksum. (Mamatha Inamdar) [RHEL-12553]
- net: thunderx: Fix the ACPI memory leak (Maurizio Lombardi) [RHEL-18244]
- null_blk: Always check queue mode setting from configfs (Ming Lei) [RHEL-18182]
- drivers: net: slip: fix NPD bug in sl_tx_timeout() (Michal Schmidt) [RHEL-6655] {CVE-2022-41858}
- mm: thp: replace DEBUG_VM BUG with VM_WARN when unmap fails for split (David Hildenbrand) [RHEL-8517]
- net/tls: do not free tls_rec on async operation in bpf_exec_tx_verdict() (Sabrina Dubroca) [RHEL-16720] {CVE-2023-6176}
- nfp: fix use-after-free in area_cache_get() (Ricardo Robaina) [RHEL-6567] {CVE-2022-3545}
- igb: set max size RX buffer when store bad packet is enabled (Wander Lairson Costa) [RHEL-15188] {CVE-2023-45871}
- igbvf: replace deprecated strncpy with strscpy (Corinna Vinschen) [RHEL-15679]
- igbvf: Change IGBVF_MIN to allow set rx/tx value between 64 and 80 (Corinna Vinschen) [RHEL-15679]
- ixgbe: Fix panic during XDP_TX with > 64 CPUs (Ken Cox) [RHEL-15682]
- ixgbe: Enable setting RSS table to default values (Ken Cox) [RHEL-15682]
- ixgbe: Allow flow hash to be set via ethtool (Ken Cox) [RHEL-15682]
- vsock/virtio: remove socket from connected/bound list on shutdown (Stefano Garzarella) [RHEL-17877]
- vsock/virtio: initialize the_virtio_vsock before using VQs (Stefano Garzarella) [RHEL-17877]
- vsock: send SIGPIPE on write to shutdowned socket (Stefano Garzarella) [RHEL-17877]
- vsock/virtio: factor our the code to initialize and delete VQs (Stefano Garzarella) [RHEL-17877]
- virtio-net: fix for skb_over_panic inside big mode (Laurent Vivier) [RHEL-7165]
- virtio-net: fix pages leaking when building skb in big mode (Laurent Vivier) [RHEL-7165]
- virtio_net: fix wrong buf address calculation when using xdp (Laurent Vivier) [RHEL-7165]
- virtio_net: get build_skb() buf by data ptr (Laurent Vivier) [RHEL-7165]
- virtio-net: fix for unable to handle page fault for address (Laurent Vivier) [RHEL-7165]
- scsi: qedi: Remove unused declarations (Nilesh Javali) [RHEL-9860]
- scsi: qedi: Fix firmware halt over suspend and resume (Nilesh Javali) [RHEL-9860]
- scsi: qedi: Fix potential deadlock on &qedi_percpu->p_work_lock (Nilesh Javali) [RHEL-9860]
- scsi: qedi: Replace all non-returning strlcpy with strscpy (Nilesh Javali) [RHEL-9860]
- scsi: qedi: Fix use after free bug in qedi_remove() (Nilesh Javali) [RHEL-9860]
- scsi: qedi: Remove unneeded version.h include (Nilesh Javali) [RHEL-9860]
- perf/x86/amd/uncore: Pass through error code for initialization failures, instead of -ENODEV (Michael Petlan) [RHEL-9993]
- perf/x86/amd/uncore: Fix uninitialized return value in amd_uncore_init() (Michael Petlan) [RHEL-9993]
- perf/x86/amd/uncore: Add memory controller support (Michael Petlan) [RHEL-9993]
- perf/x86/amd/uncore: Add group exclusivity (Michael Petlan) [RHEL-9993]
- perf/x86/amd/uncore: Use rdmsr if rdpmc is unavailable (Michael Petlan) [RHEL-9993]
- perf/x86/amd/uncore: Move discovery and registration (Michael Petlan) [RHEL-9993]
- perf/x86/amd/uncore: Refactor uncore management (Michael Petlan) [RHEL-9993]
- RDMA/hfi1: Workaround truncation compilation error (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Fix potential deadlock on &irq_src_lock and &dd->uctxt_lock (Izabela Bakollari) [RHEL-18211]
- RDMA/hfi1: Remove redundant assignment to pointer ppd (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Replace deprecated strncpy (Izabela Bakollari) [RHEL-18211]
- RDMA/hfi1: Use FIELD_GET() to extract Link Width (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Reduce printing of errors during driver shut down (Izabela Bakollari) [RHEL-18211]
- RDMA/hfi1: Use list_for_each_entry() helper (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Fix possible panic during hotplug remove (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Use struct_size() (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Suppress useless compiler warnings (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Remove trace newlines (Izabela Bakollari) [RHEL-18211]
- IB/hfi1: Drop redundant pci_enable_pcie_error_reporting() (Izabela Bakollari) [RHEL-18211]
- IB/hifi1: add a null check of kzalloc_node in hfi1_ipoib_txreq_init (Izabela Bakollari) [RHEL-18211]

* Sat Dec 09 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-530.el8]
- Bluetooth: L2CAP: Fix use-after-free in l2cap_sock_ready_cb (David Marlin) [RHEL-1231] {CVE-2023-40283}
- amd_hsmp: Add HSMP protocol version 5 messages (John Allen) [2072238]
- KVM: s390/mm: Properly reset no-dat (Cédric Le Goater) [RHEL-17383]
- KVM: s390: vsie: fix wrong VIR 37 when MSO is used (Cédric Le Goater) [RHEL-17383]
- nvme-rdma: fix typo in comment (Kamal Heib) [RHEL-10968]
- nvme-rdma: minor cleanup in nvme_rdma_create_cq() (Kamal Heib) [RHEL-10968]
- scsi: iscsi_tcp: Fix UAF during login when accessing the shost ipaddress (Chris Leech) [RHEL-8200 RHEL-8992] {CVE-2023-2162}
- scsi: iscsi_tcp: Fix UAF during logout when accessing the shost ipaddress (Chris Leech) [RHEL-8200 RHEL-8992] {CVE-2023-2162}
- ibmveth: Reduce default tx queues to 8 (Mamatha Inamdar) [RHEL-11209]
- ibmveth: Ethtool set queue support (Mamatha Inamdar) [RHEL-11209]
- ibmveth: Implement multi queue on xmit (Mamatha Inamdar) [RHEL-11209]
- ibmveth: Copy tx skbs into a premapped buffer (Mamatha Inamdar) [RHEL-11209]
- ibmveth: Use dma_alloc_coherent() instead of kmalloc/dma_map_single() (Mamatha Inamdar) [RHEL-11209]
- vt: keyboard, reorder user buffer handling in vt_do_kdgkb_ioctl (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, rename i to kb_func in vt_do_kdgkb_ioctl (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, use bool for rep (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, union perm checks in vt_do_kdsk_ioctl (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, extract vt_kdgkbent and vt_kdskbent (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, sort includes (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, include linux/spinlock.h (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, extend func_buf_lock to readers (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- vt: keyboard, simplify vt_kdgkbsent (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- tty/vt: fix write/write race in ioctl(KDSKBSENT) handler (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- tty: keyboard, do not speculate on func_table index (John W. Linville) [RHEL-3015] {CVE-2020-25656}
- Bluetooth: RFCOMM: Fix possible deadlock on socket shutdown/release (David Marlin) [RHEL-17716]
- Bluetooth: fix dangling sco_conn and use-after-free in sco_sock_timeout (David Marlin) [RHEL-17716]
- bluetooth: use dev_addr_set() (David Marlin) [RHEL-17716]
- bluetooth: use eth_hw_addr_set() (David Marlin) [RHEL-17716]
- Bluetooth: Rename driver .prevent_wake to .wakeup (David Marlin) [RHEL-17716]
- Bluetooth: btrtl: Ask ic_info to drop firmware (David Marlin) [RHEL-17716]
- Bluetooth: btusb: Add support for TP-Link UB500 Adapter (David Marlin) [RHEL-17716]
- Bluetooth: hci_sock: Replace use of memcpy_from_msg with bt_skb_sendmsg (David Marlin) [RHEL-17716]
- Bluetooth: btrtl: Add support for MSFT extension to rtl8821c devices (David Marlin) [RHEL-17716]
- Bluetooth: hci_vhci: Add force_prevent_wake entry (David Marlin) [RHEL-17716]
- Bluetooth: hci_vhci: Add force_suspend entry (David Marlin) [RHEL-17716]
- Bluetooth: Make use of hci_{suspend,resume}_dev on suspend notifier (David Marlin) [RHEL-17716]
- Bluetooth: btrsi: remove superfluous header files from btrsi.c (David Marlin) [RHEL-17716]
- Bluetooth: btrtl: Set VsMsftOpCode based on device table (David Marlin) [RHEL-17716]
- Bluetooth: Fix handling of experimental feature for codec offload (David Marlin) [RHEL-17716]
- Bluetooth: Fix handling of experimental feature for quality reports (David Marlin) [RHEL-17716]
- Bbluetooth: btusb: Add another Bluetooth part for Realtek 8852AE (David Marlin) [RHEL-17716]
- Bluetooth: btrtl: enable Realtek 8822C/8852A to support AOSP extension (David Marlin) [RHEL-17716]
- Bluetooth: hci_qca: enable Qualcomm WCN399x for AOSP extension (David Marlin) [RHEL-17716]
- Bluetooth: Apply missing portion of previously applied commit to correct context. (David Marlin) [RHEL-17716]
- Bluetooth: Fix wrong opcode when LL privacy enabled (David Marlin) [RHEL-17716]
- Bluetooth: Fix Advertisement Monitor Suspend/Resume (David Marlin) [RHEL-17716]
- Bluetooth: hci_h5: directly return hci_uart_register_device() ret-val (David Marlin) [RHEL-17716]
- Bluetooth: hci_h5: Fix (runtime)suspend issues on RTL8723BS HCIs (David Marlin) [RHEL-17716]
- Bluetooth: hci_core: Move all debugfs handling to hci_debugfs.c (David Marlin) [RHEL-17716]
- Bluetooth: btmtkuart: fix a memleak in mtk_hci_wmt_sync (David Marlin) [RHEL-17716]
- Bluetooth: hci_ldisc: require CAP_NET_ADMIN to attach N_HCI ldisc (David Marlin) [RHEL-17716]
- Bluetooth: btusb: Add gpio reset way for qca btsoc in cmd_timeout (David Marlin) [RHEL-17716]
- Bluetooth: Fix passing NULL to PTR_ERR (David Marlin) [RHEL-17716]
- Bluetooth: hci_sock: Add support for BT_{SND,RCV}BUF (David Marlin) [RHEL-17716]
- Bluetooth: eir: Move EIR/Adv Data functions to its own file (David Marlin) [RHEL-17716]
- Bluetooth: RFCOMM: Replace use of memcpy_from_msg with bt_skb_sendmmsg (David Marlin) [RHEL-17716]
- Bluetooth: Add bt_skb_sendmmsg helper (David Marlin) [RHEL-17716]
- Bluetooth: hci_uart: fix GPF in h5_recv (David Marlin) [RHEL-17716]
- Bluetooth: btintel: Fix incorrect out of memory check (David Marlin) [RHEL-17716]
- Bluetooth: Keep MSFT ext info throughout a hci_dev's life cycle (David Marlin) [RHEL-17716]
- Bluetooth: hci_vhci: Add support for offload codecs over SCO (David Marlin) [RHEL-17716]
- Bluetooth: Allow usb to auto-suspend when SCO use non-HCI transport (David Marlin) [RHEL-17716]
- Bluetooth: Add offload feature under experimental flag (David Marlin) [RHEL-17716]
- Bluetooth: Add support for msbc coding format (David Marlin) [RHEL-17716]
- Bluetooth: btintel: Define a callback to fetch codec config data (David Marlin) [RHEL-17716]
- Bluetooth: Configure codec for HFP offload use case (David Marlin) [RHEL-17716]
- Bluetooth: Add support for HCI_Enhanced_Setup_Synchronous_Connection command (David Marlin) [RHEL-17716]
- Bluetooth: Allow setting of codec for HFP offload use case (David Marlin) [RHEL-17716]
- Bluetooth: btintel: Define callback to fetch data_path_id (David Marlin) [RHEL-17716]
- Bluetooth: Allow querying of supported offload codecs over SCO socket (David Marlin) [RHEL-17716]
- Bluetooth: btintel: Read supported offload use cases (David Marlin) [RHEL-17716]
- Bluetooth: Add support for Read Local Supported Codecs V2 (David Marlin) [RHEL-17716]
- Bluetooth: Enumerate local supported codec and cache details (David Marlin) [RHEL-17716]
- Bluetooth: fix init and cleanup of sco_conn.timeout_work (David Marlin) [RHEL-17716]
- Bluetooth: call sock_hold earlier in sco_conn_del (David Marlin) [RHEL-17716]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip(MT7921) (David Marlin) [RHEL-17716]
- Bluetooth: btusb: Add the new support ID for Realtek RTL8852A (David Marlin) [RHEL-17716]
- Bluetooth: btintel: Read boot address irrespective of controller mode (David Marlin) [RHEL-17716]
- Bluetooth: btintel: Fix boot address (David Marlin) [RHEL-17716]
- Bluetooth: Fix using RPA when address has been resolved (David Marlin) [RHEL-17716]
- Bluetooth: Fix using address type from events (David Marlin) [RHEL-17716]
- Bluetooth: Fix enabling advertising for central role (David Marlin) [RHEL-17716]
- Bluetooth: set quality report callback for Intel (David Marlin) [RHEL-17716]
- Bluetooth: Support the quality report events (David Marlin) [RHEL-17716]
- Bluetooth: refactor set_exp_feature with a feature table (David Marlin) [RHEL-17716]
- Bluetooth: btintel: support link statistics telemetry events (David Marlin) [RHEL-17716]
- Bluetooth: btusb: disable Intel link statistics telemetry events (David Marlin) [RHEL-17716]
- Bluetooth: mgmt: Disallow legacy MGMT_OP_READ_LOCAL_OOB_EXT_DATA (David Marlin) [RHEL-17716]
- Bluetooth: reorganize functions from hci_sock_sendmsg() (David Marlin) [RHEL-17716]
- crypto: qat - prevent underflow in rp2srv_store() (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix deadlock in backlog processing (Vladis Dronov) [RHEL-15642]
- crypto: qat - move adf_cfg_services (Vladis Dronov) [RHEL-15642]
- crypto: qat - add num_rps sysfs attribute (Vladis Dronov) [RHEL-15642]
- crypto: qat - add rp2svc sysfs attribute (Vladis Dronov) [RHEL-15642]
- crypto: qat - add rate limiting sysfs interface (Vladis Dronov) [RHEL-15642]
- crypto: qat - add rate limiting feature to qat_4xxx (Vladis Dronov) [RHEL-15642]
- crypto: qat - add retrieval of fw capabilities (Vladis Dronov) [RHEL-15642]
- crypto: qat - add bits.h to icp_qat_hw.h (Vladis Dronov) [RHEL-15642]
- crypto: qat - move admin api (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix ring to service map for QAT GEN4 (Vladis Dronov) [RHEL-15642]
- crypto: qat - use masks for AE groups (Vladis Dronov) [RHEL-15642]
- crypto: qat - refactor fw config related functions (Vladis Dronov) [RHEL-15642]
- crypto: qat - count QAT GEN4 errors (Vladis Dronov) [RHEL-15642]
- crypto: qat - add error counters (Vladis Dronov) [RHEL-15642]
- crypto: qat - add handling of errors from ERRSOU3 for QAT GEN4 (Vladis Dronov) [RHEL-15642]
- crypto: qat - add adf_get_aram_base() helper function (Vladis Dronov) [RHEL-15642]
- crypto: qat - add handling of compression related errors for QAT GEN4 (Vladis Dronov) [RHEL-15642]
- crypto: qat - add handling of errors from ERRSOU2 for QAT GEN4 (Vladis Dronov) [RHEL-15642]
- crypto: qat - add reporting of errors from ERRSOU1 for QAT GEN4 (Vladis Dronov) [RHEL-15642]
- crypto: qat - add reporting of correctable errors for QAT GEN4 (Vladis Dronov) [RHEL-15642]
- crypto: qat - add infrastructure for error reporting (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix double free during reset (Vladis Dronov) [RHEL-15642]
- crypto: qat - add cnv_errors debugfs file (Vladis Dronov) [RHEL-15642]
- crypto: qat - add pm_status debugfs file (Vladis Dronov) [RHEL-15642]
- crypto: qat - refactor included headers (Vladis Dronov) [RHEL-15642]
- crypto: qat - Remove zlib-deflate (Vladis Dronov) [RHEL-15642]
- crypto: qat - increase size of buffers (Vladis Dronov) [RHEL-15642]
- crypto: qat - enable dc chaining service (Vladis Dronov) [RHEL-15642]
- crypto: qat - consolidate services structure (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix unregistration of compression algorithms (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix unregistration of crypto algorithms (Vladis Dronov) [RHEL-15642]
- crypto: qat - ignore subsequent state up commands (Vladis Dronov) [RHEL-15642]
- crypto: qat - do not shadow error code (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix state machines cleanup paths (Vladis Dronov) [RHEL-15642]
- crypto: qat - refactor deprecated strncpy (Vladis Dronov) [RHEL-15642]
- crypto: qat - Use list_for_each_entry() helper (Vladis Dronov) [RHEL-15642]
- Documentation: ABI: debugfs-driver-qat: fix fw_counters path (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix crypto capability detection for 4xxx (Vladis Dronov) [RHEL-15642]
- crypto: qat - Remove unused function declarations (Vladis Dronov) [RHEL-15642]
- crypto: qat - use kfree_sensitive instead of memset/kfree() (Vladis Dronov) [RHEL-15642]
- crypto: qat - replace the if statement with min() (Vladis Dronov) [RHEL-15642]
- crypto: qat - add heartbeat counters check (Vladis Dronov) [RHEL-15642]
- crypto: qat - add heartbeat feature (Vladis Dronov) [RHEL-15642]
- crypto: qat - add measure clock frequency (Vladis Dronov) [RHEL-15642]
- crypto: qat - drop obsolete heartbeat interface (Vladis Dronov) [RHEL-15642]
- crypto: qat - add internal timer for qat 4xxx (Vladis Dronov) [RHEL-15642]
- crypto: qat - add fw_counters debugfs file (Vladis Dronov) [RHEL-15642]
- crypto: qat - change value of default idle filter (Vladis Dronov) [RHEL-15642]
- crypto: qat - do not export adf_init_admin_pm() (Vladis Dronov) [RHEL-15642]
- crypto: qat - expose pm_idle_enabled through sysfs (Vladis Dronov) [RHEL-15642]
- crypto: qat - extend configuration for 4xxx (Vladis Dronov) [RHEL-15642]
- crypto: qat - refactor fw config logic for 4xxx (Vladis Dronov) [RHEL-15642]
- crypto: qat - make fw images name constant (Vladis Dronov) [RHEL-15642]
- crypto: qat - move returns to default case (Vladis Dronov) [RHEL-15642]
- crypto: qat - unmap buffers before free for RSA (Vladis Dronov) [RHEL-15642]
- crypto: qat - unmap buffer before free for DH (Vladis Dronov) [RHEL-15642]
- crypto: qat - update slice mask for 4xxx devices (Vladis Dronov) [RHEL-15642]
- crypto: qat - set deprecated capabilities as reserved (Vladis Dronov) [RHEL-15642]
- crypto: qat - add missing function declaration in adf_dbgfs.h (Vladis Dronov) [RHEL-15642]
- crypto: qat - move dbgfs init to separate file (Vladis Dronov) [RHEL-15642]
- crypto: qat - drop redundant adf_enable_aer() (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix apply custom thread-service mapping for dc service (Vladis Dronov) [RHEL-15642]
- crypto: qat - make state machine functions static (Vladis Dronov) [RHEL-15642]
- crypto: qat - refactor device restart logic (Vladis Dronov) [RHEL-15642]
- crypto: qat - replace state machine calls (Vladis Dronov) [RHEL-15642]
- crypto: qat - fix concurrency issue when device state changes (Vladis Dronov) [RHEL-15642]
- crypto: qat - delay sysfs initialization (Vladis Dronov) [RHEL-15642]
- crypto: qat - Include algapi.h for low-level Crypto API (Vladis Dronov) [RHEL-15642]
- crypto: rsa-pkcs1pad - Use helper to set reqsize (Vladis Dronov) [RHEL-15642]
- units: Add BYTES_PER_*BIT (Vladis Dronov) [RHEL-15642]

* Tue Dec 05 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-529.el8]
- netfilter: xt_sctp: validate the flag_info count (Wander Lairson Costa) [RHEL-11728] {CVE-2023-39193}
- nvmet: nul-terminate the NQNs passed in the connect command (Maurizio Lombardi) [RHEL-16690] {CVE-2023-6121}
- x86/speculation: Mark all Skylake CPUs as vulnerable to GDS (Waiman Long) [RHEL-3876]
- gve: Fix GFP flags when allocing pages (Izabela Bakollari) [2140228]
- Fix double fget() in vhost_net_set_backend() (Jon Maloy) [RHEL-7162] {CVE-2023-1838}
- mptcp: fix disconnect vs accept race (Davide Caratti) [RHEL-15347]
- mptcp: fix accept vs worker race (Davide Caratti) [RHEL-15347]
- mptcp: stops worker on unaccepted sockets at listener close (Davide Caratti) [RHEL-15347]
- mptcp: fix UaF in listener shutdown (Davide Caratti) [RHEL-15347]
- mptcp: fix lockdep false positive (Davide Caratti) [RHEL-15347]
- mptcp: use the workqueue to destroy unaccepted sockets (Davide Caratti) [RHEL-15347]
- mptcp: refactor passive socket initialization (Davide Caratti) [RHEL-15347]
- mptcp: set msk local address earlier (Davide Caratti) [RHEL-15347]
- mptcp: fix possible list corruption on passive MPJ (Davide Caratti) [RHEL-15347]
- mptcp: fix possible deadlock in subflow_error_report (Davide Caratti) [RHEL-15347]
- dmaengine: idxd: Modify the dependence of attribute pasid_enabled (Jerry Snitselaar) [RHEL-10101]
- dmaengine: ioatdma: use pci_dev_id() to simplify the code (Jerry Snitselaar) [RHEL-10101]
- dmaengine: Simplify dma_async_device_register() (Jerry Snitselaar) [RHEL-10101]
- dmaengine: qcom: hidma_mgmt: Use devm_platform_get_and_ioremap_resource() (Jerry Snitselaar) [RHEL-10101]
- dmaengine: qcom_hidma: Use devm_platform_get_and_ioremap_resource() (Jerry Snitselaar) [RHEL-10101]
- dmaengine: ioat: fixing the wrong dma_dev->chancnt (Jerry Snitselaar) [RHEL-10101]
- dmaengine: hidma: Don't set chancnt (Jerry Snitselaar) [RHEL-10101]
- dmaengine: ioat: Free up __cleanup() name (Jerry Snitselaar) [RHEL-10101]
- dmaengine: idxd: Fix passing freed memory in idxd_cdev_open() (Jerry Snitselaar) [RHEL-10101]
- dmaengine: idxd: make misc interrupt one shot (Jerry Snitselaar) [RHEL-10101]
- dmaengine: ioat: Drop redundant pci_enable_pcie_error_reporting() (Jerry Snitselaar) [RHEL-10101]
- dmaengine: ioat: use PCI core macros for PCIe Capability (Jerry Snitselaar) [RHEL-10101]
- dmaengine: idxd: Allow ATS disable update only for configurable devices (Jerry Snitselaar) [RHEL-10101]
- dmaengine: idxd: Expose ATS disable knob only when WQ ATS is supported (Jerry Snitselaar) [RHEL-10101]
- dmaengine: idxd: Simplify WQ attribute visibility checks (Jerry Snitselaar) [RHEL-10101]
- dmaengine: idxd: use spin_lock_irqsave before wait_event_lock_irq (Jerry Snitselaar) [RHEL-10101]
- dmaengine: Actually use devm_add_action_or_reset() (Jerry Snitselaar) [RHEL-10101]
- clk: fix leak on devm_clk_bulk_get_all() unwind (Jerry Snitselaar) [RHEL-10101]
- drm/amdgpu: Fix possible null pointer dereference (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/amdgpu: Fix possible null pointer dereference (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Keep a gem reference to user bos in surfaces (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: fix typo of sizeof argument (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Fix possible invalid drm gem put calls (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Fix shader stage validation (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: remove unused vmw_overlay function (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Fix Legacy Display Unit atomic drm support (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Print errors when running on broken/unsupported configs (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Drop mksstat_init_record fn as currently unused (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Fix src/dst_pitch confusion (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Replace one-element array with flexible-array member (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Do not drop the reference to the handle too soon (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Stop accessing buffer objects which failed init (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Make the driver work without the dummy resources (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Stop using raw ttm_buffer_object's (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Abstract placement selection (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Rename dummy to is_iomem (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Cleanup the vmw bo usage in the cursor paths (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Simplify fb pinning (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Rename vmw_buffer_object to vmw_bo (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Remove the duplicate bo_free function (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/vmwgfx: Use the common gem mmap instead of the custom code (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/radeon: handle NULL bo->resource in move callback (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/qxl: handle NULL bo->resource in move callback (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/gem-vram: handle NULL bo->resource in move callback (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/ttm: prevent moving of pinned BOs (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/ttm: stop allocating a dummy resource for pipelined gutting (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/ttm: stop allocating dummy resources during BO creation (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/ttm: clear the ttm_tt when bo->resource is NULL (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- drm/i915/ttm: audit remaining bo->resource (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- Revert "drm/vmwgfx: Stop accessing buffer objects which failed init" (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- Revert "drm/vmwgfx: Do not drop the reference to the handle too soon" (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- Revert "drm/vmwgfx: Fix Legacy Display Unit atomic drm support" (Jocelyn Falempe) [RHEL-14510] {CVE-2023-5633}
- ACPI: NFIT: Fix incorrect calculation of idt size (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Add IRQ override quirk for LG UltraPC 17U70P (Mark Langsdorf) [RHEL-1021]
- ACPI: property: Support strings in Apple _DSM props (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: utils: Remove Lenovo Yoga Tablet 2's MAGN0001 (Mark Langsdorf) [RHEL-1021]
- ACPI: PM: Do not turn of unused power resources on the Toshiba Click Mini (Mark Langsdorf) [RHEL-1021]
- ACPI: LPSS: Add 80862289 ACPI _HID for second PWM controller on Cherry Trail (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Ensure that notify handlers are not running after removal (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Add missing braces to acpi_sb_notify() (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CBA (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: utils: Add Picasso to the list for forcing StorageD3Enable (Mark Langsdorf) [RHEL-1021]
- ACPICA: ACPICA: check null return of ACPI_ALLOCATE_ZEROED in acpi_db_display_objects (Mark Langsdorf) [RHEL-1021]
- ACPICA: acpi_madt_oem_data: Fix flexible array member definition (Mark Langsdorf) [RHEL-1021]
- ACPICA: acpi_dmar_andd: Replace 1-element array with flexible array (Mark Langsdorf) [RHEL-1021]
- ACPICA: acpi_pci_routing_table: Replace fixed-size array with flex array member (Mark Langsdorf) [RHEL-1021]
- ACPICA: struct acpi_resource_dma: Replace 1-element array with flexible array (Mark Langsdorf) [RHEL-1021]
- ACPICA: actbl1: Replace 1-element arrays with flexible arrays (Mark Langsdorf) [RHEL-1021]
- ACPICA: struct acpi_resource_vendor: Replace 1-element array with flexible array (Mark Langsdorf) [RHEL-1021]
- ACPICA: acpi_resource_irq: Replace 1-element arrays with flexible array (Mark Langsdorf) [RHEL-1021]
- ACPICA: struct acpi_nfit_interleave: Replace 1-element array with flexible array (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: load of misaligned address (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: member access within null pointer (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: member access within misaligned address (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: member access within misaligned address (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: member access within misaligned address (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: member access within misaligned address (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: applying zero offset to null pointer (Mark Langsdorf) [RHEL-1021]
- ACPICA: Avoid undefined behavior: load of misaligned address (Mark Langsdorf) [RHEL-1021]
- ACPICA: actbl2: Replace 1-element arrays with flexible arrays (Mark Langsdorf) [RHEL-1021]
- ACPICA: Introduce ACPI_FLEX_ARRAY (Mark Langsdorf) [RHEL-1021]
- ACPICA: add support for ClockInput resource (v6.5) (Mark Langsdorf) [RHEL-1021]
- ACPICA: Update all copyrights/signons to 2023 (Mark Langsdorf) [RHEL-1021]
- ACPICA: acpisrc: Add missing tables to astable (Mark Langsdorf) [RHEL-1021]
- ACPICA: Add missing macro ACPI_FUNCTION_TRACE() for acpi_ns_repair_HID() (Mark Langsdorf) [RHEL-1021]
- ACPI: EC: Fix oops when removing custom query handlers (Mark Langsdorf) [RHEL-1021]
- ACPI: EC: Limit explicit removal of query handlers to custom query handlers (Mark Langsdorf) [RHEL-1021]
- ACPI: SPCR: Amend indentation (Mark Langsdorf) [RHEL-1021]
- ACPI: property: Refactor acpi_data_prop_read_single() (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: EINJ: warn on invalid argument when explicitly indicated by platform (Mark Langsdorf) [RHEL-1021]
- ACPI: sysfs: Enable ACPI sysfs support for CCEL records (Mark Langsdorf) [RHEL-1021]
- ACPICA: iASL: Add CCEL table to both compiler/disassembler (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Rework system-level device notification handling (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Add Medion S17413 to IRQ override quirk (Mark Langsdorf) [RHEL-1021]
- ACPI: LPIT: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1021]
- ACPI: SPCR: Prefix error messages with FW_BUG (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: Fix evaluating _PDC method when running as Xen dom0 (Mark Langsdorf) [RHEL-1021]
- ACPI: s2idle: Log when enabling wakeup IRQ fails (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: Check for null return of devm_kzalloc() in fch_misc_setup() (Mark Langsdorf) [RHEL-1021]
- ACPI: PPTT: Fix to avoid sleep in the atomic context when PPTT is absent (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: Add skip i2c clients quirk for Lenovo Yoga Book X90 (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: utils: Add Cezanne to the list for forcing StorageD3Enable (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Skip IRQ override on Asus Expertbook B2402FBA (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Do IRQ override on all TongFang GMxRGxx (Mark Langsdorf) [RHEL-1021]
- ACPI: make kobj_type structures constant (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Add IRQ overrides for MAINGEAR Vector Pro 2 models (Mark Langsdorf) [RHEL-1021]
- ACPI: PMIC: Add comments with DSDT power opregion field names (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: EINJ: Limit error type to 32-bit width (Mark Langsdorf) [RHEL-1021]
- ACPI: NFIT: fix a potential deadlock during NFIT teardown (Mark Langsdorf) [RHEL-1021]
- ACPI: Don't build ACPICA with '-Os' (Mark Langsdorf) [RHEL-1021]
- ACPI: PRM: Check whether EFI runtime is available (Mark Langsdorf) [RHEL-1021]
- ACPI: PNP: Introduce list of known non-PNP devices (Mark Langsdorf) [RHEL-1021]
- ACPICA: nsrepair: handle cases without a return value correctly (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Skip IRQ override on Asus Expertbook B2402CBA (Mark Langsdorf) [RHEL-1021]
- ACPI: Silence missing prototype warnings (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Avoid updating frequency QoS unnecessarily (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Use the "no limit" frequency QoS (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: idle: Drop unnecessary (void *) conversion (Mark Langsdorf) [RHEL-1021]
- ACPICA: Constify pathname argument for acpi_get_handle() (Mark Langsdorf) [RHEL-1021]
- ACPICA: Drop port I/O validation for some regions (Mark Langsdorf) [RHEL-1021]
- ACPI: PMIC: Add pmic_i2c_address to BYT Crystal Cove support (Mark Langsdorf) [RHEL-1021]
- ACPI: tables: Add support for NBFT (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Force AMD GUID/_REV 2 on HP Elitebook 865 (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Stop using AMD specific codepath for Rembrandt+ (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Add Asus ExpertBook B2502 to Asus quirks (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: do IRQ override on Lenovo 14ALC7 (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: do IRQ override on XMG Core 15 (Mark Langsdorf) [RHEL-1021]
- ACPI: EC: Fix ECDT probe ordering issues (Mark Langsdorf) [RHEL-1021]
- ACPI: EC: Fix EC address space handler unregistration (Mark Langsdorf) [RHEL-1021]
- ACPICA: Allow address_space_handler Install and _REG execution as 2 separate steps (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: Add skip i2c clients quirk for Medion Lifetab S10346 (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: EINJ: Refactor available_error_type_show() (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: EINJ: Fix formatting errors (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Adjust acpi_processor_notify_smm() return value (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Rearrange acpi_processor_notify_smm() (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Rearrange unregistration routine (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Drop redundant parentheses (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: perflib: Adjust white space (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: idle: Drop unnecessary statements and parens (Mark Langsdorf) [RHEL-1021]
- ACPI: thermal: Adjust critical.flags.valid check (Mark Langsdorf) [RHEL-1021]
- ACPI: fan: Convert to use sysfs_emit_at() API (Mark Langsdorf) [RHEL-1021]
- ACPICA: Fix use-after-free in acpi_ut_copy_ipackage_to_ipackage() (Mark Langsdorf) [RHEL-1021]
- ACPI: use sysfs_emit() instead of scnprintf() (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: Add skip i2c clients quirk for Lenovo Yoga Tab 3 Pro (YT3-X90F) (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: Remove a useless include (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: Silence missing prototype warnings (Mark Langsdorf) [RHEL-1021]
- ACPI: fan: Bail out if extract package failed (Mark Langsdorf) [RHEL-1021]
- ACPI: pfr_telemetry: use ACPI_FREE() to free acpi_object (Mark Langsdorf) [RHEL-1021]
- ACPI: pfr_update: use ACPI_FREE() to free acpi_object (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Fix the _OSC capability check for FFH OpRegion (Mark Langsdorf) [RHEL-1021]
- ACPI: HMAT: Fix initiator registration for single-initiator systems (Mark Langsdorf) [RHEL-1021]
- ACPI: HMAT: remove unnecessary variable initialization (Mark Langsdorf) [RHEL-1021]
- ACPI: APMT: Fix kerneldoc and indentation (Mark Langsdorf) [RHEL-1021]
- ACPI: Implement a generic FFH Opregion handler (Mark Langsdorf) [RHEL-1021]
- redhat: configs: enable  FFH OpRegion handlers (Mark Langsdorf) [RHEL-1021]
- ACPI: Enable FPDT on arm64 (Mark Langsdorf) [RHEL-1021]
- ACPI: sysfs: use sysfs_emit() to instead of scnprintf() (Mark Langsdorf) [RHEL-1021]
- ACPI: irq: Fix some kernel-doc issues (Mark Langsdorf) [RHEL-1021]
- ACPI: tables: Fix the stale comments for acpi_locate_initial_tables() (Mark Langsdorf) [RHEL-1021]
- ACPI: HMAT: use hotplug_memory_notifier() directly (Mark Langsdorf) [RHEL-1021]
- ACPICA: Fix error code path in acpi_ds_call_control_method() (Mark Langsdorf) [RHEL-1021]
- ACPICA: Add utcksum.o to the acpidump Makefile (Mark Langsdorf) [RHEL-1021]
- ACPI/IORT: Update SMMUv3 DeviceID support (Mark Langsdorf) [RHEL-1021]
- ACPI: ARM Performance Monitoring Unit Table (APMT) initial support (Mark Langsdorf) [RHEL-1021]
- ACPI: sysfs: Use kstrtobool() instead of strtobool() (Mark Langsdorf) [RHEL-1021]
- ACPI: EC: Add quirk for the HP Pavilion Gaming 15-cx0041ur (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: throttling: remove variable count (Mark Langsdorf) [RHEL-1021]
- ACPI: processor: idle: Check acpi_fetch_acpi_dev() return value (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: Drop unsetting driver data on remove (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: Add another system to quirk list for forcing StorageD3Enable (Mark Langsdorf) [RHEL-1021]
- ACPICA: Finish support for the CDAT table (Mark Langsdorf) [RHEL-1021]
- ACPICA: Improve warning message for "invalid ACPI name" (Mark Langsdorf) [RHEL-1021]
- ACPICA: Check that EBDA pointer is in valid memory (Mark Langsdorf) [RHEL-1021]
- arm64: acpi: Fix possible memory leak of ffh_ctxt (Mark Langsdorf) [RHEL-1021]
- arm64: Add architecture specific ACPI FFH Opregion callbacks (Mark Langsdorf) [RHEL-1021]
- ACPICA: Add support for FFH Opregion special context data (Mark Langsdorf) [RHEL-1021]
- ACPICA: Do not touch VGA memory when EBDA < 1ki_b (Mark Langsdorf) [RHEL-1021]
- ACPICA: Make acpi_ex_load_op() match upstream (Mark Langsdorf) [RHEL-1021]
- ACPI: scan: Add LATT2021 to acpi_ignore_dep_ids[] (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Skip IRQ override on Asus Vivobook S5602ZA (Mark Langsdorf) [RHEL-1021]
- apei/ghes: Use xchg_release() for updating new cache slot instead of cmpxchg() (Mark Langsdorf) [RHEL-1021]
- ACPI: PCI: Fix device reference counting in acpi_get_pci_dev() (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: note more about IRQ override (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: do IRQ override on LENOVO IdeaPad (Mark Langsdorf) [RHEL-1021]
- ACPI: extlog: Handle multiple records (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: Fix integer overflow in ghes_estatus_pool_init() (Mark Langsdorf) [RHEL-1021]
- ACPI: thermal: Drop redundant parens from expressions (Mark Langsdorf) [RHEL-1021]
- ACPI: thermal: Use white space more consistently (Mark Langsdorf) [RHEL-1021]
- ACPI: thermal: Drop some redundant code (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: do not add task_work to kernel thread to avoid memory leak (Mark Langsdorf) [RHEL-1021]
- ACPI: PM: Take wake IRQ into consideration when entering suspend-to-idle (Mark Langsdorf) [RHEL-1021]
- ACPI: resources: Add wake_capable parameter to acpi_dev_irq_flags (Mark Langsdorf) [RHEL-1021]
- ACPI: LPSS: Replace loop with first entry retrieval (Mark Langsdorf) [RHEL-1021]
- ACPI: LPSS: Deduplicate skipping device in acpi_lpss_create_device() (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Fix a NULL pointer dereference (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Add another ID to s2idle_dmi_table (Mark Langsdorf) [RHEL-1021]
- ACPI: Kconfig: Drop link to https://01.org/linux-acpi (Mark Langsdorf) [RHEL-1021]
- ACPI: DPTF: Drop stale link from Kconfig help (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Add a quirk for ASUSTeK COMPUTER INC. ROG Flow X13 (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Add a quirk for ASUS ROG Zephyrus G14 (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Add a quirk for Lenovo Slim 7 Pro 14ARH7 (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: If a new AMD _HID is missing assume Rembrandt (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Add a quirk for ASUS TUF Gaming A17 FA707RE (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Move _HID handling for AMD systems into structures (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: s2idle: Add module parameter to prefer Microsoft GUID (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Add ASUS model S5402ZA to quirks (Mark Langsdorf) [RHEL-1021]
- ACPI: AMBA: Add ARM DMA-330 controller to the supported list (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: Remove unneeded result variables (Mark Langsdorf) [RHEL-1021]
- ACPI: fan: Reorder symbols to get rid of a few forward declarations (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: Add a quirk for Dell Inspiron 14 2-in-1 for StorageD3Enable (Mark Langsdorf) [RHEL-1021]
- ACPI: PCI: Rework acpi_get_pci_dev() (Mark Langsdorf) [RHEL-1021]
- ACPI: HMAT: Drop unused dev_fmt() and redundant 'HMAT' prefix (Mark Langsdorf) [RHEL-1021]
- ACPI: x86: Refactor _UID handling to use acpi_dev_uid_to_integer() (Mark Langsdorf) [RHEL-1021]
- ACPI: LPSS: Refactor _UID handling to use acpi_dev_uid_to_integer() (Mark Langsdorf) [RHEL-1021]
- ACPI: utils: Add acpi_dev_uid_to_integer() helper to get _UID as integer (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Add helper function acpi_dev_get_memory_resources() (Mark Langsdorf) [RHEL-1021]
- ACPI: LPSS: Use the helper acpi_dev_get_memory_resources() (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Skip IRQ override on Asus Vivobook K3402ZA/K3502ZA (Mark Langsdorf) [RHEL-1021]
- ACPI: APD: Use the helper acpi_dev_get_memory_resources() (Mark Langsdorf) [RHEL-1021]
- ACPI: resource: Filter out the non memory resources in is_memory() (Mark Langsdorf) [RHEL-1021]
- ACPI: tables: FPDT: Don't call acpi_os_map_memory() on invalid phys address (Mark Langsdorf) [RHEL-1021]
- ACPI: s2idle: Add a new ->check() callback for platform_s2idle_ops (Mark Langsdorf) [RHEL-1021]
- ACPI: property: Silence missing-declarations warning in apple.c (Mark Langsdorf) [RHEL-1021]
- ACPI: platform: Use PLATFORM_DEVID_NONE in acpi_create_platform_device() (Mark Langsdorf) [RHEL-1021]
- ACPI: platform: Remove redundant print on -ENOMEM (Mark Langsdorf) [RHEL-1021]
- ACPI: platform: Sort forbidden_id_list[] in ascending order (Mark Langsdorf) [RHEL-1021]
- ACPI: platform: Use sizeof(*pointer) instead of sizeof(type) (Mark Langsdorf) [RHEL-1021]
- ACPI: property: Use acpi_dev_parent() (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Refactor ACPI matching functions for better readability (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Drop kernel doc annotation from acpi_bus_notify() (Mark Langsdorf) [RHEL-1021]
- ACPI: EC: Drop unneeded result variable from ec_write() (Mark Langsdorf) [RHEL-1021]
- ACPI: APEI: Add BERT error log footer (Mark Langsdorf) [RHEL-1021]
- platform/x86: asus-wmi: Move acpi_backlight=native quirks to ACPI video_detect.c (Mark Langsdorf) [RHEL-1021]
- ACPI: video: Fix indentation of video_detect_dmi_table[] entries (Mark Langsdorf) [RHEL-1021]
- platform/x86: acer-wmi: Move backlight DMI quirks to acpi/video_detect.c (Mark Langsdorf) [RHEL-1021]
- platform/x86: asus-wmi: Move acpi_backlight=vendor quirks to ACPI video_detect.c (Mark Langsdorf) [RHEL-1021]
- ACPI: video: Refactor acpi_video_get_backlight_type() a bit (Mark Langsdorf) [RHEL-1021]
- ACPI: video: Simplify acpi_video_unregister_backlight() (Mark Langsdorf) [RHEL-1021]
- ACPI: video: Remove acpi_video_bus from list before tearing it down (Mark Langsdorf) [RHEL-1021]
- ACPI: video: Remove code to unregister acpi_video backlight when a native backlight registers (Mark Langsdorf) [RHEL-1021]
- ACPI: PM: Fix NULL argument handling in acpi_device_get/set_power() (Mark Langsdorf) [RHEL-1021]
- ACPI: bus: Remove the unneeded result variable (Mark Langsdorf) [RHEL-1021]
- ACPI: OSI: Remove Linux-HPI-Hybrid-Graphics _OSI string (Mark Langsdorf) [RHEL-1021]
- ACPI: OSI: Remove Linux-Lenovo-NV-HDMI-Audio _OSI string (Mark Langsdorf) [RHEL-1021]
- ACPI: OSI: Remove Linux-Dell-Video _OSI string (Mark Langsdorf) [RHEL-1021]
- ACPI: Drop parent field from struct acpi_device (Mark Langsdorf) [RHEL-1021]
- ACPI: move from strlcpy() with unused retval to strscpy() (Mark Langsdorf) [RHEL-1021]
- ACPI: PM: Fix acpi_dev_state_d0() kerneldoc (Mark Langsdorf) [RHEL-1021]
- ACPI: scan: Eliminate __acpi_device_add() (Mark Langsdorf) [RHEL-1021]
- ACPI: scan: Rearrange initialization of ACPI device objects (Mark Langsdorf) [RHEL-1021]
- ACPI: Rename acpi_bus_get/put_acpi_device() (Mark Langsdorf) [RHEL-1021]
- ACPI: scan: Rename acpi_bus_get_parent() and rearrange it (Mark Langsdorf) [RHEL-1021]

* Thu Nov 30 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-528.el8]
- s390/smp: move rcu_cpu_starting() earlier (Joel Savitz) [RHEL-8624]
- net: fix net device address assign type (Michal Schmidt) [RHEL-6383]
- net: add check for current MAC address in dev_set_mac_address (Michal Schmidt) [RHEL-6383]
- writeback, cgroup: Fix kernel bootup panic with cgroup v2 (Waiman Long) [RHEL-17504]
- net/tls: Remove the context from the list in tls_device_down (Jay Shin) [RHEL-17301]
- tls: Fix context leak on tls_device_down (Jay Shin) [RHEL-17301]
- RDMA/core: Require admin capabilities to set system parameters (Kamal Heib) [RHEL-1033]
- RDMA/cma: Initialize ib_sa_multicast structure to 0 when join (Kamal Heib) [RHEL-1033]
- RDMA/core: Use size_{add,sub,mul}() in calls to struct_size() (Kamal Heib) [RHEL-1033]
- RDMA/cma: Fix truncation compilation warning in make_cma_ports (Kamal Heib) [RHEL-1033]
- RDMA/uverbs: Fix typo of sizeof argument (Kamal Heib) [RHEL-1033]
- IB/uverbs: Fix an potential error pointer dereference (Kamal Heib) [RHEL-1033]
- scsi: RDMA/srp: Fix residual handling (Kamal Heib) [RHEL-1033]
- rdma: fix INFINIBAND_USER_ACCESS dependency (Kamal Heib) [RHEL-1033]
- gfs2: Fix quota=quiet oversight (Bob Peterson) [RHEL-14849]
- gfs2: Free quota data objects synchronously (Andreas Gruenbacher) [RHEL-14849]
- gfs2: Fix initial quota data refcount (Andreas Gruenbacher) [RHEL-14849]
- gfs2: Factor out duplicate quota data disposal code (Andreas Gruenbacher) [RHEL-14849]
- gfs2: Use gfs2_qd_dispose in gfs2_quota_cleanup (Andreas Gruenbacher) [RHEL-14849]
- gfs2: Fix wrong quota shrinker return value (Andreas Gruenbacher) [RHEL-14849]
- gfs2: ignore negated quota changes (Bob Peterson) [RHEL-14849]
- gfs2: Introduce new quota=quiet mount option (Bob Peterson) [RHEL-14849]
- gfs2: Rename sd_{ glock => kill }_wait (Andreas Gruenbacher) [RHEL-14849]
- Bluetooth: btrtl: Set MSFT opcode for RTL8852 (David Marlin) [RHEL-2531]
- Bluetooth: Fix return value in hci_dev_do_close() (David Marlin) [RHEL-2531]
- Bluetooth: add timeout sanity check to hci_inquiry (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Remove WAKEUP_DISABLE and add WAKEUP_AUTOSUSPEND for Realtek devices (David Marlin) [RHEL-2531]
- Bluetooth: mgmt: Pessimize compile-time bounds-check (David Marlin) [RHEL-2531]
- Bluetooth: Fix race condition in handling NOP command (David Marlin) [RHEL-2531]
- Bluetooth: btbcm: add patch ram for bluetooth (David Marlin) [RHEL-2531]
- Bluetooth: Store advertising handle so it can be re-enabled (David Marlin) [RHEL-2531]
- Bluetooth: Fix handling of LE Enhanced Connection Complete (David Marlin) [RHEL-2531]
- Bluetooth: fix repeated calls to sco_sock_kill (David Marlin) [RHEL-2531]
- Bluetooth: switch to lock_sock in RFCOMM (David Marlin) [RHEL-2531]
- Bluetooth: serialize calls to sco_sock_{set,clear}_timer (David Marlin) [RHEL-2531]
- Bluetooth: switch to lock_sock in SCO (David Marlin) [RHEL-2531]
- Bluetooth: avoid circular locks in sco_sock_connect (David Marlin) [RHEL-2531]
- Bluetooth: schedule SCO timeouts with delayed_work (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Fix fall-through warnings (David Marlin) [RHEL-2531]
- Bluetooth: btintel: Combine setting up MSFT extension (David Marlin) [RHEL-2531]
- Bluetooth: increase BTNAMSIZ to 21 chars to fix potential buffer overflow (David Marlin) [RHEL-2531]
- Bluetooth: Add additional Bluetooth part for Realtek 8852AE (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Record debug log for Mediatek Chip. (David Marlin) [RHEL-2531]
- Bluetooth: hci_bcm: Fix kernel doc comments (David Marlin) [RHEL-2531]
- Bluetooth: Fix not generating RPA when required (David Marlin) [RHEL-2531]
- Bluetooth: HCI: Add proper tracking for enable status of adv instances (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Enable MSFT extension for Mediatek Chip (MT7921) (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Make the CSR clone chip force-suspend workaround more generic (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Enable MSFT extension for WCN6855 controller (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Load Broadcom firmware for Dell device 413c:8197 (David Marlin) [RHEL-2531]
- Bluetooth: btmrvl_sdio: Remove all strcpy() uses (David Marlin) [RHEL-2531]
- Bluetooth: skip invalid hci_sync_conn_complete_evt (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Add valid le states quirk (David Marlin) [RHEL-2531]
- Bluetooth: hci_h5: Add runtime suspend (David Marlin) [RHEL-2531]
- Bluetooth: hci_h5: btrtl: Maintain flow control if wakeup is enabled (David Marlin) [RHEL-2531]
- Bluetooth: hci_h5: add WAKEUP_DISABLE flag (David Marlin) [RHEL-2531]
- Bluetooth: btrsi: use non-kernel-doc comment for copyright (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Add support for LG LGSBWAC92/TWCM-K505D (David Marlin) [RHEL-2531]
- Bluetooth: sco: prevent information leak in sco_conn_defer_accept() (David Marlin) [RHEL-2531]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip (David Marlin) [RHEL-2531]
- Bluetooth: hci_h5: Disable the hci_suspend_notifier for btrtl devices (David Marlin) [RHEL-2531]
- Bluetooth: msft: Use the correct print format (David Marlin) [RHEL-2531]
- Bluetooth: mgmt: Use the correct print format (David Marlin) [RHEL-2531]
- Bluetooth: use inclusive language in hci_core.h (David Marlin) [RHEL-2531]
- Bluetooth: btqca: Moved extracting rom version info to common place (David Marlin) [RHEL-2531]
- Bluetooth: btqca: Add support for firmware image with mbn type for WCN6750 (David Marlin) [RHEL-2531]
- Bluetooth: hci_qca: Add support for QTI Bluetooth chip wcn6750 (David Marlin) [RHEL-2531]
- Bluetooth: use flexible-array member instead of zero-length array (David Marlin) [RHEL-2531]
- Bluetooth: Fix default values for advertising interval (David Marlin) [RHEL-2531]
- Bluetooth: Remove trailing semicolon in macros (David Marlin) [RHEL-2531]
- Bluetooth: Fix crash in mgmt_add_adv_patterns_monitor_complete (David Marlin) [RHEL-2531]
- Bluetooth: disable advertisement filters during suspend (David Marlin) [RHEL-2531]
- Bluetooth: advmon offload MSFT interleave scanning integration (David Marlin) [RHEL-2531]
- Bluetooth: advmon offload MSFT handle filter enablement (David Marlin) [RHEL-2531]
- Bluetooth: advmon offload MSFT handle controller reset (David Marlin) [RHEL-2531]
- Bluetooth: advmon offload MSFT remove monitor (David Marlin) [RHEL-2531]
- Bluetooth: advmon offload MSFT add monitor (David Marlin) [RHEL-2531]
- Bluetooth: advmon offload MSFT add rssi support (David Marlin) [RHEL-2531]
- Bluetooth: btrtl: Enable MSFT extension for RTL8822CE controller (David Marlin) [RHEL-2531]
- Bluetooth: btqca: Enable MSFT extension for Qualcomm WCN399x (David Marlin) [RHEL-2531]
- Bluetooth: btqca: Use NVM files based on SoC ID for WCN3991 (David Marlin) [RHEL-2531]
- Bluetooth: fix typo in struct name (David Marlin) [RHEL-2531]
- Bluetooth: btqca: Add valid le states quirk (David Marlin) [RHEL-2531]
- Bluetooth: ath3k: use usb_control_msg_send() and usb_control_msg_recv() (David Marlin) [RHEL-2531]
- Bluetooth: Use fallthrough pseudo-keyword (David Marlin) [RHEL-2531]
- Bluetooth: hci_qca: Enable WBS support for wcn3991 (David Marlin) [RHEL-2531]
- Bluetooth: L2CAP: Replace zero-length array with flexible-array (David Marlin) [RHEL-2531]
- Bluetooth: Replace BT_DBG with bt_dev_dbg for security manager support (David Marlin) [RHEL-2531]
- Bluetooth: Replace BT_DBG with bt_dev_dbg for management support (David Marlin) [RHEL-2531]
- Bluetooth: Clear HCI_LL_RPA_RESOLUTION flag on reset (David Marlin) [RHEL-2531]
- Bluetooth: Sort list of LE features constants (David Marlin) [RHEL-2531]
- Bluetooth: Add HCI device identifier for VIRTIO devices (David Marlin) [RHEL-2531]
- Bluetooth: hci_qca: Add support for Qualcomm Bluetooth SoC QCA6390 (David Marlin) [RHEL-2531]
- Bluetooth: Fixing a few comment typos in the quirk definitions. (David Marlin) [RHEL-2531]
- Bluetooth: hci_qca: Add support for Qualcomm Bluetooth SoC WCN3991 (David Marlin) [RHEL-2531]
- Bluetooth: btsdio: Use module_sdio_driver helper (David Marlin) [RHEL-2531]
- mmc: sdio: Add helper macro for sdio_driver boilerplate (David Marlin) [RHEL-2531]
- kasan: add compiler barriers to KUNIT_EXPECT_KASAN_FAIL (Nico Pache) [RHEL-5622]
- redhat: add new tests (Nico Pache) [RHEL-5622]
- redhat: disable kunit by default (Nico Pache) [RHEL-5622]
- kasan: fix unit tests with CONFIG_UBSAN_LOCAL_BOUNDS enabled (Nico Pache) [RHEL-5622]
- kasan: fix array-bounds warnings in tests (Nico Pache) [RHEL-5622]
- kasan: test: Silence GCC 12 warnings (Nico Pache) [RHEL-5622]
- tracepoint: Allow trace events in modules with TAINT_TEST (Nico Pache) [RHEL-5622]
- kunit: Fix missed memory release in kunit_free_suite_set() (Nico Pache) [RHEL-5622]
- kunit: fix kunit_test_init_section_suites(...) (Nico Pache) [RHEL-5622]
- kunit: tool: print summary of failed tests if a few failed out of a lot (Nico Pache) [RHEL-5622]
- kunit: alloc_string_stream_fragment error handling bug fix (Nico Pache) [RHEL-5622]
- kunit: Fix wild-memory-access bug in kunit_free_suite_set() (Nico Pache) [RHEL-5622]
- Documentation: kunit: Modular tests should not depend on KUNIT=y (Nico Pache) [RHEL-5622]
- kunit: update NULL vs IS_ERR() tests (Nico Pache) [RHEL-5622]
- Documentation: kunit: Update description of --alltests option (Nico Pache) [RHEL-5622]
- kunit: declare kunit_assert structs as const (Nico Pache) [RHEL-5622]
- kunit: rename base KUNIT_ASSERTION macro to _KUNIT_FAILED (Nico Pache) [RHEL-5622]
- kunit: remove format func from struct kunit_assert, get it to 0 bytes (Nico Pache) [RHEL-5622]
- kunit: make kunit_kfree(NULL) a no-op to match kfree() (Nico Pache) [RHEL-5622]
- kunit: make kunit_kfree() not segfault on invalid inputs (Nico Pache) [RHEL-5622]
- kunit: make kunit_kfree() only work on pointers from kunit_malloc() and friends (Nico Pache) [RHEL-5622]
- kunit: drop test pointer in string_stream_fragment (Nico Pache) [RHEL-5622]
- kunit: string-stream: Simplify resource use (Nico Pache) [RHEL-5622]
- Documentation: Kunit: Use full path to .kunitconfig (Nico Pache) [RHEL-5622]
- kunit: tool: rename all_test_uml.config, use it for --alltests (Nico Pache) [RHEL-5622]
- kunit: tool: remove UML specific options from all_tests_uml.config (Nico Pache) [RHEL-5622]
- lib: stackinit: update reference to kunit-tool (Nico Pache) [RHEL-5622]
- Documentation: KUnit: update links in the index page (Nico Pache) [RHEL-5622]
- Documentation: KUnit: add intro to the getting-started page (Nico Pache) [RHEL-5622]
- Documentation: KUnit: Reword start guide for selecting tests (Nico Pache) [RHEL-5622]
- Documentation: KUnit: add note about mrproper in start.rst (Nico Pache) [RHEL-5622]
- Documentation: KUnit: avoid repeating "kunit.py run" in start.rst (Nico Pache) [RHEL-5622]
- Documentation: KUnit: remove duplicated docs for kunit_tool (Nico Pache) [RHEL-5622]
- Documentation: Kunit: Add ref for other kinds of tests (Nico Pache) [RHEL-5622]
- Documentation: KUnit: Fix non-uml anchor (Nico Pache) [RHEL-5622]
- Documentation: Kunit: Fix inconsistent titles (Nico Pache) [RHEL-5622]
- Documentation: kunit: fix trivial typo (Nico Pache) [RHEL-5622]
- kunit: no longer call module_info(test, "Y") for kunit modules (Nico Pache) [RHEL-5622]
- kunit: add kunit.enable to enable/disable KUnit test (Nico Pache) [RHEL-5622]
- kunit: tool: make --raw_output=kunit (aka --raw_output) preserve leading spaces (Nico Pache) [RHEL-5622]
- module: kunit: Load .kunit_test_suites section when CONFIG_KUNIT=m (Nico Pache) [RHEL-5622]
- MAINTAINERS: kunit: add David Gow as a maintainer of KUnit (Nico Pache) [RHEL-5622]
- Documentation: KUnit: Fix example with compilation error (Nico Pache) [RHEL-5622]
- Documentation: kunit: Add CLI args for kunit_tool (Nico Pache) [RHEL-5622]
- kunit: flatten kunit_suite*** to kunit_suite** in .kunit_test_suites (Nico Pache) [RHEL-5622]
- kunit: unify module and builtin suite definitions (Nico Pache) [RHEL-5622]
- Documentation: kunit: fix example run_kunit func to allow spaces in args (Nico Pache) [RHEL-5622]
- kunit: test.h: fix a kernel-doc markup (Nico Pache) [RHEL-5622]
- kunit: tool: Enable virtio/PCI by default on UML (Nico Pache) [RHEL-5622]
- kunit: tool: make --kunitconfig repeatable, blindly concat (Nico Pache) [RHEL-5622]
- kunit: add coverage_uml.config to enable GCOV on UML (Nico Pache) [RHEL-5622]
- kunit: tool: refactor internal kconfig handling, allow overriding (Nico Pache) [RHEL-5622]
- kunit: tool: introduce --qemu_args (Nico Pache) [RHEL-5622]
- kunit: tool: simplify creating LinuxSourceTreeOperations (Nico Pache) [RHEL-5622]
- kunit: tool: cosmetic: don't specify duplicate kernel cmdline options (Nico Pache) [RHEL-5622]
- kunit: tool: refactoring printing logic into kunit_printer.py (Nico Pache) [RHEL-5622]
- kunit: tool: redo how we construct and mock LinuxSourceTree (Nico Pache) [RHEL-5622]
- kunit: tool: drop unused load_config argument (Nico Pache) [RHEL-5622]
- apparmor: test: Remove some casts which are no-longer required (Nico Pache) [RHEL-5622]
- kunit: Taint the kernel when KUnit tests are run (Nico Pache) [RHEL-5622]
- panic: Taint kernel if tests are run (Nico Pache) [RHEL-5622]
- kunit: tool: Use qemu-system-i386 for i386 runs (Nico Pache) [RHEL-5622]
- kunit: tool: update riscv QEMU config with new serial dependency (Nico Pache) [RHEL-5622]
- kunit: tool: Add list of all valid test configs on UML (Nico Pache) [RHEL-5622]
- kunit: take `kunit_assert` as `const` (Nico Pache) [RHEL-5622]
- kunit: fix UAF when run kfence test case test_gfpzero (Nico Pache) [RHEL-5622]
- lib: stackinit: Convert to KUnit (Nico Pache) [RHEL-5622]
- lib/test_stackinit: Add assigned initializers (Nico Pache) [RHEL-5622]
- lib/test_stackinit: Allow building stand-alone (Nico Pache) [RHEL-5622]
- lib/test_stackinit: Fix static initializer test (Nico Pache) [RHEL-5622]
- lib: test_stackinit.c: XFAIL switch variable init tests (Nico Pache) [RHEL-5622]
- lib/test_stackinit: Handle Clang auto-initialization pattern (Nico Pache) [RHEL-5622]
- lib: Introduce test_stackinit module (Nico Pache) [RHEL-5622]
- kunit: cleanup assertion macro internal variables (Nico Pache) [RHEL-5622]
- kunit: factor out str constants from binary assertion structs (Nico Pache) [RHEL-5622]
- kunit: consolidate KUNIT_INIT_BINARY_ASSERT_STRUCT macros (Nico Pache) [RHEL-5622]
- kunit: remove va_format from kunit_assert (Nico Pache) [RHEL-5622]
- docs: dev-tools: kunit: don't use a table for docs name (Nico Pache) [RHEL-5622]
- Documentation: dev-tools: Add Testing Overview (Nico Pache) [RHEL-5622]

* Thu Nov 23 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-527.el8]
- perf vendor events: Update PMC used in PM_RUN_INST_CMPL event for power10 platform (Michael Petlan) [RHEL-16880]
- gfs2: Fix another freeze/thaw hang (Andrew Price) [RHEL-5340]
- tcp: enforce receive buffer memory limits by allowing the tcp window to shrink (Felix Maurer) [RHEL-15023]
- cpufreq: amd-pstate: Update policy->cur in amd_pstate_adjust_perf() (Prarit Bhargava) [RHEL-10028]
- driver/base/cpu: Retry online operation if -EBUSY (Waiman Long) [RHEL-5730]
- net: openvswitch: reject negative ifindex (Antoine Tenart) [RHEL-14350]
- sctp: annotate data-races around sk->sk_wmem_queued (Xin Long) [RHEL-14838]
- sctp: fix potential deadlock on &net->sctp.addr_wq_lock (Xin Long) [RHEL-14838]
- sctp: fix an error code in sctp_sf_eat_auth() (Xin Long) [RHEL-14838]
- sctp: handle invalid error codes without calling BUG() (Xin Long) [RHEL-14838]
- sctp: fix an issue that plpmtu can never go to complete state (Xin Long) [RHEL-14838]
- sctp: add bpf_bypass_getsockopt proto callback (Xin Long) [RHEL-14838]
- powerpc/pseries: Always inline functions called from cpuidle (Mark Langsdorf) [RHEL-4666]
- cpuidle: pseries: Mark ->enter() functions as __cpuidle (Mark Langsdorf) [RHEL-4666]
- cpuidle: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-4666]
- cpuidle: driver: Update microsecond values of state parameters as needed (Mark Langsdorf) [RHEL-4666]
- cpuidle: sysfs: make kobj_type structures constant (Mark Langsdorf) [RHEL-4666]
- cpuidle: Fix poll_idle() noinstr annotation (Mark Langsdorf) [RHEL-4666]
- cpuidle-haltpoll: Replace default_idle() with arch_cpu_idle() (Mark Langsdorf) [RHEL-4666]
- cpuidle-haltpoll: select haltpoll governor (Mark Langsdorf) [RHEL-4666]
- cpuidle: Annotate poll_idle() (Mark Langsdorf) [RHEL-4666]
- powerpc/cpuidle: Set CPUIDLE_FLAG_POLLING for snooze state (Mark Langsdorf) [RHEL-4666]
- cpuidle: Remove redundant check in cpuidle_switch_governor() (Mark Langsdorf) [RHEL-4666]
- cpuidle: powernv: move from strlcpy() with unused retval to strscpy() (Mark Langsdorf) [RHEL-4666]
- cpuidle: coupled: Drop duplicate word from a comment (Mark Langsdorf) [RHEL-4666]
- KVM: s390: add tracepoint in gmap notifier (Cédric Le Goater) [RHEL-11434]
- KVM: s390: add stat counter for shadow gmap events (Cédric Le Goater) [RHEL-11434]
- KVM: s390: fix gisa destroy operation might lead to cpu stalls (Cédric Le Goater) [RHEL-9581]
- KVM: s390: interrupt: Fix single-stepping keyless mode exits (Cédric Le Goater) [RHEL-9581]
- KVM: s390: interrupt: Fix single-stepping userspace-emulated instructions (Cédric Le Goater) [RHEL-9581]
- KVM: s390: interrupt: Fix single-stepping kernel-emulated instructions (Cédric Le Goater) [RHEL-9581]
- KVM: s390: interrupt: Fix single-stepping into program interrupt handlers (Cédric Le Goater) [RHEL-9581]
- KVM: s390: interrupt: Fix single-stepping into interrupt handlers (Cédric Le Goater) [RHEL-9581]
- KVM: s390: fix sthyi error handling (Cédric Le Goater) [RHEL-9581]
- KVM: s390: pv: fix index value of replaced ASCE (Cédric Le Goater) [RHEL-9581]
- KVM: s390/diag: fix racy access of physical cpu number in diag 9c handler (Cédric Le Goater) [RHEL-9581]
- KVM: s390: vsie: fix the length of APCB bitmap (Cédric Le Goater) [RHEL-9581]
- KVM: s390: fix KVM_S390_GET_CMMA_BITS for GFNs in memslot holes (Cédric Le Goater) [RHEL-9581]
- KVM: s390: pci: fix virtual-physical confusion on module unload/load (Cédric Le Goater) [RHEL-9581]
- KVM: s390: interrupt: fix virtual-physical confusion for next alert GISA (Cédric Le Goater) [RHEL-9581]
- KVM: s390: pv: fix external interruption loop not always detected (Cédric Le Goater) [RHEL-9581]
- s390: vfio-ap: tighten the NIB validity check (Cédric Le Goater) [RHEL-9581]
- KVM: s390: pv: leak the topmost page table when destroy fails (Cédric Le Goater) [RHEL-9581]
- mbcache: Avoid nesting of cache->c_list_lock under bit locks (Carlos Maiolino) [RHEL-15010]
- ext4: fix deadlock due to mbcache entry corruption (Carlos Maiolino) [RHEL-15010]
- mbcache: automatically delete entries from cache on freeing (Carlos Maiolino) [RHEL-15010]
- ext4: fix use-after-free read in ext4_find_extent for bigalloc + inline (Carlos Maiolino) [RHEL-15010]
- ext4: fix another off-by-one fsmap error on 1k block filesystems (Carlos Maiolino) [RHEL-15010]
- ext4: fix task hung in ext4_xattr_delete_inode (Carlos Maiolino) [RHEL-15010]
- ext4: Fix function prototype mismatch for ext4_feat_ktype (Carlos Maiolino) [RHEL-15010]
- ext4: avoid unaccounted block allocation when expanding inode (Carlos Maiolino) [RHEL-15010]
- ext4: avoid BUG_ON when creating xattrs (Carlos Maiolino) [RHEL-15010]
- ext4: fix delayed allocation bug in ext4_clu_mapped for bigalloc + inline (Carlos Maiolino) [RHEL-15010]
- ext4: fix uninititialized value in 'ext4_evict_inode' (Carlos Maiolino) [RHEL-15010]
- ext4: fix corruption when online resizing a 1K bigalloc fs (Carlos Maiolino) [RHEL-15010]
- ext4: fix error code return to user-space in ext4_get_branch() (Carlos Maiolino) [RHEL-15010]
- ext4: init quota for 'old.inode' in 'ext4_rename' (Carlos Maiolino) [RHEL-15010]
- ext4: fix undefined behavior in bit shift for ext4_check_flag_values (Carlos Maiolino) [RHEL-15010]
- ext4: fix bug_on in __es_tree_search caused by bad boot loader inode (Carlos Maiolino) [RHEL-15010]
- ext4: add EXT4_IGET_BAD flag to prevent unexpected bad inode (Carlos Maiolino) [RHEL-15010]
- ext4: add helper to check quota inums (Carlos Maiolino) [RHEL-15010]
- ext4: fix bug_on in __es_tree_search caused by bad quota inode (Carlos Maiolino) [RHEL-15010]
- ext4: silence the warning when evicting inode with dioread_nolock (Carlos Maiolino) [RHEL-15010]
- ext4: fix use-after-free in ext4_ext_shift_extents (Carlos Maiolino) [RHEL-15010]
- ext4: fix warning in 'ext4_da_release_space' (Carlos Maiolino) [RHEL-15010]
- jbd2: wake up journal waiters in FIFO order, not LIFO (Carlos Maiolino) [RHEL-15010]
- ext4: place buffer head allocation before handle start (Carlos Maiolino) [RHEL-15010]
- ext4: fix check for block being out of directory size (Carlos Maiolino) [RHEL-15010] {CVE-2022-1184}
- ext4: make ext4_lazyinit_thread freezable (Carlos Maiolino) [RHEL-15010]
- ext4: fix null-ptr-deref in ext4_write_info (Carlos Maiolino) [RHEL-15010]
- ext4: limit the number of retries after discarding preallocations blocks (Carlos Maiolino) [RHEL-15010]
- ext4: fix bug in extents parsing when eh_entries == 0 and eh_depth > 0 (Carlos Maiolino) [RHEL-15010]
- jbd2: fix assertion 'jh->b_frozen_data == NULL' failure when journal aborted (Carlos Maiolino) [RHEL-15010]
- ext4: fix race when reusing xattr blocks (Carlos Maiolino) [RHEL-15010]
- ext4: unindent codeblock in ext4_xattr_block_set() (Carlos Maiolino) [RHEL-15010]
- ext4: remove EA inode entry from mbcache on inode eviction (Carlos Maiolino) [RHEL-15010]
- ext4: use kmemdup() to replace kmalloc + memcpy (Carlos Maiolino) [RHEL-15010]
- ext4: avoid remove directory when directory is corrupted (Carlos Maiolino) [RHEL-15010]
- ext4: recover csum seed of tmp_inode after migrating to extents (Carlos Maiolino) [RHEL-15010]
- mbcache: add functions to delete entry if unused (Carlos Maiolino) [RHEL-15010]
- mbcache: don't reclaim used entries (Carlos Maiolino) [RHEL-15010]
- redhat/configs: Disable AMD PMF driver (Prarit Bhargava) [RHEL-10011]
- x86/amd_nb: Add PCI ID for family 19h model 78h (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd: pmc: provide user message where s0ix is not supported (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Fix memory leak in amd_pmc_stb_debugfs_open_v2() (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd: pmc: Remove __maybe_unused from amd_pmc_suspend_handler() (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Move out of BIOS SMN pair for STB init (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Utilize SMN index 0 for driver probe (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Move idlemask check into `amd_pmc_idlemask_read` (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Don't dump data after resume from s0i3 on picasso (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Hide SMU version and program attributes for Picasso (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Don't try to read SMU version on Picasso (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd: pmc: Convert to platform remove callback returning void (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd: hsmp: Convert to platform remove callback returning void (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: remove CONFIG_SUSPEND checks (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Add line break for readability (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: differentiate STB/SMU messaging prints (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Write dummy postcode into the STB DRAM (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Add num_samples message id support to STB (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: add CONFIG_SERIO dependency (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Add a module parameter to disable workarounds (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Disable IRQ1 wakeup for RN/CZN (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: Fix refcount leak in amd_pmc_probe (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Add new ACPI ID AMDI0009 (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Remove more CONFIG_DEBUG_FS checks (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Read SMU version during suspend on Cezanne systems (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: remove CONFIG_DEBUG_FS checks (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Fix build without debugfs (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Add sysfs files for SMU (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Always write to the STB (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd: pmc: Add defines for STB events (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd/pmf: Add support for PMF core layer (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd/pmc: Add new platform support (Prarit Bhargava) [RHEL-10011]
- platform/x86/amd/pmc: Add new acpi id for PMC controller (Prarit Bhargava) [RHEL-10011]
- platform/x86: Move AMD platform drivers to separate directory (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Fix build error unused-function (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Shuffle location of amd_pmc_get_smu_version() (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Avoid reading SMU version at probe time (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Move FCH init to first use (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Move SMU logging setup out of init (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Fix compilation without CONFIG_SUSPEND (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Only report STB errors when STB enabled (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Drop CPU QoS workaround (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Output error codes in messages (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Move to later in the suspend process (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Validate entry into the deepest state on resume (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: uninitialized variable in amd_pmc_s2d_init() (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Add support for AMD Spill to DRAM STB feature (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Correct usage of SMU version (Prarit Bhargava) [RHEL-10011]
- platform/x86: amd-pmc: Make amd_pmc_stb_debugfs_fops static (Prarit Bhargava) [RHEL-10011]
- scsi: qedf: Add synchronization between I/O completions and abort (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Remove unused declaration (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Fix firmware halt over suspend and resume (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_fp_int_cmd_read() directly (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_debug_cmd_read() directly (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_stop_io_on_error_cmd_read() directly (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Fix NULL dereference in error handling (Nilesh Javali) [RHEL-9861]
- scsi: qedf: Remove unused 'num_handled' variable (Nilesh Javali) [RHEL-9861]
- scsi: qla2xxx: Fix system crash due to bad pointer access (Nilesh Javali) [RHEL-9859]
- qla2xxx: Fix double free of dsd_list during driver load. (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix NULL vs IS_ERR() bug for debugfs_create_dir() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Use raw_smp_processor_id() instead of smp_processor_id() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Correct endianness for rqstlen and rsplen (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix unused variable warning in qla2xxx_process_purls_pkt() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix spelling mistake "tranport" -> "transport" (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Remove unused variables in qla24xx_build_scsi_type_6_iocbs() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix nvme_fc_rcv_ls_req() undefined error (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Update version to 10.02.09.100-k (Nilesh Javali) [RHEL-9859]
- Revert "scsi: qla2xxx: Fix buffer overrun" (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix smatch warn for qla_init_iocb_limit() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Remove unsupported ql2xenabledif option (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Error code did not return to upper layer (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Add logs for SFP temperature monitoring (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix firmware resource tracking (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Flush mailbox commands on chip reset (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Add Unsolicited LS Request and Response Support for NVMe (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Allow 32-byte CDBs (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Move resource to allow code reuse (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Remove unused declarations (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Update version to 10.02.08.500-k (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: fix inconsistent TMF timeout (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix TMF leak through (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Turn off noisy message log (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix session hang in gnl (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix erroneous link up failure (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix command flush during TMF (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Limit TMF to 8 per function (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Adjust IOCB resource on qpair create (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix deletion race condition (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix error code in qla2x00_start_sp() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Silence a static checker warning (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Remove unused nvme_ls_waitq wait queue (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Update version to 10.02.08.400-k (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Correct the index of array (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Pointer may be dereferenced (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix buffer overrun (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Check valid rport returned by fc_bsg_to_rport() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Avoid fcport pointer dereference (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix potential NULL pointer dereference (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Array index may go out of bound (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Drop useless LIST_HEAD (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Replace one-element array with DECLARE_FLEX_ARRAY() helper (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix end of loop test (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix NULL pointer dereference in target mode (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Replace all non-returning strlcpy() with strscpy() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Update version to 10.02.08.300-k (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Wait for io return on terminate rport (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix mem access after free (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix hang in task management (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix task management cmd fail due to unavailable resource (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix task management cmd failure (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Multi-que support for TMF (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Fix memory leak in qla2x00_probe_one() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Refer directly to the qla2xxx_driver_template (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Remove default fabric ops callouts (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Drop redundant pci_enable_pcie_error_reporting() (Nilesh Javali) [RHEL-9859]
- scsi: qla2xxx: Add option to disable FC2 Target support (Nilesh Javali) [RHEL-9859]

* Fri Nov 17 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-526.el8]
- cpupower: Fix cpuidle_set to accept only numeric values for idle-set operation. (Mamatha Inamdar) [RHEL-15215]
- powerpc/vas: Limit open window failure messages in log bufffer (Mamatha Inamdar) [RHEL-14968]
- udplite: Fix NULL pointer dereference in __sk_mem_raise_allocated(). (Paolo Abeni) [RHEL-14372]
- vxlan: calculate correct header length for GPE (Petr Oros) [RHEL-14527]
- af_unix: Fix null-ptr-deref in unix_stream_sendpage(). (Guillaume Nault) [RHEL-2574] {CVE-2023-4622}
- netfilter: xt_u32: validate user space input (Phil Sutter) [RHEL-11729] {CVE-2023-39192}
- netfilter: nf_log_syslog: Consolidate entry checks (Phil Sutter) [RHEL-6044]
- netfilter: nf_log_syslog: Don't ignore unknown protocols (Phil Sutter) [RHEL-6044]
- netfilter: nf_log_syslog: Merge MAC header dumpers (Phil Sutter) [RHEL-6044]
- tipc: fix a potential deadlock on &tx->lock (Xin Long) [RHEL-14830]
- tipc: stop tipc crypto on failure in tipc_node_create (Xin Long) [RHEL-14830]
- tipc: check return value of pskb_trim() (Xin Long) [RHEL-14830]
- net: tipc: resize nlattr array to correct size (Xin Long) [RHEL-14830]
- scsi: target: core: Fix deadlock due to recursive locking (Maurizio Lombardi) [RHEL-15311]
- scsi: target: Replace strlcpy() with strscpy() (Maurizio Lombardi) [RHEL-15311]
- scsi: target: iscsi: Stop using sprintf() in iscsi_target_configfs.c (Maurizio Lombardi) [RHEL-15311]
- scsi: target: iscsi: Fix buffer overflow in lio_target_nacl_info_show() (Maurizio Lombardi) [RHEL-15311]
- scsi: target: Fix multiple LUN_RESET handling (Maurizio Lombardi) [RHEL-15311]
- scsi: target: iscsit: Free cmds before session free (Maurizio Lombardi) [RHEL-15311]
- net: xfrm: skip policies marked as dead while reinserting policies (Sabrina Dubroca) [RHEL-14518]
- ip_vti: fix potential slab-use-after-free in decode_session6 (Sabrina Dubroca) [RHEL-14518]
- ip6_vti: fix slab-use-after-free in decode_session6 (Sabrina Dubroca) [RHEL-14518]
- xfrm: fix slab-use-after-free in decode_session6 (Sabrina Dubroca) [RHEL-14518]
- net: ipv4: Use kfree_sensitive instead of kfree (Sabrina Dubroca) [RHEL-14518]
- xfrm: Linearize the skb after offloading if needed. (Sabrina Dubroca) [RHEL-14518]
- xfrm: fix inbound ipv4/udp/esp packets to UDPv6 dualstack sockets (Sabrina Dubroca) [RHEL-14518]
- net: skb_queue_purge_reason() optimizations (Antoine Tenart) [RHEL-14568]
- net: add skb_queue_purge_reason and __skb_queue_purge_reason (Antoine Tenart) [RHEL-14568]
- tcp: add TCP_OLD_SEQUENCE drop reason (Antoine Tenart) [RHEL-14568]
- net: move dropreason.h to dropreason-core.h (Antoine Tenart) [RHEL-14568]
- net: fix kfree_skb_list use of skb_mark_not_on_list (Antoine Tenart) [RHEL-14568]
- net: kfree_skb_list use kmem_cache_free_bulk (Antoine Tenart) [RHEL-14568]
- bpf: Clarify error expectations from bpf_clone_redirect (Davide Caratti) [RHEL-15040]
- veth: Fixing transmit return status for dropped packets (Davide Caratti) [RHEL-15040]
- net: fib: avoid warn splat in flow dissector (Davide Caratti) [RHEL-15040]
- net: af_key: fix sadb_x_filter validation (Davide Caratti) [RHEL-15040]
- net: dcb: choose correct policy to parse DCB_ATTR_BCN (Davide Caratti) [RHEL-15040]
- llc: Don't drop packet from non-root netns. (Davide Caratti) [RHEL-15040]
- vlan: fix a potential uninit-value in vlan_dev_hard_start_xmit() (Davide Caratti) [RHEL-15040]
- af_key: Reject optional tunnel/BEET mode templates in outbound policies (Davide Caratti) [RHEL-15040]
- af_packet: Don't send zero-byte data in packet_sendmsg_spkt(). (Davide Caratti) [RHEL-15040]
- ethtool: Fix uninitialized number of lanes (Davide Caratti) [RHEL-15040]
- vlan: partially enable SIOCSHWTSTAMP in container (Davide Caratti) [RHEL-15040]
- net/sched: act_ct: additional checks for outdated flows (Davide Caratti) [RHEL-14032]
- netfilter: flowtable: GC pushes back packets to classic path (Davide Caratti) [RHEL-14032]
- net: sched: sch_qfq: Use non-work-conserving warning handler (Davide Caratti) [RHEL-14032]
- net: sched: sch_qfq: Fix UAF in qfq_dequeue() (Davide Caratti) [RHEL-14032]
- net/sched: sch_hfsc: upgrade 'rt' to 'sc' when it becomes a inner curve (Davide Caratti) [RHEL-14032]
- net/sched: sch_hfsc: Ensure inner classes have fsc curve (Davide Caratti) [RHEL-14032]
- net/sched: fix a qdisc modification with ambiguous command request (Davide Caratti) [RHEL-14032]
- net/sched: mqprio: Add length check for TCA_MQPRIO_{MAX/MIN}_RATE64 (Davide Caratti) [RHEL-14032]
- net/sched: mqprio: add extack to mqprio_parse_nlattr() (Davide Caratti) [RHEL-14032]
- net: sched: cls_flower: Undo tcf_bind_filter in case of an error (Davide Caratti) [RHEL-14032]
- net: sched: cls_bpf: Undo tcf_bind_filter in case of an error (Davide Caratti) [RHEL-14032]
- net: sched: cls_u32: Undo refcount decrement in case update failed (Davide Caratti) [RHEL-14032]
- net: sched: cls_u32: Undo tcf_bind_filter if u32_replace_hw_knode (Davide Caratti) [RHEL-14032]
- net: sched: cls_matchall: Undo tcf_bind_filter in case of failure after mall_set_parms (Davide Caratti) [RHEL-14032]
- net/sched: flower: Ensure both minimum and maximum ports are specified (Davide Caratti) [RHEL-14032]
- net/sched: act_pedit: Add size check for TCA_PEDIT_PARMS_EX (Davide Caratti) [RHEL-14032]
- sch_netem: fix issues in netem_change() vs get_dist_table() (Davide Caratti) [RHEL-14032]
- sch_netem: acquire qdisc lock in netem_change() (Davide Caratti) [RHEL-14032]
- selftests: tc-testing: add one test for flushing explicitly created chain (Davide Caratti) [RHEL-14032]
- net/sched: cls_api: Fix lockup on flushing explicitly created chain (Davide Caratti) [RHEL-14032]
- net/sched: qdisc_destroy() old ingress and clsact Qdiscs before grafting (Davide Caratti) [RHEL-14032]
- net/sched: Refactor qdisc_graft() for ingress and clsact Qdiscs (Davide Caratti) [RHEL-14032]
- net/sched: act_ct: Fix promotion of offloaded unreplied tuple (Davide Caratti) [RHEL-14032]
- net/sched: fq_pie: ensure reasonable TCA_FQ_PIE_QUANTUM values (Davide Caratti) [RHEL-14032]
- net: sched: fix NULL pointer dereference in mq_attach (Davide Caratti) [RHEL-14032]
- net/sched: act_mirred: Add carrier check (Davide Caratti) [RHEL-14032]
- redhat/configs: delete ftdi-elan driver config (Desnes Nunes) [RHEL-13071]
- redhat/configs: delete u132-hcd driver config (Desnes Nunes) [RHEL-13071]
- usb: typec: ucsi: acpi: fix a NULL vs IS_ERR() check in probe (Desnes Nunes) [RHEL-13071]
- usb: typec: Fix fast_role_swap_current show function (Desnes Nunes) [RHEL-13071]
- usb: typec: ucsi: Fix command cancellation (Desnes Nunes) [RHEL-13071]
- USB: serial: option: add Quectel EM061KGL series (Desnes Nunes) [RHEL-13071]
- usb: typec: tps6598x: Fix broken polling mode after system suspend/resume (Desnes Nunes) [RHEL-13071]
- usb: usbfs: Use consistent mmap functions (Desnes Nunes) [RHEL-13071]
- usb: usbfs: Enforce page requirements for mmap (Desnes Nunes) [RHEL-13071]
- thunderbolt: Do not touch CL state configuration during discovery (Desnes Nunes) [RHEL-13071]
- thunderbolt: Increase DisplayPort Connection Manager handshake timeout (Desnes Nunes) [RHEL-13071]
- thunderbolt: dma_test: Use correct value for absent rings when creating paths (Desnes Nunes) [RHEL-13071]
- xhci: Fix incorrect tracking of free space on transfer rings (Desnes Nunes) [RHEL-13071]
- xhci-pci: Only run d3cold avoidance quirk for s2idle (Desnes Nunes) [RHEL-13071]
- usb-storage: fix deadlock when a scsi command timeouts more than once (Desnes Nunes) [RHEL-13071]
- usb: typec: tps6598x: Fix fault at module removal (Desnes Nunes) [RHEL-13071]
- usb: typec: altmodes/displayport: fix pin_assignment_show (Desnes Nunes) [RHEL-13071]
- USB: UHCI: adjust zhaoxin UHCI controllers OverCurrent bit value (Desnes Nunes) [RHEL-13071]
- PCI: Add ACS quirk for Zhaoxin Root/Downstream Ports (Desnes Nunes) [RHEL-13071]
- PCI: Add ACS quirk for Zhaoxin multi-function devices (Desnes Nunes) [RHEL-13071]
- PCI: Add Zhaoxin Vendor ID (Desnes Nunes) [RHEL-13071]
- USB: usbtmc: Fix direction for 0-length ioctl control messages (Desnes Nunes) [RHEL-13071]
- usb: usbtmc: Fix bug in pipe direction for control transfers (Desnes Nunes) [RHEL-13071]
- media: pvrusb2: fix DVB_CORE dependency (Desnes Nunes) [RHEL-13071]
- USB: sisusbvga: Add endpoint checks (Desnes Nunes) [RHEL-13071]
- USB: core: Add routines for endpoint checks in old drivers (Desnes Nunes) [RHEL-13071]
- usb: typec: ucsi: don't print PPM init deferred errors (Desnes Nunes) [RHEL-13071]
- usb: typec: tcpm: fix multiple times discover svids error (Desnes Nunes) [RHEL-13071]
- usb: xhci: plat: Add USB 3.0 phy support (Desnes Nunes) [RHEL-13071]
- usb: host: xhci-plat: Use dev_is_pci() helper (Desnes Nunes) [RHEL-13071]
- xhci: fix debugfs register accesses while suspended (Desnes Nunes) [RHEL-13071]
- debugfs: regset32: Add Runtime PM support (Desnes Nunes) [RHEL-13071]
- USB: serial: option: add UNISOC vendor and TOZED LT70C product (Desnes Nunes) [RHEL-13071]
- net: thunderbolt: Fix typos in comments (Desnes Nunes) [RHEL-13071]
- net: thunderbolt: Fix sparse warnings in tbnet_xmit_csum_and_map() (Desnes Nunes) [RHEL-13071]
- net: thunderbolt: Fix sparse warnings in tbnet_check_frame() and tbnet_poll() (Desnes Nunes) [RHEL-13071]
- media: mc-device: remove unnecessary __must_check (Desnes Nunes) [RHEL-13071]
- media: au0828: remove unnecessary (void*) conversions (Desnes Nunes) [RHEL-13071]
- USB: core: Fix docs warning caused by wireless_status feature (Desnes Nunes) [RHEL-13071]
- usb: typec: ucsi: acpi: add quirk for ASUS Zenbook UM325 (Desnes Nunes) [RHEL-13071]
- ACPI: OSL: Remove the helper for deactivating memory region (Desnes Nunes) [RHEL-13071]
- ACPI: OSL: Clean up printing messages (Desnes Nunes) [RHEL-13071]
- usb: typec: ucsi: acpi: Map the mailbox with memremap() (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: tps6598x: make interrupts optional (Desnes Nunes) [RHEL-13071]
- dt-bindings: Explicitly allow additional properties in common schemas (Desnes Nunes) [RHEL-13071]
- dt-bindings: connector: Convert Samsung 11-pin USB bindings to dtschema (Desnes Nunes) [RHEL-13071]
- dt-bindings: Merge gpio-usb-b-connector with usb-connector (Desnes Nunes) [RHEL-13071]
- dt-bindings: Clean-up schema indentation formatting (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: typec-tcpci: convert to DT schema format (Desnes Nunes) [RHEL-13071]
- usb: typec: tcpm: try to get role switch from tcpc fwnode (Desnes Nunes) [RHEL-13071]
- USB: core: Add API to change the wireless_status (Desnes Nunes) [RHEL-13071]
- USB: core: Add wireless_status sysfs attribute (Desnes Nunes) [RHEL-13071]
- ABI: sysfs-bus-usb: better document variable argument (Desnes Nunes) [RHEL-13071]
- thunderbolt: Introduce usb4_port_sb_opcode_err_to_errno() helper (Desnes Nunes) [RHEL-13071]
- media: pvrusb2: clean up unneeded complexity in pvrusb2 class logic (Desnes Nunes) [RHEL-13071]
- usb: move config USB_USS720 to usb's misc Kconfig (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: usb-nop-xceiv: add power-domains property (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: usb-nop-xceiv: Convert to DT schema (Desnes Nunes) [RHEL-13071]
- thunderbolt: Make use of SI units from units.h (Desnes Nunes) [RHEL-13071]
- thunderbolt: Get rid of redundant 'else' (Desnes Nunes) [RHEL-13071]
- thunderbolt: ACPI: Replace tb_acpi_find_port() with acpi_find_child_by_adr() (Desnes Nunes) [RHEL-13071]
- usb: pci-quirks: Reduce the length of a spinlock section in usb_amd_find_chipset_info() (Desnes Nunes) [RHEL-13071]
- xhci: use pm_ptr() instead of #ifdef for CONFIG_PM conditionals (Desnes Nunes) [RHEL-13071]
- usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS (Desnes Nunes) [RHEL-13071]
- usb: typec: tps6598x: Add support for polling interrupts status (Desnes Nunes) [RHEL-13071]
- usb: typec: ucsi: add PMIC Glink UCSI driver (Desnes Nunes) [RHEL-13071]
- tracing: Acquire buffer from temparary trace sequence (Desnes Nunes) [RHEL-13071]
- USB: serial: quatech2: remove unused qt2_setdevice function (Desnes Nunes) [RHEL-13071]
- usb: typec: tipd: remove unused tps6598x_write16,32 functions (Desnes Nunes) [RHEL-13071]
- usb: typec: tcpci_mt6360: remove unused mt6360_tcpc_read16 function (Desnes Nunes) [RHEL-13071]
- usb: typec: tcpm: remove unnecessary (void*) conversions (Desnes Nunes) [RHEL-13071]
- xhci: Move xhci MSI sync function to to xhci-pci (Desnes Nunes) [RHEL-13071]
- xhci: Call MSI sync function from xhci-pci instead of generic xhci code (Desnes Nunes) [RHEL-13071]
- xhci: Move functions to cleanup MSI to xhci-pci (Desnes Nunes) [RHEL-13071]
- xhci: move PCI specific MSI/MSIX cleanup away from generic xhci functions (Desnes Nunes) [RHEL-13071]
- xhci: Move functions to setup msi to xhci-pci (Desnes Nunes) [RHEL-13071]
- xhci: Avoid PCI MSI/MSIX interrupt reinitialization at resume (Desnes Nunes) [RHEL-13071]
- xhci: dbc: Provide sysfs option to configure dbc descriptors (Desnes Nunes) [RHEL-13071]
- xhci: mem: Join string literals back (Desnes Nunes) [RHEL-13071]
- xhci: mem: Replace explicit castings with appropriate specifiers (Desnes Nunes) [RHEL-13071]
- xhci: mem: Use while (i--) pattern to clean up (Desnes Nunes) [RHEL-13071]
- xhci: mem: Drop useless return:s (Desnes Nunes) [RHEL-13071]
- xhci: mem: Get rid of redundant 'else' (Desnes Nunes) [RHEL-13071]
- xhci: mem: Use dma_poll_zalloc() instead of explicit memset() (Desnes Nunes) [RHEL-13071]
- xhci: mem: Carefully calculate size for memory allocations (Desnes Nunes) [RHEL-13071]
- overflow: Provide constant expression struct_size (Desnes Nunes) [RHEL-13071]
- test_overflow: Regularize test reporting output (Desnes Nunes) [RHEL-13071]
- overflow: Implement size_t saturating arithmetic helpers (Desnes Nunes) [RHEL-13071]
- test_overflow: Add shift overflow tests (Desnes Nunes) [RHEL-13071]
- overflow.h: Add comment documenting __ab_c_size() (Desnes Nunes) [RHEL-13071]
- docs: basics.rst: get rid of rcu kernel-doc macros (Desnes Nunes) [RHEL-13071]
- docs: Do not seek comments in kernel/rcu/tree_plugin.h (Desnes Nunes) [RHEL-13071]
- docs: deprecated.rst: Add zero-length and one-element arrays (Desnes Nunes) [RHEL-13071]
- docs: Remove :c:func: from process/deprecated.rst (Desnes Nunes) [RHEL-13071]
- docs: Introduce deprecated APIs list (Desnes Nunes) [RHEL-13071]
- USB: misc: Remove unused include file usb_u132.h (Desnes Nunes) [RHEL-13071]
- usb: ftdi-elan: Delete driver (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: Drop unneeded quotes (Desnes Nunes) [RHEL-13071]
- usb: host: u132-hcd: Delete driver (Desnes Nunes) [RHEL-13071]
- media: pvrusb2: VIDEO_PVRUSB2 depends on DVB_CORE to use dvb_* symbols (Desnes Nunes) [RHEL-13071]
- usb: misc: usb3503: support usb3803 and bypass mode (Desnes Nunes) [RHEL-13071]
- usb: misc: usb3503: refactor code to prepare for usb3803 addition (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: smsc,usb3503: Add usb3803 (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: Convert SMSC USB3503 binding to a schema (Desnes Nunes) [RHEL-13071]
- usb: typec: fusb302: mark OF related data as maybe unused (Desnes Nunes) [RHEL-13071]
- usb: typec: hd3ss3220: Drop of_match_ptr for ID table (Desnes Nunes) [RHEL-13071]
- usb: typec: hd3ss3220: Convert to i2c's .probe_new() (Desnes Nunes) [RHEL-13071]
- usb: acpi: Switch to use acpi_evaluate_dsm_typed() (Desnes Nunes) [RHEL-13071]
- usb: Use of_property_read_bool() for boolean properties (Desnes Nunes) [RHEL-13071]
- usb: host: Fix refcount leak in ehci_hcd_ppc_of_probe (Desnes Nunes) [RHEL-13071]
- usb: usb251xb: Switch to use dev_err_probe() helper (Desnes Nunes) [RHEL-13071]
- thunderbolt: Refactor DROM reading (Desnes Nunes) [RHEL-13071]
- thunderbolt: use `tb_eeprom_get_drom_offset` to discover DROM offset (Desnes Nunes) [RHEL-13071]
- usb: xhci: change some trace event __dynamic_array() to __get_buf() (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: allow evaluated properties in OHCI controllers (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: usb-device: make "compatible" optional (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: hcd: correct usb-device path (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: fix yamllint check warning (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: usb-device: fix typo in required properties (Desnes Nunes) [RHEL-13071]
- dt-bindings: usb: convert usb-device.txt to YAML schema (Desnes Nunes) [RHEL-13071]
- dt-bindings: Fix SPI and I2C bus node names in examples (Desnes Nunes) [RHEL-13071]
- dt-bindings: mfd: mediatek: Add bindings for MT6360 PMIC (Desnes Nunes) [RHEL-13071]
- usb typec: mt6360: Add MT6360 Type-C DT binding documentation (Desnes Nunes) [RHEL-13071]

* Wed Nov 15 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-525.el8]
- net: xfrm: Fix xfrm_address_filter OOB read (Wander Lairson Costa) [2227304] {CVE-2023-39194}
- drm/qxl: fix UAF on handle creation (Wander Lairson Costa) [2218333] {CVE-2023-39198}
- x86/sev: Make enc_dec_hypercall() accept a size instead of npages (Vitaly Kuznetsov) [RHEL-3656]
- net: virtio_net_hdr_to_skb: count transport header in UFO (Cindy Lu) [RHEL-6030]
- ice: reset first in crash dump kernels (Petr Oros) [2139761]
- perf/core: Fix potential NULL deref (Wander Lairson Costa) [RHEL-14982] {CVE-2023-5717}
- perf: Disallow mis-matched inherited group reads (Wander Lairson Costa) [RHEL-14982] {CVE-2023-5717}
- scsi: mpt3sas: Drop redundant pci_enable_pcie_error_reporting() (Tomas Henzl) [RHEL-8246]
- scsi: mpt3sas: Fix in error path (Tomas Henzl) [RHEL-8246]
- scsi: mpt3sas: Fix loop logic (Tomas Henzl) [RHEL-8246]
- scsi: mpt3sas: Remove volatile qualifier (Tomas Henzl) [RHEL-8246]
- scsi: mpt3sas: Perform additional retries if doorbell read returns 0 (Tomas Henzl) [RHEL-8246]
- scsi: mpi3mr: Split off bus_reset function from host_reset (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Update driver version to 8.5.0.0.0 (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Enhance handling of devices removed after controller reset (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: WRITE SAME implementation (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Add support for more than 1MB I/O (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Update MPI Headers to version 3.00.28 (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Invoke soft reset upon TSU or event ack time out (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Propagate sense data for admin queue SCSI I/O (Tomas Henzl) [RHEL-8232]
- scsi: mpi3mr: Fix the type used for pointers to bitmap (Tomas Henzl) [RHEL-8232]
- regmap: Drop initial version of maximum transfer length fixes (Mark Langsdorf) [RHEL-1022]
- regmap: Account for register length when chunking (Mark Langsdorf) [RHEL-1022]
- driver core: update comments in device_rename() (Mark Langsdorf) [RHEL-1022]
- cacheinfo: Add use_arch[|_cache]_info field/function (Mark Langsdorf) [RHEL-1022]
- arch_topology: Remove early cacheinfo error message if -ENOENT (Mark Langsdorf) [RHEL-1022]
- cacheinfo: Allow early level detection when DT/ACPI info is missing/broken (Mark Langsdorf) [RHEL-1022]
- cacheinfo: Check sib_leaf in cache_leaves_are_shared() (Mark Langsdorf) [RHEL-1022]
- cacheinfo: Add arch specific early level initializer (Mark Langsdorf) [RHEL-1022]
- regmap: Factor out single value register syncing (Mark Langsdorf) [RHEL-1022]
- regmap: Add RAM backed register map (Mark Langsdorf) [RHEL-1022]
- regmap: Removed compressed cache support (Mark Langsdorf) [RHEL-1022]
- base: soc: populate machine name in soc_device_register if empty (Mark Langsdorf) [RHEL-1022]
- regmap: Clarify error for unknown cache types (Mark Langsdorf) [RHEL-1022]
- regmap: Handle sparse caches in the default sync (Mark Langsdorf) [RHEL-1022]
- regmap: add a helper to translate the register address (Mark Langsdorf) [RHEL-1022]
- regmap: cache: Silence checkpatch warning (Mark Langsdorf) [RHEL-1022]
- regmap: cache: Return error in cache sync operations for REGCACHE_NONE (Mark Langsdorf) [RHEL-1022]
- devres: Pass unique name of the resource to devm_add_action() (Mark Langsdorf) [RHEL-1022]
- device property: Clarify description of returned value in some functions (Mark Langsdorf) [RHEL-1022]
- driver core: Make state_synced device attribute writeable (Mark Langsdorf) [RHEL-1022]
- PM: domains: fix memory leak with using debugfs_lookup() (Mark Langsdorf) [RHEL-1022]
- PM: runtime: Do not call __rpm_callback() from rpm_idle() (Mark Langsdorf) [RHEL-1022]
- kobject: kset_uevent_ops: make name() callback take a const * (Mark Langsdorf) [RHEL-1022]
- kobject: kset_uevent_ops: make filter() callback take a const * (Mark Langsdorf) [RHEL-1022]
- kobject: make get_ktype() take a const pointer (Mark Langsdorf) [RHEL-1022]
- kobject: make kobject_get_ownership() take a constant kobject * (Mark Langsdorf) [RHEL-1022]
- arm64: topology: move store_cpu_topology() to shared code (Mark Langsdorf) [RHEL-1022]
- filemap: skip write and wait if end offset precedes start (Nico Pache) [RHEL-5620]
- mm/mempolicy: clean up the code logic in queue_pages_pte_range (Nico Pache) [RHEL-5620]
- mm:vmscan: fix inaccurate reclaim during proactive reclaim (Nico Pache) [RHEL-5620]
- mm/page_alloc: don't wake kswapd from rmqueue() unless __GFP_KSWAPD_RECLAIM is specified (Nico Pache) [RHEL-5620]
- writeback: fix call of incorrect macro (Nico Pache) [RHEL-5620]
- mm/page_alloc: use write_seqlock_irqsave() instead write_seqlock() + local_irq_save(). (Nico Pache) [RHEL-5620]
- mm/page_alloc: fix potential deadlock on zonelist_update_seq seqlock (Nico Pache) [RHEL-5620]
- writeback, cgroup: fix null-ptr-deref write in bdi_split_work_to_wbs (Nico Pache) [RHEL-5620]
- mm/khugepaged: check again on anon uffd-wp during isolation (Nico Pache) [RHEL-5620]
- mm/swap: fix swap_info_struct race between swapoff and get_swap_pages() (Nico Pache) [RHEL-5620]
- mm/fadvise: use LLONG_MAX instead of -1 for eof (Nico Pache) [RHEL-5620]
- mm: Make failslab writable again (Nico Pache) [RHEL-5620]
- mm: migrate: fix THP's mapcount on isolation (Nico Pache) [RHEL-5620]
- mm/memremap.c: map FS_DAX device memory as decrypted (Nico Pache) [RHEL-5620]
- mm/page_alloc: add missing is_migrate_isolate() check in set_page_guard() (Nico Pache) [RHEL-5620]
- mm: pagewalk: Fix race between unmap and page walker (Nico Pache) [RHEL-5620]
- mm/slub: add missing TID updates on slab deactivation (Nico Pache) [RHEL-5620]
- hugetlb: fix huge_pmd_unshare address update (Nico Pache) [RHEL-5620]
- fs-writeback: writeback_sb_inodes：Recalculate 'wrote' according skipped pages (Nico Pache) [RHEL-5620]
- highmem: fix checks in __kmap_local_sched_{in,out} (Nico Pache) [RHEL-5620]
- mm: fix race between MADV_FREE reclaim and blkdev direct IO read (Nico Pache) [RHEL-5620]
- mm/thp: fix NR_FILE_MAPPED accounting in page_*_file_rmap() (Nico Pache) [RHEL-5620]
- memblock: use kfree() to release kmalloced memblock regions (Nico Pache) [RHEL-5620]
- mm/list_lru.c: prefer struct_size over open coded arithmetic (Nico Pache) [RHEL-5620]
- mm/kmemleak: allow __GFP_NOLOCKDEP passed to kmemleak's gfp (Nico Pache) [RHEL-5620]
- mm/hugetlb: initialize hugetlb_usage in mm_init (Nico Pache) [RHEL-5620]
- mm: mempolicy: don't have to split pmd for huge zero page (Nico Pache) [RHEL-5620]
- mm/thp: fix page_vma_mapped_walk() if THP mapped by ptes (Nico Pache) [RHEL-5620]
- mm/thp: unmap_mapping_page() to fix THP truncate_cleanup_page() (Nico Pache) [RHEL-5620]
- delayacct: clear right task's flag after blkio completes (Nico Pache) [RHEL-5620]
- mm: remove lru_add_drain_all in alloc_contig_range (Nico Pache) [RHEL-5620]
- mm: always have io_remap_pfn_range() set pgprot_decrypted() (Nico Pache) [RHEL-5620]
- mm/page_alloc: fix documentation error (Nico Pache) [RHEL-5620]
- s390/mm: mmap base does not depend on ADDR_NO_RANDOMIZE personality (Nico Pache) [RHEL-5620]
- powerpc/mm: Fix "sz" set but not used warning (Nico Pache) [RHEL-5620]
- powerpc/mm/hash: Handle mmap_min_addr correctly in get_unmapped_area topdown search (Nico Pache) [RHEL-5620]
- mm: ksm: do not block on page lock when searching stable tree (Nico Pache) [RHEL-5620]
- powerpc/hugetlbpage: Rmove unhelpful HUGEPD_*_SHIFT macros (Nico Pache) [RHEL-5620]
- arm64: mm: Export __sync_icache_dcache() for xen-privcmd (Nico Pache) [RHEL-5620]

* Sun Nov 12 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-524.el8]
- pNFS/filelayout: treat GETDEVICEINFO errors as layout failure (Scott Mayhew) [RHEL-4969]
- mm/kmemleak: move up cond_resched() call in page scanning loop (Waiman Long) [RHEL-8630]
- net/sched: cls_rsvp: always try to match inside the linear part of skb (Davide Caratti) [RHEL-11730] {CVE-2023-42755}
- vc_screen: don't clobber return value in vcs_read (Ricardo Robaina) [2221467] {CVE-2023-3567}
- vc_screen: move load of struct vc_data pointer in vcs_read() to avoid UAF (Ricardo Robaina) [2221467] {CVE-2023-3567}
- vt_kdsetmode: extend console locking (John W. Linville) [RHEL-3016] {CVE-2021-3753}
- console: consume APC, DM, DCS (John W. Linville) [RHEL-3016] {CVE-2021-3753}
- vt_ioctl: move vt_kdsetmode out of vt_k_ioctl (John W. Linville) [RHEL-3016] {CVE-2021-3753}
- scsi: core: Fix legacy /proc parsing buffer overflow (Ewan D. Milne) [RHEL-14311]
- scsi: core: Improve scsi_vpd_inquiry() checks (Ewan D. Milne) [RHEL-14311]
- scsi: core: Fix a procfs host directory removal regression (Ewan D. Milne) [RHEL-14311]
- scsi: core: Remove the /proc/scsi/${proc_name} directory earlier (Ewan D. Milne) [RHEL-14311]
- ibmvnic: Assign XPS map to correct queue index (Mukesh Chaurasiya) [RHEL-11210]
- ibmvnic: Toggle between queue types in affinity mapping (Mukesh Chaurasiya) [RHEL-11210]
- ibmvnic: Update XPS assignments during affinity binding (Mukesh Chaurasiya) [RHEL-11210]
- ibmvnic: Add hotpluggable CPU callbacks to reassign affinity hints (Mukesh Chaurasiya) [RHEL-11210]
- ibmvnic: Assign IRQ affinity hints to device queues (Mukesh Chaurasiya) [RHEL-11210]
- mm/slub: fix a slab missed to be freed problem (Rafael Aquini) [RHEL-9526]
- mm/slub: simplify __cmpxchg_double_slab() and slab_[un]lock() (Rafael Aquini) [RHEL-9526]
- mm/slub: convert object_map_lock to non-raw spinlock (Rafael Aquini) [RHEL-9526]
- mm/slub: remove slab_lock() usage for debug operations (Rafael Aquini) [RHEL-9526]
- mm/slub: restrict sysfs validation to debug caches and make it safe (Rafael Aquini) [RHEL-9526]
- mm/slub: move free_debug_processing() further (Rafael Aquini) [RHEL-9526]
- mm/slub: remove unneeded return value of slab_pad_check (Rafael Aquini) [RHEL-9526]
- s390/qdio: fix do_sqbs() inline assembly constraint (Tobias Huschle) [RHEL-11194]
- s390/lcs: Convert sysfs sprintf to sysfs_emit (Tobias Huschle) [RHEL-11194]
- s390/lcs: Convert sprintf to scnprintf (Tobias Huschle) [RHEL-11194]
- s390/ctcm: Convert sysfs sprintf to sysfs_emit (Tobias Huschle) [RHEL-11194]
- s390/ctcm: Convert sprintf/snprintf to scnprintf (Tobias Huschle) [RHEL-11194]
- s390/qeth: Fix vipa deletion (Tobias Huschle) [RHEL-11194]
- s390/lcs: Remove FDDI option (Tobias Huschle) [RHEL-11194]
- net/ism: Remove redundant pci_clear_master (Tobias Huschle) [RHEL-11198]
- net/smc: Fix dependency of SMC on ISM (Tobias Huschle) [RHEL-11198]
- s390/ism: Do not unregister clients with registered DMBs (Tobias Huschle) [RHEL-11198]
- s390/ism: Fix and simplify add()/remove() callback handling (Tobias Huschle) [RHEL-11198]
- s390/ism: Fix locking for forwarding of IRQs and events to clients (Tobias Huschle) [RHEL-11198]
- s390/ism: Fix trying to free already-freed IRQ by repeated ism_dev_exit() (Tobias Huschle) [RHEL-11198]
- s390/ism: Set DMA coherent mask (Tobias Huschle) [RHEL-11198]
- net/ism: Remove extra include (Tobias Huschle) [RHEL-11198]
- net/smc: Introduce explicit check for v2 support (Tobias Huschle) [RHEL-11198]
- dm: fix a race condition in retrieve_deps (Benjamin Marzinski) [RHEL-13917]
- dm raid: protect md_stop() with 'reconfig_mutex' (Benjamin Marzinski) [RHEL-13917]
- dm raid: clean up four equivalent goto tags in raid_ctr() (Benjamin Marzinski) [RHEL-13917]
- dm raid: fix missing reconfig_mutex unlock in raid_ctr() error paths (Benjamin Marzinski) [RHEL-13917]
- dm integrity: fix double free on memory allocation failure (Benjamin Marzinski) [RHEL-13917]
- dm integrity: scale down the recalculate buffer if memory allocation fails (Benjamin Marzinski) [RHEL-13917]
- dm integrity: only allocate recalculate buffer when needed (Benjamin Marzinski) [RHEL-13917]
- dm integrity: reduce vmalloc space footprint on 32-bit architectures (Benjamin Marzinski) [RHEL-13917]
- dm ioctl: Refuse to create device named "." or ".." (Benjamin Marzinski) [RHEL-13917]
- dm ioctl: Refuse to create device named "control" (Benjamin Marzinski) [RHEL-13917]
- dm ioctl: structs and parameter strings must not overlap (Benjamin Marzinski) [RHEL-13917]
- dm ioctl: Avoid pointer arithmetic overflow (Benjamin Marzinski) [RHEL-13917]
- dm ioctl: Check dm_target_spec is sufficiently aligned (Benjamin Marzinski) [RHEL-13917]
- dm thin: disable discards for thin-pool if no_discard_passdown (Benjamin Marzinski) [RHEL-13917]
- dm thin metadata: Fix ABBA deadlock by resetting dm_bufio_client (Benjamin Marzinski) [RHEL-13917]
- dm crypt: fix crypt_ctr_cipher_new return value on invalid AEAD cipher (Benjamin Marzinski) [RHEL-13917]
- dm thin: update .io_hints methods to not require handling discards last (Benjamin Marzinski) [RHEL-13917]
- dm thin: remove return code variable in pool_map (Benjamin Marzinski) [RHEL-13917]

* Wed Nov 08 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-523.el8]
- cifs: Fix UAF in cifs_demultiplex_thread() (Scott Mayhew) [RHEL-7930 RHEL-9046] {CVE-2023-1192}
- x86/platform/uv: Use alternate source for socket to node data (Frank Ramsay) [RHEL-13360]
- media: technisat-usb2: break out of loop at end of buffer (Desnes Nunes) [RHEL-3013 RHEL-3895] {CVE-2019-15505}
- can: af_can: fix NULL pointer dereference in can_rcv_filter (Ricardo Robaina) [RHEL-6429 RHEL-7053] {CVE-2023-2166}
- PCI/portdrv: Prevent LS7A Bus Master clearing on shutdown (Myron Stowe) [RHEL-5147]
- kernel/fork: beware of __put_task_struct() calling context (Wander Lairson Costa) [RHEL-14767]
- KVM: x86/mmu: Fix an sign-extension bug with mmu_seq that hangs vCPUs (Peter Xu) [RHEL-7210]
- net: tun: fix bugs for oversize packet when napi frags enabled (Ricardo Robaina) [RHEL-7185 RHEL-7267] {CVE-2023-3812}
- Bluetooth: hci_ldisc: check HCI_UART_PROTO_READY flag in HCIUARTGETPROTO (Jose Ignacio Tornos Martinez) [RHEL-6357] {CVE-2023-31083}
- RDMA/qedr: clean up work queue on failure in qedr_alloc_resources() (Kamal Heib) [RHEL-10313 RHEL-11030]
- RDMA/qedr: fix repeated words in comments (Kamal Heib) [RHEL-10313 RHEL-11030]
- x86/sev: Check for user-space IOIO pointing to kernel space (Wander Lairson Costa) [RHEL-14978] {CVE-2023-46813}
- x86/sev: Check IOBM for IOIO exceptions from user-space (Wander Lairson Costa) [RHEL-14978] {CVE-2023-46813}
- x86/sev: Disable MMIO emulation from user mode (Wander Lairson Costa) [RHEL-14978] {CVE-2023-46813}
- x86/sev-es: Fix SEV-ES OUT/IN immediate opcode vc handling (Wander Lairson Costa) [RHEL-14978] {CVE-2023-46813}
- USB: core: Fix oversight in SuperSpeed initialization (Desnes Nunes) [RHEL-2569 RHEL-2675] {CVE-2023-37453}
- USB: core: Fix race by not overwriting udev->descriptor in hub_port_init() (Desnes Nunes) [RHEL-2569 RHEL-2675] {CVE-2023-37453}
- USB: core: Change usb_get_device_descriptor() API (Desnes Nunes) [RHEL-2569 RHEL-2675] {CVE-2023-37453}
- USB: core: Unite old scheme and new scheme descriptor reads (Desnes Nunes) [RHEL-2569 RHEL-2675] {CVE-2023-37453}
- bonding: do not assume skb mac_header is set (Hangbin Liu) [RHEL-13959]
- bonding: Fix incorrect deletion of ETH_P_8021AD protocol vid from slaves (Hangbin Liu) [RHEL-13959]
- bonding: support balance-alb with openvswitch (Hangbin Liu) [RHEL-13959]
- bonding: reset bond's flags when down link is P2P device (Hangbin Liu) [RHEL-13959]
- net: fix stack overflow when LRO is disabled for virtual interfaces (Hangbin Liu) [RHEL-13959]
- Documentation: bonding: fix the doc of peer_notif_delay (Hangbin Liu) [RHEL-13959]
- bonding: fix send_peer_notif overflow (Hangbin Liu) [RHEL-13959]
- bonding: Fix memory leak when changing bond type to Ethernet (Hangbin Liu) [RHEL-13959]
- bonding: restore bond's IFF_SLAVE flag if a non-eth dev enslave fails (Hangbin Liu) [RHEL-13959]
- bonding: restore IFF_MASTER/SLAVE flags on bond enslave ether type change (Hangbin Liu) [RHEL-13959]
- drivers/net/bonding/bond_3ad: return when there's no aggregator (Hangbin Liu) [RHEL-13959]
- KVM: s390: pv: Allow AP-instructions for pv-guests (Thomas Huth) [2111392]
- KVM: s390: Add UV feature negotiation (Thomas Huth) [2111392]
- s390/uv: UV feature check utility (Thomas Huth) [2111392]
- s390/vfio-ap: make sure nib is shared (Thomas Huth) [2111392]
- KVM: s390: export kvm_s390_pv*_is_protected functions (Thomas Huth) [2111392]
- s390/uv: export uv_pin_shared for direct usage (Thomas Huth) [2111392]
- s390/vfio-ap: check for TAPQ response codes 0x35 and 0x36 (Thomas Huth) [2111392]
- s390/vfio-ap: handle queue state change in progress on reset (Thomas Huth) [2111392]
- s390/vfio-ap: use work struct to verify queue reset (Thomas Huth) [2111392]
- s390/vfio-ap: store entire AP queue status word with the queue object (Thomas Huth) [2111392]
- s390/vfio-ap: remove upper limit on wait for queue reset to complete (Thomas Huth) [2111392]
- s390/vfio-ap: allow deconfigured queue to be passed through to a guest (Thomas Huth) [2111392]
- s390/vfio-ap: wait for response code 05 to clear on queue reset (Thomas Huth) [2111392]
- s390/vfio-ap: clean up irq resources if possible (Thomas Huth) [2111392]
- s390/vfio-ap: no need to check the 'E' and 'I' bits in APQSW after TAPQ (Thomas Huth) [2111392]
- s390/vfio-ap: fix memory leak in vfio_ap device driver (Thomas Huth) [2111392]
- s390/vfio-ap: remove redundant driver match function (Thomas Huth) [2111392]
- s390/vfio_ap: increase max wait time for reset verification (Thomas Huth) [2111392]
- s390/vfio_ap: fix handling of error response codes (Thomas Huth) [2111392]
- s390/vfio_ap: verify ZAPQ completion after return of response code zero (Thomas Huth) [2111392]
- s390/vfio_ap: use TAPQ to verify reset in progress completes (Thomas Huth) [2111392]
- s390/vfio_ap: check TAPQ response code when waiting for queue reset (Thomas Huth) [2111392]
- s390/vfio-ap: verify reset complete in separate function (Thomas Huth) [2111392]
- s390/vfio-ap: fix an error handling path in vfio_ap_mdev_probe_queue() (Thomas Huth) [2111392]
- s390/vfio-ap: add s390dbf logging to the vfio_ap_irq_enable function (Thomas Huth) [2111392]
- s390-vfio-ap: introduces s390 kernel debug feature for vfio_ap device driver (Thomas Huth) [2111392]

* Sun Nov 05 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-522.el8]
- netfilter: ipset: add the missing IP_SET_HASH_WITH_NET0 macro for ip_set_hash_netportnet.c (Florian Westphal) [RHEL-8444] {CVE-2023-42753}
- cxgb4: fix use after free bugs caused by circular dependency problem (Ricardo Robaina) [RHEL-6261 RHEL-7058] {CVE-2023-4133}
- ipvs: queue delayed work to expire no destination connections if expire_nodest_conn=1 (Florian Westphal) [RHEL-5742]
- bpf: Fix incorrect verifier pruning due to missing register precision taints (Artem Savkov) [RHEL-7534 RHEL-7535] {CVE-2023-2163}
- mm/memcontrol.c: remove the redundant updating of stats_flush_threshold (Waiman Long) [2238379]
- virtio_balloon: Fix endless deflation and inflation on arm64 (Gavin Shan) [RHEL-1672]
- i40e: Fix VF VLAN offloading when port VLAN is configured (Ivan Vecera) [RHEL-6384]
- libfs: take cursors out of list when moving past the end of directory (Jeffrey Layton) [RHEL-15148]
- net/core: Fix ETH_P_1588 flow dissector (Paolo Abeni) [RHEL-14379]
- skbuff: skb_segment, Call zero copy functions before using skbuff frags (Paolo Abeni) [RHEL-14379]
- net: prevent skb corruption on frag list segmentation (Paolo Abeni) [RHEL-14379]
- udp6: Fix race condition in udp6_sendmsg & connect (Paolo Abeni) [RHEL-14379]
- scsi: megaraid_sas: Driver version update to 07.727.03.00-rc1 (Tomas Henzl) [RHEL-8244]
- scsi: megaraid_sas: Log message when controller reset is requested but not issued (Tomas Henzl) [RHEL-8244]
- scsi: megaraid_sas: Increase register read retry rount from 3 to 30 for selected registers (Tomas Henzl) [RHEL-8244]
- scsi: megaraid_sas: Fix deadlock on firmware crashdump (Tomas Henzl) [RHEL-8244]
- scsi: megaraid_sas: Use pci_dev_id() to simplify the code (Tomas Henzl) [RHEL-8244]
- scsi: megaraid_sas: Convert union megasas_sgl to flex-arrays (Tomas Henzl) [RHEL-8244]
- scsi: smartpqi: Change driver version to 2.1.24-046 (Don Brace) [RHEL-1728]
- scsi: smartpqi: Enhance error messages (Don Brace) [RHEL-1728]
- scsi: smartpqi: Enhance controller offline notification (Don Brace) [RHEL-1728]
- scsi: smartpqi: Enhance shutdown notification (Don Brace) [RHEL-1728]
- scsi: smartpqi: Simplify lun_number assignment (Don Brace) [RHEL-1728]
- scsi: smartpqi: Rename pciinfo to pci_info (Don Brace) [RHEL-1728]
- scsi: smartpqi: Rename MACRO to clarify purpose (Don Brace) [RHEL-1728]
- scsi: smartpqi: Add abort handler (Don Brace) [RHEL-1728]
- x86/sgx: mark as supported (Vladis Dronov) [2041881]
- x86/sgx: Resolves SECS reclaim vs. page fault for EAUG race (Vladis Dronov) [2041881]
- x86/sgx: Break up long non-preemptible delays in sgx_vepc_release() (Vladis Dronov) [2041881]
- Documentation: Fix typos (only the SGX part) (Vladis Dronov) [2041881]
- x86/sgx: Avoid using iterator after loop in sgx_mmu_notifier_release() (Vladis Dronov) [2041881]
- selftests/sgx: Add "test_encl.elf" to TEST_FILES (Vladis Dronov) [2041881]
- convert sgx_set_attribute() to fdget()/fdput() (Vladis Dronov) [2041881]
- x86/sgx: use VM_ACCESS_FLAGS (Vladis Dronov) [2041881]
- x86/sgx: Replace kmap/kunmap_atomic() calls (Vladis Dronov) [2041881]
- x86/sgx: Allow enclaves to use Asynchrounous Exit Notification (Vladis Dronov) [2041881]
- x86/sgx: Reduce delay and interference of enclave release (Vladis Dronov) [2041881]
- x86/vdso: Conditionally export __vdso_sgx_enter_enclave() (Vladis Dronov) [2041881]
- x86/sgx: Add overflow check in sgx_validate_offset_length() (Vladis Dronov) [2041881]

* Mon Oct 30 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-521.el8]
- team: fix null-ptr-deref when team device type is changed (Hangbin Liu) [RHEL-13961]
- team: Fix incorrect deletion of ETH_P_8021AD protocol vid from slaves (Hangbin Liu) [RHEL-13961]
- team: reset team's flags when down link is P2P device (Hangbin Liu) [RHEL-13961]
- teaming: deliver link-local packets with the link they arrive on (Hangbin Liu) [RHEL-13961]
- kernfs: change kernfs_rename_lock into a read-write lock. (Ian Kent) [RHEL-11484]
- kernfs: Separate kernfs_pr_cont_buf and rename_lock. (Ian Kent) [RHEL-11484]
- kernfs: fix missing kernfs_iattr_rwsem locking (Ian Kent) [RHEL-11484]
- kernfs: Use a per-fs rwsem to protect per-fs list of kernfs_super_info (Ian Kent) [RHEL-11484]
- kernfs: Introduce separate rwsem to protect inode attributes (Ian Kent) [RHEL-11484]
- kernfs: move struct kernfs_root out of the public view. (Ian Kent) [RHEL-11484]
- iw_cxgb4: Fix potential NULL dereference in c4iw_fill_res_cm_id_entry() (Kamal Heib) [RHEL-1734]
- RDMA/cxgb4: Fix potential null-ptr-deref in pass_establish() (Kamal Heib) [RHEL-1734]
- RDMA/cxgb4: add null-ptr-check after ip_dev_find() (Kamal Heib) [RHEL-1734]
- RDMA/cxgb4: Replace 0-length arrays with flexible arrays (Kamal Heib) [RHEL-1734]
- RDMA/cxgb4: remove unnecessary NULL check in __c4iw_poll_cq_one() (Kamal Heib) [RHEL-1734]
- block: check_events: don't bother with events if unsupported (Ming Lei) [RHEL-2407]
- Revert "block: unexport DISK_EVENT_MEDIA_CHANGE for legacy/fringe drivers" (Ming Lei) [RHEL-2407]
- Revert "ide: unexport DISK_EVENT_MEDIA_CHANGE for ide-gd and ide-cd" (Ming Lei) [RHEL-2407]
- block: disk_events: introduce event flags (Ming Lei) [RHEL-2407]
- block: genhd: remove async_events field (Ming Lei) [RHEL-2407]
- ibmvnic: Ensure login failure recovery is safe from other resets (Mamatha Inamdar) [RHEL-11211]
- ibmvnic: Do partial reset on login failure (Mamatha Inamdar) [RHEL-11211]
- ibmvnic: Handle DMA unmapping of login buffs in release functions (Mamatha Inamdar) [RHEL-11211]
- ibmvnic: Unmap DMA login rsp buffer on send login fail (Mamatha Inamdar) [RHEL-11211]
- ibmvnic: Enforce stronger sanity checks on login response (Mamatha Inamdar) [RHEL-11211]
- ibmvnic: Free rwi on reset success (Mamatha Inamdar) [RHEL-11211]
- selftests: tls: swap the TX and RX sockets in some tests (Hangbin Liu) [RHEL-13962]
- selftests: mirror_gre_changes: Tighten up the TTL test match (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: tc_tunnel_key: Make filters more specific (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: tc_flower: Relax success criterion (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: ethtool_extended_state: Skip when using veth pairs (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: ethtool: Skip when using veth pairs (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: Add a helper to skip test when using veth pairs (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: Set default IPv6 traceroute utility (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: Switch off timeout (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: Skip test when no interfaces are specified (Hangbin Liu) [RHEL-13962]
- selftests: rtnetlink: remove netdevsim device after ipsec offload test (Hangbin Liu) [RHEL-13962]
- selftests: forwarding: Fix race condition in mirror installation (Hangbin Liu) [RHEL-13962]
- selftests: fib_tests: mute cleanup error message (Hangbin Liu) [RHEL-13962]
- sched/topology: Align group flags when removing degenerate domain (Phil Auld) [RHEL-2524]
- sched/fair: Use recent_used_cpu to test p->cpus_ptr (Phil Auld) [RHEL-2524]
- sched/core: Avoid double calling update_rq_clock() in __balance_push_cpu_stop() (Phil Auld) [RHEL-2524]
- sched/core: Fixed missing rq clock update before calling set_rq_offline() (Phil Auld) [RHEL-2524]
- sched/topology: Mark set_sched_topology() __init (Phil Auld) [RHEL-2524]
- sched/wait: Fix a kthread_park race with wait_woken() (Phil Auld) [RHEL-2524]
- sched: Add schedule_user() declaration (Phil Auld) [RHEL-2524]
- sched/topology: Propagate SMT flags when removing degenerate domain (Phil Auld) [RHEL-2524]
- sched_getaffinity: don't assume 'cpumask_size()' is fully initialized (Phil Auld) [RHEL-2524]
- sched/topology: Make sched_energy_mutex,update static (Phil Auld) [RHEL-2524]
- sched/fair: Fix inaccurate tally of ttwu_move_affine (Phil Auld) [RHEL-2524]
- sched/fair: Revise comment about lb decision matrix (Phil Auld) [RHEL-2524]
- sched/topology: Remove unused numa_distance in cpu_attach_domain() (Phil Auld) [RHEL-2524]
- perf vendor events: Update metric events for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events: Update metric event names for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events: Update JSON/events for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events: Move JSON/events to appropriate files for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events: Drop STORES_PER_INST metric event for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events: Drop some of the JSON/events for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events: Update the JSON/events descriptions for power10 platform (Mamatha Inamdar) [RHEL-11205]
- perf vendor events power10: Add JSON metric events to present CPI stall cycles in powerpc (Mamatha Inamdar) [RHEL-11205]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document affinity_domain_via_partition sysfs interface file (Mamatha Inamdar) [RHEL-11205]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show affinity domain via partition information (Mamatha Inamdar) [RHEL-11205]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document affinity_domain_via_domain sysfs interface file (Mamatha Inamdar) [RHEL-11205]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show affinity domain via domain information (Mamatha Inamdar) [RHEL-11205]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document affinity_domain_via_virtual_processor sysfs interface file (Mamatha Inamdar) [RHEL-11205]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show affinity domain via virtual processor information (Mamatha Inamdar) [RHEL-11205]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document processor_config sysfs interface file (Mamatha Inamdar) [RHEL-11205]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show processor config information (Mamatha Inamdar) [RHEL-11205]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document processor_bus_topology sysfs interface file (Mamatha Inamdar) [RHEL-11205]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show processor bus topology information (Mamatha Inamdar) [RHEL-11205]
- KVM: x86: Add SBPB support (Waiman Long) [RHEL-11272 RHEL-9298]
- KVM: x86: Add IBPB_BRTYPE support (Waiman Long) [RHEL-11272 RHEL-9298]
- x86/retpoline: Document some thunk handling aspects (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Remove unnecessary semicolon (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/rethunk: Use SYM_CODE_START[_LOCAL]_NOALIGN macros (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Disentangle rethunk-dependent options (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Move retbleed IBPB check into existing 'has_microcode' code block (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/bugs: Remove default case for fully switched enums (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Remove 'pred_cmd' label (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Unexport untraining functions (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Improve i-cache locality for alias mitigation (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Fix vulnerability reporting for missing microcode (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Print mitigation for retbleed IBPB case (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Print actual mitigation if requested mitigation isn't possible (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Fix SBPB enablement for (possible) future fixed HW (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/alternatives: Remove faulty optimization (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Fix SBPB enablement for spec_rstack_overflow=off (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Don't probe microcode in a guest (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Set CPUID feature bits independently of bug or mitigation status (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Fix srso_show_state() side effect (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Fix amd_check_microcode() declaration (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/CPU/AMD: Remove amd_get_topology_early() (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Correct the mitigation status when SMT is disabled (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Explain the untraining sequences a bit more (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu/kvm: Provide UNTRAIN_RET_VM (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Cleanup the untrain mess (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Rename srso_(.*)_alias to srso_alias_\1 (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Rename original retbleed methods (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Clean up SRSO return thunk mess (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/alternative: Make custom return thunk unconditional (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- objtool/x86: Fix SRSO mess (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Fix up srso_safe_ret() and __x86_return_thunk() (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu: Fix __x86_return_thunk symbol type (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/retpoline,kprobes: Fix position of thunk sections with CONFIG_LTO_CLANG (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Disable the mitigation on unaffected configurations (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/CPU/AMD: Fix the DIV(0) initial fix attempt (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20588}
- x86/retpoline: Don't clobber RFLAGS during srso_safe_ret() (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/cpu/amd: Enable Zenbleed fix for AMD Custom APU 0405 (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20593}
- driver core: cpu: Fix the fallback cpu_show_gds() name (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86: Move gds_ucode_mitigated() declaration to header (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/speculation: Add cpu_show_gds() prototype (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- driver core: cpu: Make cpu_show_not_affected() static (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Fix build breakage with the LLVM linker (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- Documentation/srso: Document IBPB aspect and fix formatting (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- driver core: cpu: Unify redundant silly stubs (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/CPU/AMD: Do not leak quotient data after a division by 0 (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20588}
- x86/srso: Tie SBPB bit setting to microcode patch detection (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Add a forgotten NOENDBR annotation (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Fix return thunks in generated code (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Add IBPB on VMEXIT (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Add IBPB (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Add SRSO_NO support (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Add IBPB_BRTYPE support (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/srso: Add a Speculative RAS Overflow mitigation (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/retbleed: Add __x86_return_thunk alignment checks (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/retbleed: Fix return thunk alignment (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/alternative: Optimize returns patching (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/microcode/AMD: Load late on both threads too (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86/returnthunk: Allow different return thunks (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- x86: Sanitize linker script (Waiman Long) [RHEL-11272 RHEL-9298] {CVE-2023-20569}
- objtool: Fix .return_sites generation (Waiman Long) [RHEL-11272 RHEL-9298]

* Fri Oct 27 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-520.el8]
- kernel/rh_messages.c: move hardware tables to rh_messages.h (Scott Weaver) [2181912]
- kernel/rh_messages.c: Wire up new calls (Prarit Bhargava) [2181912]
- drivers/pci: Update rh_messages.c (Prarit Bhargava) [2181912]
- treewide: Remove mark_driver_deprecated() (Prarit Bhargava) [2181912]
- treewide: Remove mark_hardware_deprecated() (Prarit Bhargava) [2181912]
- treewide: Remove mark_driver_unmaintained() (Prarit Bhargava) [2181912]
- drivers/pci: Remove RHEL-only pci_hw_*() functions (Prarit Bhargava) [2181912]
- treewide: Remove pci_hw_disabled() calls (Prarit Bhargava) [2181912]
- treewide: Remove pci_hw_deprecated() calls (Prarit Bhargava) [2181912]
- treewide: Remove pci_hw_unmaintained() calls (Prarit Bhargava) [2181912]
- redhat: fix bug/zjira sort in the changelog (Patrick Talbert)
- blk-mq: enforce op-specific segment limits in blk_insert_cloned_request (Ming Lei) [RHEL-14504]
- tunnels: fix kasan splat when generating ipv4 pmtu error (Guillaume Nault) [RHEL-14377]
- net:ipv6: check return value of pskb_trim() (Guillaume Nault) [RHEL-14377]
- sit: update dev->needed_headroom in ipip6_tunnel_bind_dev() (Guillaume Nault) [RHEL-14377]
- ipv4: fix null-deref in ipv4_link_failure (Felix Maurer) [RHEL-5427] {CVE-2023-42754}
- powerpc/perf/hv-24x7: Update domain value check (Michael Petlan) [RHEL-13718]
- vxlan: Expose helper vxlan_build_gbp_hdr (Izabela Bakollari) [RHEL-12413]
- vxlan: Remove unused argument from vxlan_build_gbp_hdr( ) and vxlan_build_gpe_hdr( ) (Izabela Bakollari) [RHEL-12413]
- net: ipv4: fix one memleak in __inet_del_ifa() (Guillaume Nault) [RHEL-14375]
- ipv4: Fix potential uninit variable access bug in __ip_make_skb() (Guillaume Nault) [RHEL-14375]
- icmp: guard against too small mtu (Guillaume Nault) [RHEL-14375]
- ipv6: ping: fix wrong checksum for large frames (Guillaume Nault) [RHEL-14375]
- net: ipv6/addrconf: avoid integer underflow in ipv6_create_tempaddr (Hangbin Liu) [RHEL-13954]
- ip6mr: Fix skb_under_panic in ip6mr_cache_report() (Hangbin Liu) [RHEL-13954]
- ipv6 addrconf: fix bug where deleting a mngtmpaddr can create a new temporary address (Hangbin Liu) [RHEL-13954]
- ipv6/addrconf: fix a potential refcount underflow for idev (Hangbin Liu) [RHEL-13954]
- icmp6: Fix null-ptr-deref of ip6_null_entry->rt6i_idev in icmp6_dev(). (Hangbin Liu) [RHEL-13954]
- ping6: Fix send to link-local addresses with VRF. (Hangbin Liu) [RHEL-13954]
- ipv6: Fix out-of-bounds access in ipv6_find_tlv() (Hangbin Liu) [RHEL-13954]

* Tue Oct 24 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-519.el8]
- redhat: remove kabi-rhel810 directory (Prarit Bhargava)
- redhat: Update .gitignore for 8.10 kabi files (Prarit Bhargava)
- nvmet-tcp: Fix a possible UAF in queue intialization setup (John Meneghini) [RHEL-11509 RHEL-11527] {CVE-2023-5178}
- sctp: update hb timer immediately after users change hb_interval (Xin Long) [RHEL-6045]
- s390/zcrypt_ep11misc: support API ordinal 6 with empty pin-blob (Tobias Huschle) [RHEL-11200]
- net: openvswitch: add support for l4 symmetric hashing (Antoine Tenart) [RHEL-10498]
- igmp: limit igmpv3_newpack() packet size to IP_MAX_MTU (Hangbin Liu) [RHEL-10475 RHEL-10477] {CVE-2023-42752}
- ip_tunnel: Preserve pointer const in ip_tunnel_info_opts (Ivan Vecera) [RHEL-12418]
- tracing: Fix race in perf_trace_buf initialization (Michael Petlan) [RHEL-8648]
- Input: gtco - bounds check collection indent level (Desnes Nunes) [RHEL-3014 RHEL-3892] {CVE-2019-13631}
- x86/microcode/AMD: Rip out static buffers (Prarit Bhargava) [2225261]
- perf/x86/amd: Do not WARN() on every IRQ (Michael Petlan) [RHEL-12340]
- netfilter: conntrack: Fix gre tunneling over ipv6 (Florian Westphal) [RHEL-12497]
- netfilter: handle the connecting collision properly in nf_conntrack_proto_sctp (Xin Long) [RHEL-6157]
- sctp: update transport state when processing a dupcook packet (Xin Long) [RHEL-6157]

* Wed Oct 18 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-518.el8]
- trace: Add trace_ipi_send_cpu() (Jerome Marchand) [2192614]
- sched, smp: Trace smp callback causing an IPI (Jerome Marchand) [2192614]
- smp: reword smp call IPI comment (Jerome Marchand) [2192614]
- treewide: Trace IPIs sent via smp_send_reschedule() (Jerome Marchand) [2192614]
- irq_work: Trace self-IPIs sent via arch_irq_work_raise() (Jerome Marchand) [2192614]
- smp: Trace IPIs sent via arch_send_call_function_ipi_mask() (Jerome Marchand) [2192614]
- sched, smp: Trace IPIs sent via send_call_function_single_ipi() (Jerome Marchand) [2192614]
- trace: Add trace_ipi_send_cpumask() (Jerome Marchand) [2192614]
- RDMA/umem: Set iova in ODP flow (Kamal Heib) [RHEL-1032]
- RDMA/core: Update CMA destination address on rdma_resolve_addr (Kamal Heib) [RHEL-1032]
- RDMA/core: Refactor rdma_bind_addr (Kamal Heib) [RHEL-1032]
- RDMA/cma: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-1032]
- IB/isert: Fix possible list corruption in CMA handler (Kamal Heib) [RHEL-1028]
- IB/isert: Fix dead lock in ib_isert (Kamal Heib) [RHEL-1028]
- RDMA/srpt: Add a check for valid 'mad_agent' pointer (Kamal Heib) [RHEL-1028]
- IB/iser: remove redundant new line (Kamal Heib) [RHEL-1028]
- IB/iser: centralize setting desc type and done callback (Kamal Heib) [RHEL-1028]
- IB/iser: remove unused macros (Kamal Heib) [RHEL-1028]
- IB/uverbs: Fix to consider event queue closing also upon non-blocking mode (Kamal Heib) [RHEL-1028]
- RDMA/uverbs: Restrict usage of privileged QKEYs (Kamal Heib) [RHEL-1028]
- RDMA/cma: Always set static rate to 0 for RoCE (Kamal Heib) [RHEL-1028]
- RDMA/core: Fix GID entry ref leak when create_ah fails (Kamal Heib) [RHEL-1028]
- RDMA/cm: Trace icm_send_rej event before the cm state is reset (Kamal Heib) [RHEL-1028]
- RDMA/cma: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-1028]
- RDMA/core: Fix multiple -Warray-bounds warnings (Kamal Heib) [RHEL-1028]
- RDMA/cma: Allow UD qp_type to join multicast only (Kamal Heib) [RHEL-1028]
- md/raid5: release batch_last before waiting for another stripe_head (Nigel Croxon) [RHEL-9875]
- CI: Remove unused kpet_tree_family (Nikolai Kondrashov)
- ice: Don't tx before switchdev is fully configured (Michal Schmidt) [RHEL-10997]
- fbcon: set_con2fb_map needs to set con2fb_map! (Wander Lairson Costa) [RHEL-1183] {CVE-2023-38409}
- fbcon: Fix error paths in set_con2fb_map (Wander Lairson Costa) [RHEL-1183] {CVE-2023-38409}
- mm/slab_common: fix slab_caches list corruption after kmem_cache_destroy() (Rafael Aquini) [RHEL-3652]
- sched/rt: Fix bad task migration for rt tasks (Valentin Schneider) [RHEL-3872]
- RDMA/irdma: Prevent zero-length STAG registration (Kamal Heib) [RHEL-6389] {CVE-2023-25775}
- mm/memcontrol: export memcg.swap watermark via sysfs for v2 memcg (Waiman Long) [RHEL-10099]
- cgroup: add pids.peak interface for pids controller (Waiman Long) [RHEL-10099]
- mm/memcontrol: export memcg->watermark via sysfs for v2 memcg (Waiman Long) [RHEL-10099]
- cpufreq: amd-pstate: fix global sysfs attribute type (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Add a kernel config option to set default mode (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Set a fallback policy based on preferred_profile (Prarit Bhargava) [2218687]
- ACPI: CPPC: Add definition for undefined FADT preferred PM profile value (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Make amd-pstate EPP driver name hyphenated (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Write CPPC enable bit per-socket (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Update policy->cur in amd_pstate_adjust_perf() (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Remove fast_switch_possible flag from active driver (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Add ->fast_switch() callback (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Make varaiable mode_state_machine static (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Add guided mode control support via sysfs (Prarit Bhargava) [2218687]
- amd-pstate: Fix amd_pstate mode switch (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Add guided autonomous mode (Prarit Bhargava) [2218687]
- ACPI: CPPC: Add auto select register read/write support (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: move to use bus_get_dev_root() (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: remove MODULE_LICENSE in non-modules (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Let user know amd-pstate is disabled (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Fix invalid write to MSR_AMD_CPPC_REQ (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: avoid uninitialized variable use (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: convert sprintf with sysfs_emit() (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: add driver working mode switch support (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: implement suspend and resume callbacks (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: implement amd pstate cpu online and offline callback (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: implement Pstate EPP support for the AMD processors (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: optimize driver working mode selection in amd_pstate_param() (Prarit Bhargava) [2218687]
- ACPI: CPPC: Add AMD pstate energy performance preference cppc control (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: fix kernel hang issue while amd-pstate unregistering (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Fix initial highest_perf value (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: Expose struct amd_cpudata (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: update pstate frequency transition delay time (Prarit Bhargava) [2218687]
- cpufreq: amd_pstate: map desired perf into pstate scope for powersave governor (Prarit Bhargava) [2218687]
- cpufreq: amd_pstate: fix wrong lowest perf fetch (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: fix white-space (Prarit Bhargava) [2218687]
- cpufreq: amd-pstate: simplify cpudata pointer assignment (Prarit Bhargava) [2218687]

* Tue Oct 10 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-517.el8]
- Bluetooth: L2CAP: Fix u8 overflow (Wander Lairson Costa) [2152858] {CVE-2022-45934}
- tracing/histograms: Fix parsing of "sym-offset" modifier (Jerome Marchand) [2229575]
- ice: always add legacy 32byte RXDID in supported_rxdids (Michal Schmidt) [RHEL-3379]
- task_work: cleanup notification modes (Audra Mitchell) [RHEL-1064]
- perf test topology: Use !strncmp(right platform) to fix guest PPC comparision check (Michael Petlan) [2131821]
- perf test session topology: Fix test to skip the test in guest environment (Michael Petlan) [2131821]
- sched/fair: Block nohz tick_stop when cfs bandwidth in use (Phil Auld) [RHEL-2527]
- sched, cgroup: Restore meaning to hierarchical_quota (Phil Auld) [RHEL-2527]
- sched/fair: Hide unused init_cfs_bandwidth() stub (Phil Auld) [RHEL-2527]
- rbd: take header_rwsem in rbd_dev_refresh() only when updating (Ilya Dryomov) [RHEL-11241]
- rbd: decouple parent info read-in from updating rbd_dev (Ilya Dryomov) [RHEL-11241]
- rbd: decouple header read-in from updating rbd_dev->header (Ilya Dryomov) [RHEL-11241]
- rbd: move rbd_dev_refresh() definition (Ilya Dryomov) [RHEL-11241]
- redhat: list Z-Jiras in the changelog before Y-Jiras (Herton R. Krzesinski)
- Revert "mm, meminit: recalculate pcpu batch and high limits after init completes" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm,memory_hotplug: factor out adjusting present pages into adjust_present_page_count()" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: move free_the_page" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: allow high-order pages to be stored on the per-cpu lists" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: fetch the correct pcp buddy during bulk free" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: track range of active PCP lists during bulk free" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: simplify how many pages are selected per pcp list during bulk free" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: drain the requested list first during bulk free" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: free pages in a single pass during bulk free" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: do not prefetch buddies during bulk free" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: check high-order pages for corruption during PCP operations" (Chris von Recklinghausen) [RHEL-8539]
- Revert "mm/page_alloc: fix incorrect PGFREE and PGALLOC for high-order page" (Chris von Recklinghausen) [RHEL-8539]
- Revert "cnic: Use the bitmap API to allocate bitmaps" (Chris Leech) [RHEL-1950]
- Revert "cnic: don't pass bogus GFP_ flags to dma_alloc_coherent" (Chris Leech) [RHEL-1950]
- scsi: lpfc: Prevent use-after-free during rmmod with mapped NVMe rports (Paul Ely) [RHEL-2602]
- scsi: lpfc: Early return after marking final NLP_DROPPED flag in dev_loss_tmo (Paul Ely) [RHEL-2602]
- gfs2: Add quota_change type (Bob Peterson) [2224075]

* Mon Oct 02 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-516.el8]
- bpf: Adjust insufficient default bpf_jit_limit (Viktor Malik) [2219567]
- bpf: Prevent increasing bpf_jit_limit above max (Viktor Malik) [2219567]
- NFS: Guard against READDIR loop when entry names exceed MAXNAMELEN (Benjamin Coddington) [2231130]
- perf/arm-dmc620: Fix dmc620_pmu_irqs_lock/cpu_hotplug_lock circular lock dependency (Waiman Long) [2177103]
- bonding: fix macvlan over alb bond support (Hangbin Liu) [2117816]
- s390/ipl: add missing secure/has_secure file to ipl type 'unknown' (Tobias Huschle) [RHEL-2852]
- s390/zcrypt: fix reply buffer calculations for CCA replies (Tobias Huschle) [2227778]
- intel_th: pci: Add Meteor Lake-P support (Michael Petlan) [2156847]
- perf/x86/rapl: Add support for Intel Meteor Lake (Michael Petlan) [2156816]
- iavf: schedule a request immediately after add/delete vlan (Petr Oros) [2231174]
- iavf: add iavf_schedule_aq_request() helper (Petr Oros) [2231174]
- PCI: rpaphp: Error out on busy status from get-sensor-state (Mamatha Inamdar) [2230045]
- powerpc/rtas: export rtas_error_rc() for reuse. (Mamatha Inamdar) [2230045]
- powerpc/eeh: Set channel state after notifying the drivers (Mamatha Inamdar) [2230045]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling for sysfs attributes (Tobias Huschle) [2225520]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_VERIFYKEY2 IOCTL (Tobias Huschle) [2225520]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_KBLOB2PROTK[23] (Tobias Huschle) [2225520]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_CLR2SECK2 IOCTL (Tobias Huschle) [2225520]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_GENSECK2 IOCTL (Tobias Huschle) [2225520]
- s390/pkey: fix/harmonize internal keyblob headers (Tobias Huschle) [2225520]
- s390/pkey: add support for ecc clear key (Tobias Huschle) [2225520]
- s390/pkey: do not use struct pkey_protkey (Tobias Huschle) [2225520]
- s390/pkey: introduce reverse x-mas trees (Tobias Huschle) [2225520]
- s390/pkey: zeroize key blobs (Tobias Huschle) [2225520]
- md/raid1: fix error: ISO C90 forbids mixed declarations (Nigel Croxon) [RHEL-5084]
- md raid1: allow writebehind to work on any leg device set WriteMostly (Nigel Croxon) [RHEL-5084]
- md/raid1: hold the barrier until handle_read_error() finishes (Nigel Croxon) [RHEL-5084]
- md/raid1: free the r1bio before waiting for blocked rdev (Nigel Croxon) [RHEL-5084]
- md/raid1: call free_r1bio() before allow_barrier() in raid_end_bio_io() (Nigel Croxon) [RHEL-5084]
- md/raid5-cache: fix null-ptr-deref for r5l_flush_stripe_to_raid() (Nigel Croxon) [RHEL-5084]
- md/raid10: fix a 'conf->barrier' leakage in raid10_takeover() (Nigel Croxon) [RHEL-5084]
- md: raid1: fix potential OOB in raid1_remove_disk() (Nigel Croxon) [RHEL-5084]
- md/raid5-cache: fix a deadlock in r5l_exit_log() (Nigel Croxon) [RHEL-5084]
- md/md-bitmap: hold 'reconfig_mutex' in backlog_store() (Nigel Croxon) [RHEL-5084]
- md/md-bitmap: remove unnecessary local variable in backlog_store() (Nigel Croxon) [RHEL-5084]
- md: restore 'noio_flag' for the last mddev_resume() (Nigel Croxon) [RHEL-5084]
- md: don't quiesce in mddev_suspend() (Nigel Croxon) [RHEL-5084]
- md: move initialization and destruction of 'io_acct_set' to md.c (Nigel Croxon) [RHEL-5084]
- md: enhance checking in md_check_recovery() (Nigel Croxon) [RHEL-5084]
- md: wake up 'resync_wait' at last in md_reap_sync_thread() (Nigel Croxon) [RHEL-5084]
- md: refactor idle/frozen_sync_thread() to fix deadlock (Nigel Croxon) [RHEL-5084]
- md: add a mutex to synchronize idle and frozen in action_store() (Nigel Croxon) [RHEL-5084]
- md: refactor action_store() for 'idle' and 'frozen' (Nigel Croxon) [RHEL-5084]
- Revert "md: unlock mddev before reap sync_thread in action_store" (Nigel Croxon) [RHEL-5084]
- md/raid0: add discard support for the 'original' layout (Nigel Croxon) [RHEL-5084]
- md/raid10: prevent soft lockup while flush writes (Nigel Croxon) [RHEL-5084]
- md/raid10: fix io loss while replacement replace rdev (Nigel Croxon) [RHEL-5084]
- md/raid10: Do not add spare disk when recovery fails (Nigel Croxon) [RHEL-5084]
- md/raid10: clean up md_add_new_disk() (Nigel Croxon) [RHEL-5084]
- md/raid10: prioritize adding disk to 'removed' mirror (Nigel Croxon) [RHEL-5084]
- md/raid10: improve code of mrdev in raid10_sync_request (Nigel Croxon) [RHEL-5084]
- md/raid10: fix null-ptr-deref of mreplace in raid10_sync_request (Nigel Croxon) [RHEL-5084]
- md/raid5: don't start reshape when recovery or replace is in progress (Nigel Croxon) [RHEL-5084]
- md/bitmap: factor out a helper to set timeout (Nigel Croxon) [RHEL-5084]
- md/bitmap: always wake up md_thread in timeout_store (Nigel Croxon) [RHEL-5084]
- md: factor out a helper to wake up md_thread directly (Nigel Croxon) [RHEL-5084]
- md/raid10: fix wrong setting of max_corr_read_errors (Nigel Croxon) [RHEL-5084]
- md/raid10: fix overflow of md/safe_mode_delay (Nigel Croxon) [RHEL-5084]
- md/raid5: fix a deadlock in the case that reshape is interrupted (Nigel Croxon) [RHEL-5084]
- md: add a new api prepare_suspend() in md_personality (Nigel Croxon) [RHEL-5084]
- md: export md_is_rdwr() and is_md_suspended() (Nigel Croxon) [RHEL-5084]
- md: introduce md_ro_state (Nigel Croxon) [RHEL-5084]
- md: fix data corruption for raid456 when reshape restart while grow up (Nigel Croxon) [RHEL-5084]
- md/raid5: don't allow replacement while reshape is in progress (Nigel Croxon) [RHEL-5084]
- md/raid10: check slab-out-of-bounds in md_bitmap_get_counter (Nigel Croxon) [RHEL-5084]
- md: raid1: check if adding pages to resync bio fails (Nigel Croxon) [RHEL-5084]
- md: raid1: use __bio_add_page for adding single page to bio (Nigel Croxon) [RHEL-5084]
- md: check for failure when adding pages in alloc_behind_master_bio (Nigel Croxon) [RHEL-5084]
- md: raid5: use __bio_add_page to add single page to new bio (Nigel Croxon) [RHEL-5084]
- md: raid5-log: use __bio_add_page to add single page (Nigel Croxon) [RHEL-5084]
- md: use __bio_add_page to add single page (Nigel Croxon) [RHEL-5084]
- md/raid5: fix miscalculation of 'end_sector' in raid5_read_one_chunk() (Nigel Croxon) [RHEL-5084]

* Sun Sep 24 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-515.el8]
- s390/dasd: fix hanging device after quiesce/resume (Tobias Huschle) [RHEL-2838]
- s390/dasd: fix hanging device after request requeue (Tobias Huschle) [RHEL-2830]
- s390/dasd: fix command reject error on ESE devices (Tobias Huschle) [RHEL-2850]
- s390/dasd: print copy pair message only for the correct error (Tobias Huschle) [RHEL-2831]
- s390: add z16 elf platform (Tobias Huschle) [RHEL-2854]
- s390/qeth: Don't call dev_close/dev_open (DOWN/UP) (Tobias Huschle) [RHEL-2410]
- powerpc/kprobes: Fix null pointer reference in arch_prepare_kprobe() (Mamatha Inamdar) [2227601]
- arm64: kdump: Remove custom linux,usable-memory-range handling (Baoquan He) [RHEL-2307]
- arm64: kdump: Remove custom linux,elfcorehdr handling (Baoquan He) [RHEL-2307]
- media: dvb-core: Fix use-after-free due to race condition at dvb_ca_en50221 (Dean Nelson) [RHEL-1784] {CVE-2022-45919}
- media: dvb-core: Fix use-after-free due to race at dvb_register_device() (Dean Nelson) [RHEL-1841] {CVE-2022-45884}
- media: dvb-core: Fix use-after-free due on race condition at dvb_net (Dean Nelson) [RHEL-1842] {CVE-2022-45886}
- media: dvb_ca_en50221: fix a size write bug (Dean Nelson) [RHEL-1784]
- media: dvbdev: fix refcnt bug (Dean Nelson) [RHEL-1841]
- media: dvbdev: adopts refcnt to avoid UAF (Dean Nelson) [RHEL-1841]
- media: dvbdev: fix error logic at dvb_register_device() (Dean Nelson) [RHEL-1841]
- media: dvb_net: avoid speculation from net slot (Dean Nelson) [RHEL-1842]
- media: dvb_ca_en50221: avoid speculation from CA slot (Dean Nelson) [RHEL-1784]
- media: dvbdev: Fix memleak in dvb_register_device (Dean Nelson) [RHEL-1841]
- media: media/dvb: Use kmemdup rather than duplicating its implementation (Dean Nelson) [RHEL-1841]
- media: dvbdev: remove double-unlock (Dean Nelson) [RHEL-1841]
- media: dvb-core: fix epoll() by calling poll_wait first (Dean Nelson) [RHEL-1784]
- media: dvb_ca_en50221: off by one in dvb_ca_en50221_io_do_ioctl() (Dean Nelson) [RHEL-1784]
- drm/amd/display: fix the white screen issue when >= 64GB DRAM (Mika Penttilä) [2231934]
- gfs2: conversion deadlock do_promote bypass (Bob Peterson) [2225228]
- gfs2: do_promote cleanup (Andreas Gruenbacher) [2225228]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2225228]
- x86/cpu: Enable STIBP on AMD if Automatic IBRS is enabled (Waiman Long) [2227916]
- Documentation/hw-vuln: Document the interaction between IBRS and STIBP (Waiman Long) [2227916]
- x86/CPU/AMD: Make sure EFER[AIBRSE] is set (Waiman Long) [2227916]
- fs: don't audit the capability check in simple_xattr_list() (Andrey Albershteyn) [RHEL-863]

* Tue Sep 19 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-514.el8]
- redhat: fix to be able to build with rpm 4.19.0 (Denys Vlasenko)
- redhat: add additional gating boot tests (Denys Vlasenko)
- redhat: list Z-Jiras in the changelog before Y-Jiras (Herton R. Krzesinski)
- scsi: st: Add third party poweron reset handling (John Meneghini) [1930388]
- kvm: initialize all of the kvm_debugregs structure before sending it to userspace (Jon Maloy) [2179896] {CVE-2023-1513}
- bpf: sockmap: Remove preempt_disable in sock_map_sk_acquire (Tomas Glozar) [2229965]
- s390/ap: add ap status asynch error support (Tobias Huschle) [2110511]
- s390/ap: implement SE AP bind, unbind and associate (Tobias Huschle) [2110511]
- s390/ap: introduce low frequency polling possibility (Tobias Huschle) [2110511]
- s390/ap: new low level inline functions ap_bapq() and ap_aapq() (Tobias Huschle) [2110511]
- s390/ap: provide F bit parameter for ap_rapq() and ap_zapq() (Tobias Huschle) [2110511]
- s390/ap: filter ap card functions, new queue functions attribute (Tobias Huschle) [2110511]
- s390/ap: make tapq gr2 response a struct (Tobias Huschle) [2110511]
- s390/ap: introduce new AP bus sysfs attribute features (Tobias Huschle) [2110511]
- s390/ap: exploit new B bit from QCI config info (Tobias Huschle) [2110511]
- s390/zcrypt: replace scnprintf with sysfs_emit (Tobias Huschle) [2110511]
- s390/zcrypt: rework length information for dqap (Tobias Huschle) [2110511]
- s390/zcrypt: make psmid unsigned long instead of long long (Tobias Huschle) [2110511]
- s390/ap,zcrypt,vfio: introduce and use ap_queue_status_reg union (Tobias Huschle) [2110511]
- s390/ap: fix status returned by ap_qact() (Tobias Huschle) [2110511]
- s390/ap: fix status returned by ap_aqic() (Tobias Huschle) [2110511]
- s390/ap: adjust whitespace (Tobias Huschle) [2110511]
- s390/ap: use insn format for new instructions (Tobias Huschle) [2110511]
- s390/zcrypt: Filter admin CPRBs on custom devices (Tobias Huschle) [2110511]
- s390/zcrypt: Add admask to zcdn (Tobias Huschle) [2110511]
- s390/zcrypt: CCA control CPRB sending (Tobias Huschle) [2110511]
- s390/ap: add missing virt_to_phys address conversion (Tobias Huschle) [2110511]
- s390/ap: get rid of register asm in ap_dqap() (Tobias Huschle) [2110511]
- s390/ap: get rid of register asm (Tobias Huschle) [2110511]
- s390/ap: Rework ap_dqap to deal with messages greater than recv buffer (Tobias Huschle) [2110511]
- s390/ap: rework assembler functions to use unions for in/out register variables (Tobias Huschle) [2110511]
- internal: add new files for RHEL_MINOR=10 change (Denys Vlasenko)
- thunderbolt: Fix Thunderbolt 3 display flickering issue on 2nd hot plug onwards (Desnes Nunes) [2233974]
- mm/userfaultfd: don't consider uffd-wp bit of writable migration entries (Rafael Aquini) [2231554]
- mm/userfaultfd: fix uffd-wp handling for THP migration entries (Rafael Aquini) [2231554]
- mm/userfaultfd: fix uffd-wp special cases for fork() (Rafael Aquini) [2231554]
- mm/thp: simplify copying of huge zero page pmd when fork (Rafael Aquini) [2231554]
- internal: update RHEL_MINOR for the start of RHEL-8.10 development (Denys Vlasenko)

* Wed Sep 06 2023 Patrick Talbert <ptalbert@redhat.com> [4.18.0-513.1.1.el8_9]
- thunderbolt: Fix Thunderbolt 3 display flickering issue on 2nd hot plug onwards (Desnes Nunes) [2233974]
- mm/userfaultfd: don't consider uffd-wp bit of writable migration entries (Rafael Aquini) [2231554]
- mm/userfaultfd: fix uffd-wp handling for THP migration entries (Rafael Aquini) [2231554]
- mm/userfaultfd: fix uffd-wp special cases for fork() (Rafael Aquini) [2231554]
- mm/thp: simplify copying of huge zero page pmd when fork (Rafael Aquini) [2231554]

* Fri Aug 25 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-513.el8]
- redhat/configs: enable CONFIG_INET_DIAG_DESTROY (Andrea Claudi) [2230213]
- net/sched: cls_u32: Fix reference counter leak leading to overflow (Davide Caratti) [2225202] {CVE-2023-3609}
- cifs: fix bogus cifs_mount error handling in RHEL8 (Jeffrey Layton) [2215018]
- KVM: nVMX: add missing consistency checks for CR0 and CR4 (Ricardo Robaina) [2190257] {CVE-2023-30456}
- netfilter: snat: evict closing tcp entries on reply tuple collision (Florian Westphal) [2196717]
- tun: avoid double free in tun_free_netdev (Jon Maloy) [2156366 2156371] {CVE-2022-4744}
- net/sched: cls_fw: Fix improper refcount update leads to use-after-free (Davide Caratti) [2225103] {CVE-2023-3776}
- net/sched: sch_qfq: account for stab overhead in qfq_enqueue (Davide Caratti) [2225196] {CVE-2023-3611}
- net/sched: sch_qfq: reintroduce lmax bound check for MTU (Davide Caratti) [2225196]
- net/sched: sch_qfq: refactor parsing of netlink parameters (Davide Caratti) [2225196]
- net/sched: cls_route: No longer copy tcf_result on update to avoid use-after-free (Davide Caratti) [2225512] {CVE-2023-4128}
- net/sched: cls_fw: No longer copy tcf_result on update to avoid use-after-free (Davide Caratti) [2225512] {CVE-2023-4128}
- net/sched: cls_u32: No longer copy tcf_result on update to avoid use-after-free (Davide Caratti) [2225512] {CVE-2023-4128}
- scsi: lpfc: Remove reftag check in DIF paths (Paul Ely) [2229152]
- scsi: lpfc: Modify when a node should be put in device recovery mode during RSCN (Paul Ely) [2229152]
- scsi: lpfc: Make fabric zone discovery more robust when handling unsolicited LOGO (Paul Ely) [2229152]
- scsi: lpfc: Set Establish Image Pair service parameter only for Target Functions (Paul Ely) [2229152]
- scsi: lpfc: Revise ndlp kref handling for dev_loss_tmo_callbk and lpfc_drop_node (Paul Ely) [2229152]
- scsi: lpfc: Qualify ndlp discovery state when processing RSCN (Paul Ely) [2229152]
- gfs2: Fix freeze consistency check in gfs2_trans_add_meta (Andreas Gruenbacher) [2095340]
- gfs2: gfs2_freeze_lock_shared cleanup (Andreas Gruenbacher) [2095340]
- gfs2: Replace sd_freeze_state with SDF_FROZEN flag (Andreas Gruenbacher) [2095340]
- gfs2: Rework freeze / thaw logic (Andreas Gruenbacher) [2095340]
- gfs2: Rename SDF_{FS_FROZEN => FREEZE_INITIATOR} (Andreas Gruenbacher) [2095340]
- gfs2: Reconfiguring frozen filesystem already rejected (Andreas Gruenbacher) [2095340]
- gfs2: Rename gfs2_freeze_lock{ => _shared } (Andreas Gruenbacher) [2095340]
- gfs2: Rename the {freeze,thaw}_super callbacks (Andreas Gruenbacher) [2095340]
- gfs2: Rename remaining "transaction" glock references (Andreas Gruenbacher) [2095340]
- gfs2: init system threads before freeze lock (Bob Peterson) [2095340]
- net: mana: Use the correct WQE count for ringing RQ doorbell (Bandan Das) [2222573]
- net: mana: Batch ringing RX queue doorbell on receiving packets (Bandan Das) [2222573]
- net: mana: Add support for vlan tagging (Bandan Das) [2222573]
- net: mana: Fix perf regression: remove rx_cqes, tx_cqes counters (Bandan Das) [2222573]
- net: mana: Check if netdev/napi_alloc_frag returns single page (Bandan Das) [2222573]
- net: mana: Rename mana_refill_rxoob and remove some empty lines (Bandan Das) [2222573]
- net: mana: Add support for jumbo frame (Bandan Das) [2222573]
- net: mana: Enable RX path to handle various MTU sizes (Bandan Das) [2222573]
- net: mana: Refactor RX buffer allocation code to prepare for various MTU (Bandan Das) [2222573]
- net: mana: Use napi_build_skb in RX path (Bandan Das) [2222573]
- net: mana: Remove redundant pci_clear_master (Bandan Das) [2222573]
- net: mana: Add new MANA VF performance counters for easier troubleshooting (Bandan Das) [2222573]
- ice: Fix NULL pointer deref during VF reset (Petr Oros) [2227743]
- x86/kasan: Populate shadow for shared chunk of the CPU entry area (Rafael Aquini) [2232451]
- x86/kasan: Add helpers to align shadow addresses up and down (Rafael Aquini) [2232451]
- x86/kasan: Rename local CPU_ENTRY_AREA variables to shorten names (Rafael Aquini) [2232451]
- x86/mm: Populate KASAN shadow for entire per-CPU range of CPU entry area (Rafael Aquini) [2232451]
- x86/mm: Recompute physical address for every page of per-CPU CEA mapping (Rafael Aquini) [2232451]

* Tue Aug 22 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-512.el8]
- dm cache policy smq: ensure IO doesn't prevent cleaner policy progress (Benjamin Marzinski) [2227951]
- netfilter: nf_tables: prevent OOB access in nft_byteorder_eval (Florian Westphal) [2221046] {CVE-2023-35001}
- scsi: storvsc: Remove errant duplicate code (Cathy Avery) [2211725]
- scsi: storvsc: Limit max_sectors for virtual Fibre Channel devices (Cathy Avery) [2211725]
- redhat/configs: Enable CONFIG_AMPERE_ERRATUM_AC03_CPU_38 (Shaoqin Huang) [2219725]
- arm64: errata: Mitigate Ampere1 erratum AC03_CPU_38 at stage-2 (Shaoqin Huang) [2219725]
- KVM: arm64: Correctly handle page aging notifiers for unaligned memslot (Shaoqin Huang) [2219725]
- KVM: arm64: timers: Fix resource leaks in kvm_timer_hyp_init() (Shaoqin Huang) [2219725]
- KVM: arm64: vgic-v4: Make the doorbell request robust w.r.t preemption (Shaoqin Huang) [2219725]
- KVM: arm64: Don't miss pending interrupts for suspended vCPU (Shaoqin Huang) [2219725]
- KVM: arm64: Move vGIC v4 handling for WFI out arch callback hook (Shaoqin Huang) [2219725]
- KVM: arm64: PMU: Don't overwrite PMUSERENR with vcpu loaded (Shaoqin Huang) [2219725]
- KVM: arm64: PMU: Restore the host's PMUSERENR_EL0 (Shaoqin Huang) [2219725]
- KVM: arm64: Restore mdcr_el2 from vcpu (Shaoqin Huang) [2219725]
- kvm: arm64: Remove __hyp_this_cpu_read (Shaoqin Huang) [2219725]
- wifi: rtw88: unlock on error path in rtw_ops_add_interface() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: check only affected links (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: send time sync only if needed (Íñigo Huguet) [2196823]
- wifi: clean up erroneously introduced file (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Handle return value for iwl_mvm_sta_init (Íñigo Huguet) [2196823]
- wifi: rtw88: delete timer and free skb queue when unloading (Íñigo Huguet) [2196823]
- wifi: cfg80211: Fix return value in scan logic (Íñigo Huguet) [2196823]
- Revert "wifi: ath11k: Enable threaded NAPI" (Íñigo Huguet) [2196823]
- wifi: cfg80211: fix receiving mesh packets without RFC1042 header (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921e: fix init command fail with enabled device (Íñigo Huguet) [2196823]
- wifi: ath9k: convert msecs to jiffies where needed (Íñigo Huguet) [2196823]
- wifi: ath11k: Add missing check for ioremap (Íñigo Huguet) [2196823]
- wifi: ath11k: fix memory leak in WMI firmware stats (Íñigo Huguet) [2196823]
- wifi: ath9k: Fix possible stall on ath9k_txq_list_has_key() (Íñigo Huguet) [2196823]
- wifi: ath9k: don't allow to overwrite ENDPOINT0 attributes (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: avoid baid size integer overflow (Íñigo Huguet) [2196823]
- wifi: rtw88: process VO packets without workqueue to avoid PTK rekey failed (Íñigo Huguet) [2196823]
- wifi: rtw88: Fix action frame transmission fail before association (Íñigo Huguet) [2196823]
- wifi: iwlwifi: add a few rate index validity checks (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Validate slots_num before allocating memory (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Validate tid is in valid range before using it (Íñigo Huguet) [2196823]
- wifi: iwlwifi: pcie: fix NULL pointer dereference in iwl_pcie_irq_rx_msix_handler() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: check link during TX (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add a NULL pointer check (Íñigo Huguet) [2196823]
- wifi: iwlwifi: pull from TXQs with softirqs disabled (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Correctly indicate support for VHT TX STBC (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Add NULL check before dereferencing the pointer (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix potential array out of bounds access (Íñigo Huguet) [2196823]
- wifi: rtw88: add missing unwind goto for __rtw_download_firmware() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: disable RX STBC when a device doesn't support it (Íñigo Huguet) [2196823]
- wifi: iwlwifi: don't silently ignore missing suspend or resume ops (Íñigo Huguet) [2196823]
- wifi: ath9k: avoid referencing uninit memory in ath9k_wmi_ctrl_rx (Íñigo Huguet) [2196823]
- wifi: ath9k: fix AR9003 mac hardware hang check register offset calculation (Íñigo Huguet) [2196823]
- wifi: rtw89: pci: fix interrupt enable mask for HALT C2H of RTL8851B (Íñigo Huguet) [2196823]
- wifi: rtw89: fix rtw89_read_chip_ver() for RTL8852B and RTL8851B (Íñigo Huguet) [2196823]
- wifi: rtw88: fix incorrect error codes in rtw_debugfs_set_* (Íñigo Huguet) [2196823]
- wifi: rtw88: fix incorrect error codes in rtw_debugfs_copy_from_user (Íñigo Huguet) [2196823]
- wifi: iwlwifi: pcie: Handle SO-F device for PCI id 0x7AF0 (Íñigo Huguet) [2196823]
- config: wifi: debug configs for brcm80211 (Íñigo Huguet) [2196823]
- config: wifi: set RTL8821CS, RTL8822BS and RTL8822CS as disabled (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: spin_lock_bh() to fix lockdep regression (Íñigo Huguet) [2196823]
- wifi: mac80211: fragment per STA profile correctly (Íñigo Huguet) [2196823]
- wifi: mac80211: Use active_links instead of valid_links in Tx (Íñigo Huguet) [2196823]
- wifi: cfg80211: remove links only on AP (Íñigo Huguet) [2196823]
- wifi: mac80211: take lock before setting vif links (Íñigo Huguet) [2196823]
- wifi: cfg80211: fix link del callback to call correct handler (Íñigo Huguet) [2196823]
- wifi: mac80211: fix link activation settings order (Íñigo Huguet) [2196823]
- wifi: cfg80211: fix double lock bug in reg_wdev_chan_valid() (Íñigo Huguet) [2196823]
- wifi: cfg80211: fix locking in regulatory disconnect (Íñigo Huguet) [2196823]
- wifi: cfg80211: fix locking in sched scan stop work (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Fix -Warray-bounds bug in iwl_mvm_wait_d3_notif() (Íñigo Huguet) [2196823]
- wifi: mac80211: fix switch count in EMA beacons (Íñigo Huguet) [2196823]
- wifi: mac80211: don't translate beacon/presp addrs (Íñigo Huguet) [2196823]
- wifi: mac80211: mlme: fix non-inheritence element (Íñigo Huguet) [2196823]
- wifi: cfg80211: reject bad AP MLD address (Íñigo Huguet) [2196823]
- wifi: mac80211: use correct iftype HE cap (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: fix possible NULL pointer dereference in mt7996_mac_write_txwi() (Íñigo Huguet) [2196823]
- wifi: rtw89: remove redundant check of entering LPS (Íñigo Huguet) [2196823]
- wifi: rtw89: correct PS calculation for SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2196823]
- wifi: rtw88: correct PS calculation for SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2196823]
- wifi: mt76: mt7615: fix possible race in mt7615_mac_sta_poll (Íñigo Huguet) [2196823]
- wifi: b43: fix incorrect __packed annotation (Íñigo Huguet) [2196823]
- wifi: rtw88: sdio: Always use two consecutive bytes for word operations (Íñigo Huguet) [2196823]
- mac80211_hwsim: fix memory leak in hwsim_new_radio_nl (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Add locking to the rate read flow (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Don't use valid_links to iterate sta links (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: don't trust firmware n_channels (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix OEM's name in the tas approved list (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fix OEM's name in the ppag approved list (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix initialization of a return value (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix access to fw_id_to_mac_id (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fw: fix DBGI dump (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix number of concurrent link checks (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix cancel_delayed_work_sync() deadlock (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: don't double-init spinlock (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: always free dup_data (Íñigo Huguet) [2196823]
- wifi: mac80211: recalc chanctx mindef before assigning (Íñigo Huguet) [2196823]
- wifi: mac80211: consider reserved chanctx for mindef (Íñigo Huguet) [2196823]
- wifi: mac80211: simplify chanctx allocation (Íñigo Huguet) [2196823]
- wifi: mac80211: Abort running color change when stopping the AP (Íñigo Huguet) [2196823]
- wifi: mac80211: fix min center freq offset tracing (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rfi: disable RFI feature (Íñigo Huguet) [2196823]
- wifi: mac80211: Fix puncturing bitmap handling in __ieee80211_csa_finalize() (Íñigo Huguet) [2196823]
- wifi: mac80211: fortify the spinlock against deadlock by interrupt (Íñigo Huguet) [2196823]
- wifi: cfg80211: Drop entries with invalid BSSIDs in RNR (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: fix authentication timeout due to incorrect RCR value (Íñigo Huguet) [2196823]
- wifi: brcmfmac: Check for probe() id argument being NULL (Íñigo Huguet) [2196823]
- wifi: rtw88: correct qsel_to_ep[] type as int (Íñigo Huguet) [2196823]
- wifi: rtw88: use work to update rate to avoid RCU warning (Íñigo Huguet) [2196823]
- wifi: rtw89: 8852b: adjust quota to avoid SER L1 caused by access null page (Íñigo Huguet) [2196823]
- wifi: mt76: connac: fix stats->tx_bytes calculation (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: fix endianness of MT_TXD6_TX_RATE (Íñigo Huguet) [2196823]
- wifi: rtw88: Update spelling in main.h (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Simplify setting the initial gain (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Add rtl8xxxu_write{8,16,32}_{set,clear} (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Don't print the vendor/product/serial (Íñigo Huguet) [2196823]
- wifi: rtw88: Fix memory leak in rtw88_usb (Íñigo Huguet) [2196823]
- wifi: rtw88: call rtw8821c_switch_rf_set() according to chip variant (Íñigo Huguet) [2196823]
- wifi: rtw88: set pkg_type correctly for specific rtw8821c variants (Íñigo Huguet) [2196823]
- wifi: rtw88: rtw8821c: Fix rfe_option field width (Íñigo Huguet) [2196823]
- wifi: rtw88: usb: fix priority queue to endpoint mapping (Íñigo Huguet) [2196823]
- wifi: rtw88: 8822c: add iface combination (Íñigo Huguet) [2196823]
- wifi: rtw88: handle station mode concurrent scan with AP mode (Íñigo Huguet) [2196823]
- wifi: rtw88: prevent scan abort with other VIFs (Íñigo Huguet) [2196823]
- wifi: rtw88: refine reserved page flow for AP mode (Íñigo Huguet) [2196823]
- wifi: rtw88: disallow PS during AP mode (Íñigo Huguet) [2196823]
- wifi: rtw88: 8822c: extend reserved page number (Íñigo Huguet) [2196823]
- wifi: rtw88: add port switch for AP mode (Íñigo Huguet) [2196823]
- wifi: rtw88: add bitmap for dynamic port settings (Íñigo Huguet) [2196823]
- wifi: rtw89: mac: use regular int as return type of DLE buffer request (Íñigo Huguet) [2196823]
- wifi: mac80211: remove return value check of debugfs_create_dir() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix RFKILL report when driver is going down (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mei: re-ask for ownership after it was taken by CSME (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mei: make mei filtered scan more aggressive (Íñigo Huguet) [2196823]
- wifi: iwlwifi: modify scan request and results when in link protection (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: enable support for MLO APIs (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: prefer RCU_INIT_POINTER() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix potential memory leak (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fw: fix argument to efi.get_variable (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix MIC removal confusion (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fw: fix memory leak in debugfs (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update support for b0 version (Íñigo Huguet) [2196823]
- wifi: ath11k: Remove disabling of 80+80 and 160 MHz (Íñigo Huguet) [2196823]
- wifi: ath11k: Fix SKB corruption in REO destination ring (Íñigo Huguet) [2196823]
- wifi: ath11k: Fix incorrect update of radiotap fields (Íñigo Huguet) [2196823]
- wifi: ath11k: fix tx status reporting in encap offload mode (Íñigo Huguet) [2196823]
- wifi: ath11k: add peer mac information in failure cases (Íñigo Huguet) [2196823]
- wifi: ath11k: Prevent REO cmd failures (Íñigo Huguet) [2196823]
- wifi: ath11k: fix double free of peer rx_tid during reo cmd failure (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: fill txd by host driver (Íñigo Huguet) [2196823]
- wifi: mt76: set NL80211_EXT_FEATURE_CAN_REPLACE_PTK0 on supported drivers (Íñigo Huguet) [2196823]
- wifi: mt76: dma: use napi_build_skb (Íñigo Huguet) [2196823]
- wifi: mt76: mt7615: increase eeprom size for mt7663 (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: enable mesh HW amsdu/de-amsdu support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: enable configured beacon tx rate (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: enable BSS_CHANGED_MCAST_RATE support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: enable BSS_CHANGED_BASIC_RATES support (Íñigo Huguet) [2196823]
- wifi: iwlwifi: dvm: Fix memcpy: detected field-spanning write backtrace (Íñigo Huguet) [2196823]
- wifi: mac80211: remove ieee80211_tx_status_8023 (Íñigo Huguet) [2196823]
- wifi: iwlwifi: bump FW API to 78 for AX devices (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: check firmware response size (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add MLO support to SF - use sta pointer (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: configure TLC on link activation (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fix iwl_mvm_max_amsdu_size() for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: remove RS rate init update argument (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: initialize per-link STA ratescale data (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rs-fw: properly access sband->iftype_data (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: only clients can be 20MHz-only (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix iwl_mvm_sta_rc_update for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: remove per-STA MFP setting (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: allow NL80211_EXT_FEATURE_SCAN_MIN_PREQ_CONTENT (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use BSSID when building probe requests (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: update mac id management (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adopt the latest firmware API (Íñigo Huguet) [2196823]
- wifi: mt76: connac: add nss calculation into mt76_connac2_mac_tx_rate_val() (Íñigo Huguet) [2196823]
- wifi: mt76: connac: fix txd multicast rate setting (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921e: stop chip reset worker in unregister hook (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921e: improve reliability of dma reset (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: fix missing unwind goto in `mt7921u_probe` (Íñigo Huguet) [2196823]
- mt76: mt7921: fix kernel panic by accessing unallocated eeprom.data (Íñigo Huguet) [2196823]
- wifi: mt76: move mcu_uni_event and mcu_reg_event in common code (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: enable coredump support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: add full system reset knobs into debugfs (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: enable full system reset support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: enable p2p support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: Replace fake flex-arrays with flexible-array members (Íñigo Huguet) [2196823]
- wifi: mt76: Replace zero-length array with flexible-array member (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: add Netgear AXE3000 (A8000) support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7915: drop redundant prefix of mt7915_txpower_puts() (Íñigo Huguet) [2196823]
- wifi: mt76: fix 6GHz high channel not be scanned (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921e: fix probe timeout after reboot (Íñigo Huguet) [2196823]
- wifi: mt76: move shared mac definitions in mt76_connac2_mac.h (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: get rid of eeprom.h (Íñigo Huguet) [2196823]
- wifi: mt76: add mt76_connac_gen_ppe_thresh utility routine (Íñigo Huguet) [2196823]
- wifi: mt76: get rid of unused sta_ps callbacks (Íñigo Huguet) [2196823]
- wifi: mt76: add mt76_connac_irq_enable utility routine (Íñigo Huguet) [2196823]
- wifi: mt76: move irq_tasklet in mt76_dev struct (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921e: Set memory space enable in PCI_COMMAND if unset (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: use driver flags rather than mac80211 flags to mcu (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: introduce mt7921_get_mac80211_ops utility routine (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: fix eeprom tx path bitfields (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: remove mt7996_mcu_set_pm() (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: init mpdu density cap (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: fix pointer calculation in ie countdown event (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: remove unused eeprom band selection (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: let non-bufferable MMPDUs use correct hw queue (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: add eht rx rate support (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: remove mt7996_mcu_beacon_check_caps() (Íñigo Huguet) [2196823]
- wifi: mt76: mt7915: remove mt7915_mcu_beacon_check_caps() (Íñigo Huguet) [2196823]
- wifi: mt76: connac: refresh tx session timer for WED device (Íñigo Huguet) [2196823]
- wifi: mt76: add missing locking to protect against concurrent rx/status calls (Íñigo Huguet) [2196823]
- wifi: mt76: handle failure of vzalloc in mt7615_coredump_work (Íñigo Huguet) [2196823]
- wifi: mt76: drop the incorrect scatter and gather frame (Íñigo Huguet) [2196823]
- wifi: mt76: mt7915: rework init flow in mt7915_thermal_init() (Íñigo Huguet) [2196823]
- wifi: mt76: mt7915: add dev->hif2 support for mt7916 WED device (Íñigo Huguet) [2196823]
- wifi: mt76: mt7915: expose device tree match table (Íñigo Huguet) [2196823]
- wifi: mt76: dynamic channel bandwidth changes in AP mode (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: fix radiotap bitfield (Íñigo Huguet) [2196823]
- wifi: mt76: mt7915: unlock on error in mt7915_thermal_temp_store() (Íñigo Huguet) [2196823]
- wifi: mt76: mt7996: Remove unneeded semicolon (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: fix PCI DMA hang after reboot (Íñigo Huguet) [2196823]
- wifi: mt76: mt7921: fix wrong command to set STA channel (Íñigo Huguet) [2196823]
- wifi: mt76: remove redundent MCU_UNI_CMD_* definitions (Íñigo Huguet) [2196823]
- wifi: ath9k: fix per-packet TX-power cap for TPC (Íñigo Huguet) [2196823]
- wifi: ath11k: fix undefined behavior with __fls in dp (Íñigo Huguet) [2196823]
- wifi: ath11k: Ignore frags from uninitialized peer in dp. (Íñigo Huguet) [2196823]
- wifi: ath11k: print a warning when crypto_alloc_shash() fails (Íñigo Huguet) [2196823]
- wifi: ath11k: pci: Add more MODULE_FIRMWARE() entries (Íñigo Huguet) [2196823]
- wifi: ath11k: enable SAR support on WCN6750 (Íñigo Huguet) [2196823]
- wifi: ath11k: Disable Spectral scan upon removing interface (Íñigo Huguet) [2196823]
- wifi: rtw89: add support of concurrent mode (Íñigo Huguet) [2196823]
- wifi: rtw89: Disallow power save with multiple stations (Íñigo Huguet) [2196823]
- wifi: rtw89: update statistics to FW for fine-tuning performance (Íñigo Huguet) [2196823]
- wifi: rtw89: use struct instead of macros to set H2C command of hardware scan (Íñigo Huguet) [2196823]
- wifi: rtw89: refine scan function after chanctx (Íñigo Huguet) [2196823]
- wifi: rtw89: prohibit enter IPS during HW scan (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: send more hardware module info to firmware for 8851B (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Update function to get BT RSSI and hardware counter (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add path control register to monitor list (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Enable Wi-Fi RX gain control for free run solution (Íñigo Huguet) [2196823]
- wifi: rtw89: fix power save function in WoWLAN mode (Íñigo Huguet) [2196823]
- wifi: rtw89: support WoWLAN mode for 8852be (Íñigo Huguet) [2196823]
- wifi: iwlwifi: move debug buffer allocation failure to info verbosity (Íñigo Huguet) [2196823]
- wifi: iwlwifi: make the loop for card preparation effective (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: allow number of beacons from FW (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: implement key link switching (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: implement BAID link switching (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: track station mask for BAIDs (Íñigo Huguet) [2196823]
- wifi: iwlwifi: bump FW API to 77 for AX devices (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use correct sta mask to remove queue (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: avoid iterating over an un-initialized list (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: factor out iwl_mvm_sta_fw_id_mask() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: properly implement HE AP support (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Fix _iwl_mvm_get_scan_type() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix getting lowest TX rate for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: call napi_synchronize() before freeing rx/tx queues (Íñigo Huguet) [2196823]
- wifi: iwlwifi: nvm-parse: add full BW UL MU-MIMO support (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Support devices with 5-6 out endpoints (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Clean up some messy ifs (Íñigo Huguet) [2196823]
- wifi: brcmfmac: add Cypress 43439 SDIO ids (Íñigo Huguet) [2196823]
- wifi: rtw89: fix crash due to null pointer of sta in AP mode (Íñigo Huguet) [2196823]
- wifi: rtw89: correct 5 MHz mask setting (Íñigo Huguet) [2196823]
- wifi: rtw89: 8851b: add tables for RFK (Íñigo Huguet) [2196823]
- wifi: rtw89: 8851b: add BB and RF tables (2 of 2) (Íñigo Huguet) [2196823]
- wifi: rtw89: 8851b: add BB and RF tables (1 of 2) (Íñigo Huguet) [2196823]
- wifi: rtw89: pci: update PCI related settings to support 8851B (Íñigo Huguet) [2196823]
- wifi: rtw89: mac: update MAC settings to support 8851b (Íñigo Huguet) [2196823]
- wifi: rtw89: 8851b: fix TX path to path A for one RF path chip (Íñigo Huguet) [2196823]
- wifi: rtw89: read version of analog hardware (Íñigo Huguet) [2196823]
- wifi: rtw89: use hardware CFO to improve performance (Íñigo Huguet) [2196823]
- wifi: rtw89: support parameter tables by RFE type (Íñigo Huguet) [2196823]
- wifi: rtw89: fix authentication fail during scan (Íñigo Huguet) [2196823]
- wifi: rtw89: add flag check for power state (Íñigo Huguet) [2196823]
- wifi: rtw89: add ieee80211::remain_on_channel ops (Íñigo Huguet) [2196823]
- wifi: rtw89: add function to wait for completion of TX skbs (Íñigo Huguet) [2196823]
- wifi: rtw89: 8852c: add beacon filter and CQM support (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: tx: remove misleading if statement (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Fix setting the rate for non station cases (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: validate station properly in flush (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: set STA mask for keys in MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix ptk_pn memory leak (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: make iwl_mvm_mac_ctxt_send_beacon() static (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: track AP STA pointer and use it for MFP (Íñigo Huguet) [2196823]
- wifi: iwlwifi: pcie: Fix integer overflow in iwl_write_to_user_buf (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fw: move memset before early return (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: initialize seq variable (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Fix spelling mistake "Gerenal" -> "General" (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Fix spelling mistake "upto" -> "up to" (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: enable new MLD FW API (Íñigo Huguet) [2196823]
- wifi: iwlwifi: add a new PCI device ID for BZ device (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Add RF Step Type for BZ device (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: scan legacy bands and UHB channels with same antenna (Íñigo Huguet) [2196823]
- wifi: iwlwifi: yoyo: Fix possible division by zero (Íñigo Huguet) [2196823]
- wifi: iwlwifi: yoyo: skip dump correctly on hw error (Íñigo Huguet) [2196823]
- wifi: iwlwifi: pcie: fix possible NULL pointer dereference (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Fix the duplicate dump name (Íñigo Huguet) [2196823]
- wifi: iwlwifi: pcie: work around ROM bug on AX210 integrated (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add DSM_FUNC_ENABLE_6E value to debugfs (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: cleanup beacon_inject_active during hw restart (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: support wowlan info notification version 2 (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: make HLTK configuration for PASN station optional (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: request limiting to 8 MSDUs per A-MSDU (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix shift-out-of-bounds (Íñigo Huguet) [2196823]
- wifi: iwlwifi: acpi: support modules with high antenna gain (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: don't drop unencrypted MCAST frames (Íñigo Huguet) [2196823]
- wifi: iwlwifi: dbg: print pc register data once fw dump occurred (Íñigo Huguet) [2196823]
- wifi: mac80211: add flush_sta method (Íñigo Huguet) [2196823]
- wifi: mac80211: flush queues on STA removal (Íñigo Huguet) [2196823]
- wifi: ieee80211: correctly mark FTM frames non-bufferable (Íñigo Huguet) [2196823]
- wifi: ieee80211: clean up public action codes (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: don't set CHECKSUM_COMPLETE for unsupported protocols (Íñigo Huguet) [2196823]
- wifi: iwlwifi: trans: don't trigger d3 interrupt twice (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update configurations for Bnj-a0 and specific rf devices (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update init sequence if tx diversity supported (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: move function sequence (Íñigo Huguet) [2196823]
- wifi: iwlwifi: nvm: Update HE capabilities on 6GHz band for EHT device (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor TX csum mode check (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix A-MSDU checks (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: enable bz hw checksum from c step (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use OFDM rate if IEEE80211_TX_CTL_NO_CCK_RATE is set (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: convert TID to FW value on queue remove (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update configuration for SO,SOF MAC and HR RF (Íñigo Huguet) [2196823]
- wifi: iwlwifi: add a validity check of queue_id in iwl_txq_reclaim (Íñigo Huguet) [2196823]
- wifi: iwlwifi: nvm-parse: enable 160/320 MHz for AP mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: debug: fix crash in __iwl_err() (Íñigo Huguet) [2196823]
- wifi: rtw88: Add support for the SDIO based RTL8821CS chipset (Íñigo Huguet) [2196823]
- wifi: rtw88: Add support for the SDIO based RTL8822CS chipset (Íñigo Huguet) [2196823]
- wifi: rtw88: Add support for the SDIO based RTL8822BS chipset (Íñigo Huguet) [2196823]
- wifi: rtw88: main: Reserve 8 bytes of extra TX headroom for SDIO cards (Íñigo Huguet) [2196823]
- wifi: rtw88: main: Add the {cpwm,rpwm}_addr for SDIO based chipsets (Íñigo Huguet) [2196823]
- wifi: rtw88: mac: Support SDIO specific bits in the power on sequence (Íñigo Huguet) [2196823]
- wifi: rtw88: sdio: Add HCI implementation for SDIO based chipsets (Íñigo Huguet) [2196823]
- wifi: rtw88: Clear RTW_FLAG_POWERON early in rtw_mac_power_switch() (Íñigo Huguet) [2196823]
- wifi: ath12k: Remove redundant pci_clear_master (Íñigo Huguet) [2196823]
- wifi: ath10k: Remove redundant pci_clear_master (Íñigo Huguet) [2196823]
- wifi: ath11k: Remove redundant pci_clear_master (Íñigo Huguet) [2196823]
- wifi: ath11k: Send 11d scan start before WMI_START_SCAN_CMDID (Íñigo Huguet) [2196823]
- wifi: ath11k: fix writing to unintended memory region (Íñigo Huguet) [2196823]
- wifi: ath11k: Fix invalid management rx frame length issue (Íñigo Huguet) [2196823]
- wifi: ath11k: fix rssi station dump not updated in QCN9074 (Íñigo Huguet) [2196823]
- wifi: ath11k: Configure the FTM responder role using firmware capability flag (Íñigo Huguet) [2196823]
- wifi: ath11k: Optimize 6 GHz scan time (Íñigo Huguet) [2196823]
- wifi: mac80211: set EHT support flag in AP mode (Íñigo Huguet) [2196823]
- wifi: mac80211_hwsim: fix potential NULL deref in hwsim_pmsr_report_nl() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fix duplicate entry in iwl_dev_info_table (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix the order of TIMING_MEASUREMENT notifications (Íñigo Huguet) [2196823]
- bus: mhi: host: Use mhi_tryset_pm_state() for setting fw error state (Íñigo Huguet) [2196823]
- bus: mhi: host: Remove duplicate ee check for syserr (Íñigo Huguet) [2196823]
- bus: mhi: host: Avoid ringing EV DB if there are no elements to process (Íñigo Huguet) [2196823]
- net: rfkill-gpio: Add explicit include for of.h (Íñigo Huguet) [2196823]
- net: qrtr: correct types of trace event parameters (Íñigo Huguet) [2196823]
- wifi: rt2x00: Fix memory leak when handling surveys (Íñigo Huguet) [2196823]
- wifi: b43legacy: Remove the unused function prev_slot() (Íñigo Huguet) [2196823]
- wifi: rtw89: Remove redundant pci_clear_master (Íñigo Huguet) [2196823]
- wifi: rtw89: fix potential race condition between napi_init and napi_enable (Íñigo Huguet) [2196823]
- wifi: rtw89: config EDCCA threshold during scan to prevent TX failed (Íñigo Huguet) [2196823]
- wifi: rtw89: fix incorrect channel info during scan due to ppdu_sts filtering (Íñigo Huguet) [2196823]
- wifi: rtw89: remove superfluous H2C of join_info (Íñigo Huguet) [2196823]
- wifi: rtw89: set data lowest rate according to AP supported rate (Íñigo Huguet) [2196823]
- wifi: rtw89: add counters of register-based H2C/C2H (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Update Wi-Fi Bluetooth coexistence version to 7.0.1 (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add report control v5 variation (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Update RTL8852B LNA2 hardware parameter (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Not to enable firmware report when WiFi is power saving (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add LPS protocol radio state for RTL8852B (Íñigo Huguet) [2196823]
- bus: mhi: pci_generic: Add Foxconn T99W510 (Íñigo Huguet) [2196823]
- bus: mhi: host: Use ERANGE for BHIOFF/BHIEOFF range check (Íñigo Huguet) [2196823]
- bus: mhi: host: Range check CHDBOFF and ERDBOFF (Íñigo Huguet) [2196823]
- wifi: mwifiex: remove unused evt_buf variable (Íñigo Huguet) [2196823]
- wifi: brcmsmac: ampdu: remove unused suc_mpdu variable (Íñigo Huguet) [2196823]
- wifi: rtlwifi: fix incorrect error codes in rtl_debugfs_set_write_reg() (Íñigo Huguet) [2196823]
- wifi: rtlwifi: fix incorrect error codes in rtl_debugfs_set_write_rfreg() (Íñigo Huguet) [2196823]
- wifi: brcmsmac: remove unused has_5g variable (Íñigo Huguet) [2196823]
- wifi: b43legacy: remove unused freq_r3A_value function (Íñigo Huguet) [2196823]
- wifi: rtlwifi: Replace fake flex-array with flex-array member (Íñigo Huguet) [2196823]
- wifi: rtw88: Remove redundant pci_clear_master (Íñigo Huguet) [2196823]
- wifi: rndis_wlan: Replace fake flex-array with flexible-array member (Íñigo Huguet) [2196823]
- wifi: rndis_wlan: clean up a type issue (Íñigo Huguet) [2196823]
- wifi: rtw88: remove unused rtw_pci_get_tx_desc function (Íñigo Huguet) [2196823]
- wifi: rsi: Slightly simplify rsi_set_channel() (Íñigo Huguet) [2196823]
- wifi: ipw2x00: remove unused _ipw_read16 function (Íñigo Huguet) [2196823]
- wifi: mac80211: enable EHT mesh support (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: correctly use link in iwl_mvm_sta_del() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: separate AP link management queues (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: free probe_resp_data later (Íñigo Huguet) [2196823]
- wifi: iwlwifi: bump FW API to 75 for AX devices (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: move max_agg_bufsize into host TLC lq_sta (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: send full STA during HW restart (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rework active links counting (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: update mac config when assigning chanctx (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use the correct link queue (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: clean up mac_id vs. link_id in MLD sta (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix station link data leak (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: initialize max_rc_amsdu_len per-link (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use appropriate link for rate selection (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use the new lockdep-checking macros (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: remove chanctx WARN_ON (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: avoid sending MAC context for idle (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: remove only link-specific AP keys (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: skip inactive links (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust iwl_mvm_scan_respect_p2p_go_iter() for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rxmq: report link ID to mac80211 (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use bcast/mcast link station id (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: translate management frame address (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: implement mac80211 callback change_sta_links (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use the link sta address (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust rs init to MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust radar detection to MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust iwl_mvm_sec_key_remove_ap to MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: make a few warnings only trigger once (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: coex: start handling multiple links (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rs-fw: don't crash on missing channel (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: use STA link address (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: skip MEI update for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix narrow RU check for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: make some HW flags conditional (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: implement link change ops (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust some cleanup functions to MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor iwl_mvm_mac_sta_state_common() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: update iwl_mvm_tx_reclaim() for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust to MLO assign/unassign/switch_vif_chanctx() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add fw link id allocation (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust internal stations to MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: replace bss_info_changed() with vif_cfg/link_info_changed() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add link_conf parameter for add/remove/change link (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: don't check dtim_period in new API (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust SMPS for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add set_hw_timestamp to mld ops (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add link to firmware earlier (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust some PS and PM methods to MLD (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust mld_mac_ctxt_/beacon_changed() for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: adjust smart fifo configuration to MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: align to the LINK cmd update in the FW (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: always use the sta->addr as the peers addr (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: modify link instead of removing it during csa (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix crash on queue removal for MLD API too (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix "modify_mask" value in the link cmd. (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add all missing ops to iwl_mvm_mld_ops (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add support for post_channel_switch in MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: unite sta_modify_disable_tx flows (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add cancel/remain_on_channel for MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor iwl_mvm_roc() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add some new MLD ops (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add sta handling flows for MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add an indication that the new MLD API is used (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: sta preparation for MLO (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: vif preparation for MLO (Íñigo Huguet) [2196823]
- wifi: nl80211: support advertising S1G capabilities (Íñigo Huguet) [2196823]
- wifi: mac80211: S1G capabilities information element in probe request (Íñigo Huguet) [2196823]
- mac80211: minstrel_ht: remove unused n_supported variable (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Use 64-bit division helper in iwl_mvm_get_crosstimestamp_fw() (Íñigo Huguet) [2196823]
- wifi: carl9170: Replace fake flex-array with flexible-array member (Íñigo Huguet) [2196823]
- wifi: carl9170: Fix multiple -Warray-bounds warnings (Íñigo Huguet) [2196823]
- wifi: ath10k: remove unused ath10k_get_ring_byte function (Íñigo Huguet) [2196823]
- wifi: ath12k: incorrect channel survey dump (Íñigo Huguet) [2196823]
- wifi: ath12k: fix incorrect handling of AMSDU frames (Íñigo Huguet) [2196823]
- wifi: ath12k: fix packets are sent in native wifi mode while we set raw mode (Íñigo Huguet) [2196823]
- wifi: ath12k: fill peer meta data during reo_reinject (Íñigo Huguet) [2196823]
- mac80211_hwsim: add PMSR report support via virtio (Íñigo Huguet) [2196823]
- mac80211_hwsim: add PMSR abort support via virtio (Íñigo Huguet) [2196823]
- mac80211_hwsim: add PMSR request support via virtio (Íñigo Huguet) [2196823]
- wifi: nl80211: make nl80211_send_chandef non-static (Íñigo Huguet) [2196823]
- mac80211_hwsim: add PMSR capability support (Íñigo Huguet) [2196823]
- mac80211: support RNR for EMA AP (Íñigo Huguet) [2196823]
- cfg80211: support RNR for EMA AP (Íñigo Huguet) [2196823]
- wifi: mac80211: use bullet list for amsdu_mesh_control formats list (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix NULL deref in iwl_mvm_mld_disable_txq (Íñigo Huguet) [2196823]
- wifi: mac80211_hwsim: EMA support (Íñigo Huguet) [2196823]
- wifi: mac80211_hwsim: Multiple BSSID support (Íñigo Huguet) [2196823]
- wifi: mac80211_hwsim: move beacon transmission to a separate function (Íñigo Huguet) [2196823]
- wifi: mac80211: generate EMA beacons in AP mode (Íñigo Huguet) [2196823]
- wifi: nl80211: Update the documentation of NL80211_SCAN_FLAG_COLOCATED_6GHZ (Íñigo Huguet) [2196823]
- wifi: mac80211: implement support for yet another mesh A-MSDU format (Íñigo Huguet) [2196823]
- wifi: mac80211: add mesh fast-rx support (Íñigo Huguet) [2196823]
- wifi: mac80211: use mesh header cache to speed up mesh forwarding (Íñigo Huguet) [2196823]
- wifi: mac80211: mesh fast xmit support (Íñigo Huguet) [2196823]
- wifi: mac80211: fix race in mesh sequence number assignment (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Add debugfs to get TAS status (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: support enabling and disabling HW timestamping (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update configurations for Bnj device (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor iwl_mvm_add_sta(), iwl_mvm_rm_sta() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: remove not needed initializations (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor iwl_mvm_sta_send_to_fw() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor iwl_mvm_sta (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor iwl_mvm_cfg_he_sta() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Don't send MAC CTXT cmd after deauthorization (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add stop_ap() and leave_ibss() callbacks for MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add start_ap() and join_ibss() callbacks for MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: select ptp cross timestamp from multiple reads (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: implement PHC clock adjustments (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: enable TX beacon protection (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add support for timing measurement (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: report hardware timestamps in RX/TX status (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: read synced time from firmware if supported (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add support for PTP HW clock (PHC) (Íñigo Huguet) [2196823]
- wifi: ath12k: Enable IMPS for WCN7850 (Íñigo Huguet) [2196823]
- wifi: ath12k: Identify DFS channel when sending scan channel list command (Íñigo Huguet) [2196823]
- wifi: ath12k: fix firmware assert during channel switch for peer sta (Íñigo Huguet) [2196823]
- wifi: ath12k: fix memory leak in ath12k_qmi_driver_event_work() (Íñigo Huguet) [2196823]
- wifi: ath11k: fix BUFFER_DONE read on monitor ring rx buffer (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Support new chip RTL8710BU aka RTL8188GU (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: RTL8192EU always needs full init (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Avoid disabling GCC specific flag with clang (Íñigo Huguet) [2196823]
- wifi: iwlwifi: suppress printf warnings in tracing (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fw: pnvm: fix uefi reduced TX power loading (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update configurations for Bnj and Bz devices (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rs: print BAD_RATE for invalid HT/VHT index (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Replace space with tabs as code indent (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Add required space before open '(' (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Remove prohibited spaces (Íñigo Huguet) [2196823]
- wifi: iwlwifi: fix typos in comment (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: remove setting of 'sta' parameter (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add an unassign_vif_chanctx() callback for MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor __iwl_mvm_unassign_vif_chanctx() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add an assign_vif_chanctx() callback for MLD mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: refactor __iwl_mvm_assign_vif_chanctx() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Add a remove_interface() callback for mld mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Add an add_interface() callback for mld mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add support for the new STA related commands (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add support for the new LINK command (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add support for the new MAC CTXT command (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Refactor MAC_CONTEXT_CMD sending flow (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: Refactor STA_HE_CTXT_CMD sending flow (Íñigo Huguet) [2196823]
- wifi: iwlwifi: yoyo: Add driver defined dump file name (Íñigo Huguet) [2196823]
- wifi: iwlwifi: yoyo: Add new tlv for dump file name extension (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: avoid sta lookup in queue alloc (Íñigo Huguet) [2196823]
- wifi: ath11k: fix deinitialization of firmware resources (Íñigo Huguet) [2196823]
- wifi: ath11k: Replace fake flex-array with flexible-array member (Íñigo Huguet) [2196823]
- wifi: ath12k: Add missing unwind goto in ath12k_pci_probe() (Íñigo Huguet) [2196823]
- net: Use of_property_present() for testing DT property presence (Íñigo Huguet) [2196823]
- wifi: brcmfmac: slab-out-of-bounds read in brcmf_get_assoc_ies() (Íñigo Huguet) [2196823] {CVE-2023-1380}
- wifi: rtw88: fix memory leak in rtw_usb_probe() (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add v5 firmware cycle status report (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add v2 Bluetooth scan info (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Fix wrong structure assignment at null data report (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add register monitor report v2 format (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add traffic TX/RX info and its H2C (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add WiFi role info v2 (Íñigo Huguet) [2196823]
- wifi: rtw89: coex: Add more error_map and counter to log (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: use module_usb_driver (Íñigo Huguet) [2196823]
- wifi: rtw89: release RX standby timer of beamformee CSI to save power (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: mark Edimax EW-7811Un V2 as tested (Íñigo Huguet) [2196823]
- wifi: brcmfmac: Use ISO3166 country code and rev 0 as fallback on 4356 (Íñigo Huguet) [2196823]
- wifi: move raycs, wl3501 and rndis_wlan to legacy directory (Íñigo Huguet) [2196823]
- wifi: move mac80211_hwsim and virt_wifi to virtual directory (Íñigo Huguet) [2196823]
- wifi: ath11k: add debug prints in regulatory WMI event processing (Íñigo Huguet) [2196823]
- wifi: ath11k: add support to parse new WMI event for 6 GHz (Íñigo Huguet) [2196823]
- wifi: ath11k: use proper regulatory reference for bands (Íñigo Huguet) [2196823]
- bus: mhi: host: pci_generic: Revert "Add a secondary AT port to Telit FN990" (Íñigo Huguet) [2196823]
- bus: mhi: host: pci_generic: Drop redundant pci_enable_pcie_error_reporting() (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: fix EOF bit reporting (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Do not include radiotap EHT user info if not needed (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add EHT RU allocation to radiotap (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Update logs for yoyo reset sw changes (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: clean up duplicated defines (Íñigo Huguet) [2196823]
- wifi: iwlwifi: rs-fw: break out for unsupported bandwidth (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Add support for B step of BnJ-Fm4 (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: make flush code a bit clearer (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: avoid UB shift of snif_queue (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add primary 80 known for EHT radiotap (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: parse FW frame metadata for EHT sniffer mode (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: decode USIG_B1_B7 RU to nl80211 RU width (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: rename define to generic name (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: allow Microsoft to use TAS (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add all EHT based on data0 info from HW (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add EHT radiotap info based on rate_n_flags (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add an helper function radiotap TLVs (Íñigo Huguet) [2196823]
- wifi: radiotap: separate vendor TLV into header/content (Íñigo Huguet) [2196823]
- bus: mhi: ep: Demote unsupported channel error log to debug (Íñigo Huguet) [2196823]
- bus: mhi: host: Remove mhi_poll() API (Íñigo Huguet) [2196823]
- wifi: iwlwifi: reduce verbosity of some logging events (Íñigo Huguet) [2196823]
- wifi: iwlwifi: Adding the code to get RF name for MsP device (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: mark mac header with no data frames (Íñigo Huguet) [2196823]
- wifi: iwlwifi: mvm: add LSIG info to radio tap info in EHT (Íñigo Huguet) [2196823]
- wifi: nl80211: Add support for randomizing TA of auth and deauth frames (Íñigo Huguet) [2196823]
- wifi: mac80211: add LDPC related flags in ieee80211_bss_conf (Íñigo Huguet) [2196823]
- wifi: mac80211: add EHT MU-MIMO related flags in ieee80211_bss_conf (Íñigo Huguet) [2196823]
- wifi: mac80211: introduce ieee80211_refresh_tx_agg_session_timer() (Íñigo Huguet) [2196823]
- wifi: mac80211: add support for driver adding radiotap TLVs (Íñigo Huguet) [2196823]
- wifi: radiotap: Add EHT radiotap definitions (Íñigo Huguet) [2196823]
- wifi: mac80211: fix ieee80211_link_set_associated() type (Íñigo Huguet) [2196823]
- wifi: mac80211: simplify reasoning about EHT capa handling (Íñigo Huguet) [2196823]
- wifi: mac80211: mlme: remove pointless sta check (Íñigo Huguet) [2196823]
- wifi: mac80211_hwsim: Indicate support for NL80211_EXT_FEATURE_SCAN_MIN_PREQ_CONTENT (Íñigo Huguet) [2196823]
- wifi: mac80211: add netdev per-link debugfs data and driver hook (Íñigo Huguet) [2196823]
- wifi: mac80211: remove SMPS from AP debugfs (Íñigo Huguet) [2196823]
- wifi: mac80211: add pointer from bss_conf to vif (Íñigo Huguet) [2196823]
- wifi: mac80211: warn only once on AP probe (Íñigo Huguet) [2196823]
- wifi: cfg80211/mac80211: report link ID on control port RX (Íñigo Huguet) [2196823]
- wifi: mac80211: add support for set_hw_timestamp command (Íñigo Huguet) [2196823]
- wifi: nl80211: add a command to enable/disable HW timestamping (Íñigo Huguet) [2196823]
- wifi: wireless: cleanup unused function parameters (Íñigo Huguet) [2196823]
- wifi: wireless: correct primary channel validation on 6 GHz (Íñigo Huguet) [2196823]
- wifi: wireless: return primary channel regardless of DUP (Íñigo Huguet) [2196823]
- wifi: mac80211: allow beacon protection HW offload (Íñigo Huguet) [2196823]
- wifi: mac80211: check key taint for beacon protection (Íñigo Huguet) [2196823]
- wifi: mac80211: clear all bits that relate rtap fields on skb (Íñigo Huguet) [2196823]
- wifi: mac80211: adjust scan cancel comment/check (Íñigo Huguet) [2196823]
- wifi: nl80211: Update the documentation of NL80211_SCAN_FLAG_COLOCATED_6GHZ (Íñigo Huguet) [2196823]
- gpiolib: split linux/gpio/driver.h out of linux/gpio.h (Íñigo Huguet) [2196823]
- wifi: rtlwifi: rtl8192se: Remove some unused variables (Íñigo Huguet) [2196823]
- wifi: rtw88: mac: Return the original error from rtw_mac_power_switch() (Íñigo Huguet) [2196823]
- wifi: rtw88: mac: Return the original error from rtw_pwr_seq_parser() (Íñigo Huguet) [2196823]
- wifi: brcmfmac: pcie: Add 4359C0 firmware definition (Íñigo Huguet) [2196823]
- wifi: rtw89: fix SER L1 might stop entering LPS issue (Íñigo Huguet) [2196823]
- wifi: ath11k: Add tx ack signal support for management packets (Íñigo Huguet) [2196823]
- wifi: brcmfmac: pcie: Add BCM4378B3 support (Íñigo Huguet) [2196823]
- wifi: brcmfmac: common: Add support for external calibration blobs (Íñigo Huguet) [2196823]
- wifi: brcmfmac: pcie: Load and provide TxCap blobs (Íñigo Huguet) [2196823]
- wifi: brcmfmac: common: Add support for downloading TxCap blobs (Íñigo Huguet) [2196823]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4387 (Íñigo Huguet) [2196823]
- wifi: brcmfmac: cfg80211: Pass the PMK in binary instead of hex (Íñigo Huguet) [2196823]
- wifi: brcmfmac: cfg80211: Add support for PMKID_V3 operations (Íñigo Huguet) [2196823]
- wifi: brcmfmac: feature: Add support for setting feats based on WLC version (Íñigo Huguet) [2196823]
- wifi: brcmfmac: cfg80211: Add support for scan params v2 (Íñigo Huguet) [2196823]
- wifi: brcmfmac: chip: Handle 1024-unit sizes for TCM blocks (Íñigo Huguet) [2196823]
- wifi: brcmfmac: chip: Only disable D11 cores; handle an arbitrary number (Íñigo Huguet) [2196823]
- wifi: ath11k: generate rx and tx mcs maps for supported HE mcs (Íñigo Huguet) [2196823]
- wifi: ath11k: move HE MCS mapper to a separate function (Íñigo Huguet) [2196823]
- wifi: ath11k: push MU-MIMO params from hostapd to hardware (Íñigo Huguet) [2196823]
- wifi: ath11k: modify accessor macros to match index size (Íñigo Huguet) [2196823]
- wifi: ath6kl: reduce WARN to dev_dbg() in callback (Íñigo Huguet) [2196823]
- wifi: brcmfmac: support CQM RSSI notification with older firmware (Íñigo Huguet) [2196823]
- wifi: brcmfmac: pcie: Provide a buffer of random bytes to the device (Íñigo Huguet) [2196823]
- wifi: brcmfmac: acpi: Add support for fetching Apple ACPI properties (Íñigo Huguet) [2196823]
- wifi: ath12k: remove memset with byte count of 278528 (Íñigo Huguet) [2196823]
- wifi: wcn36xx: Slightly optimize PREPARE_HAL_BUF() (Íñigo Huguet) [2196823]
- wifi: rtw89: refine FW feature judgement on packet drop (Íñigo Huguet) [2196823]
- wifi: rtw89: 8852b: enable hw_scan support (Íñigo Huguet) [2196823]
- wifi: rtw89: 8852b: add channel encoding for hw_scan (Íñigo Huguet) [2196823]
- wifi: rtw89: adjust channel encoding to common function (Íñigo Huguet) [2196823]
- wifi: rtw89: fw: configure CRASH_TRIGGER feature for 8852B (Íñigo Huguet) [2196823]
- wifi: rtw89: add tx_wake notify for 8852B (Íñigo Huguet) [2196823]
- wifi: rtw88: rtw8822c: Implement RTL8822CS (SDIO) efuse parsing (Íñigo Huguet) [2196823]
- wifi: rtw88: rtw8822b: Implement RTL8822BS (SDIO) efuse parsing (Íñigo Huguet) [2196823]
- wifi: rtw88: rtw8821c: Implement RTL8821CS (SDIO) efuse parsing (Íñigo Huguet) [2196823]
- wifi: rtw88: mac: Add SDIO HCI support in the TX/page table setup (Íñigo Huguet) [2196823]
- wifi: rtw88: mac: Add support for the SDIO HCI in rtw_pwr_seq_parser() (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: Remove always true condition in rtl8xxxu_print_chipinfo (Íñigo Huguet) [2196823]
- wifi: rtw89: add RNR support for 6 GHz scan (Íñigo Huguet) [2196823]
- wifi: rtlwifi: rtl8192de: Remove the unused variable bcnfunc_enable (Íñigo Huguet) [2196823]
- wifi: rtl8xxxu: 8188e: parse single one element of RA report for station mode (Íñigo Huguet) [2196823]
- wifi: rtlwifi: rtl8192ce: fix dealing empty EEPROM values (Íñigo Huguet) [2196823]
- wifi: ath11k: fix SAC bug on peer addition with sta band migration (Íñigo Huguet) [2196823]
- wifi: ath10k: Remove redundant assignment to changed_flags (Íñigo Huguet) [2196823]
- wifi: ath10k: snoc: enable threaded napi on WCN3990 (Íñigo Huguet) [2196823]
- wifi: ath5k: fix an off by one check in ath5k_eeprom_read_freq_list() (Íñigo Huguet) [2196823]
- wifi: ath5k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2196823]
- wifi: ath11k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2196823]
- wifi: ath12k: PCI ops for wakeup/release MHI (Íñigo Huguet) [2196823]
- wifi: ath12k: Handle lock during peer_id find (Íñigo Huguet) [2196823]
- wifi: ath9k: hif_usb: fix memory leak of remain_skbs (Íñigo Huguet) [2196823]
- wifi: ath11k: fix return value check in ath11k_ahb_probe() (Íñigo Huguet) [2196823]
- wifi: ath12k: use kfree_skb() instead of kfree() (Íñigo Huguet) [2196823]
- wifi: ath: Silence memcpy run-time false positive warning (Íñigo Huguet) [2196823]
- wifi: ath10k: Remove the unused function shadow_dst_wr_ind_addr() and ath10k_ce_error_intr_enable() (Íñigo Huguet) [2196823]
- wifi: ath12k: dp_mon: clean up some inconsistent indentings (Íñigo Huguet) [2196823]
- wifi: ath12k: dp_mon: Fix unsigned comparison with less than zero (Íñigo Huguet) [2196823]
- wifi: ath12k: Fix spelling mistakes in warning messages and comments (Íñigo Huguet) [2196823]
- wifi: ath6kl: minor fix for allocation size (Íñigo Huguet) [2196823]
- wifi: ath11k: Set ext passive scan flag to adjust passive scan start time (Íñigo Huguet) [2196823]

* Fri Aug 18 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-511.el8]
- xfrm: add NULL check in xfrm_update_ae_params (Daniel Mendes) [2218948] {CVE-2023-3772}
- scsi: storvsc: Fix handling of virtual Fibre Channel timeouts (Cathy Avery) [1986067]
- netfilter: xt_owner: Add supplementary groups option (Phil Sutter) [2136194]
- netfilter: nf_tables: can't schedule in nft_chain_validate (Florian Westphal) [2230460]
- drm/nouveau/nvkm/dp: Add workaround to fix DP 1.3+ DPCD issues (Karol Herbst) [2229989]
- net: deprecate PF_KEY (Sabrina Dubroca) [RHEL-1257]
- KVM: SEV: remove ghcb variable declarations (Vitaly Kuznetsov) [2213807]
- KVM: SEV: only access GHCB fields once (Vitaly Kuznetsov) [2213807] {CVE-2023-4155}
- KVM: SEV: snapshot the GHCB before accessing it (Vitaly Kuznetsov) [2213807] {CVE-2023-4155}
- Documentation/x86: Fix backwards on/off logic about YMM support (Waiman Long) [2229884] {CVE-2022-40982}
- KVM: Add GDS_NO support to KVM (Waiman Long) [2229884] {CVE-2022-40982}
- x86/speculation: Add Kconfig option for GDS (Waiman Long) [2229884] {CVE-2022-40982}
- x86/speculation: Add force option to GDS mitigation (Waiman Long) [2229884] {CVE-2022-40982}
- x86/speculation: Add Gather Data Sampling mitigation (Waiman Long) [2229884] {CVE-2022-40982}
- x86/bugs: Use sysfs_emit() (Waiman Long) [2229884]
- Documentation/ABI: Mention retbleed vulnerability info file for sysfs (Waiman Long) [2229884]
- docs/kernel-parameters: Update descriptions for "mitigations=" param with retbleed (Waiman Long) [2229884]
- arm64: correct the effect of mitigations off on kpti (Waiman Long) [2229884]
- x86/speculation: Add missing srbds=off to the mitigations= help text (Waiman Long) [2229884]
- usb: typec: ucsi: Mark dGPUs as DEVICE scope (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Remove ccgx,firmware-build property (Desnes Nunes) [2222463]
- usb: typec: ucsi_ccg: Add OF support (Desnes Nunes) [2222463]
- usb: typec: ucsi/ucsi_ccg: Convert to i2c's .probe_new() (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Add ACPI property to align with device-tree (Desnes Nunes) [2222463]
- dt-bindings: usb: Add Cypress cypd4226 Type-C controller (Desnes Nunes) [2222463]
- i2c: designware-pci: Switch to use i2c_new_ccgx_ucsi() (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Convert to use dev_err_probe() (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Use temporary variable for struct device (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Switch to use i2c_new_ccgx_ucsi() (Desnes Nunes) [2222463]
- i2c: Remove support for dangling device properties (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Constify the software node (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: Use PTR_ERR_OR_ZERO() to simplify code (Desnes Nunes) [2222463]
- i2c: nvidia-gpu: convert to use i2c_new_client_device() (Desnes Nunes) [2222463]
- i2c: Add support for software nodes (Desnes Nunes) [2222463]
- i2c: Introduce common module to instantiate CCGx UCSI (Desnes Nunes) [2222463]
- power: supply: Fix logic checking if system is running from battery (Desnes Nunes) [2222463]
- redhat: support virtio-mem on x86-64 as tech-preview (David Hildenbrand) [2229123]
- virtio/virtio_mem: handle a possible NULL as a memcpy parameter (David Hildenbrand) [2229123]
- virtio-mem: support VIRTIO_MEM_F_UNPLUGGED_INACCESSIBLE (David Hildenbrand) [2229123]
- virtio-mem: disallow mapping virtio-mem memory via /dev/mem (David Hildenbrand) [2229123]
- kernel/resource: disallow access to exclusive system RAM regions (David Hildenbrand) [2229123]
- kernel/resource: clean up and optimize iomem_is_exclusive() (David Hildenbrand) [2229123]
- virtio-mem: kdump mode to sanitize /proc/vmcore access (David Hildenbrand) [2229123]
- virtio-mem: factor out hotplug specifics from virtio_mem_remove() into virtio_mem_deinit_hotplug() (David Hildenbrand) [2229123]
- virtio-mem: factor out hotplug specifics from virtio_mem_probe() into virtio_mem_init_hotplug() (David Hildenbrand) [2229123]
- virtio-mem: factor out hotplug specifics from virtio_mem_init() into virtio_mem_init_hotplug() (David Hildenbrand) [2229123]
- proc/vmcore: fix possible deadlock on concurrent mmap and read (David Hildenbrand) [2229123]
- proc/vmcore: don't fake reading zeroes on surprise vmcore_cb unregistration (David Hildenbrand) [2229123]
- proc/vmcore: fix clearing user buffer by properly using clear_user() (David Hildenbrand) [2229123]
- proc/vmcore: convert oldmem_pfn_is_ram callback to more generic vmcore callbacks (David Hildenbrand) [2229123]
- proc/vmcore: let pfn_is_ram() return a bool (David Hildenbrand) [2229123]
- x86/xen: print a warning when HVMOP_get_mem_type fails (David Hildenbrand) [2229123]
- x86/xen: simplify xen_oldmem_pfn_is_ram() (David Hildenbrand) [2229123]
- x86/xen: update xen_oldmem_pfn_is_ram() documentation (David Hildenbrand) [2229123]
- virtio-mem: fix sleeping in RCU read side section in virtio_mem_online_page_cb() (David Hildenbrand) [2229123]
- virtio-mem: prioritize unplug from ZONE_MOVABLE in Big Block Mode (David Hildenbrand) [2229123]
- virtio-mem: simplify high-level unplug handling in Big Block Mode (David Hildenbrand) [2229123]
- virtio-mem: prioritize unplug from ZONE_MOVABLE in Sub Block Mode (David Hildenbrand) [2229123]
- virtio-mem: simplify high-level unplug handling in Sub Block Mode (David Hildenbrand) [2229123]
- virtio-mem: simplify high-level plug handling in Sub Block Mode (David Hildenbrand) [2229123]
- virtio-mem: use page_zonenum() in virtio_mem_fake_offline() (David Hildenbrand) [2229123]
- virtio-mem: don't read big block size in Sub Block Mode (David Hildenbrand) [2229123]
- fs/proc/kcore: use page_offline_(freeze|thaw) (David Hildenbrand) [2229123]
- virtio-mem: use page_offline_(start|end) when setting PageOffline() (David Hildenbrand) [2229123]
- mm: introduce page_offline_(begin|end|freeze|thaw) to synchronize setting PageOffline() (David Hildenbrand) [2229123]
- fs/proc/kcore: don't read offline sections, logically offline pages and hwpoisoned pages (David Hildenbrand) [2229123]
- fs/proc/kcore: pfn_is_ram check only applies to KCORE_RAM (David Hildenbrand) [2229123]
- fs/proc/kcore: drop KCORE_REMAP and KCORE_OTHER (David Hildenbrand) [2229123]
- proc/kcore: Remove unused kclist_add_remap() (David Hildenbrand) [2229123]
- x86/gart: Exclude GART aperture from kcore (David Hildenbrand) [2229123]
- kernel/resource: remove first_lvl / siblings_only logic (David Hildenbrand) [2229123]
- kernel/resource: make walk_mem_res() find all busy IORESOURCE_MEM resources (David Hildenbrand) [2229123]
- kernel/resource: make walk_system_ram_res() find all busy IORESOURCE_SYSTEM_RAM resources (David Hildenbrand) [2229123]
- kernel/resource.c: fix kernel-doc markups (David Hildenbrand) [2229123]
- resource: avoid unnecessary lookups in find_next_iomem_res() (David Hildenbrand) [2229123]
- resource: fix locking in find_next_iomem_res() (David Hildenbrand) [2229123]
- virtio-mem: check against mhp_get_pluggable_range() which memory we can hotplug (David Hildenbrand) [2229123]
- virtio-mem: Assign boolean values to a bool variable (David Hildenbrand) [2229123]
- mm/memory_hotplug: MEMHP_MERGE_RESOURCE -> MHP_MERGE_RESOURCE (David Hildenbrand) [2229123]
- virtio-mem: Big Block Mode (BBM) - safe memory hotunplug (David Hildenbrand) [2229123]
- virtio-mem: Big Block Mode (BBM) - basic memory hotunplug (David Hildenbrand) [2229123]
- mm/memory_hotplug: extend offline_and_remove_memory() to handle more than one memory block (David Hildenbrand) [2229123]
- virtio-mem: allow to force Big Block Mode (BBM) and set the big block size (David Hildenbrand) [2229123]
- virtio-mem: Big Block Mode (BBM) memory hotplug (David Hildenbrand) [2229123]
- virtio-mem: factor out adding/removing memory from Linux (David Hildenbrand) [2229123]
- virtio-mem: memory notifier callbacks are specific to Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virito-mem: existing (un)plug functions are specific to Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virtio-mem: memory block ids are specific to Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virtio-mem: nb_sb_per_mb and subblock_size are specific to Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virito-mem: subblock states are specific to Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virtio-mem: memory block states are specific to Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virito-mem: document Sub Block Mode (SBM) (David Hildenbrand) [2229123]
- virtio-mem: generalize handling when memory is getting onlined deferred (David Hildenbrand) [2229123]
- virtio-mem: don't always trigger the workqueue when offlining memory (David Hildenbrand) [2229123]
- virtio-mem: drop last_mb_id (David Hildenbrand) [2229123]
- virtio-mem: generalize virtio_mem_overlaps_range() (David Hildenbrand) [2229123]
- virtio-mem: generalize virtio_mem_owned_mb() (David Hildenbrand) [2229123]
- virtio-mem: generalize check for added memory (David Hildenbrand) [2229123]
- virtio-mem: retry fake-offlining via alloc_contig_range() on ZONE_MOVABLE (David Hildenbrand) [2229123]
- virtio-mem: factor out handling of fake-offline pages in memory notifier (David Hildenbrand) [2229123]
- virtio-mem: factor out fake-offlining into virtio_mem_fake_offline() (David Hildenbrand) [2229123]
- virtio-mem: print debug messages from virtio_mem_send_*_request() (David Hildenbrand) [2229123]
- virtio-mem: factor out calculation of the bit number within the subblock bitmap (David Hildenbrand) [2229123]
- virtio-mem: use "unsigned long" for nr_pages when fake onlining/offlining (David Hildenbrand) [2229123]
- virtio-mem: drop rc2 in virtio_mem_mb_plug_and_add() (David Hildenbrand) [2229123]
- virtio-mem: simplify MAX_ORDER - 1 / pageblock_order handling (David Hildenbrand) [2229123]
- virtio-mem: more precise calculation in virtio_mem_mb_state_prepare_next_mb() (David Hildenbrand) [2229123]
- virtio-mem: determine nid only once using memory_add_physaddr_to_nid() (David Hildenbrand) [2229123]
- MAINTAINERS: add URL for virtio-mem (David Hildenbrand) [2229123]
- virtio-mem: Constify mem_id_table (David Hildenbrand) [2229123]
- kernel/resource: make iomem_resource implicit in release_mem_region_adjustable() (David Hildenbrand) [2229123]
- virtio-mem: try to merge system ram resources (David Hildenbrand) [2229123]
- mm/memory_hotplug: MEMHP_MERGE_RESOURCE to specify merging of System RAM resources (David Hildenbrand) [2229123]
- mm/memory_hotplug: prepare passing flags to add_memory() and friends (David Hildenbrand) [2229123]
- mm/memory_hotplug: guard more declarations by CONFIG_MEMORY_HOTPLUG (David Hildenbrand) [2229123]
- include/linux/memory_hotplug.h: move definitions of {set,clear}_zone_contiguous (David Hildenbrand) [2229123]
- kernel/resource: make release_mem_region_adjustable() never fail (David Hildenbrand) [2229123]
- virtio-mem: don't special-case ZONE_MOVABLE (David Hildenbrand) [2229123]
- virtio_mem: convert to LE accessors (David Hildenbrand) [2229123]
- virtio_mem: correct tags for config space fields (David Hildenbrand) [2229123]
- virtio-mem: Fix build error due to improper use 'select' (David Hildenbrand) [2229123]
- virtio-mem: add memory via add_memory_driver_managed() (David Hildenbrand) [2229123]
- virtio-mem: silence a static checker warning (David Hildenbrand) [2229123]
- virtio_mem: convert device block size into 64bit (David Hildenbrand) [2229123]
- virtio-mem: drop unnecessary initialization (David Hildenbrand) [2229123]
- virtio-mem: Don't rely on implicit compiler padding for requests (David Hildenbrand) [2229123]
- virtio-mem: Try to unplug the complete online memory block first (David Hildenbrand) [2229123]
- virtio-mem: Use -ETXTBSY as error code if the device is busy (David Hildenbrand) [2229123]
- virtio-mem: Unplug subblocks right-to-left (David Hildenbrand) [2229123]
- virtio-mem: Drop manual check for already present memory (David Hildenbrand) [2229123]
- virtio-mem: Add parent resource for all added "System RAM" (David Hildenbrand) [2229123]
- virtio-mem: Better retry handling (David Hildenbrand) [2229123]
- virtio-mem: Offline and remove completely unplugged memory blocks (David Hildenbrand) [2229123]
- mm/memory_hotplug: Introduce offline_and_remove_memory() (David Hildenbrand) [2229123]
- virtio-mem: Allow to offline partially unplugged memory blocks (David Hildenbrand) [2229123]
- virtio-mem: Paravirtualized memory hotunplug part 2 (David Hildenbrand) [2229123]
- virtio-mem: Paravirtualized memory hotunplug part 1 (David Hildenbrand) [2229123]
- virtio-mem: Allow to specify an ACPI PXM as nid (David Hildenbrand) [2229123]
- MAINTAINERS: Add myself as virtio-mem maintainer (David Hildenbrand) [2229123]
- virtio-mem: Paravirtualized memory hotplug (David Hildenbrand) [2229123]
- Revert "drm/amd/display: edp do not add non-edid timings" (Jocelyn Falempe) [RHEL-845]
- Revert "drm/amd/display: reallocate DET for dual displays with high pixel rate ratio" (Jocelyn Falempe) [RHEL-845]
- drm/client: Fix memory leak in drm_client_modeset_probe (Jocelyn Falempe) [RHEL-845]
- drm/client: Fix memory leak in drm_client_target_cloned (Jocelyn Falempe) [RHEL-845]
- drm/atomic: Fix potential use-after-free in nonblocking commits (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: conditionally disable pcie lane/speed switching for SMU13 (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: share the code around SMU13 pcie parameters update (Jocelyn Falempe) [RHEL-845]
- drm/ttm: Don't leak a resource on swapout move error (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: avoid restore process run into dead loop. (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Correct `DMUB_FW_VERSION` macro (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Fix 128b132b link loss handling (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: add a NULL pointer check (Jocelyn Falempe) [RHEL-845]
- drm/amd: Disable PSR-SU on Parade 0803 TCON (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: fix clearing mappings for BOs that are always valid in VM (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: disable seamless boot if force_odm_combine is enabled (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Remove Phantom Pipe Check When Calculating K1 and K2 (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: fix seamless odm transitions (Jocelyn Falempe) [RHEL-845]
- drm/dp_mst: Clear MSG_RDY flag before sending new message (Jocelyn Falempe) [RHEL-845]
- drm/atomic: Allow vblank-enabled + self-refresh "disable" (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: perform a bounds check before filling dirty rectangles (Jocelyn Falempe) [RHEL-845]
- drm/nouveau: bring back blit subchannel for pre nv50 GPUs (Jocelyn Falempe) [RHEL-845]
- drm/nouveau/disp/g94: enable HDMI (Jocelyn Falempe) [RHEL-845]
- drm/nouveau/disp: fix HDMI on gt215+ (Jocelyn Falempe) [RHEL-845]
- drm/i915: Fix one wrong caching mode enum usage (Jocelyn Falempe) [RHEL-845]
- drm/i915: Don't preserve dpll_hw_state for slave crtc in Bigjoiner (Jocelyn Falempe) [RHEL-845]
- drm/panel: simple: Add Powertip PH800480T013 drm_display_mode flags (Jocelyn Falempe) [RHEL-845]
- drm/bridge: ti-sn65dsi86: Fix auxiliary bus lifetime (Jocelyn Falempe) [RHEL-845]
- drm/panel: simple: Add connector_type for innolux_at043tn24 (Jocelyn Falempe) [RHEL-845]
- drm/nouveau/acr: Abort loading ACR if no firmware was found (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: add RAS POISON interrupt funcs for jpeg_v4_0 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: add RAS POISON interrupt funcs for jpeg_v2_6 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: separate ras irq from jpeg instance irq for UVD_POISON (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Move jpeg ras block init to ras sw_init (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: add RAS POISON interrupt funcs for vcn_v4_0 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: add RAS POISON interrupt funcs for vcn_v2_6 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: separate ras irq from vcn instance irq for UVD_POISON (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Move vcn ras block init to ras sw_init (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Fix usage of UMC fill record in RAS (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Fix memcpy() in sienna_cichlid_append_powerplay_table function. (Jocelyn Falempe) [RHEL-845]
- amdgpu: validate offset_in_bo of drm_amdgpu_gem_va (Jocelyn Falempe) [RHEL-845]
- drm/radeon: fix possible division-by-zero errors (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Fix artifacting on eDP panels when engaging freesync video mode (Jocelyn Falempe) [RHEL-845]
- drm/amdkfd: Fix potential deallocation of previously deallocated memory. (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Fix a test dml32_rq_dlg_get_rq_reg() (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Fix a test CalculatePrefetchSchedule() (Jocelyn Falempe) [RHEL-845]
- drm/panel: simple: fix active size for Ampire AM-480272H3TMQW-T01H (Jocelyn Falempe) [RHEL-845]
- drm/bridge: ti-sn65dsi83: Fix enable/disable flow to meet spec (Jocelyn Falempe) [RHEL-845]
- drm/bridge: anx7625: Prevent endless probe loop (Jocelyn Falempe) [RHEL-845]
- drm/nouveau: dispnv50: fix missing-prototypes warning (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358767: Switch to devm MIPI-DSI helpers (Jocelyn Falempe) [RHEL-845]
- drm/vkms: Fix RGB565 pixel conversion (Jocelyn Falempe) [RHEL-845]
- drm: Add fixed-point helper to get rounded integer values (Jocelyn Falempe) [RHEL-845]
- drm/vkms: isolate pixel conversion functionality (Jocelyn Falempe) [RHEL-845]
- drm/panel: sharp-ls043t1le01: adjust mode settings (Jocelyn Falempe) [RHEL-845]
- drm/vram-helper: fix function names in vram helper doc (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix THS_TRAILCNT computation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix TXTAGOCNT computation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix THS_ZEROCNT computation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix TCLK_TRAILCNT computation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: Add atomic_get_input_bus_fmts() implementation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix TCLK_ZEROCNT computation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix PLL target frequency (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: fix PLL parameters computation (Jocelyn Falempe) [RHEL-845]
- drm/bridge: tc358768: always enable HS video mode (Jocelyn Falempe) [RHEL-845]
- drm/bridge: ti-sn65dsi83: Fix enable error path (Jocelyn Falempe) [RHEL-845]
- drm/bridge: it6505: Move a variable assignment behind a null pointer check in receive_timing_debugfs_show() (Jocelyn Falempe) [RHEL-845]
- drm/i915/guc/slpc: Provide sysfs for efficient freq (Jocelyn Falempe) [RHEL-845]
- drm/i915/guc: More debug print updates - GuC SLPC (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Explicitly specify update type per plane info change (Jocelyn Falempe) [RHEL-845]
- radeon: avoid double free in ci_dpm_init() (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: fix is_timing_changed() prototype (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Add logging for display MALL refresh setting (Jocelyn Falempe) [RHEL-845]
- drm: use mgr->dev in drm_dbg_kms in drm_dp_add_payload_part2 (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Ensure vmin and vmax adjust for DCE (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Validate VM ioctl flags. (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Do not update DRR while BW optimizations pending (Jocelyn Falempe) [RHEL-845]
- drm/radeon: fix race condition UAF in radeon_gem_set_domain_ioctl (Jocelyn Falempe) [RHEL-845]
- udmabuf: revert 'Add support for mapping hugepages (v4)' (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: fix the system hang while disable PSR (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Add wrapper to call planes and stream update (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Use dc_update_planes_and_stream (Jocelyn Falempe) [RHEL-845]
- drm/nouveau: add nv_encoder pointer check for NULL (Jocelyn Falempe) [RHEL-845]
- drm/nouveau/dp: check for NULL nv_connector->native_mode (Jocelyn Falempe) [RHEL-845]
- drm/bridge: ti-sn65dsi86: Avoid possible buffer overflow (Jocelyn Falempe) [RHEL-845]
- drm/nouveau: don't detect DSM for non-NVIDIA device (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Modify indirect buffer packages for resubmission (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Implement gfx9 patch functions for resubmission (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Program gds backup address as zero if no gds allocated (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Reset CP_VMID_PREEMPT after trailing fence signaled (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: add missing radeon secondary PCI ID (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: workaround for compute workload type on some skus (Jocelyn Falempe) [RHEL-845]
- drm/amd: Tighten permissions on VBIOS flashing attributes (Jocelyn Falempe) [RHEL-845]
- drm/amd: Make sure image is written to trigger VBIOS image update flow (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: edp do not add non-edid timings (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: limit DPIA link rate to HBR3 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: vcn_4_0 set instance 0 init sched score to 1 (Jocelyn Falempe) [RHEL-845]
- Revert "drm/amdgpu: remove TOPDOWN flags when allocating VRAM in large bar system" (Jocelyn Falempe) [RHEL-845]
- drm:amd:amdgpu: Fix missing buffer object unlock in failure path (Jocelyn Falempe) [RHEL-845]
- drm: panel-orientation-quirks: Change Air's quirk to support Air Plus (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: add ODM case when looking for first split pipe (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Reduce sdp bw after urgent to 90%% (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: Fix power context allocation in SMU13 (Jocelyn Falempe) [RHEL-845]
- drm/amd: Disallow s0ix without BIOS support again (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: change reserved vram info print (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: fix xclk freq on CHIP_STONEY (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: conditionally disable pcie lane switching for some sienna_cichlid SKUs (Jocelyn Falempe) [RHEL-845]
- drm/i915/gt: Use the correct error value when kernel_context() fails (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: fix Null pointer dereference error in amdgpu_device_recover_vram (Jocelyn Falempe) [RHEL-845]
- drm/i915/selftests: Add some missing error propagation (Jocelyn Falempe) [RHEL-845]
- drm/i915: Use 18 fast wake AUX sync len (Jocelyn Falempe) [RHEL-845]
- drm/i915: Explain the magic numbers for AUX SYNC/precharge length (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: reverse mclk and fclk clocks levels for renoir (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: reverse mclk and fclk clocks levels for yellow carp (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: reverse mclk clocks levels for SMU v13.0.5 (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: resolve reboot exception for si oland (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: reverse mclk and fclk clocks levels for vangogh (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: reverse mclk and fclk clocks levels for SMU v13.0.4 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: enable tmz by default for GC 11.0.1 (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Only wait for blank completion if OTG active (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: skip disabling fence driver src_irqs when device is unplugged (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: set gfx9 onwards APU atomics support to be true (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu/nv: update VCN 3 max HEVC encoding resolution (Jocelyn Falempe) [RHEL-845]
- drm/ast: Fix ARM compatibility (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Use the default reset when loading or reloading the driver (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: fix memleak in aconnector->timing_requested (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: release gpu full access after "amdgpu_device_ip_late_init" (Jocelyn Falempe) [RHEL-845]
- drm/i915: Fix PIPEDMC disabling for a bigjoiner configuration (Jocelyn Falempe) [RHEL-845]
- drm/i915: Disable DPLLs before disconnecting the TC PHY (Jocelyn Falempe) [RHEL-845]
- drm/i915: Move shared DPLL disabling into CRTC disable hook (Jocelyn Falempe) [RHEL-845]
- drm: fix drmm_mutex_init() (Jocelyn Falempe) [RHEL-845]
- drm/amd/amdgpu: limit one queue per gang (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: Fix output of pp_od_clk_voltage (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: add missing NotifyPowerSource message mapping for SMU13.0.7 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: don't enable secure display on incompatible platforms (Jocelyn Falempe) [RHEL-845]
- drm/radeon: reintroduce radeon_dp_work_func content (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Have Payload Properly Created After Resume (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: reserve the old gc_11_0_*_mes.bin (Jocelyn Falempe) [RHEL-845]
- drm/amd/amdgpu: introduce gc_*_mes_2.bin v2 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu/gfx11: update gpu_clock_counter logic (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: refine get gpu clock counter method (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu/gfx11: Adjust gfxoff before powergating on gfx11 as well (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu/gfx10: Disable gfxoff before disabling powergating. (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu/gmc11: implement get_vbios_fb_size() (Jocelyn Falempe) [RHEL-845]
- drm/amd/pm: fix possible power mode mismatch between driver and PMFW (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Enable IH retry CAM on GFX9 (Jocelyn Falempe) [RHEL-845]
- drm/amdgpu: Fix sdma v4 sw fini error (Jocelyn Falempe) [RHEL-845]
- drm/amd: Fix an out of bounds error in BIOS parser (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Correct DML calculation to follow HW SPEC (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: fixed dcn30+ underflow issue (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: reallocate DET for dual displays with high pixel rate ratio (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Use DC_LOG_DC in the trasform pixel function (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Enable HostVM based on rIOMMU active (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: enable DPG when disabling plane for phantom pipe (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: Correct DML calculation to align HW formula (Jocelyn Falempe) [RHEL-845]
- drm/amd/display: populate subvp cmd info only for the top pipe (Jocelyn Falempe) [RHEL-845]
- drm/displayid: add displayid_get_header() and check bounds better (Jocelyn Falempe) [RHEL-845]
- drm/i915: taint kernel when force probing unsupported devices (Jocelyn Falempe) [RHEL-845]
- drm/i915/dp: prevent potential div-by-zero (Jocelyn Falempe) [RHEL-845]
- drm/i915: Fix NULL ptr deref by checking new_crtc_state (Jocelyn Falempe) [RHEL-845]
- drm/i915/guc: Don't capture Gen8 regs on Xe devices (Jocelyn Falempe) [RHEL-845]
- drm/sched: Check scheduler work queue before calling timeout handling (Jocelyn Falempe) [RHEL-845]
- drm/mipi-dsi: Set the fwnode for mipi_dsi_device (Jocelyn Falempe) [RHEL-845]
- drm/nouveau/disp: More DP_RECEIVER_CAP_SIZE array fixes (Jocelyn Falempe) [RHEL-845]
- drm/dsc: fix DP_DSC_MAX_BPP_DELTA_* macro values (Jocelyn Falempe) [RHEL-845]
- drm/fbdev-generic: prohibit potential out-of-bounds access (Jocelyn Falempe) [RHEL-845]

* Tue Aug 15 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-510.el8]
- x86/show_trace_log_lvl: Ensure stack pointer is aligned, again (Oleg Nesterov) [2188093]
- ahci: Add support for Dell S140 and later controllers (Tomas Henzl) [2222879]
- s390/time: steer clocksource on STP syncs for CLOCK_MONOTONIC (Tobias Huschle) [2177649]
- memstick: r592: Fix UAF bug in r592_remove due to race condition (Wander Lairson Costa) [2215906] {CVE-2023-35825}
- scsi: zfcp: Defer fc_rport blocking until after ADISC response (Tobias Huschle) [2230241]
- RDMA/efa: Add EFA 0xefa2 PCI ID (Izabela Bakollari) [2170086]
- RDMA/efa: Support CQ receive entries with source GID (Izabela Bakollari) [2170086]
- Revert "isystem: ship and use stdarg.h" (Jocelyn Falempe) [2229185]
- drm/drm_print: Use system include for <stdargs.h> (Jocelyn Falempe) [2229185]
- x86/mm: Do not shuffle CPU entry areas without KASLR (Rafael Aquini) [2165931] {CVE-2023-0597}
- x86/mm: Randomize per-cpu entry area (Rafael Aquini) [2165931] {CVE-2023-0597}
- x86/kasan: Map shadow for percpu pages on demand (Rafael Aquini) [2165931] {CVE-2023-0597}
- x86/pti/32: Calculate the various PTI cpu_entry_area sizes correctly, make the CPU_ENTRY_AREA_PAGES assert precise (Rafael Aquini) [2165931] {CVE-2023-0597}

* Wed Aug 09 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-509.el8]
- cifs: fix for following DFS links where sharename is the same as prepath (Ronnie Sahlberg) [2130474]
- crypto: rng - Fix lock imbalance in crypto_del_rng (Herbert Xu) [2229700]
- ibmvnic: Do not reset dql stats on NON_FATAL err (Mamatha Inamdar) [2227904]
- mptcp: Correct the sock::sk_lock.owned lockdep annotations (Felix Maurer) [2228890]
- gpio: name PCA953x gpio chips after device name (Steve Best) [2226775]
- scsi: storvsc: Handle SRB status value 0x30 (Cathy Avery) [2218133]
- netfilter: nft_set_pipapo: fix improper element removal (Phil Sutter) [2225276] {CVE-2023-4004}
- macvlan: add forgotten nla_policy for IFLA_MACVLAN_BC_CUTOFF (Xin Long) [2226791]
- tcp: Reduce chance of collisions in inet6_hashfn(). (Felix Maurer) [2176119] {CVE-2023-1206}
- ipv6: fix locking issues with loops over idev->addr_list (Jiri Benc) [2123305]
- relayfs: fix out-of-bounds access in relay_file_read (Bill O'Donnell) [2215510] {CVE-2023-3268}
- kernel/relay.c: fix read_pos error when multiple readers (Bill O'Donnell) [2215510]
- seq_buf: Make trace_seq_putmem_hex() support data longer than 8 (Ricardo Robaina) [2212208] {CVE-2023-28772}
- seq_buf: Fix overflow in seq_buf_putmem_hex() (Ricardo Robaina) [2212208] {CVE-2023-28772}
- tools/power/x86/intel-speed-select: Support more than 8 sockets. (Frank Ramsay) [2212508]
- platform/x86: ISST: Remove 8 socket limit (Frank Ramsay) [2212508]
- media: saa7134: fix use after free bug in saa7134_finidev due to race condition (Wander Lairson Costa) [2215902] {CVE-2023-35823}
- Bluetooth: btmtksdio: fix possible FW initialization failure (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: fix the reset takes too long (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: mask out interrupt status (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Add support for Foxconn QCA 0xe0d0 (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Add two more Bluetooth parts for WCN6855 (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Add protocol for MediaTek bluetooth devices(MT7922) (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Add support for Foxconn MT7922A (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: Fix kernel oops when sdio suspend. (David Marlin) [2142489 2144730 2145097]
- Enable MTK BT Support for RHEL (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Add a new PID/VID 13d3/3567 for MT7921 (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mt7921s: support bluetooth reset mechanism (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mt7921s: fix btmtksdio_[drv|fw]_pmctrl() (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: refactor btmtksdio_runtime_[suspend|resume]() (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mt7921s: fix bus hang with wrong privilege (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mt7921s: fix firmware coredump retrieve (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mt7921s: Enable SCO over I2S (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mt7921s: Support wake on bluetooth (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: rename btsdio_mtk_reg_read (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: enable AOSP extension for MT7921 (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: enable msft opcode (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: fix resume failure (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: handle runtime pm only when sdio_func is available (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: drop the unnecessary variable created (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: add support of processing firmware coredump and log (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: add MT7921s Bluetooth support (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: transmit packet according to status TX_EMPTY (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: use register CRPLR to read packet length (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: update register CSDIOCSR operation (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: move interrupt service to work (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: explicitly set WHISR as write-1-clear (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksdio: add .set_bdaddr support (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btmtksido: rely on BT_MTK module (David Marlin) [2142489 2144730 2145097]
- Bluetooth: mediatek: add BT_MTK module (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Support public address configuration for MediaTek Chip. (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Support Bluetooth Reset for Mediatek Chip(MT7921) (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: Add support for Foxconn Mediatek Chip (David Marlin) [2142489 2144730 2145097]
- Bluetooth: btusb: fix blacklist_table context (David Marlin) [2142489 2144730 2145097]

* Fri Aug 04 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-508.el8]
- HID: betop: check shape of output reports (Desnes Nunes) [2212164] {CVE-2023-1073}
- media: ttusb-dec: fix memory leak in ttusb_dec_exit_dvb() (Desnes Nunes) [2153575] {CVE-2022-45887}
- selinux: make labeled NFS work when mounted before policy load (Juraj Marcin) [1753646]
- Revert "xfs: expose the blockgc workqueue knobs publicly" (Bill O'Donnell) [2223260]
- media: dm1105: Fix use after free bug in dm1105_remove due to race condition (Dean Nelson) [2215904] {CVE-2023-35824}
- media: dvb-core: Fix kernel WARNING for blocking operation in wait_event*() (Dean Nelson) [2213142] {CVE-2023-31084}
- drm/ast: report connection status on Display Port. (Jocelyn Falempe) [2189645]
- drm/ast: Add BMC virtual connector (Jocelyn Falempe) [2189645]
- x86/cpu/amd: Add a Zenbleed fix (Waiman Long) [2226832] {CVE-2023-20593}
- x86/cpu/amd: Move the errata checking functionality up (Waiman Long) [2226832] {CVE-2023-20593}
- x86/amd: Cache debug register values in percpu variables (Waiman Long) [2226832] {CVE-2023-20593}
- x86/cpu: Restore AMD's DE_CFG MSR after resume (Waiman Long) [2226832] {CVE-2023-20593}
- x86/sev: Change snp_guest_issue_request()'s fw_err argument (John Allen) [2216284]
- virt/coco/sev-guest: Double-buffer messages (John Allen) [2216284]
- virt/coco/sev-guest: Add throttling awareness (John Allen) [2216284]
- virt/coco/sev-guest: Convert the sw_exit_info_2 checking to a switch-case (John Allen) [2216284]
- virt/coco/sev-guest: Do some code style cleanups (John Allen) [2216284]
- virt/coco/sev-guest: Carve out the request issuing logic into a helper (John Allen) [2216284]
- virt/coco/sev-guest: Remove the disable_vmpck label in handle_guest_request() (John Allen) [2216284]
- virt/coco/sev-guest: Simplify extended guest request handling (John Allen) [2216284]
- virt/coco/sev-guest: Check SEV_SNP attribute at probe time (John Allen) [2216284]
- virt/sev-guest: Return -EIO if certificate buffer is not large enough (John Allen) [2216284]
- x86/sev: Mark snp_abort() noreturn (John Allen) [2216284]
- s390/uv: Update query for secret-UVCs (Cédric Le Goater) [2111749]
- s390/uv: replace scnprintf with sysfs_emit (Cédric Le Goater) [2111749]
- s390: Add attestation query information (Cédric Le Goater) [2111749]
- s390/uvdevice: Add 'Lock Secret Store' UVC (Cédric Le Goater) [2111749]
- s390/uvdevice: Add 'List Secrets' UVC (Cédric Le Goater) [2111749]
- s390/uvdevice: Add 'Add Secret' UVC (Cédric Le Goater) [2111749]
- s390/uvdevice: Add info IOCTL (Cédric Le Goater) [2111749]
- s390/uv: Always export uv_info (Cédric Le Goater) [2111749]
- s390/kasan: support protvirt with 4-level paging (Cédric Le Goater) [2111749]
- s390/protvirt: support ultravisor without secure storage limit (Cédric Le Goater) [2111749]
- s390/protvirt: parse prot_virt option in the decompressor (Cédric Le Goater) [2111749]
- s390/mm: avoid trimming to MAX_ORDER (Cédric Le Goater) [2111749]
- net/mlx5e: TC, CT: Offload ct clear only once (Amir Tzin) [2159233]
- net/mlx5: DR, Fix wrong action data allocation in decap action (Amir Tzin) [2159233]
- net/mlx5: DR, Support SW created encap actions for FW table (Amir Tzin) [2159233]
- net/mlx5e: TC, Cleanup ct resources for nic flow (Amir Tzin) [2159233]
- net/mlx5e: TC, Add null pointer check for hardware miss support (Amir Tzin) [2159233]
- RDMA/mlx5: Fix affinity assignment (Amir Tzin) [2159233]
- RDMA/mlx5: Create an indirect flow table for steering anchor (Amir Tzin) [2159233]
- RDMA/mlx5: Initiate dropless RQ for RAW Ethernet functions (Amir Tzin) [2159233]
- net/mlx5: DR, Add missing mutex init/destroy in pattern manager (Amir Tzin) [2117777]
- net/mlx5: Read embedded cpu after init bit cleared (Amir Tzin) [2159233]
- net/mlx5e: Fix error handling in mlx5e_refresh_tirs (Amir Tzin) [2159233]
- net/mlx5e: Don't attach netdev profile while handling internal error (Amir Tzin) [2159233]
- net/mlx5: Fix post parse infra to only parse every action once (Amir Tzin) [2159233]
- net/mlx5: fw_tracer, Fix event handling (Amir Tzin) [2159233]
- net/mlx5: SF, Drain health before removing device (Amir Tzin) [2159233]
- net/mlx5e: Consider internal buffers size in port buffer calculations (Amir Tzin) [2159233]
- net/mlx5e: Prevent encap offload when neigh update is running (Amir Tzin) [2159233]
- net/mlx5e: Extract remaining tunnel encap code to dedicated file (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove sample and ct limitation (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove mirror and ct limitation (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove tuple rewrite and ct limitation (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove multiple ct actions limitation (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove special handling of CT action (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove CT action reordering (Amir Tzin) [2159233]
- net/mlx5e: CT: Use per action stats (Amir Tzin) [2159233]
- net/mlx5e: TC, Move main flow attribute cleanup to helper func (Amir Tzin) [2159233]
- net/mlx5e: TC, Remove unused vf_tun variable (Amir Tzin) [2159233]
- net/mlx5e: Set default can_offload action (Amir Tzin) [2159233]
- net/mlx5: Devcom, serialize devcom registration (Amir Tzin) [2159233]
- net/mlx5: Devcom, fix error flow in mlx5_devcom_register_device (Amir Tzin) [2159233]
- net/mlx5e: Fix SQ wake logic in ptp napi_poll context (Amir Tzin) [2159233]
- net/mlx5e: Fix deadlock in tc route query code (Amir Tzin) [2159233]
- net/mlx5: Fix error message when failing to allocate device memory (Amir Tzin) [2159233]
- net/mlx5e: Use correct encap attribute during invalidation (Amir Tzin) [2159233]
- net/mlx5: DR, Check force-loopback RC QP capability independently from RoCE (Amir Tzin) [2159233]
- net/mlx5: DR, Fix crc32 calculation to work on big-endian (BE) CPUs (Amir Tzin) [2159233]
- net/mlx5: Handle pairing of E-switch via uplink un/load APIs (Amir Tzin) [2159233]
- net/mlx5: Collect command failures data only for known commands (Amir Tzin) [2159233]
- net/mlx5e: do as little as possible in napi poll when budget is 0 (Amir Tzin) [2159233]
- net/mlx5: Use recovery timeout on sync reset flow (Amir Tzin) [2159233]
- net/mlx5: DR, Add memory statistics for domain object (Amir Tzin) [2117777]
- net/mlx5: DR, Add more info in domain dbg dump (Amir Tzin) [2117777]
- net/mlx5: DR, Calculate sync threshold of each pool according to its type (Amir Tzin) [2117777]
- net/mlx5: DR, Fix dumping of legacy modify_hdr in debug dump (Amir Tzin) [2117777]
- net/mlx5: DR, Enable patterns and arguments for supporting devices (Amir Tzin) [2117777]
- net/mlx5: DR, Add support for the pattern/arg parameters in debug dump (Amir Tzin) [2117777]
- net/mlx5: DR, Modify header action of size 1 optimization (Amir Tzin) [2117777]
- net/mlx5: DR, Support decap L3 action using pattern / arg mechanism (Amir Tzin) [2117777]
- net/mlx5: DR, Apply new accelerated modify action and decapl3 (Amir Tzin) [2117777]
- net/mlx5: DR, Add modify header argument pointer to actions attributes (Amir Tzin) [2117777]
- net/mlx5: DR, Add modify header arg pool mechanism (Amir Tzin) [2117777]
- net/mlx5: DR, Fix QP continuous allocation (Amir Tzin) [2117777]
- net/mlx5: DR, Read ICM memory into dedicated buffer (Amir Tzin) [2117777]
- net/mlx5: DR, Add support for writing modify header argument (Amir Tzin) [2117777]
- net/mlx5: DR, Add create/destroy for modify-header-argument general object (Amir Tzin) [2117777]
- net/mlx5: DR, Check for modify_header_argument device capabilities (Amir Tzin) [2117777]
- net/mlx5: DR, Split chunk allocation to HW-dependent ways (Amir Tzin) [2117777]
- net/mlx5: DR, Add cache for modify header pattern (Amir Tzin) [2117777]
- net/mlx5: DR, Move ACTION_CACHE_LINE_SIZE macro to header (Amir Tzin) [2117777]
- net/mlx5: DR, Add modify-header-pattern ICM pool (Amir Tzin) [2117777]
- net/mlx5: DR, Prepare sending new WQE type (Amir Tzin) [2117777]
- net/mlx5: Add new WQE for updating flow table (Amir Tzin) [2117777]
- net/mlx5: Add mlx5_ifc bits for modify header argument (Amir Tzin) [2117777]
- net/mlx5: DR, Set counter ID on the last STE for STEv1 TX (Amir Tzin) [2117777]
- net/mlx5e: TC, Remove redundant parse_attr argument (Amir Tzin) [2165908]
- net/mlx5e: Use a simpler comparison for uplink rep (Amir Tzin) [2165908]
- net/mlx5: Lag, Add single RDMA device in multiport mode (Amir Tzin) [2165908]
- net/mlx5: Lag, set different uplink vport metadata in multiport eswitch mode (Amir Tzin) [2165908]
- net/mlx5: E-Switch, rename bond update function to be reused (Amir Tzin) [2165908]
- net/mlx5e: TC, Add peer flow in mpesw mode (Amir Tzin) [2165908]
- net/mlx5: Lag, Control MultiPort E-Switch single FDB mode (Amir Tzin) [2165908]
- net/mlx5e: Add devlink fdb_large_groups parameter (Add missing Documentation) (Amir Tzin) [2165908]
- SUNRPC: Fix READ_PLUS crasher (Benjamin Coddington) [2218539]
- SUNRPC: Remove pointer type casts from xdr_get_next_encode_buffer() (Benjamin Coddington) [2218539]
- SUNRPC: Clean up xdr_get_next_encode_buffer() (Benjamin Coddington) [2218539]
- NFSv4.1: freeze the session table upon receiving NFS4ERR_BADSESSION (Benjamin Coddington) [2218539]
- NFSv4.2: fix wrong shrinker_id (Benjamin Coddington) [2218539]
- svcrdma: Prevent page release when nothing was received (Benjamin Coddington) [2218539]
- SUNRPC: Fix UAF in svc_tcp_listen_data_ready() (Benjamin Coddington) [2218539]
- nfsd: fix double fget() bug in __write_ports_addfd() (Benjamin Coddington) [2218539]
- SUNRPC: Fix trace_svc_register() call site (Benjamin Coddington) [2218539]
- SUNRPC: remove the maximum number of retries in call_bind_status (Benjamin Coddington) [2218539]
- NFSv4.1: Always send a RECLAIM_COMPLETE after establishing lease (Benjamin Coddington) [2218539]
- NFSD: callback request does not use correct credential for AUTH_SYS (Benjamin Coddington) [2218539]
- sunrpc: only free unix grouplist after RCU settles (Benjamin Coddington) [2218539]
- nfsd: call op_release, even when op_func returns an error (Benjamin Coddington) [2218539]
- NFSD: Avoid calling OPDESC() with ops->opnum == OP_ILLEGAL (Benjamin Coddington) [2218539]
- SUNRPC: fix shutdown of NFS TCP client socket (Benjamin Coddington) [2218539]
- NFSv4: Fix hangs when recovering open state after a server reboot (Benjamin Coddington) [2218539]
- NFSD: Protect against filesystem freezing (Benjamin Coddington) [2218539]
- nfsd: fix race to check ls_layouts (Benjamin Coddington) [2218539]
- nfs4trace: fix state manager flag printing (Benjamin Coddington) [2218539]
- SUNRPC: ensure the matching upcall is in-flight upon downcall (Benjamin Coddington) [2218539]
- nfsd: under NFSv4.1, fix double svc_xprt_put on rpc_create failure (Benjamin Coddington) [2218539]
- SUNRPC: Don't leak netobj memory when gss_read_proxy_verf() fails (Benjamin Coddington) [2218539]
- NFSv4.x: Fail client initialisation if state manager thread can't run (Benjamin Coddington) [2218539]
- SUNRPC: Fix missing release socket in rpc_sockname() (Benjamin Coddington) [2218539]
- xprtrdma: Fix regbuf data not freed in rpcrdma_req_create() (Benjamin Coddington) [2218539]
- NFSD: Finish converting the NFSv3 GETACL result encoder (Benjamin Coddington) [2218539]
- NFSD: Finish converting the NFSv2 GETACL result encoder (Benjamin Coddington) [2218539]
- SUNRPC: Return true/false (not 1/0) from bool functions (Benjamin Coddington) [2218539]
- NFS: Fix an Oops in nfs_d_automount() (Benjamin Coddington) [2218539]
- NFSv4: Fix a deadlock between nfs4_open_recover_helper() and delegreturn (Benjamin Coddington) [2218539]
- NFSv4: Fix a credential leak in _nfs4_discover_trunking() (Benjamin Coddington) [2218539]
- NFSv4.2: Fix initialisation of struct nfs4_label (Benjamin Coddington) [2218539]
- NFSv4.2: Fix a memory stomp in decode_attr_security_label (Benjamin Coddington) [2218539]
- NFSv4.2: Always decode the security label (Benjamin Coddington) [2218539]
- NFSv4.2: Clear FATTR4_WORD2_SECURITY_LABEL when done decoding (Benjamin Coddington) [2218539]
- nfs4: Fix kmemleak when allocate slot failed (Benjamin Coddington) [2218539]
- NFSv4.2: Fixup CLONE dest file size for zero-length count (Benjamin Coddington) [2218539]
- SUNRPC: Fix null-ptr-deref when xps sysfs alloc failed (Benjamin Coddington) [2218539]
- NFSv4.1: We must always send RECLAIM_COMPLETE after a reboot (Benjamin Coddington) [2218539]
- NFSv4.1: Handle RECLAIM_COMPLETE trunking errors (Benjamin Coddington) [2218539]
- NFSv4: Fix a potential state reclaim deadlock (Benjamin Coddington) [2218539]
- NFSv4/pNFS: Always return layout stats on layout return for flexfiles (Benjamin Coddington) [2218539]
- NFSD: Fix handling of oversized NFSv4 COMPOUND requests (Benjamin Coddington) [2218539]
- nfsd: Fix a memory leak in an error handling path (Benjamin Coddington) [2218539]
- Revert "SUNRPC: Remove unreachable error condition" (Benjamin Coddington) [2218539]
- NFSv4: Turn off open-by-filehandle and NFS re-export for NFSv4.0 (Benjamin Coddington) [2218539]
- SUNRPC: RPC level errors should set task->tk_rpc_status (Benjamin Coddington) [2218539]
- NFS: Fix another fsync() issue after a server reboot (Benjamin Coddington) [2218539]
- net/sunrpc: fix potential memory leaks in rpc_sysfs_xprt_state_change() (Benjamin Coddington) [2218539]
- SUNRPC: Fix xdr_encode_bool() (Benjamin Coddington) [2218539]
- SUNRPC: Reinitialise the backchannel request buffers before reuse (Benjamin Coddington) [2218539]
- NFSv4.1: RECLAIM_COMPLETE must handle EACCES (Benjamin Coddington) [2218539]
- sunrpc: fix expiry of auth creds (Benjamin Coddington) [2218539]
- pNFS/flexfiles: Report RDMA connection errors to the server (Benjamin Coddington) [2218539]
- Revert "pNFS: nfs3_set_ds_client should set NFS_CS_NOPING" (Benjamin Coddington) [2218539]
- SUNRPC: Fix the calculation of xdr->end in xdr_get_next_encode_buffer() (Benjamin Coddington) [2218539]
- pNFS: Avoid a live lock condition in pnfs_update_layout() (Benjamin Coddington) [2218539]
- pNFS: Don't keep retrying if the server replied NFS4ERR_LAYOUTUNAVAILABLE (Benjamin Coddington) [2218539]
- SUNRPC: Trap RDMA segment overflows (Benjamin Coddington) [2218539]
- nfsd: Fix null-ptr-deref in nfsd_fill_super() (Benjamin Coddington) [2218539]
- NFS: Further fixes to the writeback error handling (Benjamin Coddington) [2218539]
- NFS: clean up a needless assignment in nfs_file_write() (Benjamin Coddington) [2218539]
- NFS: remove redundant code in nfs_file_write() (Benjamin Coddington) [2218539]
- NFS: Add support for eager writes (Benjamin Coddington) [2218539]
- NFS: 'flags' field should be unsigned in struct nfs_server (Benjamin Coddington) [2218539]
- NFSv4/pNFS: Do not fail I/O when we fail to allocate the pNFS layout (Benjamin Coddington) [2218539]
- NFS: Memory allocation failures are not server fatal errors (Benjamin Coddington) [2218539]
- SUNRPC: Ensure that the gssproxy client can start in a connected state (Benjamin Coddington) [2218539]
- Revert "SUNRPC: Ensure gss-proxy connects on setup" (Benjamin Coddington) [2218539]
- SUNRPC: Ensure gss-proxy connects on setup (Benjamin Coddington) [2218539]
- NFSv4: Don't invalidate inode attributes on delegation return (Benjamin Coddington) [2218539]
- SUNRPC: svc_tcp_sendmsg() should handle errors from xdr_alloc_bvec() (Benjamin Coddington) [2218539]
- SUNRPC: Handle low memory situations in call_status() (Benjamin Coddington) [2218539]
- SUNRPC: Handle ENOMEM in call_transmit_status() (Benjamin Coddington) [2218539]
- SUNRPC: Fix the svc_deferred_event trace class (Benjamin Coddington) [2218539]
- NFSv4: fix open failure with O_ACCMODE flag (Benjamin Coddington) [2218539]
- NFSv4/pNFS: Fix another issue with a list iterator pointing to the head (Benjamin Coddington) [2218539]
- NFSv4.1: Fix uninitialised variable in devicenotify (Benjamin Coddington) [2218539]
- NFSv4.1: don't retry BIND_CONN_TO_SESSION on session error (Benjamin Coddington) [2218539]
- NFS: remove unneeded check in decode_devicenotify_args() (Benjamin Coddington) [2218539]
- NFS: NFSv2/v3 clients should never be setting NFS_CAP_XATTR (Benjamin Coddington) [2218539]
- NFS: Do not report writeback errors in nfs_getattr() (Benjamin Coddington) [2218539]
- NFS: Remove an incorrect revalidation in nfs4_update_changeattr_locked() (Benjamin Coddington) [2218539]
- nfsd: nfsd4_setclientid_confirm mistakenly expires confirmed client. (Benjamin Coddington) [2218539]
- SUNRPC: Fix sockaddr handling in svcsock_accept_class trace points (Benjamin Coddington) [2218539]
- SUNRPC: Fix sockaddr handling in the svc_xprt_create_error trace point (Benjamin Coddington) [2218539]
- NFSD: Fix zero-length NFSv3 WRITEs (Benjamin Coddington) [2218539]
- NFS: Ensure the server has an up to date ctime before renaming (Benjamin Coddington) [2218539]
- NFS: Ensure the server has an up to date ctime before hardlinking (Benjamin Coddington) [2218539]

* Tue Aug 01 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-507.el8]
- Revert "NFSv4: Retry LOCK on OLD_STATEID during delegation return" (Benjamin Coddington) [2217658]
- powerpc/pseries/vas: Hold mmap_mutex after mmap lock during window close (Mamatha Inamdar) [2224883]
- KVM: x86/mmu: Fix race condition in direct_page_fault (Jon Maloy) [2179929] {CVE-2022-45869}
- x86/speculation: Allow enabling STIBP with legacy IBRS (Ricardo Robaina) [2187268] {CVE-2023-1998}
- ACPI: sleep: Avoid breaking S3 wakeup due to might_sleep() (Mark Langsdorf) [2215625]
- locking/semaphore: Add might_sleep() to down_*() family (Mark Langsdorf) [2215625]
- perf stat: Support hybrid --topdown option (Michael Petlan) [2088833]
- i40e: Wait for pending VF reset in VF set callbacks (Ivan Vecera) [2203921]
- i40e: Add helper for VF inited state check with timeout (Ivan Vecera) [2203921]
- tracing: Have filter accept "common_cpu" to be consistent (Jerome Marchand) [2210711]
- tracing/histogram: Fix sorting on old "cpu" value (Jerome Marchand) [2210711]
- tracing: Dump stacktrace trigger to the corresponding instance (Jerome Marchand) [2210711]
- tracing/histogram: Rename "cpu" to "common_cpu" (Jerome Marchand) [2210711]
- docs: histogram.txt: convert it to ReST file format (Jerome Marchand) [2210711]
- bonding: add software tx timestamping support (Hangbin Liu) [2181339]
- bonding: fix missed rcu protection (Hangbin Liu) [2181339]
- bonding: use rcu_dereference_rtnl when get bonding active slave (Hangbin Liu) [2181339]
- Bonding: return HWTSTAMP_FLAG_BONDED_PHC_INDEX to notify user space (Hangbin Liu) [2181339]
- Bonding: force user to add HWTSTAMP_FLAG_BONDED_PHC_INDEX when get/set HWTSTAMP (Hangbin Liu) [2181339]
- bond: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to active device (Hangbin Liu) [2181339]
- mm/page_alloc: fix incorrect PGFREE and PGALLOC for high-order page (Chris von Recklinghausen) [2100592]
- mm/page_alloc: check high-order pages for corruption during PCP operations (Chris von Recklinghausen) [2100592]
- mm/page_alloc: do not prefetch buddies during bulk free (Chris von Recklinghausen) [2100592]
- mm/page_alloc: free pages in a single pass during bulk free (Chris von Recklinghausen) [2100592]
- mm/page_alloc: drain the requested list first during bulk free (Chris von Recklinghausen) [2100592]
- mm/page_alloc: simplify how many pages are selected per pcp list during bulk free (Chris von Recklinghausen) [2100592]
- mm/page_alloc: track range of active PCP lists during bulk free (Chris von Recklinghausen) [2100592]
- mm/page_alloc: fetch the correct pcp buddy during bulk free (Chris von Recklinghausen) [2100592]
- mm/page_alloc: allow high-order pages to be stored on the per-cpu lists (Chris von Recklinghausen) [2100592]
- mm/page_alloc: move free_the_page (Chris von Recklinghausen) [2100592]
- mm,memory_hotplug: factor out adjusting present pages into adjust_present_page_count() (Chris von Recklinghausen) [2100592]
- mm, meminit: recalculate pcpu batch and high limits after init completes (Chris von Recklinghausen) [2100592]
- compiler_attributes.h: Add kABI workaround (Waiman Long) [2215801]
- linux/compiler-clang.h: define HAVE_BUILTIN_BSWAP* (Waiman Long) [2215801]
- compiler.h: fix barrier_data() on clang (Waiman Long) [2215801]
- compiler_types.h: Add __no_sanitize_{address,undefined} to noinstr (Waiman Long) [2215801]
- x86, kcsan: Add __no_kcsan to noinstr (Waiman Long) [2215801]
- kcsan: Add __no_kcsan function attribute (Waiman Long) [2215801]
- kcsan: Reorganize compiler.h (Waiman Long) [2215801]
- include/linux/compiler*.h: fix OPTIMIZER_HIDE_VAR (Waiman Long) [2215801]
- include/linux/compiler_types.h: don't pollute userspace with macro definitions (Waiman Long) [2215801]
- include/linux/compiler*.h: define asm_volatile_goto (Waiman Long) [2215801]
- Compiler Attributes: use feature checks instead of version checks (Waiman Long) [2215801]
- Compiler Attributes: remove unneeded sparse (__CHECKER__) tests (Waiman Long) [2215801]
- Compiler Attributes: homogenize __must_be_array (Waiman Long) [2215801]
- Compiler Attributes: remove unneeded tests (Waiman Long) [2215801]
- Compiler Attributes: always use the extra-underscores syntax (Waiman Long) [2215801]
- Compiler Attributes: remove unused attributes (Waiman Long) [2215801]
- Compiler Attributes: naked can be shared (Waiman Long) [2215801]
- Compiler Attributes: naked was fixed in gcc 4.6 (Waiman Long) [2215801]
- include/linux/compiler*.h: make compiler-*.h mutually exclusive (Waiman Long) [2215801]
- Raise the minimum required gcc version to 4.6 (Waiman Long) [2215801]
- deprecate the '__deprecated' attribute warnings entirely and for good (Waiman Long) [2215801]

* Thu Jul 27 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-506.el8]
- libceph: harden msgr2.1 frame segment length checks (Ilya Dryomov) [2222256]
- netfilter: nf_conntrack_netlink: need to hold rcu readlock when doing l4proto lookup (Florian Westphal) [2188230]
- net/mlx5: Expose steering dropped packets counter (Amir Tzin) [2223198]
- net/mlx5: Expose vnic diagnostic counters for eswitch managed vports (Amir Tzin) [2223198]
- igbvf: add PCI reset handler functions (Corinna Vinschen) [2153365]
- igbvf: Regard vf reset nack as success (Corinna Vinschen) [2153365]
- intel/igbvf: free irq on the error path in igbvf_request_msix() (Corinna Vinschen) [2153365]
- Bluetooth: L2CAP: Fix use-after-free in l2cap_disconnect_{req,rsp} (Ricardo Robaina) [2139617] {CVE-2022-3640}
- Bluetooth: L2CAP: Fix build errors in some archs (Ricardo Robaina) [2139617] {CVE-2022-3640}
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm regression (Ricardo Robaina) [2139617] {CVE-2022-3640}
- Bluetooth: L2CAP: fix use-after-free in l2cap_conn_del() (Ricardo Robaina) [2139617] {CVE-2022-3640}
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_chan_put (Ricardo Robaina) [2139617] {CVE-2022-3640}
- iavf: fix reset task race with iavf_remove() (Petr Oros) [2223604]
- iavf: fix a deadlock caused by rtnl and driver's lock circular dependencies (Petr Oros) [2223604]
- Revert "iavf: Do not restart Tx queues after reset task failure" (Petr Oros) [2223604]
- Revert "iavf: Detach device during reset task" (Petr Oros) [2223604]
- iavf: Wait for reset in callbacks which trigger it (Petr Oros) [2223604]
- iavf: use internal state to free traffic IRQs (Petr Oros) [2223604]
- iavf: Fix out-of-bounds when setting channels on remove (Petr Oros) [2223604]
- iavf: Fix use-after-free in free_netdev (Petr Oros) [2223604]
- iavf: make functions static where possible (Petr Oros) [2223604]
- iavf: fix err handling for MAC replace (Petr Oros) [2223604]
- iavf: remove some unused functions and pointless wrappers (Petr Oros) [2223604]
- iavf: remove mask from iavf_irq_enable_queues() (Petr Oros) [2223604]
- iavf: send VLAN offloading caps once after VFR (Petr Oros) [2223604]
- cpufreq: Fix parameter in parse_perf_domain() (Mark Langsdorf) [2181273]
- cpufreq: intel_pstate: remove MODULE_LICENSE in non-modules (Mark Langsdorf) [2181273]
- cpufreq: intel_pstate: Adjust balance_performance EPP for Sapphire Rapids (Mark Langsdorf) [2181273]
- cpufreq: Make kobj_type structure constant (Mark Langsdorf) [2181273]
- driver core: make kobj_type constant. (Mark Langsdorf) [2181273]
- cpufreq: Make cpufreq_unregister_driver() return void (Mark Langsdorf) [2181273]
- drivers/cpufreq: Remove "select SRCU" (Mark Langsdorf) [2181273]
- cpufreq: intel_pstate: Drop ACPI _PSS states table patching (Mark Langsdorf) [2181273]
- cpufreq: stats: Convert to use sysfs_emit_at() API (Mark Langsdorf) [2181273]
- cpufreq: Init completion before kobject_init_and_add() (Mark Langsdorf) [2181273]
- cpufreq: intel_pstate: Allow EPP 0x80 setting by the firmware (Mark Langsdorf) [2181273]
- cpufreq: ACPI: Use str_enabled_disabled() helper (Mark Langsdorf) [2181273]
- cpufreq: Generalize of_perf_domain_get_sharing_cpumask phandle format (Mark Langsdorf) [2181273]
- cpufreq: Add of_perf_domain_get_sharing_cpumask (Mark Langsdorf) [2181273]
- cpufreq: intel_pstate: Read all MSRs on the target CPU (Mark Langsdorf) [2181273]
- ACPI: CPPC: Add ACPI disabled check to acpi_cpc_valid() (Mark Langsdorf) [2181273]

* Tue Jul 25 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-505.el8]
- gfs2: Don't deref jdesc in evict (Bob Peterson) [2214356] {CVE-2023-3212}
- md/raid5: Don't do accounting for non-align read io (Nigel Croxon) [2183033]
- powerpc: Don't select HAVE_IRQ_EXIT_ON_IRQ_STACK (Mamatha Inamdar) [2218348]
- NFSv4.1: freeze the session table upon receiving NFS4ERR_BADSESSION (Benjamin Coddington) [2217963]
- proc: Use PIDTYPE_TGID in next_tgid (Brian Foster) [2047252]
- netfilter: nf_tables: unbind non-anonymous set if rule construction fails (Phil Sutter) [2214963] {CVE-2023-3390}
- netfilter: nf_tables: add NFT_TRANS_PREPARE_ERROR to deal with bound set/chain (Phil Sutter) [2214963] {CVE-2023-3390}
- netfilter: nf_tables: incorrect error path handling with NFT_MSG_NEWRULE (Phil Sutter) [2214963] {CVE-2023-3390}
- fanotify,audit: Allow audit to use the full permission event response (Richard Guy Briggs) [2055328]
- fanotify: define struct members to hold response decision context (Richard Guy Briggs) [2055328]
- fanotify: Ensure consistent variable type for response (Richard Guy Briggs) [2055328]
- RDMA/mlx4: Prevent shift wrapping in set_user_sq_size() (Amir Tzin) [2166019]
- RDMA/mlx: Calling qp event handler in workqueue context (mlx4 hunks only) (Amir Tzin) [2166019]
- net/mlx4: small optimization in mlx4_en_xmit() (Amir Tzin) [2166019]
- net/mlx4: rename two constants (Amir Tzin) [2166019]
- RDMA/mlx4: Remove NULL check before dev_{put, hold} (Amir Tzin) [2166019]
- ptp: mlx4: convert to .adjfine and adjust_by_scaled_ppm (Amir Tzin) [2166019]
- mlx4: Do type_clear() for devlink ports when type_set() was called previously (Amir Tzin) [2166019]
- cgroup: Reorganize css_set_lock and kernfs path processing (Waiman Long) [2193485]
- cgroup: Fix build failure when CONFIG_SHRINKER_DEBUG (Waiman Long) [2193485]
- cgroup: fix missing cpus_read_{lock,unlock}() in cgroup_transfer_tasks() (Waiman Long) [2193485]
- cgroup: Make cgroup_get_from_id() prettier (Waiman Long) [2193485]
- cgroup: remove obsolete comment on cgroup_on_dfl() (Waiman Long) [2193485]
- cgroup/cpuset: Wake up cpuset_attach_wq tasks in cpuset_cancel_attach() (Waiman Long) [2193485]
- kselftests: cgroup: update kmem test precision tolerance (Waiman Long) [2193485]
- cgroup/cpuset: Improve cpuset_css_alloc() description (Waiman Long) [2193485]
- selftests: cgroup: fix unsigned comparison with less than zero (Waiman Long) [2193485]
- device_cgroup: Roll back to original exceptions after copy failure (Waiman Long) [2193485]
- cgroup/cpuset: use hotplug_memory_notifier() directly (Waiman Long) [2193485]
- mm: memcontrol: don't allocate cgroup swap arrays when memcg is disabled (Waiman Long) [2193485]
- cgroup: cgroup_get_from_id() must check the looked-up kn is a directory (Waiman Long) [2193485]
- sched/psi: Don't create cgroup PSI files when psi_disabled (Waiman Long) [2193485]
- cgroup: Homogenize cgroup_get_from_id() return value (Waiman Long) [2193485]
- cgroup: cgroup: Honor caller's cgroup NS when resolving cgroup id (Waiman Long) [2193485]
- cgroup: Honor caller's cgroup NS when resolving path (Waiman Long) [2193485]
- mm: memcontrol: introduce mem_cgroup_ino() and mem_cgroup_get_from_ino() (Waiman Long) [2193485]
- cgroup: Use separate src/dst nodes when preloading css_sets for migration (Waiman Long) [2193485]
- cgroup.c: add helper __cset_cgroup_from_root to cleanup duplicated codes (Waiman Long) [2193485]
- cgroup/rstat: check updated_next only for root (Waiman Long) [2193485]
- cgroup: rstat: explicitly put loop variant in while (Waiman Long) [2193485]
- cgroup: return early if it is already on preloaded list (Waiman Long) [2193485]
- cgroup: Trace event cgroup id fields should be u64 (Waiman Long) [2193485]
- cgroup: fix a typo in comment (Waiman Long) [2193485]
- hugetlb_cgroup: remove unused hugetlb_cgroup_from_counter macro (Waiman Long) [2193485]
- cgroup: Make rebind_subsystems() disable v2 controllers all at once (Waiman Long) [2193485]
- cgroup: Avoid compiler warnings with no subsystems (Waiman Long) [2193485]
- cgroup: Fix kernel-doc (Waiman Long) [2193485]
- kernfs: use 64bit inos if ino_t is 64bit (Waiman Long) [2193485]
- kernfs: implement custom exportfs ops and fid type (Waiman Long) [2193485]
- kernfs: combine ino/id lookup functions into kernfs_find_and_get_node_by_id() (Waiman Long) [2193485]
- kernfs: kernfs_find_and_get_node_by_ino() should only look up activated nodes (Waiman Long) [2193485]
- kernfs: use dumber locking for kernfs_find_and_get_node_by_ino() (Waiman Long) [2193485]
- kernfs: fix ino wrap-around detection (Waiman Long) [2193485]
- ice: prevent NULL pointer deref during reload (Petr Oros) [2153356]
- ice: Unregister netdev and devlink_port only once (Petr Oros) [2153356]
- ice: Fix ice module unload (Petr Oros) [2153356]
- ice: Fix tx queue rate limit when TCs are configured (Petr Oros) [2153356]
- ice: Fix max_rate check while configuring TX rate limits (Petr Oros) [2153356]
- ice: Fix XDP memory leak when NIC is brought up and down (Petr Oros) [2153356]
- ice: remove comment about not supporting driver reinit (Petr Oros) [2153356]
- ice: block LAN in case of VF to VF offload (Petr Oros) [2153356]
- ice: Fix stats after PF reset (Petr Oros) [2153356]
- ice: Reset FDIR counter in FDIR init stage (Petr Oros) [2153356]
- ice: fix wrong fallback logic for FDIR (Petr Oros) [2153356]
- ice: add profile conflict check for AVF FDIR (Petr Oros) [2153356]
- ice: Fix ice_cfg_rdma_fltr() to only update relevant fields (Petr Oros) [2153356]
- ice: remove filters only if VSI is deleted (Petr Oros) [2153356]
- ice: check if VF exists before mode check (Petr Oros) [2153356]
- ice: xsk: disable txq irq before flushing hw (Petr Oros) [2153356]
- ice: avoid bonding causing auxiliary plug/unplug under RTNL lock (Petr Oros) [2153356]
- ethernet: ice: avoid gcc-9 integer overflow warning (Petr Oros) [2153356]
- ice: don't ignore return codes in VSI related code (Petr Oros) [2153356]
- ice: Fix DSCP PFC TLV creation (Petr Oros) [2153356]
- ice: copy last block omitted in ice_get_module_eeprom() (Petr Oros) [2153356]
- ice: properly alloc ICE_VSI_LB (Petr Oros) [2153356]
- ice: xsk: Fix cleaning of XDP_TX frames (Petr Oros) [2153356]
- ice: Mention CEE DCBX in code comment (Petr Oros) [2153356]
- ice: Change ice_vsi_realloc_stat_arrays() to void (Petr Oros) [2153356]
- ice: Add GPIO pin support for E823 products (Petr Oros) [2153356]
- ice: switch: fix potential memleak in ice_add_adv_recipe() (Petr Oros) [2153356]
- ice: Fix off by one in ice_tc_forward_to_queue() (Petr Oros) [2153356]
- ice: Fix disabling Rx VLAN filtering with port VLAN enabled (Petr Oros) [2153356]
- ice: fix out-of-bounds KASAN warning in virtchnl (Petr Oros) [2153356]
- ice: Do not use WQ_MEM_RECLAIM flag for workqueue (Petr Oros) [2153356]
- ice: remove unnecessary virtchnl_ether_addr struct use (Petr Oros) [2153356]
- ice: introduce .irq_close VF operation (Petr Oros) [2153356]
- ice: introduce clear_reset_state operation (Petr Oros) [2153356]
- ice: convert vf_ops .vsi_rebuild to .create_vsi (Petr Oros) [2153356]
- ice: introduce ice_vf_init_host_cfg function (Petr Oros) [2153356]
- ice: add a function to initialize vf entry (Petr Oros) [2153356]
- ice: Pull common tasks into ice_vf_post_vsi_rebuild (Petr Oros) [2153356]
- ice: move ice_vf_vsi_release into ice_vf_lib.c (Petr Oros) [2153356]
- ice: move vsi_type assignment from ice_vsi_alloc to ice_vsi_cfg (Petr Oros) [2153356]
- ice: refactor VSI setup to use parameter structure (Petr Oros) [2153356]
- ice: drop unnecessary VF parameter from several VSI functions (Petr Oros) [2153356]
- ice: fix function comment referring to ice_vsi_alloc (Petr Oros) [2153356]
- ice: Add more usage of existing function ice_get_vf_vsi(vf) (Petr Oros) [2153356]
- ice: implement devlink reinit action (Petr Oros) [2153356]
- ice: update VSI instead of init in some case (Petr Oros) [2153356]
- ice: move VSI delete outside deconfig (Petr Oros) [2153356]
- ice: sync netdev filters after clearing VSI (Petr Oros) [2153356]
- ice: split probe into smaller functions (Petr Oros) [2153356]
- ice: stop hard coding the ICE_VSI_CTRL location (Petr Oros) [2153356]
- ice: split ice_vsi_setup into smaller functions (Petr Oros) [2153356]
- ice: cleanup in VSI config/deconfig code (Petr Oros) [2153356]
- ice: alloc id for RDMA using xa_array (Petr Oros) [2153356]
- ice: move RDMA init to ice_idc.c (Petr Oros) [2153356]
- ice: Prevent set_channel from changing queues while RDMA active (Petr Oros) [2153356]
- ice: Remove redundant pci_enable_pcie_error_reporting() (Petr Oros) [2153356]
- ice: move devlink port creation/deletion (Petr Oros) [2153356]
- ice: Remove excess space (Petr Oros) [2153356]
- ice: Introduce local var for readability (Petr Oros) [2153356]
- ice: Match parameter name for ice_cfg_phy_fc() (Petr Oros) [2153356]
- ice: Explicitly return 0 (Petr Oros) [2153356]
- ice: Reduce scope of variables (Petr Oros) [2153356]
- ice: Move support DDP code out of ice_flex_pipe.c (Petr Oros) [2153356]
- ice: Remove cppcheck suppressions (Petr Oros) [2153356]
- ice: combine cases in ice_ksettings_find_adv_link_speed() (Petr Oros) [2153356]
- ice: Add support for 100G KR2/CR2/SR2 link reporting (Petr Oros) [2153356]
- ice: add missing checks for PF vsi type (Petr Oros) [2153356]
- ice: remove redundant non-null check in ice_setup_pf_sw() (Petr Oros) [2153356]
- ice: restrict PTP HW clock freq adjustments to 100, 000, 000 PPB (Petr Oros) [2153356]
- ice: Support drop action (Petr Oros) [2153356]
- ice: Handle LLDP MIB Pending change (Petr Oros) [2153356]
- ice: Add 'Execute Pending LLDP MIB' Admin Queue command (Petr Oros) [2153356]
- ice: xsk: do not use xdp_return_frame() on tx_buf->raw_buf (Petr Oros) [2153356]
- ice: Use ICE_RLAN_BASE_S instead of magic number (Petr Oros) [2153356]
- ice: Accumulate ring statistics over reset (Petr Oros) [2153356]
- ice: Accumulate HW and Netdev statistics over reset (Petr Oros) [2153356]
- ice: Remove and replace ice speed defines with ethtool.h versions (Petr Oros) [2153356]
- ice: Check for PTP HW lock more frequently (Petr Oros) [2153356]
- ice: Fix spurious interrupt during removal of trusted VF (Petr Oros) [2153356]
- ice: Enable RX queue selection using skbedit action (Petr Oros) [2153356]
- ice: Add support for VLAN priority filters in switchdev (Petr Oros) [2153356]
- ice: support features on new E810T variants (Petr Oros) [2153356]
- ice: xsk: drop power of 2 ring size restriction for AF_XDP (Petr Oros) [2153356]
- ice: xsk: change batched Tx descriptor cleaning (Petr Oros) [2153356]
- ice: reorder PF/representor devlink port register/unregister flows (Petr Oros) [2153356]
- ice: Add L2TPv3 hardware offload support (Petr Oros) [2153356]
- ice: Simplify memory allocation in ice_sched_init_port() (Petr Oros) [2153356]
- ice: switch: Simplify memory allocation (Petr Oros) [2153356]
- ice: add helper function to check FW API version (Petr Oros) [2153356]
- ice: Print human-friendly PHY types (Petr Oros) [2153356]
- ice: Add support for ip TTL & ToS offload (Petr Oros) [2153356]
- ice: xsk: use Rx ring's XDP ring when picking NAPI context (Petr Oros) [2153356]
- ice: xsk: prohibit usage of non-balanced queue id (Petr Oros) [2153356]
- ice: remove non-inclusive language (Petr Oros) [2153356]
- ice: Remove ucast_shared (Petr Oros) [2153356]
- ice: Allow 100M speeds for some devices (Petr Oros) [2153356]
- ice: Implement FCS/CRC and VLAN stripping co-existence policy (Petr Oros) [2153356]
- ice: Implement control of FCS/CRC stripping (Petr Oros) [2153356]
- ice: initialize cached_phctime when creating Rx rings (Petr Oros) [2153356]
- ice: set tx_tstamps when creating new Tx rings via ethtool (Petr Oros) [2153356]
- ice: link representors to PCI device (Petr Oros) [2153356]
- ice, xsk: Avoid refilling single Rx descriptors (Petr Oros) [2153356]
- ice, xsk: Diversify return values from xsk_wakeup call paths (Petr Oros) [2153356]
- ice, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Petr Oros) [2153356]
- ice, xsk: Decorate ICE_XDP_REDIR with likely() (Petr Oros) [2153356]
- ice: xsk: check if Rx ring was filled up to the end (Petr Oros) [2153356]
- ice: xsk: Eliminate unnecessary loop iteration (Petr Oros) [2153356]
- ice: xsk: fix GCC version checking against pragma unroll presence (Petr Oros) [2153356]
- ice: xsk: Borrow xdp_tx_active logic from i40e (Petr Oros) [2153356]
- ice: xsk: Improve AF_XDP ZC Tx and use batching API (Petr Oros) [2153356]
- ice: xsk: Avoid potential dead AF_XDP Tx processing (Petr Oros) [2153356]
- ice: Make Tx threshold dependent on ring length (Petr Oros) [2153356]
- ice: xsk: Handle SW XDP ring wrap and bump tail more often (Petr Oros) [2153356]
- ice: xsk: Force rings to be sized to power of 2 (Petr Oros) [2153356]
- ice: xsk: do not clear status_error0 for ntu + nb_buffs descriptor (Petr Oros) [2153356]
- ice: remove dead store on XSK hotpath (Petr Oros) [2153356]
- ice: xsk: clear status_error0 for each allocated desc (Petr Oros) [2153356]
- intel: Simplify bool conversion (Petr Oros) [2153356]
- ice: Use the xsk batched rx allocation interface (Petr Oros) [2153356]

* Thu Jul 20 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-504.el8]
- blk-cgroup: Reinit blkg_iostat_set after clearing in blkcg_reset_stats() (Waiman Long) [2212032]
- ipvlan:Fix out-of-bounds caused by unclear skb->cb (Davide Caratti) [2218676] {CVE-2023-3090}
- net: openvswitch: fix upcall counter access before allocation (Eelco Chaudron) [2214262]
- netfilter: Drop fragmented ndisc packets assembled in netfilter (Phil Sutter) [2217795]
- netfilter: conntrack: gre: don't set assured flag for clash entries (Florian Westphal) [2219357]
- netfilter: conntrack: allow insertion clash of gre protocol (Florian Westphal) [2219357]
- sfc: use budget for TX completions (Íñigo Huguet) [2179558]
- sfc: fix XDP queues mode with legacy IRQ (Íñigo Huguet) [2214589]
- memstick: r592: Fix UAF bug in r592_remove due to race condition (Ricardo Robaina) [2213205] {CVE-2023-3141}
- audit: avoid missing-prototype warnings (Richard Guy Briggs) [2175322]
- audit: update the mailing list in MAINTAINERS (Richard Guy Briggs) [2175322]
- audit: fix undefined behavior in bit shift for AUDIT_BIT (Richard Guy Briggs) [2175322]
- fork: Use IS_ENABLED() in account_kernel_stack() (Valentin Schneider) [2131754]
- fork: Only cache the VMAP stack in finish_task_switch() (Valentin Schneider) [2131754]
- fork: Move task stack accounting to do_exit() (Valentin Schneider) [2131754]
- fork: Move memcg_charge_kernel_stack() into CONFIG_VMAP_STACK (Valentin Schneider) [2131754]
- fork: Don't assign the stack pointer in dup_task_struct() (Valentin Schneider) [2131754]
- fork, IA64: Provide alloc_thread_stack_node() for IA64 (Valentin Schneider) [2131754]
- fork: Duplicate task_struct before stack allocation (Valentin Schneider) [2131754]
- fork: Redo ifdefs around task stack handling (Valentin Schneider) [2131754]
- fork: fix some -Wmissing-prototypes warnings (Valentin Schneider) [2131754]
- igb: fix nvm.ops.read() error handling (Corinna Vinschen) [2153360]
- igb: Fix extts capture value format for 82580/i354/i350 (Corinna Vinschen) [2153360]
- igb: Define igb_pm_ops conditionally on CONFIG_PM (Corinna Vinschen) [2153360]
- igb: fix bit_shift to be in [1..8] range (Corinna Vinschen) [2153360]
- igb: refactor igb_ptp_adjfine_82580 to use diff_by_scaled_ppm (Corinna Vinschen) [2153360]
- igb: revert rtnl_lock() that causes deadlock (Corinna Vinschen) [2153360]
- igb: Remove unnecessary aer.h include (Corinna Vinschen) [2153360]
- igb: Fix PPS input and output using 3rd and 4th SDP (Corinna Vinschen) [2153360]
- igb: Remove redundant pci_enable_pcie_error_reporting() (Corinna Vinschen) [2153360]
- igb: Add lock to avoid data race (Corinna Vinschen) [2153360]
- x86/cpu: Include the header of init_ia32_feat_ctl()'s prototype (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- x86/pm: Fix false positive kmemleak report in msr_build_context() (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- x86/speculation: Restore speculation related MSRs during S3 resume (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- kbuild: remove leftover comment for filechk utility (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- x86/cpu: Reinitialize IA32_FEAT_CTL MSR on BSP during wakeup (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- x86/rdrand: Sanity-check RDRAND output (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- x86/CPU/AMD: Clear RDRAND CPUID bit on AMD family 15h/16h (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- kbuild: change filechk to surround the given command with { } (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- firmware: refactor firmware/Makefile (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- kbuild: remove redundant 'set -e' from filechk_offsets (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- kbuild: do not redirect the first prerequisite for filechk (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- kbuild: move bin2c back to scripts/ from scripts/basic/ (Chris von Recklinghausen) [2181906] {CVE-2023-1637}
- perf/x86/ibs: Add new IBS register bits into header (Michael Petlan) [2088767]
- perf tool x86: Fix perf_env memory leak (Michael Petlan) [2088767]
- perf tool x86: Consolidate is_amd check into single function (Michael Petlan) [2088767]
- perf env: Add perf_env__cpuid, perf_env__{nr_}pmu_mappings (Michael Petlan) [2088767]
- perf/x86/amd/uncore: Fix memory leak for events array (Michael Petlan) [2088767]
- perf script: Add missing fields in usage hint (Michael Petlan) [2086837]
- perf mem: Print "LFB/MAB" for PERF_MEM_LVLNUM_LFB (Michael Petlan) [2088767]
- perf mem/c2c: Avoid printing empty lines for unsupported events (Michael Petlan) [2088767]
- perf mem/c2c: Add load store event mappings for AMD (Michael Petlan) [2088767]
- perf mem/c2c: Set PERF_SAMPLE_WEIGHT for LOAD_STORE events (Michael Petlan) [2088767]
- perf mem: Add support for printing PERF_MEM_LVLNUM_{CXL|IO} (Michael Petlan) [2088767]
- perf/mem: Rename PERF_MEM_LVLNUM_EXTN_MEM to PERF_MEM_LVLNUM_CXL (Michael Petlan) [2088767]
- perf amd ibs: Sync arch/x86/include/asm/amd-ibs.h header with the kernel (Michael Petlan) [2088767]
- tools headers UAPI: Sync include/uapi/linux/perf_event.h header with the kernel (Michael Petlan) [2088767]
- perf/uapi: Define PERF_MEM_SNOOPX_PEER in kernel header file (Michael Petlan) [2088767]
- perf: correct SNOOPX field offset (Michael Petlan) [2088767]
- perf tools: Sync addition of PERF_MEM_SNOOPX_PEER (Michael Petlan) [2088767]
- perf/x86/amd: Support PERF_SAMPLE_PHY_ADDR (Michael Petlan) [2088767]
- perf: Add sample_flags to indicate the PMU-filled sample data (Michael Petlan) [2086837]
- perf/x86/amd: Support PERF_SAMPLE_ADDR (Michael Petlan) [2088767]
- perf/x86/amd: Support PERF_SAMPLE_{WEIGHT|WEIGHT_STRUCT} (Michael Petlan) [2088767]
- perf/x86/amd: Support PERF_SAMPLE_DATA_SRC (Michael Petlan) [2088767]
- perf/x86/amd: Add IBS OP_DATA2 DataSrc bit definitions (Michael Petlan) [2088767]
- perf/mem: Introduce PERF_MEM_LVLNUM_{EXTN_MEM|IO} (Michael Petlan) [2088767]
- perf/x86/amd/uncore: Add PerfMonV2 RDPMC assignments (Michael Petlan) [2086837]
- perf/x86/amd/uncore: Add PerfMonV2 DF event format (Michael Petlan) [2086837]
- perf/x86/amd/uncore: Detect available DF counters (Michael Petlan) [2086837]
- perf/x86/amd/uncore: Use attr_update for format attributes (Michael Petlan) [2086837]
- perf/x86/amd/uncore: Use dynamic events array (Michael Petlan) [2086837]
- tracing/osnoise: set several trace_osnoise.c variables storage-class-specifier to static (John Kacur) [2175293]
- tracing/osnoise: No need for schedule_hrtimeout range (John Kacur) [2175293]
- tracing/osnoise: Use built-in RCU list checking (John Kacur) [2175293]
- tracing/osnoise: Add preempt and/or irq disabled options (John Kacur) [2175293]
- tracing/osnoise: Add PANIC_ON_STOP option (John Kacur) [2175293]
- tracing/osnoise: Make osnoise_options static (John Kacur) [2175293]
- tracing/osnoise: Add OSNOISE_WORKLOAD option (John Kacur) [2175293]
- tracing/osnoise: Add osnoise/options file (John Kacur) [2175293]
- tracing/osnoise: Fix duration type (John Kacur) [2175293]
- tracing/osnoise: Fix possible recursive locking in stop_per_cpu_kthreads (John Kacur) [2175293]
- tracing/timerlat: Do not wakeup the thread if the trace stops at the IRQ (John Kacur) [2175293]
- tracing/timerlat: Print stacktrace in the IRQ handler if needed (John Kacur) [2175293]
- tracing/timerlat: Notify IRQ new max latency only if stop tracing is set (John Kacur) [2175293]
- drivers: base: cacheinfo: Fix shared_cpu_map changes in event of CPU hotplug (Mark Lansgdorf) [2178301]
- drivers: base: cacheinfo: Update cpu_map_populated during CPU Hotplug (Mark Lansgdorf) [2178301]
- driver core: bus: move documentation for lock_key to proper location. (Mark Langsdorf) [2178301]
- cacheinfo: Check cache properties are present in DT (Mark Langsdorf) [2178301]
- cacheinfo: Fix LLC is not exported through sysfs (Mark Langsdorf) [2178301]
- of: Add of_property_present() helper (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Print full path and name of fwnode (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Avoid spurious error message (Mark Langsdorf) [2178301]
- driver core: bus: Handle early calls to bus_to_subsys() (Mark Langsdorf) [2178301]
- driver core: class: move EXPORT_SYMBOL_GPL() lines to the correct place (Mark Langsdorf) [2178301]
- driver core: cpu: don't hand-override the uevent bus_type callback. (Mark Langsdorf) [2178301]
- driver core: bus: update my copyright notice (Mark Langsdorf) [2178301]
- driver core: bus: add bus_get_dev_root() function (Mark Langsdorf) [2178301]
- driver core: bus: constify bus_unregister() (Mark Langsdorf) [2178301]
- driver core: bus: constify some internal functions (Mark Langsdorf) [2178301]
- driver core: bus: constify bus_get_kset() (Mark Langsdorf) [2178301]
- driver core: bus: constify bus_register/unregister_notifier() (Mark Langsdorf) [2178301]
- driver core: create bus_is_registered() (Mark Langsdorf) [2178301]
- driver core: bus: clean up driver_find() (Mark Langsdorf) [2178301]
- driver core: move driver_find() to bus.c (Mark Langsdorf) [2178301]
- driver core: bus: clean up bus_sort_breadthfirst() (Mark Langsdorf) [2178301]
- driver core: bus: bus iterator cleanups (Mark Langsdorf) [2178301]
- driver core: bus: bus_add/remove_driver() cleanups (Mark Langsdorf) [2178301]
- driver core: bus: bus_register/unregister_notifier() cleanups (Mark Langsdorf) [2178301]
- driver core: bus: bus_get_kset() cleanup (Mark Langsdorf) [2178301]
- driver core: bus: subsys_interface_register/unregister() cleanups (Mark Langsdorf) [2178301]
- driver core: bus: bus_register/unregister() cleanups (Mark Langsdorf) [2178301]
- driver core: bus: bus_add/probe/remove_device() cleanups (Mark Langsdorf) [2178301]
- driver core: bus: sysfs function cleanups (Mark Langsdorf) [2178301]
- driver core: bus: convert bus_create/remove_file to be constant (Mark Langsdorf) [2178301]
- driver core: bus: constantify the bus_find_* functions (Mark Langsdorf) [2178301]
- driver core: bus: implement bus_get/put() without the private pointer (Mark Langsdorf) [2178301]
- driver core: add local subsys_get and subsys_put functions (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Make cycle detection more robust (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Consolidate device link flag computation (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Allow marking a fwnode link as being part of a cycle (Mark Langsdorf) [2178301]
- driver core: Add wait_for_init_devices_probe helper function (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Add DL_FLAG_CYCLE support to device links (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Improve check for fwnode with no device/driver (Mark Langsdorf) [2178301]
- driver core: fw_devlink: Don't purge child fwnode's consumer links (Mark Langsdorf) [2178301]
- drivers: base: dd: fix memory leak with using debugfs_lookup() (Mark Langsdorf) [2178301]
- drivers: base: component: fix memory leak with using debugfs_lookup() (Mark Langsdorf) [2178301]
- drivers/base: Remove CONFIG_SRCU (Mark Langsdorf) [2178301]
- devtmpfs: convert to pr_fmt (Mark Langsdorf) [2178301]
- driver core: bus: move lock_class_key into dynamic structure (Mark Langsdorf) [2178301]
- driver core: platform: simplify __platform_driver_probe() (Mark Langsdorf) [2178301]
- driver core: platform: removed unneeded variable from __platform_driver_probe() (Mark Langsdorf) [2178301]
- cacheinfo: Initialize variables in fetch_cache_info() (Mark Langsdorf) [2178301]
- regmap: apply reg_base and reg_downshift for single register ops (Mark Langsdorf) [2178301]
- driver core: soc: remove layering violation for the soc_bus (Mark Langsdorf) [2178301]
- of: device: make of_device_uevent_modalias() take a const device * (Mark Langsdorf) [2178301]
- driver core: device_get_devnode() should take a const * (Mark Langsdorf) [2178301]
- driver core: fix up missed drivers/s390/char/hmcdrv_dev.c class.devnode() conversion. (Mark Langsdorf) [2178301]
- driver core: fix up missed scsi/cxlflash class.devnode() conversion. (Mark Langsdorf) [2178301]
- driver core: fix up some missing class.devnode() conversions. (Mark Langsdorf) [2178301]
- driver core: make struct class.devnode() take a const * (Mark Langsdorf) [2178301]
- driver core: make struct device_type.devnode() take a const * (Mark Langsdorf) [2178301]
- driver core: class: Clear private pointer on registration failures (Mark Langsdorf) [2178301]
- cacheinfo: Fix shared_cpu_map to handle shared caches at different levels (Mark Langsdorf) [2178301]
- cacheinfo: Check 'cache-unified' property to count cache leaves (Mark Langsdorf) [2178301]
- arch_topology: Build cacheinfo from primary CPU (Mark Langsdorf) [2178301]
- cacheinfo: Make default acpi_get_cache_info() return an error (Mark Langsdorf) [2178301]
- ACPI: PPTT: Update acpi_find_last_cache_level() to acpi_get_cache_info() (Mark Langsdorf) [2178301]
- ACPI: PPTT: Remove acpi_find_cache_levels() (Mark Langsdorf) [2178301]
- drivers: base: transport_class: fix resource leak when transport_add_device() fails (Mark Langsdorf) [2178301]
- driver core: location: Free struct acpi_pld_info *pld before return false (Mark Langsdorf) [2178301]
- driver core: fix resource leak in device_add() (Mark Langsdorf) [2178301]
- drivers/base/memory: Fix comments for phys_index_show() (Mark Langsdorf) [2178301]
- drivers/base/memory: rename base_memory_block_id to memory_block_id (Mark Langsdorf) [2178301]
- driver core: Fix test_async_probe_init saves device in wrong array (Mark Langsdorf) [2178301]
- device property: fix of node refcount leak in fwnode_graph_get_next_endpoint() (Mark Langsdorf) [2178301]
- driver core: bus: move bus notifier logic into bus.c (Mark Langsdorf) [2178301]
- driver core: bus.h: document bus notifiers better (Mark Langsdorf) [2178301]
- cacheinfo: Return error code in init_of_cache_level() (Mark Langsdorf) [2178301]
- cacheinfo: Use RISC-V's init_cache_level() as generic OF implementation (Mark Langsdorf) [2178301]
- platform: remove useless if-branch in __platform_get_irq_byname() (Mark Langsdorf) [2178301]
- platform: Document platform_add_devices() return value (Mark Langsdorf) [2178301]
- software node: Remove unused APIs (Mark Langsdorf) [2178301]
- software node: Switch property entry test to a new API (Mark Langsdorf) [2178301]
- platform: Provide a remove callback that returns no value (Mark Langsdorf) [2178301]
- regmap: Rework regmap_mdio_c45_{read|write} for new C45 API. (Mark Langsdorf) [2178301]
- net: Convert more users of mdiobus_* to mdiodev_* (Mark Langsdorf) [2178301]
- PM: runtime: Document that force_suspend() is incompatible with SMART_SUSPEND (Mark Langsdorf) [2178301]
- cpuidle, ARM: OMAP2+: powerdomain: Remove trace_.*_rcuidle() (Mark Langsdorf) [2178301]
- driver core: fix potential null-ptr-deref in device_add() (Mark Langsdorf) [2178301]
- PM: domains: Allow a genpd consumer to require a synced power off (Mark Langsdorf) [2178301]
- driver core: move struct subsys_dev_iter to a local file (Mark Langsdorf) [2178301]
- driver core: make subsys_dev_iter_exit() static (Mark Langsdorf) [2178301]
- driver core: make subsys_dev_iter_next() static (Mark Langsdorf) [2178301]
- driver core: make subsys_dev_iter_init() static (Mark Langsdorf) [2178301]
- driver core: remove subsys_find_device_by_id() (Mark Langsdorf) [2178301]
- driver core: make bus_get_device_klist() static (Mark Langsdorf) [2178301]
- platform/mellanox: mlxbf-pmc: Fix event typo (Mark Langsdorf) [2178301]
- firmware_loader: remove #include <generated/utsrelease.h> (Mark Langsdorf) [2178301]
- PM: runtime: Adjust white space in the core code (Mark Langsdorf) [2178301]
- device property: Fix documentation for fwnode_get_next_parent() (Mark Langsdorf) [2178301]
- PM: runtime: Relocate rpm_callback() right after __rpm_callback() (Mark Langsdorf) [2178301]
- regmap: Add FSI bus support (Mark Langsdorf) [2178301]
- PM: domains: Reverse the order of performance and enabling ops (Mark Langsdorf) [2178301]
- driver core: make struct class.dev_uevent() take a const * (Mark Langsdorf) [2178301]
- driver core: change to_subsys_private() to use container_of_const() (Mark Langsdorf) [2178301]
- xen/xenbus: move to_xenbus_device() to use container_of_const() (Mark Langsdorf) [2178301]
- virtio: move dev_to_virtio() to use container_of_const() (Mark Langsdorf) [2178301]
- cacheinfo: Remove of_node_put() for fw_token (Mark Langsdorf) [2178301]
- device property: Add a blank line in Kconfig of tests (Mark Langsdorf) [2178301]
- device property: Rename goto label to be more precise (Mark Langsdorf) [2178301]
- regmap: add regmap_might_sleep() (Mark Langsdorf) [2178301]
- regmap: Add can_sleep configuration option (Mark Langsdorf) [2178301]
- regmap: Use flexible sleep (Mark Lansgdorf) [2178301]
- platform: use fwnode_irq_get_byname instead of of_irq_get_byname to get irq (Mark Langsdorf) [2178301]
- driver core: Fix bus_type.match() error handling in __driver_attach() (Mark Langsdorf) [2178301]
- driver core: Use kstrtobool() instead of strtobool() (Mark Langsdorf) [2178301]
- cacheinfo: Decrement refcount in cache_setup_of_node() (Mark Langsdorf) [2178301]
- driver core: mark driver_allows_async_probing static (Mark Langsdorf) [2178301]
- driver core: remove devm_device_remove_group() (Mark Langsdorf) [2178301]
- driver core: remove devm_device_remove_groups() (Mark Langsdorf) [2178301]
- driver core: class: make namespace and get_ownership take const * (Mark Langsdorf) [2178301]
- devres: Use kmalloc_size_roundup() to match ksize() usage (Mark Langsdorf) [2178301]
- class: fix possible memory leak in __class_register() (Mark Langsdorf) [2178301]
- PM: domains: Power off[on] domain in hibernate .freeze[thaw]_noirq hook (Mark Langsdorf) [2178301]
- PM: domains: Consolidate genpd_restore_noirq() and genpd_resume_noirq() (Mark Langsdorf) [2178301]
- PM: domains: Pass generic PM noirq hooks to genpd_finish_suspend() (Mark Langsdorf) [2178301]
- PM: domains: Drop genpd status manipulation for hibernate restore (Mark Langsdorf) [2178301]
- PM: domains: Fix handling of unavailable/disabled idle states (Mark Langsdorf) [2178301]
- device property: Fix documentation for *_match_string() APIs (Mark Langsdorf) [2178301]
- device property: Constify parameter in device_dma_supported() and device_get_dma_attr() (Mark Langsdorf) [2178301]
- device property: Constify device child node APIs (Mark Langsdorf) [2178301]
- device property: Constify fwnode connection match APIs (Mark Langsdorf) [2178301]
- device property: Allow const parameter to dev_fwnode() (Mark Langsdorf) [2178301]
- PM: domains: log failures to register always-on domains (Mark Langsdorf) [2178301]
- dt-bindings: irqchip: Describe the IMX MU block as a MSI controller (Mark Langsdorf) [2178301]
- platform-msi: Export symbol platform_msi_create_irq_domain() (Mark Langsdorf) [2178301]
- PM: runtime: Return -EINPROGRESS from rpm_resume() in the RPM_NOWAIT case (Mark Langsdorf) [2178301]
- device property: Add const qualifier to device_get_match_data() parameter (Mark Langsdorf) [2178301]
- driver core: use IS_ERR_OR_NULL() helper in device_create_groups_vargs() (Mark Langsdorf) [2178301]
- devcoredump : Serialize devcd_del work (Mark Langsdorf) [2178301]
- regmap: mmio: replace return 0 with break in switch statement (Mark Langsdorf) [2178301]
- mm: kill is_memblock_offlined() (Mark Langsdorf) [2178301]
- driver core: remove make_class_name declaration (Mark Langsdorf) [2178301]
- regmap/hexagon: Properly fix the generic IO helpers (Mark Langsdorf) [2178301]
- regmap: trace: Remove unneeded blank lines (Mark Langsdorf) [2178301]
- regmap: trace: Remove explicit castings (Mark Langsdorf) [2178301]
- regmap: trace: Remove useless check for NULL for bulk ops (Mark Langsdorf) [2178301]
- PM: wakeup: Add extra debugging statement for multiple active IRQs (Mark Langsdorf) [2178301]
- devres: Slightly optimize alloc_dr() (Mark Langsdorf) [2178301]
- drivers: base: Print error code on synthetic uevent failure (Mark Langsdorf) [2178301]
- class: use IS_ERR_OR_NULL() helper in class_unregister() (Mark Langsdorf) [2178301]
- regmap: introduce value tracing for regmap bulk operations (Mark Langsdorf) [2178301]
- regmap: mmio: Fix MMIO accessors to avoid talking to IO port (Mark Langsdorf) [2178301]
- regmap: mmio: Introduce IO accessors that can talk to IO port (Mark Langsdorf) [2178301]
- regmap: mmio: Get rid of broken 64-bit IO (Mark Langsdorf) [2178301]
- regmap: mmio: Remove mmio_relaxed member from context (Mark Langsdorf) [2178301]
- thunderbolt: Mask ring interrupt on Intel hardware as well (Desnes Nunes) [2216483]
- thunderbolt: Clear registers properly when auto clear isn't in use (Desnes Nunes) [2216483]
- dt-bindings: usb: fsa4480: Use generic node name (Desnes Nunes) [2216483]
- media: Revert "media: uvcvideo: Set unique vdev name based in type" (Desnes Nunes) [2216483]
- media: uvcvideo: Don't expose unsupported formats to userspace (Desnes Nunes) [2216483]
- usb: typec: altmodes/displayport: Fix configure initial pin assignment (Desnes Nunes) [2216483]
- xhci: Free the command allocated for setting LPM if we return early (Desnes Nunes) [2216483]
- xhci: also avoid the XHCI_ZERO_64B_REGS quirk with a passthrough iommu (Desnes Nunes) [2216483]
- USB: serial: option: add Quectel RM500U-CN modem (Desnes Nunes) [2216483]
- thunderbolt: Rename shadowed variables bit to interrupt_bit and auto_clear_bit (Desnes Nunes) [2216483]
- thunderbolt: Disable interrupt auto clear for rings (Desnes Nunes) [2216483]
- thunderbolt: Use const qualifier for `ring_interrupt_index` (Desnes Nunes) [2216483]
- uas: Add US_FL_NO_REPORT_OPCODES for JMicron JMS583Gen 2 (Desnes Nunes) [2216483]
- USB: serial: option: add Telit FE990 compositions (Desnes Nunes) [2216483]
- USB: serial: cp210x: add Silicon Labs IFS-USB-DATACABLE IDs (Desnes Nunes) [2216483]
- thunderbolt: Use scale field when allocating USB3 bandwidth (Desnes Nunes) [2216483]
- thunderbolt: Limit USB3 bandwidth of certain Intel USB4 host routers (Desnes Nunes) [2216483]
- thunderbolt: Call tb_check_quirks() after initializing adapters (Desnes Nunes) [2216483]
- thunderbolt: Add missing UNSET_INBOUND_SBTX for retimer access (Desnes Nunes) [2216483]
- thunderbolt: Fix memory leak in margining (Desnes Nunes) [2216483]
- usb: typec: tcpm: fix warning when handle discover_identity message (Desnes Nunes) [2216483]
- usb: typec: tcpm: fix create duplicate source-capabilities file (Desnes Nunes) [2216483]
- usb: ucsi_acpi: Increase the command completion timeout (Desnes Nunes) [2216483]
- usb: ucsi: Fix ucsi->connector race (Desnes Nunes) [2216483]
- usb: ucsi: Fix NULL pointer deref in ucsi_connector_change() (Desnes Nunes) [2216483]
- thunderbolt: Add quirk to disable CLx (Desnes Nunes) [2216483]
- usb: typec: pd: Add higher capability sysfs for sink PDO (Desnes Nunes) [2216483]
- usb: typec: pd: Remove usb_suspend_supported sysfs from sink PDO (Desnes Nunes) [2216483]
- xhci: host: potential NULL dereference in xhci_generic_plat_probe() (Desnes Nunes) [2216483]
- media: usb: siano: Fix warning due to null work_func_t function pointer (Desnes Nunes) [2216483]
- media: usb: siano: Fix use after free bugs caused by do_submit_urb (Desnes Nunes) [2216483]
- media: usb: dvb-usb-v2: af9015.c: return 0 instead of 'ret'. (Desnes Nunes) [2216483]
- dt-bindings: usb: convert fcs,fusb302.txt to yaml (Desnes Nunes) [2216483]
- dt-bindings: usb: fusb302: Remove deprecated properties (Desnes Nunes) [2216483]
- usb: uvc: Enumerate valid values for color matching (Desnes Nunes) [2216483]
- USB: ene_usb6250: Allocate enough memory for full object (Desnes Nunes) [2216483]
- USB: uhci: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2216483]
- USB: ULPI: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2216483]
- USB: serial: option: add support for VW/Skoda "Carstick LTE" (Desnes Nunes) [2216483]
- usb: remove the dead USB_OHCI_SH option (Desnes Nunes) [2216483]
- xhci: decouple usb2 port resume and get_port_status request handling (Desnes Nunes) [2216483]
- xhci: clear usb2 resume related variables in one place. (Desnes Nunes) [2216483]
- xhci: rename resume_done to resume_timestamp (Desnes Nunes) [2216483]
- xhci: Pass port structure as parameter to xhci_disable_port(). (Desnes Nunes) [2216483]
- xhci: move port specific items such as state completions to port structure (Desnes Nunes) [2216483]
- xhci: pass port pointer as parameter to xhci_set_port_power() (Desnes Nunes) [2216483]
- xhci: cleanup xhci_hub_control port references (Desnes Nunes) [2216483]
- xhci: add helpers for enabling and disabling interrupters (Desnes Nunes) [2216483]
- xhci: Refactor interrupter code for initial multi interrupter support. (Desnes Nunes) [2216483]
- xhci: remove xhci_test_trb_in_td_math early development check (Desnes Nunes) [2216483]
- xhci: fix event ring segment table related masks and variables in header (Desnes Nunes) [2216483]
- USB: core: Don't hold device lock while reading the "descriptors" sysfs file (Desnes Nunes) [2216483]
- usb: early: xhci-dbc: Use memcpy_and_pad() (Desnes Nunes) [2216483]
- usb: early: xhci-dbc: Optimize early_xdbc_write() (Desnes Nunes) [2216483]
- usb: early: xhci-dbc: Fix a potential out-of-bound memory access (Desnes Nunes) [2216483]
- Documentation: usb: correct spelling (Desnes Nunes) [2216483]
- docs: usb: convert documents to ReST (Desnes Nunes) [2216483]
- Documentation/usb: Fix typo (Desnes Nunes) [2216483]
- USB: serial: clean up kl5kusb105 documentation (Desnes Nunes) [2216483]
- usb: uvc: use v4l2_fill_fmtdesc instead of open coded format name (Desnes Nunes) [2216483]
- usb: uvc: make uvc_format_desc table const (Desnes Nunes) [2216483]
- usb: uvc: move uvc_fmts and uvc_format_by_guid to own compile unit (Desnes Nunes) [2216483]
- usb: uvc: move media/v4l2-uvc.h to usb/uvc.h (Desnes Nunes) [2216483]
- media: uvcvideo: Add GUID for BGRA/X 8:8:8:8 (Desnes Nunes) [2216483]
- usb: gadget: uvc: add v4l2 try_format api call (Desnes Nunes) [2216483]
- usb: gadget: uvc: add v4l2 enumeration api calls (Desnes Nunes) [2216483]
- usb: gadget: uvc: allow for application to cleanly shutdown (Desnes Nunes) [2216483]
- usb: gadget: uvc: rename function to be more consistent (Desnes Nunes) [2216483]
- usb: gadget: uvc: fix multiple opens (Desnes Nunes) [2216483]
- thunderbolt: Add missing kernel-doc comment to tb_tunnel_maximum_bandwidth() (Desnes Nunes) [2216483]
- thunderbolt: Handle bandwidth allocation mode enablement notification (Desnes Nunes) [2216483]
- xhci: split out rcar/rz support from xhci-plat.c (Desnes Nunes) [2216483]
- usb: host: xhci-rcar: Use xhci_plat_priv.quirks instead of code settings (Desnes Nunes) [2216483]
- usb: host: xhci-plat: Remove useless DMA-32 fallback configuration (Desnes Nunes) [2216483]
- usb: host: xhci-plat: Add reset support (Desnes Nunes) [2216483]
- usb: host: xhci-plat: Improve clock handling in probe() (Desnes Nunes) [2216483]
- dt-bindings: usb: Convert Marvell Orion EHCI to DT schema (Desnes Nunes) [2216483]
- dt-bindings: usb: Convert OMAP OHCI/EHCI bindings to schema (Desnes Nunes) [2216483]
- dt-bindings: usb: Convert multiple "usb-ohci" bindings to DT schema (Desnes Nunes) [2216483]
- dt-bindings: usb: generic-ohci: Document dr_mode property (Desnes Nunes) [2216483]
- dt-bindings: usb: generic-ehci: Document dr_mode property (Desnes Nunes) [2216483]
- dt-bindings: ehci/ohci: Allow iommus property (Desnes Nunes) [2216483]
- dt-bindings: usb: generic-ohci: Add missing compatible strings (Desnes Nunes) [2216483]
- dt-bindings: usb: generic-ehci: Add missing compatible strings (Desnes Nunes) [2216483]
- dt-bindings: Fix incorrect 'reg' property sizes (Desnes Nunes) [2216483]
- dt-bindings: usb: ehci: Add missing 2nd register region (Desnes Nunes) [2216483]
- usb: typec: tcpm: Remove altmode active state updates (Desnes Nunes) [2216483]
- usb: typec: altmodes/displayport: Update active state (Desnes Nunes) [2216483]
- usb: typec: mux: Introduce GPIO-based SBU mux (Desnes Nunes) [2216483]
- redhat: configs: Add unset CONFIG_TYPEC_MUX_GPIO_SBU option (Desnes Nunes) [2216483]
- usb: typec: mux: Add On Semi fsa4480 driver (Desnes Nunes) [2216483]
- dt-bindings: usb: Add binding for fcs,fsa4480 (Desnes Nunes) [2216483]
- dt-bindings: usb: Introduce GPIO-based SBU mux (Desnes Nunes) [2216483]
- usb: host: ehci-fsl: Use DRV_NAME (Desnes Nunes) [2216483]
- usb: typec: maxim_contaminant: Implement check_contaminant callback (Desnes Nunes) [2216483]
- usb: typec: tcpci: Add callback for evaluating contaminant presence (Desnes Nunes) [2216483]
- usb: typec: tcpm: Add callbacks to mitigate wakeups due to contaminant (Desnes Nunes) [2216483]
- usb: typec: Make bus switch code retimer-aware (Desnes Nunes) [2216483]
- usb: typec: retimer: Use device type for matching (Desnes Nunes) [2216483]
- usb: typec: Add wrapper for bus switch set code (Desnes Nunes) [2216483]
- usb: typec: Add retimer handle to port altmode (Desnes Nunes) [2216483]
- usb: typec: tipd: Support wakeup (Desnes Nunes) [2216483]
- dt-bindings: usb: tps6598x: Add wakeup property (Desnes Nunes) [2216483]
- USB: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2216483]
- usb: typec: intel_pmc_mux: Deduplicate ACPI matching in probe (Desnes Nunes) [2216483]
- usb: typec: intel_pmc_mux: Don't leak the ACPI device reference count (Desnes Nunes) [2216483]
- usb: typec: tcpci: Request IRQ with IRQF_SHARED (Desnes Nunes) [2216483]
- USB: Improve usb_fill_* documentation (Desnes Nunes) [2216483]
- usb: typec: hd3ss3220: Add polling support (Desnes Nunes) [2216483]
- dt-bindings: usb: ti,hd3ss3220: Update interrupt property as optional (Desnes Nunes) [2216483]
- dt-bindings: usb: convert ti,hd3ss3220 bindings to json-schema (Desnes Nunes) [2216483]
- dt-bindings: Convert usb-connector to YAML format. (Desnes Nunes) [2216483]
- dt-bindings: usb: rt1711h: Add connector bindings (Desnes Nunes) [2216483]
- dt-bindings: usb: hd3ss3220 device tree binding document (Desnes Nunes) [2216483]
- thunderbolt: Add support for DisplayPort bandwidth allocation mode (Desnes Nunes) [2216483]
- thunderbolt: Include the additional DP IN double word in debugfs dump (Desnes Nunes) [2216483]
- thunderbolt: Add functions to support DisplayPort bandwidth allocation mode (Desnes Nunes) [2216483]
- thunderbolt: Increase timeout of DP OUT adapter handshake (Desnes Nunes) [2216483]
- thunderbolt: Take CL states into account when waiting for link to come up (Desnes Nunes) [2216483]
- thunderbolt: Improve debug logging in tb_available_bandwidth() (Desnes Nunes) [2216483]
- thunderbolt: Log DP adapter type (Desnes Nunes) [2216483]
- thunderbolt: Use decimal port number in control and tunnel logs too (Desnes Nunes) [2216483]
- media: uvcvideo: Silence memcpy() run-time false positive warnings (Desnes Nunes) [2216483]
- media: uvcvideo: Quirk for autosuspend in Logitech B910 and C910 (Desnes Nunes) [2216483]
- media: uvcvideo: Fix race condition with usb_kill_urb (Desnes Nunes) [2216483]
- media: uvcvideo: Use standard names for menus (Desnes Nunes) [2216483]
- media: uvcvideo: Fix power line control for Lenovo Integrated Camera (Desnes Nunes) [2216483]
- media: uvcvideo: Add a quirk to force GEO GC6500 Camera bits-per-pixel value (Desnes Nunes) [2216483]
- media: v4l: common: Fix naming of v4l2_get_link_rate (Desnes Nunes) [2216483]
- media: ipu3-cio2: Use v4l2_get_link_freq helper (Desnes Nunes) [2216483]
- media: ipu3-cio2: Update Copyright year and fix indentation issues (Desnes Nunes) [2216483]
- media: v4l: Add a helper for obtaining the link frequency (Desnes Nunes) [2216483]
- media: v4l2-common: add RGB565 and RGB55 to v4l2_format_info (Desnes Nunes) [2216483]
- media: v4l2-common: add pixel encoding support (Desnes Nunes) [2216483]
- media: v4l2-common: add support for new RGB32 pixelformats (Desnes Nunes) [2216483]
- media: v4l2-common: add bayer formats in v4l2_format_info (Desnes Nunes) [2216483]
- media: v4l2-common: Add an helper to apply frmsize constraints (Desnes Nunes) [2216483]
- media: v4l2-common: Fix v4l2_fill_pixfmt[_mp]() prototypes (Desnes Nunes) [2216483]
- media: Introduce helpers to fill pixel format structs (Desnes Nunes) [2216483]
- media: uvcvideo: Refactor power_line_frequency_controls_limited (Desnes Nunes) [2216483]
- media: uvcvideo: Refactor uvc_ctrl_mappings_uvcXX (Desnes Nunes) [2216483]
- media: uvcvideo: Implement mask for V4L2_CTRL_TYPE_MENU (Desnes Nunes) [2216483]
- media: uvcvideo: Extend documentation of uvc_video_clock_decode() (Desnes Nunes) [2216483]
- media: uvcvideo: Refactor __uvc_ctrl_add_mapping (Desnes Nunes) [2216483]
- media: uvcvideo: Undup use uvc_endpoint_max_bpi() code (Desnes Nunes) [2216483]
- media: uvcvideo: Simplify uvc_endpoint_max_bpi() (Desnes Nunes) [2216483]
- media: uvcvideo: Fix memory leak if uvc_ctrl_add_mapping fails (Desnes Nunes) [2216483]
- media: uvcvideo: Avoid returning invalid controls (Desnes Nunes) [2216483]
- media: uvcvideo: Avoid invalid memory access (Desnes Nunes) [2216483]
- media: uvcvideo: Set the colorspace as sRGB if undefined (Desnes Nunes) [2216483]
- media: uvcvideo: Fix memory leak of object map on error exit path (Desnes Nunes) [2216483]
- media: uvcvideo: Fix handling on Bitmask controls (Desnes Nunes) [2216483]
- media: uvcvideo: Do not return positive errors in uvc_query_ctrl() (Desnes Nunes) [2216483]
- media: uvcvideo: Return -EACCES for Wrong state error (Desnes Nunes) [2216483]
- media: uvcvideo: Improve error logging in uvc_query_ctrl() (Desnes Nunes) [2216483]
- media: uvcvideo: Check for INACTIVE in uvc_ctrl_is_accessible() (Desnes Nunes) [2216483]
- media: uvcvideo: Factor out usb_string() calls (Desnes Nunes) [2216483]
- media: uvcvideo: Limit power line control for Acer EasyCamera (Desnes Nunes) [2216483]
- media: uvcvideo: Recover stalled ElGato devices (Desnes Nunes) [2216483]
- media: uvcvideo: Remove void casting for the status endpoint (Desnes Nunes) [2216483]
- media: uvcvideo: Increase UVC_CTRL_CONTROL_TIMEOUT to 5 seconds. (Desnes Nunes) [2216483]
- media: uvcvideo: Fix usage of symbolic permissions to octal (Desnes Nunes) [2216483]
- media: uvcvideo: Fix assignment inside if condition (Desnes Nunes) [2216483]
- media: uvcvideo: Fix missing newline after declarations (Desnes Nunes) [2216483]
- media: uvcvideo: Handle errors from calls to usb_string (Desnes Nunes) [2216483]
- media: uvcvideo: Only create input devs if hw supports it (Desnes Nunes) [2216483]
- media: uvcvideo: Handle cameras with invalid descriptors (Desnes Nunes) [2216483]
- media: uvcvideo: Remove format descriptions (Desnes Nunes) [2216483]
- media: docs: Document the behaviour of uvcvideo driver (Desnes Nunes) [2216483]
- media: uvcvideo: Set error_idx during ctrl_commit errors (Desnes Nunes) [2216483]
- media: uvcvideo: Check controls flags before accessing them (Desnes Nunes) [2216483]
- media: uvcvideo: Use control names from framework (Desnes Nunes) [2216483]
- media: uvcvideo: Set unique vdev name based in type (Desnes Nunes) [2216483]
- media: uvcvideo: Use dev->name for querycap() (Desnes Nunes) [2216483]
- media: uvcvideo: Add support for V4L2_CTRL_TYPE_CTRL_CLASS (Desnes Nunes) [2216483]
- media: uvcvideo: Set capability in s_param (Desnes Nunes) [2216483]
- media: uvcvideo: Remove s_ctrl and g_ctrl (Desnes Nunes) [2216483]
- media: v4l2-ioctl: S_CTRL output the right value (Desnes Nunes) [2216483]
- media: uvcvideo: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Desnes Nunes) [2216483]
- media: pvrusb2: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Desnes Nunes) [2216483]
- media: v4l2-ioctl: Fix check_ext_ctrls (Desnes Nunes) [2216483]
- net: thunderbolt: Add tracepoints (Desnes Nunes) [2216483]
- net: thunderbolt: Add debugging when sending/receiving control packets (Desnes Nunes) [2216483]
- net: thunderbolt: Move into own directory (Desnes Nunes) [2216483]
- xhci: Convert to use list_count_nodes() (Desnes Nunes) [2216483]
- usb: typec: ucsi: Register USB Power Delivery Capabilities (Desnes Nunes) [2216483]
- xhci: Add hub_control to xhci_driver_overrides (Desnes Nunes) [2216483]
- xhci: hub: export symbol on xhci_hub_control (Desnes Nunes) [2216483]
- usb: typec: altmodes/displayport: Add hpd sysfs attribute (Desnes Nunes) [2216483]
- usb: typec: altmodes/displayport: Notify drm subsys of (Desnes Nunes) [2216483]
- usb: typec: altmodes/displayport: Make dp_altmode_notify() more generic (Desnes Nunes) [2216483]
- thunderbolt: Refactor tb_acpi_add_link() (Desnes Nunes) [2216483]
- thunderbolt: Use correct type in tb_port_is_clx_enabled() prototype (Desnes Nunes) [2216483]

* Sun Jul 16 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-503.el8]
- s390/diag: fix display of diagnose call statistics (Tobias Huschle) [2187995]
- rseq, ptrace: Add PTRACE_GET_RSEQ_CONFIGURATION request (Adrian Reber) [2218454]
- locking/rwbase: Mitigate indefinite writer starvation (Eder Zulian) [2077282]
- fbcon: Check font dimension limits (Ricardo Robaina) [2213493] {CVE-2023-3161}
- libnvdimm: Notify disk drivers to revalidate region read-only (Jeff Moyer) [1999673]
- nvdimm/region: always show the 'align' attribute (Jeff Moyer) [1999673]
- nvdimm/region: Fix default alignment for small regions (Jeff Moyer) [1999673]
- libnvdimm/region: Allow setting align attribute on regions without mappings (Jeff Moyer) [1999673]
- KVM: SVM: Return the local "r" variable from svm_set_msr() (Emanuele Giuseppe Esposito) [2124598]
- KVM: x86: Virtualize FLUSH_L1D and passthrough MSR_IA32_FLUSH_CMD (Emanuele Giuseppe Esposito) [2124598]
- KVM: x86: Move MSR_IA32_PRED_CMD WRMSR emulation to common code (Emanuele Giuseppe Esposito) [2124598]
- KVM: SVM: Passthrough MSR_IA32_PRED_CMD based purely on host+guest CPUID (Emanuele Giuseppe Esposito) [2124598]
- KVM: VMX: Passthrough MSR_IA32_PRED_CMD based purely on host+guest CPUID (Emanuele Giuseppe Esposito) [2124598]
- KVM: x86: Revert MSR_IA32_FLUSH_CMD.FLUSH_L1D enabling (Emanuele Giuseppe Esposito) [2124598]
- kvm: x86: Advertise FLUSH_L1D to user space (Emanuele Giuseppe Esposito) [2124598]
- kvm: svm: Add IA32_FLUSH_CMD guest support (Emanuele Giuseppe Esposito) [2124598]
- kvm: vmx: Add IA32_FLUSH_CMD guest support (Emanuele Giuseppe Esposito) [2124598]
- rtc: lib_test: add MODULE_LICENSE (Lenny Szubowicz) [2207975]
- rtc: efi: Remove the repeated module alias (Lenny Szubowicz) [2207975]
- efi/efivars: Set generic ops before loading SSDT (Lenny Szubowicz) [2207975]
- efi: efibc: check for efivars write capability (Lenny Szubowicz) [2207975]
- efi/efivars: Expose RT service availability via efivars abstraction (Lenny Szubowicz) [2207975]
- integrity: Check properly whether EFI GetVariable() is available (Lenny Szubowicz) [2207975]
- x86/ima: Use EFI GetVariable only when available (Lenny Szubowicz) [2207975]
- efi: Use EFI ResetSystem only when available (Lenny Szubowicz) [2207975]
- scsi: iscsi: Use EFI GetVariable only when available (Lenny Szubowicz) [2207975]
- infiniband: hfi1: Use EFI GetVariable only when available (Lenny Szubowicz) [2207975]
- efi: Register EFI rtc platform device only when available (Lenny Szubowicz) [2207975]
- efi: Use more granular check for availability for variable services (Lenny Szubowicz) [2207975]
- efi: mark all efi runtime services as unsupported on non-efi boot (Lenny Szubowicz) [2207975]
- efi: Add support for EFI_RT_PROPERTIES table (Lenny Szubowicz) [2207975]
- crypto: ccp - Add support for PCI device 0x156E (Vladis Dronov) [2180960]
- crypto: ccp - Add support for PCI device 0x17E0 (Vladis Dronov) [2180960]
- crypto: ccp - Validate that platform access mailbox registers are declared (Vladis Dronov) [2180960]
- crypto: ccp - Use lower 8 bytes to communicate with doorbell command register (Vladis Dronov) [2180960]
- crypto: ccp - Return doorbell status code as an argument (Vladis Dronov) [2180960]
- crypto: ccp - Bump up doorbell debug message to error (Vladis Dronov) [2180960]
- crypto: ccp - Drop extra doorbell checks (Vladis Dronov) [2180960]
- crypto: ccp - Don't initialize CCP for PSP 0x1649 (Vladis Dronov) [2180960]
- crypto: ccp - Clear PSP interrupt status register before calling handler (Vladis Dronov) [2180960]
- crypto: ccp - Add support for ringing a platform doorbell (Vladis Dronov) [2180960]
- crypto: ccp - Enable platform access interface on client PSP parts (Vladis Dronov) [2180960]
- crypto: ccp - Add support for an interface for platform features (Vladis Dronov) [2180960]
- crypto: ccp - Move some PSP mailbox bit definitions into common header (Vladis Dronov) [2180960]
- crypto: ccp - Add a header for multiple drivers to use `__psp_pa` (Vladis Dronov) [2180960]
- crypto: ccp - Drop TEE support for IRQ handler (Vladis Dronov) [2180960]
- crypto: ccp: Get rid of __sev_platform_init_locked()'s local function pointer (Vladis Dronov) [2180960]
- crypto: ccp - Name -1 return value as SEV_RET_NO_FW_CALL (Vladis Dronov) [2180960]
- crypto: ccp - Flush the SEV-ES TMR memory before giving it to firmware (Vladis Dronov) [2180960]
- crypto: ccp - Add a firmware definition for EPYC gen 4 processors (Vladis Dronov) [2180960]
- crypto: ccp - Provide MMIO register naming for documenation (Vladis Dronov) [2180960]
- redhat/configs: enable CONFIG_INTEL_UNCORE_FREQ_CONTROL for x86_64 (David Arcari) [2156826]
- platform/x86/intel-uncore-freq: Return error on write frequency (David Arcari) [2156826]
- platform/x86: intel-uncore-freq: Add client processors (David Arcari) [2156826]
- platform/x86: intel-uncore-freq: add Emerald Rapids support (David Arcari) [2156826]
- platform/x86: intel-uncore-freq: Use sysfs_emit() to instead of scnprintf() (David Arcari) [2156826]
- platform/x86: intel-uncore-freq: Prevent driver loading in guests (David Arcari) [2156826]
- platform/x86: intel-uncore-freq: fix uncore_freq_common_init() error codes (David Arcari) [2156826]
- platform/x86/intel-uncore-freq: Split common and enumeration part (David Arcari) [2156826]
- platform/x86/intel/uncore-freq: Display uncore current frequency (David Arcari) [2156826]
- platform/x86/intel/uncore-freq: Use sysfs API to create attributes (David Arcari) [2156826]
- platform/x86/intel/uncore-freq: Move to uncore-frequency folder (David Arcari) [2156826]
- platform/x86: intel-uncore-frequency: use default_groups in kobj_type (David Arcari) [2156826]
- platform/x86: intel-uncore-frequency: Move to intel sub-directory (David Arcari) [2156826]
- platform/x86/intel-uncore-freq: Add Sapphire Rapids server support (David Arcari) [2156826]
- platform/x86/intel-uncore-freq: make uncore_root_kobj static (David Arcari) [2156826]
- platform/x86: Convert to new CPU match macros (David Arcari) [2156826]
- platform/x86/intel-uncore-freq: Add release callback (David Arcari) [2156826]
- platform/x86/intel-uncore-freq: Fix static checker issue and potential race condition (David Arcari) [2156826]
- MAINTAINERS: Update for the intel uncore frequency control (David Arcari) [2156826]
- platform/x86: Add support for Uncore frequency control (David Arcari) [2156826]

* Tue Jul 11 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-502.el8]
- ceph: fix use-after-free bug for inodes when flushing capsnaps (Xiubo Li) [2209299]
- net/tls: tls_is_tx_ready() checked list_entry (Sabrina Dubroca) [2212176] {CVE-2023-1075}
- Revert "RDMA/umem: remove FOLL_FORCE usage" (Kamal Heib) [2210153 2210849]
- Revert "RDMA/core: Refactor rdma_bind_addr" (Kamal Heib) [2212211 2212217]
- cpufreq: intel_pstate: Fix scaling for hybrid-capable systems with disabled E-cores (David Arcari) [2221276]
- netfilter: nf_tables: fix scheduling-while-atomic splat (Phil Sutter) [2217731]
- netfilter: nf_tables: add rescheduling points during loop detection walks (Phil Sutter) [2217731]
- ipv6: Remove dependency of ipv6_frag_thdr_truncated on ipv6 module (Phil Sutter) [2217794]
- ipv6/netfilter: Discard first fragment not including all headers (Phil Sutter) [2217794]
- s390/ipl: add eckd dump support (Tobias Huschle) [2159695]
- net/smc: fix document build WARNING from smc-sysctl.rst (Tobias Huschle) [2159734]
- s390/ism: switch from 'pci_' to 'dma_' API (Tobias Huschle) [2159734]
- net/smc: Fix device de-init sequence (Tobias Huschle) [2159734]
- net/smc: fix deadlock triggered by cancel_delayed_work_syn() (Tobias Huschle) [2159734]
- net/smc: fix NULL sndbuf_desc in smc_cdc_tx_handler() (Tobias Huschle) [2159734]
- net/smc: fix fallback failed while sendmsg with fastopen (Tobias Huschle) [2159734]
- net/smc: fix application data exception (Tobias Huschle) [2159734]
- net/smc: replace mutex rmbs_lock and sndbufs_lock with rw_semaphore (Tobias Huschle) [2159734]
- net/smc: reduce unnecessary blocking in smcr_lgr_reg_rmbs() (Tobias Huschle) [2159734]
- net/smc: use read semaphores to reduce unnecessary blocking in smc_buf_create() & smcr_buf_unuse() (Tobias Huschle) [2159734]
- net/smc: llc_conf_mutex refactor, replace it with rw_semaphore (Tobias Huschle) [2159734]
- net: add missing includes of linux/splice.h (Tobias Huschle) [2159734]
- net/smc: De-tangle ism and smc device initialization (Tobias Huschle) [2159734]
- s390/ism: Consolidate SMC-D-related code (Tobias Huschle) [2159734]
- net/smc: Separate SMC-D and ISM APIs (Tobias Huschle) [2159734]
- net/smc: Register SMC-D as ISM client (Tobias Huschle) [2159734]
- net/ism: Add new API for client registration (Tobias Huschle) [2159734]
- s390/ism: Introduce struct ism_dmb (Tobias Huschle) [2159734]
- net/ism: Add missing calls to disable bus-mastering (Tobias Huschle) [2159734]
- net/smc: Terminate connections prior to device removal (Tobias Huschle) [2159734]
- net/smc: Fix possible leaked pernet namespace in smc_init() (Tobias Huschle) [2159734]
- net/smc: Fix an error code in smc_lgr_create() (Tobias Huschle) [2159734]
- net/smc: Support SO_REUSEPORT (Tobias Huschle) [2159734]
- net/smc: Introduce a specific sysctl for TEST_LINK time (Tobias Huschle) [2159734]
- net/smc: Stop the CLC flow if no link to map buffers on (Tobias Huschle) [2159734]
- net/smc: Fix possible access to freed memory in link clear (Tobias Huschle) [2159734]
- net/smc: Remove redundant refcount increase (Tobias Huschle) [2159734]
- net/smc: Enable module load on netlink usage (Tobias Huschle) [2159734]
- net/smc: Pass on DMBE bit mask in IRQ handler (Tobias Huschle) [2159734]
- s390/ism: Cleanups (Tobias Huschle) [2159734]
- net/smc: Eliminate struct smc_ism_position (Tobias Huschle) [2159734]
- tcp: Fix data-races around keepalive sysctl knobs. (Tobias Huschle) [2159734]
- net/smc: Extend SMC-R link group netlink attribute (Tobias Huschle) [2159734]
- net/smc: Allow virtually contiguous sndbufs or RMBs for SMC-R (Tobias Huschle) [2159734]
- net/smc: Use sysctl-specified types of buffers in new link group (Tobias Huschle) [2159734]
- net/smc: Introduce a sysctl for setting SMC-R buffer type (Tobias Huschle) [2159734]
- net/smc: optimize for smc_sndbuf_sync_sg_for_device and smc_rmb_sync_sg_for_cpu (Tobias Huschle) [2159734]
- net/smc: remove redundant dma sync ops (Tobias Huschle) [2159734]
- net/smc: fixes for converting from "struct smc_cdc_tx_pend **" to "struct smc_wr_tx_pend_priv *" (Tobias Huschle) [2159734]
- net/smc: set ini->smcrv2.ib_dev_v2 to NULL if SMC-Rv2 is unavailable (Tobias Huschle) [2159734]
- net/smc: postpone sk_refcnt increment in connect() (Tobias Huschle) [2159734]
- net/smc: rdma write inline if qp has sufficient inline space (Tobias Huschle) [2159734]
- net/smc: send cdc msg inline if qp has sufficient inline space (Tobias Huschle) [2159734]
- net/smc: align the connect behaviour with TCP (Tobias Huschle) [2159734]
- net/smc: non blocking recvmsg() return -EAGAIN when no data and signal_pending (Tobias Huschle) [2159734]
- net/smc: Fix slab-out-of-bounds issue in fallback (Tobias Huschle) [2159734]
- net/smc: Only save the original clcsock callback functions (Tobias Huschle) [2159734]
- net/smc: sync err code when tcp connection was refused (Tobias Huschle) [2159734]
- net/smc: Fix sock leak when release after smc_shutdown() (Tobias Huschle) [2159734]
- net/smc: Send out the remaining data in sndbuf before close (Tobias Huschle) [2159734]
- net/smc: fix a memory leak in smc_sysctl_net_exit() (Tobias Huschle) [2159734]
- net/smc: fix -Wmissing-prototypes warning when CONFIG_SYSCTL not set (Tobias Huschle) [2159734]
- net/smc: fix compile warning for smc_sysctl (Tobias Huschle) [2159734]
- net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error cause by server (Tobias Huschle) [2159734]
- net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error generated by client (Tobias Huschle) [2159734]
- net: smc: fix different types in min() (Tobias Huschle) [2159734]
- net/smc: don't send in the BH context if sock_owned_by_user (Tobias Huschle) [2159734]
- net/smc: correct settings of RMB window update limit (Tobias Huschle) [2159734]
- net/smc: send directly on setting TCP_NODELAY (Tobias Huschle) [2159734]
- net/smc: add sysctl for autocorking (Tobias Huschle) [2159734]
- net/smc: add autocorking support (Tobias Huschle) [2159734]
- net/smc: add sysctl interface for SMC (Tobias Huschle) [2159734]
- x86/resctrl: Clear staged_config[] before and after it is used (Prarit Bhargava) [1989284]
- x86/resctl: fix scheduler confusion with 'current' (Prarit Bhargava) [1989284]
- x86/resctrl: Fix a silly -Wunused-but-set-variable warning (Prarit Bhargava) [1989284]
- x86/resctrl: Add interface to write mbm_local_bytes_config (Prarit Bhargava) [1989284]
- x86/resctrl: Add interface to write mbm_total_bytes_config (Prarit Bhargava) [1989284]
- x86/resctrl: Add interface to read mbm_local_bytes_config (Prarit Bhargava) [1989284]
- x86/resctrl: Add interface to read mbm_total_bytes_config (Prarit Bhargava) [1989284]
- x86/resctrl: Support monitor configuration (Prarit Bhargava) [1989284]
- x86/resctrl: Add __init attribute to rdt_get_mon_l3_config() (Prarit Bhargava) [1989284]
- x86/resctrl: Detect and configure Slow Memory Bandwidth Allocation (Prarit Bhargava) [1989284]
- x86/cpufeatures: Add Bandwidth Monitoring Event Configuration feature flag (Prarit Bhargava) [1989284]
- x86/cpufeatures: Add Slow Memory Bandwidth Allocation feature flag (Prarit Bhargava) [1989284]
- x86/resctrl: Include new features in command line options (Prarit Bhargava) [1989284]
- x86/resctrl: Add a new resource type RDT_RESOURCE_SMBA (Prarit Bhargava) [1989284]
- x86/resctrl: Replace smp_call_function_many() with on_each_cpu_mask() (Prarit Bhargava) [1989284]
- x86/resctrl: Fix event counts regression in reused RMIDs (Prarit Bhargava) [1989284]
- x86/resctrl: Fix task CLOSID/RMID update race (Prarit Bhargava) [1989284]
- x86/resctrl: Move MSR defines into msr-index.h (Prarit Bhargava) [1989284]
- x86/resctrl: Remove arch_has_empty_bitmaps (Prarit Bhargava) [1989284]
- x86/resctrl: Fix min_cbm_bits for AMD (Prarit Bhargava) [1989284]
- x86/resctrl: Make resctrl_arch_rmid_read() return values in bytes (Prarit Bhargava) [1989284]
- x86/resctrl: Add resctrl_rmid_realloc_limit to abstract x86's boot_cpu_data (Prarit Bhargava) [1989284]
- x86/resctrl: Rename and change the units of resctrl_cqm_threshold (Prarit Bhargava) [1989284]
- x86/resctrl: Move get_corrected_mbm_count() into resctrl_arch_rmid_read() (Prarit Bhargava) [1989284]
- x86/resctrl: Move mbm_overflow_count() into resctrl_arch_rmid_read() (Prarit Bhargava) [1989284]
- x86/resctrl: Pass the required parameters into resctrl_arch_rmid_read() (Prarit Bhargava) [1989284]
- x86/resctrl: Abstract __rmid_read() (Prarit Bhargava) [1989284]
- x86/resctrl: Allow per-rmid arch private storage to be reset (Prarit Bhargava) [1989284]
- x86/resctrl: Add per-rmid arch private storage for overflow and chunks (Prarit Bhargava) [1989284]
- x86/resctrl: Calculate bandwidth from the previous __mon_event_count() chunks (Prarit Bhargava) [1989284]
- x86/resctrl: Allow update_mba_bw() to update controls directly (Prarit Bhargava) [1989284]
- x86/resctrl: Remove architecture copy of mbps_val (Prarit Bhargava) [1989284]
- x86/resctrl: Switch over to the resctrl mbps_val list (Prarit Bhargava) [1989284]
- x86/resctrl: Create mba_sc configuration in the rdt_domain (Prarit Bhargava) [1989284]
- x86/resctrl: Abstract and use supports_mba_mbps() (Prarit Bhargava) [1989284]
- x86/resctrl: Remove set_mba_sc()s control array re-initialisation (Prarit Bhargava) [1989284]
- x86/resctrl: Add domain offline callback for resctrl work (Prarit Bhargava) [1989284]
- x86/resctrl: Group struct rdt_hw_domain cleanup (Prarit Bhargava) [1989284]
- x86/resctrl: Add domain online callback for resctrl work (Prarit Bhargava) [1989284]
- x86/resctrl: Merge mon_capable and mon_enabled (Prarit Bhargava) [1989284]
- x86/resctrl: Kill off alloc_enabled (Prarit Bhargava) [1989284]
- x86/resctrl: Fix to restore to original value when re-enabling hardware prefetch register (Prarit Bhargava) [1989284]
- x86: Replace cpumask_weight() with cpumask_empty() where appropriate (Prarit Bhargava) [1989284]
- x86/resctrl: Remove redundant assignment to variable chunks (Prarit Bhargava) [1989284]
- x86/resctrl: Fix kfree() of the wrong type in domain_add_cpu() (Prarit Bhargava) [1989284]
- x86/resctrl: Free the ctrlval arrays when domain_setup_mon_state() fails (Prarit Bhargava) [1989284]
- x86/resctrl: Make resctrl_arch_get_config() return its value (Prarit Bhargava) [1989284]
- x86/resctrl: Merge the CDP resources (Prarit Bhargava) [1989284]
- x86/resctrl: Expand resctrl_arch_update_domains()'s msr_param range (Prarit Bhargava) [1989284]
- x86/resctrl: Remove rdt_cdp_peer_get() (Prarit Bhargava) [1989284]
- x86/resctrl: Merge the ctrl_val arrays (Prarit Bhargava) [1989284]
- x86/resctrl: Calculate the index from the configuration type (Prarit Bhargava) [1989284]
- x86/resctrl: Apply offset correction when config is staged (Prarit Bhargava) [1989284]
- x86/resctrl: Make ctrlval arrays the same size (Prarit Bhargava) [1989284]
- x86/resctrl: Pass configuration type to resctrl_arch_get_config() (Prarit Bhargava) [1989284]
- x86/resctrl: Add a helper to read a closid's configuration (Prarit Bhargava) [1989284]
- x86/resctrl: Rename update_domains() to resctrl_arch_update_domains() (Prarit Bhargava) [1989284]
- x86/resctrl: Allow different CODE/DATA configurations to be staged (Prarit Bhargava) [1989284]
- x86/resctrl: Group staged configuration into a separate struct (Prarit Bhargava) [1989284]
- x86/resctrl: Move the schemata names into struct resctrl_schema (Prarit Bhargava) [1989284]
- x86/resctrl: Add a helper to read/set the CDP configuration (Prarit Bhargava) [1989284]
- x86/resctrl: Swizzle rdt_resource and resctrl_schema in pseudo_lock_region (Prarit Bhargava) [1989284]
- x86/resctrl: Pass the schema to resctrl filesystem functions (Prarit Bhargava) [1989284]
- x86/resctrl: Add resctrl_arch_get_num_closid() (Prarit Bhargava) [1989284]
- x86/resctrl: Store the effective num_closid in the schema (Prarit Bhargava) [1989284]
- x86/resctrl: Walk the resctrl schema list instead of an arch list (Prarit Bhargava) [1989284]
- x86/resctrl: Label the resources with their configuration type (Prarit Bhargava) [1989284]
- x86/resctrl: Pass the schema in info dir's private pointer (Prarit Bhargava) [1989284]
- x86/resctrl: Add a separate schema list for resctrl (Prarit Bhargava) [1989284]
- x86/resctrl: Split struct rdt_domain (Prarit Bhargava) [1989284]
- x86/resctrl: Split struct rdt_resource (Prarit Bhargava) [1989284]
- x86/resctrl: Include pid.h (Prarit Bhargava) [1989284]
- x86/resctrl: Fix kernel-doc in internal.h (Prarit Bhargava) [1989284]
- x86/resctrl: Fix kernel-doc in pseudo_lock.c (Prarit Bhargava) [1989284]
- x86/resctrl: Fix init const confusion (Prarit Bhargava) [1989284]
- x86/resctrl: Fix various typos in comments, take #2 (Prarit Bhargava) [1989284]
- x86/resctrl: Fix various typos in comments (Prarit Bhargava) [1989284]
- x86/resctrl: Apply READ_ONCE/WRITE_ONCE to task_struct.{rmid,closid} (Prarit Bhargava) [1989284]
- x86/resctrl: Use task_curr() instead of task_struct->on_cpu to prevent unnecessary IPI (Prarit Bhargava) [1989284]
- x86/resctrl: Add printf attribute to log function (Prarit Bhargava) [1989284]
- x86/resctrl: Don't move a task to the same resource group (Prarit Bhargava) [1989284]
- x86/resctrl: Use an IPI instead of task_work_add() to update PQR_ASSOC MSR (Prarit Bhargava) [1989284]
- x86/resctrl: Fix incorrect local bandwidth when mba_sc is enabled (Prarit Bhargava) [1989284]
- x86/resctrl: Clean up unused function parameter in rmdir path (Prarit Bhargava) [1989284]
- x86/resctrl: Add necessary kernfs_put() calls to prevent refcount leak (Prarit Bhargava) [1989284]
- x86/resctrl: Remove superfluous kernfs_get() calls to prevent refcount leak (Prarit Bhargava) [1989284]
- x86/resctrl: Constify kernfs_ops (Prarit Bhargava) [1989284]
- x86/resctrl: Correct MBM total and local values (Prarit Bhargava) [1989284]
- x86/include/asm/msr-index.h: Add IFS Array test bits (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Update IFS doc (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Implement Array BIST test (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Sysfs interface for Array BIST (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Introduce Array Scan test to IFS (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: IFS cleanup (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Reorganize driver data (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Separate ifs_pkg_auth from ifs_data (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add missing kernel-doc entry (Prarit Bhargava) [1971937]
- Revert "platform/x86/intel/ifs: Mark as BROKEN" (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add current_batch sysfs entry (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Remove reload sysfs entry (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add metadata validation (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Use generic microcode headers and functions (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add metadata support (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Remove memory allocation from load path (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Remove image loading during init (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Return a more appropriate error code (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Remove unused selection (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Mark as BROKEN (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add CPU_SUP_INTEL dependency (Prarit Bhargava) [1971937]
- Documentation: In-Field Scan (Prarit Bhargava) [1971937]
- redhat/configs: Add CONFIG_INTEL_IFS (Prarit Bhargava) [1971937]
- redhat/configs: Add CONFIG_MICROCODE_LATE_LOADING (Prarit Bhargava) [1971937]
- stop_machine: Add stop_core_cpuslocked() for per-core operations (Prarit Bhargava) [1971937]
- trace: platform/x86/intel/ifs: Add trace point to track Intel IFS operations (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add IFS sysfs interface (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add scan test support (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Authenticate and copy to secured memory (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Check IFS Image sanity (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Read IFS firmware image (Prarit Bhargava) [1971937]
- platform/x86/intel/ifs: Add stub driver for In-Field Scan (Prarit Bhargava) [1971937]
- x86/msr-index: Define INTEGRITY_CAPABILITIES MSR (Prarit Bhargava) [1971937]
- x86/microcode/core: Return an error only when necessary (Prarit Bhargava) [1971937]
- x86/microcode/AMD: Fix mixed steppings support (Prarit Bhargava) [1971937]
- x86/microcode/AMD: Add a @cpu parameter to the reloading functions (Prarit Bhargava) [1971937]
- x86/microcode/amd: Remove load_microcode_amd()'s bsp parameter (Prarit Bhargava) [1971937]
- x86/microcode: Allow only "1" as a late reload trigger value (Prarit Bhargava) [1971937]
- x86/microcode/intel: Print old and new revision during early boot (Prarit Bhargava) [1971937]
- x86/microcode/intel: Pass the microcode revision to print_ucode_info() directly (Prarit Bhargava) [1971937]
- x86/microcode: Adjust late loading result reporting message (Prarit Bhargava) [1971937]
- x86/microcode: Check CPU capabilities after late microcode update correctly (Prarit Bhargava) [1971937]
- x86/microcode: Add a parameter to microcode_check() to store CPU capabilities (Prarit Bhargava) [1971937]
- x86/microcode: Use the DEVICE_ATTR_RO() macro (Prarit Bhargava) [1971937]
- x86/microcode/AMD: Handle multiple glued containers properly (Prarit Bhargava) [1971937]
- x86/microcode/AMD: Rename a couple of functions (Prarit Bhargava) [1971937]
- x86/microcode/intel: Do not retry microcode reloading on the APs (Prarit Bhargava) [1971937]
- x86/microcode/intel: Do not print microcode revision and processor flags (Prarit Bhargava) [1971937]
- x86/microcode/intel: Use a reserved field for metasize (Prarit Bhargava) [1971937]
- x86/microcode/intel: Add hdr_type to intel_microcode_sanity_check() (Prarit Bhargava) [1971937]
- x86/microcode/intel: Reuse microcode_sanity_check() (Prarit Bhargava) [1971937]
- x86/microcode/intel: Use appropriate type in microcode_sanity_check() (Prarit Bhargava) [1971937]
- x86/microcode/intel: Reuse find_matching_signature() (Prarit Bhargava) [1971937]
- x86/microcode: Drop struct ucode_cpu_info.valid (Prarit Bhargava) [1971937]
- x86/microcode: Do some minor fixups (Prarit Bhargava) [1971937]
- x86/microcode: Kill refresh_fw (Prarit Bhargava) [1971937]
- x86/microcode: Simplify init path even more (Prarit Bhargava) [1971937]
- x86/microcode: Rip out the subsys interface gunk (Prarit Bhargava) [1971937]
- x86/microcode/AMD: Track patch allocation size explicitly (Prarit Bhargava) [1971937]
- x86/microcode: Print previous version of microcode after reload (Prarit Bhargava) [1971937]
- x86/microcode: Remove ->request_microcode_user() (Prarit Bhargava) [1971937]
- misc: Mark MICROCODE_MINOR unused (Prarit Bhargava) [1971937]
- x86/microcode: Remove unnecessary perf callback (Prarit Bhargava) [1971937]
- x86/microcode: Taint and warn on late loading (Prarit Bhargava) [1971937]
- x86/microcode: Default-disable late loading (Prarit Bhargava) [1971937]
- x86/microcode: Rip out the OLD_INTERFACE (Prarit Bhargava) [1971937]
- x86/microcode/intel: Expose collect_cpu_info_early() for IFS (Prarit Bhargava) [1971937]
- x86/cpu: Load microcode during restore_processor_state() (Prarit Bhargava) [1971937]
- microcode: Replace zero-length arrays with flexible-array members (Prarit Bhargava) [1971937]
- x86/microcode: Use the firmware_loader built-in API (Prarit Bhargava) [1971937]
- firmware: Export firmware_request_builtin() (Prarit Bhargava) [1971937]
- x86/microcode: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [1971937]
- x86/microcode: Make microcode_init() static (Prarit Bhargava) [1971937]
- x86/microcode/intel: Check patch signature before saving microcode for early loading (Prarit Bhargava) [1971937]
- x86/microcode/amd: Remove unneeded break (Prarit Bhargava) [1971937]
- x86/microcode: Do not select FW_LOADER (Prarit Bhargava) [1971937]
- x86/microcode: Fix return value for microcode late loading (Prarit Bhargava) [1971937]
- docs: fix broken documentation links (Prarit Bhargava) [1971937]

* Tue Jul 04 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-501.el8]
- x86/cpu: Add Xeon Emerald Rapids to list of CPUs that support PPIN (Prarit Bhargava) [2215040]
- redhat: configs: increase CONFIG_DEBUG_KMEMLEAK_MEM_POOL_SIZE (Audra Mitchell) [2215423]
- docs: admin-guide: Add information about intel_pstate active mode (Prarit Bhargava) [2216962]
- net/sched: flower: fix possible OOB write in fl_set_geneve_opt() (Davide Caratti) [2214027] {CVE-2023-35788}
- scsi: aacraid: Reply queue mapping to CPUs based on IRQ affinity (Tomas Henzl) [2160149]
- cifs: missing null pointer check in cifs_mount (Ronnie Sahlberg) [2215018]
- cpufreq: intel_pstate: Enable HWP IO boost for all servers (Prarit Bhargava) [2175625]
- block: make sure local irq is disabled when calling __blkcg_rstat_flush (Ming Lei) [2208904]
- blk-cgroup: Flush stats before releasing blkcg_gq (Ming Lei) [2208904]
- scsi: storvsc: Always set no_report_opcodes (Cathy Avery) [2217552]
- scsi: storvsc: Don't pass unused PFNs to Hyper-V host (Cathy Avery) [2217552]
- scsi: storvsc: Handle BlockSize change in Hyper-V VHD/VHDX file (Cathy Avery) [2217552]
- dm thin: fix issue_discard to pass GFP_NOIO to __blkdev_issue_discard (Benjamin Marzinski) [2212240]
- dm thin metadata: check fail_io before using data_sm (Benjamin Marzinski) [2215418]
- dm: don't lock fs when the map is NULL during suspend or resume (Benjamin Marzinski) [2215418]
- redhat/configs: enable CONFIG_MANA_INFINIBAND for RHEL (Kamal Heib) [2188737]
- RDMA/mana_ib: Fix a bug when the PF indicates more entries for registering memory on first packet (Kamal Heib) [2188737]
- RDMA/mana_ib: Prevent array underflow in mana_ib_create_qp_raw() (Kamal Heib) [2188737]
- RDMA/mana: Remove redefinition of basic u64 type (Kamal Heib) [2188737]
- RDMA/mana_ib: Add a driver for Microsoft Azure Network Adapter (Kamal Heib) [2188737]
- net: mana: Define data structures for allocating doorbell page from GDMA (Kamal Heib) [2188737]
- Documentation: net: net.core.txrehash is not specific to listening sockets (Antoine Tenart) [2175716]
- net: ipv4: use consistent txhash in TIME_WAIT and SYN_RECV (Antoine Tenart) [2175716]
- net: tcp: make the txhash available in TIME_WAIT sockets for IPv4 too (Antoine Tenart) [2175716]
- net: ipv6: fix skb hash for some RST packets (Antoine Tenart) [2175716]
- ipv6: tcp: send consistent autoflowlabel in RST packets (Antoine Tenart) [2175716]
- ipv6: tcp: send consistent autoflowlabel in SYN_RECV state (Antoine Tenart) [2175716]
- ipv6: tcp: send consistent autoflowlabel in TIME_WAIT state (Antoine Tenart) [2175716]
- txhash: fix sk->sk_txrehash default (Antoine Tenart) [2175716]
- socket: Don't use u8 type in uapi socket.h (Antoine Tenart) [2175716]
- tcp: Change SYN ACK retransmit behaviour to account for rehash (Antoine Tenart) [2175716]
- txhash: Add txrehash sysctl description (Antoine Tenart) [2175716]
- txhash: Add socket option to control TX hash rethink behavior (Antoine Tenart) [2175716]
- txhash: Make rethinking txhash behavior configurable via sysctl (Antoine Tenart) [2175716]
- igc: Fix possible system crash when loading module (Corinna Vinschen) [2153370]
- igc: Clean the TX buffer and TX descriptor ring (Corinna Vinschen) [2153370]
- igc: Avoid transmit queue timeout for XDP (Corinna Vinschen) [2153370]
- igc: read before write to SRRCTL register (Corinna Vinschen) [2153370]
- igc: Enable and fix RX hash usage by netstack (Corinna Vinschen) [2153370]
- igc: Remove obsolete DMA coalescing code (Corinna Vinschen) [2153370]
- igc: fix the validation logic for taprio's gate list (Corinna Vinschen) [2153370]
- igc: Add ndo_tx_timeout support (Corinna Vinschen) [2153370]
- igc: return an error if the mac type is unknown in igc_ptp_systim_to_hwtstamp() (Corinna Vinschen) [2153370]
- igc: Remove redundant pci_enable_pcie_error_reporting() (Corinna Vinschen) [2153370]
- igc: Fix PPS delta between two synchronized end-points (Corinna Vinschen) [2153370]
- igc: Remove reset adapter task for i226 during disable tsn config (Corinna Vinschen) [2153370]
- igc: enable Qbv configuration for 2nd GCL (Corinna Vinschen) [2153370]
- igc: remove I226 Qbv BaseTime restriction (Corinna Vinschen) [2153370]
- igc: Set Qbv start_time and end_time to end_time if not being configured in GCL (Corinna Vinschen) [2153370]
- igc: recalculate Qbv end_time by considering cycle time (Corinna Vinschen) [2153370]
- igc: allow BaseTime 0 enrollment for Qbv (Corinna Vinschen) [2153370]
- igc: Add checking for basetime less than zero (Corinna Vinschen) [2153370]
- igc: Use strict cycles for Qbv scheduling (Corinna Vinschen) [2153370]
- igc: Enhance Qbv scheduling by using first flag bit (Corinna Vinschen) [2153370]
- r8152: fix the autosuspend doesn't work (Jose Ignacio Tornos Martinez) [2159264]
- r8152: move setting r8153b_rx_agg_chg_indicate() (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix the poor throughput for 2.5G devices (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix flow control issue of RTL8156A (Jose Ignacio Tornos Martinez) [2159264]
- r8152: Add __GFP_NOWARN to big allocations (Jose Ignacio Tornos Martinez) [2159264]
- r8152: reduce the control transfer of rtl8152_get_version() (Jose Ignacio Tornos Martinez) [2159264]
- r8152: remove rtl_vendor_mode function (Jose Ignacio Tornos Martinez) [2159264]
- r8152: avoid to change cfg for all devices (Jose Ignacio Tornos Martinez) [2159264]
- r8152: add vendor/device ID pair for Microsoft Devkit (Jose Ignacio Tornos Martinez) [2159264]
- cdc_ether: no need to blacklist any r8152 devices (Jose Ignacio Tornos Martinez) [2159264]
- r8152: add USB device driver for config selection (Jose Ignacio Tornos Martinez) [2159264]
- net: usb: cdc_ether: add support for Thales Cinterion PLS62-W modem (Jose Ignacio Tornos Martinez) [2159264]
- net: usb: cdc_ether: add u-blox 0x1343 composition (Jose Ignacio Tornos Martinez) [2159264]
- r8152: Add MAC passthrough support for Lenovo Travel Hub (Jose Ignacio Tornos Martinez) [2159264]
- r8152: allow userland to disable multicast (Jose Ignacio Tornos Martinez) [2159264]
- r8152: add PID for the Lenovo OneLink+ Dock (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix the RX FIFO settings when suspending (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix the units of some registers for RTL8156A (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix a WOL issue (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix accessing unset transport header (Jose Ignacio Tornos Martinez) [2159264]
- net: usb: r8152: Add in new Devices that are supported for Mac-Passthru (Jose Ignacio Tornos Martinez) [2159264]
- cdc_ether: export usbnet_cdc_zte_rx_fixup (Jose Ignacio Tornos Martinez) [2159264]
- USB: zaurus: support another broken Zaurus (Jose Ignacio Tornos Martinez) [2159264]
- Revert "net: usb: r8152: Add MAC passthrough support for more Lenovo Docks" (Jose Ignacio Tornos Martinez) [2159264]
- r8152: sync ocp base (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix the force speed doesn't work for RTL8156 (Jose Ignacio Tornos Martinez) [2159264]
- net: usb: r8152: Add MAC passthrough support for more Lenovo Docks (Jose Ignacio Tornos Martinez) [2159264]
- net: usb: use eth_hw_addr_set() for dev->addr_len cases (Jose Ignacio Tornos Martinez) [2159264]
- net: usb: use eth_hw_addr_set() instead of ether_addr_copy() (Jose Ignacio Tornos Martinez) [2159264]
- r8152: avoid to resubmit rx immediately (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix the maximum number of PLA bp for RTL8153C (Jose Ignacio Tornos Martinez) [2159264]
- r8152: fix writing USB_BP2_EN (Jose Ignacio Tornos Martinez) [2159264]
- r8152: Fix a deadlock by doubly PM resume (Jose Ignacio Tornos Martinez) [2159264]
- r8152: Fix potential PM refcount imbalance (Jose Ignacio Tornos Martinez) [2159264]
- r8152: store the information of the pipes (Jose Ignacio Tornos Martinez) [2159264]
- r8152: support pauseparam of ethtool_ops (Jose Ignacio Tornos Martinez) [2159264]
- r8152: Avoid memcpy() over-reading of ETH_SS_STATS (Jose Ignacio Tornos Martinez) [2159264]
- r8152: check the informaton of the device (Jose Ignacio Tornos Martinez) [2159264]
- r8152: remove some bit operations (Jose Ignacio Tornos Martinez) [2159264]
- r8152: redefine REALTEK_USB_DEVICE macro (Jose Ignacio Tornos Martinez) [2159264]
- r8152: remove NCM mode from REALTEK_USB_DEVICE macro (Jose Ignacio Tornos Martinez) [2159264]
- r8152: replace return with break for ram code speedup mode timeout (Jose Ignacio Tornos Martinez) [2159264]
- r8152: search the configuration of vendor mode (Jose Ignacio Tornos Martinez) [2159264]
- r8152: support PHY firmware for RTL8156 series (Jose Ignacio Tornos Martinez) [2159264]
- r8152: support new chips (Jose Ignacio Tornos Martinez) [2159264]
- r8152: add help function to change mtu (Jose Ignacio Tornos Martinez) [2159264]
- r8152: adjust rtl8152_check_firmware function (Jose Ignacio Tornos Martinez) [2159264]
- r8152: set inter fram gap time depending on speed (Jose Ignacio Tornos Martinez) [2159264]
- r8152: adjust the flow of power cut for RTL8153B (Jose Ignacio Tornos Martinez) [2159264]
- treewide: Use fallthrough pseudo-keyword (Jose Ignacio Tornos Martinez) [2159264]
- nouveau: fix client work fence deletion race (Jocelyn Falempe) [2160452]
- drm/mgag200: Fix gamma lut not initialized. (Jocelyn Falempe) [2160452]
- drm/amd/display: Fix hang when skipping modeset (Jocelyn Falempe) [2160452]
- drm/amd/display: Lowering min Z8 residency time (Jocelyn Falempe) [2160452]
- drm/amd/display: Update minimum stutter residency for DCN314 Z8 (Jocelyn Falempe) [2160452]
- drm/amd/display: Add minimum Z8 residency debug option (Jocelyn Falempe) [2160452]
- drm/i915: disable sampler indirect state in bindless heap (Jocelyn Falempe) [2160452]
- drm/i915/mtl: Add Wa_14017856879 (Jocelyn Falempe) [2160452]
- drm/i915/mtl: Add workarounds Wa_14017066071 and Wa_14017654203 (Jocelyn Falempe) [2160452]
- drm/i915: Add _PICK_EVEN_2RANGES() (Jocelyn Falempe) [2160452]
- drm/amd/display: hpd rx irq not working with eDP interface (Jocelyn Falempe) [2160452]
- drm/amd/display: merge dc_link.h into dc.h and dc_types.h (Jocelyn Falempe) [2160452]
- drm/amd/pm: avoid potential UBSAN issue on legacy asics (Jocelyn Falempe) [2160452]
- drm/amdgpu: disable sdma ecc irq only when sdma RAS is enabled in suspend (Jocelyn Falempe) [2160452]
- drm/amdgpu: drop gfx_v11_0_cp_ecc_error_irq_funcs (Jocelyn Falempe) [2160452]
- drm/amd/pm: parse pp_handle under appropriate conditions (Jocelyn Falempe) [2160452]
- drm/amd/display: Enforce 60us prefetch for 200Mhz DCFCLK modes (Jocelyn Falempe) [2160452]
- drm/amdgpu: Fix vram recover doesn't work after whole GPU reset (v2) (Jocelyn Falempe) [2160452]
- drm/amdgpu: change gfx 11.0.4 external_id range (Jocelyn Falempe) [2160452]
- drm/amdgpu/jpeg: Remove harvest checking for JPEG3 (Jocelyn Falempe) [2160452]
- drm/amdgpu/gfx: disable gfx9 cp_ecc_error_irq only when enabling legacy gfx ras (Jocelyn Falempe) [2160452]
- drm/amdgpu: fix amdgpu_irq_put call trace in gmc_v11_0_hw_fini (Jocelyn Falempe) [2160452]
- drm/amdgpu: fix an amdgpu_irq_put() issue in gmc_v9_0_hw_fini() (Jocelyn Falempe) [2160452]
- drm/amdgpu: fix amdgpu_irq_put call trace in gmc_v10_0_hw_fini (Jocelyn Falempe) [2160452]
- drm/amd/display: Change default Z8 watermark values (Jocelyn Falempe) [2160452]
- drm/amdgpu: drop redundant sched job cleanup when cs is aborted (Jocelyn Falempe) [2160452]
- drm/amd/display: fix flickering caused by S/G mode (Jocelyn Falempe) [2160452]
- drm/amd/display: fix access hdcp_workqueue assert (Jocelyn Falempe) [2160452]
- drm/amd/display: filter out invalid bits in pipe_fuses (Jocelyn Falempe) [2160452]
- drm/amd/display: Fix 4to1 MPC black screen with DPP RCO (Jocelyn Falempe) [2160452]
- drm/amd/display: Add NULL plane_state check for cursor disable logic (Jocelyn Falempe) [2160452]
- drm/panel: otm8009a: Set backlight parent to panel device (Jocelyn Falempe) [2160452]
- drm/dsc: fix drm_edp_dsc_sink_output_bpp() DPCD high byte usage (Jocelyn Falempe) [2160452]
- drm/i915/dsi: Use unconditional msleep() instead of intel_dsi_msleep() (Jocelyn Falempe) [2160452]
- drm/i915: Check pipe source size when using skl+ scalers (Jocelyn Falempe) [2160452]
- drm/i915/color: Fix typo for Plane CSC indexes (Jocelyn Falempe) [2160452]
- drm/bridge: lt8912b: Fix DSI Video Mode (Jocelyn Falempe) [2160452]
- drm/amdgpu: add a missing lock for AMDGPU_SCHED (Jocelyn Falempe) [2160452]
- drm/i915/mtl: Add the missing CPU transcoder mask in intel_device_info (Jocelyn Falempe) [2160452]
- drm/i915/guc: Actually return an error if GuC version range check fails (Jocelyn Falempe) [2160452]
- drm/i915/guc: More debug print updates - UC firmware (Jocelyn Falempe) [2160452]
- drm/amd/display: Update bounding box values for DCN321 (Jocelyn Falempe) [2160452]
- drm/amd/display: Do not clear GPINT register when releasing DMUB from reset (Jocelyn Falempe) [2160452]
- drm/amd/display: Reset OUTBOX0 r/w pointer on DMUB reset (Jocelyn Falempe) [2160452]
- drm/amd/display: Fixes for dcn32_clk_mgr implementation (Jocelyn Falempe) [2160452]
- drm/amd/display: Return error code on DSC atomic check failure (Jocelyn Falempe) [2160452]
- drm/amd/display: Add missing WA and MCLK validation (Jocelyn Falempe) [2160452]
- drm/panel: novatek-nt35950: Only unregister DSI1 if it exists (Jocelyn Falempe) [2160452]
- drm/panel: novatek-nt35950: Improve error handling (Jocelyn Falempe) [2160452]
- drm/i915: Fix memory leaks in i915 selftests (Jocelyn Falempe) [2160452]
- drm/i915: Make intel_get_crtc_new_encoder() less oopsy (Jocelyn Falempe) [2160452]
- drm/amd/display: Fix potential null dereference (Jocelyn Falempe) [2160452]
- drm/ttm/pool: Fix ttm_pool_alloc error path (Jocelyn Falempe) [2160452]
- drm/i915/pxp: limit drm-errors or warning on firmware API failures (Jocelyn Falempe) [2160452]
- drm/i915/pxp: Invalidate all PXP fw sessions during teardown (Jocelyn Falempe) [2160452]
- drm/amd/display/dc/dce60/Makefile: Fix previous attempt to silence known override-init warnings (Jocelyn Falempe) [2160452]
- accel: Link to compute accelerator subsystem intro (Jocelyn Falempe) [2160452]
- drm/bridge: adv7533: Fix adv7533_mode_valid for adv7533 and adv7535 (Jocelyn Falempe) [2160452]
- drm/probe-helper: Cancel previous job before starting new one (Jocelyn Falempe) [2160452]
- drm/vgem: add missing mutex_destroy (Jocelyn Falempe) [2160452]
- drm/i915/dg2: Drop one PCI ID (Jocelyn Falempe) [2160452]
- drm/amd/pm: re-enable the gfx imu when smu resume (Jocelyn Falempe) [2160452]
- drm/vmwgfx: Fix Legacy Display Unit atomic drm support (Jocelyn Falempe) [2160452]
- drm/fb-helper: set x/yres_virtual in drm_fb_helper_check_var (Jocelyn Falempe) [2160452]
- redhat: include new drm tests in mod-internals (Jocelyn Falempe) [2160452]
- drm/amd/display: build with std=gnu99 (Jocelyn Falempe) [2160452]
- overflow: Introduce overflows_type() and castable_to_type() (Jocelyn Falempe) [2160452]
- Revert "driver core: make struct bus_type.uevent() take a const *" (Jocelyn Falempe) [2160452]
- Revert "iommu: Add a gfp parameter to iommu_map()" (Jocelyn Falempe) [2160452]
- Revert "mm: replace vma->vm_flags direct modifications with modifier calls" (Jocelyn Falempe) [2160452]
- Merge DRM changes from upstream v6.2..v6.3 (Jocelyn Falempe) [2160452]
- redhat: include new drm_kunit_helpers in mod-internals (Jocelyn Falempe) [2160452]
- drm/i915: build i915 with std=gnu99 (Jocelyn Falempe) [2160452]
- drm/amdgpu: Add missing include for ppc64le (Jocelyn Falempe) [2160452]
- drm/fb-helper: Add missing include for s390x (Jocelyn Falempe) [2160452]
- drm/edid: Add missing include (Jocelyn Falempe) [2160452]
- Revert "drm/i915/gvt: use atomic operations to change the vGPU status" (Jocelyn Falempe) [2160452]
- Revert "kunit: Use KUNIT_EXPECT_MEMEQ macro" (Jocelyn Falempe) [2160452]
- Revert "treewide: use get_random_u32_inclusive() when possible" (Jocelyn Falempe) [2160452]
- Revert "treewide: use get_random_u32_below() instead of deprecated function" (Jocelyn Falempe) [2160452]
- Revert "overflow: Introduce overflows_type() and castable_to_type()" (Jocelyn Falempe) [2160452]
- Merge DRM changes from upstream v6.1..v6.2 (Jocelyn Falempe) [2160452]
- kconfig: disable DRM dynamic debug. (Jocelyn Falempe) [2160452]
- drm/vkms: build driver with gnu99 (Jocelyn Falempe) [2160452]
- Revert "drm: POC drm on dyndbg - use in core, 2 helpers, 3 drivers." (Jocelyn Falempe) [2160452]
- Revert "mm: free device private pages have zero refcount" (Jocelyn Falempe) [2160452]
- Revert "mm/memory.c: fix race when faulting a device private page" (Jocelyn Falempe) [2160452]
- Revert "drm/i915/gvt: simplify vgpu configuration management" (Jocelyn Falempe) [2160452]
- Revert "i915: use the VMA iterator" (Jocelyn Falempe) [2160452]
- Revert "drm/i915/userptr: restore probe_range behaviour" (Jocelyn Falempe) [2160452]
- Revert "dynamic_dname(): drop unused dentry argument" (Jocelyn Falempe) [2160452]
- Revert "i2c: Make remove callback return void" (Jocelyn Falempe) [2160452]
- Merge DRM changes from upstream v6.0..v6.1 (Jocelyn Falempe) [2160452]
- Enable A64FX_DIAG config option (Charles Mirabile) [2047817]
- NMI workaround for GIC irq controllers (Charles Mirabile) [2047817]
- arm64: entry: avoid kprobe recursion (Charles Mirabile) [2047817]
- soc: a64fx-diag: disable modular build (Charles Mirabile) [2047817]
- soc: fujitsu: Add A64FX diagnostic interrupt driver (Charles Mirabile) [2047817]
- irqchip/gic-v3: Fix priority mask handling (Charles Mirabile) [2047817]
- irqchip/gic-v3: Refactor ISB + EOIR at ack time (Charles Mirabile) [2047817]
- irqchip/gic-v3: Ensure pseudo-NMIs have an ISB between ack and handling (Charles Mirabile) [2047817]
- arm64: select TRACE_IRQFLAGS_NMI_SUPPORT (Charles Mirabile) [2047817]
- arm64: entry: Save some nops when CONFIG_ARM64_PSEUDO_NMI is not set (Charles Mirabile) [2047817]
- irqchip/gic-v3: Fix priority comparison when non-secure priorities are used (Charles Mirabile) [2047817]
- arm64: entry: add missing noinstr (Charles Mirabile) [2047817]
- arm64: suspend: Use cpuidle context helpers in cpu_suspend() (Charles Mirabile) [2047817]
- PSCI: Use cpuidle context helpers in psci_cpu_suspend_enter() (Charles Mirabile) [2047817]
- arm64: Convert cpu_do_idle() to using cpuidle context helpers (Charles Mirabile) [2047817]
- arm64: Add cpuidle context save/restore helpers (Charles Mirabile) [2047817]
- arm64: entry: make NMI entry/exit functions static (Charles Mirabile) [2047817]
- arm64: entry: split SDEI entry (Charles Mirabile) [2047817]
- arm64: entry: split bad stack entry (Charles Mirabile) [2047817]
- arm64: entry: fold el1_inv() into el1h_64_sync_handler() (Charles Mirabile) [2047817]
- arm64: entry: handle all vectors with C (Charles Mirabile) [2047817]
- arm64: entry: template the entry asm functions (Charles Mirabile) [2047817]
- arm64: entry: improve bad_mode() (Charles Mirabile) [2047817]
- arm64: entry: move bad_mode() to entry-common.c (Charles Mirabile) [2047817]
- arm64: entry: consolidate EL1 exception returns (Charles Mirabile) [2047817]
- arm64: entry: organise entry vectors consistently (Charles Mirabile) [2047817]
- arm64: entry: organise entry handlers consistently (Charles Mirabile) [2047817]
- arm64: entry: convert IRQ+FIQ handlers to C (Charles Mirabile) [2047817]
- arm64: entry: add a call_on_irq_stack helper (Charles Mirabile) [2047817]
- arm64: entry: move NMI preempt logic to C (Charles Mirabile) [2047817]
- arm64: entry: move arm64_preempt_schedule_irq to entry-common.c (Charles Mirabile) [2047817]
- arm64: entry: convert SError handlers to C (Charles Mirabile) [2047817]
- arm64: entry: unmask IRQ+FIQ after EL0 handling (Charles Mirabile) [2047817]
- arm64: remove redundant local_daif_mask() in bad_mode() (Charles Mirabile) [2047817]
- arm64: entry: always set GIC_PRIO_PSR_I_SET during entry (Charles Mirabile) [2047817]
- arm64: entry: remove test_irqs_unmasked macro (Charles Mirabile) [2047817]
- arm64: irq: allow FIQs to be handled (Charles Mirabile) [2047817]
- arm64: Always keep DAIF.[IF] in sync (Charles Mirabile) [2047817]
- arm64: entry: factor irq triage logic into macros (Charles Mirabile) [2047817]
- arm64: irq: rework root IRQ handler registration (Charles Mirabile) [2047817]
- arm64: don't use GENERIC_IRQ_MULTI_HANDLER (Charles Mirabile) [2047817]
- genirq: Allow architectures to override set_handle_irq() fallback (Charles Mirabile) [2047817]
- irqchip: Do not blindly select CONFIG_GENERIC_IRQ_MULTI_HANDLER (Charles Mirabile) [2047817]
- arm64: entry: consolidate Cortex-A76 erratum 1463225 workaround (Charles Mirabile) [2047817]
- arm64: entry: remove redundant IRQ flag tracing (Charles Mirabile) [2047817]
- arm64: entry: suppress W=1 prototype warnings (Charles Mirabile) [2047817]
- arm64: sdei: explicitly simulate PAN/UAO entry (Charles Mirabile) [2047817]
- arm64: entry: fix EL1 debug transitions (Charles Mirabile) [2047817]
- arm64: entry: fix NMI {user, kernel}->kernel transitions (Charles Mirabile) [2047817]
- arm64: entry: fix non-NMI kernel<->kernel transitions (Charles Mirabile) [2047817]
- arm64: ptrace: prepare for EL1 irq/rcu tracking (Charles Mirabile) [2047817]
- arm64: entry: fix non-NMI user<->kernel transitions (Charles Mirabile) [2047817]
- arm64: entry: move el1 irq/nmi logic to C (Charles Mirabile) [2047817]
- arm64: entry: prepare ret_to_user for function call (Charles Mirabile) [2047817]
- arm64: entry: move enter_from_user_mode to entry-common.c (Charles Mirabile) [2047817]
- arm64: entry: mark entry code as noinstr (Charles Mirabile) [2047817]
- arm64: mark idle code as noinstr (Charles Mirabile) [2047817]
- arm64: add C wrappers for SET_PSTATE_*() (Charles Mirabile) [2047817]
- kgdb: Honour the kprobe blocklist when setting breakpoints (Charles Mirabile) [2047817]
- genirq: Add stub for set_handle_irq() when !GENERIC_IRQ_MULTI_HANDLER (Charles Mirabile) [2047817]
- arm64: Improve diagnostics when trapping BRK with FAULT_BRK_IMM (Charles Mirabile) [2047817]
- arm64/entry: deduplicate SW PAN entry/exit routines (Charles Mirabile) [2047817]
- arm64: Prepare arch_nmi_enter() for recursion (Charles Mirabile) [2047817]
- arm64: Make debug exception handlers visible from RCU (Charles Mirabile) [2047817]
- irqchip: Remove unneeded select IRQ_DOMAIN (Charles Mirabile) [2047817]
- net/mlx5e: TC, Fix using eswitch mapping in nic mode (Amir Tzin) [2166015]
- net/mlx5e: Use query_special_contexts cmd only once per mdev (Amir Tzin) [2166015]
- net/mlx5e: Move Ethernet driver debugfs to profile init callback (Amir Tzin) [2166015]
- net/mlx5e: Do not update SBCM when prio2buffer command is invalid (Amir Tzin) [2166015]
- RDMA/mlx5: Use correct device num_ports when modify DC (Amir Tzin) [2166015]
- net/mlx5e: Nullify table pointer when failing to create (Amir Tzin) [2166015]
- net/mlx5e: Fix error flow in representor failing to add vport rx rule (Amir Tzin) [2166015]
- net/mlx5: E-switch, Don't destroy indirect table in split rule (Amir Tzin) [2166015]
- net/mlx5: E-switch, Create per vport table based on devlink encap mode (Amir Tzin) [2166015]
- net/mlx5e: Don't clone flow post action attributes second time (Amir Tzin) [2166015]
- Revert "net/mlx5: Expose vnic diagnostic counters for eswitch managed vports" (Amir Tzin) [2166015]
- RDMA/mlx5: Fix flow counter query via DEVX (Amir Tzin) [2166015]
- RDMA/mlx5: Check pcie_relaxed_ordering_enabled() in UMR (Amir Tzin) [2166015]
- net/mlx5: Fix wrong comment (Amir Tzin) [2166015]
- net/mlx5e: Coding style fix, add empty line (Amir Tzin) [2166015]
- RDMA/mlx5: Coding style fix reported by checkpatch (Amir Tzin) [2166015]
- net/mlx5e: Release the label when replacing existing ct entry (Amir Tzin) [2165914]
- net/mlx5: Release tunnel device after tc update skb (Amir Tzin) [2166015]
- Revert "net/mlx5: Expose steering dropped packets counter" (Amir Tzin) [2166015]
- Revert "net/mlx5e: Don't use termination table when redundant" (Amir Tzin) [2166015]
- Revert "net/mlx5: Enable management PF initialization" (Amir Tzin) [2166015]
- net/mlx5: E-Switch, Fix an Oops in error handling code (Amir Tzin) [2166015]
- net/mlx5: Read the TC mapping of all priorities on ETS query (Amir Tzin) [2166015]
- net/mlx5e: Initialize link speed to zero (Amir Tzin) [2166015]
- net/mlx5: Fix steering rules cleanup (Amir Tzin) [2166015]
- net/mlx5e: Block entering switchdev mode with ns inconsistency (Amir Tzin) [2166015 2166018]
- net/mlx5e: Set uplink rep as NETNS_LOCAL (Amir Tzin) [2166015]
- IB/mlx5: Add support for 400G_8X lane speed (Amir Tzin) [2166015]
- net/mlx5e: TC, Remove error message log print (Amir Tzin) [2166015]
- net/mlx5e: TC, fix cloned flow attribute (Amir Tzin) [2166015]
- net/mlx5e: TC, fix missing error code (Amir Tzin) [2166015]
- net/sched: TC, fix raw counter initialization (Amir Tzin) [2166015]
- net/mlx5: Set BREAK_FW_WAIT flag first when removing driver (Amir Tzin) [2166013]
- net/mlx5e: Fix cleanup null-ptr deref on encap lock (Amir Tzin) [2166013]
- net/mlx5: E-switch, Fix missing set of split_count when forward to ovs internal port (Amir Tzin) [2166013]
- net/mlx5: E-switch, Fix wrong usage of source port rewrite in split rules (Amir Tzin) [2166013 2166018]
- net/mlx5: Disable eswitch before waiting for VF pages (Amir Tzin) [2166013]
- net/mlx5: Fix setting ec_function bit in MANAGE_PAGES (Amir Tzin) [2166013]
- net/mlx5e: Don't cache tunnel offloads capability (Amir Tzin) [2166013]
- net/mlx5e: Remove hairpin write debugfs files (Amir Tzin) [2166015]
- net/mlx5: Remove NULL check before dev_{put, hold} (Amir Tzin) [2166015]
- net/mlx5e: TC, Set CT miss to the specific ct action instance (Amir Tzin) [2166015]
- net/mlx5e: Rename CHAIN_TO_REG to MAPPED_OBJ_TO_REG (Amir Tzin) [2166015]
- net/mlx5: Refactor tc miss handling to a single function (Amir Tzin) [2166015]
- net/mlx5: Kconfig: Make tc offload depend on tc skb extension (Amir Tzin) [2166015]
- net/sched: Rename user cookie and act cookie (mlx5 hunk only) (Amir Tzin) [2166015]
- IB/mlx5: Extend debug control for CC parameters (Amir Tzin) [2166015]
- net/mlx5e: Allow offloading of ct 'new' match (Amir Tzin) [2165914 2166015]
- net/mlx5e: Implement CT entry update (Amir Tzin) [2165914 2166015]
- net: flow_offload: provision conntrack info in ct_metadata(mlx5 hunks only) (Amir Tzin) [2165914 2166015]
- net/mlx5e: Fix outdated TLS comment (Amir Tzin) [2166015]
- net/mlx5e: Remove unused function mlx5e_sq_xmit_simple (Amir Tzin) [2166015]
- net/mlx5: Simplify eq list traversal (Amir Tzin) [2166015]
- net/mlx5e: Switch to using napi_build_skb() (Amir Tzin) [2166015]
- RDMA/mlx5: Use query_special_contexts for mkeys (Amir Tzin) [2166015]
- net/mlx5e: Use query_special_contexts for mkeys (Amir Tzin) [2166015]
- net/mlx5: Change define name for 0x100 lkey value (Amir Tzin) [2166015]
- net/mlx5: Expose bits for querying special mkeys (Amir Tzin) [2166015]
- RDMA/mlx5: Use rdma_umem_for_each_dma_block() (Amir Tzin) [2166015]
- net/mlx5e: TC, fix return value check in mlx5e_tc_act_stats_create() (Amir Tzin) [2166015]
- net/mlx5e: TC, support per action stats (Amir Tzin) [2166015]
- net/mlx5e: TC, map tc action cookie to a hw counter (Amir Tzin) [2166015]
- net/mlx5e: TC, store tc action cookies per attr (Amir Tzin) [2166015]
- net/mlx5e: TC, add hw counter to branching actions (Amir Tzin) [2166015]
- RDMA/mlx5: Track netdev to avoid deadlock during netdev notifier unregister (Amir Tzin) [2166015]
- net/mlx5e: Propagate an internal event in case uplink netdev changes (Amir Tzin) [2166015]
- net/mlx5e: Fix trap event handling (Amir Tzin) [2166015]
- net/mlx5: fw_tracer, Add support for unrecognized string (Amir Tzin) [2166015]
- net/mlx5: fw_tracer, Add support for strings DB update event (Amir Tzin) [2166015]
- net/mlx5: fw_tracer, allow 0 size string DBs (Amir Tzin) [2166015]
- net/mlx5: fw_tracer: Fix debug print (Amir Tzin) [2166015]
- net/mlx5: fs, Remove redundant assignment of size (Amir Tzin) [2166015]
- net/mlx5: fs_core, Remove redundant variable err (Amir Tzin) [2166015]
- net/mlx5: fs, Remove redundant vport_number assignment (Amir Tzin) [2166015]
- net/mlx5e: Remove redundant code for handling vlan actions (Amir Tzin) [2166015 2166018]
- net/mlx5: fw reset: Skip device ID check if PCI link up failed (Amir Tzin) [2166015]
- net/mlx5: Remove redundant health work lock (Amir Tzin) [2166015]
- mlx5: reduce stack usage in mlx5_setup_tc (Amir Tzin) [2166015]
- net/mlx5e: Trigger NAPI after activating an SQ (Amir Tzin) [2166015]
- net/mlx5e: IPoIB, Add support for XDR speed (Amir Tzin) [2166015]
- net/mlx5: Lag, Move mpesw related definitions to mpesw.h (Amir Tzin) [2166015]
- net/mlx5: Lag, Use flag to check for shared FDB mode (Amir Tzin) [2166015]
- net/mlx5: Lag, Remove redundant bool allocation on the stack (Amir Tzin) [2166015]
- net/mlx5: Lag, Use mlx5_lag_dev() instead of derefering pointers (Amir Tzin) [2166015]
- net/mlx5: Lag, Update multiport eswitch check to log an error (Amir Tzin) [2166015]
- net/mlx5: Add firmware support for MTUTC scaled_ppm frequency adjustments (Amir Tzin) [2166015]
- net/mlx5: Add hardware extended range support for PTP adjtime and adjphase (Amir Tzin) [2166015]
- net/mlx5: Add adjphase function to support hardware-only offset control (Amir Tzin) [2166015]
- net/mlx5: Geneve, Fix handling of Geneve object id as error code (Amir Tzin) [2166015]
- net/mlx5e: Verify flow_source cap before using it (Amir Tzin) [2166015 2166018]
- net/mlx5: ECPF, wait for VF pages only after disabling host PFs (Amir Tzin) [2166015]
- mlx5: fix possible ptp queue fifo use-after-free (Amir Tzin) [2166015]
- mlx5: fix skb leak while fifo resync and push (Amir Tzin) [2166015]
- net/mlx5: Fix memory leak in error flow of port set buffer (Amir Tzin) [2166015]
- net/mlx5e: Remove incorrect debugfs_create_dir NULL check in TLS (Amir Tzin) [2166015]
- net/mlx5e: Remove incorrect debugfs_create_dir NULL check in hairpin (Amir Tzin) [2166015]
- net/mlx5: Enhance debug print in page allocation failure (Amir Tzin) [2166015]
- net/mlx5e: kTLS, Improve connection rate by using fast update encryption key (Amir Tzin) [2166015]
- net/mlx5: Keep only one bulk of full available DEKs (Amir Tzin) [2166015]
- net/mlx5: Add async garbage collector for DEK bulk (Amir Tzin) [2166015]
- net/mlx5: Reuse DEKs after executing SYNC_CRYPTO command (Amir Tzin) [2166015]
- net/mlx5: Use bulk allocation for fast update encryption key (Amir Tzin) [2166015]
- net/mlx5: Add bulk allocation and modify_dek operation (Amir Tzin) [2166015]
- net/mlx5: Add support SYNC_CRYPTO command (Amir Tzin) [2166015]
- net/mlx5: Add new APIs for fast update encryption key (Amir Tzin) [2166015]
- net/mlx5: Refactor the encryption key creation (Amir Tzin) [2166015]
- net/mlx5: Add const to the key pointer of encryption key creation (Amir Tzin) [2166015]
- net/mlx5: Prepare for fast crypto key update if hardware supports it (Amir Tzin) [2166015]
- net/mlx5: Change key type to key purpose (Amir Tzin) [2166015]
- net/mlx5: Add IFC bits and enums for crypto key (Amir Tzin) [2166015]
- net/mlx5: Add IFC bits for general obj create param (Amir Tzin) [2166015]
- net/mlx5: Header file for crypto (Amir Tzin) [2166015]
- net/mlx5e: Use read lock for eswitch get callbacks (Amir Tzin) [2166015 2166018]
- net/mlx5e: Remove redundant allocation of spec in create indirect fwd group (Amir Tzin) [2165994 2166015]
- net/mlx5e: Support Geneve and GRE with VF tunnel offload (Amir Tzin) [2165994 2166015 2166018]
- net/mlx5: E-Switch, Fix typo for egress (Amir Tzin) [2166015]
- net/mlx5e: Warn when destroying mod hdr hash table that is not empty (Amir Tzin) [2166015]
- net/mlx5e: TC, Use common function allocating flow mod hdr or encap mod hdr (Amir Tzin) [2166015]
- net/mlx5e: TC, Add tc prefix to attach/detach hdr functions (Amir Tzin) [2166015]
- net/mlx5e: TC, Pass flow attr to attach/detach mod hdr functions (Amir Tzin) [2166015]
- net/mlx5: E-switch, Remove redundant comment about meta rules (Amir Tzin) [2166015]
- net/mlx5: Suppress error logging on UCTX creation (Amir Tzin) [2166015]
- net/mlx5e: Suppress Send WQEBB room warning for PAGE_SIZE >= 16KB (Amir Tzin) [2166015]
- net/mlx5e: Use kzalloc() in mlx5e_accel_fs_tcp_create() (Amir Tzin) [2166015]
- net/mlx5: remove redundant ret variable (Amir Tzin) [2166015]
- net/mlx5e: Replace 0-length array with flexible array (Amir Tzin) [2166015]
- net/mlx5e: Replace zero-length array with flexible-array member (Amir Tzin) [2166015]
- net/mlx5: Prevent high-rate FW commands from populating all slots (Amir Tzin) [2166015]
- net/mlx5: Introduce and use opcode getter in command interface (Amir Tzin) [2166015]
- net/mlx5: Enable management PF initialization (Amir Tzin) [2166015]
- net/mlx5e: Add hairpin debugfs files (Amir Tzin) [2166015]
- net/mlx5e: Add flow steering debugfs directory (Amir Tzin) [2166015]
- net/mlx5e: Add hairpin params structure (Amir Tzin) [2166015]
- net/mlx5e: kTLS, Add debugfs (Amir Tzin) [2166015]
- net/mlx5e: Add Ethernet driver debugfs (Amir Tzin) [2166015]
- net/mlx5e: Update shared buffer along with device buffer changes (Amir Tzin) [2166015]
- net/mlx5e: Add API to query/modify SBPR and SBCM registers (Amir Tzin) [2166015]
- net/mlx5: Expose shared buffer registers bits and structs (Amir Tzin) [2166015]
- net/mlx5: Serialize module cleanup with reload and remove (Amir Tzin) [2166013]
- net/mlx5: fw_tracer, Zero consumer index when reloading the tracer (Amir Tzin) [2166013]
- net/mlx5: fw_tracer, Clear load bit when freeing string DBs buffers (Amir Tzin) [2166013]
- net/mlx5: Expose SF firmware pages counter (Amir Tzin) [2166013]
- net/mlx5: Store page counters in a single array (Amir Tzin) [2166013]
- net/mlx5e: IPoIB, Show unknown speed instead of error (Amir Tzin) [2166013]
- net/mlx5e: Fix crash unsetting rx-vlan-filter in switchdev mode (Amir Tzin) [2055530 2166013]
- net/mlx5: Bridge, fix ageing of peer FDB entries (Amir Tzin) [2166013]
- net/mlx5: DR, Fix potential race in dr_rule_create_rule_nic (Amir Tzin) [2166013]
- net/mlx5e: Update rx ring hw mtu upon each rx-fcs flag change (Amir Tzin) [2166013]
- net/mlx5e: Don't support encap rules with gbp option (Amir Tzin) [2166013]
- net/mlx5e: Fix memory leak on updating vport counters (Amir Tzin) [2165677 2166013]
- net/mlx5e: TC, Restore pkt rate policing support (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, ignore match level for post meter rules (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Fix 'stack frame size exceeds limit' error in dr_rule (Amir Tzin) [2166013]
- net/mlx5: Lag, fix failure to cancel delayed bond work (Amir Tzin) [2166013]
- net/mlx5e: Fix RX reporter for XSK RQs (Amir Tzin) [2166013]
- net/mlx5: Expose steering dropped packets counter (Amir Tzin) [2166013]
- net/mlx5: Refactor and expand rep vport stat group (Amir Tzin) [2165677 2166013]
- net/mlx5e: TC, add support for meter mtu offload (Amir Tzin) [2165893 2166013 2166018]
- net/mlx5e: meter, add mtu post meter tables (Amir Tzin) [2165893 2166013]
- net/mlx5e: meter, refactor to allow multiple post meter tables (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Add support for range match action (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Add function that tells if STE miss addr has been initialized (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Some refactoring of miss address handling (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Manage definers with refcounts (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Handle FT action in a separate function (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Rework is_fw_table function (Amir Tzin) [2165893 2166013]
- net/mlx5: DR, Add functions to create/destroy MATCH_DEFINER general object (Amir Tzin) [2165893 2166013]
- net/mlx5: fs, add match on ranges API (Amir Tzin) [2165893 2166013]
- net/mlx5: mlx5_ifc updates for MATCH_DEFINER general object (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, allow meter jump control action (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, init post meter rules with branching attributes (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, rename post_meter actions (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, initialize branching action with target attr (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, initialize branch flow attributes (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, set control params for branching actions (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, validate action list per attribute (Amir Tzin) [2165893 2166013]
- net/mlx5e: Adjust function actions_match_supported() to upstream. (Amir Tzin) [2166006]
- net/mlx5e: TC, add terminating actions (Amir Tzin) [2165893 2166013]
- net/mlx5e: TC, reuse flow attribute post parser processing (Amir Tzin) [2165893 2166013]
- net/mlx5: fs, assert null dest pointer when dest_num is 0 (Amir Tzin) [2165893 2166013]
- net/mlx5e: E-Switch, handle flow attribute with no destinations (Amir Tzin) [2165893 2166013 2166018]
- RDMA/mlx5: Remove not-used IB_FLOW_SPEC_IB define (Amir Tzin) [2166013]
- RDMA/mlx5: no need to kfree NULL pointer (Amir Tzin) [2166013]
- net/mlx5e: TC, Add offload support for trap with additional actions (Amir Tzin) [2166013 2166018]
- net/mlx5e: Do early return when setup vports dests for slow path flow (Amir Tzin) [2166013 2166018]
- net/mlx5e: Support devlink reload of IPsec core (Amir Tzin) [2166013]
- net/mlx5: Remove redundant check (Amir Tzin) [2166013]
- net/mlx5e: Don't use termination table when redundant (Amir Tzin) [2166013]
- net/mlx5: Remove unused ctx variables (Amir Tzin) [2166013]
- net/mlx5e: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Amir Tzin) [2166013]
- net/mlx5e: Remove unneeded io-mapping.h #include (Amir Tzin) [2166013]
- net/mlx5e: CT, optimize pre_ct table lookup (Amir Tzin) [2166013]
- net/mlx5e: kTLS, Use a single async context object per a callback bulk (Amir Tzin) [2166013]
- net/mlx5e: kTLS, Remove unnecessary per-callback completion (Amir Tzin) [2166013]
- net/mlx5e: kTLS, Remove unused work field (Amir Tzin) [2166013]
- net/mlx5e: TC, Remove redundant WARN_ON() (Amir Tzin) [2166013]
- net/mlx5e: Add error flow when failing update_rx (Amir Tzin) [2166013]
- net/mlx5e: Move params kernel log print to probe function (Amir Tzin) [2166013]
- net/mlx5e: Support enhanced CQE compression (Amir Tzin) [2166013]
- net/mlx5e: Use clamp operation instead of open coding it (Amir Tzin) [2166013]
- net/mlx5e: remove unused list in arfs (Amir Tzin) [2166013]
- net/mlx5: Expose vhca_id to debugfs (Amir Tzin) [2166013]
- net/mlx5: Unregister traps on driver unload flow (Amir Tzin) [2166013]
- net/mlx5: Fix spelling mistake "destoy" -> "destroy" (Amir Tzin) [2166013]
- net/mlx5: Bridge, Use debug instead of warn if entry doesn't exists (Amir Tzin) [2166013]
- RDMA/mlx5: Change debug log level for remote access error syndromes (Amir Tzin) [2166013]
- ptp: mlx5: convert to .adjfine and adjust_by_scaled_ppm (Amir Tzin) [2166013]
- net/mlx5: DR, Remove the buddy used_list (Amir Tzin) [2166013]
- net/mlx5: DR, Keep track of hot ICM chunks in an array instead of list (Amir Tzin) [2166013]
- net/mlx5: DR, Lower sync threshold for ICM hot memory (Amir Tzin) [2166013]
- net/mlx5: DR, Allocate htbl from its own slab allocator (Amir Tzin) [2166013]
- net/mlx5: DR, Allocate icm_chunks from their own slab allocator (Amir Tzin) [2166013]
- net/mlx5: DR, Manage STE send info objects in pool (Amir Tzin) [2166013]
- net/mlx5: DR, In rehash write the line in the entry immediately (Amir Tzin) [2166013]
- net/mlx5: DR, Handle domain memory resources init/uninit separately (Amir Tzin) [2166013]
- net/mlx5: DR, Initialize chunk's ste_arrays at chunk creation (Amir Tzin) [2166013]
- net/mlx5: DR, For short chains of STEs, avoid allocating ste_arr dynamically (Amir Tzin) [2166013]
- net/mlx5: DR, Remove unneeded argument from dr_icm_chunk_destroy (Amir Tzin) [2166013]
- net/mlx5: DR, Check device state when polling CQ (Amir Tzin) [2166013]
- net/mlx5: DR, In destroy flow, free resources even if FW command failed (Amir Tzin) [2166013]
- net/mlx5: Add support for NPPS with real time mode (Amir Tzin) [2166006]
- net/mlx5: Expose NPPS related registers (Amir Tzin) [2166006]
- net/mlx5e: Use kvfree() in mlx5e_accel_fs_tcp_create() (Amir Tzin) [2166006]
- net/mlx5e: Remove leftovers from old XSK queues enumeration (Amir Tzin) [2166006]
- net/mlx5: Lag, avoid lockdep warnings (Amir Tzin) [2166006]
- net/mlx5: Update fw fatal reporter state on PCI handlers successful recover (Amir Tzin) [2166006]
- net/mlx5: Make ASO poll CQ usable in atomic context (Amir Tzin) [2166006]
- net/mlx5: E-Switch, Return EBUSY if can't get mode lock (Amir Tzin) [2166006]
- net/mlx5: E-switch, Don't update group if qos is not enabled (Amir Tzin) [2166006]
- net/mlx5: E-Switch, Allow offloading fwd dest flow table with vport (Amir Tzin) [2166006 2166018]
- net/mlx5: Set default grace period based on function type (Amir Tzin) [2166006]
- net/mlx5: Start health poll at earlier stage of driver load (Amir Tzin) [2166006]
- net/mlx5e: Expose rx_oversize_pkts_buffer counter (Amir Tzin) [2166006]
- net/mlx5: Remove from FPGA IFC file not-needed definitions (Amir Tzin) [2166006]
- net/mlx5: Remove unused structs (Amir Tzin) [2166006]
- net/mlx5: Remove unused functions (Amir Tzin) [2166006]
- net/mlx5: detect and enable bypass port select flow table (Amir Tzin) [2166006]
- net/mlx5: Lag, enable hash mode by default for all NICs (Amir Tzin) [2166006]
- net/mlx5: Lag, set active ports if support bypass port select flow table (Amir Tzin) [2166006]
- RDMA/mlx5: Don't set tx affinity when lag is in hash mode (Amir Tzin) [2166006]
- net/mlx5: add IFC bits for bypassing port select flow table (Amir Tzin) [2166006]
- RDMA/mlx5: Move function mlx5_core_query_ib_ppcnt() to mlx5_ib (Amir Tzin) [2166006]
- IB/mlx5: Support querying eswitch functions from DEVX (Amir Tzin) [2166006]
- net: ethernet: move from strlcpy with unused retval to strscpy (mlx5 hunks only) (Amir Tzin) [2166006]
- net/mlx5e: Do not use err uninitialized in mlx5e_rep_add_meta_tunnel_rule() (Amir Tzin) [2166006]
- IB/mlx5: Remove duplicate header inclusion related to ODP (Amir Tzin) [2166006]
- net/mlx5: TC, Add support for SF tunnel offload (Amir Tzin) [2166006]
- net/mlx5: E-Switch, Move send to vport meta rule creation (Amir Tzin) [2166006 2166018]
- net/mlx5: E-Switch, Split creating fdb tables into smaller chunks (Amir Tzin) [2166006 2166018]
- net/mlx5: E-Switch, Add default drop rule for unmatched packets (Amir Tzin) [2166006 2166018]
- net/mlx5: Adjust function mlx5_eswitch_inline_mode_get() location (Amir Tzin) [2166006]
- net/mlx5e: Completely eliminate priv from fs.h (Amir Tzin) [2166006]
- net/mlx5e: Make all ttc functions of en_fs get fs struct as argument (Amir Tzin) [2166006]
- net/mlx5e: Make flow steering arfs independent of priv (Amir Tzin) [2166006]
- net/mlx5e: Introduce flow steering debug macros (Amir Tzin) [2166006]
- net/mlx5e: Separate ethtool_steering from fs.h and make private (Amir Tzin) [2166006]
- net/mlx5e: Directly get flow_steering struct as input when init/cleanup ethtool steering (Amir Tzin) [2166006]
- Revert "[netdrv] net/mlx5e: Fix missing cleanup of ethtool steering during rep rx cleanup" (Amir Tzin) [2166006]
- net/mlx5e: Convert ethtool_steering member of flow_steering struct to pointer (Amir Tzin) [2166006]
- net/mlx5e: Drop priv argument of ptp function in en_fs (Amir Tzin) [2166006]
- net/mlx5e: Decouple fs_tcp from en.h (Amir Tzin) [2166006]
- net/mlx5e: Decouple fs_tt_redirect from en.h (Amir Tzin) [2166006]
- net/mlx5e: Introduce flow steering API (Amir Tzin) [2166006]
- IB/mlx5: Call io_stop_wc() after writing to WC MMIO (Amir Tzin) [2166006]

* Tue Jun 27 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-500.el8]
- mm: page_counter: mitigate consequences of a page_counter underflow (Ty Berry) [2196726]
- ceph: fix decoding of client session messages flags (Xiubo Li) [2213062]
- net: stmmac: propagate feature flags to vlan (Corinna Vinschen) [2174701]
- KVM: Avoid illegal stage2 mapping on invalid memory slot (Gavin Shan) [2190376]
- perf/x86/rapl: Add support for Intel Emerald Rapids (Michael Petlan) [2165766]
- s390/dasd: Use correct lock while counting channel queue length (Tobias Huschle) [2215889]
- inotify: show inotify mask flags in proc fdinfo (Andrey Albershteyn) [2163455]
- scsi: scsi_transport_fc: Add an additional flag to fc_host_fpin_rcv() (Ewan D. Milne) [2169276]
- perf bench: Fix numa bench to fix usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2134284]
- perf bench: Fix numa testcase to check if CPU used to bind task is online (Michael Petlan) [2134284]
- powerpc/64s: Make POWER10 and later use pause_short in cpu_relax loops (avchouha) [2188343]
- powerpc: add ISA v3.0 / v3.1 wait opcode macro (avchouha) [2188343]
- scsi: lpfc: Account for fabric domain ctlr device loss recovery (Dick Kennedy) [2213027]
- scsi: lpfc: Clear NLP_IN_DEV_LOSS flag if already in rediscovery (Dick Kennedy) [2213027]
- scsi: lpfc: Fix use-after-free rport memory access in lpfc_register_remote_port() (Dick Kennedy) [2213027]
- PCI: hv: Add a per-bus mutex state_lock (Vitaly Kuznetsov) [2184863]
- Revert "PCI: hv: Fix a timing issue which causes kdump to fail occasionally" (Vitaly Kuznetsov) [2184863]
- PCI: hv: Remove the useless hv_pcichild_state from struct hv_pci_dev (Vitaly Kuznetsov) [2184863]
- PCI: hv: Fix a race condition in hv_irq_unmask() that can cause panic (Vitaly Kuznetsov) [2184863]
- PCI: hv: Fix a race condition bug in hv_pci_query_relations() (Vitaly Kuznetsov) [2184863]
- RHEL-only: KVM: arm64: Fixes comments (Shaoqin Huang) [2202988]
- KVM: arm64: Fix buffer overflow in kvm_arm_set_fw_reg() (Shaoqin Huang) [2202988]
- KVM: selftests: arm64: Fix pte encode/decode for PA bits > 48 (Shaoqin Huang) [2202988]
- KVM: arm64: selftests: Use FIELD_GET() to extract ID register fields (Shaoqin Huang) [2202988]
- tools: Copy bitfield.h from the kernel sources (Shaoqin Huang) [2202988]
- x86/platform/uv: Update UV[23] platform code for SNC (Frank Ramsay) [2163467]
- x86/platform/uv: Remove remaining BUG_ON() and BUG() calls (Frank Ramsay) [2163467]
- x86/platform/uv: UV support for sub-NUMA clustering (Frank Ramsay) [2163467]
- x86: uv: uv_hub.h: Delete duplicated word (Frank Ramsay) [2163467]
- x86/platform/uv: Helper functions for allocating and freeing conversion tables (Frank Ramsay) [2163467]
- x86/platform/uv: When searching for minimums, start at INT_MAX not 99999 (Frank Ramsay) [2163467]
- x86/platform/uv: Fix printed information in calc_mmioh_map (Frank Ramsay) [2163467]
- x86/platform/uv: Introduce helper function uv_pnode_to_socket. (Frank Ramsay) [2163467]
- x86/platform/uv: Add platform resolving #defines for misc GAM_MMIOH_REDIRECT* (Frank Ramsay) [2163467]
- IB/hfi1: Fix sdma.h tx->num_descs off-by-one errors (Izabela Bakollari) [2170629]
- IB/hfi1: Fix math bugs in hfi1_can_pin_pages() (Izabela Bakollari) [2170629]
- IB/hfi1: Restore allocated resources on failed copyout (Izabela Bakollari) [2170629]
- IB/hfi1: Use dma_mmap_coherent for matching buffers (Izabela Bakollari) [2170629]
- IB/hfi1: Update RMT size calculation (Izabela Bakollari) [2170629]
- IB/hfi1: Split IB counter allocation (Izabela Bakollari) [2170629]
- IB/hfi1: Improve TID validity checking (Izabela Bakollari) [2170629]
- IB/hfi1: Consolidate the creation of user TIDs (Izabela Bakollari) [2170629]
- IB/hfi1: Assign npages earlier (Izabela Bakollari) [2170629]
- IB/hfi1: Fix expected receive setup error exit issues (Izabela Bakollari) [2170629]
- IB/hfi1: Reserve user expected TIDs (Izabela Bakollari) [2170629]
- IB/hfi1: Reject a zero-length user expected buffer (Izabela Bakollari) [2170629]
- RDMA/hfi1: Fix doc for hfi1_free_ctxt (Izabela Bakollari) [2170629]
- RDMA/hfi1: use sysfs_emit() to instead of scnprintf() (Izabela Bakollari) [2170629]
- RDMA/hfi1: Fix error return code in parse_platform_config() (Izabela Bakollari) [2170629]
- IB/hfi1: Switch to netif_napi_add() (Izabela Bakollari) [2170629]
- RDMA/hfi: Decrease PCI device reference count in error path (Izabela Bakollari) [2170629]
- RDMA/hfi1: don't pass bogus GFP_ flags to dma_alloc_coherent (Izabela Bakollari) [2170629]
- IB/hfi1: Replace 1-element array with singleton (Izabela Bakollari) [2170629]
- RDMA/opa_vnic: fix spelling typo in comment (Izabela Bakollari) [2170629]
- IB/hfi1: Use skb_put_data() instead of skb_put/memcpy pair (Izabela Bakollari) [2170629]
- IB/hfi1: remove rc_only_opcode and uc_only_opcode declarations (Izabela Bakollari) [2170629]
- RDMA/hfi1: fix repeated words in comments (Izabela Bakollari) [2170629]
- RDMA/hfi1: Remove the unneeded result variable (Izabela Bakollari) [2170629]
- IB: move from strlcpy with unused retval to strscpy (Izabela Bakollari) [2170629]
- perf intel-pt: Add documentation for Event Trace and TNT disable (Michael Petlan) [2154066]
- perf scripts python: export-to-postgresql.py: Export all sample flags (Michael Petlan) [2154066]
- perf scripts python: export-to-sqlite.py: Export all sample flags (Michael Petlan) [2154066]
- perf scripting python: Add all sample flags to DB export (Michael Petlan) [2154066]
- perf scripts python: intel-pt-events.py: Add Event Trace (Michael Petlan) [2154066]
- perf script: Display new D (Intr Disabled) and t (Intr Toggle) flags (Michael Petlan) [2154066]
- perf script: Display Intel PT iflag synthesized event (Michael Petlan) [2154066]
- perf script: Display Intel PT CFE (Control Flow Event) / EVD (Event Data) synthesized event (Michael Petlan) [2154066]
- perf intel-pt: Force 'quick' mode when TNT (Taken/Not-Taken packet) is disabled (Michael Petlan) [2154066]
- perf intel-pt: Synthesize new D (Intr Disabled) and t (Intr Toggle) flags (Michael Petlan) [2154066]
- perf intel-pt: Synthesize iflag event (Michael Petlan) [2154066]
- perf intel-pt: Synthesize CFE (Control Flow Event) / EVD (Event Data) event (Michael Petlan) [2154066]
- perf intel-pt: Record Event Trace capability flag (Michael Petlan) [2154066]
- perf auxtrace: Add itrace option "I" (Michael Petlan) [2154066]
- perf tools: Define new D (Intr Disable) and t (Intr Toggle) flags (Michael Petlan) [2154066]
- perf tools: Define Intel PT iflag synthesized event (Michael Petlan) [2154066]
- perf tools: Define Intel PT CFE (Control Flow Event) / EVD (Event Data) event (Michael Petlan) [2154066]
- perf intel-pt: decoder: Add MODE.Exec IFLAG processing (Michael Petlan) [2154066]
- perf intel-pt: decoder: Add CFE (Control Flow Event) and EVD (Event Data) processing (Michael Petlan) [2154066]
- perf intel-pt: decoder: Factor out clearing of FUP (Flow Update) event variables (Michael Petlan) [2154066]
- perf intel-pt: Fix error timestamp setting on the decoder error path (Michael Petlan) [2154066]
- perf intel-pt: Fix missing 'instruction' events with 'q' option (Michael Petlan) [2154066]
- perf intel-pt: Fix next 'err' value, walking trace (Michael Petlan) [2154066]
- perf intel-pt: Fix state setting when receiving overflow (OVF) packet (Michael Petlan) [2154066]
- perf intel-pt: Fix intel_pt_fup_event() assumptions about setting state type (Michael Petlan) [2154066]
- perf intel-pt: Fix sync state when a PSB (synchronization) packet is found (Michael Petlan) [2154066]
- perf intel-pt: Fix some PGE (packet generation enable/control flow packets) usage (Michael Petlan) [2154066]
- perf intel-pt: decoder: Add config bit definitions (Michael Petlan) [2154066]
- perf intel-pt: pkt-decoder: Add MODE.Exec IFLAG bit (Michael Petlan) [2154066]
- perf intel-pt: pkt-decoder: Add CFE and EVD packets (Michael Petlan) [2154066]
- perf intel-pt: pkt-decoder: Remove misplaced linebreak (Michael Petlan) [2154066]
- perf intel-pt: pkt-decoder-test: Fix scope of test_data (Michael Petlan) [2154066]
- perf/x86/intel/pt: Add a capability and config bit for disabling TNTs (Michael Petlan) [2154066]
- perf/x86/intel/pt: Add a capability and config bit for event tracing (Michael Petlan) [2154068]
- container_of: Update header inclusions (Desnes Nunes) [2196368]
- media: netup_unidvb: fix irq init by register it at the end of probe (Desnes Nunes) [2196368]
- media: dvb-usb: dw2102: fix uninit-value in su3000_read_mac_address (Desnes Nunes) [2196368]
- media: dvb-usb: digitv: fix null-ptr-deref in digitv_i2c_xfer() (Desnes Nunes) [2196368]
- media: dvb-usb-v2: rtl28xxu: fix null-ptr-deref in rtl28xxu_i2c_xfer (Desnes Nunes) [2196368]
- media: dvb-usb-v2: ce6230: fix null-ptr-deref in ce6230_i2c_master_xfer() (Desnes Nunes) [2196368]
- media: dvb-usb-v2: ec168: fix null-ptr-deref in ec168_i2c_xfer() (Desnes Nunes) [2196368]
- media: dvb-usb: az6027: fix three null-ptr-deref in az6027_i2c_xfer() (Desnes Nunes) [2196368]
- Revert "usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS" (Desnes Nunes) [2196368]
- usb: typec: Don't try to register component master without components (Desnes Nunes) [2196368]
- usb: typec: Only attempt to link USB ports if there is fwnode (Desnes Nunes) [2196368]
- usb: core: Unregister device on component_add() failure (Desnes Nunes) [2196368]
- usb: core: add quirk for Alcor Link AK9563 smartcard reader (Desnes Nunes) [2196368]
- USB: new quirk for Dell Gen 2 devices (Desnes Nunes) [2196368]
- USB: quirks: add STRING quirk for VCOM device (Desnes Nunes) [2196368]
- USB: quirks: add a Realtek card reader (Desnes Nunes) [2196368]
- usb: typec: altmodes/displayport: Fix probe pin assign check (Desnes Nunes) [2196368]
- usb: typec: ucsi: Don't attempt to resume the ports before they exist (Desnes Nunes) [2196368]
- USB: misc: iowarrior: fix up header size for USB_DEVICE_ID_CODEMERCS_IOW100 (Desnes Nunes) [2196368]
- usb: host: ehci-fsl: Fix module alias (Desnes Nunes) [2196368]
- usb: core: hub: disable autosuspend for TI TUSB8041 (Desnes Nunes) [2196368]
- USB: fix misleading usb_set_intfdata() kernel doc (Desnes Nunes) [2196368]
- usb: typec: tcpm: Fix altmode re-registration causes sysfs create fail (Desnes Nunes) [2196368]
- usb: typec: altmodes/displayport: Use proper macro for pin assignment check (Desnes Nunes) [2196368]
- usb: typec: altmodes/displayport: Fix pin assignment calculation (Desnes Nunes) [2196368]
- usb: typec: altmodes/displayport: Add pin assignment helper (Desnes Nunes) [2196368]
- usb: ucsi: Ensure connector delayed work items are flushed (Desnes Nunes) [2196368]
- xhci: Detect lpm incapable xHC USB3 roothub ports from ACPI tables (Desnes Nunes) [2196368]
- usb: acpi: add helper to check port lpm capability using acpi _DSM (Desnes Nunes) [2196368]
- xhci: Add a flag to disable USB3 lpm on a xhci root port level. (Desnes Nunes) [2196368]
- xhci: Add update_hub_device override for PCI xHCI hosts (Desnes Nunes) [2196368]
- xhci: Fix null pointer dereference when host dies (Desnes Nunes) [2196368]
- usb: xhci: Check endpoint is valid before dereferencing it (Desnes Nunes) [2196368]
- xhci-pci: set the dma max_seg_size (Desnes Nunes) [2196368]
- usb-storage: apply IGNORE_UAS only for HIKSEMI MD202 on RTL9210 (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05CN modem (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05CN (SG) modem (Desnes Nunes) [2196368]
- USB: serial: cp210x: add SCALANCE LPE-9000 device id (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EC200U modem (Desnes Nunes) [2196368]
- USB: serial: qcserial: add EM9191 QDL support (Desnes Nunes) [2196368]
- USB: serial: option: add prod. id for Quectel EG91 (Desnes Nunes) [2196368]
- USB: serial: option: add Telit LE910Cx composition 0x1204 (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05-G (RS) modem (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05-G (GR) modem (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05-G (CS) modem (Desnes Nunes) [2196368]
- thunderbolt: Disable XDomain lane 1 only in software connection manager (Desnes Nunes) [2196368]
- thunderbolt: Use correct function to calculate maximum USB3 link rate (Desnes Nunes) [2196368]
- thunderbolt: Do not call PM runtime functions in tb_retimer_scan() (Desnes Nunes) [2196368]
- Revert "usb: ulpi: defer ulpi_register on ulpi_read_id timeout" (Desnes Nunes) [2196368]
- thunderbolt: Do not report errors if on-board retimers are found (Desnes Nunes) [2196368]
- treewide: Convert del_timer*() to timer_shutdown*() (Desnes Nunes) [2196368]
- USB: core: export usb_cache_string() (Desnes Nunes) [2196368]
- usb: ulpi: defer ulpi_register on ulpi_read_id timeout (Desnes Nunes) [2196368]
- usb: storage: Add check for kcalloc (Desnes Nunes) [2196368]
- USB: sisusbvga: use module_usb_driver() (Desnes Nunes) [2196368]
- USB: sisusbvga: rename sisusb.c to sisusbvga.c (Desnes Nunes) [2196368]
- USB: sisusbvga: remove console support (Desnes Nunes) [2196368]
- media: Switch to use dev_err_probe() helper (Desnes Nunes) [2196368]
- media: uvcvideo: Fix memory leak in uvc_gpio_parse (Desnes Nunes) [2196368]
- media: usb: pwc-uncompress: Use flex array destination for memcpy() (Desnes Nunes) [2196368]
- media: usb: pwc-uncompress: Use struct_size() helper in pwc_decompress() (Desnes Nunes) [2196368]
- firmware_loader: fix up to_fw_sysfs() to preserve const (Desnes Nunes) [2196368]
- usb.h: take advantage of container_of_const() (Desnes Nunes) [2196368]
- device.h: move kobj_to_dev() to use container_of_const() (Desnes Nunes) [2196368]
- container_of: add container_of_const() that preserves const-ness of the pointer (Desnes Nunes) [2196368]
- driver core: allow kobj_to_dev() to take a const pointer (Desnes Nunes) [2196368]
- container_of: remove container_of_safe() (Desnes Nunes) [2196368]
- linux/container_of.h: switch to static_assert (Desnes Nunes) [2196368]
- media: dvb-usb: m920x: make read-only arrays static const (Desnes Nunes) [2196368]
- net: thunderbolt: Use bitwise types in the struct thunderbolt_ip_frame_header (Desnes Nunes) [2196368]
- net: thunderbolt: Switch from __maybe_unused to pm_sleep_ptr() etc (Desnes Nunes) [2196368]
- USB: serial: f81534: fix division by zero on line-speed change (Desnes Nunes) [2196368]
- xhci: remove unused stream_id parameter from xhci_handle_halted_endpoint() (Desnes Nunes) [2196368]
- xhci: Prevent infinite loop in transaction errors recovery for streams (Desnes Nunes) [2196368]
- xhci: disable U3 suspended ports in S4 hibernate poweroff_late stage (Desnes Nunes) [2196368]
- USB: hcd-pci: Fully suspend across freeze/thaw cycle (Desnes Nunes) [2196368]
- USB: core: Disable remote wakeup for freeze/quiesce (Desnes Nunes) [2196368]
- xhci: export two xhci_hub functions for xhci-pci module usage (Desnes Nunes) [2196368]
- xhci: Apply XHCI_RESET_TO_DEFAULT quirk to ADL-N (Desnes Nunes) [2196368]
- xhci: print warning when HCE was set (Desnes Nunes) [2196368]
- Revert "xhci: Convert to use list_count()" (Desnes Nunes) [2196368]
- xhci: Convert to use list_count() (Desnes Nunes) [2196368]
- usb: typec: Add partner PD object wrapper (Desnes Nunes) [2196368]
- usb: xhci-mtk: fix leakage of shared hcd when fail to set wakeup irq (Desnes Nunes) [2196368]
- usb: add usb_set_intfdata() documentation (Desnes Nunes) [2196368]
- usb: host: fix a typo in ehci.h (Desnes Nunes) [2196368]
- usb: core: hcd: Fix return value check in usb_hcd_setup_local_mem() (Desnes Nunes) [2196368]
- usb: typec: ucsi: Resume in separate work (Desnes Nunes) [2196368]
- usb: roles: fix of node refcount leak in usb_role_switch_is_parent() (Desnes Nunes) [2196368]
- net: thunderbolt: Use kmap_local_page() instead of kmap_atomic() (Desnes Nunes) [2196368]
- media: dvb-usb: az6027: fix null-ptr-deref in az6027_i2c_xfer() (Desnes Nunes) [2196368]
- media: dvb-usb: dib0700_devices: Remove unused struct dibx090p_adc (Desnes Nunes) [2196368]
- media: dib0700: remove orphan dvb_usb_dib0700_ir_proto declaration (Desnes Nunes) [2196368]
- media: dvb-usb: fix memory leak in dvb_usb_adapter_init() (Desnes Nunes) [2196368]
- media: dvb-core: Enhance shared multi-frontend support (Desnes Nunes) [2196368]
- media: docs: fix minor typos (Desnes Nunes) [2196368]
- media: dvb-frontends: a8293: fix LNB powerup failure in PCTV 461e (Desnes Nunes) [2196368]
- USB: serial: kl5kusb105: drop line-status helper (Desnes Nunes) [2196368]
- USB: serial: kl5kusb105: simplify line-status handling (Desnes Nunes) [2196368]
- USB: serial: kl5kusb105: clean up line-status handling (Desnes Nunes) [2196368]
- USB: serial: cp210x: add support for B0 hangup (Desnes Nunes) [2196368]
- USB: serial: cp210x: add Kamstrup RF sniffer PIDs (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05-G modem (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel RM520N (Desnes Nunes) [2196368]
- USB: serial: ch341: fix lost character on LCR updates (Desnes Nunes) [2196368]
- USB: serial: ch314: use usb_control_msg_recv() (Desnes Nunes) [2196368]
- USB: serial: option: add support for Cinterion MV32-WA/WB RmNet mode (Desnes Nunes) [2196368]
- USB: serial: option: add support for Cinterion MV31 with new baseline (Desnes Nunes) [2196368]
- USB: serial: io_ti: add Agilent E5805A support (Desnes Nunes) [2196368]
- USB: serial: whiteheat: fix heap overflow in WHITEHEAT_GET_DTR_RTS (Desnes Nunes) [2196368]
- USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader (Desnes Nunes) [2196368]
- USB: serial: option: add support for Cinterion MV32-WA/MV32-WB (Desnes Nunes) [2196368]
- USB: serial: option: add Telit 0x1057, 0x1058, 0x1075 compositions (Desnes Nunes) [2196368]
- USB: serial: option: add Telit FN990 compositions (Desnes Nunes) [2196368]
- USB: serial: cp210x: add ID for GW Instek GDM-834x Digital Multimeter (Desnes Nunes) [2196368]
- USB: serial: cp210x: add part-number debug printk (Desnes Nunes) [2196368]
- USB: serial: option: add Telit LN920 compositions (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM060K modem (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel RM500K module support (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EM05-G modem (Desnes Nunes) [2196368]
- USB: serial: option: add Quectel EC200S-CN module support (Desnes Nunes) [2196368]
- USB: serial: pl2303: add support for more HXN (G) types (Desnes Nunes) [2196368]
- USB: serial: option: add Telit LE910Cx 0x1250 composition (Desnes Nunes) [2196368]
- usb: typec: tipd: Set mode of operation for USB Type-C connector (Desnes Nunes) [2196368]
- usb: typec: tipd: Move tps6598x_disconnect error path to its own label (Desnes Nunes) [2196368]
- usb: typec: tipd: Fix typec_unregister_port error paths (Desnes Nunes) [2196368]
- usb: typec: tipd: Only update power status on IRQ (Desnes Nunes) [2196368]
- usb: typec: tipd: Forward plug orientation to typec subsystem (Desnes Nunes) [2196368]
- tps6598x: clear int mask on probe failure (Desnes Nunes) [2196368]
- usb: typec: tipd: Fix initialization sequence for cd321x (Desnes Nunes) [2196368]
- usb: typec: tipd: Fix typo in cd321x_switch_power_state (Desnes Nunes) [2196368]
- usb: typec: tipd: Enable event interrupts by default (Desnes Nunes) [2196368]
- usb: typec: tipd: Remove FIXME about testing with I2C_FUNC_I2C (Desnes Nunes) [2196368]
- usb: typec: tipd: Switch CD321X power state to S0 (Desnes Nunes) [2196368]
- usb: typec: tipd: Add support for Apple CD321X (Desnes Nunes) [2196368]
- usb: typec: tipd: Add short-circuit for no irqs (Desnes Nunes) [2196368]
- usb: typec: tipd: Split interrupt handler (Desnes Nunes) [2196368]
- dt-bindings: usb: tps6598x: Add Apple CD321x compatible (Desnes Nunes) [2196368]
- dt-bindings: usb: Add TI tps6598x device tree binding documentation (Desnes Nunes) [2196368]
- usb: typec: tipd: Remove WARN_ON in tps6598x_block_read (Desnes Nunes) [2196368]
- usb: typec: tipd: Add an additional overflow check (Desnes Nunes) [2196368]
- usb: typec: tipd: Don't read/write more bytes than required (Desnes Nunes) [2196368]
- usb: typec: tipd: Fix spurious fwnode_handle_put in error path (Desnes Nunes) [2196368]
- usb: typec: tipd: Cleanup resources if devm_tps6598_psy_register fails (Desnes Nunes) [2196368]
- usb: host: xhci-mtk: omit shared hcd if either root hub has no ports (Desnes Nunes) [2196368]
- usb: xhci-mtk: enable wake-up interrupt after runtime_suspend called (Desnes Nunes) [2196368]
- usb: typec: tcpci: fix of node refcount leak in tcpci_register_port() (Desnes Nunes) [2196368]
- usb: typec: Check for ops->exit instead of ops->enter in altmode_exit (Desnes Nunes) [2196368]
- usb: ftdi-elan: remove variable l (Desnes Nunes) [2196368]
- Documentation: USB: correct possessive "its" usage (Desnes Nunes) [2196368]
- usb: Check !irq instead of irq == NO_IRQ (Desnes Nunes) [2196368]
- tools: usb: ffs-aio-example: Fix build error with aarch64-*-gnu-gcc toolchain(s) (Desnes Nunes) [2196368]
- usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS (Desnes Nunes) [2196368]
- usb: ehci-pci: Set PROBE_PREFER_ASYNCHRONOUS (Desnes Nunes) [2196368]
- dt-bindings: usb: usb-drd: Describe default dual-role mode (Desnes Nunes) [2196368]
- dt-bindings: usb: xhci: Add Broadcom STB v2 compatible device (Desnes Nunes) [2196368]
- dt-bindings: usb: Convert xHCI bindings to DT schema (Desnes Nunes) [2196368]
- usb: host: Add ability to build new Broadcom STB USB drivers (Desnes Nunes) [2196368]
- dt-bindings: Add Broadcom STB USB support (Desnes Nunes) [2196368]
- dt-bindings: usb: Add generic "usb-phy" property (Desnes Nunes) [2196368]
- dt-bindings: usb: usb-hcd: Add "tpl-support" property (Desnes Nunes) [2196368]
- dt-bindings: usb: Add "ulpi/serial/hsic" PHY types (Desnes Nunes) [2196368]
- dt-bindings: usb: usb-drd: Add "otg-rev" property constraints (Desnes Nunes) [2196368]
- dt-bindings: usb: Convert generic USB properties to DT schemas (Desnes Nunes) [2196368]
- dt-bindings: usb: mtu3: add properties about USB Role Switch (Desnes Nunes) [2196368]
- dt-bindings: usb: add binding for USB GPIO based connection detection driver (Desnes Nunes) [2196368]
- dt-bindings: connector: add optional properties for Type-B (Desnes Nunes) [2196368]
- dt-bindings: connector: Add self-powered property (Desnes Nunes) [2196368]
- dt-bindings: usb: generic: Add role-switch-default-mode binding (Desnes Nunes) [2196368]
- dt-binding: usb: add usb-role-switch property (Desnes Nunes) [2196368]
- dt-binding: usb: add "super-speed-plus" (Desnes Nunes) [2196368]
- dt-bindings: usb: usb-hcd: Detach generic USB controller properties (Desnes Nunes) [2196368]
- dt-bindings: Explicitly allow additional properties in common schemas (Desnes Nunes) [2196368]
- dt-bindings: usb: Bring back phy-names (Desnes Nunes) [2196368]
- usb: core: stop USB enumeration if too many retries (Desnes Nunes) [2196368]
- usb: hub: port: add sysfs entry to switch port power (Desnes Nunes) [2196368]
- usb: typec: port-mapper: Convert to the component framework (Desnes Nunes) [2196368]
- usb: Link the ports to the connectors they are attached to (Desnes Nunes) [2196368]
- usb: Remove usb_for_each_port() (Desnes Nunes) [2196368]
- thunderbolt: Add wake on connect/disconnect on USB4 ports (Desnes Nunes) [2196368]
- thunderbolt: Link USB4 ports to their USB Type-C connectors (Desnes Nunes) [2196368]
- usb: core: Use kstrtobool() instead of strtobool() (Desnes Nunes) [2196368]
- kernel.h: split out kstrtox() and simple_strtox() to a separate header (Desnes Nunes) [2196368]
- USB: core: Change configuration warnings to notices (Desnes Nunes) [2196368]
- thunderbolt: ACPI: Use the helper fwnode_find_reference() (Desnes Nunes) [2196368]
- thunderbolt: Remove redundant assignment to variable len (Desnes Nunes) [2196368]
- thunderbolt: Use str_enabled_disabled() helper (Desnes Nunes) [2196368]
- media: device property: Add a function to test is a fwnode is a graph endpoint (Desnes Nunes) [2196368]
- usb: typec: mux: Allow multiple mux_devs per mux (Desnes Nunes) [2196368]
- usb: typec: mux: Introduce indirection (Desnes Nunes) [2196368]
- device property: Use multi-connection matchers for single case (Desnes Nunes) [2196368]
- device property: Fix fwnode_graph_devcon_match() fwnode leak (Desnes Nunes) [2196368]
- device property: Add helper to match multiple connections (Desnes Nunes) [2196368]
- Documentation: Remove device connection documentation (Desnes Nunes) [2196368]
- usb: ftdi-elan: remove variable err_count (Desnes Nunes) [2196368]
- USB: make devnode() callback in usb_class_driver take a const * (Desnes Nunes) [2196368]
- USB: remove usb_bus_type from usb.h (Desnes Nunes) [2196368]
- USB: allow some usb functions to take a const pointer. (Desnes Nunes) [2196368]

* Thu Jun 22 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-499.el8]
- s390/ap: Fix hanging ioctl caused by orphaned replies (Tobias Huschle) [2215891]
- crypto: jitter - correct health test during initialization (Vladis Dronov) [2214270]
- x86: properly define CONFIG_AS_TPAUSE in Makefile (Nico Pache) [2193009]
- zsmalloc: fix races between asynchronous zspage free and page migration (Oleksandr Natalenko) [2213146]
- netfilter: ip6t_rpfilter: Fix regression with VRF interfaces (Phil Sutter) [2169958]
- x86/mm: Avoid incomplete Global INVLPG flushes (Rafael Aquini) [2213793]
- rbd: get snapshot context after exclusive lock is ensured to be held (Ilya Dryomov) [2214973]
- rbd: move RBD_OBJ_FLAG_COPYUP_ENABLED flag setting (Ilya Dryomov) [2214973]
- vfio/pci: Also demote hiding standard cap messages (Oleksandr Natalenko) [2207849]
- vfio/pci: demote hiding ecap messages to debug level (Oleksandr Natalenko) [2207849]
- mm: avoid unnecessary page fault retires on shared memory types (Nico Pache) [2213877]
- mm: remove redundant check about FAULT_FLAG_ALLOW_RETRY bit (Nico Pache) [2213877]
- mm: Allow the [page|pfn]_mkwrite callbacks to drop the mmap_sem (Nico Pache) [2213877]
- s390/qeth: convert sysfs snprintf to sysfs_emit (Tobias Huschle) [2203380]
- s390/lcs: Fix return type of lcs_start_xmit() (Tobias Huschle) [2203380]
- s390/netiucv: Fix return type of netiucv_tx() (Tobias Huschle) [2203380]
- s390/ctcm: Fix return type of ctc{mp,}m_tx() (Tobias Huschle) [2203380]
- s390/pci: clean up left over special treatment for function zero (Tobias Huschle) [2214268]
- s390/pci: remove redundant pci_bus_add_devices() on new bus (Tobias Huschle) [2214268]
- s390/pci: only add specific device in zpci_bus_scan_device() (Tobias Huschle) [2214268]
- PCI: s390: Fix use-after-free of PCI resources with per-function hotplug (Tobias Huschle) [2214268]
- net: atlantic: fix potential memory leak in aq_ndev_close() (Íñigo Huguet) [2184353]
- net: atlantic: fix aq_vec index out of range error (Íñigo Huguet) [2179726 2184353]
- net: atlantic: verify hw_head_ lies within TX buffer ring (Íñigo Huguet) [2184353]
- net: atlantic: add check for MAX_SKB_FRAGS (Íñigo Huguet) [2184353]
- net: atlantic: reduce scope of is_rsc_complete (Íñigo Huguet) [2184353]
- net: atlantic: fix "frag[0] not initialized" (Íñigo Huguet) [2184353]
- net: atlantic: Avoid out-of-bounds indexing (Íñigo Huguet) [2179726 2184353]
- atlantic: Fix buff_ring OOB in aq_ring_rx_clean (Íñigo Huguet) [2184353]
- atlantic: Remove warn trace message. (Íñigo Huguet) [2184353]
- atlantic: Fix statistics logic for production hardware (Íñigo Huguet) [2184353]
- atlantic: Add missing DIDs and fix 115c. (Íñigo Huguet) [2184353]
- atlantic: Fix to display FW bundle version instead of FW mac version. (Íñigo Huguet) [2184353]
- atlantic: Increase delay for fw transactions (Íñigo Huguet) [2184353]
- atlantic: fix double-free in aq_ring_tx_clean (Íñigo Huguet) [2184353]
- atlantic: Fix OOB read and write in hw_atl_utils_fw_rpc_wait (Íñigo Huguet) [2184353]
- net: ethernet: aquantia: Handle error cleanup of start on open (Íñigo Huguet) [2184353]
- aquantia: Remove the build_skb path (Íñigo Huguet) [2184353]
- net: fix __dev_kfree_skb_any() vs drop monitor (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to icmpv6_echo_reply() (Antoine Tenart) [2184076]
- ipv6: icmp6: add SKB_DROP_REASON_IPV6_NDISC_NS_OTHERHOST (Antoine Tenart) [2184076]
- ipv6: icmp6: add SKB_DROP_REASON_IPV6_NDISC_BAD_OPTIONS (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to ndisc_redirect_rcv() (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to ndisc_router_discovery() (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to ndisc_recv_rs() (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to ndisc_recv_na() (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to ndisc_recv_ns() (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to ndisc_rcv() (Antoine Tenart) [2184076]
- ipv6: icmp6: add drop reason support to icmpv6_notify() (Antoine Tenart) [2184076]
- net: add pskb_may_pull_reason() helper (Antoine Tenart) [2184076]
- net-next: skbuff: refactor pskb_pull (Antoine Tenart) [2184076]
- net: dropreason: add SKB_DROP_REASON_IPV6_BAD_EXTHDR (Antoine Tenart) [2184076]
- rxrpc: Use consume_skb() rather than kfree_skb_reason() (Antoine Tenart) [2184076]
- ipv4: raw: add drop reasons (Antoine Tenart) [2184076]
- ipv6: raw: add drop reasons (Antoine Tenart) [2184076]
- tcp: add TCP_MINTTL drop reason (Antoine Tenart) [2184076]
- net: fix call location in kfree_skb_list_reason (Antoine Tenart) [2184076]
- rxrpc: Show consumed and freed packets as non-dropped in dropwatch (Antoine Tenart) [2184076]
- net: tun: rebuild error handling in tun_get_user (Antoine Tenart) [2184076]
- ALSA: Update kernel configuration for 8.9 (Jaroslav Kysela) [2179850]
- soundwire: stream: Add missing clear of alloc_slave_rt (Jaroslav Kysela) [2179850]
- soundwire: dmi-quirks: add new mapping for HP Spectre x360 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Enable 4 amplifiers instead of 2 on a HP platform (Jaroslav Kysela) [2179850]
- ALSA: hda: Fix kctl->id initialization (Jaroslav Kysela) [2179850]
- ALSA: gus: Fix kctl->id initialization (Jaroslav Kysela) [2179850]
- ALSA: cmipci: Fix kctl->id initialization (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Fix kctl->id initialization (Jaroslav Kysela) [2179850]
- ALSA: ice1712,ice1724: fix the kcontrol->id initialization (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for Clevo NS50AU (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirks for Asus ROG 2024 laptops using CS35L41 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add "Intel Reference board" and "NUC 13" SSID in the ALC256 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add Lenovo P3 Tower platform (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add a quirk for HP Slim Desktop S01 (Jaroslav Kysela) [2179850]
- ASoC: simple-card-utils: fix PCM constraint error check (Jaroslav Kysela) [2179850]
- ASoC: max98363: limit the number of channel to 1 (Jaroslav Kysela) [2179850]
- ASoC: max98363: Removed 32bit support (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add Thinkpad Neo14 to quirks list for acp6x (Jaroslav Kysela) [2179850]
- ASoC: nau8824: Add quirk to active-high jack-detect (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: fix for acp_lock access in pdm driver (Jaroslav Kysela) [2179850]
- ASoC: simple-card: Add missing of_node_put() in case of error (Jaroslav Kysela) [2179850]
- ASoC: codecs: wsa881x: do not set can_multi_write flag (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: remove code for module namespaces (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Enable headset onLenovo M70/M90 (Jaroslav Kysela) [2179850]
- regmap: sdw: check for invalid multi-register writes config (Jaroslav Kysela) [2179850]
- ALSA: hda/ca0132: add quirk for EVGA X299 DARK (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add missing checks on FE startup (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Fix avs_path_module::instance_id size (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Account for UID of ACPI device (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Fix declaration of enum avs_channel_config (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Fix declaration of enum skl_ch_cfg (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Access path components under lock (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Fix module lookup (Jaroslav Kysela) [2179850]
- ALSA: hda: Fix unhandled register update during auto-suspend period (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm: test if a BE can be prepared (Jaroslav Kysela) [2179850]
- ALSA: hda: Add NVIDIA codec IDs a3 through a7 to patch table (Jaroslav Kysela) [2179850]
- ALSA: oss: avoid missing-prototype warnings (Jaroslav Kysela) [2179850]
- ALSA: cs46xx: mark snd_cs46xx_download_image as static (Jaroslav Kysela) [2179850]
- ALSA: hda: Fix Oops by 9.1 surround channel names (Jaroslav Kysela) [2179850]
- ASoC: rt5682: Disable jack detection interrupt during suspend (Jaroslav Kysela) [2179850]
- ASoC: SOF: Separate the tokens for input and output pin index (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Fix tuples array allocation (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helper to program SoundWire PCMSyCM registers (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: initialize instance_offset member (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: use 'ml_addr' parameter consistently (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: fix base_ptr computation (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helper to get SoundWire hlink (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: fix sublink refcounting (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Fix logic for copying tuples (Jaroslav Kysela) [2179850]
- ASoC: dwc: move DMA init to snd_soc_dai_driver probe() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc3-topology: Make sure that only one cmd is sent in dai_config (Jaroslav Kysela) [2179850]
- ASoC: SOF: pm: save io region state in case of errors in resume (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-client-probes: fix pm_runtime imbalance in error handling (Jaroslav Kysela) [2179850]
- ASoC: SOF: pcm: fix pm_runtime imbalance in error handling (Jaroslav Kysela) [2179850]
- ASoC: SOF: debug: conditionally bump runtime_pm counter on exceptions (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Fix mute and micmute LEDs for yet another HP laptop (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Add a sample rate workaround for Line6 Pod Go (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Apply HP B&O top speaker profile to Pavilion 15 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirks for ASUS GU604V and GU603V (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for HP EliteBook G10 laptops (Jaroslav Kysela) [2179850]
- tools include UAPI: Sync the sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2179850]
- firewire: net: fix unexpected release of object for asynchronous request packet (Jaroslav Kysela) [2179850]
- ASoC: ssm2602: Add workaround for playback distortions (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Fix NULL pointer crash in acp_sof_ipc_msg_data function (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add a quirk for HP EliteDesk 805 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for 2nd ASUS GU603 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for Clevo L140AU (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add DMI entry to support System76 Pangolin 12 (Jaroslav Kysela) [2179850]
- ALSA: pcm: use exit controlled loop in snd_pcm_playback_silence() (Jaroslav Kysela) [2179850]
- ALSA: pcm: simplify top-up mode init in snd_pcm_playback_silence() (Jaroslav Kysela) [2179850]
- ALSA: pcm: playback silence - move silence variable updates to separate function (Jaroslav Kysela) [2179850]
- ALSA: pcm: playback silence - remove extra code (Jaroslav Kysela) [2179850]
- ALSA: pcm: fix playback silence - correct incremental silencing (Jaroslav Kysela) [2179850]
- ALSA: pcm: fix playback silence - use the actual new_hw_ptr for the threshold mode (Jaroslav Kysela) [2179850]
- ALSA: pcm: Revert "ALSA: pcm: rewrite snd_pcm_playback_silence()" (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Fix mute and micmute LEDs for an HP laptop (Jaroslav Kysela) [2179850]
- ALSA: caiaq: input: Add error handling for unsupported input methods in `snd_usb_caiaq_input_init` (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Add quirk for Pioneer DDJ-800 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: support HP Pavilion Aero 13-be0xxx Mute LED (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for ASUS UM3402YAR using CS35L41 (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add Asus VivoBook Pro 14 OLED M6400RC to the quirks list for acp6x (Jaroslav Kysela) [2179850]
- ALSA: docs: Extend module parameters description (Jaroslav Kysela) [2179850]
- ASoC: Intel: soc-acpi-cht: Add quirk for Nextbook Ares 8A tablet (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: use more existing defines instead of open-coded numbers (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add ASUS M3402RA into DMI table (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for ThinkPad P1 Gen 6 (Jaroslav Kysela) [2179850]
- ALSA: hda: Glenfly: add HD Audio PCI IDs and HDMI Codec Vendor IDs. (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: use high-level I/O in set_filterQ() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fix error handling in snd_audigy_i2c_volume_put() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: don't stop DSP in _snd_emu10k1_{,audigy_}init_efx() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: skip Sound Blaster-specific hacks for E-MU cards (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fixup DSP defines (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: use high-level I/O functions also during init (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fix SNDRV_EMU10K1_IOCTL_SINGLE_STEP (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: pull in some register definitions from kX-project (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove some bogus defines (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: eliminate some unused defines (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fix lineup of EMU_HANA_* defines (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: comment updates (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fix snd_emu1010_fpga_read() input masking for rev2 cards (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove unused emu->pcm_playback_efx_substream field (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove unused `resume` parameter from snd_emu10k1_init() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: minor optimizations (Jaroslav Kysela) [2179850]
- ASoC: max98090: make it selectable (Jaroslav Kysela) [2179850]
- ASoC: Intel: soc-acpi-byt: Fix "WM510205" match no longer working (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Rate limit usb_set_interface error reporting (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove remaining cruft from snd_emu10k1_emu1010_init() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: clean up P16V part somewhat (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: clarify various fx8010.*_mask fields (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove apparently pointless EMU_HANA_OPTION_CARDS reads (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove apparently pointless FPGA reads (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove unused snd_emu10k1_voice.emu field (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: stop doing weird things with HCFG in snd_emu10k1_emu1010_init() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: remove obsolete card type variable and defines (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fix access to Audigy GPIO port (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: drop redundant snd_emu10k1_efx_playback_pointer() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: properly assert E-MU FPGA access constaints (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: drop redundant snd_emu10k1_efx_playback_hw_free() (Jaroslav Kysela) [2179850]
- ASoC: SOF: pcm: Add an option to skip platform trigger during stop (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Do not stop/start DMA during pause/release (Jaroslav Kysela) [2179850]
- ALSA: pcm: rewrite snd_pcm_playback_silence() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Split the set_power_op for IPC3 and IPC4 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_sdw: append codec type to dai link name (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_sdw: support different devices on the same sdw link (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_sdw: set codec_num = 1 if the device is not aggregated (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_sdw_max98373: change sof_sdw_mx8373_late_probe to static call (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_sdw: remove late_probe flag in struct sof_sdw_codec_info (Jaroslav Kysela) [2179850]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw at link 2 in RPL match table (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_cirrus_common: Guard against missing buses (Jaroslav Kysela) [2179850]
- ASoC: SOF: Use no_reply calls for TX (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc: Add no reply inline calls (Jaroslav Kysela) [2179850]
- ASoC: es8316: Don't use ranges based register lookup for a single register (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Remove specific patch for Dell Precision 3260 (Jaroslav Kysela) [2179850]
- ASoC: nau8825: fix bounds check for adc_delay (Jaroslav Kysela) [2179850]
- ASoC: codecs: wcd934x: Simplify &pdev->dev in probe (Jaroslav Kysela) [2179850]
- ASoC: codecs: wcd934x: Simplify with dev_err_probe (Jaroslav Kysela) [2179850]
- ASoC: codecs: wcd9335: Simplify with dev_err_probe (Jaroslav Kysela) [2179850]
- ALSA: hda/hdmi: Remove some dead code (Jaroslav Kysela) [2179850]
- ASoC: cs35l41: Fix default regmap values for some registers (Jaroslav Kysela) [2179850]
- ASoC: ssm2602: Add support for CLKDIV2 (Jaroslav Kysela) [2179850]
- ASoC: nau8825: Add delay control for input path (Jaroslav Kysela) [2179850]
- ALSA: hda/hdmi: disable KAE for Intel DG2 (Jaroslav Kysela) [2179850]
- ASoC: da7218: Use devm_clk_get_optional() (Jaroslav Kysela) [2179850]
- ASoC: da7219: Improve the relability of AAD IRQ process (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirks for Lenovo Z13/Z16 Gen2 (Jaroslav Kysela) [2179850]
- ASoC: amd: Add check for acp config flags (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add ThinkBook 14 G5+ ARP to quirks list for acp6x (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: fix page fault in dspless mode when DSP is disabled (Jaroslav Kysela) [2179850]
- ASoC: tas5720: add missing unwind goto in tas5720_codec_probe (Jaroslav Kysela) [2179850]
- ASoC: ep93xx: Add OF support (Jaroslav Kysela) [2179850]
- ASoC: ep93xx: i2s: Make it individually selectable (Jaroslav Kysela) [2179850]
- ASoC: cs4271: flat regcache, trivial simplifications (Jaroslav Kysela) [2179850]
- ASoC: ep93xx: i2s: move enable call to startup callback (Jaroslav Kysela) [2179850]
- ASoC: amd: Add Dell G15 5525 to quirks list (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Print the format_val as hexadecimal number (Jaroslav Kysela) [2179850]
- ASoC: max98373: change power down sequence for smart amp (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: conditionally wake WPIO1PG domain (Jaroslav Kysela) [2179850]
- ASoC: Intel: Add rpl_mx98360_rt5682 driver (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: add __func__ in SoundWire lcount() error logs (Jaroslav Kysela) [2179850]
- ALSA: hda: patch_realtek: add quirk for Asus N7601ZM (Jaroslav Kysela) [2179850]
- ALSA: hda: LNL: add HD Audio PCI ID (Jaroslav Kysela) [2179850]
- ASoC: max98363: Make soc_codec_dev_max98363 static (Jaroslav Kysela) [2179850]
- soundwire: bus: Fix unbalanced pm_runtime_put() causing usage count underflow (Jaroslav Kysela) [2179850]
- ALSA: firewire-tascam: add missing unwind goto in snd_tscm_stream_start_duplex() (Jaroslav Kysela) [2179850]
- ALSA: document that struct __snd_pcm_mmap_control64 is messed up (Jaroslav Kysela) [2179850]
- ASoC: rt712-sdca: Add RT712 SDCA driver for Mic topology (Jaroslav Kysela) [2179850]
- ASoC: add snd_soc_card_mutex_lock/unlock() (Jaroslav Kysela) [2179850]
- ASoC: expand snd_soc_dpcm_mutex_lock/unlock() (Jaroslav Kysela) [2179850]
- ASoC: expand snd_soc_dapm_mutex_lock/unlock() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: tidyup dapm_connect_dai_pair() (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: documentation updates (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: update label & help in config system (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: don't create old pass-through playback device on Audigy (Jaroslav Kysela) [2179850]
- ALSA: emu10k1: fix capture interrupt handler unlinking (Jaroslav Kysela) [2179850]
- ALSA: hda/sigmatel: fix S/PDIF out on Intel D*45* motherboards (Jaroslav Kysela) [2179850]
- ALSA: i2c/cs8427: fix iec958 mixer control deactivation (Jaroslav Kysela) [2179850]
- ALSA: hda/sigmatel: add pin overrides for Intel DP45SG motherboard (Jaroslav Kysela) [2179850]
- ALSA: pcm: fix wait_time calculations (Jaroslav Kysela) [2179850]
- ASoC: SOF: pm: Tear down pipelines only if DSP was active (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helper to retrieve eml_lock (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helper to offload link ownership (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helpers to retrieve DMIC/SSP hlink (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: program SoundWire LSDIID registers (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helper to check cmdsync (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helpers for sync_arm/sync_go (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helpers to set link SYNC frequency (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helpers to enable/check interrupts (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helper to return sublink count (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add convenience helpers for SoundWire PM (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: introduce helpers for 'extended links' PM (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: special-case HDaudio regular links (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add structures to parse ALT links (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: move to a dedicated module (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add return value for hda_bus_ml_get_capabilities() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: improve hda_bus_ml_free() helper (Jaroslav Kysela) [2179850]
- ALSA: hda: add HDaudio Extended link definitions (Jaroslav Kysela) [2179850]
- Documentation: sound: add description of Intel HDaudio multi-links (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-tgl: Allow DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-skl: Allow DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-mtl: Allow DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-icl: Allow DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-cnl: Allow DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-apl: Allow DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: make DSPless mode work with DSP disabled in BIOS (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Add support for DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Skip interfaces not supported on a platform (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add support for DSPless mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add flag and state which will be used for DSP-less mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-stream: Do not dereference hstream until it is safe (Jaroslav Kysela) [2179850]
- ASoC: tegra20_ac97: Add missing unwind goto in tegra20_ac97_platform_probe() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Clarify bind failure caused by missing fw_module (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: refactor dmic codec platform device creation (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: refactor error checks in probe call (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: refactor get_chip_info callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: remove unused variables (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: remove acp_dai_probe() function (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: remove unused code (Jaroslav Kysela) [2179850]
- ASoC: soc.h: remove unused params/num_params (Jaroslav Kysela) [2179850]
- ASoC: samsung: switch to use c2c_params instead of params (Jaroslav Kysela) [2179850]
- ASoC: audio-graph-card2: switch to use c2c_params instead of params (Jaroslav Kysela) [2179850]
- ASoC: soc.h: clarify Codec2Codec params (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add DMI entries to support HP OMEN 16-n0xxx (8A42) (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for Clevo X370SNW (Jaroslav Kysela) [2179850]
- ALSA: hda/hdmi: Preserve the previous PCM device upon re-enablement (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: update the acp clock source. (Jaroslav Kysela) [2179850]
- ASoC: max98363: add soundwire amplifier driver (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4/intel: Fix spelling mistake "schduler" -> "scheduler" (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4/intel: Add missing mutex_unlock() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4/intel: Add support for chained DMA (Jaroslav Kysela) [2179850]
- ASoC: SOF: avoid a NULL dereference with unsupported widgets (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Use register macro in place of integer literal (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Use u16 consistently for old_legacy_ctrl (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Store additional legacy registers on suspend (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Store saved legacy registers in an array (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Move allocation of saved registers to struct snd_ymfpci (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Switch to DEFINE_SIMPLE_DEV_PM_OPS() (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Add error messages for abritrary IO ports on older chips (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Fix BUG_ON in probe function (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: Create card with device-managed snd_devm_card_new() (Jaroslav Kysela) [2179850]
- ASoC: soc-topology.c: dai_link->platform again (Jaroslav Kysela) [2179850]
- firmware: cs_dsp: Add a debugfs entry containing control details (Jaroslav Kysela) [2179850]
- ASoC: wm8903: Remove outdated DMIC comment (Jaroslav Kysela) [2179850]
- ASoC: es8316: Handle optional IRQ assignment (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for Lenovo ZhaoYang CF4620Z (Jaroslav Kysela) [2179850]
- ASoC: da7213.c: add missing pm_runtime_disable() (Jaroslav Kysela) [2179850]
- ASoC: audio-graph-card2-custom-sample.dtsi: use card->name to avoid long name (Jaroslav Kysela) [2179850]
- ASoC: soc-core.c: add snd_soc_add_pcm_runtimes() (Jaroslav Kysela) [2179850]
- ALSA: asihpi: remove unused loop_count variable (Jaroslav Kysela) [2179850]
- ASoC: hdac_hdmi: use set_stream() instead of set_tdm_slots() (Jaroslav Kysela) [2179850]
- ASoC: dapm: Sort speakers after other outputs (Jaroslav Kysela) [2179850]
- ASoC: soc-compress: Inherit atomicity from DAI link for Compress FE (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Fix regression on detection of Roland VS-100 (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt5682-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt715-sdca: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt715: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt712-sdca: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt711-sdca: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt711-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt700-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt1318-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt1316-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt1308-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: max98373-sdw: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: sdw-mockup: simplify set_stream (Jaroslav Kysela) [2179850]
- ASoC: codecs: cs42l42-sdw: clear stream (Jaroslav Kysela) [2179850]
- ASoC: simple-card.c: add missing of_node_put() (Jaroslav Kysela) [2179850]
- ASoC: soc-topology.c: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179850]
- ASoC: ti: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179850]
- ASoC: atmel: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179850]
- ALSA: hdspm: remove unused copy_u32_le function (Jaroslav Kysela) [2179850]
- ALSA: docs: A few more words for PCM XRUN handling and stream locks (Jaroslav Kysela) [2179850]
- ALSA: docs: Add description about ack callback -EPIPE error handling (Jaroslav Kysela) [2179850]
- ALSA: pcm: Improved XRUN handling for indirect PCM helpers (Jaroslav Kysela) [2179850]
- soundwire: intel_auxdevice: improve pm_prepare step (Jaroslav Kysela) [2179850]
- soundwire: bus: Update sdw_nread/nwrite_no_pm to handle page boundaries (Jaroslav Kysela) [2179850]
- soundwire: bus: Update kernel doc for no_pm functions (Jaroslav Kysela) [2179850]
- soundwire: bus: Remove now outdated comments on no_pm IO (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Fix support for Dell Precision 3260 (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Acer Iconia One 7 B1-750 (Jaroslav Kysela) [2179850]
- ASoC: SOF: pcm: Improve the pcm trigger sequence (Jaroslav Kysela) [2179850]
- ASoC: SOF: pcm: Make hw_params reset conditional for IPC3 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Do not perform DMA cleanup during stop (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Ensure DSP is in D0I0 during sof_ipc4_set_get_data() (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: Remove conditional dpcm_capture setting (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: Update BT offload config for MTL RVP (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: Update BT offload config for Rex (Jaroslav Kysela) [2179850]
- soundwire: stream: uniquify dev_err() logs (Jaroslav Kysela) [2179850]
- soundwire: stream: remove bus->dev from logs on multiple buses (Jaroslav Kysela) [2179850]
- ASoC: tegra: remove unneeded semicolon (Jaroslav Kysela) [2179850]
- ASoC: simple-card: add comment to indicate don't remove platforms (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-control: Return on error in sof_ipc4_widget_kcontrol_setup() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Add macros for chain-dma message bits (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Set pipeline widget before updating IPC structures (Jaroslav Kysela) [2179850]
- soundwire: amd: add pm_prepare callback and pm ops support (Jaroslav Kysela) [2179850]
- soundwire: amd: handle SoundWire wake enable interrupt (Jaroslav Kysela) [2179850]
- soundwire: amd: add runtime pm ops for AMD SoundWire manager driver (Jaroslav Kysela) [2179850]
- soundwire: amd: add SoundWire manager interrupt handling (Jaroslav Kysela) [2179850]
- soundwire: amd: enable build for AMD SoundWire manager driver (Jaroslav Kysela) [2179850]
- soundwire: amd: register SoundWire manager dai ops (Jaroslav Kysela) [2179850]
- soundwire: amd: Add support for AMD Manager driver (Jaroslav Kysela) [2179850]
- soundwire: export sdw_compute_slave_ports() function (Jaroslav Kysela) [2179850]
- soundwire: intel: don't save hw_params for use in prepare (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Fix recursive locking at XRUN during syncing (Jaroslav Kysela) [2179850]
- ALSA: hda/conexant: Partial revert of a quirk for Lenovo (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Simplify the logging of requested firmware files (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Add support for loading bin files without wmfw (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Expose the DSP boot work actions as wm_adsp_power_up() (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Support DSPs that don't require firmware download (Jaroslav Kysela) [2179850]
- firmware: cs_dsp: Support DSPs that don't require firmware download (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Use no_core_startstop to prevent creating preload control (Jaroslav Kysela) [2179850]
- firmware: cs_dsp: Introduce no_core_startstop for self-booting DSPs (Jaroslav Kysela) [2179850]
- mfd: arizona-i2c: Add the missing device table IDs for OF (Jaroslav Kysela) [2179850]
- ASoC: cs35l41: Add 12288000 clk freq to cs35l41_fs_mon clk config (Jaroslav Kysela) [2179850]
- ALSA: portman2x4: remove unused portman_read_command,data functions (Jaroslav Kysela) [2179850]
- ALSA: ymfpci: remove unused snd_ymfpci_readb function (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirks for some Clevo laptops (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Initialize in_format to NULL in sof_ipc4_get_audio_fmt (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add DMI entries to support Victus by HP Laptop 16-e1xxx (8A22) (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: update pipeline_params in process prepare (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: set copier output format for process module (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Add support for base config extension (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: add base module config extension structure (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: add effect widget support (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Move the kcontrol module_id update to helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: use common helper function in copier prepare (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: support multiple configs for BE DAIs (Jaroslav Kysela) [2179850]
- soundwire: stream: restore cumulative bus bandwidth when compute_params callback failed (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: rembrandt: Drop if blocks with always false condition (Jaroslav Kysela) [2179850]
- ALSA: sh: aica: Drop if blocks with always false condition (Jaroslav Kysela) [2179850]
- soundwire: bandwidth allocation: Use hweight32() to calculate set bits (Jaroslav Kysela) [2179850]
- soundwire: dmi-quirks: add remapping for Intel 'Rooks County' NUC M15 (Jaroslav Kysela) [2179850]
- ASoC: Intel: soc-acpi: add table for Intel 'Rooks County' NUC M15 (Jaroslav Kysela) [2179850]
- ASOC: Intel: sof_sdw: add quirk for Intel 'Rooks County' NUC M15 (Jaroslav Kysela) [2179850]
- soundwire: cadence: change access to IP_MCP_CMD_BASE (Jaroslav Kysela) [2179850]
- soundwire: cadence: split access to IP_MCP_CMDCTRL fields (Jaroslav Kysela) [2179850]
- soundwire: cadence: split access to IP_MCP_CONTROL fields (Jaroslav Kysela) [2179850]
- soundwire: cadence: split access to IP_MCP_CONFIG fields (Jaroslav Kysela) [2179850]
- soundwire: cadence: add helpers to access IP_MCP registers (Jaroslav Kysela) [2179850]
- soundwire: cadence: remove CDNS_MCP_CONFIG_SSPMOD (Jaroslav Kysela) [2179850]
- soundwire: intel: move bank switch routine to common intel_bus_common.c (Jaroslav Kysela) [2179850]
- soundwire: intel: add abstraction for cmdsync check (Jaroslav Kysela) [2179850]
- soundwire: intel: move bus common sequences to different file (Jaroslav Kysela) [2179850]
- soundwire: intel: use indirection before moving bus start/stop sequences (Jaroslav Kysela) [2179850]
- soundwire: intel: add sync_arm/sync_go to ops (Jaroslav Kysela) [2179850]
- soundwire: intel: simplify sync_go sequence (Jaroslav Kysela) [2179850]
- soundwire: intel: remove useless abstraction (Jaroslav Kysela) [2179850]
- soundwire: intel: remove PDI-level restrictions on rates and formats (Jaroslav Kysela) [2179850]
- soundwire: intel: remove stale/misleading comment (Jaroslav Kysela) [2179850]
- soundwire: intel: move common definitions to header file (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Search only pin 0 formats (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Add new tokens for input/output pin format count (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Remove the ref_audio_fmt field (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Modify the signature of sof_ipc4_init_audio_fmt() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Modify the type of available input/output formats (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Always parse the output formats in topology (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Parse the SOF_COMP_TOKENS only once (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Do not parse the DMA_BUFFER_SIZE token (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Add a new field in struct sof_ipc4_available_audio_format (Jaroslav Kysela) [2179850]
- ASoC: SOF: Use input/output pin consistently (Jaroslav Kysela) [2179850]
- ASoC: SOF: rename a couple of tokens (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-control: Add support for bytes control get and put (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Add support for TPLG_CTL_BYTES (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-control: set_volume_data only applies to VOLSW family (Jaroslav Kysela) [2179850]
- ASoC: SOF: uapi: header: Update sof_abi_hdr doc for IPC4 use (Jaroslav Kysela) [2179850]
- ASoC: SOF: uapi: header: Convert sof_abi_hdr comments to kernel style (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc3-control: Merge functions to handle bytes_ext get variants (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc3-control: Rename snd_sof_refresh_control() (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: add support for setting up loopback routes (Jaroslav Kysela) [2179850]
- ALSA: hda/ca0132: fixup buffer overrun at tuning_ctl_set() (Jaroslav Kysela) [2179850]
- ALSA: asihpi: check pao in control_message() (Jaroslav Kysela) [2179850]
- ASoC: codecs: zl38060: Mark OF related data as maybe unused (Jaroslav Kysela) [2179850]
- ASoC: codecs: rt1019: Mark OF related data as maybe unused (Jaroslav Kysela) [2179850]
- ASoC: codecs: pcm179x-spi: Mark OF related data as maybe unused (Jaroslav Kysela) [2179850]
- ASoC: codecs: adau1977-spi: Mark OF related data as maybe unused (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: Enable Bluetooth offload on adl_rt1019_rt5682 (Jaroslav Kysela) [2179850]
- ALSA: Use of_property_read_bool() for boolean properties (Jaroslav Kysela) [2179850]
- ALSA: ppc/tumbler: Use of_property_present() for testing DT property presence (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: Don't access EM2 (Jaroslav Kysela) [2179850]
- ASoC: cs35l41: Steam Deck Shared boost properties quirk (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm: fix hw->formats cleared by soc_pcm_hw_init() for dpcm (Jaroslav Kysela) [2179850]
- ASoC: hdmi-codec: only startup/shutdown on supported streams (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Enable cont_update_posn variable in pcm hw_params. (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Add pcm pointer callback for amd platforms. (Jaroslav Kysela) [2179850]
- ASoC: tegra: Support MAX9808x by machine driver (Jaroslav Kysela) [2179850]
- ASoC: tegra: Support RT5631 by machine driver (Jaroslav Kysela) [2179850]
- ASoC: tegra: Support coupled mic-hp detection (Jaroslav Kysela) [2179850]
- ALSA: hda: Match only Intel devices with CONTROLLER_IN_GPU() (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book2 Pro (Jaroslav Kysela) [2179850]
- ASoC: da7219: Initialize jack_det_mutex (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: remove redundant DAI config during hw_free (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Remove hda_ctrl_dai_widget_setup/free() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Unify DAI drv ops for IPC3 and IPC4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Define DAI widget DMA trigger ops for IPC4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Use the topology IPC dai_config op (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Add setup_hext_stream/reset_hext_stream DMA ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Define and set the HDA DAI widget DMA ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Introduce DAI widget ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Use the dai argument in ipc4_hda_dai_trigger (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Pass the CPU dai pointer (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Modify the signature of hda_link_dma_cleanup() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: remove struct hda_pipe_params (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Remove hda_link_dma_params() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: Remove BE DAI DRV ops for SSP DAI's (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix speaker, mute/micmute LEDs not work on a HP platform (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: add core token in each module extended token list (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Add support for core_id for pipelines (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Add macro to set the core_id in create_pipe message (Jaroslav Kysela) [2179850]
- ASoC: SOF: loader: Remove log prefixes for snd_sof_run_firmware (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc3: Check for upper size limit for the received message (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Fix error handling in sof_widget_ready() (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: don't squelch errors in WIDGET_SETUP phase (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Fix broken early bclk feature for SSP (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-mtrace: process pending logs upon FW crash (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: don't allocate blob if it will not be used (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Fix incorrect sample rate print unit (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: set dmic dai index from copier (Jaroslav Kysela) [2179850]
- ASoC: SOF: IPC4: update gain ipc msg definition to align with fw (Jaroslav Kysela) [2179850]
- ASoC: Intel: soc-acpi: fix copy-paste issue in topology names (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: harden D0i3 programming sequence (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-ctrl: re-add sleep after entering and exiting reset (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-tng: revert invalid bar size setting (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: Access MTL_HFPWRCTL from HDA_DSP_BAR (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-loader: use SOF helper for consistency (Jaroslav Kysela) [2179850]
- ASOC: SOF: Intel: pci-tgl: Fix device description (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: SKL: Fix device description (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: HDA: Fix device description (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: Fix the device description (Jaroslav Kysela) [2179850]
- ALSA: hda: intel-dsp-config: add MTL PCI id (Jaroslav Kysela) [2179850]
- ASoC: soc-core.c: remove useless dev_dbg() (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: remove indirect runtime copy (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.c: add missing flag check at snd_soc_pcm_dai_probe() (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Use struct_size for struct avs_modcfg_ext size (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: nau8825: Adjust clock control (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: ssm4567: Remove nau8825 bits (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt5682: Explicitly define codec format (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: da7219: Explicitly define codec format (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: max98357a: Explicitly define codec format (Jaroslav Kysela) [2179850]
- ASoC: maxim,max9867: add "mclk" support (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm: add option to start DMA after DAI (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add DMI entries to support HP OMEN 16-n0xxx (8A43) (Jaroslav Kysela) [2179850]
- ASoC: zl38060 add gpiolib dependency (Jaroslav Kysela) [2179850]
- ASoC: mt6358: Remove undefined HPx Mux enumeration values (Jaroslav Kysela) [2179850]
- ASoC: mt6358: Validate Wake on Voice 2 writes (Jaroslav Kysela) [2179850]
- ASoC: mt6358: Fix event generation for wake on voice stage 2 switch (Jaroslav Kysela) [2179850]
- ALSA: ice1712: Delete unreachable code in aureon_add_controls() (Jaroslav Kysela) [2179850]
- ALSA: ice1712: Do not left ice->gpio_mutex locked in aureon_add_controls() (Jaroslav Kysela) [2179850]
- ASoC: adau7118: don't disable regulators on device unbind (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Replace fake flexible arrays with flexible-array member (Jaroslav Kysela) [2179850]
- ALSA: cs35l41: Add shared boost feature (Jaroslav Kysela) [2179850]
- ASoC: cs35l41: Refactor error release code (Jaroslav Kysela) [2179850]
- ASoC: cs35l41: Only disable internal boost (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for HP EliteDesk 800 G6 Tower PC (Jaroslav Kysela) [2179850]
- soundwire: qcom: gracefully handle too many ports in DT (Jaroslav Kysela) [2179850]
- soundwire: qcom: define hardcoded version magic numbers (Jaroslav Kysela) [2179850]
- soundwire: qcom: correct setting ignore bit on v1.5.1 (Jaroslav Kysela) [2179850]
- ASoC: jack: allow multiple interrupt per gpio (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Improve support for Dell Precision 3260 (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: Add quirk for Rex board with mx98360a amplifier (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: Enable DMI L1 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Restrict DMI L1 disable workaround (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Do not re-enable L1 if disabled before suspend (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: Add components prefix in structs and function names (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: Centralize strings definition (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: Move nau8821 and CPU side code up for future platform (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: Check Bit Clock rate before snd_soc_dai_set_pll (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: use for_each_rtd_components instead of for (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: remove unnecessarily included headers (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: use sizeof of variable instead of struct type (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: Small code refactor (Jaroslav Kysela) [2179850]
- ASoC: amd: vangogh: Remove unnecessary init function (Jaroslav Kysela) [2179850]
- ASoC: nau8821: Implement DRC controls (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: fix possible stream_tag leak (Jaroslav Kysela) [2179850]
- ASoC: amd: yp: Add OMEN by HP Gaming Laptop 16z-n000 to quirks (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.h: fixup warning struct snd_pcm_substream not declared (Jaroslav Kysela) [2179850]
- ASoC: soc-ac97: Return correct error codes (Jaroslav Kysela) [2179850]
- ASoC: da7219: Improve the IRQ process to increase the stability (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Enable mute/micmute LEDs and speaker support for HP Laptops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: Set streaming flag for d0i3 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Enable d0i3 work for ipc4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Wake up dsp core before sending ipc msg (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: use set_pm_gate according to ipc version (Jaroslav Kysela) [2179850]
- ASoC: SOF: Introduce a new set_pm_gate() IPC PM op (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP platform. (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Fix struct definition (Jaroslav Kysela) [2179850]
- ASoC: codecs: wcd934x: Use min macro for comparison and assignment (Jaroslav Kysela) [2179850]
- ASoC: soc-ac97: Convert to agnostic GPIO API (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Enable Amp High Pass Filter (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Ensure firmware/tuning pairs are always loaded (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Correct error condition handling (Jaroslav Kysela) [2179850]
- ASoC: codecs: Modify error implicit declaration of function 'gpiod_set_value_cansleep' (Jaroslav Kysela) [2179850]
- ASoC: codecs: Modify the log print statement (Jaroslav Kysela) [2179850]
- ASoC: codecs: Fixed a spelling error in the function name (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek - fixed wrong gpio assigned (Jaroslav Kysela) [2179850]
- ALSA: hda: Fix codec device field initializan (Jaroslav Kysela) [2179850]
- ASoC: rt712-sdca: fix coding style and unconditionally return issues (Jaroslav Kysela) [2179850]
- ASoC: rt5640: Update MCLK rate in set_sysclk() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: set copier sink format (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Print queue IDs in error (Jaroslav Kysela) [2179850]
- ALSA: hda: remove redundant variable in snd_hdac_stream_start() (Jaroslav Kysela) [2179850]
- ALSA: hda/conexant: add a new hda codec SN6180 (Jaroslav Kysela) [2179850]
- SoC: rt5682s: Disable jack detection interrupt during suspend (Jaroslav Kysela) [2179850]
- ALSA: ppc: fix unused function local variable (Jaroslav Kysela) [2179850]
- ASoC: codecs: max98090: simplify snd_soc_dai_driver (Jaroslav Kysela) [2179850]
- ASoC: SOF: ops: refine parameters order in function snd_sof_dsp_update8 (Jaroslav Kysela) [2179850]
- ASoC: topology: Return -ENOMEM on memory allocation failure (Jaroslav Kysela) [2179850]
- ALSA: core: Make snd_card_free() return void (Jaroslav Kysela) [2179850]
- ALSA: core: Make snd_card_free_when_closed() return void (Jaroslav Kysela) [2179850]
- ALSA: core: Make snd_card_disconnect() return void (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add Positivo N14KP6-TG (Jaroslav Kysela) [2179850]
- ALSA: emux: Avoid potential array out-of-bound in snd_emux_xg_control() (Jaroslav Kysela) [2179850]
- ASoC: rt712-sdca: Add RT712 SDCA driver for Jack and Amp topology (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP platform. (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Add quirk for ASUS UM3402 using CS35L41 (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Elitebook, 645 G9 (Jaroslav Kysela) [2179850]
- ASoC: codecs: aw88395: initialize cur_scene_id to 0 (Jaroslav Kysela) [2179850]
- ASoC: codecs: es8326: Fix DTS properties reading (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Fix for handling spurious interrupts from DSP (Jaroslav Kysela) [2179850]
- ASoC: codecs: fix platform_no_drv_owner.cocci warning (Jaroslav Kysela) [2179850]
- ALSA: fireface: add field for the number of messages copied to user space (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: add delay function support (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: add get_stream_position support (Jaroslav Kysela) [2179850]
- ASoC: SOF: add get_stream_position ops for pcm delay (Jaroslav Kysela) [2179850]
- ASoC: SOF: add delay function support in sof framework (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: add hw_params (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: allocate time info for pcm delay feature (Jaroslav Kysela) [2179850]
- ASoC: SOF: add time info structure for ipc4 path (Jaroslav Kysela) [2179850]
- ASoC: SOF: add fw_info_box support (Jaroslav Kysela) [2179850]
- ASoC: SOF: add ipc4_fw_reg header file (Jaroslav Kysela) [2179850]
- ASoC: codecs: aw88395: Fix spelling mistake "cersion" -> "version" (Jaroslav Kysela) [2179850]
- ASoC: SOF: fix intel-soundwire link failure (Jaroslav Kysela) [2179850]
- ALSA: hda: Fix the control element identification for multiple codecs (Jaroslav Kysela) [2179850]
- ASoC: amd: update ps platform acp header file (Jaroslav Kysela) [2179850]
- ASoC: topology: Set correct unload callback for graph type (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Add missed "else" in sof_connect_dai_widget (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: use helper function (Jaroslav Kysela) [2179850]
- ALSA: pci: lx6464es: fix a debug loop (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.h: cleanup Playback/Capture data for snd_soc_dai (Jaroslav Kysela) [2179850]
- ASoC: soc-topology.c: use helper function (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: use helper function (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.c: use helper function (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: use helper function (Jaroslav Kysela) [2179850]
- ASoC: soc-core.c: use helper function (Jaroslav Kysela) [2179850]
- ASoC: ti: use helper function (Jaroslav Kysela) [2179850]
- ASoC: tegra: use helper function (Jaroslav Kysela) [2179850]
- ASoC: sof: use helper function (Jaroslav Kysela) [2179850]
- ASoC: intel: use helper function (Jaroslav Kysela) [2179850]
- ASoC: sdw-mockup: use helper function (Jaroslav Kysela) [2179850]
- ASoC: spear: use helper function (Jaroslav Kysela) [2179850]
- ASoC: cirrus: use helper function (Jaroslav Kysela) [2179850]
- ASoC: rt: use helper function (Jaroslav Kysela) [2179850]
- ASoC: max: use helper function (Jaroslav Kysela) [2179850]
- ASoC: hda: use helper function (Jaroslav Kysela) [2179850]
- ASoC: hdmi-codec: use helper function (Jaroslav Kysela) [2179850]
- ASoC: soc.h: add snd_soc_card_is_instantiated() helper (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.h: add snd_soc_dai_get/set_widget_playback/capture() helper (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.h: add snd_soc_dai_tdm_mask_set/get() helper (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.h: add snd_soc_dai_dma_data_set/get() for low level (Jaroslav Kysela) [2179850]
- ASoC: soc-dai.h: add missing snd_soc_dai_set_widget() (Jaroslav Kysela) [2179850]
- ALSA: doc: Fix PCM interface section typos (Jaroslav Kysela) [2179850]
- ALSA: firewire-motu: fix unreleased lock warning in hwdep device (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: fix uninitialized local variable (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Refactor bit width calculation (Jaroslav Kysela) [2179850]
- ASoC: rt715-sdca: fix clock stop prepare timeout issue (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book2 Pro 360 (Jaroslav Kysela) [2179850]
- ASoC: tas5720: set bit 7 in ANALOG_CTRL_REG for TAS5720A-Q1 during probe (Jaroslav Kysela) [2179850]
- ASoC: codecs: tas5720: add support for TAS5720A-Q1 (automotive) variant (Jaroslav Kysela) [2179850]
- ASoC: codecs: tas5720: split a tas5720_mute_soc_component() function (Jaroslav Kysela) [2179850]
- ASoC: topology: Use unload() op directly (Jaroslav Kysela) [2179850]
- ASoC: topology: Unify kcontrol removal code (Jaroslav Kysela) [2179850]
- ASoC: topology: Remove unnecessary check for EOF (Jaroslav Kysela) [2179850]
- ASoC: topology: Return an error on complete() failure (Jaroslav Kysela) [2179850]
- ASoC: topology: Pass correct pointer instead of casting (Jaroslav Kysela) [2179850]
- ASoC: topology: Remove unnecessary forward declarations (Jaroslav Kysela) [2179850]
- ASoC: topology: Rename remove_ handlers (Jaroslav Kysela) [2179850]
- ASoC: topology: Fix function name (Jaroslav Kysela) [2179850]
- ASoC: topology: Fix typo in functions name (Jaroslav Kysela) [2179850]
- ASoC: topology: Remove unused SOC_TPLG_PASS_PINS constant (Jaroslav Kysela) [2179850]
- ASoC: topology: Properly access value coming from topology file (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Wait for debounce interval after resume (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Don't set idle_bias_on (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Add SoundWire support (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Export some functions for SoundWire (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Separate ASP config from PLL config (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Ensure MCLKint is a multiple of the sample rate (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Add SOFT_RESET_REBOOT register (Jaroslav Kysela) [2179850]
- soundwire: stream: Add specific prep/deprep commands to port_prep callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: Do not run the trigger pipelines if no spipe is stored (Jaroslav Kysela) [2179850]
- ASoC: SOF: Protect swidget->use_count with mutex for kcontrol access race (Jaroslav Kysela) [2179850]
- ASoC: SOF: Avoid double decrementing use_count in sof_widget_setup on error (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Protect pipeline free with mutex (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: Implement pipeline trigger reference counting (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: Rename 'data' variable to trigger_list (Jaroslav Kysela) [2179850]
- ASoC: SOF: Introduce struct snd_sof_pipeline (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: Use the PCM stream's pipeline_info during trigger (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Populate the PCM stream pipeline_info (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Add flag to skip triggering pipelines during FE DAI trigger (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-pcm: Define pcm_setup/free ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Introduce PCM setup/free PCM IPC ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Set IPC-specific trigger order for DAI links (Jaroslav Kysela) [2179850]
- ASoC: SOF: pcm: do not free widgets during suspend trigger (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Only process widgets in the connected widget list (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Set up/free DAI/AIF widgets only once (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm: Export widget_in_list() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: No need to unbind routes within a pipeline (Jaroslav Kysela) [2179850]
- Documentation: sound: correct spelling (Jaroslav Kysela) [2179850]
- treewide: fix up files incorrectly marked executable (Jaroslav Kysela) [2179850]
- ASoC: cs42l56: fix DT probe (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: add buffer type support (Jaroslav Kysela) [2179850]
- ALSA: memalloc: Workaround for Xen PV (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: use different channel mask for each sdw amp feedback (Jaroslav Kysela) [2179850]
- soundwire: bus_type: Avoid lockdep assert in sdw_drv_probe() (Jaroslav Kysela) [2179850]
- soundwire: cadence: further simplify low-level xfer_msg_defer() callback (Jaroslav Kysela) [2179850]
- soundwire: stream: use consistent pattern for freeing buffers (Jaroslav Kysela) [2179850]
- soundwire: bus: Remove unused reset_page_addr() callback (Jaroslav Kysela) [2179850]
- soundwire: bus: Don't zero page registers after every transaction (Jaroslav Kysela) [2179850]
- ASoC: ts3a227e: add set_jack and get_jack_type (Jaroslav Kysela) [2179850]
- ASoC: simple-card-utils: create jack inputs for aux_devs (Jaroslav Kysela) [2179850]
- ASoC: soc-component: add get_jack_type (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Simplify probe-component implementation (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: prepare_widgets: Check swidget for NULL on sink failure (Jaroslav Kysela) [2179850]
- firewire: cdev: use single object to dispatch event for request to IEC 61883-1 FCP region (Jaroslav Kysela) [2179850]
- firewire: cdev: obsolete NULL check to detect IEC 61883-1 FCP region (Jaroslav Kysela) [2179850]
- firewire: core: use kref structure to maintain lifetime of data for fw_request structure (Jaroslav Kysela) [2179850]
- ASoC: hdmi-codec: zero clear HDMI pdata (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-mtrace: prevent underflow in sof_ipc4_priority_mask_dfs_write() (Jaroslav Kysela) [2179850]
- soundwire: bus: remove sdw_defer argument in sdw_transfer_defer() (Jaroslav Kysela) [2179850]
- soundwire: cadence: use directly bus sdw_defer structure (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Add FIXED_RATE quirk for JBL Quantum610 Wireless (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix mute/micmute LEDs, speaker don't work for a HP platform (Jaroslav Kysela) [2179850]
- ASoC: SOF: keep prepare/unprepare widgets in sink path (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: skip prepare/unprepare if swidget is NULL (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: unprepare when swidget->use_count > 0 (Jaroslav Kysela) [2179850]
- ALSA: fireface: fix locking bug in ff400_copy_msg_to_user() (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: start with the right widget type (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Set compress data offset (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add support for compress API for stream data/offset (Jaroslav Kysela) [2179850]
- ASoC: SOF: Prepare set_stream_data_offset for compress API (Jaroslav Kysela) [2179850]
- ASoC: SOF: Prepare ipc_msg_data to be used with compress API (Jaroslav Kysela) [2179850]
- ALSA: hda/ca0132: minor fix for allocation size (Jaroslav Kysela) [2179850]
- firewire: fix memory leak for payload of request subaction to IEC 61883-1 FCP region (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Use asoc_substream_to_rtd() to obtain rtd (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Use min_t instead of min with cast (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Correctly access topology fields (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Implement PCI shutdown (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Fix possible NULL pointer dereference in snd_usb_pcm_has_fixed_rate() (Jaroslav Kysela) [2179850]
- ASoC: codecs: Aw88395 chip register file, data type file and Kconfig Makefile (Jaroslav Kysela) [2179850]
- ASoC: codecs: Aw88395 function for ALSA Audio Driver (Jaroslav Kysela) [2179850]
- ASoC: codecs: ACF bin parsing and check library file for aw88395 (Jaroslav Kysela) [2179850]
- ASoC: codecs: Add i2c and codec registration for aw88395 and their associated operation functions (Jaroslav Kysela) [2179850]
- regmap: sdw: Remove 8-bit value size restriction (Jaroslav Kysela) [2179850]
- regmap: sdw: Update misleading comment (Jaroslav Kysela) [2179850]
- ALSA: fireface: implement message parser for Fireface 400 (Jaroslav Kysela) [2179850]
- ALSA: fireface: add local framework to message parser (Jaroslav Kysela) [2179850]
- ALSA: fireface: update UAPI for data of knob control (Jaroslav Kysela) [2179850]
- ALSA: fireface: add helper function to parse MIDI messages transmitted by Fireface 400 (Jaroslav Kysela) [2179850]
- ALSA: fireface: pick up time stamp for request subaction of asynchronous transaction (Jaroslav Kysela) [2179850]
- ALSA: fireface: rename callback functions (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_es8336: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcr_wm5102: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcr_rt5640: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcr_rt5651: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcht_es8316: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179850]
- ASoC: amd: acp-es8336: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add DMI support for new acer/emdoor platforms (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Spectre x360 13-aw0xxx (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: compute extra delay for runtime of PCM substream (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: obsolete return value from context payload processing layer (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: move parameter for pcm frame multiplier from context payload processing layer (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: Support mt8188 platform (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: extend tracepoints event including CYCLE_TIME of 1394 OHCI (Jaroslav Kysela) [2179850]
- ALSA: hda/hdmi: Add a HP device 0x8715 to force connect list (Jaroslav Kysela) [2179850]
- ALSA: control-led: use strscpy in set_led_id() (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Always initialize fixed_rate in snd_usb_find_implicit_fb_sync_format() (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Enable i2s tdm support for skyrim platforms (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Add i2s tdm support in machine driver (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Refactor i2s clocks programming sequence (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Refactor dai format implementation (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Add new cpu dai's in machine driver (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: keep history to process isochronous packet (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: use circular linked list for context payload processing layer (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: use circular linked list to enumerate packet descriptors (Jaroslav Kysela) [2179850]
- ASoC: nau8315: remove dependency on GPIOLIB (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: code refactoring for cache position in sequence replay (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: code refactoring for cache position in tx packets (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: code refactoring for pool position in rx packets (Jaroslav Kysela) [2179850]
- ALSA: firewire-lib: code refactoring for helper functions to pool sequence in rx packets (Jaroslav Kysela) [2179850]
- ALSA: aoa: make remove callback of soundbus driver void returned (Jaroslav Kysela) [2179850]
- ALSA: ac97: make remove callback of ac97 driver void returned (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: Fix uninitialized ret in create_acp64_platform_devs() (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Check runtime suspend capability at runtime_idle (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Don't return -EINVAL from system suspend/resume (Jaroslav Kysela) [2179850]
- mfd: arizona: Use pm_runtime_resume_and_get() to prevent refcnt leak (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP platform (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: use static function (Jaroslav Kysela) [2179850]
- ASoC: nau8822: add speaker Bridge Tied Output configuration (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: remove unused variable (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: use acp_lock to protect common registers in pdm driver (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: add mutex lock for accessing common registers (Jaroslav Kysela) [2179850]
- ALSA: hda - Enable headset mic on another Dell laptop with ALC3254 (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_ssp_amp: remove unused variable (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof-wm8804: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179850]
- ASoC: Intel: cht_bsw_rt5672: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179850]
- ASoC: Intel: cht_bsw_rt5645: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcht_da7213: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcht_cx2072x: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: More refactoring of hw constraint rules (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Relax hw constraints for implicit fb sync (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Make sure to stop endpoints before closing EPs (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek - Turn on power early (Jaroslav Kysela) [2179850]
- ASoC: rt9120: Make dev PM runtime bind AsoC component PM (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add ASUS M5402RA into DMI table (Jaroslav Kysela) [2179850]
- ASoC: wm8904: fix wrong outputs volume after power reactivation (Jaroslav Kysela) [2179850]
- ASoC: rt711-sdca: add jack detection mode for JD2 100K (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_nau8825: add variant with nau8318 amplifier. (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: move irq handler registration (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: update dev index value in irq handler (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: refactor platform device creation logic (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: implement api to retrieve acp device config (Jaroslav Kysela) [2179850]
- ASoC: Intel: fix sof-nau8825 link failure (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof-nau8825: fix module alias overflow (Jaroslav Kysela) [2179850]
- ASoC: SOF: trace: No need to check for op pointer in sof_fw_trace_free() (Jaroslav Kysela) [2179850]
- ASoC: SOF: trace: Use sof_ipc_get_ops() in sof_fw_trace_init (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-priv: Mark fw_tracing ops optional in documentation (Jaroslav Kysela) [2179850]
- ASoC: SOF: pm: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179850]
- ASoC: SOF: control: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179850]
- ASoC: SOF: pcm: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add helper macro to be used to get an IPC ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Update documentation for sof_ipc_tplg_ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: sof-audio: Treat tplg_ops->route_setup() as optional (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add FW state to debugfs (Jaroslav Kysela) [2179850]
- ASoC: SOF: pm: Always tear down pipelines before DSP suspend (Jaroslav Kysela) [2179850]
- ASoC: SOF: pm: Set target state earlier (Jaroslav Kysela) [2179850]
- ASoC: SOF: core: Print out the value of sof_debug if it is set (Jaroslav Kysela) [2179850]
- ASoC: SOF: IPC3 topology: Print the conflicting bytes sizes (Jaroslav Kysela) [2179850]
- ASoC: wm8940: Read chip ID when wm8940 codec probing (Jaroslav Kysela) [2179850]
- ASoC: wm8940: Rewrite code to set proper clocks (Jaroslav Kysela) [2179850]
- ASoC: wm8940: Remove warning when no plat data present (Jaroslav Kysela) [2179850]
- ASoC: amd: yc: Add Razer Blade 14 2022 into DMI table (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Add new quirk FIXED_RATE for JBL Quantum810 Wireless (Jaroslav Kysela) [2179850]
- ASoC: lochnagar: Fix unused lochnagar_of_match warning (Jaroslav Kysela) [2179850]
- soundwire: intel: remove DAI startup/shutdown (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: mt8195: remove a redundant comparison of sram (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Peakvol module configuration (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Parse control tuples (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add control volume operations (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add peakvol runtime-parameter requests (Jaroslav Kysela) [2179850]
- ASoC: Intel: Add HP Stream 8 to bytcr_rt5640.c (Jaroslav Kysela) [2179850]
- ASoC: da7213: Add support for mono, set frame width to 32 when possible (Jaroslav Kysela) [2179850]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Advantech MICA-071 tablet (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: initialize panic_info to zero (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Enable cache for AMD Rembrandt platform (Jaroslav Kysela) [2179850]
- ALSA: azt3328: Remove the unused function snd_azf3328_codec_outl() (Jaroslav Kysela) [2179850]
- ASoC: SOF: nocodec: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: wl1273: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: mc13783: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: cq93vc: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: bt-sco: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: adau7002: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: ac97: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: 88pm860x: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: atmel-pdmic: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: atmel-classd: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: amd: Drop empty platform remove function (Jaroslav Kysela) [2179850]
- ASoC: SOF: Revert: "core: unregister clients and machine drivers in .shutdown" (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-tgl: unblock S5 entry if DMA stop has failed" (Jaroslav Kysela) [2179850]
- ASoC: rt5640: Allow configuration of LOUT to mono differential mode (Jaroslav Kysela) [2179850]
- ALSA: hda: Error out if invalid stream is being setup (Jaroslav Kysela) [2179850]
- ASoC: soc-compress: Reposition and add pcm_mutex (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_realtek_common: set ret = 0 as initial value (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: add jsl_rt5682 board config (Jaroslav Kysela) [2179850]
- ALSA: hda/cirrus: Add extra 10 ms delay to allow PLL settle and lock. (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Workaround for XRUN at prepare (Jaroslav Kysela) [2179850]
- ALSA: pcm: Handle XRUN at trigger START (Jaroslav Kysela) [2179850]
- ASoC : SOF: amd: Add support for IPC and DSP dumps (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Use poll function instead to read ACP_SHA_DSP_FW_QUALIFIER (Jaroslav Kysela) [2179850]
- ASoC: imx-audmux: use sysfs_emit() to instead of scnprintf() (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Use SG allocation for SKL-based firmware load (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Introduce single place for pipe-config selection (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Drop pipe_config_idx (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Remove skl_tplg_is_multi_fmt() (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Update pipe_config_idx before filling BE params (Jaroslav Kysela) [2179850]
- ASoC: codecs: wcd-clsh: Remove the unused function (Jaroslav Kysela) [2179850]
- ASoC: rt715: Make read-only arrays capture_reg_H and capture_reg_L static const (Jaroslav Kysela) [2179850]
- soundwire: cadence: Drain the RX FIFO after an IO timeout (Jaroslav Kysela) [2179850]
- soundwire: cadence: Remove wasted space in response_buf (Jaroslav Kysela) [2179850]
- soundwire: cadence: Don't overflow the command FIFOs (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Allow for dumping debug window snapshot (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Allow for dumping FW_REGS area (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Gather remaining logs on strace_release() (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Probing and firmware tracing over debugfs (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add probe machine board (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Data probing soc-component (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Probe compress operations (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add data probing requests (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Drop usage of debug members in non-debug code (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Make enable_logs() dependent on DEBUG_FS (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Introduce debug-context aware helpers (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Drop fifo_lock (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Introduce avs_log_buffer_status_locked() (Jaroslav Kysela) [2179850]
- ALSA: hda: Interrupt servicing and BDL setup for compress streams (Jaroslav Kysela) [2179850]
- ALSA: hda: Prepare for compress stream support (Jaroslav Kysela) [2179850]
- ALSA: hda: Allow for compress stream to hdac_ext_stream assignment (Jaroslav Kysela) [2179850]
- ALSA: dice: Remove left-over license text (Jaroslav Kysela) [2179850]
- drm: tda99x: Don't advertise non-existent capture support (Jaroslav Kysela) [2179850]
- ASoC: hdmi-codec: Allow playback and capture to be disabled (Jaroslav Kysela) [2179850]
- ALSA: dice: add support for Focusrite Saffire Pro 40 with TCD3070 ASIC (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt5682: Refactor jack handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt5682: Add define for codec DAI name (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Add quirk for Tascam Model 12 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add DAI configuration support for AMD platforms. (Jaroslav Kysela) [2179850]
- ASoC: rt5640: Fix Jack work after system suspend (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: Clear DAIs parameters after stream_active is updated (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: add shutdown callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: Drop obsolete dependency on COMPILE_TEST (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt298: Refactor jack handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt298: Add define for codec DAI name (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt286: Refactor jack handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt286: Add define for codec DAI name (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt274: Refactor jack handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: rt274: Refer to DAI name through a constant (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: nau8825: Refactor jack handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: da7219: Refactor jack handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: bdw_rt286: Refactor jack handling (Jaroslav Kysela) [2179850]
- ALSA: pcm: fix tracing reason in hw_ptr_error (Jaroslav Kysela) [2179850]
- soundwire: stream: Move remaining register accesses over to no_pm (Jaroslav Kysela) [2179850]
- soundwire: debugfs: Switch to sdw_read_no_pm (Jaroslav Kysela) [2179850]
- soundwire: Provide build stubs for common functions (Jaroslav Kysela) [2179850]
- soundwire: bus: export sdw_nwrite_no_pm and sdw_nread_no_pm functions (Jaroslav Kysela) [2179850]
- firmware: cs_dsp: Rename KConfig symbol CS_DSP -> FW_CS_DSP (Jaroslav Kysela) [2179850]
- ASoC: nau8315: add new acpi id and compatible id (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Return whether changed when writing controls (Jaroslav Kysela) [2179850]
- firmware: cs_dsp: cs_dsp_coeff_write_ctrl() should report changed (Jaroslav Kysela) [2179850]
- ASoC: sdw-mockup: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: rt715: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: rt711: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: rt700: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: rt5682-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: rt1316-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: rt1308-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- ASoC: max98373-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179850]
- sound: sdw: Add hw_params to SoundWire config helper function (Jaroslav Kysela) [2179850]
- ASoC: max9867: Implement exact integer mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: ADD HS and SP virtual DAI. (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Fix for selecting clock source as external clock. (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Fix for reading position updates from stream box. (Jaroslav Kysela) [2179850]
- ASoC: nau8825: Add a manually mechanism for detection failure (Jaroslav Kysela) [2179850]
- ASoC: nau8825: Adjust internal clock during jack detection (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add missing audio amplifier for KBL (Jaroslav Kysela) [2179850]
- ALSA: pcm: fix undefined behavior in bit shift for SNDRV_PCM_RATE_KNOT (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Fix Kconfig dependency (Jaroslav Kysela) [2179850]
- ASoC: da7219: Fix pole orientation detection on OMTP headsets when playing music (Jaroslav Kysela) [2179850]
- ASoC: max98396: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- ASoC: codecs: es8326: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- ALSA: ppc: keywest: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- ALSA: aoa: tas: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- ALSA: aoa: onyx: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- mfd: arizona-i2c: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Initialize private data for subsequent HDA FEs (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Fix possible UAF in acp_dma_open (Jaroslav Kysela) [2179850]
- soundwire: enable optional clock registers for SoundWire 1.2 devices (Jaroslav Kysela) [2179850]
- ASoC/soundwire: remove is_sdca boolean property (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_sdw_amp: mark coeff tables with __maybe_unused (Jaroslav Kysela) [2179850]
- ASoC: SOF: dai: move AMD_HS to end of list to restore backwards-compatibility (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_nau8825: support rt1015p speaker amplifier (Jaroslav Kysela) [2179850]
- ASoC: SOF: probes: Check ops before memory allocation (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Disconnect substream if suspend or resume fails (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: Move acp63_dev_data strcture from PCI driver (Jaroslav Kysela) [2179850]
- ASoC: amd: ps: update macros with ps platform naming convention (Jaroslav Kysela) [2179850]
- ALSA: pcm: avoid nused-but-set-variable warning (Jaroslav Kysela) [2179850]
- ALSA: memalloc: Allocate more contiguous pages for fallback case (Jaroslav Kysela) [2179850]
- ASoC: codecs: Remove a useless include (Jaroslav Kysela) [2179850]
- ASoC: audio-graph-card2: remove Experimental announce (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: read multi-link capabilities earlier (Jaroslav Kysela) [2179850]
- soundwire: intel_init: remove check on number of links (Jaroslav Kysela) [2179850]
- soundwire: intel_init: remove sdw_intel_enable_irq() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: add callback to check SoundWire lcount information (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: move SoundWire interrupt enabling to callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: factor interrupt enable/disable interrupt functions (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: add per-chip enable_sdw_irq() callback (Jaroslav Kysela) [2179850]
- soundwire: intel_init: remove useless interrupt enablement in interrupt thread (Jaroslav Kysela) [2179850]
- soundwire: intel: split auxdevice to different file (Jaroslav Kysela) [2179850]
- soundwire: intel: add in-band wake callbacks in hw_ops (Jaroslav Kysela) [2179850]
- soundwire: intel: add link power management callbacks in hw_ops (Jaroslav Kysela) [2179850]
- soundwire: intel: add bus management callbacks in hw_ops (Jaroslav Kysela) [2179850]
- soundwire: intel: add register_dai callback in hw_ops (Jaroslav Kysela) [2179850]
- soundwire: intel: add debugfs callbacks in hw_ops (Jaroslav Kysela) [2179850]
- soundwire: intel: start using hw_ops (Jaroslav Kysela) [2179850]
- ASoC: Intel: soc-acpi: add MTL AIC SoundWire configurations (Jaroslav Kysela) [2179850]
- ASoC: wm_adsp: Allow client to hook into pre_run callback (Jaroslav Kysela) [2179850]
- ASoC: rt1316-sdw: get BQ params property and apply them (Jaroslav Kysela) [2179850]
- ASoC: rt1308-sdw: get BQ params property and apply them (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof rt5682: remove the duplicate codes (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: add support for ALC5682I-VD with amp rt1019p (Jaroslav Kysela) [2179850]
- ASoC: core: fix wrong size kzalloc for rtd's components member (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: get pipeline instance id from pipe_widget->instance_id (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-loader: get max pipeline number (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: rename sof_ipc4_widget_free_comp (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: set d0i3 register with d0i3_offset (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add d0i3_offset in chip_info (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add d0i3 definition for MTL (Jaroslav Kysela) [2179850]
- ASoC: SOF: topology: Add helper to get/put widget queue id (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add support to parse pin binding array from topology (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add support for parsing the number of sink/source pins (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: Implement tear_down_all_pipelines callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-loader: use small buffer for iccmax stream (Jaroslav Kysela) [2179850]
- ALSA: cs5535audio: Remove the redundant assignment (Jaroslav Kysela) [2179850]
- ASoC: soc-dai: Do not call snd_soc_link_be_hw_params_fixup() twice (Jaroslav Kysela) [2179850]
- ASoC: amd: fix ACP version typo mistake (Jaroslav Kysela) [2179850]
- ASoC: Intel: cirrus-common: Make const array uid_strings static (Jaroslav Kysela) [2179850]
- ARM: omap2: n8x0: stop instantiating codec platform data (Jaroslav Kysela) [2179850]
- ASoC: tlv320aic3x: switch to using gpiod API (Jaroslav Kysela) [2179850]
- ASoC: tlv320aic3x: remove support for platform data (Jaroslav Kysela) [2179850]
- ASoC: rt5682: Support DBVDD and LDO1-IN supplies (Jaroslav Kysela) [2179850]
- ASoC: rt5682s: Support DBVDD and LDO1-IN supplies (Jaroslav Kysela) [2179850]
- ASoC: audio-graph-card2: check also dpcm node for convert-xxx (Jaroslav Kysela) [2179850]
- ASoC: audio-graph-card2-custom-sample.dtsi: add convert-rate for DPCM (MIXer) (Jaroslav Kysela) [2179850]
- ASoC: simple-card-utils: remove asoc_simple_convert_fixup() (Jaroslav Kysela) [2179850]
- soundwire: cadence: use dai_runtime_array instead of dma_data (Jaroslav Kysela) [2179850]
- soundwire: cadence: rename sdw_cdns_dai_dma_data as sdw_cdns_dai_runtime (Jaroslav Kysela) [2179850]
- ASoC: cs42xx8-i2c.c: add module device table for of (Jaroslav Kysela) [2179850]
- ALSA: hda: clarify comments on SCF changes (Jaroslav Kysela) [2179850]
- ASoC: SOF: fix compilation issue with readb/writeb helpers (Jaroslav Kysela) [2179850]
- ASoC: codecs: da7219: Do not export internal symbols (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179850]
- ASoC: amd: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179850]
- ASoC: rockchip: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179850]
- ASoC: Intel: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179850]
- ASoC: codecs: da7219: Introduce set_jack() callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: IPC4: probes: Implement IPC4 ops for probes client device (Jaroslav Kysela) [2179850]
- ASoC: SOF: client: Add sof_client_ipc4_find_module() function (Jaroslav Kysela) [2179850]
- ASoC: SOF: client: Add sof_client_ipc_set_get_data() (Jaroslav Kysela) [2179850]
- ASoC: SOF: probes: Separate IPC3 operations to a separate file (Jaroslav Kysela) [2179850]
- ASoC: SOF: probes: Replace [0] union members with DECLARE_FLEX_ARRAY() (Jaroslav Kysela) [2179850]
- ASoC: adau1372: correct PGA enable & mute bit (Jaroslav Kysela) [2179850]
- ASoC: adau1372: add support for S24_LE mode (Jaroslav Kysela) [2179850]
- ASoC: adau1372: fix mclk (Jaroslav Kysela) [2179850]
- ASoC: SOF: introduce new DEBUG_NOCODEC mode (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: use GPL-2.0-only license (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: clarify Kconfig dependencies (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add hda_bus_ml_free helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-mlink: add helpers to suspend/resume links (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: clarify bus_init and bus_exit sequences (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: add helpers to suspend and resume cmd_io (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: clarify dependencies on SND_SOC_SOF_HDA (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-ctrl: use helper to clear RIRB status (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: add hda_codec_check_rirb_status() helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-stream: always allocate CORB/RIRB buffer (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: add stop_cmd_io helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: add hda_codec_device_remove() helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-ctrl: add codec wakeup helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: move all RIRB/CMD_IO helpers to hda-codec.c (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: add multi-link helper for LOSVID (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: start moving multi-link handling in dedicated file (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: move codec state change to hda-codec.c (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: simplify SND_SOC_SOF_HDA_AUDIO_CODEC handling (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: remove all dependencies on SND_SOC_HDAC_HDMI (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: remove option to disable the common_hdmi handling (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Enact power gating policy (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Power and clock gating policy overriding (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Standby power-state support (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Count low power streams (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Restart instead of resuming HDA capture streams (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Handle SUSPEND and RESUME triggers (Jaroslav Kysela) [2179850]
- ALSA: hda: Introduce snd_hdac_stream_wait_drsm() (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Introduce PCM power management routines (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Split pcm pages freeing operation from hw_free() (Jaroslav Kysela) [2179850]
- ASoC: core: Exit all links before removing their components (Jaroslav Kysela) [2179850]
- ASoC: tas5805m: add missing page switch. (Jaroslav Kysela) [2179850]
- ASoC: tas5805m: rework to avoid scheduling while atomic. (Jaroslav Kysela) [2179850]
- soundwire: qcom: add support for v1.7 Soundwire Controller (Jaroslav Kysela) [2179850]
- soundwire: qcom: make reset optional for v1.6 controller (Jaroslav Kysela) [2179850]
- soundwire: qcom: remove unused SWRM_SPECIAL_CMD_ID (Jaroslav Kysela) [2179850]
- ASoC: dapm: Don't use prefix for regulator name (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-loader: Return ssize_t from sof_ipc4_fw_parse_ext_man() (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: boards: Fix typo in comments (Jaroslav Kysela) [2179850]
- ASoC: Intel: boards: Fix typo in comments (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-stream: use readb/writeb for stream registers (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-stream: use snd_sof_dsp_updateb() helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: use SOF helper for consistency (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-stream: rename CL_SD_CTL registers as SD_CTL (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-stream: use SOF helpers for consistency (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: remove useless check on GCTL (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: always do a full reset (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-ctrl: remove useless sleep (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: remove useless members in hda_pipe_params (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: use component_get_drvdata to find hdac_bus (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: start removing the use of runtime->private_data in BE (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: use SOF helpers for consistency (Jaroslav Kysela) [2179850]
- ASoC: SOF: ops: add snd_sof_dsp_updateb() helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: ops: add readb/writeb helpers (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: use mmio fallback for all platforms (Jaroslav Kysela) [2179850]
- ASoC: SOF: ops: fallback to mmio in helpers (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: fix comment error (Jaroslav Kysela) [2179850]
- ALSA: asihpi: remove variable loops (Jaroslav Kysela) [2179850]
- ALSA: rawmidi: remove variable dest_frames (Jaroslav Kysela) [2179850]
- mfd: arizona: Remove #ifdef guards for PM related functions (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-codec: fix possible memory leak in hda_codec_device_init() (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: fix possible memory leak in skl_codec_device_init() (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-loader: Support for loading external libraries (Jaroslav Kysela) [2179850]
- ASoC: SOF: loader: Remove the query_fw_configuration ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Stop using the query_fw_configuration fw_loader ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: loader: Add support for IPC dependent post firmware boot ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Add ipc4 library loading implementation (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Add flag to indicate that the firmware is IMR booted (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Define platform dependent library loading callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Set the default firmware library path for IPC4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Add path definition for external firmware libraries (Jaroslav Kysela) [2179850]
- ASoC: SOF: IPC4: Add helper for looking up module by UUID (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Convert the firmware handling (loader) to library convention (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-loader: Save the maximum number of libraries supported (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc: ops: Add support for optional init and exit callbacks (Jaroslav Kysela) [2179850]
- ASoC: SOF: Drop the firmware and fw_offset from snd_sof_pdata (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-loader-skl: Use the basefw firmware container directly (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-loader: Use the basefw firmware container directly (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Use the basefw firmware container directly (Jaroslav Kysela) [2179850]
- ASoC: SOF: Introduce container struct for SOF firmware (Jaroslav Kysela) [2179850]
- ASoC: SOF: loader: Set complete state before post_fw_run op (Jaroslav Kysela) [2179850]
- soundwire: intel: Initialize clock stop timeout (Jaroslav Kysela) [2179850]
- ALSA/ASoC: hda: move SPIB/DRMS functionality from ext layer (Jaroslav Kysela) [2179850]
- ALSA: hda: hdac_ext_controller: remove useless loop (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: reduce ambiguity between 'multi-link' and 'link' DMA (Jaroslav Kysela) [2179850]
- ALSA/ASoC: hda: ext: add 'bus' prefix for multi-link stream setting (Jaroslav Kysela) [2179850]
- ALSA/ASoC: hda: ext: remove 'link' prefix for stream-related operations (Jaroslav Kysela) [2179850]
- ALSA/ASoC: hda: ext: add 'ext' prefix to snd_hdac_link_free_all (Jaroslav Kysela) [2179850]
- ALSA/ASoC: hda: clarify bus_get_link() and bus_link_get() helpers (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dai: use hlink variable/parameter (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: hda_ext_controller: use hlink variable/parameter (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: hdac_ext_controller: use helpers in loop (Jaroslav Kysela) [2179850]
- ASoC: rt1308-sdw: update the preset settings (Jaroslav Kysela) [2179850]
- ASoC: simple-card: Fix up checks for HW param fixups (Jaroslav Kysela) [2179850]
- ASoC: soc-dpcm.h: remove snd_soc_dpcm::hw_param (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.h: fixup comment for snd_soc_dapm_widget_for_each_path() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.h: cleanup white space (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: numerical order for dapm_up_seq (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: cleanup snd_soc_dapm_new_dai() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: merge dapm_power_one_widget() and dapm_widget_set_power() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: cleanup dapm_widget_set_power() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: ignore parameter NULL at snd_soc_dapm_free_widget() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: remove no meaning variable from snd_soc_dapm_add_path() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: tidyup error handling on snd_soc_dapm_add_route() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: replace snd_soc_dapm_wcache to snd_soc_dapm_widget (Jaroslav Kysela) [2179850]
- ASoC: twl4030: make read-only array ramp_base static const (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc3: Log the tx message before sending it (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: ipc4: Ack a received reply or notification separately (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: ipc4: Wait for channel to be free before sending a message (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: ipc4: Read the interrupt reason registers at the same time (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Log the tx message before sending it (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Add TDM slots setting support for ACP I2S controller (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-mtrace: protect per-core nodes against multiple open (Jaroslav Kysela) [2179850]
- soundwire: dmi-quirks: add quirk variant for LAPBC710 NUC15 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: simplify S3 resume flows (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: simplify S3 resume flows (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: simplify S3 resume flows (Jaroslav Kysela) [2179850]
- ASoC: codecs: jz4725b: add missed microphone widgets (Jaroslav Kysela) [2179850]
- ASoC: codecs: jz4725b: add missed Mixer inputs (Jaroslav Kysela) [2179850]
- ASoC: codecs: jz4725b: use right control for Master Playback (Jaroslav Kysela) [2179850]
- ALSA: hda/realtek: simplify the return of comp_bind() (Jaroslav Kysela) [2179850]
- ASoC: ak4458: add optional reset control to instead of gpio (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Support System Suspend (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Remove suspend/resume hda hooks (Jaroslav Kysela) [2179850]
- ALSA: hda/cs_dsp_ctl: Fix mutex inversion when creating controls (Jaroslav Kysela) [2179850]
- ALSA: hda: hda_cs_dsp_ctl: Ensure pwr_lock is held before reading/writing controls (Jaroslav Kysela) [2179850]
- ALSA: hda: hda_cs_dsp_ctl: Minor clean and redundant code removal (Jaroslav Kysela) [2179850]
- ASoC: codecs: hda: Fix spelling error in log message (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Simplify log control for SKL (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Simplify ignore_fw_version description (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Do not print IPC error message twice (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Do not treat unsupported IPCs as invalid (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Do not reuse msg between different IPC handlers (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add missing include to HDA board (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Simplify d0ix disabling routine (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add missing SKL-based device IDs (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Support da7219 on both KBL and APL (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Support AML with rt286 configuration (Jaroslav Kysela) [2179850]
- ASoC: wm8997: Revert "ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe" (Jaroslav Kysela) [2179850]
- ASoC: wm5110: Revert "ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe" (Jaroslav Kysela) [2179850]
- ASoC: wm5102: Revert "ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe" (Jaroslav Kysela) [2179850]
- ASoC: amd: Update Pink Sardine platform ACP register header (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Avoid superfluous endpoint setup (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Correct the return code from snd_usb_endpoint_set_params() (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Apply mutex around snd_usb_endpoint_set_params() (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Avoid unnecessary interface change at EP close (Jaroslav Kysela) [2179850]
- ASoC: cx2072x: fix spelling typo in comment (Jaroslav Kysela) [2179850]
- ALSA: hda: Update register polling macros (Jaroslav Kysela) [2179850]
- Revert "ASoC: soc-component: using pm_runtime_resume_and_get instead of pm_runtime_get_sync" (Jaroslav Kysela) [2179850]
- ASoC: codecs: allow WM8961 to be selected by the user (Jaroslav Kysela) [2179850]
- ASoC: wm8961: add support for devicetree (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Load max98927 on target platform (Jaroslav Kysela) [2179850]
- ASoC: Intel: avs: Add max98927 machine board (Jaroslav Kysela) [2179850]
- ASoC: nau8825: Add TDM support (Jaroslav Kysela) [2179850]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2179850]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2179850]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2179850]
- ASoC: core: clarify the driver name initialization (Jaroslav Kysela) [2179850]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2179850]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2179850]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2179850]
- ALSA: asihpi - Remove unused struct hpi_subsys_response (Jaroslav Kysela) [2179850]
- ALSA: sb: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179850]
- ASoC: wm8978: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179850]
- ASoC: cs35l36: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Fallback to headphones for type detect (Jaroslav Kysela) [2179850]
- ASoC: uapi: Replace zero-length arrays with __DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: control.h: Replace zero-length array with DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179850]
- usb: gadget: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ASoC: intel: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: usx2y: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: asihpi: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: hda: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: firewire: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: aloop: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179850]
- ALSA: pcm: Make mmap status read-only (Jaroslav Kysela) [2179850]
- ALSA: pcm: Avoid reference to status->state (Jaroslav Kysela) [2179850]
- ALSA: Remove some left-over license text in include/uapi/sound/ (Jaroslav Kysela) [2179850]
- ALSA: firewire: Remove some left-over license text in sound/firewire (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: mt8195: Add pcm_pointer callback (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: mt8195: Add pcm_hw_params callback (Jaroslav Kysela) [2179850]
- ALSA: memalloc: use __GFP_RETRY_MAYFAIL for DMA mem allocs (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Call snd_sof_handle_fw_exception() in case of timeout (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Only dump firmware registers for IPC3 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: Print relevant register in ipc_dump (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: skl: Use the ipc4 version of the ipc_dump (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Add separate ops for ipc_dump for IPC4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: cnl: Add separate ops for ipc_dump for IPC4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: remove the unnecessary snd_sof_dsp_read() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: reuse the common ops for PM (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: HDA: use IPC version-specific ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: MTL: define and set the disable_interrupts op (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: define and set the disable_interrupts op for cavs platforms (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Add a new op for disabling interrupts (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: use power_down_dsp op in hda_dsp_remove (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: mtl: define and set power_down_dsp op (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: define and set power_down_dsp op for HDA platforms (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: introduce new op to handle dsp power down (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_da7219_mx98360a: Access num_codecs through dai_link (Jaroslav Kysela) [2179850]
- ASoC: soc-component: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2179850]
- ALSA: hda/ca0132 - remove the unneeded result variable (Jaroslav Kysela) [2179850]
- ASoC: SOF: pci-tgl: add missing PCI IDs for RPL (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: pci-tgl: reorder PCI IDs (Jaroslav Kysela) [2179850]
- ASoC: es8316: fix register sync error in suspend/resume tests (Jaroslav Kysela) [2179850]
- ASoC: cs42l83: change cs42l83_regmap to static (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: add pcm_pointer callback for mt8186 (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Add setbias level for rt5682s codec in machine driver (Jaroslav Kysela) [2179850]
- ASoC: ts3a227e: add parameters to control debounce times (Jaroslav Kysela) [2179850]
- ALSA: usb-audio: Split endpoint setups for hw_params and prepare (take#2) (Jaroslav Kysela) [2179850]
- ASoC: rt5682s: simplify the return of rt5682s_probe() (Jaroslav Kysela) [2179850]
- ASoC: SOF: don't unprepare widget used other pipelines (Jaroslav Kysela) [2179850]
- ASoC: SOF: clear prepare state when widget is unprepared (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: remove useless assignment (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-topology: clarify calculation precedence (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add ops for SKL/KBL (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add initial SKL/KBL hardware support (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add SKL/KBL hardware code loader (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-dsp: expose functions for SKL support (Jaroslav Kysela) [2179850]
- ALSA: es18xx: Remove the unneeded result variable (Jaroslav Kysela) [2179850]
- ASoC: soc.h: use array instead of playback/capture_widget (Jaroslav Kysela) [2179850]
- ASoC: soc.h: use defined number instead of direct number (Jaroslav Kysela) [2179850]
- ASoC: soc.h: remove num_cpus/codecs (Jaroslav Kysela) [2179850]
- soundwire: intel: add helper to stop bus (Jaroslav Kysela) [2179850]
- soundwire: intel: introduce helpers to start bus (Jaroslav Kysela) [2179850]
- soundwire: intel: introduce intel_shim_check_wake() helper (Jaroslav Kysela) [2179850]
- soundwire: intel: simplify read ops assignment (Jaroslav Kysela) [2179850]
- soundwire: intel: remove intel_init() wrapper (Jaroslav Kysela) [2179850]
- soundwire: intel: move shim initialization before power up/down (Jaroslav Kysela) [2179850]
- soundwire: intel: remove clock_stop parameter in intel_shim_init() (Jaroslav Kysela) [2179850]
- soundwire: intel: move all PDI initialization under intel_register_dai() (Jaroslav Kysela) [2179850]
- soundwire: intel: move DAI registration and debugfs init earlier (Jaroslav Kysela) [2179850]
- soundwire: intel: simplify flow and use devm_ for DAI registration (Jaroslav Kysela) [2179850]
- soundwire: intel: fix error handling on dai registration issues (Jaroslav Kysela) [2179850]
- ASoC: SOF: replace ipc4-loader dev_vdbg with tracepoints (Jaroslav Kysela) [2179850]
- ASoC: SOF: replace dev_vdbg with tracepoints (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: replace dev_vdbg with tracepoints (Jaroslav Kysela) [2179850]
- ASoC: SOF: remove unneeded dev_vdbg (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: remove unneeded dev_vdbg (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: add HDA interrupt source tracing (Jaroslav Kysela) [2179850]
- ASoC: SOF: add widget setup/free tracing (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: remove always-true conditions on host and link release (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: fix locking in stream_release (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: simplify logic for stream assignment (Jaroslav Kysela) [2179850]
- ALSA: hda: Use hdac_ext prefix in snd_hdac_stream_free_all() for clarity (Jaroslav Kysela) [2179850]
- ALSA: hda: ext: make snd_hdac_ext_stream_init() static (Jaroslav Kysela) [2179850]
- ALSA: hda: document state machine for hdac_streams (Jaroslav Kysela) [2179850]
- ALSA: hda: make snd_hdac_stream_clear() static (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: override mclk_id after parsing NHLT SSP blob (Jaroslav Kysela) [2179850]
- ALSA: hda: intel-nhlt: add intel_nhlt_ssp_mclk_mask() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: refine SSP count support (Jaroslav Kysela) [2179850]
- soundwire: cadence: Simplify error paths in cdns_xfer_msg() (Jaroslav Kysela) [2179850]
- soundwire: cadence: Fix error check in cdns_xfer_msg() (Jaroslav Kysela) [2179850]
- soundwire: bus: Fix wrong port number in sdw_handle_slave_alerts() (Jaroslav Kysela) [2179850]
- soundwire: cadence: Write to correct address for each FIFO chunk (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: add pcm_hw_params callback for mt8186 (Jaroslav Kysela) [2179850]
- ALSA: ppc: Switch to use for_each_child_of_node() macro (Jaroslav Kysela) [2179850]
- ASoC: Intel: skylake: remove unnecessary dev_set_drvdata() (Jaroslav Kysela) [2179850]
- soundwire: qcom: do not send status of device 0 during alert (Jaroslav Kysela) [2179850]
- soundwire: qcom: update status from device id 1 (Jaroslav Kysela) [2179850]
- ASoC: max98390: Fix dsm calibration reading (Jaroslav Kysela) [2179850]
- soundwire: cadence: Don't overwrite msg->buf during write commands (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_ssp_amp: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASOC: SOF: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_es8336: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_nau8825: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_cs42l42: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Switch to dev_err_probe() helper (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Implement 'set_bclk_ratio' (Jaroslav Kysela) [2179850]
- ASoC: cs42l83: Extend CS42L42 support to new part (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Export regmap elements to core namespace (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Split I2C identity into separate module (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Pass component and dai defs into common probe (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Split cs42l42_resume into two functions (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Split probe() and remove() into stages (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Use cs42l42->dev instead of &i2c_client->dev (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Add bitclock frequency argument to cs42l42_pll_config() (Jaroslav Kysela) [2179850]
- soundwire: bus: Don't exit early if no device IDs were programmed (Jaroslav Kysela) [2179850]
- soundwire: cadence: Fix lost ATTACHED interrupts when enumerating (Jaroslav Kysela) [2179850]
- soundwire: bus: Don't re-enumerate before status is UNATTACHED (Jaroslav Kysela) [2179850]
- soundwire: bus: Don't lose unattach notifications (Jaroslav Kysela) [2179850]
- soundwire: cadence: fix updating slave status when a bus has multiple peripherals (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm: Switch to use dev_err_probe() helper (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Switch to use dev_err_probe() helper (Jaroslav Kysela) [2179850]
- ASoC: bcm2835-i2s: Switch to use dev_err_probe() helper (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: increase SRAM inbox and outbox size to 1024 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Adding amd HS functionality to the sof core (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Add support for Rembrandt plaform. (Jaroslav Kysela) [2179850]
- ASoC: SOF: amd: Make ACP core code generic for newer SOC transition (Jaroslav Kysela) [2179850]
- ASoC: nau8825: Add ADCOUT IO drive strength control (Jaroslav Kysela) [2179850]
- ASoC: ak4458: Add ak4458_reset in device probe and remove (Jaroslav Kysela) [2179850]
- ASoC: Intel: sof_rt5682: remove SOF_RT1015_SPEAKER_AMP_100FS flag (Jaroslav Kysela) [2179850]
- ASoC: rt5682s: Reduce coupling of PLLB setting (Jaroslav Kysela) [2179850]
- ASoC: rt5682s: Reduce coupling of I2S1 setting (Jaroslav Kysela) [2179850]
- ASoC: rt5682s: Reduce coupling of Micbias and Vref2 settings (Jaroslav Kysela) [2179850]
- ALSA: dummy: Add customizable volume min/max. (Jaroslav Kysela) [2179850]
- ALSA: dummy: Fix trailing whitespaces. (Jaroslav Kysela) [2179850]
- soundwire: cadence: remove unused sdw_cdns_master_ops declaration (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Add mtrace type information for IPC4 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: icl: Set IPC4-specific DSP ops (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Add support for mtrace log extraction (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Configure the debug box offset (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Add define for the outbox window index (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Add macro to get core ID from log buffer status message (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4: Only print LOG BUFFER update message info if requested (Jaroslav Kysela) [2179850]
- sound: oss: dmasound: remove software_input_volume declaration (Jaroslav Kysela) [2179850]
- ALSA: memalloc: remove snd_dma_sg_ops declaration (Jaroslav Kysela) [2179850]
- ALSA: line6: remove line6_set_raw declaration (Jaroslav Kysela) [2179850]
- ASoC: hdmi-codec.c: use devm_kzalloc() for DMA data (Jaroslav Kysela) [2179850]
- ASoC: soc-core.c: setup rtd->pmdown_time at soc_new_pcm_runtime() (Jaroslav Kysela) [2179850]
- ASoC: ak4458: Remove component probe() and remove() (Jaroslav Kysela) [2179850]
- ASoC: max98390: Remove unnecessary amp on/off conrtol (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: tidyup snd_soc_dai_link_event_pre_pmu() (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: add comment for kzalloc()/kfree() on snd_soc_dai_link_event_pre_pmu() (Jaroslav Kysela) [2179850]
- ASoC: sti-sas: Remove the unneeded result variable (Jaroslav Kysela) [2179850]
- ASoC: simple-card-utils: switch to using gpiod API (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: mt8195: Add devicetree support to select topologies (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: mt8195: Add generic pcm_{open,close} callbacks (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: mt8195: Add mailbox generic callbacks for IPC (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: fixup snd_soc_dapm_new_control_unlocked() error handling (Jaroslav Kysela) [2179850]
- ASoC: soc-dapm.c: don't use WARN_ON() at snd_soc_dai_link_event_pre_pmu() (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Utilize acpi_get_subsystem_id() (Jaroslav Kysela) [2179850]
- ALSA: hda: cs35l41: Call put_device() in the scope of get_device() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Remove strsplit_u32() and tokenize_input() (Jaroslav Kysela) [2179850]
- lib/string_helpers: Introduce parse_int_array_user() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Introduce function sof_of_machine_select (Jaroslav Kysela) [2179850]
- ALSA: asihpi - Remove useless code in hpi_meter_get_peak() (Jaroslav Kysela) [2179850]
- ASoC: amd: fix spelling mistake: "i.e" -> "i.e." (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: check fe condition at out of loop (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: add soc_pcm_ret() (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: remove unnecessary codec2codec_close_delayed_work() (Jaroslav Kysela) [2179850]
- ALSA: hda/hdmi: Replace zero-length array with DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179850]
- ASoC: codecs: max98088: remove redundant ret variable (Jaroslav Kysela) [2179850]
- ASoC: amd: enable Pink sardine platform machine driver build. (Jaroslav Kysela) [2179850]
- ASoC: amd: add Pink Sardine machine driver using dmic (Jaroslav Kysela) [2179850]
- ASoC: amd: create platform device for acp6.2 machine driver (Jaroslav Kysela) [2179850]
- ASoC: amd: enable Pink Sardine acp6.2 drivers build (Jaroslav Kysela) [2179850]
- ASoC: amd: add acp6.2 pdm driver pm ops (Jaroslav Kysela) [2179850]
- ASoC: amd: add acp6.2 pci driver pm ops (Jaroslav Kysela) [2179850]
- ASoC: amd: add acp6.2 pdm driver dma ops (Jaroslav Kysela) [2179850]
- ASoC: amd: add acp6.2 irq handler (Jaroslav Kysela) [2179850]
- ASoC: amd: add acp6.2 pdm platform driver (Jaroslav Kysela) [2179850]
- ASoC: amd: add platform devices for acp6.2 pdm driver and dmic driver (Jaroslav Kysela) [2179850]
- ASoC: amd: add acp6.2 init/de-init functions (Jaroslav Kysela) [2179850]
- ASoC: amd: add Pink Sardine ACP PCI driver (Jaroslav Kysela) [2179850]
- ASoC: amd: add Pink Sardine platform ACP IP register header (Jaroslav Kysela) [2179850]
- ASoC: max98396: Make data monitor features configurable (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Modify dai_id macros to be more generic (Jaroslav Kysela) [2179850]
- ASoC: tas2562: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2179850]
- ASoC: tas2764: Export highpass filter setting (Jaroslav Kysela) [2179850]
- ASoC: tas2764: Add IRQ handling (Jaroslav Kysela) [2179850]
- ASoC: sigmadsp: switch to use kmemdup_nul() helper (Jaroslav Kysela) [2179850]
- ASoC: max98088: add support for noise gate reg (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: Use generic implementation for .ipc_msg_data field (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: add snd_sof_dsp_ops callbacks for pcm and mail box (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: Add dai driver for mt8186 (Jaroslav Kysela) [2179850]
- ASoC: codecs: add suspend and resume for ES8316 (Jaroslav Kysela) [2179850]
- ASoC: SOF: imx8ulp: add missing of_node_put() in imx8ulp_probe() (Jaroslav Kysela) [2179850]
- ASoC: SOF: imx: imx8ulp: declare ops structure as static (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Skip IMR boot after a firmware crash or boot failure (Jaroslav Kysela) [2179850]
- ASoC: SOF: ipc4-loader: Verify ext manifest magic number (Jaroslav Kysela) [2179850]
- ASoC: SOF: Kconfig: Make IPC_MESSAGE_INJECTOR depend on SND_SOC_SOF (Jaroslav Kysela) [2179850]
- ASoC: SOF: Kconfig: Make IPC_FLOOD_TEST depend on SND_SOC_SOF (Jaroslav Kysela) [2179850]
- ALSA: memalloc: Drop special handling of GFP for CONTINUOUS allocation (Jaroslav Kysela) [2179850]
- ASoC: Intel: sst: Switch to standard device pages (Jaroslav Kysela) [2179850]
- ALSA: pdaudiocf: Drop superfluous GFP setup (Jaroslav Kysela) [2179850]
- ALSA: vx: Drop superfluous GFP setup (Jaroslav Kysela) [2179850]
- ASoC: atmel_ssc_dai: Remove the unneeded result variable (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup WakeEnable and WakeStatus (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup AC Timing Control (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup IO control (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup PCM Stream channel map and channel count (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup PCM stream capabilities (Jaroslav Kysela) [2179850]
- soundwire: intel: add comment for control stream cap/chmap (Jaroslav Kysela) [2179850]
- soundwire: intel: remove unused PDM capabilities (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup SHIM SYNC (Jaroslav Kysela) [2179850]
- soundwire: intel: remove IPPTR unused definition (Jaroslav Kysela) [2179850]
- soundwire: intel: regroup definitions for LCTL (Jaroslav Kysela) [2179850]
- soundwire: intel: cleanup definition of LCOUNT (Jaroslav Kysela) [2179850]
- soundwire: intel: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2179850]
- soundwire: bus: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2179850]
- soundwire: intel: set dev_num_ida_min (Jaroslav Kysela) [2179850]
- soundwire: bus: allow device number to be unique at system level (Jaroslav Kysela) [2179850]
- soundwire: bus: rename sdw_ida as sdw_bus_ida (Jaroslav Kysela) [2179850]
- soundwire: dmi-quirks: add remapping for HP Omen 16-k0005TX (Jaroslav Kysela) [2179850]
- ALSA: hda: cleanup definitions for multi-link registers (Jaroslav Kysela) [2179850]
- ASoC: wcd9335: remove always-true condition (Jaroslav Kysela) [2179850]
- ASoC: hdmi-codec: remove unused definitions (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Remove dai_posn variable (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Add copy function for capture case (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Move sof_compr_copy functionality (Jaroslav Kysela) [2179850]
- ASoC: Intel: fix unused-variable warning in probe_codec (Jaroslav Kysela) [2179850]
- ASoC: soc-pcm.c: summarize related settings at soc_new_pcm() (Jaroslav Kysela) [2179850]
- ASoC: SOF: Fix compilation when HDA_AUDIO_CODEC config is disabled (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: add a label to make error path more clean (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: switch to use dev_err_probe() (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: remove unnecessary NULL checks (Jaroslav Kysela) [2179850]
- ASoC: Change handling of unimplemented set_bclk_ratio (Jaroslav Kysela) [2179850]
- ALSA: hda: Remove unused defines (Jaroslav Kysela) [2179850]
- ALSA: hda: Remove unused MAX_PIN_CONFIGS constant (Jaroslav Kysela) [2179850]
- ALSA: hda: Rework snd_hdac_stream_reset() to use macros (Jaroslav Kysela) [2179850]
- ALSA: hda: Move stream-register polling macros (Jaroslav Kysela) [2179850]
- ASoC: SOF: imx: Add i.MX8ULP HW support (Jaroslav Kysela) [2179850]
- ASoC: soc-utils-test: Add test for snd_soc_params_to_bclk() (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Use snd_soc_tdm_params_to_bclk() (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Fix comment typo in cs42l42_slow_start_put() (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Move cs42l42_supply_names to .c file (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Add include dependencies to cs42l42.h (Jaroslav Kysela) [2179850]
- ASoC: cs42l42: Don't include kernel.h (Jaroslav Kysela) [2179850]
- ASoC: codecs: es8326: change es8326_regmap_config to static (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Add support for computing timestamps (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Save channel count and sample bytes (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Introduce sof_compr_stream (Jaroslav Kysela) [2179850]
- ASoC: SOF: compress: Remove byte offset computation (Jaroslav Kysela) [2179850]
- soundwire: intel: Remove unnecessary TODO (Jaroslav Kysela) [2179850]
- ASoC: Variable type completion (Jaroslav Kysela) [2179850]
- ASoC: core: remove setting platform_max in kcontrol macros (Jaroslav Kysela) [2179850]
- ALSA: hda: Fix page fault in snd_hda_codec_shutdown() (Jaroslav Kysela) [2179850]
- ALSA: hda: Remove codec init and exit routines (Jaroslav Kysela) [2179850]
- ALSA: hda: Always free codec on the device release (Jaroslav Kysela) [2179850]
- ASoC: Intel: Drop hdac_ext usage for codec device creation (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: Introduce HDA codec init and exit routines (Jaroslav Kysela) [2179850]
- ASoC: Intel: Skylake: Introduce HDA codec init and exit routines (Jaroslav Kysela) [2179850]
- ASoC: codecs: add support for ES8326 (Jaroslav Kysela) [2179850]
- ASoC: Intel: Drop legacy HSW/BDW board-match information (Jaroslav Kysela) [2179850]
- ASoC: Intel: catpt: Drop SND_SOC_ACPI_INTEL_MATCH dependency (Jaroslav Kysela) [2179850]
- ASoC: Intel: bdw_rt286: Rename module (Jaroslav Kysela) [2179850]
- ASoC: Intel: hsw_rt5640: Rename module (Jaroslav Kysela) [2179850]
- ASoC: soc-utils: Improve kerneldoc for snd_soc_tdm_params_to_bclk() (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Add TDM support for acp i2s stream (Jaroslav Kysela) [2179850]
- ASoC: amd: acp: Initialize list to store acp_stream during pcm_open (Jaroslav Kysela) [2179850]
- ASoC: Variable type completion (Jaroslav Kysela) [2179850]
- ASoC: simple-card-utils: Fixup DAI sample format (Jaroslav Kysela) [2179850]
- ASoC: SOF: mediatek: Add sof_mt8186_machs for mt8186 (Jaroslav Kysela) [2179850]
- ASoC: SOF: Introduce function sof_of_machine_select (Jaroslav Kysela) [2179850]
- ASoC: omap: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: DAPM: Replace sprintf() calls with sysfs_emit_at() (Jaroslav Kysela) [2179850]
- ASoC: core: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: Intel: skylake: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: Intel: catpt: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: Intel: sst: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: tlv320aic26: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: cs43130: Replace scnprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ALSA: aoa: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ALSA: ac97: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179850]
- ASoC: Intel: cirrus-common: Use UID to map correct amp to prefix (Jaroslav Kysela) [2179850]
- ASoC: codecs: show PING status on resume failures (Jaroslav Kysela) [2179850]
- soundwire: add sdw_show_ping_status() helper (Jaroslav Kysela) [2179850]
- soundwire: intel/cadence: expose PING status in manager ops (Jaroslav Kysela) [2179850]
- soundwire: add read_ping_status helper definition in manager ops (Jaroslav Kysela) [2179850]
- soundwire: qcom: Update error prints to debug prints (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda: Drop no longer used ROM state definitions (Jaroslav Kysela) [2179850]
- ASoC: SOF: Intel: hda-loader: Use the FSR state definitions during bootup (Jaroslav Kysela) [2179850]
- ALSA: wavefront: remove redundant assignment to pointer end (Jaroslav Kysela) [2179850]
- soundwire: Use acpi_dev_for_each_child() (Jaroslav Kysela) [2179850]
- firewire: cdev: fix potential leak of kernel stack due to uninitialized value (Jaroslav Kysela) [2179850]
- list: Add list_next_entry_circular() and list_prev_entry_circular() (Jaroslav Kysela) [2179850]
- ASoC: cs43130: Re-use generic struct u16_fract (Jaroslav Kysela) [2179850]
- firewire: fix potential uaf in outbound_phy_packet_callback() (Jaroslav Kysela) [2179850]
- firewire: add kernel API to access packet structure in request structure for AR context (Jaroslav Kysela) [2179850]
- firewire: add kernel API to access CYCLE_TIME register (Jaroslav Kysela) [2179850]
- firewire: Add dummy read_csr/write_csr functions (Jaroslav Kysela) [2179850]
- treewide: Replace open-coded flex arrays in unions (Jaroslav Kysela) [2179850]
- firewire: Remove function callback casts (Jaroslav Kysela) [2179850]
- ALSA: doc: Document PC Beep Hidden Register on Realtek ALC256 (Jaroslav Kysela) [2179850]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2179850]

* Fri Jun 16 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-498.el8]
- Revert "softirq: Let ksoftirqd do its job" (Oleg Nesterov) [2196767]
- perf: Fix check before add_event_to_groups() in perf_group_detach() (Michael Petlan) [2209645] {CVE-2023-2235}
- perf/core: Call LSM hook after copying perf_event_attr (Audra Mitchell) [2172142]
- kprobes: Skip clearing aggrprobe's post_handler in kprobe-on-ftrace case (Audra Mitchell) [2172142]
- cgroup/cpuset: Enable update_tasks_cpumask() on top_cpuset (Audra Mitchell) [2172142]
- cgroup: Fix race condition at rebind_subsystems() (Audra Mitchell) [2172142]
- tick/nohz: unexport __init-annotated tick_nohz_full_setup() (Audra Mitchell) [2172142]
- ipc/mqueue: use get_tree_nodev() in mqueue_get_tree() (Audra Mitchell) [2172142]
- genirq: Synchronize interrupt thread startup (Audra Mitchell) [2172142]
- genirq: Initialize request_mutex if CONFIG_SPARSE_IRQ=n (Audra Mitchell) [2172142]
- scftorture: Fix distribution of short handler delays (Audra Mitchell) [2172142]
- tick/nohz: Use WARN_ON_ONCE() to prevent console saturation (Audra Mitchell) [2172142]
- ipc/sem: do not sleep with a spin lock held (Audra Mitchell) [2172142]
- signal: In get_signal test for signal_group_exit every time through the loop (Audra Mitchell) [2172142]
- genirq: Move prio assignment into the newly created thread (Audra Mitchell) [2172142]
- sched,irq: Convert to sched_set_fifo() (Audra Mitchell) [2172142]
- cgroup/cpuset: Fix violation of cpuset locking rule (Audra Mitchell) [2172142]
- timers: Move clearing of base::timer_running under base:: Lock (Audra Mitchell) [2172142]
- cgroup1: fix leaked context root causing sporadic NULL deref in LTP (Audra Mitchell) [2172142]
- jump_label: Fix usage in module __init (Audra Mitchell) [2172142]
- padata: fix possible padata_works_lock deadlock (Audra Mitchell) [2172142]
- genirq/PM: Always unlock IRQ descriptor in rearm_wake_irq() (Audra Mitchell) [2172142]
- padata: upgrade smp_mb__after_atomic to smp_mb in padata_do_serial (Audra Mitchell) [2172142]
- cpu/speculation: Warn on unsupported mitigations= parameter (Audra Mitchell) [2172142]
- x86/speculation: Remove redundant arch_smt_update() invocation (Audra Mitchell) [2172142]
- cpu/hotplug: Non-SMP machines do not make use of booted_once (Audra Mitchell) [2172142]
- can: usb_8dev: usb_8dev_start_xmit(): fix double dev_kfree_skb() in error path (Jose Ignacio Tornos Martinez) [2156581] {CVE-2022-28388}
- kernfs: Improve kernfs_notify() poll notification latency (Ian Kent) [2195844]
- stmmac: fix changing mac address (Corinna Vinschen) [2177654]
- net/sched: cls_tcindex: downgrade to imperfect hash (Davide Caratti) [2192308] {CVE-2023-1829}
- Bluetooth: btsdio: fix use after free bug in btsdio_remove due to race condition (Ricardo Robaina) [2185961] {CVE-2023-1989}
- net: qcom/emac: Fix use after free bug in emac_remove due to race condition (Ricardo Robaina) [2192673] {CVE-2023-2483}
- s390/crypto: improve retry logic in case of master key change (Tobias Huschle) [2212794]
- bpf: pull before calling skb_postpull_rcsum() (Felix Maurer) [2186521]
- bpf, sockmap: fix race in sock_map_free() (Felix Maurer) [2186521]
- bpf, sock_map: Move cancel_work_sync() out of sock lock (Felix Maurer) [2186521]
- brcmfmac: Switch to appropriate helper to load EFI variable contents (Lenny Szubowicz) [2183047]
- iwlwifi: Switch to proper EFI variable store interface (Lenny Szubowicz) [2183047]
- efi: Store mask of supported runtime services in struct efi (Lenny Szubowicz) [2183047]
- NFS: Don't report errors from nfs_pageio_complete() more than once (Benjamin Coddington) [2213644]
- NFS: Do not report flush errors in nfs_write_end() (Benjamin Coddington) [2213644]
- NFS: Don't report ENOSPC write errors twice (Benjamin Coddington) [2213644]
- NFS: fsync() should report filesystem errors over EINTR/ERESTARTSYS (Benjamin Coddington) [2213644]
- NFS: Do not report EINTR/ERESTARTSYS as mapping errors (Benjamin Coddington) [2213644]
- net: openvswitch: release vport resources on failure (Antoine Tenart) [2190225]
- net: openvswitch: Add support to count upcall packets (Antoine Tenart) [2190225]
- net: openvswitch: fix race on port output (Antoine Tenart) [2190225]
- net: openvswitch: fix possible memory leak in ovs_meter_cmd_set() (Antoine Tenart) [2190225]
- net: openvswitch: fix flow memory leak in ovs_flow_cmd_new (Antoine Tenart) [2190225]
- openvswitch: Fix flow lookup to use unmasked key (Antoine Tenart) [2190225]
- openvswitch: switch from WARN to pr_warn (Antoine Tenart) [2190225]
- EDAC/i10nm: Add Intel Emerald Rapids server support (Aristeu Rozanski) [2165649]
- EDAC/skx_common: Delete duplicated and unreachable code (Aristeu Rozanski) [2165649]
- EDAC/skx_common: Enable EDAC support for the "near" memory (Aristeu Rozanski) [2165649]
- EDAC/i10nm: Print an extra register set of retry_rd_err_log (Aristeu Rozanski) [2165649]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers for HBM (Aristeu Rozanski) [2165649]
- EDAC/skx_common: Add ChipSelect ADXL component (Aristeu Rozanski) [2165649]
- EDAC/i10nm: Fix NVDIMM detection (Aristeu Rozanski) [2165649]
- EDAC/skx_common: Set the memory type correctly for HBM memory (Aristeu Rozanski) [2165649]
- EDAC/mc: Add new HBM2 memory type (Aristeu Rozanski) [2165649]
- EDAC: Replace EDAC_DIMM_PTR() macro with edac_get_dimm() function (Aristeu Rozanski) [2165649]
- tpm: disable hwrng for fTPM on some AMD designs (Štěpán Horáček) [2159583]
- tpm/eventlog: Don't abort tpm_read_log on faulty ACPI address (Štěpán Horáček) [2159583]
- tpm: Use managed allocation for bios event log (Štěpán Horáček) [2159583]
- efi: tpm: Avoid READ_ONCE() for accessing the event log (Štěpán Horáček) [2159583]
- tpm: Allow system suspend to continue when TPM suspend fails (Štěpán Horáček) [2159583]
- tpm: tpm_tis: Add the missed acpi_put_table() to fix memory leak (Štěpán Horáček) [2159583]
- tpm: tpm_crb: Add the missed acpi_put_table() to fix memory leak (Štěpán Horáček) [2159583]
- tpm: acpi: Call acpi_put_table() to fix memory leak (Štěpán Horáček) [2159583]
- tpm/tpm_crb: Fix error message in __crb_relinquish_locality() (Štěpán Horáček) [2159583]
- tpm: Avoid function type cast of put_device() (Štěpán Horáček) [2159583]
- char: tpm: Protect tpm_pm_suspend with locks (Štěpán Horáček) [2159583]
- efi/tpm: Pass correct address to memblock_reserve (Štěpán Horáček) [2159583]
- char: move from strlcpy with unused retval to strscpy (Štěpán Horáček) [2159583]
- tpm: eventlog: Fix section mismatch for DEBUG_SECTION_MISMATCH (Štěpán Horáček) [2159583]
- tpm: Fix buffer access in tpm2_get_tpm_pt() (Štěpán Horáček) [2159583]
- tpm: ibmvtpm: Correct the return value in tpm_ibmvtpm_probe() (Štěpán Horáček) [2159583]
- tpm: use try_get_ops() in tpm-space.c (Štěpán Horáček) [2159583]
- tpm: Fix error handling in async work (Štěpán Horáček) [2159583]
- tpm: vtpm_proxy: Check length to avoid compiler warning (Štěpán Horáček) [2159583]
- tpm: fix NPE on probe for missing device (Štěpán Horáček) [2159583]
- tpm: fix potential NULL pointer access in tpm_del_char_device (Štěpán Horáček) [2159583]
- tpm_tis: Fix an error handling path in 'tpm_tis_core_init()' (Štěpán Horáček) [2159583]
- tpm: add request_locality before write TPM_INT_ENABLE (Štěpán Horáček) [2159583]
- tpm_tis_spi: Add missing SPI ID (Štěpán Horáček) [2159583]
- tpm: fix Atmel TPM crash caused by too frequent queries (Štěpán Horáček) [2159583]
- tpm: Check for integer overflow in tpm2_map_response_body() (Štěpán Horáček) [2159583]
- KEYS: trusted: Fix TPM reservation for seal/unseal (Štěpán Horáček) [2135881]
- KVM: x86: Add helpers to recalc physical vs. logical optimized APIC maps (John Allen) [2117761]
- KVM: x86: Allow APICv APIC ID inhibit to be cleared (John Allen) [2117761]
- KVM: x86: Track required APICv inhibits with variable, not callback (John Allen) [2117761]
- Revert "KVM: SVM: Do not throw warning when calling avic_vcpu_load on a running vcpu" (John Allen) [2117761]
- KVM: SVM: Handle multiple logical targets in AVIC kick fastpath (John Allen) [2117761]
- KVM: SVM: Require logical ID to be power-of-2 for AVIC entry (John Allen) [2117761]
- KVM: SVM: Update svm->ldr_reg cache even if LDR is "bad" (John Allen) [2117761]
- KVM: SVM: Always update local APIC on writes to logical dest register (John Allen) [2117761]
- KVM: SVM: Inhibit AVIC if vCPUs are aliased in logical mode (John Allen) [2117761]
- KVM: x86: Inhibit APICv/AVIC if the optimized physical map is disabled (John Allen) [2117761]
- KVM: x86: Honor architectural behavior for aliased 8-bit APIC IDs (John Allen) [2117761]
- Documentation: KVM: Add SPDX-License-Identifier tag (John Allen) [2117761]
- Documentation: KVM: add virtual CPU errata documentation (John Allen) [2117761]
- KVM: x86: Disable APIC logical map if vCPUs are aliased in logical mode (John Allen) [2117761]
- KVM: x86: Disable APIC logical map if logical ID covers multiple MDAs (John Allen) [2117761]
- KVM: x86: Skip redundant x2APIC logical mode optimized cluster setup (John Allen) [2117761]
- KVM: x86: Explicitly track all possibilities for APIC map's logical modes (John Allen) [2117761]
- KVM: x86: Explicitly skip optimized logical map setup if vCPU's LDR==0 (John Allen) [2117761]
- KVM: SVM: Add helper to perform final AVIC "kick" of single vCPU (John Allen) [2117761]
- KVM: SVM: Document that vCPU ID == APIC ID in AVIC kick fastpatch (John Allen) [2117761]
- Revert "KVM: SVM: Use target APIC ID to complete x2AVIC IRQs when possible" (John Allen) [2117761]
- KVM: SVM: Replace "avic_mode" enum with "x2avic_enabled" boolean (John Allen) [2117761]
- KVM: x86: Inhibit APIC memslot if x2APIC and AVIC are enabled (John Allen) [2117761]
- KVM: x86: Handle APICv updates for APIC "mode" changes via request (John Allen) [2117761]
- KVM: x86: Don't inhibit APICv/AVIC if xAPIC ID mismatch is due to 32-bit ID (John Allen) [2117761]
- KVM: x86: Don't inhibit APICv/AVIC on xAPIC ID "change" if APIC is disabled (John Allen) [2117761]
- KVM: SVM: Process ICR on AVIC IPI delivery failure due to invalid target (John Allen) [2117761]
- KVM: SVM: Flush the "current" TLB when activating AVIC (John Allen) [2117761]
- KVM: x86: Purge "highest ISR" cache when updating APICv state (John Allen) [2117761]
- KVM: x86: Blindly get current x2APIC reg value on "nodecode write" traps (John Allen) [2117761]
- KVM: x86: Bug the VM if an accelerated x2APIC trap occurs on a "bad" reg (John Allen) [2117761]
- KVM: x86: Do not block APIC write for non ICR registers (John Allen) [2117761]
- KVM: x86: Add support for vICR APIC-write VM-Exits in x2APIC mode (John Allen) [2117761]
- KVM: x86: fix APICv/x2AVIC disabled when vm reboot by itself (John Allen) [2117761]
- KVM: SEV: fix misplaced closing parenthesis (John Allen) [2117761]
- KVM: SVM: Do not virtualize MSR accesses for APIC LVTT register (John Allen) [2117761]
- KVM: SVM: Fix x2APIC MSRs interception (John Allen) [2117761]
- KVM: x86: nSVM: optimize svm_set_x2apic_msr_interception (John Allen) [2117761]
- KVM: SVM: Add AVIC doorbell tracepoint (John Allen) [2117761]
- KVM: SVM: Use target APIC ID to complete x2AVIC IRQs when possible (John Allen) [2117761]
- KVM: x86: Warning APICv inconsistency only when vcpu APIC mode is valid (John Allen) [2117761]
- KVM: x86: Move APIC access page helper to common x86 code (John Allen) [2117761]
- KVM: SVM: Introduce hybrid-AVIC mode (John Allen) [2117761]
- KVM: SVM: Do not throw warning when calling avic_vcpu_load on a running vcpu (John Allen) [2117761]
- KVM: SVM: Modify AVIC GATag to support max number of 512 vCPUs (John Allen) [2117761]
- KVM: SVM: Fix a benign off-by-one bug in AVIC physical table mask (John Allen) [2117761]
- KVM: SVM: Ignore writes to Remote Read Data on AVIC write traps (John Allen) [2117761]
- KVM: SVM: Introduce logic to (de)activate x2AVIC mode (John Allen) [2117761]
- KVM: x86: nSVM: always intercept x2apic msrs (John Allen) [2117761]
- KVM: SVM: Don't put/load AVIC when setting virtual APIC mode (John Allen) [2117761]
- KVM: SVM: Refresh AVIC configuration when changing APIC mode (John Allen) [2117761]
- KVM: x86: Deactivate APICv on vCPU with APIC disabled (John Allen) [2117761]
- KVM: SVM: Adding support for configuring x2APIC MSRs interception (John Allen) [2117761]
- KVM: SVM: Do not support updating APIC ID when in x2APIC mode (John Allen) [2117761]
- KVM: SVM: Compute dest based on sender's x2APIC status for AVIC kick (John Allen) [2117761]
- KVM: SVM: Update avic_kick_target_vcpus to support 32-bit APIC ID (John Allen) [2117761]
- KVM: SVM: Update max number of vCPUs supported for x2AVIC mode (John Allen) [2117761]
- KVM: svm/avic: Drop "struct kvm_x86_ops" for avic_hardware_setup() (John Allen) [2117761]
- KVM: SVM: Detect X2APIC virtualization (x2AVIC) support (John Allen) [2117761]
- KVM: x86: lapic: Rename [GET/SET]_APIC_DEST_FIELD to [GET/SET]_XAPIC_DEST_FIELD (John Allen) [2117761]
- x86/cpufeatures: Introduce x2AVIC CPUID bit (John Allen) [2117761]
- KVM: x86: SVM: fix nested PAUSE filtering when L0 intercepts PAUSE (John Allen) [2117761]
- KVM: x86: nSVM: support PAUSE filtering when L0 doesn't intercept PAUSE (John Allen) [2117761]
- KVM: x86: SVM: drop preempt-safe wrappers for avic_vcpu_load/put (John Allen) [2117761]
- KVM: x86: disable preemption around the call to kvm_arch_vcpu_{un|}blocking (John Allen) [2117761]
- KVM: x86: disable preemption while updating apicv inhibition (John Allen) [2117761]
- KVM: SVM: Fix x2APIC Logical ID calculation for avic_kick_target_vcpus_fast (John Allen) [2117761]
- KVM: x86: SVM: fix avic_kick_target_vcpus_fast (John Allen) [2117761]
- KVM: SVM: Use target APIC ID to complete AVIC IRQs when possible (John Allen) [2117761]
- KVM: x86: SVM: remove avic's broken code that updated APIC ID (John Allen) [2117761]
- KVM: x86: inhibit APICv/AVIC on changes to APIC ID or APIC base (John Allen) [2117761]
- KVM: x86: document AVIC/APICv inhibit reasons (John Allen) [2117761]
- KVM: x86: SVM: allow AVIC to co-exist with a nested guest running (John Allen) [2117761]
- KVM: x86: allow per cpu apicv inhibit reasons (John Allen) [2117761]
- KVM: x86: SVM: allow to force AVIC to be enabled (John Allen) [2117761]

* Fri Jun 09 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-497.el8]
- sctp: fix a potential overflow in sctp_ifwdtsn_skip (Xin Long) [2189324]
- sctp: check send stream number after wait_for_sndbuf (Xin Long) [2189324]
- sctp: sctp_sock_filter(): avoid list_entry() on possibly empty list (Xin Long) [2189324]
- sctp: fail if no bound addresses can be used for a given scope (Xin Long) [2189324]
- sctp: sysctl: make extra pointers netns aware (Xin Long) [2189324]
- sctp: add a refcnt in sctp_stream_priorities to avoid a nested loop (Xin Long) [2189324]
- sctp: delete free member from struct sctp_sched_ops (Xin Long) [2189324]
- sctp: fix memory leak in sctp_stream_outq_migrate() (Xin Long) [2189324]
- sctp: clear out_curr if all frag chunks of current msg are pruned (Xin Long) [2189324]
- sctp: remove the unnecessary sinfo_stream check in sctp_prsctp_prune_unsent (Xin Long) [2189324]
- sched/fair: Fix imbalance overflow (Phil Auld) [RHEL-419]
- sched/fair: Move calculate of avg_load to a better location (Phil Auld) [RHEL-419]
- sched/fair: Sanitize vruntime of entity being migrated (Phil Auld) [RHEL-419]
- sched/rt: pick_next_rt_entity(): check list_entry (Phil Auld) [RHEL-419]
- sched/fair: sanitize vruntime of entity being placed (Phil Auld) [RHEL-419]
- sched/fair: Limit sched slice duration (Phil Auld) [RHEL-419]
- sched/topology: Add __init for sched_init_domains() (Phil Auld) [RHEL-419]
- sched/core: Reorganize ttwu_do_wakeup() and ttwu_do_activate() (Phil Auld) [RHEL-419]
- sched/core: Micro-optimize ttwu_runnable() (Phil Auld) [RHEL-419]
- sched/numa: Stop an exhastive search if an idle core is found (Phil Auld) [RHEL-419]
- sched/topology: Add __init for init_defrootdomain (Phil Auld) [RHEL-419]
- sched: Clear ttwu_pending after enqueue_task() (Phil Auld) [RHEL-419]
- sched/psi: Fix possible missing or delayed pending event (Phil Auld) [RHEL-419]
- sched/fair: Cleanup for SIS_PROP (Phil Auld) [RHEL-419]
- sched/fair: Default to false in test_idle_cores() (Phil Auld) [RHEL-419]
- sched/fair: Remove useless check in select_idle_core() (Phil Auld) [RHEL-419]
- sched/fair: Avoid double search on same cpu (Phil Auld) [RHEL-419]
- sched/fair: Remove redundant check in select_idle_smt() (Phil Auld) [RHEL-419]
- sched: Rename task_running() to task_on_cpu() (Phil Auld) [RHEL-419]
- sched/fair: Move call to list_last_entry() in detach_tasks (Phil Auld) [RHEL-419]
- sched/fair: Cleanup loop_max and loop_break (Phil Auld) [RHEL-419]
- sched/fair: Make sure to try to detach at least one movable task (Phil Auld) [RHEL-419]
- sched: Add update_current_exec_runtime helper (Phil Auld) [RHEL-419]
- sched/fair: Don't init util/runnable_avg for !fair task (Phil Auld) [RHEL-419]
- sched/fair: Move task sched_avg attach to enqueue_task_fair() (Phil Auld) [RHEL-419]
- sched/fair: Update comments in enqueue/dequeue_entity() (Phil Auld) [RHEL-419]
- sched/fair: Maintain task se depth in set_task_rq() (Phil Auld) [RHEL-419]
- sched/debug: Print each field value left-aligned in sched_show_task() (Phil Auld) [RHEL-419]
- sched/fair: Make per-cpu cpumasks static (Phil Auld) [RHEL-419]
- sched/fair: Rename select_idle_mask to select_rq_mask (Phil Auld) [RHEL-419]
- sched: Snapshot thread flags (Phil Auld) [RHEL-419]
- sched/fair: find_idlest_group(): Remove unused sd_flag parameter (Phil Auld) [RHEL-419]
- redhat/genlog.py: add support to list/process zstream Jira tickets (Herton R. Krzesinski)
- powercap: intel_rapl: add support for Emerald Rapids (Prarit Bhargava) [2156804]
- vsock: avoid to close connected socket after the timeout (Stefano Garzarella) [2209710]
- sfc: Fix module EEPROM reporting for QSFP modules (Íñigo Huguet) [2192382]
- perf script: Fix missing Retire Latency fields option documentation (Michael Petlan) [2177014]
- perf event x86: Add retire_lat when synthesizing PERF_SAMPLE_WEIGHT_STRUCT (Michael Petlan) [2177014]
- perf test x86: Support the retire_lat (Retire Latency) sample_type check (Michael Petlan) [2177014]
- perf script: Support Retire Latency (Michael Petlan) [2177014]
- perf report: Support Retire Latency (Michael Petlan) [2177014]

* Thu Jun 01 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-496.el8]
- netfilter: nft_redir: correct value of inet type `.maxattrs` (Florian Westphal) [2189517]
- netfilter: tproxy: fix deadlock due to missing BH disable (Florian Westphal) [2189517]
- netfilter: ebtables: fix table blob use-after-free (Florian Westphal) [2189517]
- netfilter: ctnetlink: fix possible refcount leak in ctnetlink_create_conntrack() (Florian Westphal) [2189517]
- netfilter: nf_tables: make table handle allocation per-netns friendly (Florian Westphal) [2189517]
- netfilter: nf_tables: really skip inactive sets when allocating name (Florian Westphal) [2189517]
- intel_idle: add Emerald Rapids Xeon support (Prarit Bhargava) [2156824]
- tools/power turbostat: Introduce support for EMR (Prarit Bhargava) [2156806]
- kunit: drm: make DRM buddy test compatible with other pages sizes (Nico Pache) [2209108]
- redhat: fix missing kunit module in mod-internal.list (Nico Pache) [2209108]
- bluetooth: Perform careful capability checks in hci_sock_ioctl() (Ricardo Robaina) [2196353] {CVE-2023-2002}
- macvlan: Fix mc_filter calculation (Xin Long) [2186948]
- macvlan: Add netlink attribute for broadcast cutoff (Xin Long) [2186948]
- macvlan: Skip broadcast queue if multicast with single receiver (Xin Long) [2186948]
- net: macvlan: fix memory leaks of macvlan_common_newlink (Xin Long) [2186948]
- net: macvlan: change schedule system_wq to system_unbound_wq (Xin Long) [2186948]
- net: macvlan: fix potential UAF problem for lowerdev (Xin Long) [2186948]
- macvlan: Support for high multicast packet rate (Xin Long) [2186948]
- macvlan: Skip loopback packets in RX handler (Xin Long) [2186948]
- macvlan: fix null dereference in macvlan_device_event() (Xin Long) [2186948]
- macvlan: add cond_resched() during multicast processing (Xin Long) [2186948]
- macvlan: schedule bc_work even if error (Xin Long) [2186948]
- macvlan: replace kfree_skb by consume_skb for drop profiles (Xin Long) [2186948]
- tipc: fix unexpected link reset due to discovery messages (Xin Long) [2193242]
- tipc: Fix potential OOB in tipc_link_proto_rcv() (Xin Long) [2193242]
- tipc: check skb_linearize() return value in tipc_disc_rcv() (Xin Long) [2193242]
- tipc: fix the msg->req tlv len check in tipc_nl_compat_name_table_dump_header (Xin Long) [2193242]
- tipc: fix a null-ptr-deref in tipc_topsrv_accept (Xin Long) [2193242]
- s390/dasd: fix hanging blockdevice after request requeue (Tobias Huschle) [2043875]
- s390/dasd: add autoquiesce event for start IO error (Tobias Huschle) [2043875]
- s390/dasd: add aq_timeouts autoquiesce trigger (Tobias Huschle) [2043875]
- s390/dasd: add aq_requeue sysfs attribute (Tobias Huschle) [2043875]
- s390/dasd: add aq_mask sysfs attribute (Tobias Huschle) [2043875]
- s390/dasd: add autoquiesce feature (Tobias Huschle) [2043875]
- s390/dasd: remove unused DASD EER defines (Tobias Huschle) [2043875]
- md: Fix bitmap offset type in sb writer (Nigel Croxon) [2189478]
- md/raid5: Improve performance for sequential IO (Nigel Croxon) [2189478]
- md/raid5: remove unused working_disks variable (Nigel Croxon) [2189478]
- md/raid10: fix memleak of md thread (Nigel Croxon) [2189478]
- md/raid10: fix memleak for 'conf->bio_split' (Nigel Croxon) [2189478]
- md/raid10: fix leak of 'r10bio->remaining' for recovery (Nigel Croxon) [2189478]
- md/raid10: don't BUG_ON() in raise_barrier() (Nigel Croxon) [2189478]
- md: fix soft lockup in status_resync (Nigel Croxon) [2189478]
- md: add error_handlers for raid0 and linear (Nigel Croxon) [2151208 2189478]
- md: Use optimal I/O size for last bitmap page (Nigel Croxon) [2189478]
- md: Fix types in sb writer (Nigel Croxon) [2189478]
- md: Move sb writer loop to its own function (Nigel Croxon) [2189478]
- md/raid10: Fix typo in comment (replacment -> replacement) (Nigel Croxon) [2189478]
- md/raid10: fix null-ptr-deref in raid10_sync_request (Nigel Croxon) [2189478]
- md/raid10: fix task hung in raid10d (Nigel Croxon) [2189478]
- md: simplify sysctl registration (Nigel Croxon) [2189478]
- HID: intel-ish-hid: ipc: Fix potential use-after-free in work function (Tony Camuso) [2182388]
- devm-helpers: Fix devm_delayed_work_autocancel() kerneldoc (Tony Camuso) [2182388]
- devm-helpers: Add resource managed version of work init (Tony Camuso) [2182388]
- workqueue: Add resource managed version of delayed work init (Tony Camuso) [2182388]
- HID: stop drivers from selecting CONFIG_HID (Tony Camuso) [2182388]
- HID: intel_ish-hid: Add check for ishtp_dma_tx_map (Tony Camuso) [2182388]
- HID: intel-ish-hid: ishtp: remove variable rb_count (Tony Camuso) [2182388]

* Fri May 26 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-495.el8]
- i40e: Add support for VF to specify its primary MAC address (Stefan Assmann) [2091552]
- net/tg3: resolve deadlock in tg3_reset_task() during EEH (Ken Cox) [2159218 2166475]
- HID: asus: use spinlock to safely schedule workers (Ricardo Robaina) [2186282] {CVE-2023-1079}
- HID: asus: use spinlock to protect concurrent accesses (Ricardo Robaina) [2186282] {CVE-2023-1079}
- e1000e: Disable TSO on i219-LM card to increase speed (Ken Cox) [2109782]
- erspan: get the proto with the md version for collect_md (Xin Long) [2207724]
- netfilter: nf_tables: deactivate anonymous set from preparation phase (Florian Westphal) [2196148] {CVE-2023-32233}
- scsi: scsi_dh_alua: Fix memleak for 'qdata' in alua_activate() (Ewan D. Milne) [2171092]
- scsi: core: Add BLIST_SKIP_VPD_PAGES for SKhynix H28U74301AMR (Ewan D. Milne) [2171092]
- scsi: core: Add BLIST_NO_VPD_SIZE for some VDASD (Ewan D. Milne) [2171092]
- scsi: core: Fix a source code comment (Ewan D. Milne) [2171092]
- scsi: Revert "scsi: core: map PQ=1, PDT=other values to SCSI_SCAN_TARGET_PRESENT" (Ewan D. Milne) [2171092]
- scsi: scsi_debug: Delete unreachable code in inquiry_vpd_b0() (Ewan D. Milne) [2171092]
- scsi: core: Use SCSI_SCAN_INITIAL in do_scsi_scan_host() (Ewan D. Milne) [2171092]
- scsi: core: Use SCSI_SCAN_RESCAN in __scsi_add_device() (Ewan D. Milne) [2171092]
- scsi: Define the COMPLETED sense key (Ewan D. Milne) [2171092]
- scsi: core: Add I/O timeout count for SCSI device (Ewan D. Milne) [2171092]
- tipc: check the bearer min mtu properly when setting it by netlink (Xin Long) [2185143]
- tipc: do not update mtu if msg_max is too small in mtu negotiation (Xin Long) [2185143]
- tipc: add tipc_bearer_min_mtu to calculate min mtu (Xin Long) [2185143]
- net/tipc: fix tipc header files for kernel-doc (Xin Long) [2185143]
- scsi: smartpqi: Update version to 2.1.22-040 (Don Brace) [2162103]
- scsi: smartpqi: Update copyright to 2023 (Don Brace) [2162103]
- scsi: smartpqi: Add sysfs entry for NUMA node in /sys/block/sdX/device (Don Brace) [2162103]
- scsi: smartpqi: Stop sending driver-initiated TURs (Don Brace) [2162103]
- scsi: smartpqi: Fix byte aligned writew for ARM servers (Don Brace) [2162103]
- scsi: smartpqi: Add support for RAID NCQ priority (Don Brace) [2162103]
- scsi: smartpqi: Validate block layer host tag (Don Brace) [2162103]
- scsi: smartpqi: Remove contention for raid_bypass_cnt (Don Brace) [2162103]
- scsi: smartpqi: Fix rare SAS transport memory leak (Don Brace) [2162103]
- scsi: smartpqi: Remove NULL pointer check (Don Brace) [2162103]
- scsi: smartpqi: Add new controller PCI IDs (Don Brace) [2162103]
- scsi: smartpqi: Map full length of PCI BAR 0 (Don Brace) [2162103]
- scsi: smartpqi: Replace one-element array with flexible-array member (Don Brace) [2162103]
- scsi: mpi3mr: Use -ENOMEM instead of -1 in mpi3mr_expander_add() (Tomas Henzl) [2163671]
- scsi: mpi3mr: Use IRQ save variants of spinlock to protect chain frame allocation (Tomas Henzl) [2163671]
- scsi: mpi3mr: Handle soft reset in progress fault code (0xF002) (Tomas Henzl) [2163671]
- scsi: mpi3mr: Update driver version to 8.4.1.0.0 (Tomas Henzl) [2163671]
- scsi: mpi3mr: Update copyright year (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix W=1 compilation warnings (Tomas Henzl) [2163671]
- scsi: mpi3mr: Update MPI Headers to revision 27 (Tomas Henzl) [2163671]
- scsi: mpi3mr: Avoid escalating to higher level reset when target is removed (Tomas Henzl) [2163671]
- scsi: mpi3mr: Modify MUR timeout value to 120 seconds (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix admin queue memory leak upon soft reset (Tomas Henzl) [2163671]
- scsi: mpi3mr: Successive VD delete and add causes FW fault (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix expander node leak in mpi3mr_remove() (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix memory leaks in mpi3mr_init_ioc() (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix sas_hba.phy memory leak in mpi3mr_remove() (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix mpi3mr_hba_port memory leak in mpi3mr_remove() (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix config page DMA memory leak (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix throttle_groups memory leak (Tomas Henzl) [2163671]
- scsi: mpi3mr: Bad drive in topology results kernel crash (Tomas Henzl) [2163671]
- scsi: mpi3mr: NVMe command size greater than 8K fails (Tomas Henzl) [2163671]
- scsi: mpi3mr: Return proper values for failures in firmware init path (Tomas Henzl) [2163671]
- scsi: mpi3mr: Wait for diagnostic save during controller init (Tomas Henzl) [2163671]
- scsi: mpi3mr: Driver unload crashes host when enhanced logging is enabled (Tomas Henzl) [2163671]
- scsi: mpi3mr: ioctl timeout when disabling/enabling interrupt (Tomas Henzl) [2163671]
- scsi: mpi3mr: Remove unneeded version.h include (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix missing mrioc->evtack_cmds initialization (Tomas Henzl) [2163671]
- scsi: mpi3mr: Use number of bits to manage bitmap sizes (Tomas Henzl) [2163671]
- scsi: mpi3mr: Remove unnecessary memcpy() to alltgt_info->dmi (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix issues in mpi3mr_get_all_tgt_info() (Tomas Henzl) [2163671]
- scsi: mpi3mr: Fix an issue found by KASAN (Tomas Henzl) [2163671]
- scsi: mpi3mr: Refer CONFIG_SCSI_MPI3MR in Makefile (Tomas Henzl) [2163671]
- scsi: mpi3mr: Remove usage of dma_get_required_mask() API (Tomas Henzl) [2163671]
- scsi: mpi3mr: Suppress command reply debug prints (Tomas Henzl) [2163671]
- ipmi: ipmb: Fix the MODULE_PARM_DESC associated to 'retry_time_ms' (Tony Camuso) [2174220]
- ipmi:ssif: Add a timer between request retries (Tony Camuso) [2174220]
- ipmi:ssif: Remove rtc_us_timer (Tony Camuso) [2174220]
- ipmi_ssif: Rename idle state and check (Tony Camuso) [2174220]
- ipmi:ssif: resend_msg() cannot fail (Tony Camuso) [2174220]
- ipmi/watchdog: use strscpy() to instead of strncpy() (Tony Camuso) [2174220]
- ipmi: ssif_bmc: Convert to i2c's .probe_new() (Tony Camuso) [2174220]
- ipmi: fix use after free in _ipmi_destroy_user() (Tony Camuso) [2174220]
- ipmi:ssif: Increase the message retry time (Tony Camuso) [2174220]
- ipmi: Fix some kernel-doc warnings (Tony Camuso) [2174220]
- ipmi: ssif_bmc: Use EPOLLIN instead of POLLIN (Tony Camuso) [2174220]
- ipmi: fix msg stack when IPMI is disconnected (Tony Camuso) [2174220]
- ipmi: fix memleak when unload ipmi driver (Tony Camuso) [2174220]
- ipmi: fix long wait in unload when IPMI disconnect (Tony Camuso) [2174220]
- ipmi: kcs: Poll OBF briefly to reduce OBE latency (Tony Camuso) [2174220]
- ipmi: ssif_bmc: Add SSIF BMC driver (Tony Camuso) [2174220]
- ipmi: Remove unused struct watcher_entry (Tony Camuso) [2174220]
- ipmi: kcs: aspeed: Update port address comments (Tony Camuso) [2174220]
- ipmi: Add __init/__exit annotations to module init/exit funcs (Tony Camuso) [2174220]
- ipmi:ipmb: Don't call ipmi_unregister_smi() on a register failure (Tony Camuso) [2174220]
- ipmi:ipmb: Fix a vague comment and a typo (Tony Camuso) [2174220]
- ipmi: Fix comment typo (Tony Camuso) [2174220]
- char: ipmi: modify NPCM KCS configuration (Tony Camuso) [2174220]
- cipso: Fix data-races around sysctl. (Juraj Marcin) [2181138]
- netlabel: fix out-of-bounds memory accesses (Juraj Marcin) [2181138]
- CIPSO: Fix unaligned memory access in cipso_v4_gentag_hdr (Juraj Marcin) [2181138]
- netlabel_domainhash.c: Use built-in RCU list checking (Juraj Marcin) [2181138]
- net: netlabel: Use built-in RCU list checking (Juraj Marcin) [2181138]
- netlabel: remove redundant assignment to pointer iter (Juraj Marcin) [2181138]
- capabilities: fix potential memleak on error path from vfs_getxattr_alloc() (Juraj Marcin) [2181138]
- selinux: enable use of both GFP_KERNEL and GFP_ATOMIC in convert_context() (Juraj Marcin) [2181138]
- selinux: free contexts previously transferred in selinux_add_opt() (Juraj Marcin) [2181138]
- LSM: general protection fault in legacy_parse_param (Juraj Marcin) [2181138]
- selinux: check return value of sel_make_avc_files (Juraj Marcin) [2181138]
- net/sched: flower: fix error handler on replace (Ivan Vecera) [2180870]
- Revert "net/sched: flower: Fix wrong handle assignment during filter change" (Ivan Vecera) [2180870]
- net/sched: flower: fix filter idr initialization (Ivan Vecera) [2180870]
- net/sched: cls_api: remove block_cb from driver_list before freeing (Ivan Vecera) [2180870]
- net/sched: flower: Fix wrong handle assignment during filter change (Ivan Vecera) [2180870]
- net/sched: cls_api: Initialize miss_cookie_node when action miss is not used (Ivan Vecera) [2180870]
- net/sched: sch_fq: fix integer overflow of "credit" (Ivan Vecera) [2180870]
- net/sched: clear actions pointer in miss cookie init fail (Ivan Vecera) [2180870]
- net/sched: mqprio: simplify handling of nlattr portion of TCA_OPTIONS (Ivan Vecera) [2180870]
- l2tp: generate correct module alias strings (Ivan Vecera) [2180870]
- net/sched: act_api: add specific EXT_WARN_MSG for tc action (Ivan Vecera) [2180870]
- Revert "net/sched: act_api: move TCA_EXT_WARN_MSG to the correct hierarchy" (Ivan Vecera) [2180870]
- netfilter: ctnetlink: revert to dumping mark regardless of event type (Ivan Vecera) [2180870]
- net/sched: flower: fix fl_change() error recovery path (Ivan Vecera) [2180870]
- net/sched: act_api: move TCA_EXT_WARN_MSG to the correct hierarchy (Ivan Vecera) [2180870]
- net/sched: act_connmark: handle errno on tcf_idr_check_alloc (Ivan Vecera) [2180870]
- net/sched: act_sample: fix action bind logic (Ivan Vecera) [2180870]
- net/sched: act_mpls: fix action bind logic (Ivan Vecera) [2180870]
- net/sched: act_pedit: fix action bind logic (Ivan Vecera) [2180870]
- net/sched: cls_api: Move call to tcf_exts_miss_cookie_base_destroy() (Ivan Vecera) [2180870]
- net/sched: flower: Support hardware miss to tc action (Ivan Vecera) [2180870]
- net/sched: flower: Move filter handle initialization earlier (Ivan Vecera) [2180870]
- net/sched: cls_api: Support hardware miss to tc action (Ivan Vecera) [2180870]
- net/sched: Rename user cookie and act cookie (Ivan Vecera) [2180870]
- net/sched: taprio: dynamic max_sdu larger than the max_mtu is unlimited (Ivan Vecera) [2180870]
- net/sched: taprio: don't allow dynamic max_sdu to go negative after stab adjustment (Ivan Vecera) [2180870]
- net/sched: taprio: fix calculation of maximum gate durations (Ivan Vecera) [2180870]
- net/sched: act_pedit: use percpu overlimit counter when available (Ivan Vecera) [2180870]
- net/sched: act_gate: use percpu stats (Ivan Vecera) [2180870]
- net/sched: act_connmark: transition to percpu stats and rcu (Ivan Vecera) [2180870]
- net/sched: act_nat: transition to percpu stats and rcu (Ivan Vecera) [2180870]
- selftests: forwarding: tc_actions: cleanup temporary files when test is aborted (Ivan Vecera) [2180870]
- net/sched: support per action hw stats (Ivan Vecera) [2180870]
- net/sched: introduce flow_offload action cookie (Ivan Vecera) [2180870]
- net/sched: pass flow_stats instead of multiple stats args (Ivan Vecera) [2180870]
- net/sched: act_pedit, setup offload action for action stats query (Ivan Vecera) [2180870]
- net/sched: optimize action stats api calls (Ivan Vecera) [2180870]
- net/sched: act_ctinfo: use percpu stats (Ivan Vecera) [2180870]
- net/sched: fix error recovery in qdisc_create() (Ivan Vecera) [2180870]
- net/sched: taprio: don't segment unnecessarily (Ivan Vecera) [2180870]
- net/sched: taprio: split segmentation logic from qdisc_enqueue() (Ivan Vecera) [2180870]
- net/sched: taprio: automatically calculate queueMaxSDU based on TC gate durations (Ivan Vecera) [2180870]
- net/sched: keep the max_frm_len information inside struct sched_gate_list (Ivan Vecera) [2180870]
- net/sched: taprio: warn about missing size table (Ivan Vecera) [2180870]
- net/sched: make stab available before ops->init() call (Ivan Vecera) [2180870]
- net/sched: taprio: calculate guard band against actual TC gate close time (Ivan Vecera) [2180870]
- net/sched: taprio: calculate budgets per traffic class (Ivan Vecera) [2180870]
- net/sched: taprio: rename close_time to end_time (Ivan Vecera) [2180870]
- net/sched: taprio: calculate tc gate durations (Ivan Vecera) [2180870]
- net/sched: taprio: give higher priority to higher TCs in software dequeue mode (Ivan Vecera) [2180870]
- net/sched: taprio: avoid calling child->ops->dequeue(child) twice (Ivan Vecera) [2180870]
- net/sched: taprio: refactor one skb dequeue from TXQ to separate function (Ivan Vecera) [2180870]
- net/sched: taprio: continue with other TXQs if one dequeue() failed (Ivan Vecera) [2180870]
- net/sched: taprio: delete peek() implementation (Ivan Vecera) [2180870]
- net: sched: sch: Fix off by one in htb_activate_prios() (Ivan Vecera) [2180870]
- net/sched: taprio: only pass gate mask per TXQ for igc, stmmac, tsnep, am65_cpsw (Ivan Vecera) [2180870]
- net/sched: taprio: pass mqprio queue configuration to ndo_setup_tc() (Ivan Vecera) [2180870]
- net/sched: refactor mqprio qopt reconstruction to a library function (Ivan Vecera) [2180870]
- net/sched: taprio: centralize mqprio qopt validation (Ivan Vecera) [2180870]
- net/sched: mqprio: add extack messages for queue count validation (Ivan Vecera) [2180870]
- net/sched: mqprio: allow offloading drivers to request queue count validation (Ivan Vecera) [2180870]
- net/sched: mqprio: allow reverse TC:TXQ mappings (Ivan Vecera) [2180870]
- net/sched: move struct tc_mqprio_qopt_offload from pkt_cls.h to pkt_sched.h (Ivan Vecera) [2180870]
- net/sched: mqprio: refactor offloading and unoffloading to dedicated functions (Ivan Vecera) [2180870]
- net/sched: mqprio: refactor nlattr parsing to a separate function (Ivan Vecera) [2180870]
- netlink: add support for formatted extack messages (Ivan Vecera) [2180870]
- net/sched: simplify tcf_pedit_act (Ivan Vecera) [2180870]
- net/sched: transition act_pedit to rcu and percpu stats (Ivan Vecera) [2180870]
- net: sched: sch: Bounds check priority (Ivan Vecera) [2180870]
- net: Kconfig: fix spellos (Ivan Vecera) [2180870]
- net/sched: sch_taprio: do not schedule in taprio_reset() (Ivan Vecera) [2180870]
- sched: add new attr TCA_EXT_WARN_MSG to report tc extact message (Ivan Vecera) [2180870]
- net/sched: sch_taprio: fix possible use-after-free (Ivan Vecera) [2180870]
- net: sched: htb: fix htb_classify() kernel-doc (Ivan Vecera) [2180870]
- net/sched: fix retpoline wrapper compilation on configs without tc filters (Ivan Vecera) [2180870]
- net: sched: update the nat flag for icmp error packets in ct_nat_execute (Ivan Vecera) [2180870]
- net/sched: avoid indirect classify functions on retpoline kernels (Ivan Vecera) [2180870]
- net/sched: avoid indirect act functions on retpoline kernels (Ivan Vecera) [2180870]
- net/sched: add retpoline wrapper for tc (Ivan Vecera) [2180870]
- net/sched: move struct action_ops definition out of ifdef (Ivan Vecera) [2180870]
- netfilter: ctnetlink: fix compilation warning after data race fixes in ct mark (Ivan Vecera) [2180870]
- net: sched: allow act_ct to be built without NF_NAT (Ivan Vecera) [2180870]
- netfilter: conntrack: Fix data-races around ct mark (Ivan Vecera) [2180870]
- net: flow_offload: add support for ARP frame matching (Ivan Vecera) [2180870]
- selftests: tc-testing: Add matchJSON to tdc (Ivan Vecera) [2180870]
- Documentation: networking: TC queue based filtering (Ivan Vecera) [2180870]
- act_skbedit: skbedit queue mapping for receive queue (Ivan Vecera) [2180870]
- net: sched: cake: fix null pointer access issue when cake_init() fails (Ivan Vecera) [2180870]
- net: sched: use tc_cls_bind_class() in filter (Ivan Vecera) [2180870]
- net: sched: cls_api: introduce tc_cls_bind_class() helper (Ivan Vecera) [2180870]
- net: sched: ensure n arg not empty before call bind_class (Ivan Vecera) [2180870]
- selftests/tc-testing: update qdisc/cls/action features in config (Ivan Vecera) [2180870]
- net/sched: taprio: allow user input of per-tc max SDU (Ivan Vecera) [2180870]
- net/sched: query offload capabilities through ndo_setup_tc() (Ivan Vecera) [2180870]
- net: sched: act_bpf: simplify code logic in tcf_bpf_init() (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for teql qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for tbf qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for taprio qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for skbprio qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for sfq qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for sfb qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for plug qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for pfifo_fast qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for hhf qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for gred qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for fq qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for etf qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for codel qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for choke qdisc (Ivan Vecera) [2180870]
- selftests/tc-testing: add selftests for atm qdisc (Ivan Vecera) [2180870]
- headers: Remove some left-over license text (Ivan Vecera) [2180870]
- net/sched: taprio: simplify list iteration in taprio_dev_notifier() (Ivan Vecera) [2180870]
- net/sched: taprio: remove unnecessary taprio_list_lock (Ivan Vecera) [2180870]
- net: sched: remove unused tcf_result extension (Ivan Vecera) [2180870]
- net: sched: simplify code in mall_reoffload (Ivan Vecera) [2180870]
- net: sched: act_ct: remove redundant variable err (Ivan Vecera) [2180870]
- selftests/tc-testings: add list case for basic filter (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for tcindex filter (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for rsvp filter (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for route filter (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for flow filter (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for cgroup filter (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for bpf filter (Ivan Vecera) [2180870]
- net/sched: use tc_cls_stats_dump() in filter (Ivan Vecera) [2180870]
- net/sched: cls_api: add helper for tc cls walker stats dump (Ivan Vecera) [2180870]
- net/sched: taprio: replace safety precautions with comments (Ivan Vecera) [2180870]
- net/sched: taprio: add extack messages in taprio_init (Ivan Vecera) [2180870]
- net/sched: taprio: stop going through private ops for dequeue and peek (Ivan Vecera) [2180870]
- net/sched: taprio: remove redundant FULL_OFFLOAD_IS_ENABLED check in taprio_enqueue (Ivan Vecera) [2180870]
- net/sched: taprio: use rtnl_dereference for oper and admin sched in taprio_destroy() (Ivan Vecera) [2180870]
- net/sched: taprio: taprio_dump and taprio_change are protected by rtnl_mutex (Ivan Vecera) [2180870]
- net/sched: taprio: taprio_offload_config_changed() is protected by rtnl_mutex (Ivan Vecera) [2180870]
- net/sched: taprio: avoid disabling offload when it was never enabled (Ivan Vecera) [2180870]
- flow_offload: Introduce flow_match_l2tpv3 (Ivan Vecera) [2180870]
- net/sched: flower: Add L2TPv3 filter (Ivan Vecera) [2180870]
- flow_dissector: Add L2TPv3 dissectors (Ivan Vecera) [2180870]
- skbuff: make __skb_header_pointer()'s data argument const (Ivan Vecera) [2180870]
- tools headers uapi: Update linux/in.h copy (Ivan Vecera) [2180870]
- uapi: move IPPROTO_L2TP to in.h (Ivan Vecera) [2180870]
- selftests/tc-testings: add tunnel_key action deleting test case (Ivan Vecera) [2180870]
- selftests/tc-testings: add sample action deleting test case (Ivan Vecera) [2180870]
- selftests/tc-testings: add nat action deleting test case (Ivan Vecera) [2180870]
- selftests/tc-testings: add ife action deleting test case (Ivan Vecera) [2180870]
- selftests/tc-testings: add connmark action deleting test case (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for xt action (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for gate action (Ivan Vecera) [2180870]
- selftests/tc-testings: add selftests for ctinfo action (Ivan Vecera) [2180870]
- net: sched: act_vlan: get rid of tcf_vlan_walker and tcf_vlan_search (Ivan Vecera) [2180870]
- net: sched: act_tunnel_key: get rid of tunnel_key_walker and tunnel_key_search (Ivan Vecera) [2180870]
- net: sched: act_skbmod: get rid of tcf_skbmod_walker and tcf_skbmod_search (Ivan Vecera) [2180870]
- net: sched: act_skbedit: get rid of tcf_skbedit_walker and tcf_skbedit_search (Ivan Vecera) [2180870]
- net: sched: act_simple: get rid of tcf_simp_walker and tcf_simp_search (Ivan Vecera) [2180870]
- net: sched: act_sample: get rid of tcf_sample_walker and tcf_sample_search (Ivan Vecera) [2180870]
- net: sched: act_police: get rid of tcf_police_walker and tcf_police_search (Ivan Vecera) [2180870]
- net: sched: act_pedit: get rid of tcf_pedit_walker and tcf_pedit_search (Ivan Vecera) [2180870]
- net: sched: act_nat: get rid of tcf_nat_walker and tcf_nat_search (Ivan Vecera) [2180870]
- net: sched: act_mpls: get rid of tcf_mpls_walker and tcf_mpls_search (Ivan Vecera) [2180870]
- net: sched: act_mirred: get rid of tcf_mirred_walker and tcf_mirred_search (Ivan Vecera) [2180870]
- net: sched: act_ipt: get rid of tcf_ipt_walker/tcf_xt_walker and tcf_ipt_search/tcf_xt_search (Ivan Vecera) [2180870]
- net: sched: act_ife: get rid of tcf_ife_walker and tcf_ife_search (Ivan Vecera) [2180870]
- net: sched: act_gate: get rid of tcf_gate_walker and tcf_gate_search (Ivan Vecera) [2180870]
- net: sched: act_gact: get rid of tcf_gact_walker and tcf_gact_search (Ivan Vecera) [2180870]
- net: sched: act_ctinfo: get rid of tcf_ctinfo_walker and tcf_ctinfo_search (Ivan Vecera) [2180870]
- net: sched: act_ct: get rid of tcf_ct_walker and tcf_ct_search (Ivan Vecera) [2180870]
- net: sched: act_csum: get rid of tcf_csum_walker and tcf_csum_search (Ivan Vecera) [2180870]
- net: sched: act_connmark: get rid of tcf_connmark_walker and tcf_connmark_search (Ivan Vecera) [2180870]
- net: sched: act_bpf: get rid of tcf_bpf_walker and tcf_bpf_search (Ivan Vecera) [2180870]
- net: sched: act_api: implement generic walker and search for tc action (Ivan Vecera) [2180870]
- net: sched: act: move global static variable net_id to tc_action_ops (Ivan Vecera) [2180870]
- net: sched: htb: remove redundant resource cleanup in htb_init() (Ivan Vecera) [2180870]
- net/sched: cls_api: remove redundant 0 check in tcf_qevent_init() (Ivan Vecera) [2180870]
- net: sched: etf: remove true check in etf_enable_offload() (Ivan Vecera) [2180870]
- net: sched: gred: remove NULL check before free table->tab in gred_destroy() (Ivan Vecera) [2180870]
- net: sched: remove redundant NULL check in change hook function (Ivan Vecera) [2180870]
- net: sched: gred/red: remove unused variables in struct red_stats (Ivan Vecera) [2180870]
- net: sched: choke: remove unused variables in struct choke_sched_data (Ivan Vecera) [2180870]
- net: sched: using TCQ_MIN_PRIO_BANDS in prio_tune() (Ivan Vecera) [2180870]
- net_sched: remove impossible conditions (Ivan Vecera) [2180870]
- net: sched: remove unnecessary init of qdisc skb head (Ivan Vecera) [2180870]
- net: sched: delete duplicate cleanup of backlog and qlen (Ivan Vecera) [2180870]
- net: sched: remove duplicate check of user rights in qdisc (Ivan Vecera) [2180870]
- net_sched: move from strlcpy with unused retval to strscpy (Ivan Vecera) [2180870]
- net: sched: delete unused input parameter in qdisc_create (Ivan Vecera) [2180870]
- net: sched: remove the unused return value of unregister_qdisc (Ivan Vecera) [2180870]
- net_sched: cls_route: disallow handle of 0 (Ivan Vecera) [2180870]
- net/sched: sch_cbq: change the type of cbq_set_lss to void (Ivan Vecera) [2180870]
- net/sched: remove qdisc_root_lock() helper (Ivan Vecera) [2180870]
- net/sched: sch_cbq: Delete unused delay_timer (Ivan Vecera) [2180870]
- net/sched: remove return value of unregister_tcf_proto_ops (Ivan Vecera) [2180870]
- net: extract port range fields from fl_flow_key (Ivan Vecera) [2180870]
- net/sched: act_ct: set 'net' pointer when creating new nf_flow_table (Ivan Vecera) [2180870]
- net: sched: provide shim definitions for taprio_offload_{get,free} (Ivan Vecera) [2180870]
- time64.h: consolidate uses of PSEC_PER_NSEC (Ivan Vecera) [2180870]
- selftests: tc-testing: Add testcases to test new flush behaviour (Ivan Vecera) [2180870]
- tc-testing: gitignore, delete plugins directory (Ivan Vecera) [2180870]
- net/sched: sch_netem: Fix arithmetic in netem_dump() for 32-bit platforms (Ivan Vecera) [2180870]
- net_sched: em_meta: add READ_ONCE() in var_sk_bound_if() (Ivan Vecera) [2180870]
- selftests: forwarding: tc_actions: allow mirred egress test to run on non-offloaded h2 (Ivan Vecera) [2180870]
- net: sched: support hash selecting tx queue (Ivan Vecera) [2180870]
- net: sched: use queue_mapping to pick tx queue (Ivan Vecera) [2180870]
- net_sched: make qdisc_reset() smaller (Ivan Vecera) [2180870]
- sch_red: Fix a typo (Ivan Vecera) [2180870]
- wifi: ath9k: Don't mark channelmap stack variable read-only in ath9k_mci_update_wlan_channels() (Jose Ignacio Tornos Martinez) [2183487]
- net: qrtr: Fix an uninit variable access bug in qrtr_tx_resume() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: ignore key disable commands (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: reduce the MHI timeout to 20s (Jose Ignacio Tornos Martinez) [2183487]
- net: qrtr: Do not do DEL_SERVER broadcast after DEL_CLIENT (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: fix fw used for offload check for mt7922 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: Fix use-after-free in fw features query. (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix SDIO suspend/resume regression (Jose Ignacio Tornos Martinez) [2183487]
- net: qrtr: Fix a refcount bug in qrtr_recvmsg() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix invalid drv_sta_pre_rcu_remove calls for non-uploaded sta (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix flow dissection for forwarded packets (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix mesh forwarding (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix receiving mesh packets in forwarding=0 networks (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix the size calculation of ieee80211_ie_len_eht_cap() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix potential null pointer dereference (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: drop bogus static keywords in A-MSDU rx (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix mesh path discovery based on unicast packets (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix qos on mesh interfaces (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Serialize ieee80211_handle_wake_tx_queue() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: mark OF related data as maybe unused (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: do not check WED status for non-mmio devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add back 160MHz channel width support for MT7915 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: do not run mt76_unregister_device() on unregistered hw (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Partial revert "wifi: cfg80211: Fix use after free for wext" (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: fix MLO connection ownership (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: check basic rates validity (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: fix puncturing bitmap policy (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: fix NULL-ptr deref in offchan check (Jose Ignacio Tornos Martinez) [2183487]
- wifi: wext: warn about usage only once (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: allow system suspend to survive ath11k (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: add LEDS_CLASS dependency (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: remove unused iwl_dbgfs_is_match() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix AP mode authentication transmission failed (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: use RTW_FLAG_POWERON flag to prevent to power on/off twice (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: p2p: Introduce generic flexible array frame member (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add documentation for amsdu_mesh_control (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: remove gfp parameter from cfg80211_obss_color_collision_notify description (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: always initialize link_sta with sta (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: pass 'sta' to ieee80211_rx_data_set_sta() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Set SSID if it is not already set (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: move H2C of del_pkt_offload before polling FW status ready (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: use readable return 0 in rtw89_mac_cfg_ppdu_status() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: usb: drop now unnecessary URB size check (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: usb: send Zero length packets if necessary (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: usb: Set qsel correctly (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix off-by-one link setting (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Fix for Rx fragmented action frames (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: avoid u32_encode_bits() warning (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Don't translate MLD addresses for multicast (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: call reg_notifier for self managed wiphy from driver hint (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: get rid of gfp in cfg80211_bss_color_notify (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: Allow authentication frames and set keys on NAN interface (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix non-MLO station association (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Allow NSS change only up to capability (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add a workaround for receiving non-standard mesh A-MSDU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix receiving A-MSDU frames on mesh interfaces (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: remove mesh forwarding congestion check (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: factor out bridge tunnel / RFC1042 header check (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: move A-MSDU check in ieee80211_data_to_8023_exthdr (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: make rate u32 in sta_set_rate_info_rx() (Jose Ignacio Tornos Martinez) [2183487]
- rfkill: Use sysfs_emit() to instead of sprintf() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Allow action frames to be transmitted with link BSS in MLD (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: configure puncturing bitmap (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: include puncturing bitmap in channel switch events (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: validate and configure puncturing bitmap (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: move puncturing bitmap validation from mac80211 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: return error message for malformed chandef (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211_hwsim: Rename pid to portid to avoid confusion (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: add MLO_LINK_ID to CMD_STOP_AP event (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: emit CMD_START_AP on multicast group when an AP is started (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: mlme: handle EHT channel puncturing (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Extend cfg80211_update_owe_info_event() for MLD AP (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Extend cfg80211_new_sta() for MLD AP (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: move color collision detection report in a delayed work (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Fix use after free for wext (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Authentication offload to user space for MLO connection in STA mode (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: trace: remove MAC_PR_{FMT,ARG} (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: fix txdw7 assignment of TX DESC v3 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Add LED control code for RTL8723AU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Add LED control code for RTL8192EU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Add LED control code for RTL8188EU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Register the LED and make it blink (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: phy: set TX power according to RF path number by chip (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: correct register mask name of TX power offset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: use passed channel in set_tx_shape_dfir() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852be: enable CLKREQ of PCI capability (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: try to use NORMAL_CE type firmware first (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: don't support LPS-PG mode after firmware 0.29.26.0 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: reset IDMEM mode to default value (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add use of pkt_list offload to debug entry (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: refine packet offload flow (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix potential wrong mapping for pkt-offload (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: disallow enter PS mode after create TDLS link (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: refine MCC C2H debug logs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix parsing offset for MCC C2H (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: deal with RXI300 error (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: debug: avoid invalid access on RTW89_DBG_SEL_MAC_30 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: mac: add function to get TSF (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: split out generic part of rtw89_mac_port_tsf_sync() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: correct unit for port offset and refine macro (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Update Wi-Fi Bluetooth coexistence version to 7.0.0 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Fix test fail when coexist with raspberryPI A2DP idle (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Correct A2DP exist variable source (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Set Bluetooth background scan PTA request priority (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Refine coexistence log (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Force to update TDMA parameter when radio state change (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Clear Bluetooth HW PTA counter when radio state change (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Update Wi-Fi external control TDMA parameters/tables (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: change cfg80211_set_channel() name and signature (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: fix loop iterator in mwifiex_update_ampdu_txwinsize() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: Replace one-element array with flexible-array member (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: Replace one-element arrays with flexible-array members (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Replace one-element array with flexible-array member (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: Support firmware hotfix version in GET_HW_SPEC responses (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: Support SD8978 chipset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mwifiex: Add missing compatible string for SD8787 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: pcie: Perform correct BCM4364 firmware selection (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4377 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4355 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Rename Cypress 89459 to BCM4355 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: mac: Use existing macros in rtw_pwr_seq_parser() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Move enum rtw_tx_queue_type mapping code to tx.{c,h} (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: pci: Change queue datatype to enum rtw_tx_queue_type (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: pci: Use enum type for rtw_hw_queue_mapping() and ac_to_hwq (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: support ww power config in dts node (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt76x0u: report firmware version through ethtool (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: complete wed reset support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add mt7915 wed reset callbacks (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: reset wed queues in mt76_dma_rx_reset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: add reset to mt76_dma_wed_setup signature (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add EHT beamforming support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: enable EHT support in firmware (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add support for EHT rate report (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add EHT capability init (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: rework capability init (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add helpers for wtbl and interface limit (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add variants support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add EHT rate stats for ethtool (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: increase wcid size to 1088 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add cmd id related to EHT support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add helpers for EHT capability (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add CMD_CBW_320MHZ (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add EHT phy type (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: remove __mt76_mcu_restart macro (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: rely on mt76_connac_tx_complete_skb (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: rely on mt76_connac_txp_skb_unmap (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: rely on mt76_connac_txp_common structure (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: rely on mt76_connac2_mac_tx_rate_val (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: fix error code of return in mt7921_acpi_read (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: release rxwi in mt7915_wed_release_rx_buf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix memory leak in mt7915_mmio_wed_init_rx_buf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: fix rx filter incorrect by drv/fw inconsistent (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add memory barrier to SDIO queue kick (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: reduce polling time in pmctrl (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add flexible polling wait-interval support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix WED TxS reporting (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: wed: enable red per-band token drop (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: set sku initial value to zero (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921u: add support for Comfast CF-952AX (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: fix switch default case in mt7996_reverse_frag0_hdr_trans (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7615: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7603: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: fix memory leak running mt76_dma_tx_cleanup (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: free rx_head in mt76_dma_rx_cleanup (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix memory leak in mt7996_mcu_exit (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix memory leak in mt7915_mcu_exit (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: introduce mt76_queue_is_wed_rx utility routine (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: fix invalid remain_on_channel duration (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: remove BW160 and BW80+80 support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: fix POWER_CTRL command name typo (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: do not hardcode vht beamform cap (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: update register for CFEND_RATE (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix chainmask calculation in mt7996_set_antenna() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: add ack signal support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: fix channel switch fail in monitor mode (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add chip id condition in mt7915_check_eeprom() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add error message in mt7915_thermal_set_cur_throttle_state() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: rework mt7915_thermal_temp_store() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: rework mt7915_mcu_set_thermal_throttling (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: call mt7915_mcu_set_thermal_throttling() only after init_work (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: fix deadlock in mt7921_abort_roc (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Fix off by one in mhi_ep_process_cmd_ring() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: fix compilation errors in rfkill() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: bump FW API to 74 for AX devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: Reset rate index if rate is wrong (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: simplify by using SKB MAC header pointer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: add sniffer meta data APIs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: rx: add sniffer support for EHT mode (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: always send nullfunc frames on MGMT queue (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: remove h from printk format specifier (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: improve tag handling in iwl_request_firmware (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mention the response structure in the kerneldoc (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: add minimal EHT rate reporting (Jose Ignacio Tornos Martinez) [2183487]
- net: qrtr: free memory on error path in radix_tree_insert() (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Change state_lock to mutex (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Save channel state locally during suspend and resume (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Move chan->lock to the start of processing queued ch ring (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Fix the debug message for MHI_PKT_TYPE_RESET_CHAN_CMD cmd (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Only send -ENOTCONN status if client driver is available (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Check if the channel is supported by the controller (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: ep: Power up/down MHI stack during MHI RESET (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: Update mhi driver description (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: Update Makefile to used Kconfig flags (Jose Ignacio Tornos Martinez) [2183487]
- wifi: wireless: deny wireless extensions on MLO-capable devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: wireless: warn on most wireless extension usage (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: drop extra 'e' from ieeee80211... name (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Deduplicate certificate loading (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add kernel-doc for EHT structure (Jose Ignacio Tornos Martinez) [2183487]
- mac80211: support minimal EHT rate reporting on RX (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Add HE MU-MIMO related flags in ieee80211_bss_conf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Add VHT MU-MIMO related flags in ieee80211_bss_conf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Use MLD address to indicate MLD STA disconnection (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Support 32 bytes KCK key in GTK rekey offload (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Fix extended KCK key length check in nl80211_set_rekey_data() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: remove support for static WEP (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: Add support to read EEPROM caldata (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: Add new qmi_bdf_type to handle caldata (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: Fix incorrect qmi_file_type enum values (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: dp_mon: Fix uninitialized warning related to the pktlog (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: dp_mon: Fix out of bounds clang warning (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: hal_rx: Use memset_startat() for clearing queue descriptors (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: Fix uninitilized variable clang warnings (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: wmi: delete PSOC_HOST_MAX_NUM_SS (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: hal: convert offset macros to functions (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: hal: add ab parameter to macros using it (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Fix memory leak in ath11k_peer_rx_frag_setup (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: fix ce memory mapping for ahb devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Remove the unused function ath10k_ce_shadow_src_ring_write_index_set() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: add channel 177 into 5 GHz channel list (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Add support to configure FTM responder role (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: Fix potential stack-out-of-bounds write in ath9k_wmi_rsp_callback() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: hif_usb: clean up skbs if ath9k_hif_usb_rx_stream() fails (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: htc_hst: free skb in ath9k_htc_rx_msg() if there is no callback function (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Dump the efuse only for untested devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Print the ROM version too (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Use non-atomic sta iterator in rtw_ra_mask_info_update() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Use rtw_iterate_vifs() for rtw_vif_watch_dog_iter() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Move register access from rtw_bf_assoc() outside the RCU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Use a longer retry limit of 48 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Report the RSSI to the firmware (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rt2x00: Remove useless else if (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt7601u: fix an integer underflow (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: rtl8723ae: fix obvious spelling error tyep->type (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix memory leaks with RTL8723BU, RTL8192EU (Jose Ignacio Tornos Martinez) [2183487]
- Revert "wifi: mac80211: fix memory leak in ieee80211_if_add()" (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: fix a regression in adding rx buffers (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: fill the missing configuration about queue empty checking (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix assignation of TX BD RAM table (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: rfk: correct ADC clock settings (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: correct register definitions of digital CFO and spur elimination (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: set the correct mac_id for management frames (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix null vif pointer when get management frame date rate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Change Wi-Fi role info related logic to version separate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Change RTL8852B use v1 TDMA policy (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Packet traffic arbitration hardware owner monitor (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: refactor debug log of slot list (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Change firmware steps report to version separate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Change Wi-Fi Null data report to version separate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Add version code for Wi-Fi firmware coexistence control (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Update WiFi role info H2C report (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: only read Bluetooth counter of report version 1 for RTL8852A (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Add v5 firmware control report (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Change firmware control report to version separate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Add v4 version firmware cycle report (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Rename BTC firmware cycle report by feature version (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Remove le32 to CPU translator at firmware cycle report (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: Fix a typo in debug message (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: ensure CLM version is null-terminated to prevent stack-out-of-bounds (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rndis_wlan: Prevent buffer overflow in rndis_query_oid (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: fix regression for Broadcom PCIe wifi devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: avoid NULL-deref in survey dump for 2G only device (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: avoid handling disabled channels for survey dump (Jose Ignacio Tornos Martinez) [2183487]
- net: rfkill: gpio: add DT support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix double space in comment (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: debugfs: fix to work with multiple PCI devices (Jose Ignacio Tornos Martinez) [2183487]
- mac80211: Fix MLO address translation for multiple bss case (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: reset multiple BSSID options in stop_ap() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Fix iTXQ AMPDU fragmentation handling (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: sdata can be NULL during AMPDU start (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Proper mark iTXQs for resumption (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: Prefer DT board type over DMI board type (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: remove most hidden macro dependencies on ah (Jose Ignacio Tornos Martinez) [2183487]
- wifi: wl3501_cs: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: unmap dma buffer in brcmf_msgbuf_alloc_pktid() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: fix potential memory leak in brcmf_netdev_start_xmit() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix potential stack-out-of-bounds in brcmf_c_preinit_dcmds() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: fixing transmisison failure for rtl8192eu (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Add rate control code for RTL8188EU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Support new chip RTL8188EU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Define masks for cck_agc_rpt bits (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Make rtl8xxxu_load_firmware take const char* (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Deduplicate the efuse dumping code (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: rfk: refine AGC tuning flow of DPK for irregular PA (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: refine 6 GHz scanning dwell time (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: update BSS color mapping register (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Change TDMA related logic to version separate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: refactor _chk_btc_report() to extend more features (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Add v2 BT AFH report and related variable (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Update BTC firmware report bitmap definition (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: Enable Bluetooth report when show debug info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: use new introduction BTC version format (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: add BTC format version derived from firmware version (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: select CONFIG_RELAY (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: Fix global-out-of-bounds bug in _rtl8812ae_phy_set_txpower_limit() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: rfk: recover RX DCK failure (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: rfk: correct DPK settings (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: rfk: correct DACK setting (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fw: adapt to new firmware format of security section (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: consider ER SU as a TX capability (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: don't call dev_kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix assignment to bit field priv->cck_agc_report_type (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix assignment to bit field priv->pi_enabled (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: rtl8723be: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: rtl8188ee: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: rtl8821ae: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: get rid of wed rx_buf_ring page_frag_cache (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: resource leaks at mt7921_check_offload_capability() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: rely on queue page_frag_cache for wed rx queues (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: handle possible mt76_rx_token_consume failures (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: dma: do not increment queue head if mt76_dma_add_buf fails (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7615: enable per-phy led support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable per-phy led support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: move leds struct in mt76_phy (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: move leds field in leds struct (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix unintended sign extension of mt7915_hw_queue_read() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix unintended sign extension of mt7996_hw_queue_read() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: add support to update fw capability with MTFG table (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt76x0: fix oob access in mt76x0_phy_get_target_power (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix endianness warning in mt7996_mcu_sta_he_tlv (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: drop always true condition of __mt7996_reg_addr() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: drop always true condition of __mt7915_reg_addr() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: check the correctness of event data (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: check return value before accessing free_block_num (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: check return value before accessing free_block_num (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: split mcu chan_mib array up (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix integer handling issue of mt7996_rf_regval_set() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix insecure data handling of mt7996_mcu_rx_radar_detected() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: fix insecure data handling of mt7996_mcu_ie_countdown() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix mt7915_rate_txpower_get() resource leaks (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921s: fix slab-out-of-bounds access in sdio host (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add missing of_node_put() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: fix monitor mode bringup crash (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Fix scan request param frame size warning (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: Fix use-after-free in ath9k_hif_usb_disconnect() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: fixing IQK failures for rtl8192eu (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: btcoexist: fix conditions branches that are never executed (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: rtl8192se: remove redundant rtl_get_bbreg() call (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Add rtw8723du chipset support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Add rtw8822cu chipset support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Add rtw8822bu chipset support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Add rtw8821cu chipset support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Add common USB chip support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: iterate over vif/sta list non-atomically (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Drop coex mutex (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Drop h2c.lock (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Drop rf_lock (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: Call rtw_fw_beacon_filter_config() with rtwdev->mutex held (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: print firmware type in info message (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add join info upon create interface (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix unsuccessful interface_add flow (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: stop mac port function when stop_ap() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add mac TSF sync function (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix error return code in brcmf_sdio_download_firmware() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Introduce rtl8xxxu_update_ra_report (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix the channel width reporting (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Add __packed to struct rtl8723bu_c2h (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: add vendor name in revinfo debugfs file (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: add support Broadcom BCA firmware api (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: add support for Cypress firmware api (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: add support for vendor-specific firmware api (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: add firmware vendor info in driver info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: add function to unbind device to bus layer api (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: add ipq5018 device support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: add new hw ops for IPQ5018 to get rx dest ring hashmap (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: initialize hw_ops for IPQ5018 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: update hal srng regs for IPQ5018 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: remap ce register space for IPQ5018 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: update ce configurations for IPQ5018 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: update hw params for IPQ5018 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: fw: use correct IML/ROM status register (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: dump: Update check for UMAC valid FW address (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: d3: add TKIP to the GTK iterator (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: clean up comments (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: Don't use deprecated register (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: pcie: Add reading and storing of crf and cdb id. (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: replace usage of found with dedicated list iterator variable (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: dump: Update check for valid FW address (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: don't access packet before checking len (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: modify new queue allocation command (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: nvm-parse: enable WiFi7 for Fm radio for now (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: add reset to rx_ring_setup callback (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Fix race condition with struct htt_ppdu_stats_info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: fix QCOM_SMEM dependency (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921e: add pci .shutdown() support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: mmio: fix naming convention (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add support to configure spatial reuse parameter set (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: enable ack signal support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: enable use_cts_prot support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: rely on band_idx of mt76_phy (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable per bandwidth power limit support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: introduce mt7915_get_power_bound() (Jose Ignacio Tornos Martinez) [2183487]
- mt76: mt7915: Fix PCI device refcount leak in mt7915_pci_init_hif2() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: fix coverity overrun-call in mt76_get_txpower() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7996: add driver for MediaTek Wi-Fi 7 (802.11be) devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt76x0: remove dead code in mt76x0_phy_get_target_power (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix band_idx usage (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable .sta_set_txpwr support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add basedband Txpower info into debugfs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add support to configure spatial reuse parameter set (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add missing MODULE_PARM_DESC (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable WED RX stats (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable WED RX support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: introduce mt76_connac_mcu_sta_wed_update utility routine (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add info parameter to rx_skb signature (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add WED RX support to dma queue alloc (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add WED RX support to mt76_dma_rx_fill (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: add WED RX support to mt76_dma_{add,get}_buf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: introduce rxwi and rx token utility routines (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: introduce helper for mt7996 chipset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add more starec command tags (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add more bss info command tags (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: introduce unified event table (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add more unified command IDs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: rework fields for larger bandwidth support in sta_rec_bf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: update struct sta_rec_phy (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: rework macros for unified command (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: introduce chanctx support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: introduce remain_on_channel support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: accept hw scan request at a time (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: drop ieee80211_[start, stop]_queues in driver (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: add unified ROC cmd/event support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7921: add chanctx parameter to mt76_connac_mcu_uni_add_bss signature (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: add mt76_connac_mcu_uni_set_chctx (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: do not run mt76u_status_worker if the device is not running (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: update nss calculation in txs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: don't claim 160MHz support with mt7915 DBDC (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: Fix VHT beamforming capabilities with DBDC (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: Fix chainmask calculation on mt7915 DBDC (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable coredump support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add full system reset into debugfs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable full system reset support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: rework mt7915_dma_reset() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: move aggr_stats array in mt76_phy (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7615: rely on mt7615_phy in mt7615_mac_reset_counters (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix reporting of TX AGGR histogram (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7615: enable use_cts_prot support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable use_cts_prot support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: fix bandwidth 80MHz link fail in 6GHz band (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add ack signal support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: improve accuracy of time_busy calculation (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable wed for mt7986-wmac chipset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: enable wed for mt7986 chipset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: move wed init routines in mmio.c (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix mt7915_mac_set_timing() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: set correct antenna for radar detection on MT7915D (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: add spatial extension index support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: connac: introduce mt76_connac_spe_idx() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: rework testmode tx antenna setting (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: deal with special variant of mt7916 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: rework eeprom tx paths and streams init (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: reserve 8 bits for the index of rf registers (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt7915: fix bounds checking for tx-free-done command (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: Remove unused inline function mt76_wcid_mask_test() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: mt76x02: simplify struct mt76x02_rate_power (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mt76: move mt76_rate_power from core to mt76x02 driver code (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix and simplify unencrypted drop check for mesh (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add support for restricting netdev features per vif (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: update TIM for S1G specification changes (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: don't parse multi-BSSID in assoc resp (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: use bss_from_pub() instead of container_of() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: remove unnecessary synchronize_net() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Drop not needed check for NULL (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Fix not unregister reg_pdev when load_builtin_regdb_keys() fails (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: fix comparison of BSS frequencies (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Correct example of ieee80211_iface_limit (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix memory leak in ieee80211_if_add() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ieee80211: Do not open-code qos address offsets (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: link rtw89_vif and chanctx stuffs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fw: implement MCC related H2C (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: mac: process MCC related C2H (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: introduce helpers to wait/complete on condition (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: check if atomic before queuing c2h (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: rfk: rename rtw89_mcc_info to rtw89_rfk_mcc_info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: 8821c: enable BT device recovery mechanism (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: turn off PoP function in monitor mode (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add HE radiotap for monitor mode (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: enable mac80211 virtual monitor interface (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Check the count value of channel spec to prevent out-of-bounds reads (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath12k: driver for Qualcomm Wi-Fi 7 devices (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: add reset to tx_ring_setup callback (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: add mtk_wed_rx_reset routine (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: update mtk_wed_stop (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: move MTK_WDMA_RESET_IDX_TX configuration in mtk_wdma_tx_reset (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: return status value in mtk_wdma_rx_reset (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: add wcid overwritten support for wed v1 (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: add configure wed wo support (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: rename tx_wdma array in rx_wdma (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: introduce wed wo support (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_wed: introduce wed mcu support (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_wed: add missing of_node_put() (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_wed: add missing put_device() in mtk_wed_add_hw() (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_wed: add axi bus support (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_wed: add wed support for mt7986 chipset (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_wed: add mtk_wed_configure_irq and mtk_wed_dma_{enable/disable} (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_soc: fix off by one check of ARRAY_SIZE (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_soc: add check for allocation failure (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_soc/wed: fix sparse endian warnings (Jose Ignacio Tornos Martinez) [2183487]
- net: ethernet: mtk_eth_soc: fix return value check in mtk_wed_add_hw() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: fix parameter passing to iwl_mei_alive_notif() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: return error value in case PLDR sync failed (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: trigger PCI re-enumeration in case of PLDR sync (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: fix double free on tx path. (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: print OTP info after alive (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: nvm: Update EHT capabilities for GL device (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: nvm-parse: support A-MPDU in EHT 2.4 GHz (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: advertise 320 MHz in 6 GHz only conditionally (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: set HE PHY bandwidth according to band (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: support PPE Thresholds for EHT (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: add support for EHT 1K aggregation size (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: rs: add support for parsing max MCS per NSS/BW in 11be (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: support 320 MHz PHY configuration (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: Advertise EHT capabilities (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw88: fix race condition when doing H2C command (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Store WLAN firmware version in SMEM image table (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: avoid inaccessible IO operations during doing change_interface() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: switch BANDEDGE and TX_SHAPE based on OFDMA trigger frame (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: read CFO from FD or preamble CFO field of phy status ie_type 1 accordingly (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: correct TX power controlled by BT-coexistence (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Use struct_size() in code ralated to struct brcmf_dload_data_le (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: replace one-element array with flexible-array member in struct brcmf_dload_data_le (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Use struct_size() and array_size() in code ralated to struct brcmf_gscan_config (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Replace one-element array with flexible-array member (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Remove redundant argument offset (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Fix return value in ath10k_pci_init() (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: pci_generic: Add definition for some VIDs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: Fix some error handling path in rtw89_wow_enable() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: Avoid clashing function prototypes (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Use u32_get_bits in *_identify_chip (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Use strscpy instead of sprintf (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Name some bits used in burst init (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Rename rtl8xxxu_8188f_channel_to_group (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Split up rtl8xxxu_identify_chip (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Move burst init to a function (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: wait for the mac to stop on suspend (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: iwlmei: report disconnection as temporary (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: use wait_event_timeout() return value (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: implement PLDR flow (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: Fix getting the lowest rate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: support new key API (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: dbg: use bit of DRAM alloc ID to store failed allocs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: print an error instead of a warning on invalid rate (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: cfg: disable STBC for BL step A devices (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: dbg: add support for DBGC4 on BZ family and above (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: use old checksum for Bz A-step (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: fix potential NULL-ptr deref after clone (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: avoid blocking sap messages handling due to rtnl lock (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: fix tx DHCP packet for devices with new Tx API (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: don't send SAP commands if AMT is disabled (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mei: make sure ownership confirmed message is sent (Jose Ignacio Tornos Martinez) [2183487]
- wifi: iwlwifi: mvm: send TKIP connection status to csme (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Use IEEE80211_SEQ_TO_SN() for seq_ctrl conversion (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: Remove unused variable mismatch (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: change debug mask of message of no TX resource (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Trigger sta disconnect on hardware restart (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: update D-MAC and C-MAC dump to diagnose SER (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: dump dispatch status via debug port (Jose Ignacio Tornos Martinez) [2183487]
- wifi: Use kstrtobool() instead of strtobool() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Avoiding Connection delay (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix for when connect request is not success (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: correctly remove all p2p vif (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: pci_generic: Add HP variant of T99W175 (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: pci_generic: add support for sc8280xp-crd SDX55 variant (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Use dev_* instead of pr_info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Set IEEE80211_HW_SUPPORT_FAST_XMIT (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Recognise all possible chip cuts (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix the CCK RSSI calculation (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Add central frequency offset tracking (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix potential NULL pointer dereference in 'brcmf_c_preinit_dcmds()' (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix a typo "unknow" (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtlwifi: rtl8192ee: remove static variable stop_report_cnt (Jose Ignacio Tornos Martinez) [2183487]
- bcma: Use the proper gpio include (Jose Ignacio Tornos Martinez) [2183487]
- mtd: rawnand: brcmnand: Add platform data structure for BCMA (Jose Ignacio Tornos Martinez) [2183487]
- wifi: brcmfmac: Fix potential shift-out-of-bounds in brcmf_fw_alloc_request() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Make QMI message rules const (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Make QMI message rules const (Jose Ignacio Tornos Martinez) [2183487]
- soc: qcom: qmi: use const for struct qmi_elem_info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: synchronize ath11k_mac_he_gi_to_nl80211_he_gi()'s return type (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Fix qmi_msg_handler data structure initialization (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: remove variable sent (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: Fix spelling mistake KIP_RESOTRE -> KIP_RESTORE (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add WoWLAN pattern match support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add WoWLAN function support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add related H2C for WoWLAN mode (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add drop tx packet function (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add function to adjust and restore PLE quota (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: move enable_cpu/disable_cpu into fw_download (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: collect and send RF parameters to firmware for WoWLAN (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: check if sta's mac_id is valid under AP/TDLS (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add BW info for both TX and RX in phy_info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: make table of RU mask constant (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: declare support bands with const (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fw: adapt to new firmware format of dynamic header (Jose Ignacio Tornos Martinez) [2183487]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (net). (Jose Ignacio Tornos Martinez) [2183487]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: pci_generic: Add a secondary AT port to Telit FN990 (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: Fix race between channel preparation and M0 event (Jose Ignacio Tornos Martinez) [2183487]
- bus: mhi: host: Use mhi_soc_reset() API in place of register write (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: fix monitor vdev creation with firmware recovery (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix reads of uninitialized variables hw_ctrl_s1, sw_ctrl_s1 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add 8852be to Makefile and Kconfig (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: phy: add dummy C2H handler to avoid warning message (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops related to RF calibration (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: rfk: add DPK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: rfk: add TSSI (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: rfk: add IQK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: rfk: add RX DCK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: rfk: add RCK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: rfk: add DACK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Delay the unmapping of the buffer (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Check return value of ath10k_get_arvif() in ath10k_wmi_event_tdls_peer() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Fix firmware crash on vdev delete race condition (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Send PME message during wakeup from D3cold (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: add support to configure channel dwell time (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: suppress add interface error (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add basic attributes of chip_info (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add functions to control BB to assist RF calibrations (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops to configure TX/RX path (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops to query PPDU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops related to BT coexistence (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops to get thermal (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add basic baseband chip_ops (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add power on/off functions (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops::set_channel_help (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Update module description (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Fix reading the vendor of combo chips (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Make some arrays const (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: fix wrong bandwidth settings after scan (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: correct 6 GHz scan behavior (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops::set_channel (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: make generic functions to convert subband gain index (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add HFC quota arrays (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: set proper configuration before loading NCTL (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: parse PHY status only when PPDU is to_self (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: coex: move chip_ops::btc_bt_aci_imp to a generic code (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: verify the expected usb_endpoints are present (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: hif_usb: Fix use-after-free in ath9k_hif_usb_reg_in_cb() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: Remove -Warray-bounds exception (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: hif_usb: fix memory leak of urbs in ath9k_hif_usb_dealloc_tx_urbs() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: realtek: remove duplicated wake_tx_queue (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath9k: Make arrays prof_prio and channelmap static const (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Fix spelling mistake "chnange" -> "change" (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Drop support for TX push path (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add wake_tx_queue callback to drivers (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add internal handler for wake_tx_queue (Jose Ignacio Tornos Martinez) [2183487]
- cfg80211: Update Transition Disable policy during port authorization (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: minstrel_ht: remove unused has_mrr member from struct minstrel_priv (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: remove support for AddBA with fragmentation (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: agg-rx: avoid band check (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: prohibit IEEE80211_HT_CAP_DELAY_BA with MLO (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: don't clear DTIM period after setting it (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: change AddBA deny error message (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: mlme: mark assoc link in output (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add RCU _check() link access variants (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: fix AddBA response addressing (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: set internal scan request BSSID (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: advertise TWT requester only with HW support (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: use link_id in ieee80211_change_bss() (Jose Ignacio Tornos Martinez) [2183487]
- wifi: nl80211: use link ID in NL80211_CMD_SET_BSS (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: transmit AddBA with MLD address (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: wme: use ap_addr instead of deflink BSSID (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Process association status for affiliated links (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: Parse station profile from association response (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211/mac80211: Fix ML element common size validation (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211/mac80211: Fix ML element common size calculation (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ieee80211: Support validating ML station profile length (Jose Ignacio Tornos Martinez) [2183487]
- wifi: cfg80211: support reporting failed links (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: recalc station aggregate data during link switch (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: include link address in debugfs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add API to show the link STAs in debugfs (Jose Ignacio Tornos Martinez) [2183487]
- wifi: mac80211: add pointer from link STA to STA (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: add to dump TX FIFO 0/1 for 8852C (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: set pin MUX to enable BT firmware log (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: phy: ignore warning of bb gain cfg_type 4 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: update BB parameters to v28 (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: rfk: correct miscoding delay of DPK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852c: correct set of IQK backup registers (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: Fix AP interface delete issue (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: support station interface creation version 1, 2 and 3 (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: add creating station interface support (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: dump dongle memory when attaching failed (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: return error when getting invalid max_flowrings from dongle (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: add a timer to read console periodically in PCIE bus (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: Fix authentication latency caused by OBSS stats survey (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: fix CERT-P2P:5.1.10 failure (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: fix firmware trap while dumping obss stats (Jose Ignacio Tornos Martinez) [2183487]
- brcmfmac: Add dump_survey cfg80211 ops for HostApd AutoChannelSelection (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtl8xxxu: Support new chip RTL8188FU (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852be: add 8852BE PCI entry (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops to read phy cap (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops to read efuse (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add chip_ops::set_txpwr (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: debug: txpwr_table considers sign (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: phy: make generic txpwr setting functions (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add tables for RFK (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add BB and RF tables (2 of 2) (Jose Ignacio Tornos Martinez) [2183487]
- wifi: rtw89: 8852b: add BB and RF tables (1 of 2) (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: Don't exit on wakeup failure (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath10k: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Jose Ignacio Tornos Martinez) [2183487]
- wifi: ath11k: stop tx queues immediately upon firmware exit (Jose Ignacio Tornos Martinez) [2183487]
- Revert "mac80211: set NETIF_F_LLTX when using intermediate tx queues" (Jose Ignacio Tornos Martinez) [2183487]
- treewide: use get_random_u32() when possible (Jose Ignacio Tornos Martinez) [2183487]
- treewide: use prandom_u32_max() when possible, part 1 (Jose Ignacio Tornos Martinez) [2183487]
- hwrng: core - let sleep be interrupted when unregistering hwrng (Jose Ignacio Tornos Martinez) [2183487]
- tracing/kprobes: Do the notrace functions check without kprobes on ftrace (Mukesh Chaurasiya) [2203370]
- tracing/kprobes: Fix a double initialization typo (Mukesh Chaurasiya) [2203370]
- tracing/kprobe: Check whether the non-suffixed symbol is notrace (Mukesh Chaurasiya) [2203370]
- tracing/kprobes: Fix to check notrace function with correct range (Mukesh Chaurasiya) [2203370]
- tracing/kprobes: Fix within_notrace_func() to check only notrace functions (Mukesh Chaurasiya) [2203370]
- powerpc/kprobes: Fix kprobe Oops happens in booke (Mukesh Chaurasiya) [2203370]
- xfs: verify buffer contents when we skip log replay (Andrey Albershteyn) [2187456] {CVE-2023-2124}
- perf c2c: Add report option to show false sharing in adjacent cachelines (Michael Petlan) [2193188]
- powerpc/papr_scm: Update the NUMA distance table for the target node (Mamatha Inamdar) [2183474]
- i2c: xgene-slimpro: Fix out-of-bounds bug in xgene_slimpro_i2c_xfer() (Tony Camuso) [2188408] {CVE-2023-2194}
- prlimit: do_prlimit needs to have a speculation check (Alex Gladkov) [2196314] {CVE-2023-0458}
- vmxnet3: use gro callback when UPT is enabled (Izabela Bakollari) [2183057]
- r8152: Rate limit overflow messages (Jose Ignacio Tornos Martinez) [2153573] {CVE-2022-3594}
- docs: Remove unnecessary unicode character (Patrick Talbert) [2207988]
- PCI: vmd: Add quirk to configure PCIe ASPM and LTR (Myron Stowe) [2136922]
- PCI: vmd: Create feature grouping for client products (Myron Stowe) [2136922]
- PCI: vmd: Use PCI_VDEVICE in device list (Myron Stowe) [2136922]
- PCI/ASPM: Add pci_enable_link_state() (Myron Stowe) [2136922]
- PCI: vmd: Fix secondary bus reset for Intel bridges (Myron Stowe) [2136922]
- PCI: vmd: Disable MSI remapping after suspend (Myron Stowe) [2136922]
- PCI: vmd: Add DID 8086:7D0B and 8086:AD0B for Intel MTL SKUs (Myron Stowe) [2136922]
- PCI: vmd: Use devm_kasprintf() instead of simple kasprintf() (Myron Stowe) [2136922]

* Mon May 22 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-494.el8]
- net/sched: sch_fq: fix integer overflow of "credit" (Davide Caratti) [2187718]
- net: sched: gred: prevent races when adding offloads to stats (Davide Caratti) [2187718]
- sch_htb: Avoid grafting on htb_destroy_class_offload when destroying htb (Davide Caratti) [2187718]
- net/sched: act_mpls: Fix warning during failed attribute validation (Davide Caratti) [2187718]
- net: sched: fix memory leak in tcindex_set_parms (Davide Caratti) [2187718]
- net_sched: reject TCF_EM_SIMPLE case for complex ematch module (Davide Caratti) [2187718]
- net: sched: Fix use after free in red_enqueue() (Davide Caratti) [2187718]
- net: sched: fix race condition in qdisc_graft() (Davide Caratti) [2187718]
- net: sched: sfb: fix null pointer access issue when sfb_init() fails (Davide Caratti) [2187718]
- net/sched: cls_api: Fix flow action initialization (Davide Caratti) [2187718]
- scsi: lpfc: Update inbox lpfc driver for RHEL 8.9 to 14.0.0.21. (Paul Ely) [2165048]
- scsi: lpfc: Copyright updates for 14.2.0.11 patches (Paul Ely) [2165048]
- scsi: lpfc: Copyright updates for 14.2.0.10 patches (Paul Ely) [2165048]
- scsi: lpfc: Defer issuing new PLOGI if received RSCN before completing REG_LOGIN (Paul Ely) [2165048]
- scsi: lpfc: Record LOGO state with discovery engine even if aborted (Paul Ely) [2165048]
- scsi: lpfc: Fix lockdep warning for rx_monitor lock when unloading driver (Paul Ely) [2165048]
- scsi: lpfc: Reorder freeing of various DMA buffers and their list removal (Paul Ely) [2165048]
- scsi: lpfc: Prevent lpfc_debugfs_lockstat_write() buffer overflow (Paul Ely) [2165048]
- scsi: lpfc: Introduce new attention types for lpfc_sli4_async_fc_evt() handler (Paul Ely) [2165048]
- scsi: lpfc: Fix use-after-free KFENCE violation during sysfs firmware write (Paul Ely) [2165048]
- scsi: lpfc: Exit PRLI completion handling early if ndlp not in PRLI_ISSUE state (Paul Ely) [2165048]
- scsi: lpfc: Remove duplicate ndlp kref decrement in lpfc_cleanup_rpis() (Paul Ely) [2165048]
- scsi: lpfc: Remove redundant clean up code in disable_vport() (Paul Ely) [2165048]
- scsi: lpfc: Fix crash involving race between FLOGI timeout and devloss handler (Paul Ely) [2165048]
- net: sched: sch_qfq: prevent slab-out-of-bounds in qfq_activate_agg (Ricardo Robaina) [2192680] {CVE-2023-2248 CVE-2023-31436}
- vfio/ccw: remove old IDA format restrictions (Tobias Huschle) [2187662]
- vfio/ccw: handle a guest Format-1 IDAL (Tobias Huschle) [2187662]
- vfio/ccw: allocate/populate the guest idal (Tobias Huschle) [2187662]
- vfio/ccw: calculate number of IDAWs regardless of format (Tobias Huschle) [2187662]
- vfio/ccw: read only one Format-1 IDAW (Tobias Huschle) [2187662]
- vfio/ccw: refactor the idaw counter (Tobias Huschle) [2187662]
- vfio/ccw: populate page_array struct inline (Tobias Huschle) [2187662]
- vfio/ccw: record the page offset in struct pfn_array (Tobias Huschle) [2187662]
- vfio/ccw: pass page count to page_array struct (Tobias Huschle) [2187662]
- vfio/ccw: simplify CCW chain fetch routines (Tobias Huschle) [2187662]
- vfio/ccw: move where IDA flag is set in ORB (Tobias Huschle) [2187662]
- vfio/ccw: allow non-zero storage keys (Tobias Huschle) [2187662]
- iavf: remove active_cvlans and active_svlans bitmaps (Stefan Assmann) [2153349]
- iavf: refactor VLAN filter states (Stefan Assmann) [2153349]
- iavf: do not track VLAN 0 filters (Stefan Assmann) [2153349]
- iavf: fix non-tunneled IPv6 UDP packet type and hashing (Stefan Assmann) [2153349]
- iavf: fix inverted Rx hash condition leading to disabled hash (Stefan Assmann) [2153349]
- net/sched: move struct tc_mqprio_qopt_offload from pkt_cls.h to pkt_sched.h (Stefan Assmann) [2153349]
- iavf/iavf_main: actually log ->src mask when talking about it (Stefan Assmann) [2153349]
- iavf: Fix VF driver counting VLAN 0 filters (Stefan Assmann) [2153349]
- iavf: Change information about device removal in dmesg (Stefan Assmann) [2153349]
- iavf: Replace __FUNCTION__ with __func__ (Stefan Assmann) [2153349]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Stefan Assmann) [2153349]
- ipv4: prevent potential spectre v1 gadget in fib_metrics_match() (Guillaume Nault) [2188040]
- ipv4: prevent potential spectre v1 gadget in ip_metrics_convert() (Guillaume Nault) [2188040]
- ipv4: Fix error return code in fib_table_insert() (Guillaume Nault) [2188040]
- ipv4: drop dst in multicast routing path (Guillaume Nault) [2188040]
- net: igmp: respect RCU rules in ip_mc_source() and ip_mc_msfilter() (Guillaume Nault) [2188040]
- xfrm: Zero padding when dumping algos and encap (Sabrina Dubroca) [2189212]
- xfrm: redact SA secret with lockdown confidentiality (Sabrina Dubroca) [2189212]
- xfrm: fix bug with DSCP copy to v6 from v4 tunnel (Sabrina Dubroca) [2189212]
- xfrm: enforce validity of offload input flags (Sabrina Dubroca) [2189212]
- ice: Remove LAG+SRIOV mutual exclusion (Michal Schmidt) [2120585]
- ext4: correct the misjudgment in ext4_iget_extra_inode (Carlos Maiolino) [2193101]
- ext4: correct max_inline_xattr_value_size computing (Carlos Maiolino) [2193101]
- ext4: fix use-after-free in ext4_xattr_set_entry (Carlos Maiolino) [2193101] {CVE-2023-2513}
- ext4: add EXT4_INODE_HAS_XATTR_SPACE macro in xattr.h (Carlos Maiolino) [2193101]
- ixgbevf: Fix resource leak in ixgbevf_init_module() (Ken Cox) [2153374]
- ixgbevf: Add error messages on vlan error (Ken Cox) [2153374]

* Tue May 16 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-493.el8]
- kunit: make kunit_test_timeout compatible with comment (Nico Pache) [2168375]
- kunit: fix assert_type for comparison macros (Nico Pache) [2168375]
- redhat: include new kunit tests in mod-internals (Nico Pache) [2168375]
- kernel.h: split out mathematical helpers (Nico Pache) [2168375]
- linux/kernel.h: fix overflow for DIV_ROUND_UP_ULL (Nico Pache) [2168375]
- linux/kernel.h: Use parentheses around argument in u64_to_user_ptr() (Nico Pache) [2168375]
- <linux/kernel.h>: drop the gcc-3.3 'const' hack in roundup() (Nico Pache) [2168375]
- kernel.h: documentation for roundup() vs round_up() (Nico Pache) [2168375]
- apparmor: test: Use NULL macros (Nico Pache) [2168375]
- kasan: test: Use NULL macros (Nico Pache) [2168375]
- kunit: use NULL macros (Nico Pache) [2168375]
- kunit: Introduce _NULL and _NOT_NULL macros (Nico Pache) [2168375]
- kunit: decrease macro layering for EQ/NE asserts (Nico Pache) [2168375]
- kunit: decrease macro layering for integer asserts (Nico Pache) [2168375]
- kunit: reduce layering in string assertion macros (Nico Pache) [2168375]
- kunit: drop unused intermediate macros for ptr inequality checks (Nico Pache) [2168375]
- kunit: make KUNIT_EXPECT_EQ() use KUNIT_EXPECT_EQ_MSG(), etc. (Nico Pache) [2168375]
- Documentation: kunit: Remove redundant 'tips.rst' page (Nico Pache) [2168375]
- Documentation: KUnit: reword description of assertions (Nico Pache) [2168375]
- kunit: tool: Don't download risc-v opensbi firmware with wget (Nico Pache) [2168375]
- drm/tests: Split up test cases in igt_check_drm_format_min_pitch (Nico Pache) [2168375]
- kunit: executor: Fix a memory leak on failure in kunit_filter_tests (Nico Pache) [2168375]
- Documentation: kunit: Cleanup run_wrapper, fix x-ref (Nico Pache) [2168375]
- kunit: use kmemdup in kunit_filter_tests(), take suite as const (Nico Pache) [2168375]
- kunit: fix executor OOM error handling logic on non-UML (Nico Pache) [2168375]
- drm: selftest: convert drm_mm selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_buddy selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_framebuffer selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_dp_mst_helper selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_plane_helper selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_format selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_rect selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_cmdline_parser selftest to KUnit (Nico Pache) [2168375]
- drm: selftest: convert drm_damage_helper selftest to KUnit (Nico Pache) [2168375]
- drm/doc: Add KUnit documentation (Nico Pache) [2168375]
- kunit: drop unused assert_type from kunit_assert and clean up macros (Nico Pache) [2168375]
- kunit: split out part of kunit_assert into a static const (Nico Pache) [2168375]
- kunit: factor out kunit_base_assert_format() call into kunit_fail() (Nico Pache) [2168375]
- kunit: drop unused kunit* field in kunit_assert (Nico Pache) [2168375]
- kunit: move check if assertion passed into the macros (Nico Pache) [2168375]
- kunit: tool: misc cleanups (Nico Pache) [2168375]
- kunit: tool: minor cosmetic cleanups in kunit_parser.py (Nico Pache) [2168375]
- kunit: tool: make parser stop overwriting status of suites w/ no_tests (Nico Pache) [2168375]
- kunit: tool: remove dead parse_crash_in_log() logic (Nico Pache) [2168375]
- kunit: tool: print clearer error message when there's no TAP output (Nico Pache) [2168375]
- kunit: tool: stop using a shell to run kernel under QEMU (Nico Pache) [2168375]
- kunit: tool: update test counts summary line format (Nico Pache) [2168375]
- kunit: bail out of test filtering logic quicker if OOM (Nico Pache) [2168375]
- lib/Kconfig.debug: change KUnit tests to default to KUNIT_ALL_TESTS (Nico Pache) [2168375]
- kunit: Rework kunit_resource allocation policy (Nico Pache) [2168375]
- thunderbolt: Add KUnit test for devices with no DisplayPort adapters (Nico Pache) [2168375]
- drm/todo: Add entry for converting kselftests to kunit (Nico Pache) [2168375]
- drm/todo: Add entry for using kunit in the subsystem (Nico Pache) [2168375]
- kunit: fix debugfs code to use enum kunit_status, not bool (Nico Pache) [2168375]
- kunit: add ability to specify suite-level init and exit functions (Nico Pache) [2168375]
- kunit: rename print_subtest_{start,end} for clarity (s/subtest/suite) (Nico Pache) [2168375]
- kunit: add support for kunit_suites that reference init code (Nico Pache) [2168375]
- Documentation: kunit: change complete_and_exit to kthread_complete_and_exit (Nico Pache) [2168375]
- mm/slub, kunit: Make slub_kunit unaffected by user specified flags (Nico Pache) [2168375]
- kunit: Make kunit_remove_resource() idempotent (Nico Pache) [2168375]
- list: test: Test the hlist structure (Nico Pache) [2168375]
- ASoC: soc-utils: Add kunit test for snd_soc_tdm_params_to_bclk() (Nico Pache) [2168375]
- ASoC: soc-utils: Add helper to calculate BCLK from TDM info (Nico Pache) [2168375]
- Documentation: kunit: update kconfig options needed for UML coverage (Nico Pache) [2168375]
- kunit: split resource API impl from test.c into new resource.c (Nico Pache) [2168375]
- kunit: split resource API from test.h into new resource.h (Nico Pache) [2168375]
- kunit: tool: more descriptive metavars/--help output (Nico Pache) [2168375]
- kunit: tool: Do not colorize output when redirected (Nico Pache) [2168375]
- kunit: tool: properly report the used arch for --json, or '' if not known (Nico Pache) [2168375]
- kunit: tool: refactor how we plumb metadata into JSON (Nico Pache) [2168375]
- kunit: tool: drop mostly unused KunitResult.result field (Nico Pache) [2168375]
- kunit: tool: readability tweaks in KernelCI json generation logic (Nico Pache) [2168375]
- kunit: tool: simplify code since build_dir can't be None (Nico Pache) [2168375]
- kunit: tool: drop last uses of collections.namedtuple (Nico Pache) [2168375]
- kunit: tool: drop unused KernelDirectoryPath var (Nico Pache) [2168375]
- kunit: tool: make --json handling a bit clearer (Nico Pache) [2168375]
- Documentation: kunit: fix path to .kunitconfig in start.rst (Nico Pache) [2168375]
- Documentation: kunit: Fix cross-referencing warnings (Nico Pache) [2168375]
- binfmt_elf: Introduce KUnit test (Nico Pache) [2168375]
- list: test: Add a test for list_entry_is_head() (Nico Pache) [2168375]
- list: test: Add a test for list_is_head() (Nico Pache) [2168375]
- list: test: Add test for list_del_init_careful() (Nico Pache) [2168375]
- list: introduce list_is_head() helper and re-use it in list.h (Nico Pache) [2168375]
- list: add "list_del_init_careful()" to go with "list_empty_careful()" (Nico Pache) [2168375]
- kunit: add example test case showing off all the expect macros (Nico Pache) [2168375]
- test_hash.c: refactor into kunit (Nico Pache) [2168375]
- lib/Kconfig.debug: properly split hash test kernel entries (Nico Pache) [2168375]
- test_hash.c: split test_hash_init (Nico Pache) [2168375]
- test_hash.c: split test_int_hash into arch-specific functions (Nico Pache) [2168375]
- hash.h: remove unused define directive (Nico Pache) [2168375]
- iio: test: Add check against NULL for buffer in tests. (Nico Pache) [2168375]
- net: kunit: add a test for dev_addr_lists (Nico Pache) [2168375]
- kprobes: convert tests to kunit (Nico Pache) [2168375]
- bitfield: build kunit tests without structleak plugin (Nico Pache) [2168375]
- thunderbolt: build kunit tests without structleak plugin (Nico Pache) [2168375]
- iio/test-format: build kunit tests without structleak plugin (Nico Pache) [2168375]
- gcc-plugins/structleak: add makefile var for disabling structleak (Nico Pache) [2168375]
- math: RATIONAL_KUNIT_TEST should depend on RATIONAL instead of selecting it (Nico Pache) [2168375]
- math: make RATIONAL tristate (Nico Pache) [2168375]
- rtc: move RTC_LIB_KUNIT_TEST to proper location (Nico Pache) [2168375]
- rtc: Improve performance of rtc_time64_to_tm(). Add tests. (Nico Pache) [2168375]
- lib/math/rational: add Kunit test cases (Nico Pache) [2168375]
- time/kunit: Add missing MODULE_LICENSE() (Nico Pache) [2168375]
- kasan: test: make use of kunit_skip() (Nico Pache) [2168375]
- time: Improve performance of time64_to_tm() (Nico Pache) [2168375]
- iio: Remove a cast in iio-test-format which is no longer required (Nico Pache) [2168375]
- lib: kunit: suppress a compilation warning of frame size (Nico Pache) [2168375]
- kasan: docs: update tests section (Nico Pache) [2168375]
- iio: Add basic unit test for iio_format_value() (Nico Pache) [2168375]
- Documentation: KUnit: Fix usage bug (Nico Pache) [2168375]
- kunit: fix missing f in f-string in run_checks.py (Nico Pache) [2168375]
- kunit: tool: Import missing importlib.abc (Nico Pache) [2168375]
- kunit: replace kernel.h with the necessary inclusions (Nico Pache) [2168375]
- Documentation: KUnit: Restyled Frequently Asked Questions (Nico Pache) [2168375]
- Documentation: KUnit: Restyle Test Style and Nomenclature page (Nico Pache) [2168375]
- Documentation: KUnit: Rework writing page to focus on writing tests (Nico Pache) [2168375]
- Documentation: kunit: Reorganize documentation related to running tests (Nico Pache) [2168375]
- Documentation: KUnit: Added KUnit Architecture (Nico Pache) [2168375]
- Documentation: KUnit: Rewrite getting started (Nico Pache) [2168375]
- Documentation: KUnit: Rewrite main page (Nico Pache) [2168375]
- kunit: tool: Default --jobs to number of CPUs (Nico Pache) [2168375]
- kunit: tool: fix newly introduced typechecker errors (Nico Pache) [2168375]
- kunit: tool: make `build` subcommand also reconfigure if needed (Nico Pache) [2168375]
- kunit: tool: delete kunit_parser.TestResult type (Nico Pache) [2168375]
- kunit: tool: use dataclass instead of collections.namedtuple (Nico Pache) [2168375]
- kunit: tool: suggest using decode_stacktrace.sh on kernel crash (Nico Pache) [2168375]
- kunit: tool: reconfigure when the used kunitconfig changes (Nico Pache) [2168375]
- kunit: tool: revamp message for invalid kunitconfig (Nico Pache) [2168375]
- kunit: tool: add --kconfig_add to allow easily tweaking kunitconfigs (Nico Pache) [2168375]
- kunit: tool: move Kconfig read_from_file/parse_from_string to package-level (Nico Pache) [2168375]
- kunit: tool: print parsed test results fully incrementally (Nico Pache) [2168375]
- kunit: Report test parameter results as (K)TAP subtests (Nico Pache) [2168375]
- kunit: Don't crash if no parameters are generated (Nico Pache) [2168375]
- kunit: tool: Report an error if any test has no subtests (Nico Pache) [2168375]
- kunit: tool: Do not error on tests without test plans (Nico Pache) [2168375]
- kunit: add run_checks.py script to validate kunit changes (Nico Pache) [2168375]
- kunit: tool: fix --json output for skipped tests (Nico Pache) [2168375]
- kunit: tool: fix typecheck errors about loading qemu configs (Nico Pache) [2168375]
- kunit: tool: continue past invalid utf-8 output (Nico Pache) [2168375]
- kunit: tool: improve compatibility of kunit_parser with KTAP specification (Nico Pache) [2168375]
- kunit: tool: yield output from run_kernel in real time (Nico Pache) [2168375]
- kunit: tool: support running each suite/test separately (Nico Pache) [2168375]
- kunit: tool: actually track how long it took to run tests (Nico Pache) [2168375]
- kunit: tool: factor exec + parse steps into a function (Nico Pache) [2168375]
- kunit: add 'kunit.action' param to allow listing out tests (Nico Pache) [2168375]
- kunit: tool: show list of valid --arch options when invalid (Nico Pache) [2168375]
- kunit: tool: misc fixes (unused vars, imports, leaked files) (Nico Pache) [2168375]
- kunit: fix too small allocation when using suite-only kunit.filter_glob (Nico Pache) [2168375]
- kunit: tool: allow filtering test cases via glob (Nico Pache) [2168375]
- kunit: tool: better handling of quasi-bool args (--json, --raw_output) (Nico Pache) [2168375]
- kunit: tool: make --raw_output support only showing kunit output (Nico Pache) [2168375]
- kunit: tool: add --kernel_args to allow setting module params (Nico Pache) [2168375]
- kunit: tool: Assert the version requirement (Nico Pache) [2168375]
- kunit: tool: remove unnecessary "annotations" import (Nico Pache) [2168375]
- Documentation: kunit: drop obsolete note about uml_abort for coverage (Nico Pache) [2168375]
- kunit: tool: Fix error messages for cases of no tests and wrong TAP header (Nico Pache) [2168375]
- kunit: tool: Support skipped tests in kunit_tool (Nico Pache) [2168375]
- kunit: tool: internal refactor of parser input handling (Nico Pache) [2168375]
- kunit: Remove the unused all_tests.config (Nico Pache) [2168375]
- kunit: Move default config from arch/um -> tools/testing/kunit (Nico Pache) [2168375]
- kunit: arch/um/configs: Enable KUNIT_ALL_TESTS by default (Nico Pache) [2168375]
- kunit: tool: add support for QEMU (Nico Pache) [2168375]
- kunit: tool: make --kunitconfig accept dirs, add lib/kunit fragment (Nico Pache) [2168375]
- kunit: tool: Disable PAGE_POISONING under --alltests (Nico Pache) [2168375]
- kunit: tool: Fix a python tuple typing error (Nico Pache) [2168375]
- iommu/amd: Indicate whether DMA remap support is enabled (Desnes Nunes) [2184064]
- Revert "usb: typec: ucsi: add a common function ucsi_unregister_connectors()" (Desnes Nunes) [2184064]
- usb: typec: ucsi: Only check the contract if there is a connection (Desnes Nunes) [2184064]
- media: uvcvideo: Fix InterfaceProtocol for Quanta camera (Desnes Nunes) [2184064]
- net: thunderbolt: fix memory leak in tbnet_open() (Desnes Nunes) [2184064]
- USB: serial: option: add u-blox LARA-L6 modem (Desnes Nunes) [2184064]
- USB: serial: option: add u-blox LARA-R6 00B modem (Desnes Nunes) [2184064]
- USB: serial: option: remove old LARA-R6 PID (Desnes Nunes) [2184064]
- net: thunderbolt: Fix error handling in tbnet_init() (Desnes Nunes) [2184064]
- USB: serial: option: add Fibocom FM160 0x0111 composition (Desnes Nunes) [2184064]
- USB: serial: option: add Fibocom MA510 modem (Desnes Nunes) [2184064]
- USB: serial: option: add Fibocom L610 modem (Desnes Nunes) [2184064]
- USB: serial: option: add device id for Foxconn T99W265 (Desnes Nunes) [2184064]
- USB: serial: option: add Fibocom FM101-GL variants (Desnes Nunes) [2184064]
- USB: serial: option: add Telit LE910S1 0x9200 composition (Desnes Nunes) [2184064]
- usb: add NO_LPM quirk for Realforce 87U Keyboard (Desnes Nunes) [2184064]
- usb: typec: tipd: Prevent uninitialized event{1,2} in IRQ handler (Desnes Nunes) [2184064]
- usb: typec: mux: Enter safe mode only when pins need to be reconfigured (Desnes Nunes) [2184064]
- USB: bcma: Make GPIO explicitly optional (Desnes Nunes) [2184064]
- USB: serial: option: add Sierra Wireless EM9191 (Desnes Nunes) [2184064]
- xhci: Remove device endpoints from bandwidth list when freeing the device (Desnes Nunes) [2184064]
- xhci-pci: Set runtime PM as default policy on all xHC 1.2 or later devices (Desnes Nunes) [2184064]
- xhci: Add quirk to reset host back to default state at shutdown (Desnes Nunes) [2184064]
- usb: xhci: add XHCI_SPURIOUS_SUCCESS to ASM1042 despite being a V0.96 controller (Desnes Nunes) [2184064]
- Revert "xhci: turn off port power in shutdown" (Desnes Nunes) [2184064]
- xhci-pci: Allow host runtime PM as default for Intel Meteor Lake xHCI (Desnes Nunes) [2184064]
- xhci-pci: Allow host runtime PM as default for Intel Raptor Lake xHCI (Desnes Nunes) [2184064]
- xhci: turn off port power in shutdown (Desnes Nunes) [2184064]
- xhci: Keep interrupt disabled in initialization until host is running. (Desnes Nunes) [2184064]
- fbdev: sisfb: use explicitly signed char (Desnes Nunes) [2184064]
- usb: typec: ucsi: acpi: Implement resume callback (Desnes Nunes) [2184064]
- usb: typec: ucsi: Check the connection on resume (Desnes Nunes) [2184064]
- usb: host: ehci-exynos: switch to using gpiod API (Desnes Nunes) [2184064]
- usb: typec: ucsi_ccg: Disable UCSI ALT support on Tegra (Desnes Nunes) [2184064]
- usb: typec: Replace custom implementation of device_match_fwnode() (Desnes Nunes) [2184064]
- usb: typec: ucsi: Don't warn on probe deferral (Desnes Nunes) [2184064]
- usb: typec: ucsi: Wait for the USB role switches (Desnes Nunes) [2184064]
- usb: typec: ucsi: add a common function ucsi_unregister_connectors() (Desnes Nunes) [2184064]
- usb: typec: ucsi: Better fix for missing unplug events issue (Desnes Nunes) [2184064]
- usb: typec: ucsi: Read the PDOs in separate work (Desnes Nunes) [2184064]
- usb: typec: ucsi: Check the partner alt modes always if there is PD contract (Desnes Nunes) [2184064]
- usb: typec: ucsi: acpi: Reduce the command completion timeout (Desnes Nunes) [2184064]
- usb: typec: ucsi: Add polling mechanism for partner tasks like alt mode checking (Desnes Nunes) [2184064]
- usb: typec: ucsi: Don't stop alt mode registration on busy condition (Desnes Nunes) [2184064]
- usb: typec: ucsi: Always cancel the command if PPM reports BUSY condition (Desnes Nunes) [2184064]
- usb: add quirks for Lenovo OneLink+ Dock (Desnes Nunes) [2184064]
- USB: NO_LPM quirk Lenovo USB-C to Ethernet Adapher(RTL8153-04) (Desnes Nunes) [2184064]
- USB: NO_LPM quirk Lenovo Powered USB-C Travel Hub (Desnes Nunes) [2184064]
- usb: idmouse: fix an uninit-value in idmouse_open (Desnes Nunes) [2184064]
- usb: ulpi: use DEFINE_SHOW_ATTRIBUTE to simplify ulpi_regs (Desnes Nunes) [2184064]
- usb: ulpi: Add debugfs support (Desnes Nunes) [2184064]
- usb: typec: fusb302: Switch to use dev_err_probe() helper (Desnes Nunes) [2184064]
- usb: typec: qcom-pmic-typec: Switch to use dev_err_probe() helper (Desnes Nunes) [2184064]
- usb: typec: stusb160x: Switch to use dev_err_probe() helper (Desnes Nunes) [2184064]
- USB: serial: qcserial: add new usb-id for Dell branded EM7455 (Desnes Nunes) [2184064]
- thunderbolt: Explicitly enable lane adapter hotplug events at startup (Desnes Nunes) [2184064]
- media: flexcop-usb: use usb_endpoint_maxp() (Desnes Nunes) [2184064]
- media: flexcop-usb: clean up URB initialisation (Desnes Nunes) [2184064]
- media: flexcop-usb: clean up endpoint sanity checks (Desnes Nunes) [2184064]
- media: flexcop-usb: fix endpoint type check (Desnes Nunes) [2184064]
- media: flexcop-usb: sanity checking of endpoint type (Desnes Nunes) [2184064]
- media: dib0700: fix rc endpoint lookup (Desnes Nunes) [2184064]
- media: flexcop-usb: fix endpoint sanity check (Desnes Nunes) [2184064]
- media: b2c2-flexcop-usb: add sanity checking (Desnes Nunes) [2184064]
- media: flexcop-usb: fix NULL-ptr deref in flexcop_usb_transfer_init() (Desnes Nunes) [2184064]
- media: usb/dvb-usb-v2: fix repeated words in comments (Desnes Nunes) [2184064]
- thunderbolt: Use dev_err_probe() (Desnes Nunes) [2184064]
- thunderbolt: Convert to use sysfs_emit()/sysfs_emit_at() APIs (Desnes Nunes) [2184064]
- Revert "usb: storage: Add quirk for Samsung Fit flash" (Desnes Nunes) [2184064]
- USB: add RESET_RESUME quirk for NVIDIA Jetson devices in RCM (Desnes Nunes) [2184064]
- media: uvcvideo: move uvc_format_desc to common header (Desnes Nunes) [2184064]
- media: uvcvideo: Add UVC_GUID_FORMAT_H265 (Desnes Nunes) [2184064]
- media: v4l: move helper functions for fractions from uvc to v4l2-common (Desnes Nunes) [2184064]
- xhci: remove unused lpm_failed_dev member from struct xhci_hcd (Desnes Nunes) [2184064]
- xhci: remove unused command member from struct xhci_hcd struct (Desnes Nunes) [2184064]
- xhci: show fault reason for a failed enable slot command (Desnes Nunes) [2184064]
- xhci: Don't show warning for reinit on known broken suspend (Desnes Nunes) [2184064]
- xhci: dbc: Fix memory leak in xhci_alloc_dbc() (Desnes Nunes) [2184064]
- usb: host: xhci: Fix potential memory leak in xhci_alloc_stream_info() (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: clean up driver prefix (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: move driver structure (Desnes Nunes) [2184064]
- USB: serial: make remove callback return void (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: clean up attribute visibility logic (Desnes Nunes) [2184064]
- USB: serial: console: move mutex_unlock() before usb_serial_put() (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: convert to use dev_groups (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: add support for HP and HA devices (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: simplify divisor handling (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: assume hi-speed type (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: clean up baudrate request (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: clean up attribute handling (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: clean up modem-status handling (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: tighten device-type detection (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: rename channel index (Desnes Nunes) [2184064]
- USB: serial: kl5kusb105: use usb_control_msg_recv() and usb_control_msg_send() (Desnes Nunes) [2184064]
- USB: serial: keyspan_pda: use usb_control_msg_recv() (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: use usb_control_msg_recv() (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: include FT2232D in type string (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: rename chip types (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: drop redundant chip type comments (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: clean up chip type enum (Desnes Nunes) [2184064]
- USB: serial: ftdi_sio: fix 300 bps rate for SIO (Desnes Nunes) [2184064]
- usb: typec: intel_pmc_mux: Use the helper acpi_dev_get_memory_resources() (Desnes Nunes) [2184064]
- usb: misc: usb3503: call clk_disable_unprepare in the error handling (Desnes Nunes) [2184064]
- usb: misc: uss720: fix uninitialized variable rlen (Desnes Nunes) [2184064]
- thunderbolt: debugfs: Fix spelling mistakes in seq_puts text (Desnes Nunes) [2184064]
- thunderbolt: Add support for ASMedia NVM image format (Desnes Nunes) [2184064]
- thunderbolt: Move vendor specific NVM handling into nvm.c (Desnes Nunes) [2184064]
- thunderbolt: Provide tb_retimer_nvm_read() analogous to tb_switch_nvm_read() (Desnes Nunes) [2184064]
- thunderbolt: Rename and make nvm_read() available for other files (Desnes Nunes) [2184064]
- thunderbolt: Extend NVM version fields to 32-bits (Desnes Nunes) [2184064]
- thunderbolt: Allow NVM upgrade of USB4 host routers (Desnes Nunes) [2184064]
- scsi: uas: Drop DID_TARGET_FAILURE use (Desnes Nunes) [2184064]
- usb: clean up after dropping driver registration log spam (Desnes Nunes) [2184064]
- USB: host: ehci-atmel: Add support for HSIC phy (Desnes Nunes) [2184064]
- dt-bindings: usb: atmel: add USB PHY type property (Desnes Nunes) [2184064]
- USB: xhci: make xhci_get_endpoint_address static (Desnes Nunes) [2184064]
- thunderbolt: Add support for receiver lane margining (Desnes Nunes) [2184064]
- thunderbolt: Add helper to check if CL states are enabled on port (Desnes Nunes) [2184064]
- thunderbolt: Pass CL state bitmask to tb_port_clx_supported() (Desnes Nunes) [2184064]
- thunderbolt: Move port CL state functions into correct place in switch.c (Desnes Nunes) [2184064]
- thunderbolt: Move tb_xdomain_parent() to tb.h (Desnes Nunes) [2184064]
- USB: hcd-pci: Drop the unused id parameter from usb_hcd_pci_probe() (Desnes Nunes) [2184064]
- USB: FHCI: Switch to GPIO descriptors (Desnes Nunes) [2184064]
- net: thunderbolt: Update module description with mention of USB4 (Desnes Nunes) [2184064]
- net: thunderbolt: Convert to use SPDX identifier (Desnes Nunes) [2184064]
- net: thunderbolt: Enable full end-to-end flow control (Desnes Nunes) [2184064]
- net: thunderbolt: Align the driver to the USB4 networking spec (Desnes Nunes) [2184064]
- net: thunderbolt: Add comment clarifying prtcstns flags (Desnes Nunes) [2184064]
- thunderbolt: Add back Intel Falcon Ridge end-to-end flow control workaround (Desnes Nunes) [2184064]
- thunderbolt: Make iommu_dma_protection more accurate (Desnes Nunes) [2184064]
- iommu: Add capability for pre-boot DMA protection (Desnes Nunes) [2184064]
- iommu: Introduce device_iommu_capable() (Desnes Nunes) [2184064]
- thunderbolt: Show link type for XDomain connections too (Desnes Nunes) [2184064]
- thunderbolt: Add KUnit test for devices with no DisplayPort adapters (Desnes Nunes) [2184064]
- thunderbolt: Add support for XDomain lane bonding (Desnes Nunes) [2184064]
- thunderbolt: Split setting link width and lane bonding into own functions (Desnes Nunes) [2184064]
- thunderbolt: Move tb_port_state() prototype to correct place (Desnes Nunes) [2184064]
- thunderbolt: Fix typo in comment (Desnes Nunes) [2184064]
- thunderbolt: Replace usage of found with dedicated list iterator variable (Desnes Nunes) [2184064]
- net: thunderbolt: Enable DMA paths only after rings are enabled (Desnes Nunes) [2184064]
- usb: reduce kernel log spam on driver registration (Desnes Nunes) [2184064]
- usb: host: xhci-plat: suspend/resume clks for brcm (Desnes Nunes) [2184064]
- usb: host: xhci-plat: suspend and resume clocks (Desnes Nunes) [2184064]
- usb: host: Initiate urb ep with udev ep0 (Desnes Nunes) [2184064]
- usb: ehci: Use endpoint in URB to get maxpacket (Desnes Nunes) [2184064]
- dt-bindings: usb: Add missing (unevaluated|additional)Properties on child nodes (Desnes Nunes) [2184064]
- dt-bindings: usb: Add DT bindings for STUSB160x Type-C controller (Desnes Nunes) [2184064]
- media: uvcvideo: Limit power line control for Sonix Technology (Desnes Nunes) [2184064]
- media: uvcvideo: Use entity get_cur in uvc_ctrl_set (Desnes Nunes) [2184064]
- media: uvcvideo: Fix typo 'the the' in comment (Desnes Nunes) [2184064]
- media: uvcvideo: Use indexed loops in uvc_ctrl_init_ctrl() (Desnes Nunes) [2184064]
- media: uvcvideo: Fix invalid pointer in uvc_ctrl_init_ctrl() (Desnes Nunes) [2184064]
- media: uvcvideo: Remove unneeded goto (Desnes Nunes) [2184064]
- media: uvcvideo: Limit power line control for Acer EasyCamera (Desnes Nunes) [2184064]
- media: uvcvideo: Limit power line control for Quanta cameras (Desnes Nunes) [2184064]
- media: uvcvideo: Limit power line control for Chicony Easycamera (Desnes Nunes) [2184064]
- media: uvcvideo: Limit power line control for Chicony Easycamera (Desnes Nunes) [2184064]
- media: uvcvideo: Limit power line control for Quanta UVC Webcam (Desnes Nunes) [2184064]
- media: uvcvideo: Add support for per-device control mapping overrides (Desnes Nunes) [2184064]
- media: uvcvideo: Add missing value for power_line_frequency (Desnes Nunes) [2184064]
- media: uvcvideo: Replace broken URL (Desnes Nunes) [2184064]
- media: uvcvideo: Fix comment blocks style (Desnes Nunes) [2184064]
- media: uvcvideo: refactor __uvc_ctrl_add_mapping (Desnes Nunes) [2184064]
- media: technisat-usb2: Fix comment typo (Desnes Nunes) [2184064]
- media: tm6000: Fix typo 'the the' in comment (Desnes Nunes) [2184064]
- media: gspca: Fix typo 'the the' in comment (Desnes Nunes) [2184064]
- thunderbolt: Add support for Intel Meteor Lake (Desnes Nunes) [2184064]
- thunderbolt: Add comment where Thunderbolt 4 PCI IDs start (Desnes Nunes) [2184064]
- usb/hcd: Fix dma_map_sg error check (Desnes Nunes) [2184064]
- usb: move from strlcpy with unused retval to strscpy (Desnes Nunes) [2184064]
- usb: typec: tcpci_rt1711h: Fix CC PHY noise filter of voltage level (Desnes Nunes) [2184064]
- usb: typec: tcpci: Move function "tcpci_to_typec_cc" to common (Desnes Nunes) [2184064]
- usb: typec: tcpci_rt1711h: Add compatible id with rt1715 (Desnes Nunes) [2184064]
- usb: typec: tcpci_rt1711h: Add initial phy setting (Desnes Nunes) [2184064]
- usb: typec: tcpci_rt1711h: Add regulator support when source vbus (Desnes Nunes) [2184064]
- usb: typec: tcpci_rt1711h: Fix vendor setting when set vconn (Desnes Nunes) [2184064]
- dt-bindings usb: typec: rt1711h: Add binding for Richtek RT1711H (Desnes Nunes) [2184064]
- usb: common: debug: Check non-standard control requests (Desnes Nunes) [2184064]
- usb: typec: ucsi: stm32g0: Fix spelling mistake "booloader" -> "bootloader" (Desnes Nunes) [2184064]
- usb: common: usb-conn-gpio: Simplify some error message (Desnes Nunes) [2184064]
- scsi: target: iscsi: Fix an error message in iscsi_check_key() (Maurizio Lombardi) [2186500]
- scsi: target: core: Fix warning on RT kernels (Maurizio Lombardi) [2186500]
- scsi: target: core: Remove unused variable 'unit_serial_len' (Maurizio Lombardi) [2186500]
- scsi: target: Remove the unused function transport_lba_64_ext() (Maurizio Lombardi) [2186500]
- fix iov_iter_bvec() "direction" argument (Maurizio Lombardi) [2186500]
- scsi: target: tcm_loop: Fix possible name leak in tcm_loop_setup_hba_bus() (Maurizio Lombardi) [2186500]
- scsi: target: core: New key must be used for moved PR (Maurizio Lombardi) [2186500]
- scsi: target: core: UA on all LUNs after reset (Maurizio Lombardi) [2186500]
- scsi: target: core: Abort all preempted regs if requested (Maurizio Lombardi) [2186500]
- scsi: target: core: Fix memory leak in preempt_and_abort (Maurizio Lombardi) [2186500]
- scsi: target: core: Fix preempt and abort for allreg res (Maurizio Lombardi) [2186500]
- scsi: target: Remove unused se_tmr_req_cache declaration (Maurizio Lombardi) [2186500]
- scsi: target: alua: Do not report emtpy port group (Maurizio Lombardi) [2186500]
- scsi: target: core: Set MULTIP bit for se_device with multiple ports (Maurizio Lombardi) [2186500]
- scsi: target: pscsi: Remove repeated word "calling" (Maurizio Lombardi) [2186500]
- scsi: target: core: De-RCU of se_lun and se_lun acl (Maurizio Lombardi) [2186500]
- scsi: target: core: Fix race during ACL removal (Maurizio Lombardi) [2186500]
- scsi: target: Remove XDWRITEREAD emulated support (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Do not require target authentication (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Allow AuthMethod=None (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Support base64 in CHAP (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Add support for extended CDB AHS (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Fix clang -Wformat warnings (Maurizio Lombardi) [2186500]
- scsi: target: Remove incorrect zero blocks WRITE_SAME check (Maurizio Lombardi) [2186500]
- scsi: target: Remove duplicate "the" (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Fix NULL pointer dereference in iscsi_conn_auth_required() (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Control authentication per ACL (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Extract auth functions (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Add upcast helpers (Maurizio Lombardi) [2186500]
- scsi: target: tcmu: Avoid holding XArray lock when calling lock_page (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Rename iscsi_session to iscsit_session (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Rename iscsi_conn to iscsit_conn (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Rename iscsi_cmd to iscsit_cmd (Maurizio Lombardi) [2186500]
- scsi: target: tcmu: Fix possible data corruption (Maurizio Lombardi) [2186500]
- scsi: target: core: Silence the message about unknown VPD pages (Maurizio Lombardi) [2186500]
- target: remove an incorrect unmap zeroes data deduction (Maurizio Lombardi) [2186500]
- scsi: target: Fix incorrect use of cpumask_t (Maurizio Lombardi) [2186500]
- scsi: target: tcmu: Fix possible page UAF (Maurizio Lombardi) [2186500]
- scsi: target: Add iscsi/cpus_allowed_list in configfs (Maurizio Lombardi) [2186500]
- scsi: target: tcmu: Make cmd_ring_size changeable via configfs (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Make sure the np under each tpg is unique (Maurizio Lombardi) [2186500]
- scsi: target: configfs: Delete unnecessary checks for NULL (Maurizio Lombardi) [2186500]
- scsi: target: core: Use RCU helpers for INQUIRY t10_alua_tg_pt_gp (Maurizio Lombardi) [2186500]
- scsi: target: core: Remove from tmr_list during LUN unlink (Maurizio Lombardi) [2186500]
- scsi: target: core: Stop using bdevname() (Maurizio Lombardi) [2186500]
- scsi: target: Perform ALUA group changes in one step (Maurizio Lombardi) [2186500]
- scsi: target: Replace lun_tg_pt_gp_lock with rcu in I/O path (Maurizio Lombardi) [2186500]
- scsi: target: Fix alua_tg_pt_gps_count tracking (Maurizio Lombardi) [2186500]
- scsi: target: Fix ordered tag handling (Maurizio Lombardi) [2186500]
- scsi: target: Fix ordered CMD_T_SENT handling (Maurizio Lombardi) [2186500]
- scsi: target: tcmu: Allocate zeroed pages for data area (Maurizio Lombardi) [2186500]
- scsi: target: tcmu: Use struct_size() helper in kmalloc() (Maurizio Lombardi) [2186500]
- scsi: target: sbp: Replace enable attr with ops.enable (Maurizio Lombardi) [2186500]
- scsi: target: iscsi: Replace tpg enable attr with ops.enable (Maurizio Lombardi) [2186500]
- scsi: target: core: Add common tpg/enable attribute (Maurizio Lombardi) [2186500]
- scsi: target: core: Make logs less verbose (Maurizio Lombardi) [2186500]
- scsi: target: Remove unused function arguments (Maurizio Lombardi) [2186500]
- scsi: target: Fix spelling mistake "CONFLIFT" -> "CONFLICT" (Maurizio Lombardi) [2186500]
- dm: don't lock fs when the map is NULL in process of resume (Benjamin Marzinski) [2192702]
- dm flakey: add an "error_reads" option (Benjamin Marzinski) [2192702]
- dm flakey: remove trailing space in the table line (Benjamin Marzinski) [2192702]
- dm flakey: fix a crash with invalid table line (Benjamin Marzinski) [2192702]
- dm ioctl: fix nested locking in table_clear() to remove deadlock concern (Benjamin Marzinski) [2192702]
- dm: unexport dm_get_queue_limits() (Benjamin Marzinski) [2192702]
- dm: add helper macro for simple DM target module init and exit (Benjamin Marzinski) [2192702]
- dm raid: remove unused d variable (Benjamin Marzinski) [2192702]
- dm mirror: add DMERR message if alloc_workqueue fails (Benjamin Marzinski) [2192702]
- dm: push error reporting down to dm_register_target() (Benjamin Marzinski) [2192702]
- dm integrity: call kmem_cache_destroy() in dm_integrity_init() error path (Benjamin Marzinski) [2192702]
- dm error: add discard support (Benjamin Marzinski) [2192702]
- dm zero: add discard support (Benjamin Marzinski) [2192702]
- dm table: allow targets without devices to set ->io_hints (Benjamin Marzinski) [2192702]
- dm verity: fix error handling for check_at_most_once on FEC (Benjamin Marzinski) [2192702]
- dm thin: speed up cell_defer_no_holder() (Benjamin Marzinski) [2192702]
- dm bufio: don't bug for clear developer oversight (Benjamin Marzinski) [2192702]
- dm bufio: never crash if dm_bufio_in_request() (Benjamin Marzinski) [2192702]
- dm bufio: use WARN_ON in dm_bufio_client_destroy and dm_bufio_exit (Benjamin Marzinski) [2192702]
- dm bufio: remove unused dm_bufio_release_move interface (Benjamin Marzinski) [2192702]
- dm stats: check for and propagate alloc_percpu failure (Benjamin Marzinski) [2192702]
- dm crypt: avoid accessing uninitialized tasklet (Benjamin Marzinski) [2192702]
- dm crypt: add cond_resched() to dmcrypt_write() (Benjamin Marzinski) [2192702]
- dm thin: fix deadlock when swapping to thin device (Benjamin Marzinski) [2192702]
- units: add the HZ macros (Jocelyn Falempe) [2160451]
- isystem: ship and use stdarg.h (Jocelyn Falempe) [2160451]
- i915: Move list_count() to list.h as list_count_nodes() for broader use (Jocelyn Falempe) [2160451]
- resource: Convert DEFINE_RES_NAMED() to be compound literal (Jocelyn Falempe) [2160451]
- media: videobuf2: Assert held reservation lock for dma-buf mmapping (Jocelyn Falempe) [2160451]
- media: videobuf2: Stop using internal dma-buf lock (Jocelyn Falempe) [2160451]
- media: videobuf2: Prepare to dynamic dma-buf locking specification (Jocelyn Falempe) [2160451]
- media: videobuf2-dma-contig.c: remove spurious 'b' in message (Jocelyn Falempe) [2160451]
- dma-buf: Add unlocked variant of attachment-mapping functions (Jocelyn Falempe) [2160451]
- dma-buf: Add unlocked variant of vmapping functions (Jocelyn Falempe) [2160451]
- kbuild: simplify access to the kernel's version (Jocelyn Falempe) [2160451]
- hwmon: (core) Add support for rated attributes (Jocelyn Falempe) [2160451]
- ACPI: video: Allow GPU drivers to report no panels (Jocelyn Falempe) [2160451]
- drm: Move nomodeset kernel parameter to drivers/video (Jocelyn Falempe) [2160451]
- PM: core: Add EXPORT[_GPL]_SIMPLE_DEV_PM_OPS macros (Jocelyn Falempe) [2160451]
- PM: runtime: Add DEFINE_RUNTIME_DEV_PM_OPS() macro (Jocelyn Falempe) [2160451]
- ACPI: video: Make backlight class device registration a separate step (v2) (Jocelyn Falempe) [2160451]
- ACPI: video: Add acpi_video_backlight_use_native() helper (Jocelyn Falempe) [2160451]
- scsi: sched/wait: Add wait_event_lock_irq_timeout for TASK_UNINTERRUPTIBLE usage (Jocelyn Falempe) [2160451]
- iosys-map: Add IOSYS_MAP_INIT_VADDR_IOMEM() (Jocelyn Falempe) [2160451]
- perf branch: Fix interpretation of branch records (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Adjust LBR regardless of filtering (Michael Petlan) [2086826]
- perf/x86/utils: Fix uninitialized var in get_branch_type() (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Add LbrExtV2 branch speculation info support (Michael Petlan) [2086826]
- perf/core: Add speculation info to branch entries (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Use fusion-aware branch classifier (Michael Petlan) [2086826]
- perf/x86: Make branch classifier fusion-aware (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Add LbrExtV2 software branch filter support (Michael Petlan) [2086826]
- perf/x86: Move branch classifier (Michael Petlan) [2086826]
- perf: Add irq and exception return branch types (Michael Petlan) [2086826]
- perf/x86/intel/ds: Check return values of insn decoder functions (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Add LbrExtV2 hardware branch filter support (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Add LbrExtV2 branch record support (Michael Petlan) [2086826]
- perf/x86/amd/lbr: Detect LbrExtV2 support (Michael Petlan) [2086826]
- x86/cpufeatures: Add LbrExtV2 feature bit (Michael Petlan) [2086826]
- perf/x86/amd/core: Add generic branch record interfaces (Michael Petlan) [2086826]
- perf/x86/amd/core: Refactor branch attributes (Michael Petlan) [2086826]
- perf/x86/amd/brs: Move feature-specific functions (Michael Petlan) [2086826]
- scsi: zfcp: Trace when request remove fails after qdio send fails (Tobias Huschle) [2159733]
- scsi: zfcp: Change the type of all fsf request id fields and variables to u64 (Tobias Huschle) [2159733]
- scsi: zfcp: Make the type for accessing request hashtable buckets size_t (Tobias Huschle) [2159733]
- scsi: zfcp: Drop redundant "the" in the comments (Tobias Huschle) [2159733]
- s390/qeth: Convert sprintf/snprintf to scnprintf (Tobias Huschle) [2159732]
- s390/qeth: Convert sysfs sprintf to sysfs_emit (Tobias Huschle) [2159732]
- s390/qeth: Use constant for IP address buffers (Tobias Huschle) [2159732]
- s390/ctcm: cleanup indenting (Tobias Huschle) [2159732]
- s390/ipl: add loadparm parameter to eckd ipl/reipl data (Tobias Huschle) [2159689]
- s390/ipl: add DEFINE_GENERIC_LOADPARM() (Tobias Huschle) [2159689]
- s390/ipl: use octal values instead of S_* macros (Tobias Huschle) [2159689]
- s390/ipl: add eckd support (Tobias Huschle) [2159689]
- net/iucv: Fix size of interrupt data (Tobias Huschle) [2192507]
- workqueue: Protects wq_unbound_cpumask with wq_pool_attach_mutex (Waiman Long) [2176760]
- workqueue: make sysfs of unbound kworker cpumask more clever (Waiman Long) [2176760]
- workqueue: Rename "delayed" (delayed by active management) to "inactive" (Waiman Long) [2176760]
- workqueue: Kick a worker based on the actual activation of delayed works (Waiman Long) [2176760]
- workqueue: fix UAF in pwq_unbound_release_workfn() (Waiman Long) [2176760]
- workqueue: fix a piece of comment about reserved bits for work flags (Waiman Long) [2176760]
- workqueue: void unneeded requeuing the pwq in rescuer thread (Waiman Long) [2176760]
- mm/memcg: Fix mem_cgroup_id_get_online() underflow problem (Waiman Long) [2176760]
- net: fix NULL pointer in skb_segment_list (Paolo Abeni) [2188595]
- net: stream: purge sk_error_queue in sk_stream_kill_queues() (Paolo Abeni) [2188595]
- skbuff: Account for tail adjustment during pull operations (Paolo Abeni) [2188595]
- net: vmxnet3: Fix NULL pointer dereference in vmxnet3_rq_rx_complete() (Seiji Nishikawa) [2186419]
- tipc: add an extra conn_get in tipc_conn_alloc (Xin Long) [2177374] {CVE-2023-1382}
- tipc: set con sock in tipc_conn_alloc (Xin Long) [2177374] {CVE-2023-1382}
- net: sched: fix memory leak in tcindex_set_parms (Davide Caratti) [2181874]
- net/sched: tcindex: search key must be 16 bits (Davide Caratti) [2181874]
- net/sched: tcindex: update imperfect hash filters respecting rcu (Davide Caratti) [2181874] {CVE-2023-1281}
- crypto: rng - Use a different crypto_rng for reseeding (Herbert Xu) [2193410]
- media: rc: Fix use-after-free bugs caused by ene_tx_irqsim() (Ricardo Robaina) [2174409] {CVE-2023-1118}

* Tue May 09 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-492.el8]
- xfs: assert in xfs_btree_del_cursor should take into account error (Andrey Albershteyn) [2183168]
- xfs: prevent a UAF when log IO errors race with unmount (Andrey Albershteyn) [2183168]
- xfs: fix NULL pointer dereference in xfs_getbmap() (Andrey Albershteyn) [2183168]
- xfs: avoid a UAF when log intent item recovery fails (Andrey Albershteyn) [2183168]
- xfs: fix memory leak in xfs_errortag_init (Andrey Albershteyn) [2183168]
- xfs: Fix unreferenced object reported by kmemleak in xfs_sysfs_init() (Andrey Albershteyn) [2183168]
- xfs: fix sb write verify for lazysbcount (Andrey Albershteyn) [2183168]
- xfs: invalidate block device page cache during unmount (Andrey Albershteyn) [2183168]
- xfs: invalidate xfs_bufs when allocating cow extents (Andrey Albershteyn) [2183168]
- xfs: dquot shrinker doesn't check for XFS_DQFLAG_FREEING (Andrey Albershteyn) [2183168]
- xfs: fix intermittent hang during quotacheck (Andrey Albershteyn) [2183168]
- xfs: fix exception caused by unexpected illegal bestcount in leaf dir (Andrey Albershteyn) [2183168]
- xfs: fix super block buf log item UAF during force shutdown (Andrey Albershteyn) [2183168]
- xfs: fix uninitialized variable access (Andrey Albershteyn) [2183168]
- xfs: fix potential log item leak (Andrey Albershteyn) [2183168]
- xfs: fix inode reservation space for removing transaction (Andrey Albershteyn) [2183168]
- xfs: fix extent busy updating (Andrey Albershteyn) [2183168]
- xfs: fix low space alloc deadlock (Andrey Albershteyn) [2183168]
- xfs: purge dquots after inode walk fails during quotacheck (Andrey Albershteyn) [2183168]
- xfs: get root inode correctly at bulkstat (Andrey Albershteyn) [2183168]
- iomap: iomap: fix memory corruption when recording errors during writeback (Andrey Albershteyn) [2183168]
- xfs: attach dquots to inode before reading data/cow fork mappings (Andrey Albershteyn) [2183168]
- xfs: get rid of assert from xfs_btree_islastblock (Andrey Albershteyn) [2183168]
- xfs: fix use-after-free in xattr node block inactivation (Andrey Albershteyn) [2183168]
- xfs: pass the correct cursor to xfs_iomap_prealloc_size (Andrey Albershteyn) [2183168]
- xfs: don't report reserved bnobt space as available (Andrey Albershteyn) [2183168]
- xfs: fix overfilling of reserve pool (Andrey Albershteyn) [2183168]
- xfs: always succeed at setting the reserve pool size (Andrey Albershteyn) [2183168]
- xfs: remove infinite loop when reserving free block pool (Andrey Albershteyn) [2166567 2183168]
- xfs: don't include bnobt blocks when reserving free block pool (Andrey Albershteyn) [2183168]
- xfs: document the XFS_ALLOC_AGFL_RESERVE constant (Andrey Albershteyn) [2183168]
- xfs: prevent UAF in xfs_log_item_in_current_chkpt (Andrey Albershteyn) [2183168]
- xfs: fix incorrect i_nlink caused by inode racing (Andrey Albershteyn) [2183168]
- xfs: fix incorrect error-out in xfs_remove (Andrey Albershteyn) [2183168]
- KVM: s390: GISA: sort out physical vs virtual pointers usage (Cédric Le Goater) [2169294]
- KVM: s390: disable migration mode when dirty tracking is disabled (Cédric Le Goater) [2169294]
- KVM: s390: Unwind kvm_arch_init() piece-by-piece() if a step fails (Cédric Le Goater) [2169294]
- iommu/s390: Make attach succeed even if the device is in error state (Cédric Le Goater) [2169294]
- KVM: s390: pci: Fix allocation size of aift kzdev elements (Cédric Le Goater) [2169294]
- iommu/s390: Fix incorrect aperture check (Cédric Le Goater) [2169294]
- KVM: s390: VSIE: sort out virtual/physical address in pin_guest_page (Cédric Le Goater) [2169294]
- KVM: s390: pv: sort out physical vs virtual pointers usage (Cédric Le Goater) [2169294]
- KVM: s390: sida: sort out physical vs virtual pointers usage (Cédric Le Goater) [2169294]
- KVM: s390: sort out physical vs virtual pointers usage (Cédric Le Goater) [2169294]
- iommu/s390: Fail probe for non-PCI devices (Cédric Le Goater) [2169294]
- PCI/AER: Remove redundant Device Control Error Reporting Enable (Myron Stowe) [2180894]
- PCI/AER: Configure ECRC only if AER is native (Myron Stowe) [2180894]
- PCI/AER: Iterate over error counters instead of error strings (Myron Stowe) [2180894]
- PCI/AER: Enable error reporting when AER is native (Myron Stowe) [2180894]
- PCI/AER: Configure ECRC for every device (Myron Stowe) [2180894]
- PCI/AER: Clear MULTI_ERR_COR/UNCOR_RCV bits (Myron Stowe) [2180894]
- PCI/sysfs: Use sysfs_emit() and sysfs_emit_at() in "show" functions (Myron Stowe) [2180894]
- PCI/AER: Use consistent format when printing PCI device (Myron Stowe) [2180894]
- PCI/sysfs: Rely on lengths from scnprintf(), dsm_label_utf16s_to_utf8s() (Myron Stowe) [2180894]
- PCI/sysfs: Fix dsm_label_utf16s_to_utf8s() buffer overrun (Myron Stowe) [2180894]
- mlxsw: minimal: Fix deadlock in ports creation (Petr Oros) [2177956]
- mlxsw: core: Fix use-after-free calling devl_unlock() in mlxsw_core_bus_device_unregister() (Petr Oros) [2177956]
- net: devlink: convert reload command to take implicit devlink->lock (Petr Oros) [2177956]
- mlxsw: convert driver to use unlocked devlink API during init/fini (Petr Oros) [2177956]
- mlxsw: Narrow the critical section of devl_lock during ports creation/removal (Petr Oros) [2177956]
- ice: sleep, don't busy-wait, in the SQ send retry loop (Michal Schmidt) [2184013]
- ice: remove unused buffer copy code in ice_sq_send_cmd_retry() (Michal Schmidt) [2184013]
- ice: sleep, don't busy-wait, for ICE_CTL_Q_SQ_CMD_TIMEOUT (Michal Schmidt) [2184013]
- ice: remove ice_ctl_q_info::sq_cmd_timeout (Michal Schmidt) [2184013]
- ice: increase the GNSS data polling interval to 20 ms (Michal Schmidt) [2184013]
- ice: do not busy-wait to read GNSS data (Michal Schmidt) [2184013]
- enic: Use irq_update_affinity_hint() (Michal Schmidt) [2101515]
- ethernet:enic: Fix a use after free bug in enic_hard_start_xmit (Michal Schmidt) [2101515]
- net: enic: Cure the enic api locking trainwreck (Michal Schmidt) [2101515]
- enic: switch from 'pci_' to 'dma_' API (Michal Schmidt) [2101515]
- enic: convert to new udp_tunnel_nic infra (Michal Schmidt) [2101515]
- enic: let core reject the unsupported coalescing parameters (Michal Schmidt) [2101515]
- scsi: mpt3sas: Fix an issue when driver is being removed (Tomas Henzl) [2166206]
- scsi: mpt3sas: Remove HBA BIOS version in the kernel log (Tomas Henzl) [2166206]
- scsi: mpt3sas: Don't print sense pool info twice (Tomas Henzl) [2166206]
- scsi: mpt3sas: Fix NULL pointer access in mpt3sas_transport_port_add() (Tomas Henzl) [2166206]
- scsi: mpt3sas: Fix a memory leak (Tomas Henzl) [2166206]
- scsi: mpt3sas: Demote log level for trace buffer allocation to info (Tomas Henzl) [2166206]
- scsi: mpt3sas: Fix possible resource leaks in mpt3sas_transport_port_add() (Tomas Henzl) [2166206]
- scsi: mpt3sas: Remove usage of dma_get_required_mask() API (Tomas Henzl) [2166206]
- scsi: mpt3sas: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Tomas Henzl) [2166206]
- ipmi: msghandler: kABI implementation was wrong (Tony Camuso) [2182345]
- hwmon: (xgene) Fix use after free bug in xgene_hwmon_remove due to race condition (Chris von Recklinghausen) [2184583] {CVE-2023-1855}
- RDMA/irdma: Add ipv4 check to irdma_find_listener() (Kamal Heib) [2117129 2135976]
- RDMA/irdma: Increase iWARP CM default rexmit count (Kamal Heib) [2117129 2135976]
- RDMA/irdma: Fix memory leak of PBLE objects (Kamal Heib) [2117129 2135976]
- RDMA/irdma: Do not generate SW completions for NOPs (Kamal Heib) [2117129 2135976]
- RDMA/irdma: Remove a redundant irdma_arp_table() call (Kamal Heib) [2117129 2135976]
- migrate: grab the compound head in migration_entry_wait_on_locked (Nico Pache) [2188249]
- module: Don't wait for GOING modules (Mark Langsdorf) [1964563]
- redhat/configs: Fix DEBUG_BLK_CGROUP and BFQ_CGROUP_DEBUG configs (Vladis Dronov)
- x86/MCE/AMD: Clear DFR errors found in THR handler (Prarit Bhargava) [2190279]

* Fri May 05 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-491.el8]
- iommu/amd: Update amd_iommu_fault structure to include PCI seg ID (Jerry Snitselaar) [2117775]
- iommu/amd: Update device_state structure to include PCI seg ID (Jerry Snitselaar) [2117775]
- iommu/amd: Print PCI segment ID in error log messages (Jerry Snitselaar) [2117775]
- iommu/amd: Add PCI segment support for ivrs_[ioapic/hpet/acpihid] commands (Jerry Snitselaar) [2117775]
- iommu/amd: Specify PCI segment ID when getting pci device (Jerry Snitselaar) [2117775]
- iommu/amd: Include PCI segment ID when initialize IOMMU (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce get_device_sbdf_id() helper function (Jerry Snitselaar) [2117775]
- iommu/amd: Flush upto last_bdf only (Jerry Snitselaar) [2117775]
- iommu/amd: Remove global amd_iommu_[dev_table/alias_table/last_bdf] (Jerry Snitselaar) [2117775]
- iommu/amd: Update set_dev_entry_bit() and get_dev_entry_bit() (Jerry Snitselaar) [2117775]
- iommu/amd: Update (un)init_device_table_dma() (Jerry Snitselaar) [2117775]
- iommu/amd: Update set_dte_irq_entry (Jerry Snitselaar) [2117775]
- iommu/amd: Update dump_dte_entry (Jerry Snitselaar) [2117775]
- iommu/amd: Update iommu_ignore_device (Jerry Snitselaar) [2117775]
- iommu/amd: Update set_dte_entry and clear_dte_entry (Jerry Snitselaar) [2117775]
- iommu/amd: Convert to use per PCI segment rlookup_table (Jerry Snitselaar) [2117775]
- iommu/amd: Update alloc_irq_table and alloc_irq_index (Jerry Snitselaar) [2117775]
- iommu/amd: Update amd_irte_ops functions (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce struct amd_ir_data.iommu (Jerry Snitselaar) [2117775]
- iommu/amd: Update irq_remapping_alloc to use IOMMU lookup helper function (Jerry Snitselaar) [2117775]
- iommu/amd: Convert to use rlookup_amd_iommu helper function (Jerry Snitselaar) [2117775]
- iommu/amd: Convert to use per PCI segment irq_lookup_table (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment rlookup table size (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment alias table size (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment device table size (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment last_bdf (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment unity map list (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment alias_table (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment old_dev_tbl_cpy (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment dev_data_list (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment irq_lookup_table (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment rlookup table (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce per PCI segment device table (Jerry Snitselaar) [2117775]
- iommu/amd: Introduce pci segment structure (Jerry Snitselaar) [2117775]
- iommu/amd: Update struct iommu_dev_data definition (Jerry Snitselaar) [2117775]
- redhat: configs: Enable CONFIG_INTEL_IOMMU_PERF_EVENTS (Jerry Snitselaar) [2176995]
- iommu/vt-d: Fix an IOMMU perfmon warning when CPU hotplug (Jerry Snitselaar) [2176995]
- iommu/vt-d: Enable IOMMU perfmon support (Jerry Snitselaar) [2176995]
- iommu/vt-d: Add IOMMU perfmon overflow handler support (Jerry Snitselaar) [2176995]
- iommu/vt-d: Support cpumask for IOMMU perfmon (Jerry Snitselaar) [2176995]
- iommu/vt-d: Add IOMMU perfmon support (Jerry Snitselaar) [2176995]
- iommu/vt-d: Support Enhanced Command Interface (Jerry Snitselaar) [2176995]
- iommu/vt-d: Retrieve IOMMU perfmon capability information (Jerry Snitselaar) [2176995]
- iommu/vt-d: Fix error handling in sva enable/disable paths (Jerry Snitselaar) [2181397]
- iommu/vt-d: Support size of the register set in DRHD (Jerry Snitselaar) [2181397]
- iommu/vt-d: Allow zero SAGAW if second-stage not supported (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove include/linux/intel-svm.h (Jerry Snitselaar) [2181397]
- iommu/vt-d: Allow to use flush-queue when first level is default (Jerry Snitselaar) [2181397]
- iommu/vt-d: Fix PASID directory pointer coherency (Jerry Snitselaar) [2181397]
- iommu/vt-d: Set No Execute Enable bit in PASID table entry (Jerry Snitselaar) [2181397]
- iommu: Remove SVM_FLAG_SUPERVISOR_MODE support (Jerry Snitselaar) [2181397]
- iommu/vt-d: Fix PCI device refcount leak in prq_event_thread() (Jerry Snitselaar) [2181397]
- PCI: Enable PASID only when ACS RR & UF enabled on upstream path (Jerry Snitselaar) [2181397]
- iommu/vt-d: Set SRE bit only when hardware has SRS cap (Jerry Snitselaar) [2181397]
- iommu/vt-d: Preset Access bit for IOVA in FL non-leaf paging entries (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove pasid_set_eafe() (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove unnecessary SVA data accesses in page fault path (Jerry Snitselaar) [2181397]
- iommu/vt-d: Add RPLS to quirk list to skip TE disabling (Jerry Snitselaar) [2181397]
- iommu: Remove guest pasid related interfaces and definitions (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove guest pasid related callbacks (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove unused PASID_DISABLED (Jerry Snitselaar) [2181397]
- iommu/vt-d: Clean up unused PASID updating functions (Jerry Snitselaar) [2181397]
- iommu/vtd: Replace acpi_bus_get_device() (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove unused dma_to_mm_pfn function (Jerry Snitselaar) [2181397]
- iommu/vt-d: Use bitmap_zalloc() when applicable (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove unused macros (Jerry Snitselaar) [2181397]
- iommu/vt-d: Allow NVS regions in arch_rmrr_sanity_check() (Jerry Snitselaar) [2181397]
- iommu/vt-d: Use rcu_lock in get_resv_regions (Jerry Snitselaar) [2181397]
- iommu: Add gfp parameter to iommu_alloc_resv_region (Jerry Snitselaar) [2181397]
- iommu/vt-d: Fix PCI device refcount leak in dmar_dev_scope_init() (Jerry Snitselaar) [2181397]
- iommu/vt-d: Fix PCI device refcount leak in has_external_pci() (Jerry Snitselaar) [2181397]
- iommu/vt-d: Remove iova_cache_get/put() (Jerry Snitselaar) [2181397]
- iommu/vt-d: Add missing "__init" for rmrr_sanity_check() (Jerry Snitselaar) [2181397]
- iommu/arm-smmu: Force identity domains for legacy binding (Jerry Snitselaar) [2181397]
- iommu/arm-smmu-v3: Properly handle the return value of arm_smmu_cmdq_build_cmd() (Jerry Snitselaar) [2181397]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands in arm_smmu_atc_inv_master() (Jerry Snitselaar) [2181397]
- iommu/arm-smmu: Add clk_bulk_{prepare/unprepare} to system pm callbacks (Jerry Snitselaar) [2181397]
- iommu: Make sysfs robust for non-API groups (Jerry Snitselaar) [2181397]
- iommu: Use right way to retrieve iommu_ops (Jerry Snitselaar) [2181397]
- iommu: Remove apply_resv_region (Jerry Snitselaar) [2181397]
- iommu/dma: Explicitly sort PCI DMA windows (Jerry Snitselaar) [2181397]
- iommu: Do not dereference fwnode in struct device (Jerry Snitselaar) [2181397]
- iommu: Remove duplicate ida_free in iommu_group_alloc (Jerry Snitselaar) [2181397]
- iommu: Directly use ida_alloc()/free() (Jerry Snitselaar) [2181397]
- iommu/iova: change IOVA_MAG_SIZE to 127 to save memory (Jerry Snitselaar) [2181397]
- iommu/iova: Fix alloc iova overflows issue (Jerry Snitselaar) [2181397]
- iova: Remove iovad->rcaches check in iova_rcache_get() (Jerry Snitselaar) [2181397]
- iova: Remove magazine BUG_ON() checks (Jerry Snitselaar) [2181397]
- iova: Remove some magazine pointer NULL checks (Jerry Snitselaar) [2181397]
- swiotlb: fix a braino in the alignment check fix (Jerry Snitselaar) [2181397]
- swiotlb: fix slot alignment checks (Jerry Snitselaar) [2181397]
- swiotlb: use wrap_area_index() instead of open-coding it (Jerry Snitselaar) [2181397]
- swiotlb: fix the deadlock in swiotlb_do_find_slots (Jerry Snitselaar) [2181397]
- swiotlb: mark swiotlb_memblock_alloc() as __init (Jerry Snitselaar) [2181397]
- swiotlb: remove swiotlb_max_segment (Jerry Snitselaar) [2181397]
- swiotlb: reduce the swiotlb buffer size on allocation failure (Jerry Snitselaar) [2181397]
- swiotlb: replace kmap_atomic() with memcpy_{from,to}_page() (Jerry Snitselaar) [2181397]
- swiotlb: don't panic! (Jerry Snitselaar) [2181397]
- iommu/vt-d: Avoid superfluous IOTLB tracking in lazy mode (Jerry Snitselaar) [2175620]
- iommu/amd: Add map/unmap_pages() iommu_domain_ops callback support (Jerry Snitselaar) [2181397]
- iommu/amd/io-pgtable: Implement unmap_pages io_pgtable_ops callback (Jerry Snitselaar) [2181397]
- iommu/amd/io-pgtable: Implement map_pages io_pgtable_ops callback (Jerry Snitselaar) [2181397]
- iommu/vt-d: Avoid unnecessary global DMA cache invalidation (Jerry Snitselaar) [2176983]
- iommu/vt-d: Avoid unnecessary global IRTE cache invalidation (Jerry Snitselaar) [2176983]
- iommu/vt-d: Fix buggy QAT device mask (Jerry Snitselaar) [2169568]
- iommu/vt-d: Add a fix for devices need extra dtlb flush (Jerry Snitselaar) [2169568]
- xfs: fix off-by-one-block in xfs_discard_folio() (Carlos Maiolino) [2112147]
- xfs: drop write error injection is unfixable, remove it (Carlos Maiolino) [2112147]
- xfs: use iomap_valid method to detect stale cached iomaps (Carlos Maiolino) [2112147]
- iomap: write iomap validity checks (Carlos Maiolino) [2112147]
- xfs: xfs_bmap_punch_delalloc_range() should take a byte range (Carlos Maiolino) [2112147]
- iomap: buffered write failure should not truncate the page cache (Carlos Maiolino) [2112147]
- iomap: Export page_cache_seek_hole_data (Carlos Maiolino) [2112147]
- xfs,iomap: move delalloc punching to iomap (Carlos Maiolino) [2112147]
- xfs: use byte ranges for write cleanup ranges (Carlos Maiolino) [2112147]
- xfs: punching delalloc extents on write failure is racy (Carlos Maiolino) [2112147]
- xfs: write page faults in iomap are not buffered writes (Carlos Maiolino) [2112147]
- iomap: iomap_read_inline_data cleanup (Carlos Maiolino) [2112147]
- iomap: Fix inline extent handling in iomap_readpage (Carlos Maiolino) [2112147]
- iomap: constify iomap_iter_srcmap (Carlos Maiolino) [2112147]
- iomap: rework unshare flag (Carlos Maiolino) [2112147]
- iomap: pass an iomap_iter to various buffered I/O helpers (Carlos Maiolino) [2112147]
- iomap: remove iomap_apply (Carlos Maiolino) [2112147]
- fsdax: Fix infinite loop in dax_iomap_rw() (Carlos Maiolino) [2112147]
- fsdax: switch dax_iomap_rw to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_swapfile_activate to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_seek_data to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_seek_hole to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_bmap to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_fiemap to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch __iomap_dio_rw to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: support REQ_OP_ZONE_APPEND (Carlos Maiolino) [2112147]
- iomap: add a filesystem hook for direct I/O bio submission (Carlos Maiolino) [2112147]
- iomap: switch iomap_page_mkwrite to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_zero_range to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: Change calling convention for zeroing (Carlos Maiolino) [2112147]
- iomap: switch iomap_file_unshare to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch iomap_file_buffered_write to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: switch readahead and readpage to use iomap_iter (Carlos Maiolino) [2112147]
- iomap: add the new iomap_iter model (Carlos Maiolino) [2112147]
- iomap: fix the iomap_readpage_actor return value for inline data (Carlos Maiolino) [2112147]
- iomap: Support inline data with block size < page size (Carlos Maiolino) [2112147]
- fs: mark the iomap argument to __block_write_begin_int const (Carlos Maiolino) [2112147]
- fsdax: mark the iomap argument to dax_iomap_sector as const (Carlos Maiolino) [2112147]
- iomap: mark the iomap argument to iomap_read_page_sync const (Carlos Maiolino) [2112147]
- iomap: mark the iomap argument to iomap_read_inline_data const (Carlos Maiolino) [2112147]
- iomap: mark the iomap argument to iomap_inline_data_valid const (Carlos Maiolino) [2112147]
- iomap: mark the iomap argument to iomap_inline_data const (Carlos Maiolino) [2112147]
- iomap: mark the iomap argument to iomap_sector const (Carlos Maiolino) [2112147]
- ipv6: Fix an uninit variable access bug in __ip6_make_skb() (Hangbin Liu) [2185798]
- ipv6: Fix tcp socket connection with DSCP. (Hangbin Liu) [2185798]
- ipv6: Fix datagram socket connection with DSCP. (Hangbin Liu) [2185798]
- ipv6: avoid use-after-free in ip6_fragment() (Hangbin Liu) [2185798]
- ipv6: addrlabel: fix infoleak when sending struct ifaddrlblmsg to network (Hangbin Liu) [2185798]
- ipv6: fix WARNING in ip6_route_net_exit_late() (Hangbin Liu) [2185798]
- ipv6: ensure sane device mtu in tunnels (Hangbin Liu) [2185798]
- KVM: arm64: PMU: Restore the guest's EL0 event counting after migration (Shaoqin Huang) [2175146]
- KVM: arm64: Retry fault if vma_lookup() results become invalid (Shaoqin Huang) [2175146]
- KVM: arm64: PMU: Don't save PMCR_EL0.{C,P} for the vCPU (Shaoqin Huang) [2175146]
- KVM: arm64: PMU: Fix GET_ONE_REG for vPMC regs to return the current value (Shaoqin Huang) [2175146]
- KVM: arm64: timers: Convert per-vcpu virtual offset to a global value (Shaoqin Huang) [2175146]
- KVM: arm64: Fix non-kerneldoc comments (Shaoqin Huang) [2175146]
- arm64/sysreg: clean up some inconsistent indenting (Shaoqin Huang) [2175146]
- KVM: arm64: timers: Don't BUG() on unhandled timer trap (Shaoqin Huang) [2175146]
- KVM: arm64: Reduce overhead of trapped timer sysreg accesses (Shaoqin Huang) [2175146]
- KVM: arm64: Don't arm a hrtimer for an already pending timer (Shaoqin Huang) [2175146]
- KVM: arm64: Fix S1PTW handling on RO memslots (Shaoqin Huang) [2175146]
- KVM: arm64: Fix typo in comment (Shaoqin Huang) [2175146]
- KVM: arm64: Fix pvtime documentation (Shaoqin Huang) [2175146]
- KVM: arm64: Fix PAR_TO_HPFAR() to work independently of PA_BITS. (Shaoqin Huang) [2175146]
- KVM: arm64: nvhe: Fix build with profile optimization (Shaoqin Huang) [2175146]
- fuse: wait for writepages in syncfs (Brian Foster) [2185834]
- virtio_fs: Modify format for virtio_fs_direct_access (Brian Foster) [2185834]
- virtiofs: delete unused parameter for virtio_fs_cleanup_vqs (Brian Foster) [2185834]
- virtiofs: use strscpy for copying the queue name (Brian Foster) [2185834]
- virtiofs: propagate sync() to file server (Brian Foster) [2185834]
- fuse: add a flag FUSE_SETXATTR_ACL_KILL_SGID to kill SGID (Brian Foster) [2185834]
- fuse: extend FUSE_SETXATTR request (Brian Foster) [2185834]
- virtiofs: fix userns (Brian Foster) [2185834]
- virtiofs: remove useless function (Brian Foster) [2185834]
- virtiofs: split requests that exceed virtqueue size (Brian Foster) [2185834]
- virtiofs: fix memory leak in virtio_fs_probe() (Brian Foster) [2185834]
- virtio_fs: convert to LE accessors (Brian Foster) [2185834]
- dmaengine: use sysfs_emit() to instead of scnprintf() (Jerry Snitselaar) [2181398]
- dmaengine: Simplify dmaenginem_async_device_register() function (Jerry Snitselaar) [2181398]
- dmaengine: idma64: Update bytes_transferred field (Jerry Snitselaar) [2181398]
- dmaengine: dw: Move check for paused channel to dwc_get_residue() (Jerry Snitselaar) [2181398]
- dmaengine: ptdma: check for null desc before calling pt_cmd_callback (Jerry Snitselaar) [2181398]
- dmaengine: idxd: Fix default allowed read buffers value in group (Jerry Snitselaar) [2181398]
- dmaengine: idxd: Set traffic class values in GRPCFG on DSA 2.0 (Jerry Snitselaar) [2181398]
- ptdma: pt_core_execute_cmd() should use spinlock (Jerry Snitselaar) [2181398]
- dmaengine: Fix double increment of client_count in dma_chan_get() (Jerry Snitselaar) [2181398]
- dmaengine: ioat: stop mod_timer from resurrecting deleted timer in __cleanup() (Jerry Snitselaar) [2153929]
- cifs: set a minimum of 120s for next dns resolution (Ronnie Sahlberg) [2182867]
- cifs: use the expiry output of dns_query to schedule next resolution (Ronnie Sahlberg) [2182867]
- cifs: sanitize paths in cifs_update_super_prepath. (Ronnie Sahlberg) [2182472]
- redhat/configs: Fix incorrect configs location and content (Vladis Dronov)
- scsi: megaraid_sas: Fix double kfree() (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Fix fw_crash_buffer_show() (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Fix crash after a double completion (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Driver version update to 07.725.01.00-rc1 (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Add crash dump mode capability bit in MFI capabilities (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Update max supported LD IDs to 240 (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Add flexible array member for SGLs (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Fix some spelling mistakes in comment (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Remove unnecessary kfree() (Tomas Henzl) [2163670]
- scsi: megaraid_sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2163670]
- scsi: megaraid: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Tomas Henzl) [2163670]
- scsi: ses: Handle enclosure with just a primary component gracefully (Tomas Henzl) [2188481]
- ipvlan: hold lower dev to avoid possible use-after-free (Davide Caratti) [2188055]
- net: macvlan: Use built-in RCU list checking (Davide Caratti) [2188055]
- x86/split_lock: Enumerate architectural split lock disable bit (Prarit Bhargava) [2123535]
- bpf: bpf_fib_lookup should not return neigh in NUD_FAILED state (Yauheni Kaliuta) [2175160]
- hwmon: (coretemp) avoid RDMSR interrupts to isolated CPUs (Marcelo Tosatti) [2158707]
- scsi: target: iscsi: Handle abort for WRITE_PENDING cmds (Maurizio Lombardi) [2156588]
- scsi: target: iscsit: Fix TAS handling during conn cleanup (Maurizio Lombardi) [2156588]

* Tue May 02 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-490.el8]
- RDMA/cma: Distinguish between sockaddr_in and sockaddr_in6 by size (Kamal Heib) [2170083]
- RDMA/umem: Remove unused 'work' member from struct ib_umem (Kamal Heib) [2170083]
- RDMA/restrack: Correct spelling (Kamal Heib) [2170083]
- scripts/spelling.txt: add "exsits" pattern and fix typo instances (Kamal Heib) [2170083]
- RDMA/cma: Refactor the inbound/outbound path records process flow (Kamal Heib) [2170083]
- RDMA/core: Refactor rdma_bind_addr (Kamal Heib) [2170083]
- IB/IPoIB: Fix legacy IPoIB due to wrong number of queues (Kamal Heib) [2170076]
- RDMA/core: Fix ib block iterator counter overflow (Kamal Heib) [2170076]
- RDMA/srp: Move large values to a new enum for gcc13 (Kamal Heib) [2170076]
- IB/IPoIB: Fix queue count inconsistency for PKEY child interfaces (Kamal Heib) [2170076]
- RDMA/cm: Make QP FLUSHABLE for supported device (Kamal Heib) [2170076]
- RDMA: Extend RDMA kernel verbs ABI to support flush (Kamal Heib) [2170076]
- RDMA: Extend RDMA user ABI to support flush (Kamal Heib) [2170076]
- RDMA/cma: Change RoCE packet life time from 18 to 16 (Kamal Heib) [2170076]
- RDMA/srp: Fix error return code in srp_parse_options() (Kamal Heib) [2170076]
- RDMA: Extend RDMA kernel ABI to support atomic write (Kamal Heib) [2170076]
- RDMA: Extend RDMA user ABI to support atomic write (Kamal Heib) [2170076]
- RDMA/umem: remove FOLL_FORCE usage (Kamal Heib) [2170076]
- RDMA/nldev: Fix failure to send large messages (Kamal Heib) [2170076]
- RDMA/nldev: Add NULL check to silence false warnings (Kamal Heib) [2170076]
- RDMA/nldev: Add checks for nla_nest_start() in fill_stat_counter_qps() (Kamal Heib) [2170076]
- IB/isert: use the ISCSI_LOGIN_CURRENT_STAGE macro (Kamal Heib) [2170076]
- RDMA/nldev: Return "-EAGAIN" if the cm_id isn't from expected port (Kamal Heib) [2170076]
- RDMA/core: Make sure "ib_port" is valid when access sysfs node (Kamal Heib) [2170076]
- RDMA/restrack: Release MR restrack when delete (Kamal Heib) [2170076]
- IB/mad: Don't call to function that might sleep while in atomic context (Kamal Heib) [2170076]
- RDMA/core: Fix order of nldev_exit call (Kamal Heib) [2170076]
- RDMA/core: fix repeated words in comments (Kamal Heib) [2170076]
- IB/iser: open code iser_disconnected_handler (Kamal Heib) [2170076]
- IB/iser: add safety checks for state_mutex lock (Kamal Heib) [2170076]
- IB/iser: open code iser_conn_state_comp_exch (Kamal Heib) [2170076]
- RDMA/opa_vnic: fix spelling typo in comment (Kamal Heib) [2170076]
- RDMA/core: return -EOPNOSUPP for ODP unsupported device (Kamal Heib) [2170076]
- IB/uverbs: fix the typo of optional (Kamal Heib) [2170076]
- treewide: use get_random_u32() when possible (Kamal Heib) [2170070]
- treewide: use prandom_u32_max() when possible, part 1 (Kamal Heib) [2170070]
- RDMA/core: Clean up a variable name in ib_create_srq_user() (Kamal Heib) [2170070]
- RDMA/srp: Support more than 255 rdma ports (Kamal Heib) [2170070]
- RDMA/cm: Use DLID from inbound/outbound PathRecords as the datapath DLID (Kamal Heib) [2170070]
- RDMA/cma: Multiple path records support with netlink channel (Kamal Heib) [2170070]
- RDMA/core: Rename rdma_route.num_paths field to num_pri_alt_paths (Kamal Heib) [2170070]
- RDMA/srpt: Use flex array destination for memcpy() (Kamal Heib) [2170070]
- IB/cm: Refactor cm_insert_listen() and cm_find_listen() (Kamal Heib) [2170070]
- IB/cm: remove cm_id_priv->id.service_mask and service_mask parameter of cm_init_listen() (Kamal Heib) [2170070]
- IB/cm: Remove the service_mask parameter from ib_cm_listen() (Kamal Heib) [2170070]
- RDMA/core: Remove 'device' argument from rdma_build_skb() (Kamal Heib) [2170070]
- RDMA/srp: Use the attribute group mechanism for sysfs attributes (Kamal Heib) [2170070]
- RDMA/srp: Handle dev_set_name() failure (Kamal Heib) [2170070]
- RDMA/srp: Remove the srp_host.released completion (Kamal Heib) [2170070]
- RDMA/srp: Rework the srp_add_port() error path (Kamal Heib) [2170070]
- IB: move from strlcpy with unused retval to strscpy (Kamal Heib) [2170070]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Kamal Heib) [2170070]
- RDMA/core: Delete IPsec flow action logic from the core (Kamal Heib) [2170070]
- net: Don't include filter.h from net/sock.h (Kamal Heib) [2170070]
- scsi: qla2xxx: Synchronize the IOCB count to be in order (Nilesh Javali) [2164947]
- scsi: qla2xxx: Perform lockless command completion in abort path (Nilesh Javali) [2164947]
- scsi: qla2xxx: Use the proper SCSI midlayer interfaces for PI (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove the unused variable wwn (Nilesh Javali) [2164947]
- scsi: qla2xxx: Simplify if condition evaluation (Nilesh Javali) [2164947]
- scsi: qla2xxx: Use a variable for repeated mem_size computation (Nilesh Javali) [2164947]
- scsi: qla2xxx: Make qla_trim_buf() and __qla_adjust_buf() static (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix printk() format string (Nilesh Javali) [2164947]
- scsi: qla2xxx: Update version to 10.02.08.200-k (Nilesh Javali) [2164947]
- scsi: qla2xxx: Select qpair depending on which CPU post_cmd() gets called (Nilesh Javali) [2164947]
- scsi: qla2xxx: edif: Fix clang warning (Nilesh Javali) [2164947]
- scsi: qla2xxx: edif: Reduce memory usage during low I/O (Nilesh Javali) [2164947]
- scsi: qla2xxx: edif: Fix stall session after app start (Nilesh Javali) [2164947]
- scsi: qla2xxx: edif: Fix performance dip due to lock contention (Nilesh Javali) [2164947]
- scsi: qla2xxx: Relocate/rename vp map (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove dead code (GNN ID) (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove dead code (GPNID) (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove dead code (Nilesh Javali) [2164947]
- scsi: qla2xxx: Update version to 10.02.08.100-k (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix IOCB resource check warning (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove increment of interface err cnt (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix erroneous link down (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove unintended flag clearing (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix stalled login (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix exchange oversubscription for management commands (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix exchange oversubscription (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix DMA-API call trace on NVMe LS requests (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix link failure in NPIV environment (Nilesh Javali) [2164947]
- scsi: qla2xxx: Check if port is online before sending ELS (Nilesh Javali) [2164947]
- scsi: qla2xxx: Initialize vha->unknown_atio_[list, work] for NPIV hosts (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove duplicate of vha->iocb_work initialization (Nilesh Javali) [2164947]
- scsi: qla2xxx: Remove unused variable 'found_devs' (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix set-but-not-used variable warnings (Nilesh Javali) [2164947]
- scsi: qla2xxx: Fix memory leak in __qlt_24xx_handle_abts() (Nilesh Javali) [2164947]
- ethtool: eeprom: fix null-deref on genl_info in dump (Davide Caratti) [2188002]
- packet: do not set TP_STATUS_CSUM_VALID on CHECKSUM_COMPLETE (Davide Caratti) [2188002]
- af_key: Fix send_acquire race with pfkey_register (Davide Caratti) [2188002]
- net: llc: fix skb_over_panic (Davide Caratti) [2188002]
- inet_ecn: Fix endianness of checksum update when setting ECT(1) (Davide Caratti) [2188002]
- RDMA/irdma: Fix potential NULL-ptr-dereference (Kamal Heib) [2153377]
- RDMA/irdma: Split CQ handler into irdma_reg_user_mr_type_cq (Kamal Heib) [2153377]
- RDMA/irdma: Split QP handler into irdma_reg_user_mr_type_qp (Kamal Heib) [2153377]
- RDMA/irdma: Split mr alloc and free into new functions (Kamal Heib) [2153377]
- RDMA/irdma: Split MEM handler into irdma_reg_user_mr_type_mem (Kamal Heib) [2153377]
- RDMA/irdma: Remove extra ret variable in favor of existing err (Kamal Heib) [2153377]
- RDMA/irdma: Initialize net_type before checking it (Kamal Heib) [2153377]
- RDMA/irdma: Do not request 2-level PBLEs for CQ alloc (Kamal Heib) [2153377]
- RDMA/irdma: Fix RQ completion opcode (Kamal Heib) [2153377]
- RDMA/irdma: Fix inline for multiple SGE's (Kamal Heib) [2153377]
- bnxt_en: Fix mqprio and XDP ring checking logic (Ken Cox) [2159222]
- bnxt: Do not read past the end of test names (Ken Cox) [2159222]
- bnxt: report FEC block stats via standard interface (Ken Cox) [2159222]
- bnxt_en: Remove debugfs when pci_register_driver failed (Ken Cox) [2159222]
- bnxt_en: update RSS config using difference algorithm (Ken Cox) [2159222]
- bnxt_en: refactor VNIC RSS update functions (Ken Cox) [2159222]
- bnxt_en: fix potentially incorrect return value for ndo_rx_flow_steer (Ken Cox) [2159222]
- bnxt_en: Fix possible crash in bnxt_hwrm_set_coal() (Ken Cox) [2159222]
- bnxt_en: fix the handling of PCIE-AER (Ken Cox) [2159222]
- bnxt_en: refactor bnxt_cancel_reservations() (Ken Cox) [2159222]
- bnxt_en: check and resize NVRAM UPDATE entry before flashing (Ken Cox) [2159222]
- bnxt_en: Update firmware interface to 1.10.2.118 (Ken Cox) [2159222]
- bnxt_en: replace reset with config timestamps (Ken Cox) [2159222]
- hugetlbfs: don't delete error page from pagecache (Aristeu Rozanski) [2188334]
- mm: shmem: don't truncate page if memory failure happens (Aristeu Rozanski) [2188334]
- mm: hwpoison: handle non-anonymous THP correctly (Aristeu Rozanski) [2188334]
- mm: hwpoison: refactor refcount check handling (Aristeu Rozanski) [2188334]
- scsi: qedf: Remove set but unused variable 'page' (Nilesh Javali) [2164955]
- scsi: qedf: Fix a UAF bug in __qedf_probe() (Nilesh Javali) [2164955]
- xfs: don't use BMBT btree split workers for IO completion (Carlos Maiolino) [2127493]
- tools/power turbostat: Add support for MeteorLake platforms (Derek Barbosa) [2153966]
- x86/bugs: Workaround for incorrectly set X86_BUG_RETBLEED under VMware (Waiman Long) [2184343]

* Thu Apr 27 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-489.el8]
- nvmet: fix workqueue MEM_RECLAIM flushing dependency (Maurizio Lombardi) [2187618]
- nvmet: use a private workqueue instead of the system workqueue (Maurizio Lombardi) [2187618]
- nvme: fix discard support without oncs (Maurizio Lombardi) [2187618]
- nvme-pci: fix timeout request state check (Maurizio Lombardi) [2187618]
- nvme: fix multipath crash caused by flush request when blktrace is enabled (Maurizio Lombardi) [2187618]
- nvme: return err on nvme_init_non_mdts_limits fail (Maurizio Lombardi) [2187618]
- nvme initialize core quirks before calling nvme_init_subsystem (Maurizio Lombardi) [2187618]
- nvmet: fix memory leak in nvmet_subsys_attr_model_store_locked (Maurizio Lombardi) [2187618]
- nvme: quiet user passthrough command errors (Maurizio Lombardi) [2187618]
- nvme-tcp: fix possible circular locking when deleting a controller under memory pressure (Maurizio Lombardi) [2187618]
- nvme-hwmon: kmalloc the NVME SMART log buffer (Maurizio Lombardi) [2187618]
- nvme-hwmon: consistently ignore errors from nvme_hwmon_init (Maurizio Lombardi) [2187618]
- nvme-pci: disable write zeroes on various Kingston SSD (Maurizio Lombardi) [2187618]
- nvme-pci: avoid the deepest sleep state on ZHITAI TiPro5000 SSDs (Maurizio Lombardi) [2187618]
- nvme-rdma: fix possible hang caused during ctrl deletion (Maurizio Lombardi) [2187618]
- nvmet-tcp: add bounds check on Transfer Tag (Maurizio Lombardi) [2187618]
- nvmet-tcp: handle ICReq PDU received in NVMET_TCP_Q_LIVE state (Maurizio Lombardi) [2187618]
- nvme-pci: set min_align_mask before calculating max_hw_sectors (Maurizio Lombardi) [2187618]
- nvme: enumerate controller flags (Maurizio Lombardi) [2187618]
- nvme: ensure subsystem reset is single threaded (Maurizio Lombardi) [2187618]
- nvme: copy firmware_rev on each init (Maurizio Lombardi) [2187618]
- nvme: restrict management ioctls to admin (Maurizio Lombardi) [2187618]
- nvme: consider also host_iface when checking ip options (Maurizio Lombardi) [2187618]
- nvme: move from strlcpy with unused retval to strscpy (Maurizio Lombardi) [2187618]
- nvme: add comment for unaligned "fake" nqn (Maurizio Lombardi) [2187618]
- nvme-pci: disable Write Zeroes on Phison E3C/E4C (Maurizio Lombardi) [2187618]
- nvmet: fix mar and mor off-by-one errors (Maurizio Lombardi) [2187618]
- nvmet: fix a use-after-free (Maurizio Lombardi) [2187618]
- nvmet-tcp: fix unhandled tcp states in nvmet_tcp_state_change() (Maurizio Lombardi) [2187618]
- nvme-fabrics: Fix a typo in an error message (Maurizio Lombardi) [2187618]
- nvme-fabrics: parse nvme connect Linux error codes (Maurizio Lombardi) [2187618]
- nvmet-tcp: fix lockdep complaint on nvmet_tcp_wq flush during queue teardown (Maurizio Lombardi) [2187618]
- nvme: rename nvme_validate_or_alloc_ns to nvme_scan_ns (Maurizio Lombardi) [2187618]
- nvme: catch -ENODEV from nvme_revalidate_zones again (Maurizio Lombardi) [2187618]
- nvme-pci: print the command name of aborted commands (Maurizio Lombardi) [2187618]
- nvme: use command_id instead of req->tag in trace_nvme_complete_rq() (Maurizio Lombardi) [2187618]
- nvme-pci: use nvme core helper to cancel requests in tagset (Maurizio Lombardi) [2187618]
- nvme-tcp: use in-capsule data for I/O connect (Maurizio Lombardi) [2187618]
- nvme-rdma: remove timeout for getting RDMA-CM established event (Maurizio Lombardi) [2187618]
- nvmet: parse fabrics commands on io queues (Maurizio Lombardi) [2187618]
- nvme-fabrics: decode 'authentication required' connect error (Maurizio Lombardi) [2187618]
- nvme-loop: use nvme core helpers to cancel all requests in a tagset (Maurizio Lombardi) [2187618]
- nvme: handle the persistent internal error AER (Maurizio Lombardi) [2187618]
- nvme: remove a double word in a comment (Maurizio Lombardi) [2187618]
- nvme: use struct group for generic command dwords (Maurizio Lombardi) [2187618]
- nvme-pci: fix freeze accounting for error handling (Maurizio Lombardi) [2187618]
- nvmet-tcp: fix regression in data_digest calculation (Maurizio Lombardi) [2187618]
- nvme: add a bogus subsystem NQN quirk for Micron MTFDKBA2T0TFH (Maurizio Lombardi) [2187618]
- nvme-pci: disable write zeros support on UMIC and Samsung SSDs (Maurizio Lombardi) [2187618]
- nvme-pci: avoid the deepest sleep state on ZHITAI TiPro7000 SSDs (Maurizio Lombardi) [2187618]
- nvme-pci: add trouble shooting steps for timeouts (Maurizio Lombardi) [2187618]
- nvme: add device name to warning in uuid_show() (Maurizio Lombardi) [2187618]
- nvmet: fix typo in comment (Maurizio Lombardi) [2187618]
- nvme: set controller enable bit in a separate write (Maurizio Lombardi) [2187618]
- nvme: set non-mdts limits in nvme_scan_work (Maurizio Lombardi) [2187618]
- nvme-pci: harden drive presence detect in nvme_dev_disable() (Maurizio Lombardi) [2187618]
- nvme-pci: fix a NULL pointer dereference in nvme_alloc_admin_tags (Maurizio Lombardi) [2187618]
- nvme: mark internal passthru request RQF_QUIET (Maurizio Lombardi) [2187618]
- nvme: remove unneeded include from constants file (Maurizio Lombardi) [2187618]
- nvme: set dma alignment to dword (Maurizio Lombardi) [2187618]
- nvme: fix interpretation of DMRSL (Maurizio Lombardi) [2187618]
- ixgbe: add double of VLAN header when computing the max MTU (Ken Cox) [2153372]
- ixgbe: allow to increase MTU to 3K with XDP enabled (Ken Cox) [2153372]
- ixgbe: Filter out spurious link up indication (Ken Cox) [2153372]
- ixgbe: XDP: fix checker warning from rcu pointer (Ken Cox) [2153372]
- ixgbe: fix pci device refcount leak (Ken Cox) [2153372]
- ixgbe: change MAX_RXD/MAX_TXD based on adapter type (Ken Cox) [2153372]
- tracing: kprobes: Prohibit probing on notrace function (Mukesh Chaurasiya) [2183475]
- powerpc/kprobes: Ignore traps that happened in real mode (Mukesh Chaurasiya) [2183475]
- nvme-rdma: handle number of queue changes (Kamal Heib) [2160665]
- nvme-rdma: remove timeout for getting RDMA-CM established event (Kamal Heib) [2160665]
- nvmet-rdma: fix kernel-doc warning for nvmet_rdma_device_removal (Kamal Heib) [2160665]
- net: mpls: fix stale pointer if allocation fails during device rename (Guillaume Nault) [2184956] {CVE-2023-26545}
- block: don't set GD_NEED_PART_SCAN if scan partition failed (Ming Lei) [2151112]
- block: fix wrong mode for blkdev_put() from disk_scan_partitions() (Ming Lei) [2151112]
- block: fix scan partition for exclusively open device again (Ming Lei) [2151112]
- mm: swap: get rid of livelock in swapin readahead (Aristeu Rozanski) [2035182 2182084]
- redhat: require reasonably recent grub2 _only_ if grub2 is already installed (Denys Vlasenko) [2183531]
- i40e: Fix kernel crash during reboot when adapter is in recovery mode (Stefan Assmann) [2153348]
- i40e: add double of VLAN header when computing the max MTU (Stefan Assmann) [2153348]
- i40e: Add checking for null for nlmsg_find_attr() (Stefan Assmann) [2153348]
- net/i40e: Replace 0-length array with flexible array (Stefan Assmann) [2153348]
- i40e: use ERR_PTR error print in i40e messages (Stefan Assmann) [2153348]
- i40e: use int for i40e_status (Stefan Assmann) [2153348]
- i40e: Remove string printing for i40e_status (Stefan Assmann) [2153348]
- i40e: Remove unused i40e status codes (Stefan Assmann) [2153348]
- net/sched: move struct tc_mqprio_qopt_offload from pkt_cls.h to pkt_sched.h (Stefan Assmann) [2153348]
- i40e: Remove redundant pci_enable_pcie_error_reporting() (Stefan Assmann) [2153348]
- virtchnl: i40e/iavf: rename iwarp to rdma (Stefan Assmann) [2153348]
- treewide: Convert del_timer*() to timer_shutdown*() (Stefan Assmann) [2153348]
- i40e: allow toggling loopback mode via ndo_set_features callback (Stefan Assmann) [2153348]
- i40e: Disallow ip4 and ip6 l4_4_bytes (Stefan Assmann) [2153348]
- i40e: Fix for VF MAC address 0 (Stefan Assmann) [2153348]
- i40e: Fix not setting default xps_cpus after reset (Stefan Assmann) [2153348]
- dm: fix __send_duplicate_bios() to always allow for splitting IO (Benjamin Marzinski) [2183559]
- dm: fix improper splitting for abnormal bios (Benjamin Marzinski) [2183559]
- dm: remove unnecessary (void*) conversion in event_callback() (Benjamin Marzinski) [2179207]
- dm ioctl: remove unnecessary check when using dm_get_mdptr() (Benjamin Marzinski) [2179207]
- dm ioctl: assert _hash_lock is held in __hash_remove (Benjamin Marzinski) [2179207]
- dm cache: add cond_resched() to various workqueue loops (Benjamin Marzinski) [2179207]
- dm thin: add cond_resched() to various workqueue loops (Benjamin Marzinski) [2179207]
- dm: add cond_resched() to dm_wq_work() (Benjamin Marzinski) [2179207]
- dm: update targets using system workqueues to use a local workqueue (Benjamin Marzinski) [2179207]
- dm: remove flush_scheduled_work() during local_exit() (Benjamin Marzinski) [2179207]
- dm: declare variables static when sensible (Benjamin Marzinski) [2179207]
- dm ioctl: prefer strscpy() instead of strlcpy() (Benjamin Marzinski) [2179207]
- dm: avoid 'do {} while(0)' loop in single statement macros (Benjamin Marzinski) [2179207]
- dm: favour __packed versus "__attribute__ ((packed))" (Benjamin Marzinski) [2179207]
- dm: favour __aligned(N) versus "__attribute__ (aligned(N))" (Benjamin Marzinski) [2179207]
- dm: adjust EXPORT_SYMBOL() to follow functions immediately (Benjamin Marzinski) [2179207]
- dm block-manager: avoid not required parentheses (Benjamin Marzinski) [2179207]
- dm: send just one event on resize, not two (Benjamin Marzinski) [2179207]
- dm table: check that a dm device doesn't reference itself (Benjamin Marzinski) [2179207]
- dm raid: fix some spelling mistakes in comments (Benjamin Marzinski) [2179207]
- dm verity: stop using WQ_UNBOUND for verify_wq (Benjamin Marzinski) [2179207]
- dm integrity: Remove bi_sector that's only used by commented debug code (Benjamin Marzinski) [2179207]
- dm crypt: Slightly simplify crypt_set_keyring_key() (Benjamin Marzinski) [2179207]
- dm ioctl: drop always-false condition (Benjamin Marzinski) [2179207]
- dm flakey: fix logic when corrupting a bio (Benjamin Marzinski) [2179207]
- dm flakey: fix a bug with 32-bit highmem systems (Benjamin Marzinski) [2179207]
- dm flakey: don't corrupt the zero page (Benjamin Marzinski) [2179207]
- dm cache: Add some documentation to dm-cache-background-tracker.h (Benjamin Marzinski) [2179207]
- dm cache: free background tracker's queued work in btracker_destroy (Benjamin Marzinski) [2179207]
- dm ioctl: fix a couple ioctl codes (Benjamin Marzinski) [2179207]
- dm ioctl: a small code cleanup in list_version_get_info (Benjamin Marzinski) [2179207]
- sfc: include vport_id in filter spec hash and equal() (Íñigo Huguet) [2159251]
- ptp: convert remaining drivers to adjfine interface (Íñigo Huguet) [2159251]
- sfc: Use kmap_local_page() instead of kmap_atomic() (Íñigo Huguet) [2159251]
- sfc: use sysfs_emit() to instead of scnprintf() (Íñigo Huguet) [2159251]
- selftests: forwarding: add tunnel_key "nofrag" test case (Davide Caratti) [2103797]
- selftests: tc-testing: add tunnel_key "nofrag" test case (Davide Caratti) [2103797]
- selftests: tc-testing: add "depends_on" property to skip tests (Davide Caratti) [2103797]
- net/sched: act_tunnel_key: add support for "don't fragment" (Davide Caratti) [2103797]
- e1000e: Fix TX dispatch condition (Ken Cox) [2153313]
- e1000e: Separate MTP board type from ADP (Ken Cox) [2153313]
- drivers/net/ethernet/e1000e: check return value of e1e_rphy() (Ken Cox) [2153313]
- ipvs: add sysctl_run_estimation to support disable estimation (Hangbin Liu) [2182003]
- scsi: ses: Don't attach if enclosure has no components (Tomas Henzl) [1975026]
- scsi: ses: Fix slab-out-of-bounds in ses_intf_remove() (Tomas Henzl) [1975026]
- scsi: ses: Fix possible desc_ptr out-of-bounds accesses (Tomas Henzl) [1975026]
- scsi: ses: Fix possible addl_desc_ptr out-of-bounds accesses (Tomas Henzl) [1975026]
- scsi: ses: Fix slab-out-of-bounds in ses_enclosure_data_process() (Tomas Henzl) [1975026]
- vmxnet3: move rss code block under eop descriptor (Izabela Bakollari) [2172579]

* Fri Apr 21 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-488.el8]
- crypto: qat - add support for 402xx devices (Vladis Dronov) [2144529]
- crypto: qat - drop log level of msg in get_instance_node() (Vladis Dronov) [2144529]
- crypto: qat - fix out-of-bounds read (Vladis Dronov) [2144529]
- Documentation: qat: change kernel version (Vladis Dronov) [2144529]
- crypto: qat - add qat_zlib_deflate (Vladis Dronov) [2144529]
- crypto: qat - extend buffer list logic interface (Vladis Dronov) [2144529]
- crypto: qat - fix spelling mistakes from 'bufer' to 'buffer' (Vladis Dronov) [2144529]
- crypto: qat - add resubmit logic for decompression (Vladis Dronov) [2144529]
- crypto: acomp - define max size for destination (Vladis Dronov) [2144529]
- crypto: qat - enable deflate for QAT GEN4 (Vladis Dronov) [2144529]
- crypto: qat - expose deflate through acomp api for QAT GEN2 (Vladis Dronov) [2144529]
- crypto: qat - rename and relocate GEN2 config function (Vladis Dronov) [2144529]
- crypto: qat - relocate qat_algs_alloc_flags() (Vladis Dronov) [2144529]
- crypto: qat - relocate backlog related structures (Vladis Dronov) [2144529]
- crypto: qat - extend buffer list interface (Vladis Dronov) [2144529]
- crypto: qat - generalize crypto request buffers (Vladis Dronov) [2144529]
- crypto: qat - change bufferlist logic interface (Vladis Dronov) [2144529]
- crypto: qat - rename bufferlist functions (Vladis Dronov) [2144529]
- crypto: qat - relocate bufferlist logic (Vladis Dronov) [2144529]
- crypto: qat - Use helper to set reqsize (Vladis Dronov) [2144529]
- crypto: kpp - Add helper to set reqsize (Vladis Dronov) [2144529]
- crypto: qat - fix error return code in adf_probe (Vladis Dronov) [2144529]
- crypto: qat - remove ADF_STATUS_PF_RUNNING flag from probe (Vladis Dronov) [2144529]
- selftests: net: rps_default_mask.sh: delete veth link specifically (Hangbin Liu) [2185801]
- selftests: net: devlink_port_split.py: skip test if no suitable device available (Hangbin Liu) [2185801]
- selftests: mirror_gre_bridge_1q: Avoid changing PVID while interface is operational (Hangbin Liu) [2185801]
- selftests/tls: Add {} to avoid static checker warning (Hangbin Liu) [2185801]
- selftests: nft_nat: ensuring the listening side is up before starting the client (Hangbin Liu) [2185801]
- selftest: fib_tests: Always cleanup before exit (Hangbin Liu) [2185801]
- selftests/net: Interpret UDP_GRO cmsg data as an int value (Hangbin Liu) [2185801]
- selftests: forwarding: lib: quote the sysctl values (Hangbin Liu) [2185801]
- selftests: net: udpgso_bench_tx: Cater for pending datagrams zerocopy benchmarking (Hangbin Liu) [2185801]
- selftests: net: udpgso_bench: Fix racing bug between the rx/tx programs (Hangbin Liu) [2185801]
- selftests: net: udpgso_bench_rx/tx: Stop when wrong CLI args are provided (Hangbin Liu) [2185801]
- selftests: net: udpgso_bench_rx: Fix 'used uninitialized' compiler warning (Hangbin Liu) [2185801]
- selftests: rtnetlink: correct xfrm policy rule in kci_test_ipsec_offload (Hangbin Liu) [2185801]
- selftests: forwarding: Fix failing tests with old libnet (Hangbin Liu) [2185801]
- powerpc/pseries/mobility: set NMI watchdog factor during an LPM (Mamatha Inamdar) [2186026]
- powerpc/watchdog: introduce a NMI watchdog's factor (Mamatha Inamdar) [2186026]
- watchdog: export lockup_detector_reconfigure (Mamatha Inamdar) [2186026]
- powerpc/mobility: wait for memory transfer to complete (Mamatha Inamdar) [2186026]
- crypto: drbg - Only fail when jent is unavailable in FIPS mode (Vladis Dronov) [2175712]
- crypto: jitter - permanent and intermittent health errors (Vladis Dronov) [2175712]
- crypto: jitter - quit sample collection loop upon RCT failure (Vladis Dronov) [2175712]
- crypto: jitter - don't limit ->health_failure check to FIPS mode (Vladis Dronov) [2175712]
- crypto: jitter - drop kernel-doc notation (Vladis Dronov) [2175712]
- selftests/livepatch: normalize sysctl error message (Julia Denham) [RHEL-256]
- livepatch: Skip livepatch tests if ftrace cannot be configured (Julia Denham) [RHEL-256]
- livepatch: Add a missing newline character in klp_module_coming() (Julia Denham) [RHEL-256]
- livepatch: fix race between fork and KLP transition (Julia Denham) [RHEL-256]
- scsi: bnx2i: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Nilesh Javali) [2164956]
- x86/xen: Split HVM vector callback setup and interrupt gate allocation (Prarit Bhargava) [2187810]
- s390/uaccess: add missing earlyclobber annotations to __clear_user() (Tobias Huschle) [2183078]
- s390/qeth: fix use-after-free in hsci (Tobias Huschle) [2183992]
- SUNRPC: Fix a server shutdown leak (Benjamin Coddington) [2166107]
- powerpc/pseries/vas: Ignore VAS update for DLPAR if copy/paste is not enabled (Mamatha Inamdar) [2184979]
- cnic: don't pass bogus GFP_ flags to dma_alloc_coherent (Nilesh Javali) [2164958]
- cnic: Use the bitmap API to allocate bitmaps (Nilesh Javali) [2164958]

* Tue Apr 18 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-487.el8]
- perf vendor events intel: Add uncore event list for Sapphirerapids (Michael Petlan) [2180657]
- perf vendor events intel: Add metrics for Sapphirerapids (Michael Petlan) [2180657]
- perf vendor events intel: Update core event list for Sapphirerapids (Michael Petlan) [2180657]
- perf vendor events intel: Add sapphirerapids events (Michael Petlan) [2180657]
- perf vendor events intel: Update metrics for Alderlake (Michael Petlan) [2180656]
- perf vendor events: Fix Alderlake metric groups (Michael Petlan) [2180656]
- perf vendor events intel: Add metrics for Alderlake (Michael Petlan) [2180656]
- perf/x86/rapl: Add support for Intel Raptor Lake (Michael Petlan) [2180654]
- perf/x86/intel: Add Cooper Lake stepping to isolation_ucodes[] (Michael Petlan) [2153896]
- perf/x86/intel/cstate: Add Emerald Rapids (Michael Petlan) [2156802]
- perf/x86/intel: Add Emerald Rapids (Michael Petlan) [2156802]
- perf/x86/intel/uncore: Add Emerald Rapids (Michael Petlan) [2156802]
- perf/x86/msr: Add Emerald Rapids (Michael Petlan) [2156802]
- perf/x86/msr: Add Sapphire Rapids CPU support (Michael Petlan) [2156802]
- perf/x86/intel/uncore: Add Meteor Lake support (Michael Petlan) [2177039]
- perf/x86/msr: Add Meteor Lake support (Michael Petlan) [2153962]
- perf/x86/cstate: Add Meteor Lake support (Michael Petlan) [2153962]
- perf/x86/intel: Support Architectural PerfMon Extension leaf (Michael Petlan) [2153962]
- x86/cpufeatures: Add Architectural PerfMon Extension bit (Michael Petlan) [2153962]
- perf/x86: Support Retire Latency (Michael Petlan) [2153962]
- perf/x86: Add Meteor Lake support (Michael Petlan) [2153962]
- perf: Add PMU_FORMAT_ATTR_SHOW (Michael Petlan) [2153962]
- mm/hugetlb: add dedicated func to get 'allowed' nodemask for current process (Rafael Aquini) [2153926]
- mm/hugetlb: simplify the calculation of variables (Rafael Aquini) [2153926]
- mm/mempolicy: fix lock contention on mems_allowed (Rafael Aquini) [2153926]
- mm/mempolicy: do not allow illegal MPOL_F_NUMA_BALANCING | MPOL_LOCAL in mbind() (Rafael Aquini) [2153926]
- mm/mempolicy.c: use in_task() in mempolicy_slab_node() (Rafael Aquini) [2153926]
- mm/mempolicy: unify the create() func for bind/interleave/prefer-many policies (Rafael Aquini) [2153926]
- mm/mempolicy: advertise new MPOL_PREFERRED_MANY (Rafael Aquini) [2153926]
- mm/hugetlb: add support for mempolicy MPOL_PREFERRED_MANY (Rafael Aquini) [2153926]
- mm/memplicy: add page allocation function for MPOL_PREFERRED_MANY policy (Rafael Aquini) [2153926]
- mm/mempolicy: add MPOL_PREFERRED_MANY for multiple preferred nodes (Rafael Aquini) [2153926]
- mm/mempolicy: use readable NUMA_NO_NODE macro instead of magic number (Rafael Aquini) [2153926]
- mm/mempolicy: unify the parameter sanity check for mbind and set_mempolicy (Rafael Aquini) [2153926]
- mm/mempolicy: use unified 'nodes' for bind/interleave/prefer policies (Rafael Aquini) [2153926]
- mm/mempolicy: don't handle MPOL_LOCAL like a fake MPOL_PREFERRED policy (Rafael Aquini) [2153926]
- mm/mempolicy: cleanup nodemask intersection check for oom (Rafael Aquini) [2153926]
- mm/mempolicy: fix mpol_misplaced kernel-doc (Rafael Aquini) [2153926]
- numa balancing: migrate on fault among multiple bound nodes (Rafael Aquini) [2153926]
- mm/hugetlb: add mempolicy check in the reservation routine (Rafael Aquini) [2153926]
- mm: remove unused alloc_page_vma_node() (Rafael Aquini) [2153926]
- mm/mempolicy: remove or narrow the lock on current (Rafael Aquini) [2153926]
- mm, mempolicy: fix uninit memory access (Rafael Aquini) [2153926]
- mm/mempool: minor coding style tweaks (Rafael Aquini) [2153926]
- mm: fix typos in comments (Rafael Aquini) [2153926]
- futex: Do not apply time namespace adjustment on FUTEX_LOCK_PI (Joel Savitz) [2170113]
- Revert 337f13046ff0 ("futex: Allow FUTEX_CLOCK_REALTIME with FUTEX_WAIT op") (Joel Savitz) [2170113]
- kernel, fs: Introduce and use set_restart_fn() and arch_set_restart_data() (Joel Savitz) [2170113]
- futex: Remove unneeded gotos (Joel Savitz) [2170113]
- rtmutex: Ensure that the top waiter is always woken up (Joel Savitz) [2170113]
- rtmutex: Add acquire semantics for rtmutex lock acquisition slow path (Joel Savitz) [2170113]
- locking/lockdep: Fix lockdep_init_map_*() confusion (Joel Savitz) [2170113]
- locking/lockdep: Avoid potential access of invalid memory in lock_class (Joel Savitz) [2170113]
- lockdep: Correct lock_classes index mapping (Joel Savitz) [2170113]
- locking/rtmutex: Squash self-deadlock check for ww_rt_mutex. (Joel Savitz) [2170113]
- locking/rtmutex: Fix incorrect condition in rtmutex_spin_on_owner() (Joel Savitz) [2170113]
- kallsyms: remove arch specific text and data check (Joel Savitz) [2170113]
- lockdep: Let lock_is_held_type() detect recursive read as read (Joel Savitz) [2170113]
- lockdep: Fix wait-type for empty stack (Joel Savitz) [2170113]
- locking/lockdep: Improve noinstr vs errors (Joel Savitz) [2170113]
- locking/lockdep: Correct calling tracepoints (Joel Savitz) [2170113]
- locking/percpu-rwsem: Use this_cpu_{inc,dec}() for read_count (Joel Savitz) [2170113]
- locking/ww_mutex: Fix runtime warning in the WW mutex selftest (Joel Savitz) [2170113]
- fortify: Do not cast to "unsigned char" (Josef Oskera) [2139487]
- fortify: Use SIZE_MAX instead of (size_t)-1 (Josef Oskera) [2139487]
- afs: Work around strnlen() oops with CONFIG_FORTIFIED_SOURCE=y (Josef Oskera) [2139487]
- net/mlx4_en: Introduce flexible array to silence overflow warning (Josef Oskera) [2139487]
- wusbcore: silence fortify warning (Josef Oskera) [2139487]
- skbuff: Switch structure bounds to struct_group() (Josef Oskera) [2139487]
- RDMA/cxgb4: fix accept failure due to increased cpl_t5_pass_accept_rpl size (Josef Oskera) [2139487]
- intel_th: msu: Use memset_startat() for clearing hw header (Josef Oskera) [2139487]
- dm integrity: Use struct_group() to zero struct journal_sector (Josef Oskera) [2139487]
- iw_cxgb4: Use memset_startat() for cpl_t5_pass_accept_rpl (Josef Oskera) [2139487]
- scsi: lpfc: Use struct_group() to initialize struct lpfc_cgn_info (Josef Oskera) [2139487]
- netfilter: conntrack: Use memset_startat() to zero struct nf_conn (Josef Oskera) [2139487]
- netfilter: conntrack: avoid gcc-10 zero-length-bounds warning (Josef Oskera) [2139487]
- thermal: int340x: Use struct_group() for memcpy() region (Josef Oskera) [2139487]
- net/af_iucv: Use struct_group() to zero struct iucv_sock region (Josef Oskera) [2139487]
- ipv6: Use memset_after() to zero rt6_info (Josef Oskera) [2139487]
- bnx2x: Use struct_group() for memcpy() region (Josef Oskera) [2139487]
- tracing: Use memset_startat() to zero struct trace_iterator (Josef Oskera) [2139487]
- xfrm: Use memset_after() to clear padding (Josef Oskera) [2139487]
- HID: roccat: Use struct_group() to zero kone_mouse_event (Josef Oskera) [2139487]
- scsi: ibmvscsi: Avoid multi-field memset() overflow by aiming at srp (Josef Oskera) [2139487]
- ipv4: ip_output.c: Fix out-of-bounds warning in ip_copy_addrs() (Josef Oskera) [2139487]
- media: ngene: Fix out-of-bounds bug in ngene_command_config_free_buf() (Josef Oskera) [2139487]
- s390/zcrypt: Switch to flexible array member (Josef Oskera) [2139487]
- s390/speculation: Use statically initialized const for instructions (Josef Oskera) [2139487]
- cifs: avoid extra calls in posix_info_parse (Josef Oskera) [2139487]
- x86/entry: Fixup bad_iret vs noinstr (Josef Oskera) [2139487]
- x86/traps: Mark fixup_bad_iret() noinstr (Josef Oskera) [2139487]
- x86/doublefault: Remove memmove() call (Josef Oskera) [2139487]
- tracing: Initialize iter->seq after zeroing in tracing_read_pipe() (Josef Oskera) [2139487]
- tracing: Silence GCC 9 array bounds warning (Josef Oskera) [2139487]
- fortify: Fix __compiletime_strlen() under UBSAN_BOUNDS_LOCAL (Josef Oskera) [2139487]
- fortify: Provide a memcpy trap door for sharp corners (Josef Oskera) [2139487]
- fortify: Make pointer arguments const (Josef Oskera) [2139487]
- fortify: Replace open-coded __gnu_inline attribute (Josef Oskera) [2139487]
- fortify: Update compile-time tests for Clang 14 (Josef Oskera) [2139487]
- fortify: Detect struct member overflows in memset() at compile-time (Josef Oskera) [2139487]
- fortify: Detect struct member overflows in memmove() at compile-time (Josef Oskera) [2139487]
- fortify: Detect struct member overflows in memcpy() at compile-time (Josef Oskera) [2139487]
- fortify: strlen: Avoid shadowing previous locals (Josef Oskera) [2139487]
- fortify: Add compile-time FORTIFY_SOURCE tests (Josef Oskera) [2139487]
- fortify: Allow strlen() and strnlen() to pass compile-time known lengths (Josef Oskera) [2139487]
- fortify: Prepare to improve strnlen() and strlen() warnings (Josef Oskera) [2139487]
- fortify: Fix dropped strcpy() compile-time write overflow check (Josef Oskera) [2139487]
- fortify: Explicitly disable Clang support (Josef Oskera) [2139487]
- fortify: Move remaining fortify helpers into fortify-string.h (Josef Oskera) [2139487]
- lib/string: Move helper functions out of string.c (Josef Oskera) [2139487]
- lib/string.c: update match_string() doc-strings with correct behavior (Josef Oskera) [2139487]
- string.h: move fortified functions definitions in a dedicated header. (Josef Oskera) [2139487]
- string.h: add FORTIFY coverage for strscpy() (Josef Oskera) [2139487]
- lib: string.h: detect intra-object overflow in fortified string functions (Josef Oskera) [2139487]
- lib: string_helpers: provide kfree_strarray() (Josef Oskera) [2139487]
- lib/string.c: implement stpcpy (Josef Oskera) [2139487]
- kernel-doc: core-api: include string.h into core-api (Josef Oskera) [2139487]
- docs/core-api: move *{str,mem}dup* to "String Manipulation" (Josef Oskera) [2139487]
- selftests/tc-testing: add show class case for red qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add show class case for prio qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add show class case for mq qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add show class case for ingress qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for qfq qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for netem qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for multiq qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for mqprio qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for htb qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for hfsc qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for fq_codel qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for dsmark qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for drr qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for cbs qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for cbq qdisc (Ivan Vecera) [2172130]
- selftests/tc-testing: add selftests for cake qdisc (Ivan Vecera) [2172130]
- net/sched: use tc_qdisc_stats_dump() in qdisc (Ivan Vecera) [2172130]
- net/sched: sch_api: add helper for tc qdisc walker stats dump (Ivan Vecera) [2172130]
- hwrng: core - use per-rng quality value instead of global setting (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - start and stop in-kernel rngd in separate function (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - do not bother to order list of devices by quality (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - credit entropy for low quality sources of randomness (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - break out of hwrng_fillfn if current rng is not trusted (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - only set cur_rng_set_by_user if it is working (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - use rng_fillbuf in add_early_randomness() (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - read() callback must be called for size of 32 or more bytes (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - explicit ordering of initcalls (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - Use DEVICE_ATTR_<RW|RO> macro (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - remove redundant initialization of variable err (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - convert sysfs sprintf/snprintf family to sysfs_emit (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - remove redundant initialization of variable ret (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - Fix use-after-free warning in hwrng_register() (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - move add_early_randomness() out of rng_mutex (Jose Ignacio Tornos Martinez) [2172884]
- hwrng: core - document the quality field (Jose Ignacio Tornos Martinez) [2172884]
- netfilter: nf_conntrack: allow early drop of offloaded UDP conns (Florian Westphal) [2183080]
- net/sched: act_ct: offload UDP NEW connections (Florian Westphal) [2183080]
- net/sched: act_ct: set ctinfo in meta action depending on ct state (Florian Westphal) [2183080]
- netfilter: flowtable: cache info of last offload (Florian Westphal) [2183080]
- netfilter: flowtable: allow unidirectional rules (Florian Westphal) [2183080]
- netfilter: flowtable: fixup UDP timeout depending on ct state (Florian Westphal) [2183080]
- ptp_clock: Let the ADJ_OFFSET interface respect the ADJ_NANO flag for PHC devices. (Íñigo Huguet) [2180896]
- ptp: Add adjust_phase to ptp_clock_caps capability. (Íñigo Huguet) [2180896]
- ptp: Add adjphase function to support phase offset control. (Íñigo Huguet) [2180896]
- kernfs: dont take d_lock on revalidate (Ian Kent) [2126350]
- kernfs: dont take i_lock on inode attr read (Ian Kent) [2126350]
- kernfs: remove redundant kernfs_rwsem declaration. (Ian Kent) [2126350]
- kernfs: fix potential NULL dereference in __kernfs_remove (Ian Kent) [2126350]
- kernfs: fix NULL dereferencing in kernfs_remove (Ian Kent) [2126350]
- kernfs: prevent early freeing of root node (Ian Kent) [2126350]
- kernfs: switch global kernfs_rwsem lock to per-fs lock (Ian Kent) [2126350]
- workqueue: Fold rebind_worker() within rebind_workers() (Valentin Schneider) [2088578]
- workqueue: Unbind kworkers before sending them to exit() (Valentin Schneider) [2088578]
- workqueue: Don't hold any lock while rcuwait'ing for !POOL_MANAGER_ACTIVE (Valentin Schneider) [2088578]
- workqueue: Convert the idle_timer to a timer + work_struct (Valentin Schneider) [2088578]
- workqueue: Factorize unbind/rebind_workers() logic (Valentin Schneider) [2088578]
- workqueue: Protects wq_unbound_cpumask with wq_pool_attach_mutex (Valentin Schneider) [2088578]
- workqueue: make sysfs of unbound kworker cpumask more clever (Valentin Schneider) [2088578]
- fuse: add feature flag for expire-only (Pavel Reichl) [2109496]
- fuse: add "expire only" mode to FUSE_NOTIFY_INVAL_ENTRY (Pavel Reichl) [2109496]
- fuse: extend init flags (Pavel Reichl) [2109496]
- wifi: iwlwifi: mvm: protect TXQ list manipulation (Jose Ignacio Tornos Martinez) [2152168]
- wifi: iwlwifi: mvm: fix mvmtxq->stopped handling (Jose Ignacio Tornos Martinez) [2152168]
- thunderbolt: Explicitly enable lane adapter hotplug events at startup (Desnes Nunes) [2130062]
- x86/tsc: Add option to force frequency recalibration with HW timer (Prarit Bhargava) [2100597]
- ovl: fix use after free in struct ovl_aio_req (Miklos Szeredi) [2176159] {CVE-2023-1252}

* Thu Apr 13 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-486.el8]
- mm/memremap: fix missing call to untrack_pfn() in pagemap_range() (Nico Pache) [2168370]
- arm64: mm: correct the inside linear map range during hotplug check (Nico Pache) [2168370]
- s390/mm: define arch_get_mappable_range() (Nico Pache) [2168370]
- arm64/mm: define arch_get_mappable_range() (Nico Pache) [2168370]
- mm/memory_hotplug: prevalidate the address range being added with platform (Nico Pache) [2168370]
- s390/extmem: return correct segment type in __segment_load() (Nico Pache) [2168370]
- s390/vmem: get rid of memory segment list (Nico Pache) [2168370]
- arm64/mm: Validate hotplug range before creating linear mapping (Nico Pache) [2168370]
- mm/truncate.c: make __invalidate_mapping_pages() static (Nico Pache) [2168370]
- powerpc/mm: fix "section_base" set but not used (Nico Pache) [2168370]
- powerpc: Avoid link stack corruption in misc asm functions (Nico Pache) [2168370]
- powerpc/booke: Avoid link stack corruption in several places (Nico Pache) [2168370]
- powerpc/mm: Fix lockup on kernel exec fault (Nico Pache) [2168370]
- x86: fix seq_file iteration for pat/memtype.c (Nico Pache) [2168370]
- powerpc/book3s64/hash: Add cond_resched to avoid soft lockup warning (Nico Pache) [2168370]
- powerpc/nvdimm: Update vmemmap_populated to check sub-section range (Nico Pache) [2168370]
- powerpc/pseries: Fix cpu_hotplug_lock acquisition in resize_hpt() (Nico Pache) [2168370]
- x86/mm: Sync also unmappings in vmalloc_sync_all() (Nico Pache) [2168370]
- Fix page corruption caused by racy check in __free_pages (Nico Pache) [2168370]
- mm/gup: fix gup_pud_range() for dax (Nico Pache) [2168370]
- memcg: Fix possible use-after-free in memcg_write_event_control() (Nico Pache) [2168370]
- mm/huge_memory: use pfn_to_online_page() in split_huge_pages_all() (Nico Pache) [2168370]
- mm: fix madivse_pageout mishandling on non-LRU page (Nico Pache) [2168370]
- mm/page_alloc: fix race condition between build_all_zonelists and page allocation (Nico Pache) [2168370]
- mm/slub: fix to return errno if kmalloc() fails (Nico Pache) [2168370]
- writeback: avoid use-after-free after removing device (Nico Pache) [2168370]
- x86/mm: Use proper mask when setting PUD mapping (Nico Pache) [2168370]
- mm/mmap.c: fix missing call to vm_unacct_memory in mmap_region (Nico Pache) [2168370]
- mm/hmm: fault non-owner device private entries (Nico Pache) [2168370]
- mm: split huge PUD on wp_huge_pud fallback (Nico Pache) [2168370]
- mm/page_owner: use strscpy() instead of strlcpy() (Nico Pache) [2168370]
- mm/vmscan: take min_slab_pages into account when try to call shrink_node (Nico Pache) [2168370]
- x86: Fix return value of __setup handlers (Nico Pache) [2168370]
- mm: fix unexpected zeroed page mapping with zram swap (Nico Pache) [2168370]
- mm, page_alloc: fix build_zonerefs_node() (Nico Pache) [2168370]
- mm/mempolicy: fix mpol_new leak in shared_policy_replace (Nico Pache) [2168370]
- mm/slub: remove forced_order parameter in calculate_sizes (Nico Pache) [2168370]
- mm/usercopy: return 1 from hardened_usercopy __setup() handler (Nico Pache) [2168370]
- mm/thp: ClearPageDoubleMap in first page_add_file_rmap() (Nico Pache) [2168370]
- mm/thp: refix __split_huge_pmd_locked() for migration PMD (Nico Pache) [2168370]
- mempolicy: mbind_range() set_policy() after vma_merge() (Nico Pache) [2168370]
- mm/pages_alloc.c: don't create ZONE_MOVABLE beyond the end of a node (Nico Pache) [2168370]
- mm: userfaultfd: fix missing cache flush in mcopy_atomic_pte() and __mcopy_atomic() (Nico Pache) [2168370]
- mm: hugetlb: fix missing cache flush in copy_huge_page_from_user() (Nico Pache) [2168370]
- mm: thp: fix wrong cache flush in remove_migration_pmd() (Nico Pache) [2168370]
- mm: fix missing cache flush for all tail pages of compound page (Nico Pache) [2168370]
- tmpfs: fix regressions from wider use of ZERO_PAGE (Nico Pache) [2168370]
- tmpfs: do not allocate pages on read (Nico Pache) [2168370]
- shmem: mapping_set_exiting() to help mapped resilience (Nico Pache) [2168370]
- mm/hmm.c: allow VM_MIXEDMAP to work with hmm_range_fault (Nico Pache) [2168370]
- shmem: fix a race between shmem_unused_huge_shrink and shmem_evict_inode (Nico Pache) [2168370]
- mm, slub: use prefetchw instead of prefetch (Nico Pache) [2168370]
- arm64: mm: update max_pfn after memory hotplug (Nico Pache) [2168370]
- mm, vmscan: guarantee drop_slab_node() termination (Nico Pache) [2168370]
- fs, mm: fix race in unlinking swapfile (Nico Pache) [2168370]
- fs: inode: count invalidated shadow pages in pginodesteal (Nico Pache) [2168370]
- mm, fadvise: improve the expensive remote LRU cache draining after FADV_DONTNEED (Nico Pache) [2168370]
- mm/filemap.c: rewrite mapping_needs_writeback in less fancy manner (Nico Pache) [2168370]
- fs: drop_caches: fix skipping over shadow cache inodes (Nico Pache) [2168370]
- mm: introduce and use mapping_empty() (Nico Pache) [2168370]
- mm: remove irqsave/restore locking from contexts with irqs enabled (Nico Pache) [2168370]
- mm: zswap: clean up confusing comment (Nico Pache) [2168370]
- mm/memory_hotplug: use helper function zone_end_pfn() to get end_pfn (Nico Pache) [2168370]
- mm: vmstat: add some comments on internal storage of byte items (Nico Pache) [2168370]
- mm: vmstat: fix NOHZ wakeups for node stat changes (Nico Pache) [2168370]
- mm/mmap.c: replace do_brk with do_brk_flags in comment of insert_vm_struct() (Nico Pache) [2168370]
- mm/mmap.c: use helper function allow_write_access() in __remove_shared_vm_struct() (Nico Pache) [2168370]
- mm: use helper function mapping_allow_writable() (Nico Pache) [2168370]
- mm: memcontrol: reword obsolete comment of mem_cgroup_unmark_under_oom() (Nico Pache) [2168370]
- mm/page_counter: correct the obsolete func name in the comment of page_counter_try_charge() (Nico Pache) [2168370]
- mm: memcontrol: correct the comment of mem_cgroup_iter() (Nico Pache) [2168370]
- x86/mm: use max memory block size on bare metal (Nico Pache) [2168370]
- mm/util.c: remove the VM_WARN_ONCE for vm_committed_as underflow check (Nico Pache) [2168370]
- include/linux/swapops.h: correct guards for non_swap_entry() (Nico Pache) [2168370]
- mm: set vm_next and vm_prev to NULL in vm_area_dup() (Nico Pache) [2168370]
- mm: don't prepare anon_vma if vma has VM_WIPEONFORK (Nico Pache) [2168370]
- page-flags: fix a crash at SetPageError(THP_SWAP) (Nico Pache) [2168370]
- mm/rmap.c: fix outdated comment in page_get_anon_vma() (Nico Pache) [2168370]
- mm/mmap.c: extract __vma_unlink_list() as counterpart for __vma_link_list() (Nico Pache) [2168370]
- mm: hugetlb: switch to css_tryget() in hugetlb_cgroup_charge_cgroup() (Nico Pache) [2168370]
- x86/mm: Kill stray kernel fault handling comment (Nico Pache) [2168370]
- arm64/numa: Unify common error path in numa_init() (Nico Pache) [2168370]
- tools/power/x86/intel-speed-select: v1.14 release (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Adjust uncore max/min frequency (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Fix display of uncore min frequency (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Add Emerald Rapid quirk (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: turbo-freq auto mode with SMT off (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: cpufreq reads on offline CPUs (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Use null-terminated string (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove duplicate dup() (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Handle open() failure case (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove unused non_block flag (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove wrong check in set_isst_id() (Prarit Bhargava) [2154078]
- platform/x86: ISST: Fix typo in comments (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Release v1.13 (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Optimize CPU initialization (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Utilize cpu_map to get physical id (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove unused struct clos_config fields (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Enforce isst_id value (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Do not export get_physical_id (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Introduce is_cpu_in_power_domain helper (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Cleanup get_physical_id usage (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Convert more function to use isst_id (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Add pkg and die in isst_id (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Introduce struct isst_id (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove unused core_mask array (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove dead code (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Fix cpu count for TDP level display (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Remove unneeded semicolon (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Fix off by one check (Prarit Bhargava) [2154078]
- platform/x86: ISST: PUNIT device mapping with Sub-NUMA clustering (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Fix warning for perf_cap.cpu (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: Display error on turbo mode disabled (Prarit Bhargava) [2154078]
- tools/power/x86/intel-speed-select: fix build failure when using -Wl,--as-needed (Prarit Bhargava) [2154078]
- KVM: x86: Propagate the AMD Automatic IBRS feature to the guest (Waiman Long) [1989283]
- x86/cpu: Support AMD Automatic IBRS (Waiman Long) [1989283]
- x86/cpu, kvm: Add the SMM_CTL MSR not present feature (Waiman Long) [1989283]
- x86/cpu, kvm: Add the Null Selector Clears Base feature (Waiman Long) [1989283]
- x86/cpu, kvm: Move X86_FEATURE_LFENCE_RDTSC to its native leaf (Waiman Long) [1989283]
- x86/cpu, kvm: Add the NO_NESTED_DATA_BP feature (Waiman Long) [1989283]
- KVM: x86: Move open-coded CPUID leaf 0x80000021 EAX bit propagation code (Waiman Long) [1989283]
- x86/cpu, kvm: Add support for CPUID_80000021_EAX (Waiman Long) [1989283]
- x86/bugs: Make sure MSR_SPEC_CTRL is updated properly upon resume from S3 (Waiman Long) [1989283]
- KVM: x86: Advertise that the SMM_CTL MSR is not supported (Waiman Long) [1989283]
- Documentation/hw-vuln: Update spectre doc (Waiman Long) [1989283]
- nvme-tcp: fence TCP socket on receive error (John Meneghini) [2116939]
- nvme-multipath: fix possible hang in live ns resize with ANA access (John Meneghini) [2116939]
- nvme-tcp: fix possible hang caused during ctrl deletion (John Meneghini) [2116939]
- nvme-tcp: fix regression that causes sporadic requests to time out (John Meneghini) [2116939]
- nvme-tcp: fix UAF when detecting digest errors (John Meneghini) [2116939]
- nvme-tcp: check if the queue is allocated before stopping it (John Meneghini) [2116939]
- nvme-tcp: always fail a request when sending it failed (John Meneghini) [2116939]
- nvme: fix regression when disconnect a recovering ctrl (John Meneghini) [2116939]
- nvme-multipath: use vmalloc for ANA log buffer (John Meneghini) [2116939]
- bfq: fix waker_bfqq inconsistency crash (Ming Lei) [2177565]
- blktrace: Fix output non-blktrace event when blk_classic option enabled (Ming Lei) [2177565]
- blk-wbt: fix that 'rwb->wc' is always set to 1 in wbt_init() (Ming Lei) [2177565]
- blk-wbt: call rq_qos_add() after wb_normal is initialized (Ming Lei) [2177565]
- block: sync mixed merged request's failfast with 1st bio's (Ming Lei) [2177565]
- blk-mq: Fix potential io hung for shared sbitmap per tagset (Ming Lei) [2177565]
- block: bio-integrity: Copy flags when bio_integrity_payload is cloned (Ming Lei) [2177565]
- dim: initialize all struct fields (Audra Mitchell) [2172125]
- XArray: Update the LRU list in xas_split() (Audra Mitchell) [2172125]
- lib: bitmap: fix many kernel-doc warnings (Audra Mitchell) [2172125]
- vsprintf: Fix %%pK with kptr_restrict == 0 (Audra Mitchell) [2172125]
- lib: uninline simple_strntoull() as well (Audra Mitchell) [2172125]
- lib: dimlib: fix help text typos (Audra Mitchell) [2172125]
- locks: fix TOCTOU race when granting write lease (Waiman Long) [2152051]
- locks: eliminate false positive conflicts for write lease (Waiman Long) [2152051]
- locks: Use inode_is_open_for_write (Waiman Long) [2152051]
- fs/locks: remove unnecessary white space. (Waiman Long) [2152051]
- fs/locks: use properly initialized file_lock when unlocking. (Waiman Long) [2152051]
- redhat/configs: Enable CONFIG_PINCTRL_METEORLAKE in RHEL (Prarit Bhargava) [2156845]
- pinctrl: intel: Add Intel Meteor Lake pin controller support (Prarit Bhargava) [2156845]
- md: fix regression for null-ptr-deference in __md_stop() (Nigel Croxon) [2162231]
- md: avoid signed overflow in slot_store() (Nigel Croxon) [2162231]
- md: Free resources in __md_stop (Nigel Croxon) [2162231]
- md: account io_acct_set usage with active_io (Nigel Croxon) [2162231]
- md: use MD_RESYNC_* whenever possible (Nigel Croxon) [2162231]
- md: Free writes_pending in md_stop (Nigel Croxon) [2162231]
- md: Change active_io to percpu (Nigel Croxon) [2162231]
- md: Factor out is_md_suspended helper (Nigel Croxon) [2162231]
- md: don't update recovery_cp when curr_resync is ACTIVE (Nigel Croxon) [2162231]
- md: fold unbind_rdev_from_array into md_kick_rdev_from_array (Nigel Croxon) [2162231]
- md: mark md_kick_rdev_from_array static (Nigel Croxon) [2162231]
- mm/kmemleak: fix UAF bug in kmemleak_scan() (Waiman Long) [2172763]
- mm/kmemleak: simplify kmemleak_cond_resched() usage (Waiman Long) [2172763]
- mm/kmemleak.c: fix a comment (Waiman Long) [2172763]
- ptp: introduce a phase offset in the periodic output request (Íñigo Huguet) [2179072]
- ptp: add ability to configure duty cycle for periodic output (Íñigo Huguet) [2179072]
- platform/x86: intel/pmc/core: Add Meteor Lake mobile support (Prarit Bhargava) [2153968]
- platform/x86: intel/pmc/core: Add Meteor Lake support to pmc core driver (Prarit Bhargava) [2153968]
- sched/core: Fix arch_scale_freq_tick() on tickless systems (Phil Auld) [2184083]
- qede: avoid uninitialized entries in coal_entry array (Michal Schmidt) [2160054]
- qede: fix interrupt coalescing configuration (Jonathan Toppins) [2160054]
- powerpc/64s: Unmerge EX_LR and EX_DAR (Mamatha Inamdar) [2134271]
- powercap: intel_rapl: add support for Meteor Lake (Prarit Bhargava) [2153964]
- dm: fix __send_duplicate_bios() to always allow for splitting IO (Benjamin Marzinski) [2184429]
- dm: fix improper splitting for abnormal bios (Benjamin Marzinski) [2184429]
- ovl: fail on invalid uid/gid mapping at copy up (Miklos Szeredi) [2165342] {CVE-2023-0386}

* Fri Apr 07 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-485.el8]
- timers: Provide timer_shutdown[_sync]() (Ivan Vecera) [2174474]
- timers: Add shutdown mechanism to the internal functions (Ivan Vecera) [2174474]
- timers: Split [try_to_]del_timer[_sync]() to prepare for shutdown mode (Ivan Vecera) [2174474]
- timers: Silently ignore timers with a NULL function (Ivan Vecera) [2174474]
- timers: Rename del_timer() to timer_delete() (Ivan Vecera) [2174474]
- timers: Rename del_timer_sync() to timer_delete_sync() (Ivan Vecera) [2174474]
- timers: Use del_timer_sync() even on UP (Ivan Vecera) [2174474]
- timers: Update kernel-doc for various functions (Ivan Vecera) [2174474]
- timers: Replace BUG_ON()s (Ivan Vecera) [2174474]
- timers: Get rid of del_singleshot_timer_sync() (Ivan Vecera) [2174474]
- clocksource/drivers/sp804: Do not use timer namespace for timer_shutdown() function (Ivan Vecera) [2174474]
- clocksource/drivers/arm_arch_timer: Do not use timer namespace for timer_shutdown() function (Ivan Vecera) [2174474]
- misc/sgi-xp: Replace in_interrupt() usage (Ivan Vecera) [2174474]
- timers: Don't block on ->expiry_lock for TIMER_IRQSAFE timers (Ivan Vecera) [2174474]
- hvcs: Synchronize hotplug remove with port free (Mamatha Inamdar) [2167962]
- hvcs: Use vhangup in hotplug remove (Mamatha Inamdar) [2167962]
- hvcs: Get reference to tty in remove (Mamatha Inamdar) [2167962]
- hvcs: Use driver groups to manage driver attributes (Mamatha Inamdar) [2167962]
- hvcs: Use dev_groups to manage hvcs device attributes (Mamatha Inamdar) [2167962]
- hvcs: Fix hvcs port reference counting (Mamatha Inamdar) [2167962]
- tty: hvcs: Don't NULL tty->driver_data until hvcs_cleanup() (Mamatha Inamdar) [2167962]
- docs/memory-barriers.txt/kokr: introduce io_stop_wc() and add implementation for ARM64 (Ivan Vecera) [2179061]
- docs/memory-barriers.txt: Add a missed closing parenthesis (Ivan Vecera) [2179061]
- asm-generic: Add missing brackets for io_stop_wc macro (Ivan Vecera) [2179061]
- asm-generic: introduce io_stop_wc() and add implementation for ARM64 (Ivan Vecera) [2179061]
- ipv4: Fix incorrect table ID in IOCTL path (Guillaume Nault) [2176792]
- ipv4: Fix incorrect route flushing when table ID 0 is used (Guillaume Nault) [2176792]
- ipv4: Fix incorrect route flushing when source address is deleted (Guillaume Nault) [2176792]
- selftests: Add source route tests to fib_tests (Guillaume Nault) [2176792]
- mm/rmap: split page_dup_rmap() into page_dup_file_rmap() and page_try_dup_anon_rmap() (David Hildenbrand) [2179164]
- mm/memory: slightly simplify copy_present_pte() (David Hildenbrand) [2179164]
- mm/hugetlb: take src_mm->write_protect_seq in copy_hugetlb_page_range() (David Hildenbrand) [2179164]
- mm: /proc/sys/vm/stat_refresh stop checking monotonic numa stats (Waiman Long) [2178001]
- mm: /proc/sys/vm/stat_refresh skip checking known negative stats (Waiman Long) [2178001]
- mm: no more EINVAL from /proc/sys/vm/stat_refresh (Waiman Long) [2178001]
- mm: restore node stat checking in /proc/sys/vm/stat_refresh (Waiman Long) [2178001]
- sfc: ef10: don't overwrite offload features at NIC reset (Íñigo Huguet) [2154500]
- sfc: correctly advertise tunneled IPv6 segmentation (Íñigo Huguet) [2154500]
- igb: conditionalize I2C bit banging on external thermal sensor support (Corinna Vinschen) [2130727]
- platform/x86: ISST: PUNIT device mapping with Sub-NUMA clustering (Prarit Bhargava) [2139963]
- x86/nmi: Make register_nmi_handler() more robust (Ani Sinha) [2037005]
- net: tls: fix possible race condition between do_tls_getsockopt_conf() and do_tls_setsockopt_conf() (Sabrina Dubroca) [2179819] {CVE-2023-28466}
- cpufreq: intel_pstate: hybrid: Use known scaling factor for P-cores (Prarit Bhargava) [2179183]
- target: iscsi: use GFP_NOIO with loopback connections (Maurizio Lombardi) [2156546]
- core_pattern: add CPU specifier (Oleksandr Natalenko) [1968108]
- Bluetooth: L2CAP: Fix accepting connection request for invalid SPSM (David Marlin) [2148404] {CVE-2022-42896}
- ipv6: prevent router_solicitations for team port (Xin Long) [2141600]
- ipv6: Don't send rs packets to the interface of ARPHRD_TUNNEL (Xin Long) [2141600]
- Bluetooth: L2CAP: Fix attempting to access uninitialized memory (David Marlin) [2148408] {CVE-2022-42895}
- redhat/scripts/create-tarball.sh: Use nproc instead of rpm macros (Prarit Bhargava)
- Revert "Switch to z-stream for 8.8 for CKI pipelines" (Denys Vlasenko)

* Wed Apr 05 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-484.el8]
- ethernet: Remove vf rate limit check for drivers (Izabela Bakollari) [2172124]
- rtnetlink: verify rate parameters for calls to ndo_set_vf_rate (Izabela Bakollari) [2172124]
- sfc: Change VF mac via PF as first preference if available. (Íñigo Huguet) [2117449]
- Fix genlog.py to ensure that comments retain "%%" characters. (Eder Zulian) [RHEL-340]
- redhat: fix duplicate jira issues in the resolves line (Eder Zulian) [RHEL-340]
- redhat: add support for Jira issues in changelog (Eder Zulian) [RHEL-340]
- redhat/configs: Put CONFIG_SFC_* to a proper location (Vladis Dronov)
- redhat/configs: Put CONFIG_SEV_GUEST to a proper location (Vladis Dronov)
- Reinstate "GFS2: free disk inode which is deleted by remote node -V2" (Bob Peterson) [2181343]
- iavf: fix hang on reboot with ice (Stefan Assmann) [2181811]
- iavf: Fix race condition between iavf_shutdown and iavf_remove (Stefan Assmann) [2181811]
- net/ulp: use consistent error code when blocking ULP (Sabrina Dubroca) [2176955] {CVE-2023-0461}
- net/ulp: prevent ULP without clone op from entering the LISTEN status (Sabrina Dubroca) [2176955] {CVE-2023-0461}
- lockd: lockd server-side shouldn't set fl_ops (Jeffrey Layton) [2179329]
- NFS: Correct timing for assigning access cache timestamp (Benjamin Coddington) [2180851]
- Switch to z-stream for 8.8 for CKI pipelines (Michael Hofmann)
- KVM: VMX: Execute IBPB on emulated VM-exit when guest has IBRS (Jon Maloy) [2160033] {CVE-2022-2196}

* Fri Mar 31 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-483.el8]
- tracing/hwlat: Replace sched_setaffinity with set_cpus_allowed_ptr (Jerome Marchand) [2174935]
- drivers: hv, hyperv_fb: Untangle and refactor Hyper-V panic notifiers (Mohammed Gamal) [2172513]
- video: hyperv_fb: Avoid taking busy spinlock on panic path (Mohammed Gamal) [2172513]
- HID: hyperv: remove unused struct synthhid_msg (Mohammed Gamal) [2172513]
- HID: hyperv: Replace one-element array with flexible-array member (Mohammed Gamal) [2172513]
- clocksource: hyper-v: Add TSC page support for root partition (Mohammed Gamal) [2172443]
- clocksource: hyper-v: Use TSC PFN getter to map vvar page (Mohammed Gamal) [2172443]
- clocksource: hyper-v: Introduce TSC PFN getter (Mohammed Gamal) [2172443]
- clocksource: hyper-v: Introduce a pointer to TSC page (Mohammed Gamal) [2172443]
- HV: hv_balloon: fix memory leak with using debugfs_lookup() (Mohammed Gamal) [2172435]
- debugfs: add debugfs_lookup_and_remove() (Mohammed Gamal) [2172435]
- Drivers: hv: Enable vmbus driver for nested root partition (Mohammed Gamal) [2172435]
- video: hyperv_fb: Avoid taking busy spinlock on panic path (Mohammed Gamal) [2172435]

* Mon Mar 27 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-482.el8]
- sched/deadline: Add more reschedule cases to prio_changed_dl() (Valentin Schneider) [2120570]
- perf/x86/uncore: Add new Raptor Lake S support (Michael Petlan) [2120365]
- perf/x86/cstate: Add new Raptor Lake S support (Michael Petlan) [2120365]
- perf/x86/msr: Add new Raptor Lake S support (Michael Petlan) [2120365]
- perf/x86: Add new Raptor Lake S support (Michael Petlan) [2120365]
- net: sched: atm: dont intepret cls results when asked to drop (Davide Caratti) [2168336] {CVE-2023-23455}
- nvdimm: Allow overwrite in the presence of disabled dimms (Aristeu Rozanski) [2154070]
- Revert "GFS2: free disk inode which is deleted by remote node -V2" (Bob Peterson) [2109600]
- gfs2: Evict inodes cooperatively (Andreas Gruenbacher) [2109600]
- gfs2: Flush delete work before shrinking inode cache (Andreas Gruenbacher) [2109600]
- gfs2: Add SDF_DEACTIVATING super block flag (Bob Peterson) [2109600]
- gfs2: check gl_object in rgrp glops (Bob Peterson) [2109600]
- gfs2: Split the two kinds of glock "delete" work (Andreas Gruenbacher) [2109600]
- gfs2: Move delete workqueue into super block (Andreas Gruenbacher) [2109600]
- gfs2: Use container_of() for gfs2_glock(aspace) (Andreas Gruenbacher) [2109600]
- gfs2: Get rid of GLF_PENDING_DELETE flag (Andreas Gruenbacher) [2109600]
- gfs2: Make glock lru list scanning safer (Andreas Gruenbacher) [2109600]
- gfs2: Fix use-after-free in gfs2_glock_shrink_scan (Andreas Gruenbacher) [2109600]
- gfs2: Clean up gfs2_scan_glock_lru (Andreas Gruenbacher) [2109600]
- gfs2: gl_object races fix (Andreas Gruenbacher) [2109600]
- iomap/gfs2: Unlock and put folio in page_done handler (Andreas Gruenbacher) [2109600]
- iomap: Add __iomap_put_folio helper (Andreas Gruenbacher) [2109600]
- gfs2: Remove support for glock holder auto-demotion (2) (Andreas Gruenbacher) [2109600]
- gfs2: Remove support for glock holder auto-demotion (Andreas Gruenbacher) [2109600]
- gfs2: Minor gfs2_try_evict cleanup (Andreas Gruenbacher) [2109600]
- gfs2: Partially revert gfs2_inode_lookup change (Andreas Gruenbacher) [2109600]
- gfs2: Add gfs2_inode_lookup comment (Andreas Gruenbacher) [2109600]
- gfs2: Uninline and improve glock_{set,clear}_object (Andreas Gruenbacher) [2109600]
- gfs2: Simply dequeue iopen glock in gfs2_evict_inode (Andreas Gruenbacher) [2109600]
- gfs2: Clean up after gfs2_create_inode rework (Andreas Gruenbacher) [2109600]
- gfs2: Avoid dequeuing GL_ASYNC glock holders twice (Andreas Gruenbacher) [2109600]
- gfs2: Handle -EBUSY result of insert_inode_locked4 (Andreas Gruenbacher) [2109600]
- gfs2: Fix and clean up create / evict interaction (Andreas Gruenbacher) [2109600]
- gfs2: Clean up initialization of "ip" in gfs2_create_inode (Andreas Gruenbacher) [2109600]
- gfs2: Get rid of ghs[] in gfs2_create_inode (Andreas Gruenbacher) [2109600]
- gfs2: Dequeue waiters when withdrawn (Bob Peterson) [2109600]
- gfs2: Prevent double iput for journal on error (Bob Peterson) [2109600]
- Revert "gfs2: stop using generic_writepages in gfs2_ail1_start_one" (Andreas Gruenbacher) [2109600]
- gfs2: remove ->writepage (Andreas Gruenbacher) [2109600]
- gfs2: stop using generic_writepages in gfs2_ail1_start_one (Andreas Gruenbacher) [2109600]
- gfs2: List traversal in do_promote is safe (Andreas Gruenbacher) [2109600]
- gfs2: do_promote glock holder stealing fix (Bob Peterson) [2109600]
- gfs2: Use better variable name (Andreas Gruenbacher) [2109600]
- gfs2: Make go_instantiate take a glock (Andreas Gruenbacher) [2109600]
- gfs2: Add new go_held glock operation (Andreas Gruenbacher) [2109600]
- gfs2: Revert 'Fix "truncate in progress" hang' (Andreas Gruenbacher) [2109600]
- gfs2: Instantiate glocks ouside of glock state engine (Andreas Gruenbacher) [2109600]
- gfs2: Fix up gfs2_glock_async_wait (Andreas Gruenbacher) [2109600]
- gfs2: Add GL_NOPID flag for process-independent glock holders (Andreas Gruenbacher) [2109600]
- gfs2: dump inode object for iopen glocks (Bob Peterson) [2109600]
- gfs2: convert to use DEFINE_SEQ_ATTRIBUTE macro (Andreas Gruenbacher) [2109600]
- gfs2: Use TRY lock in gfs2_inode_lookup for UNLINKED inodes (Bob Peterson) [2109600]
- Updated dist tag to el8_8 (Lucas Zampieri)
- Revert "net/mlx5: Don't perform lookup after already known sec_path" (Amir Tzin) [2176349]
- KVM: x86: do not report a vCPU as preempted outside instruction boundaries (Jon Maloy) [2124800] {CVE-2022-39189}
- Drivers: vmbus: Check for channel allocation before looking up relids (Mohammed Gamal) [2178622]
- drm/nouveau/fb/tu102-: fix register used to determine scrub status (Karol Herbst) [2168648]
- drm/nouveau/devinit/tu102-: wait for GFW_BOOT_PROGRESS == COMPLETED (Karol Herbst) [2168648]
- fs/proc: task_mmu.c: don't read mapcount for migration entry (Jay Shin) [2174623]
- perf/core: Fix cgroup event list management (Michael Petlan) [2162525]

* Tue Mar 21 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-481.el8]
- redhat: include all certs (Red Hat and CentOS) in the srpm (Denys Vlasenko) [2179095]
- redhat: do not require grub2 on s390x (Denys Vlasenko) [2179095]
- thermal: int340x: Add Meteor Lake PCI device ID (Prarit Bhargava) [2156822]
- i2c: i801: Add support for Intel Meteor Lake-P (Prarit Bhargava) [2156841]

* Sat Mar 18 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-480.el8]
- redhat: fix the signing failure on ppc64el on centos (Denys Vlasenko) [2179095]

* Sat Mar 18 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-479.el8]
- redhat: add centos signing certs (Denys Vlasenko)
- redhat: fix "make rh-brew" not choosing _scratch_ build (Denys Vlasenko)
- mfd: intel-lpss: Add Intel Meteor Lake-P PCI IDs (Prarit Bhargava) [2156843]
- x86/cpu: Add CPU model numbers for Meteor Lake (Prarit Bhargava) [2153936]
- redhat: require grub2 >= 2.02-99 (Denys Vlasenko) [2179095]
- redhat: delete unused script and file (Denys Vlasenko) [2179095]
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Denys Vlasenko) [2179095]
- redhat: align file names with names of signing keys for ppc and s390 (Denys Vlasenko) [2179095]

* Thu Mar 16 2023 Denys Vlasenko <dvlasenk@redhat.com> [4.18.0-478.el8]
- net/tunnel: wait until all sk_user_data reader finish before releasing the sock (Hangbin Liu) [2176344]
- powerpc/pseries: unregister VPA when hot unplugging a CPU (Mamatha Inamdar) [2143007]
- net: mana: Fix IRQ name - add PCI and queue number (Mohammed Gamal) [2172474]
- net: mana: Fix return type of mana_start_xmit() (Mohammed Gamal) [2172474]
- net: mana: Define data structures for protection domain and memory registration (Mohammed Gamal) [2172474]
- net: mana: Define and process GDMA response code GDMA_STATUS_MORE_ENTRIES (Mohammed Gamal) [2172474]
- net: mana: Define max values for SGL entries (Mohammed Gamal) [2172474]
- net: mana: Move header files to a common location (Mohammed Gamal) [2172474]
- net: mana: Record port number in netdev (Mohammed Gamal) [2172474]
- net: mana: Export Work Queue functions for use by RDMA driver (Mohammed Gamal) [2172474]
- net: mana: Set the DMA device max segment size (Mohammed Gamal) [2172474]
- net: mana: Handle vport sharing between devices (Mohammed Gamal) [2172474]
- net: mana: Record the physical address for doorbell page region (Mohammed Gamal) [2172474]
- net: mana: Add support for auxiliary device (Mohammed Gamal) [2172474]
- hv_netvsc: Check status in SEND_RNDIS_PKT completion message (Mohammed Gamal) [2172438]
- hv_netvsc: Allocate memory in netvsc_dma_map() with GFP_ATOMIC (Mohammed Gamal) [2172438]
- hv_netvsc: Fix missed pagebuf entries in netvsc_dma_map/unmap() (Mohammed Gamal) [2172438]
- Drivers: hv: Make remove callback of hyperv driver void returned (Mohammed Gamal) [2172438]
- hv: fix comment typo in vmbus_channel/low_latency (Mohammed Gamal) [2172434]
- x86/hyperv: Introduce HV_MAX_SPARSE_VCPU_BANKS/HV_VCPUS_PER_SPARSE_BANK constants (Mohammed Gamal) [2172434]
- x86/hyperv: Fix hv_get/set_register for nested bringup (Mohammed Gamal) [2172434]
- x86/hyperv: Add an interface to do nested hypercalls (Mohammed Gamal) [2172434]
- Drivers: hv: Setup synic registers in case of nested root partition (Mohammed Gamal) [2172434]
- x86/hyperv: Add support for detecting nested hypervisor (Mohammed Gamal) [2172434]
- x86/hyperv: Add HV_EXPOSE_INVARIANT_TSC define (Mohammed Gamal) [2172434]
- x86/hyperv: Expand definition of struct hv_vp_assist_page (Mohammed Gamal) [2172434]
- KVM: x86: hyper-v: Expose support for extended gva ranges for flush hypercalls (Mohammed Gamal) [2172434]
- x86/hyperv: Move VMCB enlightenment definitions to hyperv-tlfs.h (Mohammed Gamal) [2172434]
- iommu/hyper-v: Allow hyperv irq remapping without x2apic (Mohammed Gamal) [2172434]
- smp: Fix offline cpu check in flush_smp_call_function_queue() (Waiman Long) [2169471]
- sched/fair: Trigger the update of blocked load on newly idle cpu (Waiman Long) [2169471]
- redhat: rh-dist-git should depend on rh-srpm (Denys Vlasenko)
- redhat: change kabi tarballs to use the package release (Denys Vlasenko)
- redhat/Makefile: add variables used in rhel9 makefiles (Denys Vlasenko)
- redhat/Makefile: Remove RHPRODUCT variable (Denys Vlasenko)
- redhat/scripts/rh-dist-git.sh: expand sources from srpm (Denys Vlasenko)
- redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning (Denys Vlasenko)
- redhat/scripts/rh-dist-git.sh: Use Makefile variables (Denys Vlasenko)
- redhat: fix typo and make the output more silent for dist-git sync (Denys Vlasenko)
- redhat: add initial support for centos stream dist-git sync on Makefiles (Denys Vlasenko)
- internal: update RHEL_MINOR for the start of RHEL-8.9 development (Denys Vlasenko)
- watchdog: diag288_wdt: fix __diag288() inline assembly (Tobias Huschle) [2171361]
- watchdog: diag288_wdt: do not use stack buffers for hardware data (Tobias Huschle) [2171361]
- bonding: add documentation for peer_notif_delay (Ryosuke Yasuoka) [2171348]
- net: mana: Fix IRQ name - add PCI and queue number (Mohammed Gamal) [2166787]
- crypto: des - disallow des3 in FIPS mode (Vladis Dronov) [2175234]
- self-tests: more rps self tests (Paolo Abeni) [2168878]
- net: make default_rps_mask a per netns attribute (Paolo Abeni) [2168878]
- self-tests: introduce self-tests for RPS default mask (Paolo Abeni) [2168878]
- net: introduce default_rps_mask netns attribute (Paolo Abeni) [2168878]
- net-sysctl: factor-out rpm mask manipulation helpers (Paolo Abeni) [2168878]
- net-sysctl: factor out cpumask parsing helper (Paolo Abeni) [2168878]
- txhash: Make rethinking txhash behavior configurable via sysctl (Paolo Abeni) [2168878]
- net-sysfs: Call dev_hold always in rx_queue_add_kobject (Paolo Abeni) [2168878]
- net-sysfs: Call dev_hold always in netdev_queue_add_kobject (Paolo Abeni) [2168878]
- net-sysfs: fix netdev_queue_add_kobject() breakage (Paolo Abeni) [2168878]
- net-sysfs: Fix reference count leak in rx|netdev_queue_add_kobject (Paolo Abeni) [2168878]
- ice/ptp: fix the PTP worker retrying indefinitely if the link went down (Petr Oros) [2166392]
- ice: reschedule ice_ptp_wait_for_offset_valid during reset (Petr Oros) [2166392]
- ice: make Tx and Rx vernier offset calibration independent (Petr Oros) [2166392]
- ice: only check set bits in ice_ptp_flush_tx_tracker (Petr Oros) [2166392]
- ice: handle flushing stale Tx timestamps in ice_ptp_tx_tstamp (Petr Oros) [2166392]
- ice: cleanup allocations in ice_ptp_alloc_tx_tracker (Petr Oros) [2166392]
- ice: protect init and calibrating check in ice_ptp_request_ts (Petr Oros) [2166392]
- ice: check Tx timestamp memory register for ready timestamps (Petr Oros) [2166392]
- ice: handle discarding old Tx requests in ice_ptp_tx_tstamp (Petr Oros) [2166392]
- ice: always call ice_ptp_link_change and make it void (Petr Oros) [2166392]
- ice: fix misuse of "link err" with "link status" (Petr Oros) [2166392]
- ice: Reset TS memory for all quads (Petr Oros) [2166392]
- ice: Remove the E822 vernier "bypass" logic (Petr Oros) [2166392]
- ice: Use more generic names for ice_ptp_tx fields (Petr Oros) [2166392]
- ice: Merge pin initialization of E810 and E810T adapters (Petr Oros) [2166392]
- ice: Check if reset in progress while waiting for offsets (Petr Oros) [2166392]
- NFS: Judge the file access cache's timestamp in rcu path (Benjamin Coddington) [2161321]
- redhat: switch to z-stream for 8.8 (Lucas Zampieri)

* Wed Mar 08 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-477.2.1.el8]
- net: mana: Fix IRQ name - add PCI and queue number (Mohammed Gamal) [2166787]
- crypto: des - disallow des3 in FIPS mode (Vladis Dronov) [2175234]
- self-tests: more rps self tests (Paolo Abeni) [2168878]
- net: make default_rps_mask a per netns attribute (Paolo Abeni) [2168878]
- self-tests: introduce self-tests for RPS default mask (Paolo Abeni) [2168878]
- net: introduce default_rps_mask netns attribute (Paolo Abeni) [2168878]
- net-sysctl: factor-out rpm mask manipulation helpers (Paolo Abeni) [2168878]
- net-sysctl: factor out cpumask parsing helper (Paolo Abeni) [2168878]
- txhash: Make rethinking txhash behavior configurable via sysctl (Paolo Abeni) [2168878]
- net-sysfs: Call dev_hold always in rx_queue_add_kobject (Paolo Abeni) [2168878]
- net-sysfs: Call dev_hold always in netdev_queue_add_kobject (Paolo Abeni) [2168878]
- net-sysfs: fix netdev_queue_add_kobject() breakage (Paolo Abeni) [2168878]
- net-sysfs: Fix reference count leak in rx|netdev_queue_add_kobject (Paolo Abeni) [2168878]

* Mon Mar 06 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-477.1.1.el8]
- ice/ptp: fix the PTP worker retrying indefinitely if the link went down (Petr Oros) [2166392]
- ice: reschedule ice_ptp_wait_for_offset_valid during reset (Petr Oros) [2166392]
- ice: make Tx and Rx vernier offset calibration independent (Petr Oros) [2166392]
- ice: only check set bits in ice_ptp_flush_tx_tracker (Petr Oros) [2166392]
- ice: handle flushing stale Tx timestamps in ice_ptp_tx_tstamp (Petr Oros) [2166392]
- ice: cleanup allocations in ice_ptp_alloc_tx_tracker (Petr Oros) [2166392]
- ice: protect init and calibrating check in ice_ptp_request_ts (Petr Oros) [2166392]
- ice: check Tx timestamp memory register for ready timestamps (Petr Oros) [2166392]
- ice: handle discarding old Tx requests in ice_ptp_tx_tstamp (Petr Oros) [2166392]
- ice: always call ice_ptp_link_change and make it void (Petr Oros) [2166392]
- ice: fix misuse of "link err" with "link status" (Petr Oros) [2166392]
- ice: Reset TS memory for all quads (Petr Oros) [2166392]
- ice: Remove the E822 vernier "bypass" logic (Petr Oros) [2166392]
- ice: Use more generic names for ice_ptp_tx fields (Petr Oros) [2166392]
- ice: Merge pin initialization of E810 and E810T adapters (Petr Oros) [2166392]
- ice: Check if reset in progress while waiting for offsets (Petr Oros) [2166392]
- NFS: Judge the file access cache's timestamp in rcu path (Benjamin Coddington) [2161321]
- redhat: switch to z-stream for 8.8 (Lucas Zampieri)

* Thu Feb 23 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-477.el8]
- cpufreq: intel_pstate: Add Sapphire Rapids support in no-HWP mode (Prarit Bhargava) [2170564]

* Thu Feb 23 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-476.el8]
- igb: Initialize mailbox message for VF reset (Corinna Vinschen) [2103948]
- igb: Allocate MSI-X vector when testing (Corinna Vinschen) [2103948]
- igb: Proactively round up to kmalloc bucket size (Corinna Vinschen) [2103948]
- igb: Do not free q_vector unless new one was allocated (Corinna Vinschen) [2103948]
- ptp: introduce helpers to adjust by scaled parts per million (Corinna Vinschen) [2103948]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Corinna Vinschen) [2103948]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2103948]
- igb: convert .adjfreq to .adjfine (Corinna Vinschen) [2103948]
- ASoC: Intel: soc-acpi: add configuration for variant of 0C11 product (Jaroslav Kysela) [2100582]
- ASoC: Intel: soc-acpi: add configuration for variant of 0C40 product (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw: use common helpers for all Realtek amps (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw: Add support for SKU 0C11 product (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw: Add support for SKU 0C4F product (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw: Add support for SKU 0C40 product (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw: Add support for SKU 0C10 product (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw_rt1316: add BQ params for the Dell models (Jaroslav Kysela) [2100582]
- ASoC: Intel: sof_sdw_rt1308: add BQ params for the Dell models (Jaroslav Kysela) [2100582]
- ASoC: intel: sof_sdw: add rt1318 codec support. (Jaroslav Kysela) [2100582]
- ASoC: rt1318: Add RT1318 SDCA vendor-specific driver (Jaroslav Kysela) [2100582]
- ASoC: Intel: soc-acpi: update codec addr on 0C11/0C4F product (Jaroslav Kysela) [2100582]
- ASoC: Intel: soc-acpi: add SKU 0C11 SoundWire configuration (Jaroslav Kysela) [2100582]
- ASoC: Intel: soc-acpi: add SKU 0C40 SoundWire configuration (Jaroslav Kysela) [2100582]
- ASoC: Intel: soc-acpi: add SKU 0C10 SoundWire configuration (Jaroslav Kysela) [2100582]
- ASoC: Intel: soc-acpi-intel-rpl-match: add rpl_sdca_3_in_1 support (Jaroslav Kysela) [2100582]

* Wed Feb 22 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-475.el8]
- net: ena: Update NUMA TPH hint register upon NUMA node update (Petr Oros) [2167316]
- net: ena: Set default value for RX interrupt moderation (Petr Oros) [2167316]
- net: ena: Fix rx_copybreak value update (Petr Oros) [2167316]
- net: ena: Use bitmask to indicate packet redirection (Petr Oros) [2167316]
- net: ena: Account for the number of processed bytes in XDP (Petr Oros) [2167316]
- net: ena: Don't register memory info on XDP exchange (Petr Oros) [2167316]
- net: ena: Fix toeplitz initial hash value (Petr Oros) [2167316]
- net: ena: Fix error handling in ena_init() (Petr Oros) [2167316]
- net: sched: disallow noqueue for qdisc classes (Xin Long) [2168282] {CVE-2022-47929}
- net: sched: cbq: dont intepret cls results when asked to drop (Xin Long) [2168327] {CVE-2023-23454}
- sctp: do not check hb_timer.expires when resetting hb_timer (Xin Long) [2133092]
- arm64: Add AMPERE1 to the Spectre-BHB affected list (Mark Salter) [2140727]
- net: mana: Fix accessing freed irq affinity_hint (Emanuele Giuseppe Esposito) [2168969]
- net: mana: Assign interrupts to CPUs based on NUMA nodes (Emanuele Giuseppe Esposito) [2168969]
- Revert "RDMA/irdma: Report the correct link speed" (Kamal Heib) [2143088]
- Documentation/sysctl: document page_lock_unfairness (Nico Pache) [2165737] {CVE-2022-3623}
- mm: allow a controlled amount of unfairness in the page lock (Nico Pache) [2165737] {CVE-2022-3623}
- mm/hugetlb: fix races when looking up a CONT-PTE/PMD size hugetlb page (Nico Pache) [2165737] {CVE-2022-3623}
- mm/migration: fix potential pte_unmap on an not mapped pte (Nico Pache) [2165737] {CVE-2022-3623}
- mm/migrate.c: rework migration_entry_wait() to not take a pageref (Nico Pache) [2165737] {CVE-2022-3623}
- mm: make wait_on_page_writeback() wait for multiple pending writebacks (Nico Pache) [2165737] {CVE-2022-3623}
- mm: rewrite wait_on_page_bit_common() logic (Nico Pache) [2165737] {CVE-2022-3623}
- mm/gup.c: use is_vm_hugetlb_page() to check whether to follow huge (Nico Pache) [2165737] {CVE-2022-3623}

* Mon Feb 20 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-474.el8]
- perf/x86/amd: Fix crash due to race between amd_pmu_enable_all, perf NMI and throttling (Michael Petlan) [2085282]
- x86/perf: Fix snapshot_branch_stack warning in VM (Michael Petlan) [2085282]
- perf/x86/amd/core: Fix reloading events for SVM (Michael Petlan) [2085282 2086722]
- perf/x86/amd: Run AMD BRS code only on supported hw (Michael Petlan) [2085282]
- perf/x86/amd: Fix AMD BRS period adjustment (Michael Petlan) [2085282]
- perf/x86/amd: Remove unused variable 'hwc' (Michael Petlan) [2085282]
- perf/ibs: Fix comment (Michael Petlan) [2085282]
- perf report: Add tools/arch/x86/include/asm/amd-ibs.h (Michael Petlan) [2085282]
- perf/amd/ibs: Advertise zen4_ibs_extensions as pmu capability attribute (Michael Petlan) [2085282]
- perf/amd/ibs: Add support for L3 miss filtering (Michael Petlan) [2085282]
- perf/amd/ibs: Use ->is_visible callback for dynamic attributes (Michael Petlan) [2085282]
- perf/amd/ibs: Cascade pmu init functions' return value (Michael Petlan) [2085282]
- perf/amd/ibs: Use interrupt regs ip for stack unwinding (Michael Petlan) [2085282]
- perf/x86/amd/core: Add PerfMonV2 overflow handling (Michael Petlan) [2085282 2086722]
- perf/x86/amd/core: Add PerfMonV2 counter control (Michael Petlan) [2085282 2086722]
- perf/x86/amd/core: Detect available counters (Michael Petlan) [2085282 2086722]
- perf/x86/amd/core: Detect PerfMonV2 support (Michael Petlan) [2085282 2086722]
- x86/msr: Add PerfCntrGlobal* registers (Michael Petlan) [2085282 2086722]
- x86/cpufeatures: Add PerfMonV2 feature bit (Michael Petlan) [2085282 2086722]
- perf/x86: Unify format of events sysfs show (Michael Petlan) [2085282]
- perf/x86/amd: Add idle hooks for branch sampling (Michael Petlan) [2085282]
- perf: Enable branch record for software events (Michael Petlan) [2085282]
- redhat/configs: Enable AMD Zen3 branch sampling by default (Michael Petlan) [2085282]
- perf/x86/amd: Make Zen3 branch sampling opt-in (Michael Petlan) [2085282]
- perf/x86/amd: Add AMD branch sampling period adjustment (Michael Petlan) [2085282]
- perf/x86/amd: Enable branch sampling priv level filtering (Michael Petlan) [2085282]
- perf/x86/amd: Add branch-brs helper event for Fam19h BRS (Michael Petlan) [2085282]
- perf/x86/amd: Add AMD Fam19h Branch Sampling support (Michael Petlan) [2085282]
- perf/x86/amd/ibs: Add bitfield definitions in new <asm/amd-ibs.h> header (Michael Petlan) [2085282]
- perf/amd/uncore: Allow the driver to be built as a module (Michael Petlan) [2085282]
- perf/amd/uncore: Clean up header use, use <linux/ include paths instead of <asm/ (Michael Petlan) [2085282]
- perf/amd/uncore: Simplify code, use free_percpu()'s built-in check for NULL (Michael Petlan) [2085282]
- x86/cpufeatures: Add AMD Fam19h Branch Sampling feature (Michael Petlan) [2085282]
- perf/core: Add perf_clear_branch_entry_bitfields() helper (Michael Petlan) [2085282]

* Fri Feb 17 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-473.el8]
- ice: fix lost multicast packets in promisc mode (Ken Cox) [2138215]
- RDMA/irdma: Cap MSIX used to online CPUs + 1 (Kamal Heib) [2118548]
- usb: mon: make mmapped memory read only (Desnes Nunes) [2157697] {CVE-2022-43750}
- blk-cgroup: don't update io stat for root cgroup (Ming Lei) [2167547]
- x86/hyperv: Remove unregister syscore call from Hyper-V cleanup (Mohammed Gamal) [1865745]
- perf test: Skip watchpoint tests if no watchpoints available (Michael Petlan) [2148337]
- powercap: intel_rapl: Add support for RAPTORLAKE_P (Prarit Bhargava) [2076726]
- crypto: hmac - disallow keys < 112 bits in FIPS mode (Vladis Dronov) [2166715]
- crypto: hmac - add fips_skip support (Vladis Dronov) [2166715]
- crypto: dh - limit key size to 2048 in FIPS mode (Vladis Dronov) [2166715]
- crypto: rsa - limit key size to 2048 in FIPS mode (Vladis Dronov) [2166715]

* Wed Feb 15 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-472.el8]
- netfilter: flowtable_offload: add missing locking (Florian Westphal) [2134371]
- netfilter: ipset: Rework long task execution when adding/deleting entries (Florian Westphal) [2134371]
- netfilter: ipset: fix hash:net,port,net hang with /0 subnet (Florian Westphal) [2134371]
- netfilter: ipset: regression in ip_set_hash_ip.c (Florian Westphal) [2134371]
- netfilter: ipset: Limit the maximal range of consecutive elements to add/delete (Florian Westphal) [2134371]
- netfilter: flowtable: really fix NAT IPv6 offload (Florian Westphal) [2134371]
- netfilter: nft_set_pipapo: Actually validate intervals in fields after the first one (Florian Westphal) [2134371]
- netfilter: Cleanup nft_net->module_list from nf_tables_exit_net() (Florian Westphal) [2134371]
- netfilter: nf_tables: fix nft_counters_enabled underflow at nf_tables_addchain() (Florian Westphal) [2134371]
- netfilter: nf_tables: do not leave chain stats enabled on error (Florian Westphal) [2134371]
- ipvs: use explicitly signed chars (Florian Westphal) [2134371]
- netfilter: nf_tables: release flow rule object from commit path (Florian Westphal) [2134371]
- netfilter: nf_tables: fix percpu memory leak at nf_tables_addchain() (Florian Westphal) [2134371]
- netfilter: nf_tables: clean up hook list when offload flags check fails (Florian Westphal) [2134371]
- netfilter: br_netfilter: Drop dst references before setting. (Florian Westphal) [2134371]
- netfilter: nft_tproxy: restrict to prerouting hook (Florian Westphal) [2134371]
- netfilter: ebtables: fix memory leak when blob is malformed (Florian Westphal) [2134371]
- netfilter: ebtables: reject blobs that don't provide all entry points (Florian Westphal) [2134371]
- netfilter: nf_tables: check NFT_SET_CONCAT flag if field_count is specified (Florian Westphal) [2134371]
- netfilter: nf_tables: relax NFTA_SET_ELEM_KEY_END set flags requirements (Florian Westphal) [2134371]
- netfilter: nf_tables: NFTA_SET_ELEM_KEY_END requires concat and interval flags (Florian Westphal) [2134371]
- netfilter: nf_tables: validate NFTA_SET_ELEM_OBJREF based on NFT_SET_OBJECT flag (Florian Westphal) [2134371]
- netfilter: nf_tables: possible module reference underflow in error path (Florian Westphal) [2134371]
- netfilter: nf_tables: disallow NFTA_SET_ELEM_KEY_END with NFT_SET_ELEM_INTERVAL_END flag (Florian Westphal) [2134371]
- netfilter: nf_tables: use READ_ONCE and WRITE_ONCE for shared generation id access (Florian Westphal) [2134371]
- netfilter: nf_tables: fix null deref due to zeroed list head (Florian Westphal) [2134371]

* Wed Feb 15 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-471.el8]
- bnxt_en: fix memory leak in bnxt_nvm_test() (Ken Cox) [2112186]
- bnxt_en: Fix HDS and jumbo thresholds for RX packets (Ken Cox) [2112186]
- bnxt_en: Fix first buffer size calculations for XDP multi-buffer (Ken Cox) [2112186]
- bnxt_en: Fix XDP RX path (Ken Cox) [2112186]
- bnxt_en: Simplify bnxt_xdp_buff_init() (Ken Cox) [2112186]
- bnxt: prevent skb UAF after handing over to PTP worker (Ken Cox) [2112186]
- bnxt_en: fix flags to check for supported fw version (Ken Cox) [2112186]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2112186]
- bnxt_en: fix NQ resource accounting during vf creation on 57500 chips (Ken Cox) [2112186]
- bnxt_en: set missing reload flag in devlink features (Ken Cox) [2112186]
- bnxt_en: Use PAGE_SIZE to init buffer when multi buffer XDP is not in use (Ken Cox) [2112186]
- bnxt_en: Remove duplicated include bnxt_devlink.c (Ken Cox) [2112186]
- bnxt_en: implement callbacks for devlink selftests (Ken Cox) [2112186]
- bnxt_en: Fix bnxt_refclk_read() (Ken Cox) [2112186]
- bnxt_en: fix livepatch query (Ken Cox) [2112186]
- bnxt_en: Fix bnxt_reinit_after_abort() code path (Ken Cox) [2112186]
- bnxt_en: reclaim max resources if sriov enable fails (Ken Cox) [2112186]
- bnxt: Use the bitmap API to allocate bitmaps (Ken Cox) [2112186]
- bnxt: Fix typo in comments (Ken Cox) [2112186]
- eth: bnxt: make ulp_id unsigned to make GCC 12 happy (Ken Cox) [2112186]
- bnxt_en: Enable packet timestamping for all RX packets (Ken Cox) [2112186]
- bnxt_en: Configure ptp filters during bnxt open (Ken Cox) [2112186]
- bnxt_en: Update firmware interface to 1.10.2.95 (Ken Cox) [2112186]
- bnxt: add page_pool support for aggregation ring when using xdp (Ken Cox) [2112186]
- bnxt: change receive ring space parameters (Ken Cox) [2112186]
- bnxt: rename bnxt_rx_pages to bnxt_rx_agg_pages_skb (Ken Cox) [2112186]
- bnxt: refactor bnxt_rx_pages operate on skb_shared_info (Ken Cox) [2112186]
- bnxt: add flag to denote that an xdp program is currently attached (Ken Cox) [2112186]
- bnxt: refactor bnxt_rx_xdp to separate xdp_init_buff/xdp_prepare_buff (Ken Cox) [2112186]
- bnxt: report header-data split state (Ken Cox) [2112186]
- net: Don't include filter.h from net/sock.h (Ken Cox) [2112186]
- ethernet: constify references to netdev->dev_addr in drivers (Ken Cox) [2112186]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2112186]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Ken Cox) [2112186]
- bnxt_en: Use struct_group_attr() for memcpy() region (Ken Cox) [2112186]
- net: don't include ethtool.h from netdevice.h (Ken Cox) [2112186]
- treewide: Use fallthrough pseudo-keyword (Ken Cox) [2112186]
- net: Use skb_frag_off accessors (Ken Cox) [2112186]
- net: Use skb accessors in network drivers (Ken Cox) [2112186]
- ethernet: remove redundant memset (Ken Cox) [2112186]
- treewide: Add SPDX license identifier - Makefile/Kconfig (Ken Cox) [2112186]

* Wed Feb 15 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-470.el8]
- ASoC: amd: renoir: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169761]
- ASoC: amd: renoir: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169761]
- ASoC: amd: yc: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169761]
- ASoC: amd: yc: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169761]
- genirq: Fix reference leaks on irq affinity notifiers (Ricardo Robaina) [2154842]
- genirq: Prevent use-after-free and work list corruption (Ricardo Robaina) [2154842]
- perf/x86/uncore: Don't WARN_ON_ONCE() for a broken discovery table (Michael Petlan) [2154044]
- perf/x86/uncore: Add a quirk for UPI on SPR (Michael Petlan) [2154044]
- perf/x86/uncore: Ignore broken units in discovery table (Michael Petlan) [2154044]
- perf/x86/uncore: Fix potential NULL pointer in uncore_get_alias_name (Michael Petlan) [2154044]
- perf/x86/uncore: Factor out uncore_device_to_die() (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Support extra IMC channel on Ice Lake server (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix CAS_COUNT_WRITE issue for ICX (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix IIO event constraints for Snowridge (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix IIO event constraints for Skylake Server (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix filter_tid mask for CHA events on Skylake Server (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix Intel ICX IIO event constraints (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix reference count leak in __uncore_imc_init_box() (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix reference count leak in snr_uncore_mmio_map() (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix reference count leak in hswep_has_limit_sbox() (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Fix reference count leak in sad_cfg_iio_topology() (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Make set_mapping() procedure void (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Update sysfs-devices-mapping file (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Enable UPI topology discovery for Sapphire Rapids (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Enable UPI topology discovery for Icelake Server (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Get UPI NodeID and GroupID (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Enable UPI topology discovery for Skylake Server (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Generalize get_topology() for SKX PMUs (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Disable I/O stacks to PMU mapping on ICX-D (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Clear attr_update properly (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Introduce UPI topology type (Michael Petlan) [2154044]
- perf/x86/intel/uncore: Generalize IIO topology support (Michael Petlan) [2154044]

* Wed Feb 15 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-469.el8]
- net/mlx4: Check retval of mlx4_bitmap_init (Amir Tzin) [2150787]
- net/mlx4: Fix error check for dma_map_sg (Amir Tzin) [2150787]
- net/mlx4_en: Fix wrong return value on ioctl EEPROM query failure (Amir Tzin) [2150787]
- RDMA/mlx4: Avoid flush_scheduled_work() usage (Amir Tzin) [2150787]
- net: mellanox: fix open-coded for_each_set_bit() (Amir Tzin) [2150787]
- tracing: Add linear buckets to histogram logic (Jerome Marchand) [2161509]
- configs/generic: enable CONFIG_RTC_SYSTOHC (Marcelo Tosatti) [2135417]
- watchdog: fix UAF in reboot notifier handling in watchdog core code (Wander Lairson Costa) [2131308]

* Tue Feb 14 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-468.el8]
- drm/i915/fbdev: do not create fbdev if HPD is suspended (Jocelyn Falempe) [2156006]
- drm/i915/fbdev: suspend HPD before fbdev unregistration (Jocelyn Falempe) [2156006]
- drm/i915/hpd: suspend MST at the end of intel_modeset_driver_remove (Jocelyn Falempe) [2156006]
- drm/i915/gvt: fix vgpu debugfs clean in remove (Jocelyn Falempe) [2115903]
- drm/i915/gvt: fix gvt debugfs destroy (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix kernel warning during topology setup (Jocelyn Falempe) [2115903]
- Revert "drm/amd/display: Enable Freesync Video Mode by default" (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix double release compute pasid (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix kfd_process_device_init_vm error handling (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix size validation for non-exclusive domains (v4) (Jocelyn Falempe) [2115903]
- drm/i915/gvt: fix double free bug in split_2MB_gtt_entry (Jocelyn Falempe) [2115903]
- drm/i915: unpin on error in intel_vgpu_shadow_mm_pin() (Jocelyn Falempe) [2115903]
- drm/amd/pm: correct the fan speed retrieving in PWM for some SMU13 asics (Jocelyn Falempe) [2115903]
- drm/amd/pm: bump SMU13.0.0 driver_if header to version 0x34 (Jocelyn Falempe) [2115903]
- drm/amd/pm: add missing SMU13.0.7 mm_dpm feature mapping (Jocelyn Falempe) [2115903]
- drm/amd/pm: add missing SMU13.0.0 mm_dpm feature mapping (Jocelyn Falempe) [2115903]
- drm/i915/migrate: Account for the reserved_space (Jocelyn Falempe) [2115903]
- drm/i915: improve the catch-all evict to handle lock contention (Jocelyn Falempe) [2115903]
- drm/amdgpu: make display pinning more flexible (v2) (Jocelyn Falempe) [2115903]
- drm/amdgpu: handle polaris10/11 overlap asics (v2) (Jocelyn Falempe) [2115903]
- drm/amd/display: Add DCN314 display SG Support (Jocelyn Falempe) [2115903]
- drm/i915/ttm: consider CCS for backup objects (Jocelyn Falempe) [2115903]
- drm/i915/dsi: fix VBT send packet port selection for dual link DSI (Jocelyn Falempe) [2115903]
- drm/vmwgfx: Validate the box size for the snooped cursor (Jocelyn Falempe) [2115903]
- drm/connector: send hotplug uevent on connector cleanup (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix mmhub register base coding error (Jocelyn Falempe) [2115903]
- drm/amd/pm: correct SMU13.0.0 pstate profiling clock settings (Jocelyn Falempe) [2115903]
- drm/amd/pm: update SMU13.0.0 reported maximum shader clock (Jocelyn Falempe) [2115903]
- drm/amdgpu: skip MES for S0ix as well since it's part of GFX (Jocelyn Falempe) [2115903]
- drm/amd/display: revert Disable DRR actions during state commit (Jocelyn Falempe) [2115903]
- drm/amd/pm: avoid large variable on kernel stack (Jocelyn Falempe) [2115903]
- drm/i915/display: Don't disable DDI/Transcoder when setting phy test pattern (Jocelyn Falempe) [2115903]
- drm/sti: Fix return type of sti_{dvo,hda,hdmi}_connector_mode_valid() (Jocelyn Falempe) [2115903]
- drm/fsl-dcu: Fix return type of fsl_dcu_drm_connector_mode_valid() (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix DTBCLK disable requests and SRC_SEL programming (Jocelyn Falempe) [2115903]
- drm/amd/display: Use the largest vready_offset in pipe group (Jocelyn Falempe) [2115903]
- drm/amd/display: fix array index out of bound error in bios parser (Jocelyn Falempe) [2115903]
- drm/amd/display: Workaround to increase phantom pipe vactive in pipesplit (Jocelyn Falempe) [2115903]
- drm/sti: Use drm_mode_copy() (Jocelyn Falempe) [2115903]
- drm/amd/display: Disable DRR actions during state commit (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix type of second parameter in odn_edit_dpm_table() callback (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix type of second parameter in trans_msg() callback (Jocelyn Falempe) [2115903]
- Revert "drm/amd/display: Limit max DSC target bpp for specific monitors" (Jocelyn Falempe) [2115903]
- drm/edid: add a quirk for two LG monitors to get them to work on 10bpc (Jocelyn Falempe) [2115903]
- drm/amd/display: prevent memory leak (Jocelyn Falempe) [2115903]
- drm/i915/bios: fix a memory leak in generate_lfp_data_ptrs (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix memory leakage (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix PCI device refcount leak in amdgpu_atrm_get_bios() (Jocelyn Falempe) [2115903]
- drm/radeon: Fix PCI device refcount leak in radeon_atrm_get_bios() (Jocelyn Falempe) [2115903]
- amdgpu/nv.c: Corrected typo in the video capabilities resolution (Jocelyn Falempe) [2115903]
- drm/amd/pm/smu11: BACO is supported when it's in BACO state (Jocelyn Falempe) [2115903]
- drm/tegra: Add missing clk_disable_unprepare() in tegra_dc_probe() (Jocelyn Falempe) [2115903]
- drm/i915/guc: make default_lists const data (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix pci device refcount leak (Jocelyn Falempe) [2115903]
- drm/fourcc: Fix vsub/hsub for Q410 and Q401 (Jocelyn Falempe) [2115903]
- amdgpu/pm: prevent array underflow in vega20_odn_edit_dpm_table() (Jocelyn Falempe) [2115903]
- drm/radeon: Add the missed acpi_put_table() to fix memory leak (Jocelyn Falempe) [2115903]
- drm/ttm: fix undefined behavior in bit shift for TTM_TT_FLAG_PRIV_POPULATED (Jocelyn Falempe) [2115903]
- drm/panel/panel-sitronix-st7701: Remove panel on DSI attach failure (Jocelyn Falempe) [2115903]
- drm/amd/display: wait for vblank during pipe programming (Jocelyn Falempe) [2115903]
- drm/i915/guc: Fix GuC error capture sizing estimation and reporting (Jocelyn Falempe) [2115903]
- drm/i915/guc: Add error-capture init warnings when needed (Jocelyn Falempe) [2115903]
- drm/i915/guc: Make GuC log sizes runtime configurable (Jocelyn Falempe) [2115903]
- drm/i915/guc: Fix capture size warning and bump the size (Jocelyn Falempe) [2115903]
- drm/i915/guc: Add a helper for log buffer size (Jocelyn Falempe) [2115903]
- drm/i915: Fix compute pre-emption w/a to apply to compute engines (Jocelyn Falempe) [2115903]
- drm/i915/guc: Limit scheduling properties to avoid overflow (Jocelyn Falempe) [2115903]
- drm/bridge: it6505: Initialize AUX channel in it6505_i2c_probe (Jocelyn Falempe) [2115903]
- drm/amdgpu/powerplay/psm: Fix memory leak in power state init (Jocelyn Falempe) [2115903]
- drm/bridge: adv7533: remove dynamic lane switching from adv7533 bridge (Jocelyn Falempe) [2115903]
- drm/atomic-helper: Don't allocate new plane state in CRTC check (Jocelyn Falempe) [2115903]
- drm/amdgpu/vcn: update vcn4 fw shared data structure (Jocelyn Falempe) [2115903]
- drm: bridge: dw_hdmi: fix preference of RGB modes over YUV420 (Jocelyn Falempe) [2115903]
- drm/bridge: ti-sn65dsi86: Fix output polarity setting bug (Jocelyn Falempe) [2115903]
- drm/vmwgfx: Fix race issue calling pin_user_pages (Jocelyn Falempe) [2115903]
- drm/shmem-helper: Avoid vm_open error paths (Jocelyn Falempe) [2115903]
- drm/shmem-helper: Remove errant put in error path (Jocelyn Falempe) [2115903]
- drm/amd/display: fix array index out of bound error in DCN32 DML (Jocelyn Falempe) [2115903]
- drm/amdgpu/sdma_v4_0: turn off SDMA ring buffer in the s2idle suspend (Jocelyn Falempe) [2115903]
- drm/vmwgfx: Don't use screen objects when SEV is active (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix use-after-free during gpu recovery (Jocelyn Falempe) [2115903]
- drm/amd/display: Use new num clk levels struct for max mclk index (Jocelyn Falempe) [2115903]
- drm/amd/display: Avoid setting pixel rate divider to N/A (Jocelyn Falempe) [2115903]
- drm/amd/display: Use viewport height for subvp mall allocation size (Jocelyn Falempe) [2115903]
- drm/i915: Remove non-existent pipes from bigjoiner pipe mask (Jocelyn Falempe) [2115903]
- drm/i915: Never return 0 if not all requests retired (Jocelyn Falempe) [2115903]
- drm/i915: Fix negative value passed as remaining time (Jocelyn Falempe) [2115903]
- drm/amdgpu: enable Vangogh VCN indirect sram mode (Jocelyn Falempe) [2115903]
- drm/amdgpu: temporarily disable broken Clang builds due to blown stack-frame (Jocelyn Falempe) [2115903]
- drm/amd/pm: update driver if header for smu_13_0_7 (Jocelyn Falempe) [2115903]
- drm/amd/pm: update driver-if header for smu_v13_0_10 (Jocelyn Falempe) [2115903]
- drm/amd/pm: add smu_v13_0_10 driver if version (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix userptr HMM range handling v2 (Jocelyn Falempe) [2115903]
- drm/amdgpu: cleanup error handling in amdgpu_cs_parser_bos (Jocelyn Falempe) [2115903]
- drm/amdgpu: move setting the job resources (Jocelyn Falempe) [2115903]
- drm/amdgpu: Partially revert "drm/amdgpu: update drm_display_info correctly when the edid is read" (Jocelyn Falempe) [2115903]
- drm/amdgpu: always register an MMU notifier for userptr (Jocelyn Falempe) [2115903]
- drm/amd/display: Update soc bounding box for dcn32/dcn321 (Jocelyn Falempe) [2115903]
- drm/amd/amdgpu: reserve vm invalidation engine for firmware (Jocelyn Falempe) [2115903]
- drm/amdgpu: Enable Aldebaran devices to report CU Occupancy (Jocelyn Falempe) [2115903]
- drm/amdgpu/psp: don't free PSP buffers on suspend (Jocelyn Falempe) [2115903]
- drm/amd/display: No display after resume from WB/CB (Jocelyn Falempe) [2115903]
- drm/amd/dc/dce120: Fix audio register mapping, stop triggering KASAN (Jocelyn Falempe) [2115903]
- drm/display/dp_mst: Fix drm_dp_mst_add_affected_dsc_crtcs() return code (Jocelyn Falempe) [2115903]
- drm/i915/ttm: never purge busy objects (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix a memory limit issue (Jocelyn Falempe) [2115903]
- drm/amdgpu: disable BACO support on more cards (Jocelyn Falempe) [2115903]
- drm/amd/display: use uclk pstate latency for fw assisted mclk validation dcn32 (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix calculation for cursor CAB allocation (Jocelyn Falempe) [2115903]
- drm/amd/display: Update MALL SS NumWays calculation (Jocelyn Falempe) [2115903]
- drm/amd/display: Add debug option for allocating extra way for cursor (Jocelyn Falempe) [2115903]
- drm/amd/display: Added debug option for forcing subvp num ways (Jocelyn Falempe) [2115903]
- drm/amdkfd: update GFX11 CWSR trap handler (Jocelyn Falempe) [2115903]
- drm/amdgpu: Enable SA software trap. (Jocelyn Falempe) [2115903]
- dma-buf: Use dma_fence_unwrap_for_each when importing fences (Jocelyn Falempe) [2115903]
- dma-buf: fix racing conflict of dma_heap_add() (Jocelyn Falempe) [2115903]
- drm/i915: Fix warn in intel_display_power_*_domain() functions (Jocelyn Falempe) [2115903]
- drm/amd/display: only fill dirty rectangles when PSR is enabled (Jocelyn Falempe) [2115903]
- drm/amdgpu: Drop eviction lock when allocating PT BO (Jocelyn Falempe) [2115903]
- Revert "drm/amdgpu: Revert "drm/amdgpu: getting fan speed pwm for vega10 properly"" (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix gpio port mapping issue (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix FCLK deviation and tool compile issues (Jocelyn Falempe) [2115903]
- drm/amd/display: Zeromem mypipe heap struct before using it (Jocelyn Falempe) [2115903]
- drm: panel-orientation-quirks: Add quirk for Acer Switch V 10 (SW5-017) (Jocelyn Falempe) [2115903]
- drm: panel-orientation-quirks: Add quirk for Nanote UMPC-01 (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix prefetch calculations for dcn32 (Jocelyn Falempe) [2115903]
- drm/amd/display: don't enable DRM CRTC degamma property for DCE (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix optc2_configure warning on dcn314 (Jocelyn Falempe) [2115903]
- drm/amd/display: Support parsing VRAM info v3.0 from VBIOS (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix access timeout to DPIA AUX at boot time (Jocelyn Falempe) [2115903]
- drm/amd/display: Add HUBP surface flip interrupt handler (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix invalid DPIA AUX reply causing system hang (Jocelyn Falempe) [2115903]
- drm/display: Don't assume dual mode adaptors support i2c sub-addressing (Jocelyn Falempe) [2115903]
- drm/amd/pm: fix SMU13 runpm hang due to unintentional workaround (Jocelyn Falempe) [2115903]
- drm/amd/pm: enable runpm support over BACO for SMU13.0.0 (Jocelyn Falempe) [2115903]
- drm/amd/pm: enable runpm support over BACO for SMU13.0.7 (Jocelyn Falempe) [2115903]
- drm: Fix potential null-ptr-deref in drm_vblank_destroy_worker() (Jocelyn Falempe) [2115903]
- drm/drv: Fix potential memory leak in drm_dev_init() (Jocelyn Falempe) [2115903]
- drm/panel: simple: set bpc field for logic technologies displays (Jocelyn Falempe) [2115903]
- drm/amd/display: Investigate tool reported FCLK P-state deviations (Jocelyn Falempe) [2115903]
- drm/amd/display: Round up DST_after_scaler to nearest int (Jocelyn Falempe) [2115903]
- drm/amd/display: Use forced DSC bpp in DML (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix DCN32 DSC delay calculation (Jocelyn Falempe) [2115903]
- drm/amd: Fail the suspend if resources can't be evicted (Jocelyn Falempe) [2115903]
- drm/amdgpu: set fb_modifiers_not_supported in vkms (Jocelyn Falempe) [2115903]
- drm/amd/display: Enable timing sync on DCN32 (Jocelyn Falempe) [2115903]
- drm/amd/display: Ignore Cable ID Feature (Jocelyn Falempe) [2115903]
- drm/imx: imx-tve: Fix return type of imx_tve_connector_mode_valid (Jocelyn Falempe) [2115903]
- drm/scheduler: fix fence ref counting (Jocelyn Falempe) [2115903]
- drm/amd/display: Don't return false if no stream (Jocelyn Falempe) [2115903]
- drm/amd/display: Remove wrong pipe control lock (Jocelyn Falempe) [2115903]
- drm/amdgpu: Adjust MES polling timeout for sriov (Jocelyn Falempe) [2115903]
- drm/amdkfd: Migrate in CPU page fault use current mm (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix error handling in kfd_criu_restore_events (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix error handling in criu_checkpoint (Jocelyn Falempe) [2115903]
- drm/amdgpu: disable BACO on special BEIGE_GOBY card (Jocelyn Falempe) [2115903]
- drm/amdgpu: workaround for TLB seq race (Jocelyn Falempe) [2115903]
- drm/amd/display: Update SR watermarks for DCN314 (Jocelyn Falempe) [2115903]
- drm/amd/pm: update SMU IP v13.0.4 msg interface header (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix reg timeout in enc314_enable_fifo (Jocelyn Falempe) [2115903]
- drm/i915/dmabuf: fix sg_table handling in map_dma_buf (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix the lpfn checking condition in drm buddy (Jocelyn Falempe) [2115903]
- drm/i915: Do not set cache_dirty for DGFX (Jocelyn Falempe) [2115903]
- drm/i915/psr: Send update also on invalidate (Jocelyn Falempe) [2115903]
- drm/vc4: Fix missing platform_unregister_drivers() call in vc4_drm_register() (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix NULL pointer dereference in svm_migrate_to_ram() (Jocelyn Falempe) [2115903]
- drm/amdkfd: handle CPU fault on COW mapping (Jocelyn Falempe) [2115903]
- drm/amd/display: Set memclk levels to be at least 1 for dcn32 (Jocelyn Falempe) [2115903]
- drm/amd/display: Limit dcn32 to 1950Mhz display clock (Jocelyn Falempe) [2115903]
- drm/amd/display: Acquire FCLK DPM levels on DCN32 (Jocelyn Falempe) [2115903]
- drm/i915/sdvo: Grab mode_config.mutex during LVDS init to avoid WARNs (Jocelyn Falempe) [2115903]
- drm/i915: Simplify intel_panel_add_edid_alt_fixed_modes() (Jocelyn Falempe) [2115903]
- drm/i915: Allow more varied alternate fixed modes for panels (Jocelyn Falempe) [2115903]
- drm/i915/sdvo: Setup DDC fully before output init (Jocelyn Falempe) [2115903]
- drm/i915/sdvo: Filter out invalid outputs more sensibly (Jocelyn Falempe) [2115903]
- drm/amd/display: Update DSC capabilitie for DCN314 (Jocelyn Falempe) [2115903]
- drm/amd/display: Update latencies on DCN321 (Jocelyn Falempe) [2115903]
- drm/amdgpu: disable GFXOFF during compute for GFX11 (Jocelyn Falempe) [2115903]
- drm/i915: stop abusing swiotlb_max_segment (Jocelyn Falempe) [2115903]
- drm/rockchip: fix fbdev on non-IOMMU devices (Jocelyn Falempe) [2115903]
- drm/rockchip: dw_hdmi: filter regulator -EPROBE_DEFER error messages (Jocelyn Falempe) [2115903]
- drm/amdgpu: dequeue mes scheduler during fini (Jocelyn Falempe) [2115903]
- drm/amdgpu: Program GC registers through RLCG interface in gfx_v11/gmc_v11 (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix type of reset_type parameter in hqd_destroy() callback (Jocelyn Falempe) [2115903]
- drm/amd/pm: skip loading pptable from driver on secure board for smu_v13_0_10 (Jocelyn Falempe) [2115903]
- drm/amdgpu: set vm_update_mode=0 as default for Sienna Cichlid in SRIOV case (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix memory leak in kfd_mem_dmamap_userptr() (Jocelyn Falempe) [2115903]
- drm/i915/dp: Reset frl trained flag before restarting FRL training (Jocelyn Falempe) [2115903]
- drm/i915/dgfx: Keep PCI autosuspend control 'on' by default on all dGPU (Jocelyn Falempe) [2115903]
- drm/bridge: ps8640: Add back the 50 ms mystery delay after HPD (Jocelyn Falempe) [2115903]
- drm/msm: Fix return type of mdp4_lvds_connector_mode_valid (Jocelyn Falempe) [2115903]
- drm/msm/hdmi: fix memory corruption with too many bridges (Jocelyn Falempe) [2115903]
- drm/msm/dsi: fix memory corruption with too many bridges (Jocelyn Falempe) [2115903]
- drm/amdkfd: correct the cache info for gfx1036 (Jocelyn Falempe) [2115903]
- drm/amdkfd: update gfx1037 Lx cache setting (Jocelyn Falempe) [2115903]
- drm/amd/display: Revert logic for plane modifiers (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix pstate setting issue (Jocelyn Falempe) [2115903]
- drm/amdgpu: disallow gfxoff until GC IP blocks complete s2idle resume (Jocelyn Falempe) [2115903]
- drm/amdgpu: Remove ATC L2 access for MMHUB 2.1.x (Jocelyn Falempe) [2115903]
- drm/i915: Extend Wa_1607297627 to Alderlake-P (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix for BO move issue (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix VRAM BO swap issue (Jocelyn Falempe) [2115903]
- drm/vc4: Add module dependency on hdmi-codec (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix sdma doorbell init ordering on APUs (Jocelyn Falempe) [2115903]
- drm/amd/pm: update SMU IP v13.0.4 driver interface version (Jocelyn Falempe) [2115903]
- drm/amd/pm: fulfill SMU13.0.0 cstate control interface (Jocelyn Falempe) [2115903]
- drm/amd/pm: disable cstate feature for gpu reset scenario (Jocelyn Falempe) [2115903]
- drm/amd/pm: add SMU IP v13.0.4 IF version define to V7 (Jocelyn Falempe) [2115903]
- drm/amd/pm: fulfill SMU13.0.7 cstate control interface (Jocelyn Falempe) [2115903]
- drm/i915/bios: Use hardcoded fp_timing size for generating LFP data pointers (Jocelyn Falempe) [2115903]
- drm/i915/bios: Validate fp_timing terminator presence (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix build breakage with CONFIG_DEBUG_FS=n (Jocelyn Falempe) [2115903]
- Revert "drm/amd/display: correct hostvm flag" (Jocelyn Falempe) [2115903]
- drm/amdkfd: Fix UBSAN shift-out-of-bounds warning (Jocelyn Falempe) [2115903]
- drm/amd/display: polling vid stream status in hpo dp blank (Jocelyn Falempe) [2115903]
- drm/amd/display: Remove interface for periodic interrupt 1 (Jocelyn Falempe) [2115903]
- drm/dp: Don't rewrite link config when setting phy test pattern (Jocelyn Falempe) [2115903]
- drm/amdgpu: fix initial connector audio value (Jocelyn Falempe) [2115903]
- drm/amd/display: correct hostvm flag (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix urgent latency override for DCN32/DCN321 (Jocelyn Falempe) [2115903]
- drm/amdgpu: SDMA update use unlocked iterator (Jocelyn Falempe) [2115903]
- drm: panel-orientation-quirks: Add quirk for Aya Neo Air (Jocelyn Falempe) [2115903]
- drm: panel-orientation-quirks: Add quirk for Anbernic Win600 (Jocelyn Falempe) [2115903]
- drm/vc4: vec: Fix timings for VEC modes (Jocelyn Falempe) [2115903]
- drm/admgpu: Skip CG/PG on SOC21 under SRIOV VF (Jocelyn Falempe) [2115903]
- drm/amdgpu: Skip the program of MMMC_VM_AGP_* in SRIOV on MMHUB v3_0_0 (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix variable dereferenced before check (Jocelyn Falempe) [2115903]
- drm: bridge: dw_hdmi: only trigger hotplug event on link change (Jocelyn Falempe) [2115903]
- drm/amd: fix potential memory leak (Jocelyn Falempe) [2115903]
- udmabuf: Set ubuf->sg = NULL if the creation of sg table fails (Jocelyn Falempe) [2115903]
- drm/amd/display: fix overflow on MIN_I64 definition (Jocelyn Falempe) [2115903]
- gpu: lontium-lt9611: Fix NULL pointer dereference in lt9611_connector_init() (Jocelyn Falempe) [2115903]
- drm: Prevent drm_copy_field() to attempt copying a NULL pointer (Jocelyn Falempe) [2115903]
- drm: Use size_t type for len variable in drm_copy_field() (Jocelyn Falempe) [2115903]
- drm/nouveau/nouveau_bo: fix potential memory leak in nouveau_bo_alloc() (Jocelyn Falempe) [2115903]
- virtio-gpu: fix shift wrapping bug in virtio_gpu_fence_event_create() (Jocelyn Falempe) [2115903]
- drm/vmwgfx: Fix memory leak in vmw_mksstat_add_ioctl() (Jocelyn Falempe) [2115903]
- drm/amdgpu: Fix memory leak in hpd_rx_irq_create_workqueue() (Jocelyn Falempe) [2115903]
- drm/bochs: fix blanking (Jocelyn Falempe) [2115903]
- drm/virtio: set fb_modifiers_not_supported (Jocelyn Falempe) [2115903]
- drm/bridge: it6505: Fix the order of DP_SET_POWER commands (Jocelyn Falempe) [2115903]
- drm/bridge: megachips: Fix a null pointer dereference bug (Jocelyn Falempe) [2115903]
- drm/amdgpu: add missing pci_disable_device() in amdgpu_pmops_runtime_resume() (Jocelyn Falempe) [2115903]
- drm: fix drm_mipi_dbi build errors (Jocelyn Falempe) [2115903]
- drm/panel: use 'select' for Ili9341 panel driver helpers (Jocelyn Falempe) [2115903]
- drm/virtio: Fix same-context optimization (Jocelyn Falempe) [2115903]
- drm/i915/dg2: Bump up CDCLK for DG2 (Jocelyn Falempe) [2115903]
- drm/dp_mst: fix drm_dp_dpcd_read return value checks (Jocelyn Falempe) [2115903]
- drm/format-helper: Fix test on big endian architectures (Jocelyn Falempe) [2115903]
- drm/bridge: parade-ps8640: Fix regulator supply order (Jocelyn Falempe) [2115903]
- drm/bridge: tc358767: Add of_node_put() when breaking out of loop (Jocelyn Falempe) [2115903]
- drm/bridge: anx7625: Fix refcount bug in anx7625_parse_dt() (Jocelyn Falempe) [2115903]
- drm/virtio: Correct drm_gem_shmem_get_sg_table() error handling (Jocelyn Falempe) [2115903]
- drm/bridge: it6505: Power on downstream device in .atomic_enable (Jocelyn Falempe) [2115903]
- drm/mipi-dsi: Detach devices when removing the host (Jocelyn Falempe) [2115903]
- drm/bridge: Avoid uninitialized variable warning (Jocelyn Falempe) [2115903]
- drm: bridge: adv7511: unregister cec i2c device after cec adapter (Jocelyn Falempe) [2115903]
- drm: bridge: adv7511: fix CEC power down control register offset (Jocelyn Falempe) [2115903]
- drm/amdgpu: Enable F32_WPTR_POLL_ENABLE in mqd (Jocelyn Falempe) [2115903]
- drm/amdgpu: Enable VCN PG on GC11_0_1 (Jocelyn Falempe) [2115903]
- drm/amd/display: explicitly disable psr_feature_enable appropriately (Jocelyn Falempe) [2115903]
- drm/amd/display: Add HUBP surface flip interrupt handler (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix vblank refcount in vrr transition (Jocelyn Falempe) [2115903]
- drm/amd/display: Enable 2 to 1 ODM policy if supported (Jocelyn Falempe) [2115903]
- drm/amd/display: Enable dpia support for dcn314 (Jocelyn Falempe) [2115903]
- drm/amd/display: Validate DSC After Enable All New CRTCs (Jocelyn Falempe) [2115903]
- drm/amd/display: zeromem mypipe heap struct before using it (Jocelyn Falempe) [2115903]
- drm/amd/display: Update PMFW z-state interface for DCN314 (Jocelyn Falempe) [2115903]
- drm/amd/display: Fix watermark calculation (Jocelyn Falempe) [2115903]
- drm/i915: Fix display problems after resume (Jocelyn Falempe) [2115903]
- drm/i915/guc: Fix revocation of non-persistent contexts (Jocelyn Falempe) [2115903]
- drm/i915/gt: Use i915_vm_put on ppgtt_create error paths (Jocelyn Falempe) [2115903]
- drm/nouveau: fix a use-after-free in nouveau_gem_prime_import_sg_table() (Jocelyn Falempe) [2115903]
- drm/udl: Restore display mode on resume (Jocelyn Falempe) [2115903]
- drm/virtio: Use appropriate atomic state in virtio_gpu_plane_cleanup_fb() (Jocelyn Falempe) [2115903]
- drm/virtio: Unlock reservations on dma_resv_reserve_fences() error (Jocelyn Falempe) [2115903]
- drm/virtio: Unlock reservations on virtio_gpu_object_shmem_init() error (Jocelyn Falempe) [2115903]
- drm/virtio: Check whether transferred 2D BO is shmem (Jocelyn Falempe) [2115903]
- Revert "drm/amdgpu: use dirty framebuffer helper" (Jocelyn Falempe) [2115903]

* Mon Feb 13 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-467.el8]
- nvme: fix SRCU protection of nvme_ns_head list (Ewan D. Milne) [2113865]
- perf vendor events power10: Fix hv-24x7 metric events (Mamatha Inamdar) [2149192]
- perf tests: Fix 'perf probe' error log check in skip_if_no_debuginfo (Mamatha Inamdar) [2149192]
- perf tests: Fix *probe_vfs_getname.sh test failures (Mamatha Inamdar) [2149192]
- blk-cgroup: Optimize blkcg_rstat_flush() (Waiman Long) [2162173]
- blk-cgroup: Return -ENOMEM directly in blkcg_css_alloc() error path (Waiman Long) [2162173]
- blk-cgroup: factor out blkcg_iostat_update() (Waiman Long) [2162173]
- mm/memcg: Free percpu stats memory of dying memcg's again (Waiman Long) [2162173]
- memcg: sync flush only if periodic flush is delayed (Waiman Long) [2162173]
- memcg: better bounds on the memcg stats updates (Waiman Long) [2162173]
- memcg: unify memcg stat flushing (Waiman Long) [2162173]
- memcg: flush stats only if updated (Waiman Long) [2162173]
- memcg: flush lruvec stats in the refault (Waiman Long) [2162173]
- memcg: infrastructure to flush memcg stats (Waiman Long) [2162173]
- memcg: switch lruvec stats to rstat (Waiman Long) [2162173]
- mm/memcg: Remove mem_cgroup_per_node from being kABI protected (Waiman Long) [2162173]
- mm/memcg: Revert "Free percpu stats memory of dying memcg's" (Waiman Long) [2162173]

* Mon Feb 13 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-466.el8]
- virt/sev-guest: Prevent IV reuse in the SNP guest driver (John Allen) [2087262]
- virt/sev-guest: Add a MODULE_ALIAS (John Allen) [2087262]
- virt/sev-guest: Remove unnecessary free in init_crypto() (John Allen) [2087262]
- x86/sev: Don't use cc_platform_has() for early SEV-SNP calls (John Allen) [2087262]
- x86/boot: Don't propagate uninitialized boot_params->cc_blob_address (John Allen) [2087262]
- x86/idt: Rework IDT setup for boot CPU (John Allen) [2087262]
- x86/cpu: Init AP exception handling from cpu_init_secondary() (John Allen) [2087262]
- x86/idt: Cleanup trap_init() (John Allen) [2087262]
- x86/idt: Annotate alloc_intr_gate() with __init (John Allen) [2087262]
- redhat/configs: enable CONFIG_SEV_GUEST (John Allen) [2087262]
- virt: sev-guest: Pass the appropriate argument type to iounmap() (John Allen) [2087262]
- x86/compressed/64: Add identity mappings for setup_data entries (John Allen) [2087262]
- x86/sev: Mark the code returning to user space as syscall gap (John Allen) [2087262]
- x86/sev: Annotate stack change in the #VC handler (John Allen) [2087262]
- x86/sev: Remove duplicated assignment to variable info (John Allen) [2087262]
- x86/sev: Fix address space sparse warning (John Allen) [2087262]
- x86/sev: Get the AP jump table address from secrets page (John Allen) [2087262]
- x86/sev: Add missing __init annotations to SEV init routines (John Allen) [2087262]
- virt: sevguest: Rename the sevguest dir and files to sev-guest (John Allen) [2087262]
- virt: sevguest: Change driver name to reflect generic SEV support (John Allen) [2087262]
- x86/boot: Put globals that are accessed early into the .data section (John Allen) [2087262]
- x86/boot: Add an efi.h header for the decompressor (John Allen) [2087262]
- virt: sevguest: Fix bool function returning negative value (John Allen) [2087262]
- virt: sevguest: Fix return value check in alloc_shared_pages() (John Allen) [2087262]
- x86/sev: Unroll string mmio with CC_ATTR_GUEST_UNROLL_STRING_IO (John Allen) [2087262]
- x86/sev-es: Replace open-coded hlt-loop with sev_es_terminate() (John Allen) [2087262]
- virt: sevguest: Add documentation for SEV-SNP CPUID Enforcement (John Allen) [2087262]
- virt: sevguest: Add support to get extended report (John Allen) [2087262]
- virt: sevguest: Add support to derive key (John Allen) [2087262]
- virt: Add SEV-SNP guest driver (John Allen) [2087262]
- x86/sev: Register SEV-SNP guest request platform device (John Allen) [2087262]
- x86/sev: Provide support for SNP guest request NAEs (John Allen) [2087262]
- x86/sev: Add a sev= cmdline option (John Allen) [2087262]
- x86/sev: Use firmware-validated CPUID for SEV-SNP guests (John Allen) [2087262]
- x86/sev: Add SEV-SNP feature detection/setup (John Allen) [2087262]
- x86/sev: Check SME/SEV support in CPUID first (John Allen) [2087262]
- x86/compressed/64: Add identity mapping for Confidential Computing blob (John Allen) [2087262]
- x86/compressed: Export and rename add_identity_map() (John Allen) [2087262]
- x86/compressed: Use firmware-validated CPUID leaves for SEV-SNP guests (John Allen) [2087262]
- x86/compressed: Add SEV-SNP feature detection/setup (John Allen) [2087262]
- x86/boot: Add a pointer to Confidential Computing blob in bootparams (John Allen) [2087262]
- x86/boot: Preserve boot_params.secure_boot from sanitizing (John Allen) [2087262]
- x86/boot: Fix boot regression caused by bootparam sanitizing (John Allen) [2087262]
- x86/boot: Save fields explicitly, zero out everything else (John Allen) [2087262]
- x86/compressed/64: Add support for SEV-SNP CPUID table in #VC handlers (John Allen) [2087262]
- x86/sev: Move MSR-based VMGEXITs for CPUID to helper (John Allen) [2087262]
- KVM: x86: Move lookup of indexed CPUID leafs to helper (John Allen) [2087262]
- x86/boot: Add Confidential Computing type to setup_data (John Allen) [2087262]
- x86/compressed/acpi: Move EFI kexec handling into common code (John Allen) [2087262]
- x86/compressed/acpi: Move EFI vendor table lookup to helper (John Allen) [2087262]
- x86/compressed/acpi: Move EFI config table lookup to helper (John Allen) [2087262]
- x86/compressed/acpi: Move EFI system table lookup to helper (John Allen) [2087262]
- x86/compressed/acpi: Move EFI detection to helper (John Allen) [2087262]
- x86/head/64: Re-enable stack protection (John Allen) [2087262]
- x86/sev: Use SEV-SNP AP creation to start secondary CPUs (John Allen) [2087262]
- x86/apic/of: Fix CPU devicetree-node lookups (John Allen) [2087262]
- x86/mm: Validate memory when changing the C-bit (John Allen) [2087262]
- x86/kernel: Validate ROM memory before accessing when SEV-SNP is active (John Allen) [2087262]
- x86/kernel: Mark the .bss..decrypted section as shared in the RMP table (John Allen) [2087262]
- x86/sev: Add helper for validating pages in early enc attribute changes (John Allen) [2087262]
- x86/sev: Register GHCB memory when SEV-SNP is active (John Allen) [2087262]
- x86/compressed: Register GHCB memory when SEV-SNP is active (John Allen) [2087262]
- x86/compressed: Add helper for validating pages in the decompression stage (John Allen) [2087262]
- x86/sev: Check the VMPL level (John Allen) [2087262]
- x86/sev: Add a helper for the PVALIDATE instruction (John Allen) [2087262]
- x86/sev: Check SEV-SNP features support (John Allen) [2087262]
- x86/mm: Extend cc_attr to include AMD SEV-SNP (John Allen) [2087262]
- x86/sev: Detect/setup SEV/SME features earlier in boot (John Allen) [2087262]
- x86/compressed/64: Detect/setup SEV/SME features earlier during boot (John Allen) [2087262]
- x86/boot: Use MSR read/write helpers instead of inline assembly (John Allen) [2087262]
- x86/boot: Introduce helpers for MSR reads/writes (John Allen) [2087262]
- KVM: SVM: Update the SEV-ES save area mapping (John Allen) [2087262]
- KVM: SVM: Create a separate mapping for the GHCB save area (John Allen) [2087262]
- KVM: SVM: Create a separate mapping for the SEV-ES save area (John Allen) [2087262]
- KVM: SVM: Define sev_features and VMPL field in the VMSA (John Allen) [2087262]
- x86/sev: Remove do_early_exception() forward declarations (John Allen) [2087262]
- x86/sev: Make the #VC exception stacks part of the default stacks storage (John Allen) [2087262]
- x86: Increase exception stack sizes (John Allen) [2087262]
- x86/head64: Carve out the guest encryption postprocessing into a helper (John Allen) [2087262]
- x86/sev: Get rid of excessive use of defines (John Allen) [2087262]
- x86/sev: Add defines for GHCB version 2 MSR protocol requests (John Allen) [2087262]
- x86/sev: Make sure IRQs are disabled while GHCB is active (John Allen) [2087262]
- x86/sev: Propagate #GP if getting linear instruction address failed (John Allen) [2087262]
- x86/insn: Extend error reporting from insn_fetch_from_user[_inatomic]() (John Allen) [2087262]
- x86/sev-es: Convert to insn_decode() (John Allen) [2087262]
- x86/sev-es: Split vc_decode_insn() (John Allen) [2087262]
- x86/insn-eval: Make 0 a valid RIP for insn_get_effective_ip() (John Allen) [2087262]
- x86/sev: Fix error message in runtime #VC handler (John Allen) [2087262]
- x86/sev-es: Optimize __sev_es_ist_enter() for better readability (John Allen) [2087262]
- x86/sev: Do not require Hypervisor CPUID bit for SEV guests (John Allen) [2087262]
- x86/boot/compressed/64: Cleanup exception handling before booting kernel (John Allen) [2087262]
- x86/sev-es: Remove subtraction of res variable (John Allen) [2087262]

* Thu Feb 09 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-465.el8]
- net: mlx5: eliminate anonymous module_init & module_exit (Amir Tzin) [2157750]
- net/mlx5: E-switch, Fix switchdev mode after devlink reload (Amir Tzin) [2157750]
- net/mlx5e: Set decap action based on attr for sample (Amir Tzin) [2157750]
- net/mlx5e: QoS, Fix wrongfully setting parent_element_id on MODIFY_SCHEDULING_ELEMENT (Amir Tzin) [2157750]
- net/mlx5: E-switch, Fix setting of reserved fields on MODIFY_SCHEDULING_ELEMENT (Amir Tzin) [2157750]
- net/mlx5e: Avoid false lock dependency warning on tc_ht even more (Amir Tzin) [2157750]
- net/mlx5: fix missing mutex_unlock in mlx5_fw_fatal_reporter_err_work() (Amir Tzin) [2157750]
- net/mlx5: Fix ptp max frequency adjustment range (Amir Tzin) [2157750]
- net/mlx5e: IPoIB, Fix child PKEY interface stats on rx path (Amir Tzin) [2157750]
- net/mlx5e: IPoIB, Block PKEY interfaces with less rx queues than parent (Amir Tzin) [2157750]
- net/mlx5e: IPoIB, Block queue count configuration when sub interfaces are present (Amir Tzin) [2157750]
- net/mlx5e: Verify dev is present for fix features ndo (Amir Tzin) [2157750]
- net/mlx5: Fix command stats access after free (Amir Tzin) [2157750]
- net/mlx5e: TC, Keep mod hdr actions after mod hdr alloc (Amir Tzin) [2157750]
- net/mlx5: check attr pointer validity before dereferencing it (Amir Tzin) [2157750]
- RDMA/mlx5: Fix validation of max_rd_atomic caps for DC (Amir Tzin) [2157750]
- RDMA/mlx5: Fix mlx5_ib_get_hw_stats when used for device (Amir Tzin) [2157750]
- net/mlx5e: Set geneve_tlv_option_0_exist when matching on geneve option (Amir Tzin) [2157750]
- net/mlx5e: Fix hw mtu initializing at XDP SQ allocation (Amir Tzin) [2157750]
- net/mlx5e: Always clear dest encap in neigh-update-del (Amir Tzin) [2157750]
- net/mlx5e: CT: Fix ct debugfs folder name (Amir Tzin) [2157750]
- net/mlx5e: IPoIB, Don't allow CQE compression to be turned on by default (Amir Tzin) [2157750]
- net/mlx5: Fix RoCE setting at HCA level (Amir Tzin) [2157750]
- net/mlx5: Avoid recovery in probe flows (Amir Tzin) [2157750]
- net/mlx5: Fix io_eq_size and event_eq_size params validation (Amir Tzin) [2157750]
- net/mlx5: Add forgotten cleanup calls into mlx5_init_once() error path (Amir Tzin) [2157750]
- net/mlx5: E-Switch, properly handle ingress tagged packets on VST (Amir Tzin) [2157750 2096109]
- dm thin: Use last transaction's pmd->root when commit failed (Benjamin Marzinski) [2162537]
- dm thin: resume even if in FAIL mode (Benjamin Marzinski) [2162537]
- dm cache: set needs_check flag after aborting metadata (Benjamin Marzinski) [2162537]
- dm cache: Fix ABBA deadlock between shrink_slab and dm_cache_metadata_abort (Benjamin Marzinski) [2162537]
- dm thin: Fix ABBA deadlock between shrink_slab and dm_pool_abort_metadata (Benjamin Marzinski) [2162537]
- dm integrity: Fix UAF in dm_integrity_dtr() (Benjamin Marzinski) [2162537]
- dm cache: Fix UAF in destroy() (Benjamin Marzinski) [2162537]
- dm thin: Fix UAF in run_timer_softirq() (Benjamin Marzinski) [2162537]
- dm integrity: clear the journal on suspend (Benjamin Marzinski) [2162537]
- dm integrity: flush the journal on suspend (Benjamin Marzinski) [2162537]
- dm bufio: Fix missing decrement of no_sleep_enabled if dm_bufio_client_create failed (Benjamin Marzinski) [2162537]
- dm ioctl: fix misbehavior if list_versions races with module loading (Benjamin Marzinski) [2162537]

* Thu Feb 09 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-464.el8]
- net: gso: fix panic on frag_list with mixed head alloc types (Jiri Benc) [2136229]
- futex: Resend potentially swallowed owner death notification (Rafael Aquini) [2161526]
- Bluetooth: L2CAP: Fix memory leak in vhci_write (Wander Lairson Costa) [2155872] {CVE-2022-3619}
- net: Use this_cpu_inc() to increment net->core_stats (Antoine Tenart) [2152542]
- vlan: fix memory leak in vlan_newlink() (Xin Long) [2051415]
- vlan: move dev_put into vlan_dev_uninit (Xin Long) [2051415]
- vlan: introduce vlan_dev_free_egress_priority (Xin Long) [2051415]
- vlan: fix memory leak in vlan_dev_set_egress_priority (Xin Long) [2051415]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2103956]
- intel/ixgbevf:fix repeated words in comments (Ken Cox) [2103956]
- intel: remove unused macros (Ken Cox) [2103956]
- ixgbe: propagate XFRM offload state direction instead of flags (Ken Cox) [2103956]
- ixgbevf: add disable link state (Ken Cox) [2103956]
- ixgbevf: clean up some inconsistent indenting (Ken Cox) [2103956]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Ken Cox) [2103956]
- intel: Remove rcu_read_lock() around XDP program invocation (Ken Cox) [2103956]

* Thu Feb 09 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-463.el8]
- RDMA/siw: Always consume all skbuf data in sk_data_ready() upcall. (Kamal Heib) [2141420]
- cifs: fix use-after-free caused by invalid pointer `hostname` (Ronnie Sahlberg) [2154172]
- ceph: blocklist the kclient when receiving corrupted snap trace (Xiubo Li) [2162414]
- ceph: move mount state enum to super.h (Xiubo Li) [2162414]
- xfs: estimate post-merge refcounts correctly (Bill O'Donnell) [2161678]
- xfs: hoist refcount record merge predicates (Bill O'Donnell) [2161678]
- NFS: Fix revalidation of empty readdir pages (Benjamin Coddington) [2166364]
- NFS: Don't deadlock when cookie hashes collide (Benjamin Coddington) [2166364]
- locking/rwsem: Disable preemption in all down_read*() and up_read() code paths (Waiman Long) [2162139]
- locking/rwsem: Prevent non-first waiter from spinning in down_write() slowpath (Waiman Long) [2162139]
- locking/rwsem: Allow slowpath writer to ignore handoff bit if not set by first waiter (Waiman Long) [2162139]
- locking/rwsem: Always try to wake waiters in out_nolock path (Waiman Long) [2162139]
- locking/rwsem: No need to check for handoff bit if wait queue empty (Waiman Long) [2162139]
- locking/rwsem: Make handoff bit handling more consistent (Waiman Long) [2162139]
- dax: fix ENOMEM handling in grab_mapping_entry() (Andrey Albershteyn) [2128474]
- crypto: ccp - Failure on re-initialization due to duplicate sysfs filename (Vladis Dronov) [2130714]
- crypto: ccp - Avoid page allocation failure warning for SEV_GET_ID2 (Vladis Dronov) [2130714]
- crypto: ccp - Add support for TEE for PCI ID 0x14CA (Vladis Dronov) [2130714]
- crypto: ccp - Remove unused struct ccp_crypto_cpu (Vladis Dronov) [2130714]
- crypto: ccp - Add __init/__exit annotations to module init/exit funcs (Vladis Dronov) [2130714]
- i40e: Fix the inability to attach XDP program on downed interface (Ivan Vecera) [2121511]
- mm, compaction: fix fast_isolate_around() to stay within boundaries (Daniel Vacek) [2149309]

* Wed Feb 08 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-462.el8]
- aio: fix mremap after fork null-deref (Jeff Moyer) [2166088]
- mm/hugetlb: use hugetlb_pte_stable in migration race check (Rafael Aquini) [2158120] {CVE-2022-3522}
- mm/hugetlb: fix race condition of uffd missing/minor handling (Rafael Aquini) [2158120] {CVE-2022-3522}
- mm/hugetlb: simplify the code when alloc_huge_page() failed in hugetlb_no_page() (Rafael Aquini) [2158120] {CVE-2022-3522}
- mm/hugetlb: pass the old pte entry value to hugetlb_no_page() (Rafael Aquini) [2158120] {CVE-2022-3522}
- perf/arm-cmn: Add more bits to child node address offset field (Charles Mirabile) [2122267]
- perf/arm-cmn: Decode CAL devices properly in debugfs (Charles Mirabile) [2122267]
- perf/arm-cmn: Fix filter_sel lookup (Charles Mirabile) [2122267]
- drivers/perf: arm_spe: Expose saturating counter to 16-bit (Charles Mirabile) [2122267]
- perf/arm-cmn: Add CMN-700 support (Charles Mirabile) [2122267]
- perf/arm-cmn: Refactor occupancy filter selector (Charles Mirabile) [2122267]
- perf/arm-cmn: Add CMN-650 support (Charles Mirabile) [2122267]
- perf: check return value of armpmu_request_irq() (Charles Mirabile) [2122267]
- arm_pmu: Validate single/group leader events (Charles Mirabile) [2122267]
- perf: qcom_l2_pmu: fix an incorrect NULL check on list iterator (Charles Mirabile) [2122267]
- drivers/perf: arm_pmu: Handle 47 bit counters (Charles Mirabile) [2122267]
- perf/arm-cmn: Update watchpoint format (Charles Mirabile) [2122267]
- perf/arm-cmn: Hide XP PUB events for CMN-600 (Charles Mirabile) [2122267]
- perf: replace bitmap_weight with bitmap_empty where appropriate (Charles Mirabile) [2122267]
- perf: Replace acpi_bus_get_device() (Charles Mirabile) [2122267]
- perf/arm-cmn: Make arm_cmn_debugfs static (Charles Mirabile) [2122267]
- perf/arm-ccn: Use platform_get_irq() to get the interrupt (Charles Mirabile) [2122267]
- perf/smmuv3: Don't cast parameter in bit operations (Charles Mirabile) [2122267]
- perf/smmuv3: Use msi_get_virq() (Charles Mirabile) [2122267]
- perf/smmuv3: Synthesize IIDR from CoreSight ID registers (Charles Mirabile) [2122267]
- perf/arm-cmn: Add debugfs topology info (Charles Mirabile) [2122267]
- perf/arm-cmn: Add CI-700 Support (Charles Mirabile) [2122267]
- perf/arm-cmn: Support new IP features (Charles Mirabile) [2122267]
- devres: provide devm_krealloc() (Charles Mirabile) [2122267]
- devres: move the size check from alloc_dr() into a separate function (Charles Mirabile) [2122267]
- perf/arm-cmn: Demarcate CMN-600 specifics (Charles Mirabile) [2122267]
- perf/arm-cmn: Move group validation data off-stack (Charles Mirabile) [2122267]
- perf/arm-cmn: Optimise DTC counter accesses (Charles Mirabile) [2122267]
- perf/arm-cmn: Optimise DTM counter reads (Charles Mirabile) [2122267]
- perf/arm-cmn: Refactor DTM handling (Charles Mirabile) [2122267]
- perf/arm-cmn: Streamline node iteration (Charles Mirabile) [2122267]
- perf/arm-cmn: Refactor node ID handling (Charles Mirabile) [2122267]
- perf/arm-cmn: Drop compile-test restriction (Charles Mirabile) [2122267]
- perf/arm-cmn: Account for NUMA affinity (Charles Mirabile) [2122267]
- perf/arm-cmn: Fix CPU hotplug unregistration (Charles Mirabile) [2122267]
- drivers/perf: thunderx2_pmu: Change data in size tx2_uncore_event_update() (Charles Mirabile) [2122267]
- perf: qcom_l2_pmu: move to use request_irq by IRQF_NO_AUTOEN flag (Charles Mirabile) [2122267]
- arm_pmu: move to use request_irq by IRQF_NO_AUTOEN flag (Charles Mirabile) [2122267]
- arm64: perf: Fix 64-bit event counter read truncation (Charles Mirabile) [2122267]
- drivers/perf: Replace spin_lock_irqsave to spin_lock (Charles Mirabile) [2122267]
- arm_pmu: arm64: Use NMIs for PMU (Charles Mirabile) [2122267]
- arm_pmu: Introduce pmu_irq_ops (Charles Mirabile) [2122267]
- arm64: perf: Defer irq_work to IPI_IRQ_WORK (Charles Mirabile) [2122267]
- arm64: perf: Remove PMU locking (Charles Mirabile) [2122267]
- arm64: perf: Avoid PMXEV* indirection (Charles Mirabile) [2122267]
- arm64: perf: Add missing ISB in armv8pmu_enable_counter() (Charles Mirabile) [2122267]
- perf: arm_spe: Remove unnecessary zero check on 'nr_pages' (Charles Mirabile) [2122267]
- drivers/perf: arm_pmu_acpi: Fix incorrect checking of gicc pointer (Charles Mirabile) [2122267]
- perf/smmuv3: Use platform_get_irq_optional() for wired interrupt (Charles Mirabile) [2122267]

* Wed Feb 08 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-461.el8]
- wifi: rtw89: Add missing check for alloc_workqueue (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: fix potential leak in rtw89_append_probe_req_ie() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix initialization of rx->link and rx->link_sta (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: Drop stations iterator where the iterator function may sleep (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath9k: use proper statements in conditionals (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix MLO + AP_VLAN check (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: fix coverity uninit_use_in_call in mt76_connac2_reverse_frag0_hdr_trans() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: nl80211: Add checks for nla_nest_start() in nl80211_send_iface() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: Add missing __packed annotation of struct mt7921_clc (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: do not send firmware FW_FEATURE_NON_DL region (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: Fix use after rcu_read_unlock in rtl8xxxu_bss_info_changed (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: fix physts IE page check (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: fix wrong power after multiple SAR set (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: Fix some error handling path in rtw89_core_sta_assoc() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: use u32_encode_bits() to fill MAC quota value (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: fix reporting of TX AGGR histogram (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix ifdef symbol name (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: fix firmware assert during bandwidth change for peer sta (Jose Ignacio Tornos Martinez) [2136125]
- Revert "mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD" (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: gen2: Turn on the rate control (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: fix warning in dma_free_coherent() of memory chunks while recovery (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: check link ID in auth/assoc continuation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: mlme: fix null-ptr deref on failed assoc (Jose Ignacio Tornos Martinez) [2136125]
- wifi: fix multi-link element subelement iteration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: fix antenna signal are way off in monitor mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac8021: fix possible oob access in ieee80211_get_rate_duration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: don't allow multi-BSSID in S1G (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: fix buffer overflow in elem comparison (Jose Ignacio Tornos Martinez) [2136125]
- net: mhi: Fix memory leak in mhi_net_dellink() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Fix QCN9074 firmware boot on x86 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: Set TWT Information Frame Disabled bit as 1 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: Fix ack frame idr leak when mesh has no route (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix general-protection-fault in ieee80211_subif_start_xmit() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: fix debugfs attribute ps with rc table support (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: Fix bitrates overflow issue (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: fix memory leak in query_regdb_file() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix memory free error when registering wiphy fail (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: silence a sparse RCU warning (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: use explicitly signed or unsigned types (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: mac: fix reading 16 bytes from a region of size 0 warning (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: fix rx checksum offload on mt7615/mt7915/mt7921 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: fix receiving LLC packets on mt7615/mt7915 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: update hidden BSSes to avoid WARN_ON (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix crash in beacon protection for P2P-device (Jose Ignacio Tornos Martinez) [2136125 2134582] {CVE-2022-42722}
- wifi: mac80211_hwsim: avoid mac80211 warning on bad rate (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: avoid nontransmitted BSS list corruption (Jose Ignacio Tornos Martinez) [2136125 2134511] {CVE-2022-42721}
- wifi: cfg80211: fix BSS refcounting bugs (Jose Ignacio Tornos Martinez) [2136125 2134460] {CVE-2022-42720}
- wifi: cfg80211: ensure length byte is present before access (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix MBSSID parsing use-after-free (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211/mac80211: reject bad MBSSID elements (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: fix u8 overflow in cfg80211_update_notlisted_nontrans() (Jose Ignacio Tornos Martinez) [2136125 2134385] {CVE-2022-41674}
- wifi: nl80211: Split memcpy() of struct nl80211_wowlan_tcp_data_token flexible array (Jose Ignacio Tornos Martinez) [2136125]
- wifi: wext: use flex array destination for memcpy() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: fix ieee80211_data_to_8023_exthdr handling of small packets (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: netdev compatible TX stop for iTXQ drivers (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix decap offload for stations on AP_VLAN interfaces (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: unlock on error in ieee80211_can_powered_addr_change() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: remove/avoid misleading prints (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix probe req HE capabilities access (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: do not drop packets smaller than the LLC-SNAP header on fast-rx (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: fix rate reporting / throughput regression on mt7915 and newer (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: Improve rtl8xxxu_queue_select (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: Fix AIFS written to REG_EDCA_*_PARAM (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: gen2: Enable 40 MHz channel width (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852b: configure DLE mem (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: check DLE FIFO size with reserved size (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: mac: correct register of report IMR (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: set power cut closed for 8852be (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: add to do PCI auto calibration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852b: implement chip_ops::{enable,disable}_bb_rf (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: add DMA busy checking bits to chip info (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: mac: define DMA channel mask to avoid unsupported channels (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: mask out unsupported TX channels (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: Track scan_cmd allocation size explicitly (Jose Ignacio Tornos Martinez) [2136125]
- brcmfmac: Remove the call to "dtim_assoc" IOVAR (Jose Ignacio Tornos Martinez) [2136125]
- brcmfmac: increase dcmd maximum buffer size (Jose Ignacio Tornos Martinez) [2136125]
- brcmfmac: Support 89459 pcie (Jose Ignacio Tornos Martinez) [2136125]
- brcmfmac: increase default max WOWL patterns to 16 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Fix deadlock during WoWLAN suspend (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Remove redundant ath11k_mac_drain_tx (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add spectral scan support for 160 MHz (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add support to get power save duration for each client (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: fix peer addition/deletion error on sta band migration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support for enable/disable MSDU aggregation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: disable 26-tone RU HE TB PPDU transmissions (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support for processing P2P power saving (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support WMM-PS in P2P GO mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: set wifi_role of P2P (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: send OFDM rate only in P2P mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support P2P (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: correctly set BBP register 86 for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: set SoC wmac clock register (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: set VGC gain for both chains of MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: set correct TX_SW_CFG1 MAC register for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: fix HT20/HT40 bandwidth switch on MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: move helper functions up in file (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add TX LOFT calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: don't run Rt5592 IQ calibration on MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add RXIQ calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add RXDCOC calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add r calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add RF self TXDC calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: move up and reuse busy wait functions (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add support for external PA on MT7620 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: add throughput LED trigger (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: define RF5592 in init_eeprom routine (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: fix number of VHT beamformee spatial streams (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: retrieve MAC address from system firmware if provided (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: add get_txpower mac ops (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: move firmware stats out of debugfs (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath9k: fix repeated the words in a comment (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath9k: fix repeated to words in a comment (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath10k: reset pointer after memory free to avoid potential use-after-free (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: fix failed to find the peer with peer_id 0 when disconnected (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: change complete() to complete_all() for scan.completed (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: update coexistence to 6.3.0 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: add logic to control BT scan priority (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: summarize Wi-Fi to BT scoreboard and inform BT one time a cycle (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: modify LNA2 setting to avoid BT destroyed Wi-Fi aggregation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: add WL_S0 hardware TX/RX mask to allow WL_S0 TX/RX during GNT_BT (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: add v1 Wi-Fi firmware steps report (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: add v1 summary info to parse the traffic status from firmware (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: translate slot ID to readable name (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: add v1 cycle report to parsing Bluetooth A2DP status (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mwifiex: fix array of flexible structures warnings (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rndis_wlan: fix array of flexible structures warning (Jose Ignacio Tornos Martinez) [2136125]
- mwifiex: fix sleep in atomic context bugs caused by dev_coredumpv (Jose Ignacio Tornos Martinez) [2136125]
- bus: mhi: host: pci_generic: Add a secondary AT port to Telit FN990 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add WoW support for WCN6750 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Include STA_KEEPALIVE_ARP_RESPONSE TLV header by default (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rt2x00: Fix "Error - Attempt to send packet over invalid queue 2" (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: add multi-port ID to TX descriptor (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: fix rx filter after scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: free unused skb to prevent memory leak (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: reset halt registers before turn on wifi CPU (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: update LTR settings (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: mac: set NAV upper to 25ms (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: initialize DMA of CMAC (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support SER L1 simulation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: support fw crash simulation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: introudce functions to drop packets (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: unify use of rtw89_h2c_tx() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: concentrate control function of TX DMA channel (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: correct enable functions of HCI/PCI DMA (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: L1 DMA reset has offloaded to FW (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support for setting TID specific configuration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support for setting HE GI and LTF (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: show connecting state in debug message (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: Combine set grant WL/BT and correct the debug log (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: Remove trace_step at COEX-MECH control structure for RTL8852C (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: Parsing Wi-Fi firmware TDMA info from reports (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: Parsing Wi-Fi firmware error message from reports (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: Move coexistence firmware buffer size parameter to chip info (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: Add v1 Wi-Fi firmware power-saving null data report (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: coex: use void pointer as temporal type to copy report (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4378 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: pcie: Support PCIe core revisions >= 64 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: msgbuf: Increase RX ring sizes to 1024 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: firmware: Allow platform to override macaddr (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: pcie: Perform firmware selection for Apple platforms (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: of: Fetch Apple properties (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: pcie: Read Apple OTP information (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: firmware: Support passing in multiple board_types (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: pcie/sdio/usb: Get CLM blob via standard firmware mechanism (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: firmware: Handle per-board clm_blob files (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: d3: parse keys from wowlan info notification (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: iterate over interfaces after an assert in d3 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: trigger resume flow before wait for notifications (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: Add handling for scan offload match info notification (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: enable resume based on notifications (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: Add support for d3 end notification (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: Add support for wowlan wake packet notification (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: Add support for wowlan info notification (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: don't check D0I3 version (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: cfg: remove IWL_DEVICE_BZ_COMMON macro (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: refactor iwl_mvm_set_sta_rate() a bit (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: rxmq: further unify some VHT/HE code (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: rxmq: refactor mac80211 rx_status setting (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: mvm: fix typo in struct iwl_rx_no_data API (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: pcie: add support for BZ devices (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Fix kernel-doc issues (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Fix miscellaneous spelling errors (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath10k: Fix miscellaneous spelling errors (Jose Ignacio Tornos Martinez) [2136125]
- bus: mhi: host: always print detected modem name (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921s: Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7663s: Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921e: fix random fw download fail (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: introduce Country Location Control support (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921e: fix rmmod crash in driver reload test (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: reset msta->airtime_ac while clearing up hw value (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7915: do not check state before configuring implicit beamform (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: fix uninitialized pointer in mt7921_mac_fill_rx (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7915: fix mcs value in ht mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: get rid of the false positive reset (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: connac: fix in comment (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: add PPDU based TxS support for WED device (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: move move mt76_sta_stats to mt76_wcid (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: fix the firmware version report (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_[start, stop]_ap (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt76_usb.mt76u_mcu.burst is always false remove related code (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7663s: add rx_check callback (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: connac: fix possible unaligned access in mt76_connac_mcu_add_nested_tlv (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7915: fix possible unaligned access in mt7915_mac_add_twt_setup (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7615: add mt7615_mutex_acquire/release in mt7615_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: sdio: fix transmitting packet hangs (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: sdio: add rx_check callback for sdio devices (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: delete stray if statement (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: fix use after free in mt7921_acpi_read() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7915: fix an uninitialized variable bug (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: sdio: poll sta stat when device transmits data (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: sdio: fix the deadlock caused by sdio->stat_work (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921: move mt7921_rx_check and mt7921_queue_rx_skb in mac.c (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921u: remove unnecessary MT76_STATE_SUSPEND (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921u: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921s: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: mt7921e: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: add rx_check callback for usb devices (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: testmode: use random payload for tx packets (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mt76: connac: introduce mt76_connac_reg_map structure (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: Remove copy-paste leftover in gen2_update_rate_mask (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: gen2: Fix mistake in path B IQ calibration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: split scan including lots of channels (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: support hw_scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: call tx_wake notify for 8852c in deep ps mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support deep ps mode for rtw8852c (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: set response rate selection (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: set TX to single path TX on path B in 6GHz band (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: enlarge polling timeout of RX DCK (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: enable the interference cancellation of MU-MIMO on 6GHz (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: add DIG register struct to share common algorithm (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: support TX diversity for 1T2R chipset (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: record signal strength per RF path (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: configure TX path via H2C command (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: parse phycap of TX/RX antenna number (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: use u32_get_bits to access C2H content of PHY capability (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Increase TCL data ring size for WCN6750 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add multi TX ring support for WCN6750 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Enable threaded NAPI (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: mhi: fix potential memory leak in ath11k_mhi_register() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: implement SRAM dump debugfs interface (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Split PCI write/read functions (Jose Ignacio Tornos Martinez) [2136125]
- ath11k: Enable remain-on-channel support on WCN6750 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mwifiex: fix endian annotations in casts (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mwifiex: fix endian conversion (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mwifiex: mark a variable unused (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: Fix skb misuse in TX queue selection (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: remove redundant variable err (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: add 43439 SDIO ids and initialization (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: Simplify the error handling code (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mwifiex: Fix comment typo (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: Add DMI nvram filename quirk for Chuwi Hi8 Pro tablet (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: Use ISO3166 country code and rev 0 as fallback on 43430 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: fix use-after-free bug in brcmf_netdev_start_xmit() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: iwlwifi: calib: Refactor iwl_calib_result usage for clarity (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: always activate all links (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: implement link switching (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: keep A-MSDU data in sta and per-link (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: set up beacon timing config on links (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: add vif/sta link RCU dereference macros (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: send NDP for link (de)activation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: extend ieee80211_nullfunc_get() for MLO (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: track active STA links (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: skip inactive links on TX (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: add ieee80211_find_sta_by_link_addrs API (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: isolate driver from inactive links (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: make smps_mode per-link (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: use correct rx link_sta instead of default (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: set link_sta in reorder timeout (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: fix multi-channel handling in netlink RX (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: call drv_sta_state() under sdata_lock() in reconfig (Jose Ignacio Tornos Martinez) [2136125]
- wifi: nl80211: add MLD address to assoc BSS entries (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: mlme: refactor QoS settings code (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: warn on invalid link address (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix double SW scan stop (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: mlme: assign link address correctly (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: move link code to a new file (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: refactor RX a bit (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: check STA magic in change_sta_links (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: remove unused arg to ieee80211_chandef_eht_oper (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: remove multicast workaround (Jose Ignacio Tornos Martinez) [2136125]
- wifi: nl80211: remove redundant err variable (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: Support POWERED_ADDR_CHANGE feature (Jose Ignacio Tornos Martinez) [2136125]
- wifi: nl80211: Add POWERED_ADDR_CHANGE feature (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: prevent 4-addr use on MLDs (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: prevent VLANs on MLDs (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add support to connect to non-transmit MBSSID profiles (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Fix hardware restart failure due to twt debugfs failure (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add TWT debugfs support for STA interface (Jose Ignacio Tornos Martinez) [2136125]
- wifi: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: add missing destroy_workqueue() on error path in rtw_core_init() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtl8xxxu: tighten bounds checking in rtl8xxxu_read_efuse() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: declare to support beamformee above bandwidth 80MHz (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: correct polling address of address CAM (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: no HTC field if TX rate might fallback to legacy (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: correct TX resource checking in low power mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: fix interrupt stuck after leaving low power mode (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: enlarge the CFO tracking boundary (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: correct suspend/resume setting for variant chips (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: enable CLK_REQ, ASPM, L1 and L1ss for 8852c (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: pci: fix PCI PHY auto adaption by using software restore (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: set TBTT shift configuration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: add retry to change power_mode state (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: correct BA CAM allocation (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: initialize and correct BA CAM content (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: declare correct BA CAM number (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: update TX power tables to R49 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852c: update RF radio A/B parameters to R49 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: TX power limit/limit_ru consider negative (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Update Wi-Fi driver/firmware TDMA cycle report for RTL8852c (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Add v1 Wi-Fi SCC coexistence policy (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Move _set_policy to chip_ops (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: update WL role info v1 for RTL8852C branch using (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Add v1 version TDMA format and parameters (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Define BT B1 slot length (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Add logic to parsing rtl8852c firmware type ctrl report (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: Move Wi-Fi firmware coexistence matching version to chip (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: coex: update radio state for RTL8852A/RTL8852C (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: 8852c: adjust mactxen delay of mac/phy interface (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: 8852c: modify PCIE prebkf time (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: ser: leave lps with mutex (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: declare support HE HTC always (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: 8852a: update HW setting on BB (Jose Ignacio Tornos Martinez) [2136125]
- rtw89: 8852c: disable dma during mac init (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: declare support for mac80211 chanctx ops by chip (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: add skeleton of mac80211 chanctx ops support (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: introduce entity mode and its recalculated prototype (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: initialize entity and configure default chandef (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: concentrate chandef setting to stack callback (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: concentrate parameter control for setting channel callback (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: rfk: concentrate parameter control while set_channel() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: txpwr: concentrate channel related control to top (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: create rtw89_chan centrally to avoid breakage (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: re-arrange channel related stuffs under HAL (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: introduce rtw89_chan for channel stuffs (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: rewrite decision on channel by entity state (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Add cold boot calibration support on WCN6750 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Fix incorrect QMI message ID mappings (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath11k: Register shutdown handler for WCN6750 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath9k: avoid uninit memory read in ath9k_htc_rx_msg() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix potential deadlock in ieee80211_key_link() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: fix uninitialized use of primary channel index (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: use full 'unsigned int' type (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: read ethtool's sta_stats from sinfo (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: correct SMPS mode in HE 6 GHz capability (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: Add link_id to cfg80211_ch_switch_started_notify() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: nl80211: send MLO links channel info in GET_INTERFACE (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: allow bw change during channel switch in mesh (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: clean up a needless assignment in ieee80211_sta_activate_link() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: allow link address A2 in TXQ dequeue (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix control port frame addressing (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: set link ID in TX info for beacons (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: fix link change handling (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: maintain link_id in link_sta (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211/mac80211: check EHT capability size correctly (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211_hwsim: split iftype data into AP/non-AP (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: mlme: don't add empty EML capabilities (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: use link ID for MLO in queued frames (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: use the corresponding link for stats update (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: add link information in ieee80211_rx_status (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: properly implement MLO key handling (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: Add link_id parameter to various key operations for MLO (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: Prevent cfg80211_wext_siwencodeext() on MLD (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: reject connect response with MLO params for WEP (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: fix use-after-free (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: use link in TXQ parameter configuration (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: add link id to txq params (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: set link BSSID (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: get correct AP link chandef (Jose Ignacio Tornos Martinez) [2136125]
- wifi: cfg80211: Update RNR parsing to align with Draft P802.11be_D2.0 (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: properly set old_links when removing a link (Jose Ignacio Tornos Martinez) [2136125]
- wifi: mac80211: accept STA changes without link changes (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: prohibit enter IPS during HW scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: add flag check before enter or leave IPS (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: add flushing queue before HW scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: fix WARNING:rtw_get_tx_power_params() during HW scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: add the update channel flow to support setting by parameters (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: add mutex when set regulatory and get Tx power table (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: add mutex when set SAR (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: Fix to add skb free for TIM update info when tx is completed (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: Fix to add brcmf_clear_assoc_ies when rmmod (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: fix invalid address access when enabling SCAN log level (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: fix scheduling while atomic issue when deleting flowring (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmfmac: fix continuous 802.1x tx pending timeout error (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath10k: add peer map clean up for peer delete in ath10k_sta_state() (Jose Ignacio Tornos Martinez) [2136125]
- wifi: ath10k: Set tx credit to one for WCN3990 snoc based devices (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: 8852a: correct WDE IMR settings (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw89: refine leaving LPS function (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtlwifi: 8192de: correct checking of IQK reload (Jose Ignacio Tornos Martinez) [2136125]
- wifi: brcmsmac: remove duplicate words (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: access chip_info by const pointer (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: phy: fix warning of possible buffer overflow (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: fix store OP channel info timing when HW scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: fix stopping queues in wrong timing when HW scan (Jose Ignacio Tornos Martinez) [2136125]
- wifi: rtw88: 8822c: extend supported probe request size (Jose Ignacio Tornos Martinez) [2136125]

* Tue Feb 07 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-459.el8]
- ALSA: pcm: Move rwsem lock inside snd_ctl_elem_read to prevent UAF (Jaroslav Kysela) [2125548] {CVE-2023-0266}
- ALSA: usb-audio: Remove redundant workaround for Roland quirk (Jaroslav Kysela) [2125548]
- ASoC: jz4740-i2s: Handle independent FIFO flush bits (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Apply dual codec fixup for Dell Latitude laptops (Jaroslav Kysela) [2125548]
- ALSA: patch_realtek: Fix Dell Inspiron Plus 16 (Jaroslav Kysela) [2125548]
- ALSA: hda/hdmi: Static PCM mapping again with AMD HDMI codecs (Jaroslav Kysela) [2125548]
- ALSA: line6: fix stack overflow in line6_midi_transmit (Jaroslav Kysela) [2125548]
- ALSA: line6: correct midi status byte when receiving data from podxt (Jaroslav Kysela) [2125548]
- ALSA: hda/hdmi: Add HP Device 0x8711 to force connect list (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add quirk for Lenovo TianYi510Pro-14IOB (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: add the quirk for KT0206 device (Jaroslav Kysela) [2125548]
- ASoC: rt5670: Remove unbalanced pm_runtime_put() (Jaroslav Kysela) [2125548]
- ASoC: rockchip: spdif: Add missing clk_disable_unprepare() in rk_spdif_runtime_resume() (Jaroslav Kysela) [2125548]
- ASoC: wm8994: Fix potential deadlock (Jaroslav Kysela) [2125548]
- ALSA: hda/hdmi: fix stream-id config keep-alive for rt suspend (Jaroslav Kysela) [2125548]
- ALSA: hda/hdmi: set default audio parameters for KAE silent-stream (Jaroslav Kysela) [2125548]
- ALSA: hda/hdmi: fix i915 silent stream programming flow (Jaroslav Kysela) [2125548]
- ASoC: rockchip: pdm: Add missing clk_disable_unprepare() in rockchip_pdm_runtime_resume() (Jaroslav Kysela) [2125548]
- ASoC: audio-graph-card: fix refcount leak of cpu_ep in __graph_for_each_link() (Jaroslav Kysela) [2125548]
- ASoC: mediatek: mt8173-rt5650-rt5514: fix refcount leak in mt8173_rt5650_rt5514_dev_probe() (Jaroslav Kysela) [2125548]
- ASoC: Intel: Skylake: Fix driver hang during shutdown (Jaroslav Kysela) [2125548]
- ALSA: hda: add snd_hdac_stop_streams() helper (Jaroslav Kysela) [2125548]
- ASoC: sof_es8336: fix possible use-after-free in sof_es8336_remove() (Jaroslav Kysela) [2125548]
- ASoC: amd: yc: Add Xiaomi Redmi Book Pro 14 2022 into DMI table (Jaroslav Kysela) [2125548]
- ASoC: Intel: avs: Add quirk for KBL-R RVP platform (Jaroslav Kysela) [2125548]
- ASoC: codecs: rt298: Add quirk for KBL-R RVP platform (Jaroslav Kysela) [2125548]
- ALSA: mts64: fix possible null-ptr-defer in snd_mts64_interrupt (Jaroslav Kysela) [2125548]
- ALSA: pcm: Set missing stop_operating flag at undoing trigger start (Jaroslav Kysela) [2125548]
- ASoC: pcm512x: Fix PM disable depth imbalance in pcm512x_probe (Jaroslav Kysela) [2125548]
- ALSA: asihpi: fix missing pci_disable_device() (Jaroslav Kysela) [2125548]
- ASoC: mediatek: mtk-btcvsd: Add checks for write and read of mtk_btcvsd_snd (Jaroslav Kysela) [2125548]
- ASoC: qcom: Add checks for devm_kcalloc (Jaroslav Kysela) [2125548]
- ASoC: Intel: avs: Lock substream before snd_pcm_stop() (Jaroslav Kysela) [2125548]
- ASoC: pxa: fix null-pointer dereference in filter() (Jaroslav Kysela) [2125548]
- ASoC: Intel: avs: Fix potential RX buffer overflow (Jaroslav Kysela) [2125548]
- ASoC: Intel: avs: Fix DMA mask assignment (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2125548]
- ASoC: ops: Correct bounds check for second channel on SX controls (Jaroslav Kysela) [2125548]
- ASoC: cs42l51: Correct PGA Volume minimum value (Jaroslav Kysela) [2125548]
- ASoC: ops: Check bounds for second channel in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2125548]
- ASoC: fsl_micfil: explicitly clear CHnF flags (Jaroslav Kysela) [2125548]
- ASoC: fsl_micfil: explicitly clear software reset bit (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: More robust component matching for CS35L41 (Jaroslav Kysela) [2125548]
- ASoC: soc-pcm: Add NULL check in BE reparenting (Jaroslav Kysela) [2125548]
- ALSA: seq: Fix function prototype mismatch in snd_seq_expand_var_event (Jaroslav Kysela) [2125548]
- ASoC: rt711-sdca: fix the latency time of clock stop prepare state machine transitions (Jaroslav Kysela) [2125548]
- ASoC: wm8962: Wait for updated value of WM8962_CLOCKING1 register (Jaroslav Kysela) [2125548]
- ASoC: ops: Fix bounds check for _sx controls (Jaroslav Kysela) [2125548]
- ALSA: dice: fix regression for Lexicon I-ONIX FW810S (Jaroslav Kysela) [2125548]
- ASoC: sof_es8336: reduce pop noise on speaker (Jaroslav Kysela) [2125548]
- ASoC: SOF: ipc3-topology: use old pipeline teardown flow with SOF2.1 and older (Jaroslav Kysela) [2125548]
- ASoC: hda: intel-dsp-config: add ES83x6 quirk for IceLake (Jaroslav Kysela) [2125548]
- ASoC: Intel: soc-acpi: add ES83x6 support to IceLake (Jaroslav Kysela) [2125548]
- ASoC: Intel: bytcht_es8316: Add quirk for the Nanote UMPC-01 (Jaroslav Kysela) [2125548]
- ASoC: amd: yc: Add Alienware m17 R5 AMD into DMI table (Jaroslav Kysela) [2125548]
- ASoC: max98373: Add checks for devm_kcalloc (Jaroslav Kysela) [2125548]
- ASoC: soc-pcm: Don't zero TDM masks in __soc_pcm_open() (Jaroslav Kysela) [2125548]
- ASoC: sgtl5000: Reset the CHIP_CLK_CTRL reg on remove (Jaroslav Kysela) [2125548]
- ASoC: hdac_hda: fix hda pcm buffer overflow issue (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: add quirk to fix Hamedal C20 disconnect issue (Jaroslav Kysela) [2125548]
- ASoC: SOF: topology: No need to assign core ID if token parsing failed (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book Pro 360 (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: fix speakers for Samsung Galaxy Book Pro (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Drop snd_BUG_ON() from snd_usbmidi_output_open() (Jaroslav Kysela) [2125548]
- ASoC: soc-utils: Remove __exit for snd_soc_util_exit() (Jaroslav Kysela) [2125548]
- ASoC: rt5677: fix legacy dai naming (Jaroslav Kysela) [2125548]
- ASoC: rt5514: fix legacy dai naming (Jaroslav Kysela) [2125548]
- ASoC: tas2764: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125548]
- ASoC: tas2770: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125548]
- ASoC: core: Fix use-after-free in snd_soc_exit() (Jaroslav Kysela) [2125548]
- ASoC: codecs: jz4725b: Fix spelling mistake "Sourc" -> "Source", "Routee" -> "Route" (Jaroslav Kysela) [2125548]
- ASoC: amd: yc: Add Lenovo Thinkbook 14+ 2022 21D0 to quirks table (Jaroslav Kysela) [2125548]
- ASoC: amd: yc: Adding Lenovo ThinkBook 14 Gen 4+ ARA and Lenovo ThinkBook 16 Gen 4+ ARA to the Quirks List (Jaroslav Kysela) [2125548]
- ASoC: rt1308-sdw: add the default value of some registers (Jaroslav Kysela) [2125548]
- ASoC: Intel: sof_rt5682: Add quirk for Rex board (Jaroslav Kysela) [2125548]
- ASoC: Intel: sof_sdw: add quirk variant for LAPBC710 NUC15 (Jaroslav Kysela) [2125548]
- ASoC: codecs: jz4725b: fix capture selector naming (Jaroslav Kysela) [2125548]
- ASoC: codecs: jz4725b: use right control for Capture Volume (Jaroslav Kysela) [2125548]
- ASoC: codecs: jz4725b: fix reported volume for Master ctl (Jaroslav Kysela) [2125548]
- ASoC: codecs: jz4725b: add missed Line In power control bit (Jaroslav Kysela) [2125548]
- ASoC: wm8962: Add an event handler for TEMP_HP and TEMP_SPK (Jaroslav Kysela) [2125548]
- ASoC: rt1019: Fix the TDM settings (Jaroslav Kysela) [2125548]
- ASoC: rt5682s: Fix the TDM Tx settings (Jaroslav Kysela) [2125548]
- ASoC: mt6660: Keep the pm_runtime enables before component stuff in mt6660_i2c_probe (Jaroslav Kysela) [2125548]
- ASoC: wm8997: Revert "ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe" (Jaroslav Kysela) [2125548]
- ASoC: wm5110: Revert "ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe" (Jaroslav Kysela) [2125548]
- ASoC: wm5102: Revert "ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe" (Jaroslav Kysela) [2125548]
- ALSA: memalloc: Try dma_alloc_noncontiguous() at first (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Add DSD support for Accuphase DAC-60 (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Add quirk entry for M-Audio Micro (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Yet more regression for for the delayed card registration (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add Positivo C6300 model quirk (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41 (Jaroslav Kysela) [2125548]
- ALSA: hda: fix potential memleak in 'add_widget_node' (Jaroslav Kysela) [2125548]
- ALSA: hda/ca0132: add quirk for EVGA Z390 DARK (Jaroslav Kysela) [2125548]
- ALSA: hda/hdmi - enable runtime pm for more AMD display audio (Jaroslav Kysela) [2125548]
- ALSA: memalloc: Don't fall back for SG-buffer with IOMMU (Jaroslav Kysela) [2125548]
- ALSA: aoa: Fix I2S device accounting (Jaroslav Kysela) [2125548]
- ALSA: aoa: i2sbus: fix possible memory leak in i2sbus_add_dev() (Jaroslav Kysela) [2125548]
- ALSA: ac97: fix possible memory leak in snd_ac97_dev_register() (Jaroslav Kysela) [2125548]
- ASoC: SOF: Intel: pci-tgl: fix ADL-N descriptor (Jaroslav Kysela) [2125548]
- ASoC: SOF: Intel: pci-tgl: use RPL specific firmware definitions (Jaroslav Kysela) [2125548]
- ASoC: Intel: common: add ACPI matching tables for Raptor Lake (Jaroslav Kysela) [2125548]
- ALSA: rme9652: use explicitly signed char (Jaroslav Kysela) [2125548]
- ALSA: au88x0: use explicitly signed char (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add another HP ZBook G9 model quirks (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Add quirks for M-Audio Fast Track C400/600 (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41 (Jaroslav Kysela) [2125548]
- ALSA: Use del_timer_sync() before freeing timer (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Fix last interface check for registration (Jaroslav Kysela) [2125548]
- ASoC: amd: yc: Add Lenovo Yoga Slim 7 Pro X to quirks table (Jaroslav Kysela) [2125548]
- ASoC: amd: yc: Add ASUS UM5302TA into DMI table (Jaroslav Kysela) [2125548]
- ASoC: SOF: add quirk to override topology mclk_id (Jaroslav Kysela) [2125548]
- ASoC: SOF: pci: Change DMI match info to support all Chrome platforms (Jaroslav Kysela) [2125548]
- ALSA: intel-dspconfig: add ES8336 support for AlderLake-PS (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Register card at the last interface (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Add quirk to enable Avid Mbox 3 support (Jaroslav Kysela) [2125548]
- ASoC: mt6660: Fix PM disable depth imbalance in mt6660_i2c_probe (Jaroslav Kysela) [2125548]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2125548]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2125548]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2125548]
- ASoC: stm: Fix PM disable depth imbalance in stm32_i2s_probe (Jaroslav Kysela) [2125548]
- ASoC: stm32: spdifrx: Fix PM disable depth imbalance in stm32_spdifrx_probe (Jaroslav Kysela) [2125548]
- ASoC: stm32: dfsdm: Fix PM disable depth imbalance in stm32_adfsdm_probe (Jaroslav Kysela) [2125548]
- ALSA: dmaengine: increment buffer pointer atomically (Jaroslav Kysela) [2125548]
- ASoC: da7219: Fix an error handling path in da7219_register_dai_clks() (Jaroslav Kysela) [2125548]
- ASoC: eureka-tlv320: Hold reference returned from of_find_xxx API (Jaroslav Kysela) [2125548]
- ASoC: wm_adsp: Handle optional legacy support (Jaroslav Kysela) [2125548]
- ASoC: rsnd: Add check for rsnd_mod_power_on (Jaroslav Kysela) [2125548]
- ASoC: soc-pcm.c: call __soc_pcm_close() in soc_pcm_close() (Jaroslav Kysela) [2125548]
- ASoC: mt6359: fix tests for platform_get_irq() failure (Jaroslav Kysela) [2125548]
- ASoC: wcd934x: fix order of Slimbus unprepare/disable (Jaroslav Kysela) [2125548]
- ASoC: wcd9335: fix order of Slimbus unprepare/disable (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add Intel Reference SSID to support headset keys (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add quirk for ASUS GV601R laptop (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Fix NULL dererence at error path (Jaroslav Kysela) [2125548]
- ALSA: usb-audio: Fix potential memory leaks (Jaroslav Kysela) [2125548]
- ALSA: rawmidi: Drop register_mutex in snd_rawmidi_free() (Jaroslav Kysela) [2125548]
- ALSA: oss: Fix potential deadlock at unregistration (Jaroslav Kysela) [2125548]
- ALSA: hda/realtek: Add quirk for HP Zbook Firefly 14 G9 model (Jaroslav Kysela) [2125548]
- ALSA: hda: Fix position reporting on Poulsbo (Jaroslav Kysela) [2125548]

* Mon Feb 06 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-458.el8]
- KVM: x86: smm: preserve interrupt shadow in SMRAM (Maxim Levitsky) [2097144]
- KVM: x86: SVM: don't save SVM state to SMRAM when VM is not long mode capable (Maxim Levitsky) [2097144]
- KVM: x86: SVM: use smram structs (Maxim Levitsky) [2097144]
- KVM: svm: drop explicit return value of kvm_vcpu_map (Maxim Levitsky) [2097144]
- KVM: x86: smm: use smram struct for 64 bit smram load/restore (Maxim Levitsky) [2097144]
- KVM: x86: smm: use smram struct for 32 bit smram load/restore (Maxim Levitsky) [2097144]
- KVM: x86: smm: use smram structs in the common code (Maxim Levitsky) [2097144]
- KVM: x86: smm: add structs for KVM's smram layout (Maxim Levitsky) [2097144]
- KVM: x86: smm: check for failures on smm entry (Maxim Levitsky) [2097144]
- KVM: x86: do not go through ctxt->ops when emulating rsm (Maxim Levitsky) [2097144]
- KVM: x86: move SMM exit to a new file (Maxim Levitsky) [2097144]
- KVM: x86: move SMM entry to a new file (Maxim Levitsky) [2097144]
- KVM: x86: start moving SMM-related functions to new files (Maxim Levitsky) [2097144]
- bug: introduce ASSERT_STRUCT_OFFSET (Maxim Levitsky) [2097144]
- KVM: x86: Rename and expose helper to detect if INIT/SIPI are allowed (Maxim Levitsky) [2097144]
- KVM: x86: smm: number of GPRs in the SMRAM image depends on the image format (Maxim Levitsky) [2097144]
- KVM: x86: emulator: update the emulation mode after CR0 write (Maxim Levitsky) [2097144]
- KVM: x86: emulator: update the emulation mode after rsm (Maxim Levitsky) [2097144]
- KVM: x86: emulator: introduce emulator_recalc_and_set_mode (Maxim Levitsky) [2097144]
- KVM: x86: emulator: em_sysexit should update ctxt->mode (Maxim Levitsky) [2097144]
- KVM: x86: Bug the VM if the emulator accesses a non-existent GPR (Maxim Levitsky) [2097144]
- KVM: x86: Reduce the number of emulator GPRs to '8' for 32-bit KVM (Maxim Levitsky) [2097144]
- KVM: x86: Use 16-bit fields to track dirty/valid emulator GPRs (Maxim Levitsky) [2097144]
- KVM: x86: Omit VCPU_REGS_RIP from emulator's _regs array (Maxim Levitsky) [2097144]
- KVM: x86: Harden _regs accesses to guard against buggy input (Maxim Levitsky) [2097144]
- KVM: x86: Grab regs_dirty in local 'unsigned long' (Maxim Levitsky) [2097144]

* Fri Feb 03 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-457.el8]
- RDMA/bnxt_re: Fix endianness warning for req.pkey (Kamal Heib) [2142690]
- RDMA/bnxt_re: Use bitmap_zalloc() when applicable (Kamal Heib) [2142690]
- RDMA/bnxt_re: Remove dynamic pkey table (Kamal Heib) [2142690]
- RDMA/bnxt_re: Scan the whole bitmap when checking if "disabling RCFW with pending cmd-bit" (Kamal Heib) [2142690]
- RDMA/bnxt_re: Remove unneeded variable (Kamal Heib) [2142690]
- RDMA/bnxt_re: Remove unsupported bnxt_re_modify_ah callback (Kamal Heib) [2142690]
- RDMA/bnxt_re: Use helper function to set GUIDs (Kamal Heib) [2142690]
- RDMA/bnxt_re: Check if the vlan is valid before reporting (Kamal Heib) [2142690]
- RDMA/bnxt_re: Correct FRMR size calculation (Kamal Heib) [2142690]
- RDMA/bnxt_re: Use GFP_KERNEL in non atomic context (Kamal Heib) [2142690]
- RDMA/bnxt_re: Fix FRMR issue with single page MR allocation (Kamal Heib) [2142690]
- RDMA/bnxt_re: Fix query SRQ failure (Kamal Heib) [2142690]
- RDMA/bnxt_re: Suppress unwanted error messages (Kamal Heib) [2142690]
- RDMA/bnxt_re: Support multiple page sizes (Kamal Heib) [2142690]
- RDMA/bnxt_re: Reduce the delay in polling for hwrm command completion (Kamal Heib) [2142690]
- RDMA/bnxt_re: Use separate response buffer for stat_ctx_free (Kamal Heib) [2142690]
- net/mlx5: Lag, Fix for loop when checking lag (Amir Tzin) [2112917]
- net/mlx5e: Fix use-after-free when reverting termination table (Amir Tzin) [2112927]
- net/mlx5: Fix uninitialized variable bug in outlen_write() (Amir Tzin) [2112927]
- net/mlx5: E-switch, Fix duplicate lag creation (Amir Tzin) [2112927 2112917]
- net/mlx5: E-switch, Destroy legacy fdb table when needed (Amir Tzin) [2112927 2112917]
- net/mlx5: DR, Fix uninitialized var warning (Amir Tzin) [2112927]
- net/mlx5e: Offload rule only when all encaps are valid (Amir Tzin) [2112927]
- net/mlx5: Fix sync reset event handler error flow (Amir Tzin) [2112927]
- net/mlx5: E-Switch, Set correctly vport destination (Amir Tzin) [2112927]
- net/mlx5: Fix handling of entry refcount when command is not issued to FW (Amir Tzin) [2112927]
- net/mlx5: cmdif, Print info on any firmware cmd failure to tracepoint (Amir Tzin) [2112927]
- net/mlx5: SF: Fix probing active SFs during driver probe phase (Amir Tzin) [2112927]
- net/mlx5: Fix FW tracer timestamp calculation (Amir Tzin) [2112927]
- net/mlx5: Do not query pci info while pci disabled (Amir Tzin) [2112927 2129249]
- net/mlx5e: TC, Fix slab-out-of-bounds in parse_tc_actions (Amir Tzin) [2112927]
- net/mlx5e: Clean up and fix error flows in mlx5e_alloc_rq (Amir Tzin) [2112927]
- net/mlx5: DR, Fix the SMFS sync_steering for fast teardown (Amir Tzin) [2112927]
- net/mlx5e: E-Switch, Fix comparing termination table instance (Amir Tzin) [2112927]
- net/mlx5e: TC, Fix wrong rejection of packet-per-second policing (Amir Tzin) [2112927 2049622]
- net/mlx5e: Fix tc acts array not to be dependent on enum order (Amir Tzin) [2112927]
- net/mlx5e: Add missing sanity checks for max TX WQE size (Amir Tzin) [2112927]
- net/mlx5: fw_reset: Don't try to load device in case PCI isn't working (Amir Tzin) [2112927]
- net/mlx5: E-switch, Set to legacy mode if failed to change switchdev mode (Amir Tzin) [2112927 2112917]
- net/mlx5: Allow async trigger completion execution on single CPU systems (Amir Tzin) [2112927]
- net/mlx5: Bridge, verify LAG state when adding bond to bridge (Amir Tzin) [2112927]
- net/mlx5: Fix crash during sync firmware reset (Amir Tzin) [2112927]
- net/mlx5e: TC, Fix cloned flow attr instance dests are not zeroed (Amir Tzin) [2112927]
- net/mlx5: Fix possible use-after-free in async command interface (Amir Tzin) [2112927]
- net/mlx5: ASO, Create the ASO SQ with the correct timestamp format (Amir Tzin) [2112927 2049622]
- net/mlx5e: Update restore chain id for slow path packets (Amir Tzin) [2112927]
- net/mlx5e: Extend SKB room check to include PTP-SQ (Amir Tzin) [2112927]
- net/mlx5: DR, Fix matcher disconnect error flow (Amir Tzin) [2112927]
- net/mlx5: Wait for firmware to enable CRS before pci_restore_state (Amir Tzin) [2112927]
- net/mlx5e: Do not increment ESN when updating IPsec ESN state (Amir Tzin) [2112927]
- net/mlx5e: Fix calculations for ICOSQ size (Amir Tzin) [2112927]
- net/mlx5: Fix spelling mistake "syndrom" -> "syndrome" (Amir Tzin) [2112927]
- net/mlx5e: Fix a typo in mlx5e_xdp_mpwqe_is_full (Amir Tzin) [2112927]
- RDMA/mlx5: Don't compare mkey tags in DEVX indirect mkey (Amir Tzin) [2112927]
- RDMA/mlx5: Fix UMR cleanup on error flow of driver init (Amir Tzin) [2112927]
- RDMA/mlx5: Rely on RoCE fw cap instead of devlink when setting profile (Amir Tzin) [2112927]
- net/mlx5: Unlock on error in mlx5_sriov_enable() (Amir Tzin) [2112927]
- net/mlx5e: Fix use after free in mlx5e_fs_init() (Amir Tzin) [2112927]
- net/mlx5e: kTLS, Use _safe() iterator in mlx5e_tls_priv_tx_list_cleanup() (Amir Tzin) [2112927]
- net/mlx5: unlock on error path in esw_vfs_changed_event_handler() (Amir Tzin) [2112927 2150647]
- net/mlx5e: Fix wrong tc flag used when set hw-tc-offload off (Amir Tzin) [2112927]
- net/mlx5e: TC, Add missing policer validation (Amir Tzin) [2112927]
- net/mlx5e: Fix wrong application of the LRO state (Amir Tzin) [2112927]
- net/mlx5: Avoid false positive lockdep warning by adding lock_class_key (Amir Tzin) [2112927]
- net/mlx5: Fix cmd error logging for manage pages cmd (Amir Tzin) [2112927]
- net/mlx5: Disable irq when locking lag_lock (Amir Tzin) [2112927]
- net/mlx5: Eswitch, Fix forwarding decision to uplink (Amir Tzin) [2112927 2150647]
- net/mlx5: LAG, fix logic over MLX5_LAG_FLAG_NDEVS_READY (Amir Tzin) [2112927]
- net/mlx5e: Properly disable vlan strip on non-UL reps (Amir Tzin) [2112927]
- net/mlx5e: Allocate flow steering storage during uplink initialization (Amir Tzin) [2112927]
- RDMA/mlx5: Use the proper number of ports (Amir Tzin) [2112927]
- mlx5: do not use RT_TOS for IPv6 flowlabel (Amir Tzin) [2112927]
- RDMA/mlx5: Add missing check for return value in get namespace flow (Amir Tzin) [2112927]
- net/mlx5e: xsk: Discard unaligned XSK frames on striding RQ (Amir Tzin) [2112927]
- net: devlink: convert reload command to take implicit devlink->lock (mlx5 hunk only) (Amir Tzin) [2112927]
- devlink: Hold the instance lock in health callbacks (mlx5 hunk only) (Amir Tzin) [2112927]
- net/mlx5: Lock mlx5 devlink health recovery callback (Amir Tzin) [2112927]
- net/mlx5: Lock mlx5 devlink reload callbacks (Amir Tzin) [2112927]
- net/mlx5: Move fw reset unload to mlx5_fw_reset_complete_reload (Amir Tzin) [2112927]
- net/mlx5e: kTLS, Dynamically re-size TX recycling pool (Amir Tzin) [2112927]
- net/mlx5e: kTLS, Recycle objects of device-offloaded TLS TX connections (Amir Tzin) [2112927]
- net/mlx5e: kTLS, Take stats out of OOO handler (Amir Tzin) [2112927]
- net/mlx5e: kTLS, Introduce TLS-specific create TIS (Amir Tzin) [2112927]
- net/mlx5e: Move mlx5e_init_l2_addr to en_main (Amir Tzin) [2112927]
- net/mlx5e: Split en_fs ndo's and move to en_main (Amir Tzin) [2112927]
- net/mlx5e: Separate mlx5e_set_rx_mode_work and move caller to en_main (Amir Tzin) [2112927]
- net/mlx5e: Add mdev to flow_steering struct (Amir Tzin) [2112927]
- net/mlx5e: Report flow steering errors with mdev err report API (Amir Tzin) [2112927]
- net/mlx5e: Convert mlx5e_flow_steering member of mlx5e_priv to pointer (Amir Tzin) [2112927]
- net/mlx5e: Allocate VLAN and TC for featured profiles only (Amir Tzin) [2112927]
- net/mlx5e: Make mlx5e_tc_table private (Amir Tzin) [2112927]
- net/mlx5e: Convert mlx5e_tc_table member of mlx5e_flow_steering to pointer (Amir Tzin) [2112927]
- net/mlx5e: TC, Support tc action api for police (Amir Tzin) [2112927]
- net/mlx5e: TC, Separate get/update/replace meter functions (Amir Tzin) [2112927]
- net/mlx5e: Add red and green counters for metering (Amir Tzin) [2112927]
- net/mlx5e: TC, Allocate post meter ft per rule (Amir Tzin) [2112927]
- net/mlx5: DR, Add support for flow metering ASO (Amir Tzin) [2112927]
- net/mlx5: Fix driver use of uninitialized timeout (Amir Tzin) [2112927]
- net/mlx5: DR, Fix SMFS steering info dump format (Amir Tzin) [2112927]
- net/mlx5: Adjust log_max_qp to be 18 at most (Amir Tzin) [2112927]
- net/mlx5e: Modify slow path rules to go to slow fdb (Amir Tzin) [2112927 2150647]
- net/mlx5e: Fix calculations related to max MPWQE size (Amir Tzin) [2112927]
- net/mlx5e: xsk: Account for XSK RQ UMRs when calculating ICOSQ size (Amir Tzin) [2112927]
- net/mlx5e: Fix the value of MLX5E_MAX_RQ_NUM_MTTS (Amir Tzin) [2112927]
- net/mlx5e: TC, Fix post_act to not match on in_port metadata (Amir Tzin) [2112927]
- net/mlx5e: Remove WARN_ON when trying to offload an unsupported TLS cipher/version (Amir Tzin) [2112927]
- RDMA/mlx5: Rename the mkey cache variables and functions (Amir Tzin) [2112927]
- RDMA/mlx5: Store in the cache mkeys instead of mrs (Amir Tzin) [2112927]
- RDMA/mlx5: Store the number of in_use cache mkeys instead of total_mrs (Amir Tzin) [2112927]
- RDMA/mlx5: Replace cache list with Xarray (Amir Tzin) [2112927]
- RDMA/mlx5: Replace ent->lock with xa_lock (Amir Tzin) [2112927]
- net/mlx5: CT: Remove warning of ignore_flow_level support for non PF (Amir Tzin) [2112927]
- net/mlx5e: Add resiliency for PTP TX port timestamp (Amir Tzin) [2112927]
- net/mlx5: Expose ts_cqe_metadata_size2wqe_counter (Amir Tzin) [2112927]
- net/mlx5e: HTB, move htb functions to a new file (Amir Tzin) [2112927]
- net/mlx5e: HTB, change functions name to follow convention (Amir Tzin) [2112927]
- net/mlx5e: HTB, remove priv from htb function calls (Amir Tzin) [2112927]
- net/mlx5e: HTB, hide and dynamically allocate mlx5e_htb structure (Amir Tzin) [2112927]
- net/mlx5e: HTB, move stats and max_sqs to priv (Amir Tzin) [2112927]
- net/mlx5e: HTB, move section comment to the right place (Amir Tzin) [2112927]
- net/mlx5e: HTB, move ids to selq_params struct (Amir Tzin) [2112927]
- net/mlx5e: HTB, reduce visibility of htb functions (Amir Tzin) [2112927]
- net/mlx5e: Fix mqprio_rl handling on devlink reload (Amir Tzin) [2112927]
- net/mlx5e: Report header-data split state through ethtool (Amir Tzin) [2112927]
- RDMA/mlx5: Expose steering anchor to userspace (Amir Tzin) [2112927]
- RDMA/mlx5: Refactor get flow table function (Amir Tzin) [2112927]
- net/mlx5: fs, allow flow table creation with a UID (Amir Tzin) [2112927]
- net/mlx5: fs, expose flow table ID to users (Amir Tzin) [2112927]
- net/mlx5: Expose the ability to point to any UID from shared UID (Amir Tzin) [2112927]
- net/mlx5e: Remove the duplicating check for striding RQ when enabling LRO (Amir Tzin) [2112927]
- net/mlx5e: Move the LRO-XSK check to mlx5e_fix_features (Amir Tzin) [2112927]
- net/mlx5e: Extend flower police validation (Amir Tzin) [2112927]
- net/mlx5e: configure meter in flow action (Amir Tzin) [2112927 2150647 2049622]
- net/mlx5e: Removed useless code in function (Amir Tzin) [2112927]
- net/mlx5: Bridge, implement QinQ support (Amir Tzin) [2112927]
- net/mlx5: Bridge, implement infrastructure for VLAN protocol change (Amir Tzin) [2112927]
- net/mlx5: Bridge, extract VLAN push/pop actions creation (Amir Tzin) [2112927]
- net/mlx5: Bridge, rename filter fg to vlan_filter (Amir Tzin) [2112927]
- net/mlx5: Bridge, refactor groups sizes and indices (Amir Tzin) [2112927]
- net/mlx5: debugfs, Add num of in-use FW command interface slots (Amir Tzin) [2112927]
- net/mlx5: Expose vnic diagnostic counters for eswitch managed vports (Amir Tzin) [2112927 2150647 2049881]
- net/mlx5: Use software VHCA id when it's supported (Amir Tzin) [2112927]
- net/mlx5: Introduce ifc bits for using software vhca id (Amir Tzin) [2112927]
- net/mlx5: Use the bitmap API to allocate bitmaps (Amir Tzin) [2112927]
- devlink: Hold the instance lock in port_new / port_del callbacks (mlx5 hunks only) (Amir Tzin) [2112925]
- net/mlx5: Remove devl_unlock from mlx5_devlink_eswitch_mode_set (Amir Tzin) [2112927 2150647]
- net/mlx5: Use devl_ API in mlx5e_devlink_port_register (Amir Tzin) [2112927 2150647]
- net/mlx5: Use devl_ API in mlx5_esw_devlink_sf_port_register (Amir Tzin) [2112927]
- net/mlx5: Use devl_ API in mlx5_esw_offloads_devlink_port_register (Amir Tzin) [2112927 2150647]
- net/mlx5: Use devl_ API for rate nodes destroy (Amir Tzin) [2112927 2150647]
- net/mlx5: Remove devl_unlock from mlx5_eswtich_mode_callback_enter (Amir Tzin) [2112927 2150647]
- net/mlx5: fix 32bit build (Amir Tzin) [2112927 2049622]
- net/mlx5e: TC, Support offloading police action (Amir Tzin) [2112927 2049622]
- net/mlx5e: Add flow_action to parse state (Amir Tzin) [2112927 2049622]
- net/mlx5e: Add post meter table for flow metering (Amir Tzin) [2112927 2049622]
- net/mlx5e: Add generic macros to use metadata register mapping (Amir Tzin) [2112927 2049622]
- net/mlx5e: Get or put meter by the index of tc police action (Amir Tzin) [2112927 2049622]
- net/mlx5e: Add support to modify hardware flow meter parameters (Amir Tzin) [2112927 2049622]
- net/mlx5e: Prepare for flow meter offload if hardware supports it (Amir Tzin) [2112927 2049622]
- net/mlx5: Implement interfaces to control ASO SQ and CQ (Amir Tzin) [2112927 2049622]
- net/mlx5: Add support to create SQ and CQ for ASO (Amir Tzin) [2112927 2049622]
- net/mlx5: E-switch: Change eswitch mode only via devlink command (Amir Tzin) [2112927 2150647 2112917]
- net/mlx5: E-switch, Remove dependency between sriov and eswitch mode (Amir Tzin) [2112927 2150647 2112917]
- net/mlx5: E-switch, Introduce flag to indicate if fdb table is created (Amir Tzin) [2112927 2112917]
- net/mlx5: E-switch, Introduce flag to indicate if vport acl namespace is created (Amir Tzin) [2112927 2112917]
- net/mlx5: delete dead code in mlx5_esw_unlock() (Amir Tzin) [2112927]
- net/mlx5: Delete ipsec_fs header file as not used (Amir Tzin) [2112927]
- net/mlx5: Add bits and fields to support enhanced CQE compression (Amir Tzin) [2112927]
- net/mlx5: Remove not used MLX5_CAP_BITS_RW_MASK (Amir Tzin) [2112927]
- net/mlx5: group fdb cleanup to single function (Amir Tzin) [2112927]
- net/mlx5: Add support EXECUTE_ASO action for flow entry (Amir Tzin) [2112927 2049622]
- net/mlx5: Add HW definitions of vport debug counters (Amir Tzin) [2112927]
- net/mlx5: Add IFC bits and enums for flow meter (Amir Tzin) [2112927 2049622]
- RDMA/mlx5: Support handling of modify-header pattern ICM area (Amir Tzin) [2112927]
- net/mlx5: Manage ICM of type modify-header pattern (Amir Tzin) [2112927]
- net/mlx5: Introduce header-modify-pattern ICM properties (Amir Tzin) [2112927]
- RDMA/mlx5: Add a umr recovery flow (Amir Tzin) [2112927]
- net/mlx5e: Ring the TX doorbell on DMA errors (Amir Tzin) [2112925]
- net/mlx5e: Fix capability check for updating vnic env counters (Amir Tzin) [2112925]
- net/mlx5: Lag, correct get the port select mode str (Amir Tzin) [2112925]
- net/mlx5e: Fix enabling sriov while tc nic rules are offloaded (Amir Tzin) [2112925]
- net/mlx5e: kTLS, Fix build time constant test in RX (Amir Tzin) [2112925]
- net/mlx5e: kTLS, Fix build time constant test in TX (Amir Tzin) [2112925]
- net/mlx5: Lag, decouple FDB selection and shared FDB (Amir Tzin) [2112925]
- net/mlx5: TC, allow offload from uplink to other PF's VF (Amir Tzin) [2112925]
- mellanox: mlx5: avoid uninitialized variable warning with gcc-12 (Amir Tzin) [2112925]
- net/mlx5: E-Switch, pair only capable devices (Amir Tzin) [2112925 2150647]
- Revert "net/mlx5e: Allow relaxed ordering over VFs" (Amir Tzin) [2112925]
- net/mlx5: Fix mlx5_get_next_dev() peer device matching (Amir Tzin) [2112925]
- RDMA/mlx5: Remove duplicate pointer assignment in mlx5_ib_alloc_implicit_mr() (Amir Tzin) [2112925]
- net/mlx5: fix multiple definitions of mlx5_lag_mpesw_init / mlx5_lag_mpesw_cleanup (Amir Tzin) [2112925]
- net/mlx5: Support multiport eswitch mode (Amir Tzin) [2112925 2150647]
- net/mlx5: Remove unused argument (Amir Tzin) [2112925]
- net/mlx5: Lag, refactor lag state machine (Amir Tzin) [2112925]
- net/mlx5e: Add XDP SQs to uplink representors steering tables (Amir Tzin) [2112925]
- net/mlx5e: Allow relaxed ordering over VFs (Amir Tzin) [2112925]
- net/mlx5e: Support partial GSO for tunnels over vlans (Amir Tzin) [2112925]
- net/mlx5e: IPoIB, Improve ethtool rxnfc callback structure in IPoIB (Amir Tzin) [2112925]
- net/mlx5e: Allocate virtually contiguous memory for reps structures (Amir Tzin) [2112925]
- net/mlx5e: Allocate virtually contiguous memory for VLANs list (Amir Tzin) [2112925]
- net/mlx5: Allocate virtually contiguous memory in pci_irq.c (Amir Tzin) [2112925]
- net/mlx5: Allocate virtually contiguous memory in vport.c (Amir Tzin) [2112925]
- net/mlx5: Inline db alloc API function (Amir Tzin) [2112925]
- net/mlx5: Add last command failure syndrome to debugfs (Amir Tzin) [2112925]
- net/mlx5: sparse: error: context imbalance in 'mlx5_vf_get_core_dev' (Amir Tzin) [2112925]
- net/mlx5: Expose mlx5_sriov_blocking_notifier_register / unregister APIs (Amir Tzin) [2112925]
- net/mlx5: Lag, add debugfs to query hardware lag state (Amir Tzin) [2112925]
- net/mlx5: Lag, use buckets in hash mode (Amir Tzin) [2112925]
- net/mlx5: Lag, refactor dmesg print (Amir Tzin) [2112925]
- net/mlx5: Support devices with more than 2 ports (Amir Tzin) [2112925]
- net/mlx5: Lag, use actual number of lag ports (Amir Tzin) [2112925]
- net/mlx5: Lag, use hash when in roce lag on 4 ports (Amir Tzin) [2112925]
- net/mlx5: Lag, support single FDB only on 2 ports (Amir Tzin) [2112925]
- net/mlx5: Lag, store number of ports inside lag object (Amir Tzin) [2112925]
- net/mlx5: Lag, filter non compatible devices (Amir Tzin) [2112925]
- net/mlx5: Lag, use lag lock (Amir Tzin) [2112925]
- net/mlx5: Lag, move E-Switch prerequisite check into lag code (Amir Tzin) [2112925]
- net/mlx5: devcom only supports 2 ports (Amir Tzin) [2112925]
- net/mlx5: Lag, expose number of lag ports (Amir Tzin) [2112925]
- net/mlx5: Increase FW pre-init timeout for health recovery (Amir Tzin) [2112925]
- net/mlx5: Add exit route when waiting for FW (Amir Tzin) [2112925]
- net/mlx5e: Use XFRM state direction instead of flags (Amir Tzin) [2112925]
- net/mlx5: Allow future addition of IPsec object modifiers (Amir Tzin) [2112925]
- net/mlx5: Don't perform lookup after already known sec_path (Amir Tzin) [2112925]
- net/mlx5: Cleanup XFRM attributes struct (Amir Tzin) [2112925]
- net/mlx5: Remove not-supported ICV length (Amir Tzin) [2112925]
- net/mlx5: Simplify IPsec capabilities logic (Amir Tzin) [2112925]
- net/mlx5: Don't advertise IPsec netdev support for non-IPsec device (Amir Tzin) [2112925]
- net/mlx5: Make sure that no dangling IPsec FS pointers exist (Amir Tzin) [2112925]
- net/mlx5: Clean IPsec FS add/delete rules (Amir Tzin) [2112925]
- net/mlx5: Simplify HW context interfaces by using SA entry (Amir Tzin) [2112925]
- net/mlx5: Remove indirections from esp functions (Amir Tzin) [2112925]
- net/mlx5: Merge various control path IPsec headers into one file (Amir Tzin) [2112925]
- net/mlx5: Remove useless validity check (Amir Tzin) [2112925]
- net/mlx5: Store IPsec ESN update work in XFRM state (Amir Tzin) [2112925]
- net/mlx5: Reduce useless indirection in IPsec FS add/delete flows (Amir Tzin) [2112925]
- net/mlx5: Don't hide fallback to software IPsec in FS code (Amir Tzin) [2112925]
- net/mlx5: Check IPsec TX flow steering namespace in advance (Amir Tzin) [2112925]
- net/mlx5: Simplify IPsec flow steering init/cleanup functions (Amir Tzin) [2112925]
- net/mlx5: fs, an FTE should have no dests when deleted (Amir Tzin) [2112925]
- net/mlx5: fs, call the deletion function of the node (Amir Tzin) [2112925]
- net/mlx5: fs, delete the FTE when there are no rules attached to it (Amir Tzin) [2112925]
- net/mlx5: fs, do proper bookkeeping for forward destinations (Amir Tzin) [2112925]
- net/mlx5: fs, add unused destination type (Amir Tzin) [2112925]
- net/mlx5: fs, jump to exit point and don't fall through (Amir Tzin) [2112925]
- net/mlx5: fs, refactor software deletion rule (Amir Tzin) [2112925]
- net/mlx5: fs, split software and IFC flow destination definitions (Amir Tzin) [2112925]
- net/mlx5e: TC, set proper dest type (Amir Tzin) [2112925]
- net/mlx5e: Remove unused mlx5e_dcbnl_build_rep_netdev function (Amir Tzin) [2112925]
- net/mlx5e: Drop error CQE handling from the XSK RX handler (Amir Tzin) [2112925]
- net/mlx5: Print initializing field in case of timeout (Amir Tzin) [2112925]
- net/mlx5: Delete redundant default assignment of runtime devlink params (Amir Tzin) [2112925]
- net/mlx5: Remove useless kfree (Amir Tzin) [2112925]
- net/mlx5: use kvfree() for kvzalloc() in mlx5_ct_fs_smfs_matcher_create (Amir Tzin) [2112925]
- RDMA/mlx5: Clean UMR QP type flow from mlx5_ib_post_send() (Amir Tzin) [2112925]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to update xlt (Amir Tzin) [2112925]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to update MR pas (Amir Tzin) [2112925]
- RDMA/mlx5: Move creation and free of translation tables to umr.c (Amir Tzin) [2112925]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to rereg pd access (Amir Tzin) [2112925]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to revoke MRs (Amir Tzin) [2112925]
- RDMA/mlx5: Introduce mlx5_umr_post_send_wait() (Amir Tzin) [2112925]
- RDMA/mlx5: Expose wqe posting helpers outside of wr.c (Amir Tzin) [2112925]
- RDMA/mlx5: Simplify get_umr_update_access_mask() (Amir Tzin) [2112925]
- RDMA/mlx5: Move mkey ctrl segment logic to umr.c (Amir Tzin) [2112925]
- RDMA/mlx5: Move umr checks to umr.h (Amir Tzin) [2112925]
- RDMA/mlx5: Move init and cleanup of UMR to umr.c (Amir Tzin) [2112925]
- RDMA/mlx5: Fix flow steering egress flow (Amir Tzin) [2112925]
- mlx5, xsk: Diversify return values from xsk_wakeup call paths (Amir Tzin) [2112925]
- net/mlx5: Remove not-implemented IPsec capabilities (Amir Tzin) [2112925]
- net/mlx5: Remove ipsec_ops function table (Amir Tzin) [2112925]
- net/mlx5: Reduce kconfig complexity while building crypto support (Amir Tzin) [2112925]
- net/mlx5: Move IPsec file to relevant directory (Amir Tzin) [2112925]
- net/mlx5: Remove not-needed IPsec config (Amir Tzin) [2112925]
- net/mlx5: Align flow steering allocation namespace to common style (Amir Tzin) [2112925]
- net/mlx5: Unify device IPsec capabilities check (Amir Tzin) [2112925]
- net/mlx5: Remove useless IPsec device checks (Amir Tzin) [2112925]
- net/mlx5: Remove ipsec vs. ipsec offload file separation (Amir Tzin) [2112925]
- RDMA/mlx5: Drop crypto flow steering API (Amir Tzin) [2112925]
- RDMA/mlx5: Delete never supported IPsec flow action (Amir Tzin) [2112925]
- net/mlx5: Remove FPGA ipsec specific statistics (Amir Tzin) [2112925]
- net/mlx5: Remove XFRM no_trailer flag (Amir Tzin) [2112925]
- net/mlx5: Remove not-used IDA field from IPsec struct (Amir Tzin) [2112925]
- net/mlx5: Delete metadata handling logic (Amir Tzin) [2112925]
- net/mlx5_fpga: Drop INNOVA IPsec support (Amir Tzin) [2112925]
- net/mlx5: Cleanup kTLS function names and their exposure (Amir Tzin) [2112925]
- net/mlx5: Remove tls vs. ktls separation as it is the same (Amir Tzin) [2112925]
- net/mlx5: Remove indirection in TLS build (Amir Tzin) [2112925]
- net/mlx5: Reliably return TLS device capabilities (Amir Tzin) [2112925]
- net/mlx5_fpga: Drop INNOVA TLS support (Amir Tzin) [2112925]
- ipv6: Use ipv6_only_sock() helper in condition (mlx5 hunk only). (Amir Tzin) [2112925]
- Revert "stmmac/intel: mark driver as tech preview" (Mark Salter) [2122230]
- net: stmmac: Fix queue statistics reading (Mark Salter) [2122230]
- stmmac: intel: Update PCH PTP clock rate from 200MHz to 204.8MHz (Mark Salter) [2122230]
- net: stmmac: power up/down serdes in stmmac_open/release (Mark Salter) [2122230]
- stmmac: intel: Simplify intel_eth_pci_remove() (Mark Salter) [2122230]
- net: stmmac: work around sporadic tx issue on link-up (Mark Salter) [2122230]
- stmmac: intel: Add a missing clk_disable_unprepare() call in intel_eth_pci_remove() (Mark Salter) [2122230]
- net: phylink: fix SGMII inband autoneg enable (Mark Salter) [2122230]
- net: phylink: fix NULL pl->pcs dereference during phylink_pcs_poll_start (Mark Salter) [2122230]
- net: phylink: disable PCS polling over major configuration (Mark Salter) [2122230]
- net: phylink: remove pcs_ops member (Mark Salter) [2122230]
- net: pcs: xpcs: depends on PHYLINK in Kconfig (Mark Salter) [2122230]
- net: phylink: add QSGMII support to phylink_mii_c22_pcs_encode_advertisement() (Mark Salter) [2122230]
- net: stmmac: make mdio register skips PHY scanning for fixed-link (Mark Salter) [2122230]
- stmmac: intel: add phy-mode and fixed-link ACPI _DSD setting support (Mark Salter) [2122230]
- net: pcs: xpcs: add CL37 1000BASE-X AN support (Mark Salter) [2122230]
- stmmac: intel: prepare to support 1000BASE-X phy interface setting (Mark Salter) [2122230]
- net: make xpcs_do_config to accept advertising for pcs-xpcs and sja1105 (Mark Salter) [2122230]
- net: pcs: xpcs: propagate xpcs_read error to xpcs_get_state_c37_sgmii (Mark Salter) [2122230]
- net: stmmac: remove redunctant disable xPCS EEE call (Mark Salter) [2122230]
- net: stmmac: fix dma queue left shift overflow issue (Mark Salter) [2122230]
- net: stmmac: switch to use interrupt for hw crosstimestamping (Mark Salter) [2122230]
- net: stmmac: fix unbalanced ptp clock issue in suspend/resume flow (Mark Salter) [2122230]
- net: stmmac: fix pm runtime issue in stmmac_dvr_remove() (Mark Salter) [2122230]
- net: stmmac: dwc-qos: Disable split header for Tegra194 (Mark Salter) [2122230]
- stmmac: intel: Fix an error handling path in intel_eth_pci_probe() (Mark Salter) [2122230]
- stmmac: intel: Add RPL-P PCI ID (Mark Salter) [2122230]
- net: stmmac: use dev_err_probe() for reporting mdio bus registration failure (Mark Salter) [2122230]
- net: stmmac: remove unused get_addr() callback (Mark Salter) [2122230]
- net: pcs: pcs-xpcs: Convert to mdiobus_c45_read (Mark Salter) [2122230]
- net: phylink: Convert to mdiobus_c45_{read|write} (Mark Salter) [2122230]
- net: stmmac: stmmac_main: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2122230]
- net: phylink: remove phylink_helper_basex_speed() (Mark Salter) [2122230]
- net: phylink: remove phylink_set_10g_modes() (Mark Salter) [2122230]
- net: stmmac: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2122230]
- net: stmmac: fix missing pci_disable_device() on error in stmmac_pci_probe() (Mark Salter) [2122230]
- net: stmmac: disable Split Header (SPH) for Intel platforms (Mark Salter) [2122230]
- net: stmmac: Use readl_poll_timeout_atomic() in atomic state (Mark Salter) [2122230]
- net: stmmac: Fix unset max_speed difference between DT and non-DT platforms (Mark Salter) [2122230]
- stmmac: intel: Add ADL-N PCI ID (Mark Salter) [2122230]
- net: stmmac: switch no PTP HW support message to info level (Mark Salter) [2122230]
- net: phylink: remove phylink_set_pcs() (Mark Salter) [2122230]
- stmmac: intel: Enable 2.5Gbps for Intel AlderLake-S (Mark Salter) [2122230]
- net: phylink: remove phylink_config's pcs_poll (Mark Salter) [2122230]
- net: phylink: use legacy_pre_march2020 (Mark Salter) [2122230]
- net: phylink: add legacy_pre_march2020 indicator (Mark Salter) [2122230]
- net: stmmac: optimize locking around PTP clock reads (Mark Salter) [2122230]
- net: stmmac: use .mac_select_pcs() interface (Mark Salter) [2122230]
- net: stmmac: convert to phylink_generic_validate() (Mark Salter) [2122230]
- net: stmmac: remove phylink_config.pcs_poll usage (Mark Salter) [2122230]
- net: stmmac/xpcs: convert to pcs_validate() (Mark Salter) [2122230]
- net: convert users of bitmap_foo() to linkmode_foo() (Mark Salter) [2122230]
- net: phylink: add pcs_validate() method (Mark Salter) [2122230]
- net: phylink: add mac_select_pcs() method to phylink_mac_ops (Mark Salter) [2122230]
- net: phylink: tidy up disable bit clearing (Mark Salter) [2122230]
- net: phylink: handle NA interface mode in phylink_fwnode_phy_connect() (Mark Salter) [2122230]
- net: phylink: Add helpers for c22 registers without MDIO (Mark Salter) [2122230]
- net: phylink: add 1000base-KX to phylink_caps_to_linkmodes() (Mark Salter) [2122230]
- net: phylink: add generic validate implementation (Mark Salter) [2122230]
- net: phylink: use supported_interfaces for phylink validation (Mark Salter) [2122230]
- net: phylink: add MAC phy_interface_t bitmap (Mark Salter) [2122230]
- net: phy: add phy_interface_t bitmap support (Mark Salter) [2122230]
- net: phylink: Convert some users of mdiobus_* to mdiodev_* (Mark Salter) [2122230]
- net: phylink: use mdiobus_modify_changed() helper (Mark Salter) [2122230]
- net: mdio: add mdiobus_modify_changed() (Mark Salter) [2122230]
- net: phylink: add phylink_set_10g_modes() helper (Mark Salter) [2122230]
- net: stmmac: fill in supported_interfaces (Mark Salter) [2122230]
- net: stmmac: convert to phylink_get_linkmodes() (Mark Salter) [2122230]
- net: xpcs: add support for retrieving supported interface modes (Mark Salter) [2122230]
- net: mdio: Add helper functions for accessing MDIO devices (Mark Salter) [2122230]
- net: stmmac: fix return value of __setup handler (Mark Salter) [2122230]
- net: stmmac: only enable DMA interrupts when ready (Mark Salter) [2122230]
- net: stmmac: ensure PTP time register reads are consistent (Mark Salter) [2122230]
- net: stmmac: dump gmac4 DMA registers correctly (Mark Salter) [2122230]
- net: stmmac: properly handle with runtime pm in stmmac_dvr_remove() (Mark Salter) [2122230]
- net: stmmac: skip only stmmac_ptp_register when resume from suspend (Mark Salter) [2122230]
- drivers/net/ethernet: clean up mis-targeted comments (Mark Salter) [2122230]
- net: stmmac: configure PTP clock source prior to PTP initialization (Mark Salter) [2122230]
- net: stmmac: reduce unnecessary wakeups from eee sw timer (Mark Salter) [2122230]
- net: stmmac: remove unused members in struct stmmac_priv (Mark Salter) [2122230]
- net: stmmac: Fix "Unbalanced pm_runtime_enable!" warning (Mark Salter) [2122230]
- net: stmmac: add tc flower filter for EtherType matching (Mark Salter) [2122230]
- net: stmmac: bump tc when get underflow error from DMA descriptor (Mark Salter) [2122230]
- stmmac: remove ethtool driver version info (Mark Salter) [2122230]
- net: stmmac: Calculate CDC error only once (Mark Salter) [2122230]
- net: stmmac: ptp: fix potentially overflowing expression (Mark Salter) [2122230]
- net: stmmac: fix tc flower deletion for VLAN priority Rx steering (Mark Salter) [2122230]
- net: stmmac: Avoid DMA_CHAN_CONTROL write if no Split Header support (Mark Salter) [2122230]
- net: stmmac: Disable Tx queues when reconfiguring the interface (Mark Salter) [2122230]
- net: phylink: Force retrigger in case of latched link-fail indicator (Mark Salter) [2122230]
- net: phylink: Force link down and retrigger resolve on interface change (Mark Salter) [2122230]
- net: stmmac: retain PTP clock time during SIOCSHWTSTAMP ioctls (Mark Salter) [2122230]
- stmmac_pci: Fix underflow size in stmmac_rx (Mark Salter) [2122230]
- net: stmmac: Fix signed/unsigned wreckage (Mark Salter) [2122230]
- net: stmmac: allow a tc-taprio base-time of zero (Mark Salter) [2122230]
- ethernet: stmmac: use eth_hw_addr_set() (Mark Salter) [2122230]
- net: phylink: Support disabling autonegotiation for PCS (Mark Salter) [2122230]
- net: stmmac: fix off-by-one error in sanity check (Mark Salter) [2122230]
- net: stmmac: fix gcc-10 -Wrestrict warning (Mark Salter) [2122230]
- net: phylink: don't call netif_carrier_off() with NULL netdev (Mark Salter) [2122230]
- net: stmmac: Fix E2E delay mechanism (Mark Salter) [2122230]
- net: stmmac: add support for dwmac 3.40a (Mark Salter) [2122230]
- net: stmmac: fix get_hw_feature() on old hardware (Mark Salter) [2122230]
- net: stmmac: trigger PCS EEE to turn off on link down (Mark Salter) [2122230]
- net: pcs: xpcs: fix incorrect steps on disable EEE (Mark Salter) [2122230]
- net: pcs: xpcs: fix incorrect CL37 AN sequence (Mark Salter) [2122230]
- net: stmmac: fix EEE init issue when paired with EEE capable PHYs (Mark Salter) [2122230]
- net: stmmac: allow CSR clock of 300MHz (Mark Salter) [2122230]
- net: stmmac: platform: fix build warning when with !CONFIG_PM_SLEEP (Mark Salter) [2122230]
- net: stmmac: fix system hang caused by eee_ctrl_timer during suspend/resume (Mark Salter) [2122230]
- net: stmmac: fix MAC not working when system resume back with WoL active (Mark Salter) [2122230]
- net: phylink: add suspend/resume support (Mark Salter) [2122230]
- net: stmmac: add ethtool per-queue irq statistic support (Mark Salter) [2122230]
- net: stmmac: add ethtool per-queue statistic framework (Mark Salter) [2122230]
- net: stmmac: fix INTR TBU status affecting irq count statistic (Mark Salter) [2122230]
- net: pcs: xpcs: Add Pause Mode support for SGMII and 2500BaseX (Mark Salter) [2122230]
- net: stmmac: fix kernel panic due to NULL pointer dereference of plat->est (Mark Salter) [2122230]
- net: pcs: xpcs: fix error handling on failed to allocate memory (Mark Salter) [2122230]
- net: stmmac: add est_irq_status callback function for GMAC 4.10 and 5.10 (Mark Salter) [2122230]
- net: stmmac: ptp: update tas basetime after ptp adjust (Mark Salter) [2122230]
- net: stmmac: add mutex lock to protect est parameters (Mark Salter) [2122230]
- net: stmmac: separate the tas basetime calculation function (Mark Salter) [2122230]
- net: stmmac: Terminate FPE workqueue in suspend (Mark Salter) [2122230]
- stmmac: intel: set PCI_D3hot in suspend (Mark Salter) [2122230]
- stmmac: intel: Enable PHY WOL option in EHL (Mark Salter) [2122230]
- net: stmmac: option to enable PHY WOL with PMT enabled (Mark Salter) [2122230]
- net: stmmac: remove redundant continue statement (Mark Salter) [2122230]
- stmmac: intel: fix wrong kernel-doc (Mark Salter) [2122230]
- stmmac: intel: move definitions to dwmac-intel header file (Mark Salter) [2122230]
- net: pcs: xpcs: export xpcs_do_config and xpcs_link_up (Mark Salter) [2122230]
- net: pcs: xpcs: also ignore phy id if it's all ones (Mark Salter) [2122230]
- net: pcs: xpcs: add support for sgmii with no inband AN (Mark Salter) [2122230]
- net: pcs: xpcs: move register bit descriptions to a header file (Mark Salter) [2122230]
- net: stmmac: reduce indentation when calling stmmac_xpcs_setup (Mark Salter) [2122230]
- net: stmmac: reverse Christmas tree notation in stmmac_xpcs_setup (Mark Salter) [2122230]
- net: pcs: xpcs: rename mdio_xpcs_args to dw_xpcs (Mark Salter) [2122230]
- net: phylink: Refactor phylink_of_phy_connect() (Mark Salter) [2122230]
- net: phylink: introduce phylink_fwnode_phy_connect() (Mark Salter) [2122230]
- net: phy: Introduce phy related fwnode functions (Mark Salter) [2122230]
- net: phy: Introduce fwnode_mdio_find_device() (Mark Salter) [2122230]
- net: stmmac: Fix unused values warnings (Mark Salter) [2122230]
- net: stmmac: Fix mixed enum type warning (Mark Salter) [2122230]
- net: stmmac: Fix missing { } around two statements in an if statement (Mark Salter) [2122230]
- net: stmmac: explicitly deassert GMAC_AHB_RESET (Mark Salter) [2122230]
- net: stmmac: platform: use optional clk/reset get APIs (Mark Salter) [2122230]
- net: stmmac: fix NPD with phylink_set_pcs if there is no MDIO bus (Mark Salter) [2122230]
- net: stmmac: enable Intel mGbE 2.5Gbps link speed (Mark Salter) [2122230]
- net: pcs: add 2500BASEX support for Intel mGbE controller (Mark Salter) [2122230]
- net: stmmac: split xPCS setup from mdio register (Mark Salter) [2122230]
- net: pcs: xpcs: convert to phylink_pcs_ops (Mark Salter) [2122230]
- net: pcs: xpcs: convert to mdio_device (Mark Salter) [2122230]
- net: pcs: xpcs: use mdiobus_c45_addr in xpcs_{read,write} (Mark Salter) [2122230]
- net: pcs: xpcs: export xpcs_probe (Mark Salter) [2122230]
- net: pcs: xpcs: export xpcs_config_eee (Mark Salter) [2122230]
- net: pcs: xpcs: export xpcs_validate (Mark Salter) [2122230]
- net: pcs: xpcs: make the checks related to the PHY interface mode stateless (Mark Salter) [2122230]
- net: pcs: xpcs: delete shim definition for mdio_xpcs_get_ops() (Mark Salter) [2122230]
- net: pcs: xpcs: there is only one PHY ID (Mark Salter) [2122230]
- net: stmmac: enable platform specific safety features (Mark Salter) [2122230]
- net: stmmac: the XPCS obscures a potential "PHY not found" error (Mark Salter) [2122230]
- net: stmmac: Add callbacks for DWC xpcs Energy Efficient Ethernet (Mark Salter) [2122230]
- net: pcs: Introducing support for DWC xpcs Energy Efficient Ethernet (Mark Salter) [2122230]

* Thu Feb 02 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-456.el8]
- xfs: reserve quota for dir expansion when linking/unlinking files (Bill O'Donnell) [2086880]
- scsi: storvsc: Fix swiotlb bounce buffer leak in confidential VM (Emanuele Giuseppe Esposito) [2150659]
- ACPICA: Fix operand resolution (Mark Langsdorf) [2156144]
- driver core: Add missing kernel doc for device::msi_lock (Myron Stowe) [2158839]
- PCI/MSI: Protect msi_desc::masked for multi-MSI (Myron Stowe) [2158839]
- KVM: arm64: Don't retrieve memory slot again in page fault handler (Gavin Shan) [2161161]
- fs: allow cross-vfsmount reflink/dedupe (Andrey Albershteyn) [2086200]
- powerpc/hv-gpci: Fix hv_gpci event list (Mamatha Inamdar) [2161258]
- powerpc: declare unmodified attribute_group usages const (Mamatha Inamdar) [2161258]
- drm/amd: Delay removal of the firmware framebuffer (Michel Dänzer) [2162039]
- cpuidle: Add cpu_idle_miss trace event (Mark Langsdorf) [2122312]
- cpuidle: haltpoll: Add trace points for guest_halt_poll_ns grow/shrink (Mark Langsdorf) [2122312]
- efi/cper, cxl: Decode CXL Error Log (Lenny Szubowicz) [2143733]
- efi/cper, cxl: Decode CXL Protocol Error Section (Lenny Szubowicz) [2143733]
- efi: cper: Add support for printing Firmware Error Record Reference (Lenny Szubowicz) [2143733]
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_reassemble_sdu (Wander Lairson Costa) [2152927] {CVE-2022-3564}
- drm/i915: Fix CFI violations in gt_sysfs (Jocelyn Falempe) [2154880]
- NFS: Clear the file access cache upon login (Benjamin Coddington) [2050832]
- NFS: don't store 'struct cred *' in struct nfs_access_entry (Benjamin Coddington) [2050832]
- NFS: pass cred explicitly for access tests (Benjamin Coddington) [2050832]
- NFS: change nfs_access_get_cached to only report the mask (Benjamin Coddington) [2050832]
- init: Initialize noop_backing_dev_info early (Nico Pache) [2160228]
- mm: vmscan: make rotations a secondary factor in balancing anon vs file (Nico Pache) [2160228]
- writeback: Fix inode->i_io_list not be protected by inode->i_lock error (Nico Pache) [2160228]
- mm: vmscan: fix extreme overreclaim and swap floods (Nico Pache) [2160228]
- mm/page_alloc: ensure kswapd doesn't accidentally go to sleep (Nico Pache) [2160228]
- mm/page_io: count submission time as thrashing delay for delayacct (Nico Pache) [2160228]
- delayacct: support re-entrance detection of thrashing accounting (Nico Pache) [2160228]
- filemap: make the accounting of thrashing more consistent (Nico Pache) [2160228]
- writeback: don't warn on an unregistered BDI in __mark_inode_dirty (Nico Pache) [2160228]
- s390/dasd: fix no record found for raw_track_access (Tobias Huschle) [2161270]
- crypto: testmgr - disallow certain DRBG hash functions in FIPS mode (Vladis Dronov) [2152133]
- dmaengine: idxd: Fix crc_val field for completion record (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Make read buffer sysfs attributes invisible for Intel IAA (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Make max batch size attributes in sysfs invisible for Intel IAA (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Do not call DMX TX callbacks during workqueue disable (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Prevent use after free on completion memory (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Let probe fail when workqueue cannot be enabled (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Fix max batch size for Intel IAA (Jerry Snitselaar) [2144375]
- dmaengine: idxd: add configuration for concurrent batch descriptor processing (Jerry Snitselaar) [2144375]
- dmanegine: idxd: reformat opcap output to match bitmap_parse() input (Jerry Snitselaar) [2144375]
- dmaengine: idxd: add configuration for concurrent work descriptor processing (Jerry Snitselaar) [2144375]
- dmaengine: idxd: add WQ operation cap restriction support (Jerry Snitselaar) [2144375]
- dmaengine: idxd: convert ats_dis to a wq flag (Jerry Snitselaar) [2144375]
- dmaengine: idxd: track enabled workqueues in bitmap (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Set wq state to disabled in idxd_wq_disable_cleanup() (Jerry Snitselaar) [2144375]
- dmaengine: idxd: Do not enable user type Work Queue without Shared Virtual Addressing (Jerry Snitselaar) [2144375]
- dmaengine: idxd: fix RO device state error after been disabled/reset (Jerry Snitselaar) [2144375]
- dmaengine: idxd: avoid deadlock in process_misc_interrupts() (Jerry Snitselaar) [2144375]
- KVM: x86: nSVM: implement nested LBR virtualization (Emanuele Giuseppe Esposito) [2155149]
- KVM: x86: nSVM: correctly virtualize LBR msrs when L2 is running (Emanuele Giuseppe Esposito) [2155149]
- kvm: x86: SVM: use vmcb* instead of svm->vmcb where it makes sense (Emanuele Giuseppe Esposito) [2155149]
- KVM: x86: nSVM: implement nested VMLOAD/VMSAVE (Emanuele Giuseppe Esposito) [2155149]
- eth: octeon: fix build after netif_napi_add() changes (Íñigo Huguet) [2152918]
- net: drop the weight argument from netif_napi_add (Íñigo Huguet) [2152918]
- net: remove netif_tx_napi_add() (Íñigo Huguet) [2152918]
- ipoib: switch to netif_napi_add_weight() (Íñigo Huguet) [2152918]
- IB/hfi1: switch to netif_napi_add_weight() (Íñigo Huguet) [2152918]
- IB/hfi1: switch to netif_napi_add_tx() (Íñigo Huguet) [2152918]
- crypto: caam/qi2 - switch to netif_napi_add_tx_weight() (Íñigo Huguet) [2152918]
- can: can-dev: move to netif_napi_add_weight() (Íñigo Huguet) [2152918]
- net: virtio: switch to netif_napi_add_weight() (Íñigo Huguet) [2152918]
- r8152: switch to netif_napi_add_weight() (Íñigo Huguet) [2152918]
- eth: switch to netif_napi_add_weight() (Íñigo Huguet) [2152918]
- mt76: switch to netif_napi_add_tx() (Íñigo Huguet) [2152918]
- net: move snowflake callers to netif_napi_add_tx_weight() (Íñigo Huguet) [2152918]
- net: switch to netif_napi_add_tx() (Íñigo Huguet) [2152918]
- can: m_can: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2152918]
- eth: remove remaining copies of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2152918]
- eth: benet: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2152918]
- eth: atlantic: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2152918]
- eth: smsc: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2152918]
- eth: remove copies of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2152918]
- netdev: reshuffle netif_napi_add() APIs to allow dropping weight (Íñigo Huguet) [2152918]
- ipv6: raw: Deduct extension header length in rawv6_push_pending_frames (Hangbin Liu) [2162124] {CVE-2023-0394}
- netfilter: conntrack: handle tcp challenge acks during connection reuse (Florian Westphal) [2158726]
- act_mirred: use the backlog for nested calls to mirred ingress (Davide Caratti) [2131339] {CVE-2022-4269}
- net/sched: act_mirred: better wording on protection against excessive stack growth (Davide Caratti) [2131339]
- xfs: add selinux labels to whiteout inodes (Andrey Albershteyn) [2094060]
- tdx: enable TDX attestation driver (Wander Lairson Costa) [2076748]
- selftests/tdx: Test TDX attestation GetReport support (Wander Lairson Costa) [2076748]
- virt: Add TDX guest driver (Wander Lairson Costa) [2076748]
- x86/tdx: Add a wrapper to get TDREPORT0 from the TDX Module (Wander Lairson Costa) [2076748]
- proc: proc_skip_spaces() shouldn't think it is working on C strings (Wander Lairson Costa) [2152572] {CVE-2022-4378}
- proc: avoid integer type confusion in get_proc_long (Wander Lairson Costa) [2152572] {CVE-2022-4378}
- NFSv4.2: Update mode bits after ALLOCATE and DEALLOCATE (Jeffrey Layton) [2127153]
- NFS: nfsiod should not block forever in mempool_alloc() (Jeffrey Layton) [2127153]
- NFSv4.1: Handle NFS4ERR_DELAY replies to OP_SEQUENCE correctly (Benjamin Coddington) [2061259]
- NFSv4.1: Don't decrease the value of seq_nr_highest_sent (Benjamin Coddington) [2061259]

* Wed Feb 01 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-455.el8]
- uas: ignore UAS for Thinkplus chips (Torez Smith) [2113004]
- usb-storage: Add Hiksemi USB3-FW to IGNORE_UAS (Torez Smith) [2113004]
- thunderbolt: Explicitly reset plug events delay back to USB4 spec value (Torez Smith) [2113004]
- USB: serial: option: add Quectel BG95 0x0203 composition (Torez Smith) [2113004]
- thunderbolt: Add support for Intel Maple Ridge single port controller (Torez Smith) [2113004]
- USB: core: Fix RST error in hub.c (Torez Smith) [2113004]
- kunit: fix Kconfig for build-in tests USB4 and Nitro Enclaves (Torez Smith) [2113004]
- usb: storage: Add ASUS <0x0b05:0x1932> to IGNORE_UAS (Torez Smith) [2113004]
- USB: serial: cp210x: add Decagon UCA device id (Torez Smith) [2113004]
- USB: core: Prevent nested device-reset calls (Torez Smith) [2113004]
- usb: typec: Remove retimers properly (Torez Smith) [2113004]
- USB: serial: ftdi_sio: add Omron CS1W-CIF31 device id (Torez Smith) [2113004]
- USB: serial: option: add support for OPPO R11 diag port (Torez Smith) [2113004]
- xhci: Add grace period after xHC start to prevent premature runtime suspend. (Torez Smith) [2113004]
- xhci: Fix null pointer dereference in remove if xHC has only one roothub (Torez Smith) [2113004]
- USB: cdc-acm: Add Icom PMR F3400 support (0c26:0020) (Torez Smith) [2113004]
- usb: xhci-mtk: fix bandwidth release issue (Torez Smith) [2113004]
- usb: xhci-mtk: relax TT periodic bandwidth allocation (Torez Smith) [2113004]
- usb: typec: altmodes/displayport: correct pin assignment for UFP receptacles (Torez Smith) [2113004]
- usb: typec: intel_pmc_mux: Add new ACPI ID for Meteor Lake IOM device (Torez Smith) [2113004]
- usb-storage: Add ignore-residue quirk for NXP PN7462AU (Torez Smith) [2113004]
- usb: typec: tcpm: Return ENOTSUPP for power supply prop writes (Torez Smith) [2113004]
- thunderbolt: Check router generation before connecting xHCI (Torez Smith) [2113004]
- thunderbolt: Use the actual buffer in tb_async_error() (Torez Smith) [2113004]
- USB: usbsevseg: convert sysfs snprintf to sysfs_emit (Torez Smith) [2113004]
- dt-bindings: usb: Add binding for TI USB8041 hub controller (Torez Smith) [2113004]
- usb: typec: ucsi: stm32g0: add bootloader support (Torez Smith) [2113004]
- usb: typec: ucsi: stm32g0: add support for stm32g0 controller (Torez Smith) [2113004]
- dt-bindings: usb: typec: add bindings for stm32g0 controller (Torez Smith) [2113004]
- usb: typec: ucsi: Acknowledge the GET_ERROR_STATUS command completion (Torez Smith) [2113004]
- usb: typec: retimer: Add missing id check in match callback (Torez Smith) [2113004]
- USB: xhci: Fix comment typo (Torez Smith) [2113004]
- usb/typec/tcpm: fix repeated words in comments (Torez Smith) [2113004]
- usb/misc: fix repeated words in comments (Torez Smith) [2113004]
- usb/image: fix repeated words in comments (Torez Smith) [2113004]
- usb/host: fix repeated words in comments (Torez Smith) [2113004]
- usb/core: fix repeated words in comments (Torez Smith) [2113004]
- usb/atm: fix repeated words in comments (Torez Smith) [2113004]
- USB: HCD: Fix URB giveback issue in tasklet function (Torez Smith) [2113004]
- usb: xhci_plat_remove: avoid NULL dereference (Torez Smith) [2113004]
- USB: serial: fix tty-port initialized comments (Torez Smith) [2113004]
- USB: serial: usb_wwan: replace DTR/RTS magic numbers with macros (Torez Smith) [2113004]
- USB: cdc-acm: use CDC serial-state defines (Torez Smith) [2113004]
- USB: cdc-acm: use CDC control-line defines (Torez Smith) [2113004]
- USB: cdc: add serial-state defines (Torez Smith) [2113004]
- USB: cdc: add control-signal defines (Torez Smith) [2113004]
- net/cdc_ncm: Increase NTB max RX/TX values to 64kb (Torez Smith) [2113004]
- usb: typec: Add retimer handle to port (Torez Smith) [2113004]
- usb: typec: Add support for retimers (Torez Smith) [2113004]
- dt-bindings: usb: Add analogix anx7411 PD binding (Torez Smith) [2113004]
- usb: ldusb: replace ternary operator with max_t() (Torez Smith) [2113004]
- USB: serial: fix repeated word "the" in comments (Torez Smith) [2113004]
- USB: serial: io_edgeport: fix spelling mistakes (Torez Smith) [2113004]
- USB: serial: ftdi_sio: add Belimo device ids (Torez Smith) [2113004]
- thunderbolt: test: Use kunit_test_suite() macro (Torez Smith) [2113004]
- media: pvrusb2: drop unexpected word 'a' in comments (Torez Smith) [2113004]
- media: gspca: drop unexpected word 'is' in the comments (Torez Smith) [2113004]
- usb: typec: add missing uevent when partner support PD (Torez Smith) [2113004]
- tools: usb: testusb: Add super-plus speed reporting (Torez Smith) [2113004]
- tools: usb: testusb: Add super speed reporting (Torez Smith) [2113004]
- tools: usb: testusb: Add wireless speed reporting (Torez Smith) [2113004]
- usb: typec: tcpci: move tcpci.h to include/linux/usb/ (Torez Smith) [2113004]
- ARM: sa1100/assabet: move dmabounce hack to ohci driver (Torez Smith) [2113004]
- usb: host: xhci: use snprintf() in xhci_decode_trb() (Torez Smith) [2113004]
- USB: cdc-acm: use define for timeout (Torez Smith) [2113004]
- usb: typec_altmode: add a missing "@" at a kernel-doc parameter (Torez Smith) [2113004]
- usb: core: sysfs: convert sysfs snprintf to sysfs_emit (Torez Smith) [2113004]
- media: usb: gspca: aligned '*' each line (Torez Smith) [2113004]
- media: hdpvr: fix error value returns in hdpvr_read (Torez Smith) [2113004]
- media: em28xx: Remove useless license text when SPDX-License-Identifier is already used (Torez Smith) [2113004]
- USB: serial: use kmemdup instead of kmalloc + memcpy (Torez Smith) [2113004]
- usb: host: ehci-q: Fix ehci_submit_single_step_set_feature annotation typo (Torez Smith) [2113004]
- USB: storage: Fix typo in comment (Torez Smith) [2113004]
- usb: typec: mux: Add CONFIG guards for functions (Torez Smith) [2113004]
- usb: typec: mux: Allow muxes to specify mode-switch (Torez Smith) [2113004]
- usb: musb: Add support for PolarFire SoC's musb controller (Torez Smith) [2113004]
- media: pvrusb2: fix memory leak in pvr_probe (Torez Smith) [2113004]
- media: airspy: respect the DMA coherency rules (Torez Smith) [2113004]
- media: usbtv: Add PAL-Nc standard (Torez Smith) [2113004]
- thunderbolt: Fix typo in comment (Torez Smith) [2113004]
- dt-bindings: usb: add documentation for aspeed udc (Torez Smith) [2113004]
- usb: Avoid extra usb SET_SEL requests when enabling link power management (Torez Smith) [2113004]
- usb: typec: tcpm: Register USB Power Delivery Capabilities (Torez Smith) [2113004]
- usb: typec: USB Power Delivery helpers for ports and partners (Torez Smith) [2113004]
- usb: typec: Separate USB Power Delivery from USB Type-C (Torez Smith) [2113004]
- usb: hub: port: add sysfs entry to switch port power (Torez Smith) [2113004]
- ucsi_ccg: ACPI based I2c client enumeration for AMD ASICs (Torez Smith) [2113004]
- ucsi_ccg: Do not hardcode interrupt polarity and type (Torez Smith) [2113004]
- usb: xhci-mtk: add support optional controller reset (Torez Smith) [2113004]
- usb: typec: tcpm: fix typo in comment (Torez Smith) [2113004]
- usb: xhci: tegra: Fix error check (Torez Smith) [2113004]
- usb: common: usb-conn-gpio: Allow wakeup from system suspend (Torez Smith) [2113004]
- usbip: vudc: Don't enable IRQs prematurely (Torez Smith) [2113004]
- USB: usbip: clean up mixed use of _irq() and _irqsave() (Torez Smith) [2113004]
- USB: Follow-up to SPDX identifiers addition - remove now useless comments (Torez Smith) [2113004]
- thunderbolt: Fix some kernel-doc comments (Torez Smith) [2113004]
- usb: hub: Simplify error and success path in port_over_current_notify (Torez Smith) [2113004]
- usb: remove Link Powermanagement (LPM) disable before port reset. (Torez Smith) [2113004]
- thunderbolt: Change TMU mode to HiFi uni-directional once DisplayPort tunneled (Torez Smith) [2113004]
- usb: core: Bail out when port is stuck in reset loop (Torez Smith) [2113004]
- thunderbolt: Add CL1 support for USB4 and Titan Ridge routers (Torez Smith) [2113004]
- thunderbolt: Change downstream router's TMU rate in both TMU uni/bidir mode (Torez Smith) [2113004]
- USB: core: Fix bug in resuming hub's handling of wakeup requests (Torez Smith) [2113004]
- thunderbolt: Fix typos in CLx enabling (Torez Smith) [2113004]
- usb: hub: Add delay for SuperSpeed hub resume to let links transit to U0 (Torez Smith) [2113004]
- usb: hub: make wait_for_connected() take an int instead of a pointer to int (Torez Smith) [2113004]
- thunderbolt: CLx disable before system suspend only if previously enabled (Torez Smith) [2113004]
- usb: hub: avoid warm port reset during USB3 disconnect (Torez Smith) [2113004]
- thunderbolt: Silently ignore CLx enabling in case CLx is not supported (Torez Smith) [2113004]

* Mon Jan 30 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-454.el8]
- config: Enable Security Path (Ricardo Robaina) [2161309]
- tcp: Fix build break when CONFIG_IPV6=n (Jamie Bainbridge) [2143849]
- tcp: annotate data-race around queue->synflood_warned (Jamie Bainbridge) [2143849]
- tcp: Add listening address to SYN flood message (Jamie Bainbridge) [2143849]
- tcp: Fix data-races around sysctl_tcp_syncookies. (Jamie Bainbridge) [2143849]
- firmware_loader: Fix memory leak in firmware upload (Mark Langsdorf) [2122319]
- firmware_loader: Fix use-after-free during unregister (Mark Langsdorf) [2122319]
- firmware_loader: fix memory leak for paged buffer (Mark Langsdorf) [2122319]
- firmware_loader: describe 'module' parameter of firmware_upload_register() (Mark Langsdorf) [2122319]
- firmware_loader: Move definitions from sysfs_upload.h to sysfs.h (Mark Langsdorf) [2122319]
- firmware_loader: Add sysfs nodes to monitor fw_upload (Mark Langsdorf) [2122319]
- firmware_loader: Add firmware-upload support (Mark Langsdorf) [2122319]
- firmware_loader: Split sysfs support from fallback (Mark Langsdorf) [2122319]
- firmware_loader: Clear data and size in fw_free_paged_buf (Mark Langsdorf) [2122319]
- firmware: Use kvmalloc for page tables (Mark Langsdorf) [2122319]
- firmware: Unify the paged buffer release helper (Mark Langsdorf) [2122319]
- firmware: Free temporary page table after vmapping (Mark Langsdorf) [2122319]
- arch_topology: Make cluster topology span at least SMT CPUs (Mark Langsdorf) [2122319]
- driver core: fix driver_set_override() issue with empty strings (Mark Langsdorf) [2122319]
- arch_topology: Silence early cacheinfo errors when non-existent (Mark Langsdorf) [2122319]
- driver core: Don't probe devices after bus_type.match() probe deferral (Mark Langsdorf) [2122319]
- regmap: spi: Reserve space for register address/padding (Mark Langsdorf) [2122319]
- arch_topology: Fix cache attributes detection in the CPU hotplug path (Mark Langsdorf) [2122319]
- cacheinfo: Use atomic allocation for percpu cache attributes (Mark Langsdorf) [2122319]
- regmap: permit to set reg_update_bits with bulk implementation (Mark Langsdorf) [2122319]
- PM: domains: Ensure genpd_debugfs_dir exists before remove (Mark Langsdorf) [2122319]
- PM: runtime: Extend support for wakeirq for force_suspend|resume (Mark Langsdorf) [2122319]
- regmap: add WARN_ONCE when invalid mask is provided to regmap_field_init() (Mark Langsdorf) [2122319]
- PM: wakeup: Unify device_init_wakeup() for PM_SLEEP and !PM_SLEEP (Mark Langsdorf) [2122319]
- arch_topology: Warn that topology for nested clusters is not supported (Mark Langsdorf) [2122319]
- arch_topology: Add support for parsing sockets in /cpu-map (Mark Langsdorf) [2122319]
- arch_topology: Set cluster identifier in each core/thread from /cpu-map (Mark Langsdorf) [2122319]
- arch_topology: Limit span of cpu_clustergroup_mask() (Mark Langsdorf) [2122319]
- arch_topology: Don't set cluster identifier as physical package identifier (Mark Langsdorf) [2122319]
- arch_topology: Avoid parsing through all the CPUs once a outlier CPU is found (Mark Langsdorf) [2122319]
- arch_topology: Check for non-negative value rather than -1 for IDs validity (Mark Langsdorf) [2122319]
- arch_topology: Set thread sibling cpumask only within the cluster (Mark Langsdorf) [2122319]
- arch_topology: Drop LLC identifier stash from the CPU topology (Mark Langsdorf) [2122319]
- arm64: topology: Remove redundant setting of llc_id in CPU topology (Mark Langsdorf) [2122319]
- arch_topology: Use the last level cache information from the cacheinfo (Mark Langsdorf) [2122319]
- arch_topology: Add support to parse and detect cache attributes (Mark Langsdorf) [2122319]
- cacheinfo: Align checks in cache_shared_cpu_map_{setup,remove} for readability (Mark Langsdorf) [2122319]
- cacheinfo: Use cache identifiers to check if the caches are shared if available (Mark Langsdorf) [2122319]
- cacheinfo: Allow early detection and population of cache attributes (Mark Langsdorf) [2122319]
- cacheinfo: Add support to check if last level cache(LLC) is valid or shared (Mark Langsdorf) [2122319]
- cacheinfo: Move cache_leaves_are_shared out of CONFIG_OF (Mark Langsdorf) [2122319]
- cacheinfo: Add helper to access any cache index for a given CPU (Mark Langsdorf) [2122319]
- cacheinfo: Use of_cpu_device_node_get instead cpu_dev->of_node (Mark Langsdorf) [2122319]
- regmap: cache: Add extra parameter check in regcache_init (Mark Langsdorf) [2122319]
- regmap-irq: Refactor checks for status bulk read support (Mark Langsdorf) [2122319]
- regmap-irq: Remove mask_writeonly and regmap_irq_update_bits() (Mark Langsdorf) [2122319]
- regmap-irq: Remove inappropriate uses of regmap_irq_update_bits() (Mark Langsdorf) [2122319]
- driver core: fix potential deadlock in __driver_attach (Mark Langsdorf) [2122319]
- devtmpfs: fix the dangling pointer of global devtmpfsd thread (Mark Langsdorf) [2122319]
- regmap: Don't warn about cache only mode for devices with no cache (Mark Langsdorf) [2122319]
- regmap: Wire up regmap_config provided bulk write in missed functions (Mark Langsdorf) [2122319]
- regmap: Make regmap_noinc_read() return -ENOTSUPP if map->read isn't set (Mark Langsdorf) [2122319]
- regmap: Re-introduce bulk read support check in regmap_bulk_read() (Mark Langsdorf) [2122319]
- init: Initialize noop_backing_dev_info early (Mark Langsdorf) [2122319]
- driver core: Introduce device_find_any_child() helper (Mark Langsdorf) [2122319]
- regmap: cache: Fix syntax errors in comments (Mark Langsdorf) [2122319]
- PM: domains: Trust domain-idle-states from DT to be correct by genpd (Mark Langsdorf) [2122319]
- PM: domains: Measure power-on/off latencies in genpd based on a governor (Mark Langsdorf) [2122319]
- PM: domains: Allocate governor data dynamically based on a genpd governor (Mark Langsdorf) [2122319]
- PM: domains: Clean up some code in pm_genpd_init() and genpd_remove() (Mark Langsdorf) [2122319]
- PM: domains: Fix initialization of genpd's next_wakeup (Mark Langsdorf) [2122319]
- PM: domains: Fixup QoS latency measurements for IRQ safe devices in genpd (Mark Langsdorf) [2122319]
- PM: domains: Measure suspend/resume latencies in genpd based on governor (Mark Langsdorf) [2122319]
- PM: domains: Move the next_wakeup variable into the struct gpd_timing_data (Mark Langsdorf) [2122319]
- PM: domains: Allocate gpd_timing_data dynamically based on governor (Mark Langsdorf) [2122319]
- PM: domains: Skip another warning in irq_safe_dev_in_sleep_domain() (Mark Langsdorf) [2122319]
- PM: domains: Rename irq_safe_dev_in_no_sleep_domain() in genpd (Mark Langsdorf) [2122319]
- PM: domains: Don't check PM_QOS_FLAG_NO_POWER_OFF in genpd (Mark Langsdorf) [2122319]
- PM: domains: Drop redundant code for genpd always-on governor (Mark Langsdorf) [2122319]
- PM: domains: Add GENPD_FLAG_RPM_ALWAYS_ON for the always-on governor (Mark Langsdorf) [2122319]
- PM: wakeup: expose pm_wakeup_pending to modules (Mark Langsdorf) [2122319]
- driver core: fix deadlock in __device_attach (Mark Langsdorf) [2122319]
- driver: base: fix UAF when driver_attach failed (Mark Langsdorf) [2122319]
- driver core: location: Add "back" as a possible output for panel (Mark Langsdorf) [2122319]
- driver core: location: Free struct acpi_pld_info *pld (Mark Langsdorf) [2122319]
- regmap: Add missing map->bus check (Mark Langsdorf) [2122319]
- device property: Advertise fwnode and device property count API calls (Mark Langsdorf) [2122319]
- driver core: location: Check for allocations failure (Mark Langsdorf) [2122319]
- regmap: Add bulk read/write callbacks into regmap_config (Mark Langsdorf) [2122319]
- device property: Fix recent breakage of fwnode_get_next_parent_dev() (Mark Langsdorf) [2122319]
- drivers/base/memory: fix an unlikely reference counting issue in __add_memory_block() (Mark Langsdorf) [2122319]
- driver core: Add dma_cleanup callback in bus_type (Mark Langsdorf) [2122319]
- driver core: Add sysfs support for physical location of a device (Mark Langsdorf) [2122319]
- drivers/base/node.c: fix compaction sysfs file leak (Mark Langsdorf) [2122319]
- driver core: Prevent overriding async driver of a device before it probe (Mark Langsdorf) [2122319]
- Documentation: dd: Use ReST lists for return values of driver_deferred_probe_check_state() (Mark Langsdorf) [2122319]
- regmap: cache: set max_register with reg_stride (Mark Langsdorf) [2122319]
- firmware_loader: Check fw_state_is_done in loading_store (Mark Langsdorf) [2122319]
- driver: platform: Add helper for safer setting of driver_override (Mark Langsdorf) [2122319]
- PM: domains: Move genpd's time-accounting to ktime_get_mono_fast_ns() (Mark Langsdorf) [2122319]
- PM: runtime: Allow to call __pm_runtime_set_status() from atomic context (Mark Langsdorf) [2122319]
- device property: Drop 'test' prefix in parameters of fwnode_is_ancestor_of() (Mark Langsdorf) [2122319]
- device property: Introduce fwnode_for_each_parent_node() (Mark Langsdorf) [2122319]
- device property: Allow error pointer to be passed to fwnode APIs (Mark Langsdorf) [2122319]
- device property: Check fwnode->secondary in fwnode_graph_get_next_endpoint() (Mark Langsdorf) [2122319]
- PM: runtime: Avoid device usage count underflows (Mark Langsdorf) [2122319]
- PM: domains: Extend dev_pm_domain_detach() doc (Mark Langsdorf) [2122319]

* Wed Jan 25 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-453.el8]
- gitlab-ci: use CI templates from production branch (Michael Hofmann)
- cpufreq: ACPI: Remove unused variables 'acpi_cpufreq_online' and 'ret' (Mark Langsdorf) [2038200]
- cpufreq: ACPI: Only set boost MSRs on supported CPUs (Mark Langsdorf) [2038200]
- cpufreq: ACPI: Defer setting boost MSRs (Mark Langsdorf) [2038200]
- s390/kexec: fix ipl report address for kdump (Tobias Huschle) [2161328]
- iavf: schedule watchdog immediately when changing primary MAC (Michal Schmidt) [2152493]
- iavf: Move netdev_update_features() into watchdog task (Michal Schmidt) [2152493]
- iavf: fix temporary deadlock and failure to set MAC address (Michal Schmidt) [2152493]
- iavf: Fix error handling in iavf_init_module() (Michal Schmidt) [2152493]

* Mon Jan 23 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-452.el8]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2103955]
- ixgbe: stop resetting SYSTIME in ixgbe_ptp_start_cyclecounter (Ken Cox) [2103955]
- ixgbe: Manual AN-37 for troublesome link partners for X550 SFI (Ken Cox) [2103955]
- ixgbe: Don't call kmap() on page allocated with GFP_ATOMIC (Ken Cox) [2103955]
- ixgbe: convert .adjfreq to .adjfine (Ken Cox) [2103955]
- ixgbe: drop unexpected word 'for' in comments (Ken Cox) [2103955]
- ixgbe: remove unexpected word "the" (Ken Cox) [2103955]
- intel: remove unused macros (Ken Cox) [2103955]
- ixgbe: Fix typos in comments (Ken Cox) [2103955]
- drivers, ixgbe: export vf statistics (Ken Cox) [2103955]
- ixgbe: fix unexpected VLAN Rx in promisc mode on VF (Ken Cox) [2103955]
- ixgbe: fix bcast packets Rx on VF after promisc removal (Ken Cox) [2103955]
- ixgbe: propagate XFRM offload state direction instead of flags (Ken Cox) [2103955]
- ixgbe: Fix module_param allow_unsupported_sfp type (Ken Cox) [2103955]
- ixgbe: ensure IPsec VF<->PF compatibility (Ken Cox) [2103955]
- ixgbe, xsk: Get rid of redundant 'fallthrough' (Ken Cox) [2103955]
- ixgbe, xsk: Diversify return values from xsk_wakeup call paths (Ken Cox) [2103955]
- ixgbe, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ken Cox) [2103955]
- ixgbe, xsk: Decorate IXGBE_XDP_REDIR with likely() (Ken Cox) [2103955]
- ixgbe: add improvement for MDD response functionality (Ken Cox) [2103955]
- ixgbe: add the ability for the PF to disable VF link state (Ken Cox) [2103955]
- ixgbe: xsk: change !netif_carrier_ok() handling in ixgbe_xmit_zc() (Ken Cox) [2103955]
- ixgbe: Remove non-inclusive language (Ken Cox) [2103955]
- ixgbe: Use irq_update_affinity_hint() (Ken Cox) [2103955]
- net: convert users of bitmap_foo() to linkmode_foo() (Ken Cox) [2103955]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2103955]
- net: Use skb_frag_off accessors (Ken Cox) [2103955]
- drm/i915: Fix watermark calculations for DG2 CCS+CC modifier (Jocelyn Falempe) [2041686]
- drm/i915: Fix watermark calculations for DG2 CCS modifiers (Jocelyn Falempe) [2041686]
- drm/i915: Fix watermark calculations for gen12+ CCS+CC modifier (Jocelyn Falempe) [2041686]
- drm/i915: Fix watermark calculations for gen12+ MC CCS modifier (Jocelyn Falempe) [2041686]
- drm/i915: Fix watermark calculations for gen12+ RC CCS modifier (Jocelyn Falempe) [2041686]
- drm/i915/uc: fix device/bus include on rhel8 (Jocelyn Falempe) [2041686]
- drm/i915/display: consider DG2_RC_CCS_CC when migrating buffers (Jocelyn Falempe) [2041686]
- drm/i915: allow control over the flags when migrating (Jocelyn Falempe) [2041686]
- drm/i915/display: handle migration for dpt (Jocelyn Falempe) [2041686]
- drm/i915/huc: better define HuC status getparam possible return values. (Jocelyn Falempe) [2041686]
- drm/i915/huc: stall media submission until HuC is loaded (Jocelyn Falempe) [2041686]
- drm/i915/huc: track delayed HuC load with a fence (Jocelyn Falempe) [2041686]
- drm/i915/dg2: setup HuC loading via GSC (Jocelyn Falempe) [2041686]
- drm/i915/pxp: add huc authentication and loading command (Jocelyn Falempe) [2041686]
- drm/i915/pxp: implement function for sending tee stream command (Jocelyn Falempe) [2041686]
- drm/i915/pxp: load the pxp module when we have a gsc-loaded huc (Jocelyn Falempe) [2041686]
- drm/i915/gt: Flush to global observation point before breadcrumb write (Jocelyn Falempe) [2041686]
- drm/i915/guc/slpc: Add SLPC selftest live_slpc_power (Jocelyn Falempe) [2041686]
- drm/i915/guc/slpc: Run SLPC selftests on all tiles (Jocelyn Falempe) [2041686]
- drm/i915: Remove unwanted pointer unpacking (Jocelyn Falempe) [2041686]
- drm/i915/guc: Enable compute scheduling on DG2 (Jocelyn Falempe) [2041686]
- drm/i915/dg2: introduce Wa_22015475538 (Jocelyn Falempe) [2041686]
- drm/i915/uc: Update to latest GuC and use new-format GuC/HuC names (Jocelyn Falempe) [2041686]
- Revert "drm/i915/dg2: extend Wa_1409120013 to DG2" (Jocelyn Falempe) [2041686]
- drm/i915/gsc: allocate extended operational memory in LMEM (Jocelyn Falempe) [2041686]
- drm/i915/gsc: add GSC XeHP SDV platform definition (Jocelyn Falempe) [2041686]
- drm/i915/gsc: add slow_firmware flag to the gsc device definition (Jocelyn Falempe) [2041686]
- drm/i915/gsc: skip irq initialization if using polling (Jocelyn Falempe) [2041686]
- drm/i915/uc: Add patch level version number support (Jocelyn Falempe) [2041686]
- drm/i915/uc: Support for version reduced and multiple firmware files (Jocelyn Falempe) [2041686]
- drm/i915/ttm: Abort suspend on i915_ttm_backup failure (Jocelyn Falempe) [2041686]
- drm/i915/dg2: Incorporate Wa_16014892111 into DRAW_WATERMARK tuning (Jocelyn Falempe) [2041686]
- drm/i915/guc: Record CTB info in error logs (Jocelyn Falempe) [2041686]
- drm/i915/guc: Add GuC <-> kernel time stamp translation information (Jocelyn Falempe) [2041686]
- drm/i915/guc: Don't use pr_err when not necessary (Jocelyn Falempe) [2041686]
- drm/i915/dg2: Add support for DC5 state (Jocelyn Falempe) [2041686]
- drm/i915/dmc: Update DG2 DMC firmware to v2.07 (Jocelyn Falempe) [2041686]
- drm/i915/dg2: Add additional tuning settings (Jocelyn Falempe) [2041686]
- drm/i915/gt: Add dedicated function for non-ctx register tuning settings (Jocelyn Falempe) [2041686]
- drm/i915/dg2: Add Wa_1509727124 (Jocelyn Falempe) [2041686]
- drm/i915/dg2: Update DG2 to GuC v70.4.1 (Jocelyn Falempe) [2041686]
- drm/i915/dg2: Add additional HDMI pixel clock frequencies (Jocelyn Falempe) [2041686]
- Revert "drm/i915/dg2: Add preemption changes for Wa_14015141709" (Jocelyn Falempe) [2041686]
- config: Enable TDX Guest (Wander Lairson Costa) [1836977]
- x86/tdx: mark TDX as a tech preview (Wander Lairson Costa) [1836977]
- x86/tdx: Panic on bad configs that #VE on "private" memory access (Wander Lairson Costa) [1836977]
- x86/tdx: Prepare for using "INFO" call for a second purpose (Wander Lairson Costa) [1836977]
- x86/tdx: Handle load_unaligned_zeropad() page-cross to a shared page (Wander Lairson Costa) [1836977]
- x86/tdx: Clarify RIP adjustments in #VE handler (Wander Lairson Costa) [1836977]
- vt: Initialize conswitchp to dummy_con if unset (Wander Lairson Costa) [1836977]
- x86/tdx: Fix early #VE handling (Wander Lairson Costa) [1836977]
- x86/tdx: Fix RETs in TDX asm (Wander Lairson Costa) [1836977]
- x86/apic: Do apic driver probe for "nosmp" use case (Wander Lairson Costa) [1836977]
- x86/mm: Fix spacing within memory encryption features message (Wander Lairson Costa) [1836977]
- x86/kaslr: Fix build warning in KASLR code in boot stub (Wander Lairson Costa) [1836977]
- Documentation/x86: Document TDX kernel architecture (Wander Lairson Costa) [1836977]
- ACPICA: Avoid cache flush inside virtual machines (Wander Lairson Costa) [1836977]
- x86/tdx/ioapic: Add shared bit for IOAPIC base address (Wander Lairson Costa) [1836977]
- x86/mm: Make DMA memory shared for TD guest (Wander Lairson Costa) [1836977]
- x86/mm/cpa: Add support for TDX shared memory (Wander Lairson Costa) [1836977]
- x86/tdx: Make pages shared in ioremap() (Wander Lairson Costa) [1836977]
- x86/topology: Disable CPU online/offline control for TDX guests (Wander Lairson Costa) [1836977]
- x86/boot: Avoid #VE during boot for TDX platforms (Wander Lairson Costa) [1836977]
- x86/boot/compressed/64: Use TEST reg,reg instead of CMP $0,reg (Wander Lairson Costa) [1836977]
- x86/boot/compressed/64: Do not corrupt EDX on EFER.LME=1 setting (Wander Lairson Costa) [1836977]
- x86/boot/compressed/64: Set EFER.LME=1 in 32-bit trampoline before returning to long mode (Wander Lairson Costa) [1836977]
- x86/boot: Set CR0.NE early and keep it set during the boot (Wander Lairson Costa) [1836977]
- x86/acpi/x86/boot: Add multiprocessor wake-up support (Wander Lairson Costa) [1836977]
- x86/boot: Add a trampoline for booting APs via firmware handoff (Wander Lairson Costa) [1836977]
- x86/asm/realmode: Use SYM_DATA_* instead of GLOBAL (Wander Lairson Costa) [1836977]
- x86/realmode: Remove trampoline_status (Wander Lairson Costa) [1836977]
- x86/tdx: Wire up KVM hypercalls (Wander Lairson Costa) [1836977]
- x86/tdx: Port I/O: Add early boot support (Wander Lairson Costa) [1836977]
- x86/tdx: Port I/O: Add runtime hypercalls (Wander Lairson Costa) [1836977]
- x86/boot: Port I/O: Add decompression-time support for TDX (Wander Lairson Costa) [1836977]
- x86/boot: Port I/O: Allow to hook up alternative helpers (Wander Lairson Costa) [1836977]
- x86: Consolidate port I/O helpers (Wander Lairson Costa) [1836977]
- x86: Adjust types used in port I/O helpers (Wander Lairson Costa) [1836977]
- x86/tdx: Detect TDX at early kernel decompression time (Wander Lairson Costa) [1836977]
- x86/tdx: Handle in-kernel MMIO (Wander Lairson Costa) [1836977]
- x86/tdx: Handle CPUID via #VE (Wander Lairson Costa) [1836977]
- x86/tdx: Add MSR support for TDX guests (Wander Lairson Costa) [1836977]
- x86/tdx: Add HLT support for TDX guests (Wander Lairson Costa) [1836977]
- x86/traps: Add #VE support for TDX guest (Wander Lairson Costa) [1836977]
- x86/traps: Refactor exc_general_protection() (Wander Lairson Costa) [1836977]
- x86/traps: Cleanup do_general_protection() (Wander Lairson Costa) [1836977]
- x86/dumpstack: Introduce die_addr() for die() with #GP fault address (Wander Lairson Costa) [1836977]
- x86/traps: Print address on #GP (Wander Lairson Costa) [1836977]
- x86/kprobes: Inline kprobe_exceptions_notify() into do_general_protection() (Wander Lairson Costa) [1836977]
- x86/tdx: Exclude shared bit from __PHYSICAL_MASK (Wander Lairson Costa) [1836977]
- x86/tdx: Extend the confidential computing API to support TDX guests (Wander Lairson Costa) [1836977]
- x86/tdx: Add __tdx_module_call() and __tdx_hypercall() helper functions (Wander Lairson Costa) [1836977]
- x86/tdx: Provide common base for SEAMCALL and TDCALL C wrappers (Wander Lairson Costa) [1836977]
- x86/tdx: Detect running as a TDX guest in early boot (Wander Lairson Costa) [1836977]
- x86/mm/cpa: Generalize __set_memory_enc_pgtable() (Wander Lairson Costa) [1836977]
- x86/mm/pat: Don't flush cache if hardware enforces cache coherency across encryption domnains (Wander Lairson Costa) [1836977]
- x86/coco: Add API to handle encryption mask (Wander Lairson Costa) [1836977]
- x86/cc: Move arch/x86/{kernel/cc_platform.c => coco/core.c} (Wander Lairson Costa) [1836977]
- x86/sev-es: Use insn_decode_mmio() for MMIO implementation (Wander Lairson Costa) [1836977]
- x86/insn-eval: Introduce insn_decode_mmio() (Wander Lairson Costa) [1836977]
- x86/insn-eval: Introduce insn_get_modrm_reg_ptr() (Wander Lairson Costa) [1836977]
- x86/insn-eval: Handle insn_get_opcode() failure (Wander Lairson Costa) [1836977]
- x86/sev: Move common memory encryption code to mem_encrypt.c (Wander Lairson Costa) [1836977]
- x86/sev: Rename mem_encrypt.c to mem_encrypt_amd.c (Wander Lairson Costa) [1836977]
- x86/virtio: Have SEV guests enforce restricted virtio memory access (Wander Lairson Costa) [1836977]
- devlink: protect devlink dump by the instance lock (Petr Oros) [2131116]
- devlink: hold region lock when flushing snapshots (Petr Oros) [2131116]
- net: devlink: enable parallel ops on netlink interface (Petr Oros) [2131116]
- net: devlink: remove devlink_mutex (Petr Oros) [2131116]
- net: devlink: convert reload command to take implicit devlink->lock (Petr Oros) [2131116]
- net: devlink: introduce "unregistering" mark and use it during devlinks iteration (Petr Oros) [2131116]
- devlink: Fix use-after-free after a failed reload (Petr Oros) [2131116]
- net: devlink: Fix missing mutex_unlock() call (Petr Oros) [2131116]
- Documentation: devlink: add add devlink-selftests to the table of contents (Petr Oros) [2131116]
- devlink: Hold the instance lock in health callbacks (Petr Oros) [2131116]
- net/mlx4: Lock mlx4 devlink reload callback (Petr Oros) [2131116]
- net/mlx4: Use devl_ API for devlink port register / unregister (Petr Oros) [2131116]
- net/mlx4: Use devl_ API for devlink region create / destroy (Petr Oros) [2131116]
- net: devlink: remove region snapshots list dependency on devlink->lock (Petr Oros) [2131116]
- net: devlink: remove region snapshot ID tracking dependency on devlink->lock (Petr Oros) [2131116]
- devlink: introduce framework for selftests (Petr Oros) [2131116]
- net: devlink: remove redundant net_eq() check from sb_pool_get_dumpit() (Petr Oros) [2131116]
- net: devlink: move net check into devlinks_xa_for_each_registered_get() (Petr Oros) [2131116]
- net: devlink: make sure that devlink_try_get() works with valid pointer during xarray iteration (Petr Oros) [2131116]
- netdevsim: convert driver to use unlocked devlink API during init/fini (Petr Oros) [2131116]
- net: devlink: add unlocked variants of devlink_region_create/destroy() functions (Petr Oros) [2131116]
- net: devlink: add unlocked variants of devlink_dpipe*() functions (Petr Oros) [2131116]
- net: devlink: add unlocked variants of devlink_sb*() functions (Petr Oros) [2131116]
- net: devlink: add unlocked variants of devlink_resource*() functions (Petr Oros) [2131116]
- net: devlink: add unlocked variants of devling_trap*() functions (Petr Oros) [2131116]
- net: devlink: avoid false DEADLOCK warning reported by lockdep (Petr Oros) [2131116]
- net: devlink: fix return statement in devlink_port_new_notify() (Petr Oros) [2131116]
- net: devlink: fix a typo in function name devlink_port_new_notifiy() (Petr Oros) [2131116]
- net: devlink: make devlink_dpipe_headers_register() return void (Petr Oros) [2131116]
- net: devlink: move unlocked function prototypes alongside the locked ones (Petr Oros) [2131116]
- net: devlink: use helpers to work with devlink->lock mutex (Petr Oros) [2131116]
- net: devlink: fix unlocked vs locked functions descriptions (Petr Oros) [2131116]
- devlink: Hold the instance lock in port_new / port_del callbacks (Petr Oros) [2131116]
- powercap: intel_rapl: Add support for RAPTORLAKE_S (Prarit Bhargava) [2120363]
- selftests/bpf: Fix test_varlen verification failure with latest llvm (Yauheni Kaliuta) [2149222]
- iwlwifi: remove firmware version limit for AC9560 (Íñigo Huguet) [2129361]
- wifi: iwlwifi: fw: skip PPAG for JF (Íñigo Huguet) [2129361]
- sched: Improve wake_up_all_idle_cpus() take #2 (Julia Denham) [2134931]
- selftests/livepatch: better synchronize test_klp_callbacks_busy (Julia Denham) [2121204]
- sched,livepatch: Use wake_up_if_idle() (Joe Lawrence) [2134931]
- sched: Simplify wake_up_*idle*() (Joe Lawrence) [2134931]
- sched,livepatch: Use task_call_func() (Joe Lawrence) [2134931]
- sched,rcu: Rework try_invoke_on_locked_down_task() (Joe Lawrence) [2134931]
- sched: Improve try_invoke_on_locked_down_task() (Joe Lawrence) [2134931]
- arm64/bpf: Remove 128MB limit for BPF JIT programs (Yauheni Kaliuta) [2140163]
- bpf: Define bpf_jit_alloc_exec_limit for arm64 JIT (Yauheni Kaliuta) [2140163]
- arm64: extable: add `type` and `data` fields (Yauheni Kaliuta) [2140163]
- arm64: extable: use `ex` for `exception_table_entry` (Yauheni Kaliuta) [2140163]
- arm64: extable: make fixup_exception() return bool (Yauheni Kaliuta) [2140163]
- arm64: extable: consolidate definitions (Yauheni Kaliuta) [2140163]
- arm64: kvm: use kvm_exception_table_entry (Yauheni Kaliuta) [2140163]
- s390/cio: check the subchannel validity for dev_busid (Tobias Huschle) [2160494]
- s390/cio: add dev_busid sysfs entry for each subchannel (Tobias Huschle) [2160494]

* Thu Jan 19 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-451.el8]
- intel_idle: Add AlderLake-N support (Prarit Bhargava) [2144692]
- selftests/timens: add a test for vfork+exit (Oleg Nesterov) [2116444]
- fs/exec: switch timens when a task gets a new mm (Oleg Nesterov) [2116444]
- namespace: make timens_on_fork() return nothing (Oleg Nesterov) [2116444]
- timens: make vdso_join_timens() always succeed (Oleg Nesterov) [2116444]
- xfrm: Fix oops in __xfrm_state_delete() (Sabrina Dubroca) [2156048]
- tcp: Fix data races around icsk->icsk_af_ops. (Guillaume Nault) [2143904] {CVE-2022-3566}
- ice: synchronize the misc IRQ when tearing down Tx tracker (Petr Oros) [2148858]
- ice: fix handling of burst Tx timestamps (Petr Oros) [2148858]
- vhost/vsock: Fix error handling in vhost_vsock_init() (Stefano Garzarella) [2159969]
- net: vmw_vsock: vmci: Check memcpy_from_msg() (Stefano Garzarella) [2159969]
- vhost/vsock: Use kvmalloc/kvfree for larger packets. (Stefano Garzarella) [2159969]
- vsock: Set socket state back to SS_UNCONNECTED in vsock_connect_timeout() (Stefano Garzarella) [2159969]
- vsock: Fix memory leak in vsock_connect() (Stefano Garzarella) [2159969]
- tools/power turbostat: Add support for RPL-S (Prarit Bhargava) [2122848]

* Tue Jan 17 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-450.el8]
- nvme: re-order nvme_alloc_ns to match "nvme: use blk_mq_alloc_disk" (Chris Leech) [2152742]
- perf vendor events amd: Add Zen 4 mapping (Michael Petlan) [2148294]
- perf vendor events amd: Add Zen 4 metrics (Michael Petlan) [2148294]
- perf vendor events amd: Add Zen 4 uncore events (Michael Petlan) [2148294]
- perf vendor events amd: Add Zen 4 core events (Michael Petlan) [2148294]
- cpuhotplug: Fix KABI breakage (Prarit Bhargava) [2156529]
- scsi: target: core: Fix hard lockup when executing a compare-and-write command (Maurizio Lombardi) [2119897]
- x86/topology: Fix duplicated core ID within a package (Prarit Bhargava) [2159553]
- x86/topology: Fix multiple packages shown on a single-package system (Prarit Bhargava) [2159553]
- hwmon/coretemp: Handle large core ID value (Prarit Bhargava) [2159553]
- x86: Remove vendor checks from prefer_mwait_c1_over_halt (Prarit Bhargava) [2150067]
- x86: Handle idle=nomwait cmdline properly for x86_idle (Prarit Bhargava) [2150067]
- cpufreq: intel_pstate: Support Sapphire Rapids OOB mode (Prarit Bhargava) [2117767]
- KVM: nVMX: Inject #GP, not #UD, if "generic" VMXON CR0/CR4 check fails (Emanuele Giuseppe Esposito) [2159433]
- vmxnet3: correctly report csum_level for encapsulated packet (Izabela Bakollari) [2158809]
- mei: pxp: support matching with a gfx discrete card (Jocelyn Falempe) [2147557]
- mei: pxp: add command streamer API to the PXP driver (Jocelyn Falempe) [2147557]
- mei: bus: extend bus API to support command streamer API (Jocelyn Falempe) [2147557]
- mei: adjust extended header kdocs (Jocelyn Falempe) [2147557]
- mei: bus: enable sending gsc commands (Jocelyn Falempe) [2147557]
- mei: add support to GSC extended header (Jocelyn Falempe) [2147557]
- mei: debugfs: add pxp mode to devstate in debugfs (Jocelyn Falempe) [2147557]
- mei: drop ready bits check after start (Jocelyn Falempe) [2147557]
- mei: gsc: add transition to PXP mode in resume flow (Jocelyn Falempe) [2147557]
- mei: gsc: setup gsc extended operational memory (Jocelyn Falempe) [2147557]
- mei: mkhi: add memory ready command (Jocelyn Falempe) [2147557]
- mei: bus: export common mkhi definitions into a separate header (Jocelyn Falempe) [2147557]
- mei: extend timeouts on slow devices (Jocelyn Falempe) [2147557]
- mei: gsc: wait for reset thread on stop (Jocelyn Falempe) [2147557]
- mei: gsc: use polling instead of interrupts (Jocelyn Falempe) [2147557]
- mei: add slow_firmware flag to the mei auxiliary device (Jocelyn Falempe) [2147557]
- mei: add kdoc for struct mei_aux_device (Jocelyn Falempe) [2147557]
- mei: me: fix clang -Wformat warning (Jocelyn Falempe) [2147557]
- mei: me: add raptor lake point S DID (Jocelyn Falempe) [2147557]
- mei: hbm: drop capability response on early shutdown (Jocelyn Falempe) [2147557]
- mei: me: set internal pg flag to off on hardware reset (Jocelyn Falempe) [2147557]
- misc/mei: Add NULL check to component match callback functions (Jocelyn Falempe) [2147557]
- drm/display: Move HDCP helpers into display-helper module (Jocelyn Falempe) [2147557]
- mei: gsc: retrieve the firmware version (Jocelyn Falempe) [2147557]
- mei: gsc: add runtime pm handlers (Jocelyn Falempe) [2147557]
- mei: gsc: setup char driver alive in spite of firmware handshake failure (Jocelyn Falempe) [2147557]
- mei: add support for graphics system controller (gsc) devices (Jocelyn Falempe) [2147557]
- mei: avoid iterator usage outside of list_for_each_entry (Jocelyn Falempe) [2147557]
- mei: do not overwrite state on hw start (Jocelyn Falempe) [2147557]
- mei: me: fix reset policy on read error in interrupt (Jocelyn Falempe) [2147557]
- mei: me: avoid link reset on shutdown (Jocelyn Falempe) [2147557]
- mei: me: disable driver on the ign firmware (Jocelyn Falempe) [2147557]
- mei: me: Use dma_set_mask_and_coherent() and simplify code (Jocelyn Falempe) [2147557]
- mei: hbm: fix client dma reply status (Jocelyn Falempe) [2147557]
- mei: cleanup status before client dma setup call (Jocelyn Falempe) [2147557]
- mei: add POWERING_DOWN into device state print (Jocelyn Falempe) [2147557]
- mei: Remove some dead code (Jocelyn Falempe) [2147557]
- mei: bus: add client dma interface (Jocelyn Falempe) [2147557]
- mei: hbm: drop hbm responses on early shutdown (Jocelyn Falempe) [2147557]
- mei: me: add Ice Lake-N device id. (Jocelyn Falempe) [2147557]
- mei: pxp: export pavp client to me client bus (Jocelyn Falempe) [2147557]
- mei: Remove usage of the deprecated "pci-dma-compat.h" API (Jocelyn Falempe) [2147557]
- mei: constify passed buffers and structures (Jocelyn Falempe) [2147557]
- mei: revamp mei extension header structure layout. (Jocelyn Falempe) [2147557]
- mei: fix kdoc in the driver (Jocelyn Falempe) [2147557]
- mei: hdcp: SPDX tag should be the first line (Jocelyn Falempe) [2147557]
- mei: request autosuspend after sending rx flow control (Jocelyn Falempe) [2147557]
- mei: Drop unnecessary NULL check after container_of (Jocelyn Falempe) [2147557]
- mei: me: add Alder Lake P device id. (Jocelyn Falempe) [2147557]
- mei: allow map and unmap of client dma buffer only for disconnected client (Jocelyn Falempe) [2147557]
- mei: use sysfs_emit() in tx_queue_limit_show sysfs (Jocelyn Falempe) [2147557]
- mei: bus: block send with vtag on non-conformat FW (Jocelyn Falempe) [2147557]
- mei: bus: change remove callback to return void (Jocelyn Falempe) [2147557]
- mei: bus: simplify mei_cl_device_remove() (Jocelyn Falempe) [2147557]
- mei: implement client dma setup. (Jocelyn Falempe) [2147557]
- mei: hbm: add client dma hbm messages (Jocelyn Falempe) [2147557]
- mei: add support for client dma capability (Jocelyn Falempe) [2147557]
- mei: allow clients on bus to communicate in remove callback (Jocelyn Falempe) [2147557]
- mei: me: add adler lake point LP DID (Jocelyn Falempe) [2147557]
- mei: hbm: drop hbm responses on shutdown (Jocelyn Falempe) [2147557]
- mei: hbm: call mei_set_devstate() on hbm stop response (Jocelyn Falempe) [2147557]
- mei: document that mei_msg_hdr_init returns ERR_PTR (Jocelyn Falempe) [2147557]
- mei: fix transfer over dma with extended header (Jocelyn Falempe) [2147557]
- misc/mei/hdcp: Fix AUTH_STREAM_REQ cmd buffer len (Jocelyn Falempe) [2147557]
- mei: bus: enable pavp device. (Jocelyn Falempe) [2147557]
- mei: bus: add vtag support (Jocelyn Falempe) [2147557]
- Revert "mei: virtio: virtualization frontend driver" (Jocelyn Falempe) [2147557]
- mei: bus: fix a kernel-doc markup (Jocelyn Falempe) [2147557]
- mei: protect mei_cl_mtu from null dereference (Jocelyn Falempe) [2147557]
- mei: bus: deinitialize callback functions on init failure (Jocelyn Falempe) [2147557]
- mei: bus: do not start a read for disconnected clients (Jocelyn Falempe) [2147557]
- misc: mei: remove unneeded break (Jocelyn Falempe) [2147557]
- mei: hw: Replace zero-length array with flexible-array member (Jocelyn Falempe) [2147557]
- mei: virtio: virtualization frontend driver (Jocelyn Falempe) [2147557]
- mei: add connect with vtag ioctl (Jocelyn Falempe) [2147557]
- mei: bus: unconditionally enable clients with vtag support (Jocelyn Falempe) [2147557]
- mei: bus: use zero vtag for bus clients. (Jocelyn Falempe) [2147557]
- mei: handle tx queue flushing for vtag connections (Jocelyn Falempe) [2147557]
- mei: add a vtag map for each client (Jocelyn Falempe) [2147557]
- mei: add a spin lock to protect rd_completed queue (Jocelyn Falempe) [2147557]
- mei: bump hbm version to 2.2 (Jocelyn Falempe) [2147557]
- mei: add support for mei extended header. (Jocelyn Falempe) [2147557]
- mei: add vtag support bit in client properties (Jocelyn Falempe) [2147557]
- mei: restrict vtag support to hbm version 2.2 (Jocelyn Falempe) [2147557]
- mei: hbm: add capabilities message (Jocelyn Falempe) [2147557]
- Revert "scsi: iscsi: ql4xxx: Use per-session workqueue for unbinding" (Chris Leech) [2122624]
- Revert "scsi: iscsi: Use the session workqueue for recovery" (Chris Leech) [2122624]
- l2tp: Don't sleep and disable BH under writer-side sk_callback_lock (Guillaume Nault) [2145235] {CVE-2022-4129}
- l2tp: Serialize access to sk_user_data with sk_callback_lock (Guillaume Nault) [2145235] {CVE-2022-4129}
- net: fix a concurrency bug in l2tp_tunnel_register() (Guillaume Nault) [2145235] {CVE-2022-4129}
- net: tap: fix general protection fault when freeing an skb when the ring is full (Antoine Tenart) [2152802]
- platform/x86/intel/pmt: Sapphire Rapids PMT errata fix (Prarit Bhargava) [2144689]
- RDMA/core: Fix null-ptr-deref in ib_core_cleanup() (Kamal Heib) [2120677]
- RDMA/rxe: Fix mr leak in RESPST_ERR_RNR (Kamal Heib) [2120677]
- IB/hfi1: Correctly move list in sc_disable() (Kamal Heib) [2120677]
- RDMA/cma: Use output interface for net_dev check (Kamal Heib) [2120677]
- RDMA/usnic: fix set-but-not-unused variable 'flags' warning (Kamal Heib) [2120677]
- IB/rdmavt: Add __init/__exit annotations to module init/exit funcs (Kamal Heib) [2120677]
- RDMA/rxe: Fix resize_finish() in rxe_queue.c (Kamal Heib) [2120677]
- IB: Set IOVA/LENGTH on IB_MR in core/uverbs layers (Kamal Heib) [2120677]
- RDMA/cm: Use SLID in the work completion as the DLID in responder side (Kamal Heib) [2120677]
- RDMA/siw: Fix QP destroy to wait for all references dropped. (Kamal Heib) [2120677]
- RDMA/srp: Fix srp_abort() (Kamal Heib) [2120677]
- RDMA/irdma: Validate udata inlen and outlen (Kamal Heib) [2120677]
- RDMA/irdma: Align AE id codes to correct flush code and event (Kamal Heib) [2120677]
- RDMA/rxe: Fix the error caused by qp->sk (Kamal Heib) [2120677]
- RDMA/rxe: Fix "kernel NULL pointer dereference" error (Kamal Heib) [2120677]
- RDMA/rxe: Remove an unused member from struct rxe_mr (Kamal Heib) [2120677]
- x86/fpu: Fix copy_xstate_to_uabi() to copy init states correctly (Dean Nelson) [2122850]
- x86/fpu: Exclude dynamic states from init_fpstate (Dean Nelson) [2122850]
- x86/fpu: Fix the init_fpstate size check with the actual size (Dean Nelson) [2122850]
- x86/fpu: Configure init_fpstate attributes orderly (Dean Nelson) [2122850]
- x86/fpu/xstate: Fix the ARCH_REQ_XCOMP_PERM implementation (Dean Nelson) [2122850]
- ceph: rely on vfs for setgid stripping (Andrey Albershteyn) [2128904]
- fs: move S_ISGID stripping into the vfs_*() helpers (Andrey Albershteyn) [2128904]
- fs: Add missing umask strip in vfs_tmpfile (Andrey Albershteyn) [2128904]
- fs: add mode_strip_sgid() helper (Andrey Albershteyn) [2128904]

* Thu Jan 12 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-449.el8]
- x86/insn: Add AMX instructions to the x86 instruction decoder (Prarit Bhargava) [2117765]
- intel_idle: Add a new flag to initialize the AMX state (Prarit Bhargava) [2117765]
- x86/fpu: Add a helper to prepare AMX state for low-power CPU idle (Prarit Bhargava) [2117765]
- intel_idle: make SPR C1 and C1E be independent (Prarit Bhargava) [2117765]
- rpmspec: drop traceevent files instead of just excluding them from files list (Michael Petlan) [2155509]
- powerpc/bpf/64: Add instructions for atomic_[cmp]xchg (Mamatha Inamdar) [2113254]
- powerpc/bpf/64: add support for atomic fetch operations (Mamatha Inamdar) [2113254]
- powerpc/bpf/64: add support for BPF_ATOMIC bitwise operations (Mamatha Inamdar) [2113254]
- powerpc/bpf: Simplify bpf_to_ppc() and adopt it for powerpc64 (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Store temp registers' bpf to ppc mapping (Mamatha Inamdar) [2113254]
- powerpc/bpf: Use _Rn macros for GPRs (Mamatha Inamdar) [2113254]
- powerpc/bpf: Move bpf_jit64.h into bpf_jit_comp64.c (Mamatha Inamdar) [2113254]
- powerpc/bpf: Cleanup bpf_jit.h (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Get rid of PPC_BPF_[LL|STL|STLU] macros (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Convert some of the uses of PPC_BPF_[LL|STL] to PPC_BPF_[LD|STD] (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Optimize instruction sequence used for function calls (Mamatha Inamdar) [2113254]
- powerpc64/bpf elfv1: Do not load TOC before calling functions (Mamatha Inamdar) [2113254]
- powerpc64/bpf elfv2: Setup kernel TOC in r2 on entry (Mamatha Inamdar) [2113254]
- powerpc64: Set PPC64_ELF_ABI_v[1|2] macros to 1 (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Use r12 for constant blinding (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Do not save/restore LR on each call to bpf_stf_barrier() (Mamatha Inamdar) [2113254]
- powerpc/bpf: Handle large branch ranges with BPF_EXIT (Mamatha Inamdar) [2113254]
- powerpc/bpf: Emit a single branch instruction for known short branch ranges (Mamatha Inamdar) [2113254]
- powerpc/bpf: Skip branch range validation during first pass (Mamatha Inamdar) [2113254]
- powerpc64/bpf: Limit 'ldbrx' to processors compliant with ISA v2.06 (Mamatha Inamdar) [2113254]
- tools/bpf: Rename 'struct event' to avoid naming conflict (Mamatha Inamdar) [2113254]
- bpf: Guard against accessing NULL pt_regs in bpf_get_task_stack() (Mamatha Inamdar) [2113254]
- bpf ppc64: Access only if addr is kernel address (Mamatha Inamdar) [2113254]
- bpf ppc64: Add BPF_PROBE_MEM support for JIT (Mamatha Inamdar) [2113254]
- powerpc/ppc-opcode: introduce PPC_RAW_BRANCH() macro (Mamatha Inamdar) [2113254]
- bpf powerpc: refactor JIT compiler code (Mamatha Inamdar) [2113254]
- bpf powerpc: Remove extra_pass from bpf_jit_build_body() (Mamatha Inamdar) [2113254]
- bpf powerpc: Remove unused SEEN_STACK (Mamatha Inamdar) [2113254]
- powerpc/bpf: Emit stf barrier instruction sequences for BPF_NOSPEC (Mamatha Inamdar) [2113254]
- powerpc/security: Add a helper to query stf_barrier type (Mamatha Inamdar) [2113254]
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (Mamatha Inamdar) [2113254]
- powerpc/bpf: Fix BPF_MOD when imm == 1 (Mamatha Inamdar) [2113254]
- powerpc/bpf: Validate branch ranges (Mamatha Inamdar) [2113254]
- powerpc/lib: Add helper to check if offset is within conditional branch range (Mamatha Inamdar) [2113254]
- powerpc/lib/feature-fixups: Use PPC_RAW_xxx() macros (Mamatha Inamdar) [2113254]
- powerpc: Move PPC_HA() PPC_HI() and PPC_LO() to ppc-opcode.h (Mamatha Inamdar) [2113254]
- swapfile: fix soft lockup in scan_swap_map_slots (Waiman Long) [2155734]
- mm/swap: add helper swap_offset_available() (Waiman Long) [2155734]
- pNFS/filelayout: Fix coalescing test for single DS (Benjamin Coddington) [2158520]
- arm64: kdump: Support crashkernel=X fall back to reserve region above DMA zones (Pingfan Liu) [1940674]
- arm64: kdump: Provide default size when crashkernel=Y,low is not specified (Pingfan Liu) [1940674]
- media: dmxdev: fix UAF when dvb_register_device() fails (Dean Nelson) [2123301] {CVE-2022-41218}
- crypto: s390/aes - drop redundant xts key check (Vladis Dronov) [2158893]
- crypto: xts - implement xts_verify_key() with xts_check_key() (Vladis Dronov) [2158893]
- audit: cache ctx->major in audit_filter_syscall() (Richard Guy Briggs) [2123854]
- audit: free audit_proctitle only on task exit (Richard Guy Briggs) [2123854]
- audit: explicitly check audit_context->context enum value (Richard Guy Briggs) [2123854]
- audit: move audit_return_fixup before the filters (Richard Guy Briggs) [2123854]
- audit: fix potential double free on error path from fsnotify_add_inode_mark (Richard Guy Briggs) [2123854]
- i2c: ismt: Fix an out-of-bounds bug in ismt_access() (Prarit Bhargava) [2119066] {CVE-2022-2873}
- net: dropreason: add SKB_DROP_REASON_FRAG_TOO_FAR (Antoine Tenart) [2155186]
- net: dropreason: add SKB_DROP_REASON_FRAG_REASM_TIMEOUT (Antoine Tenart) [2155186]
- net: dropreason: add SKB_DROP_REASON_DUP_FRAG (Antoine Tenart) [2155186]
- net: dropreason: propagate drop_reason to skb_release_data() (Antoine Tenart) [2155186]
- net: dropreason: add SKB_CONSUMED reason (Antoine Tenart) [2155186]
- ipv4: remove redundant null pointer check before kfree_skb (Antoine Tenart) [2155186]

* Mon Jan 09 2023 Lucas Zampieri <lzampier@redhat.com> [4.18.0-448.el8]
- turbostat: Bring code up-to-date with upstream (Prarit Bhargava) [2117769]
- tools/power turbostat: Enable accumulate RAPL display (Prarit Bhargava) [2117769]
- tools/power turbostat: version 2022.07.28 (Prarit Bhargava) [2117769]
- tools/power turbostat: do not decode ACC for ICX and SPR (Prarit Bhargava) [2117769]
- tools/power turbostat: fix SPR PC6 limits (Prarit Bhargava) [2117769]
- tools/power turbostat: cleanup 'automatic_cstate_conversion_probe()' (Prarit Bhargava) [2117769]
- tools/power turbostat: separate SPR from ICX (Prarit Bhargava) [2117769]
- tools/power turbosstat: fix comment (Prarit Bhargava) [2117769]
- tools/power turbostat: Support RAPTORLAKE P (Prarit Bhargava) [2117769]
- tools/power turbostat: add support for ALDERLAKE_N (Prarit Bhargava) [2117769]
- tools/power turbostat: dump secondary Turbo-Ratio-Limit (Prarit Bhargava) [2117769]
- tools/power turbostat: simplify dump_turbo_ratio_limits() (Prarit Bhargava) [2117769]
- tools/power turbostat: dump CPUID.7.EDX.Hybrid (Prarit Bhargava) [2117769]
- tools/power turbostat: update turbostat.8 (Prarit Bhargava) [2117769]
- tools/power turbostat: Show uncore frequency (Prarit Bhargava) [2117769]
- tools/power turbostat: Fix file pointer leak (Prarit Bhargava) [2117769]
- tools/power turbostat: replace strncmp with single character compare (Prarit Bhargava) [2117769]
- tools/power turbostat: print the kernel boot commandline (Prarit Bhargava) [2117769]
- tools/power turbostat: Introduce support for RaptorLake (Prarit Bhargava) [2117769]
- tools/power turbostat: version 2022.04.16 (Prarit Bhargava) [2117769]
- tools/power turbostat: No build warnings with -Wextra (Prarit Bhargava) [2117769]
- tools/power turbostat: be more useful as non-root (Prarit Bhargava) [2117769]
- tools/power turbostat: fix ICX DRAM power numbers (Prarit Bhargava) [2117769]
- tools/power turbostat: Support thermal throttle count print (Prarit Bhargava) [2117769]
- tools/power turbostat: Allow printing header every N iterations (Prarit Bhargava) [2117769]
- tools/power turbostat: Allow -e for all names. (Prarit Bhargava) [2117769]
- tools/power turbostat: print power values upto three decimal (Prarit Bhargava) [2117769]
- tools/power turbostat: Add Power Limit4 support (Prarit Bhargava) [2117769]
- tools/power turbostat: fix dump for AMD cpus (Prarit Bhargava) [2117769]
- tools/power turbostat: tweak --show and --hide capability (Prarit Bhargava) [2117769]
- NFSv4: Retry LOCK on OLD_STATEID during delegation return (Benjamin Coddington) [2137826]
- KVM: s390: pv: don't allow userspace to set the clock under PV (Tobias Huschle) [2154284]
- net: mana: Fix race on per-CQ variable napi work_done (Emanuele Giuseppe Esposito) [2151722]
- powercap: intel_rapl: support new layout of Psys PowerLimit Register on SPR (Prarit Bhargava) [2106143]
- ceph: choose auth MDS for getxattr with the Xs caps (Milind Changire) [2126703]
- ceph: try to choose the auth MDS if possible for getattr (Milind Changire) [2126703]
- ceph: convert to generic_file_llseek (Milind Changire) [2126707]
- ceph: don't leak snap_rwsem in handle_cap_grant (Milind Changire) [2126706]
- ceph: prevent a client from exceeding the MDS maximum xattr size (Milind Changire) [2126704]
- ceph: add session already open notify support (Milind Changire) [2126701]
- ceph: use correct index when encoding client supported features (Milind Changire) [2143875]
- ceph: switch TASK_INTERRUPTIBLE to TASK_KILLABLE (Milind Changire) [2126700]
- ceph: allow ceph.dir.rctime xattr to be updatable (Milind Changire) [2126699]
- ipv6: Use ipv6_only_sock() helper in condition. (Izabela Bakollari) [2144855]
- ipv6: Remove __ipv6_only_sock(). (Izabela Bakollari) [2144855]
- redhat/configs: Switch CONFIG_X86_AMD_PSTATE to built-in (Prarit Bhargava) [2150424]
- Documentation: add amd-pstate kernel command line options (Prarit Bhargava) [2150424]
- cpufreq: amd-pstate: add amd-pstate driver parameter for mode selection (Prarit Bhargava) [2150424]
- cpufreq: amd-pstate: change amd-pstate driver to be built-in type (Prarit Bhargava) [2150424]
- cpufreq: amd-pstate: cpufreq: amd-pstate: reset MSR_AMD_PERF_CTL register at init (Prarit Bhargava) [2150424]
- scsi: target: iscsi: Fix a race condition between login_work and the login thread (Maurizio Lombardi) [2153832]
- virtio_console: Introduce an ID allocator for virtual console numbers (Cédric Le Goater) [2072437]
- blk-throttle: fix that io throttle can only work for single bio (Ming Lei) [2088193]
- scsi: zfcp: Fix double free of FSF request when qdio send fails (Tobias Huschle) [2155157]
- scsi: qla2xxx: Fix crash when I/O abort times out (Nilesh Javali) [2115820]
- perf trace: Fix SIGSEGV when processing syscall args (Michael Petlan) [2145089]
- config: mhi: set CONFIG_MHI_BUS_EP to disabled (Íñigo Huguet) [2136123]
- config: rtw89: set CONFIG_RTW89_8852C to disabled (Íñigo Huguet) [2136123]
- wifi: ath11k: avoid deadlock during regulatory update in ath11k_regd_update() (Íñigo Huguet) [2136123 2139481]
- wifi: mac80211: mlme: Fix double unlock on assoc success handling (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: Fix missing unlock on beacon RX (Íñigo Huguet) [2136123]
- wifi: mac80211: fix memory corruption in minstrel_ht_update_rates() (Íñigo Huguet) [2136123]
- wifi: mac80211: fix regression with non-QoS drivers (Íñigo Huguet) [2136123]
- wifi: mac80211: ensure vif queues are operational after start (Íñigo Huguet) [2136123]
- wifi: mac80211: don't start TX with fq->lock to fix deadlock (Íñigo Huguet) [2136123]
- wifi: cfg80211: fix MCS divisor value (Íñigo Huguet) [2136123]
- wifi: mt76: fix 5 GHz connection regression on mt76x0/mt76x2 (Íñigo Huguet) [2136123]
- wifi: mt76: fix reading current per-tid starting sequence number for aggregation (Íñigo Huguet) [2136123]
- wifi: iwlwifi: Mark IWLMEI as broken (Íñigo Huguet) [2136123]
- wifi: iwlwifi: don't spam logs with NSS>2 messages (Íñigo Huguet) [2136123]
- wifi: use struct_group to copy addresses (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: check length for virtio packets (Íñigo Huguet) [2136123]
- wifi: mac80211: fix locking in auth/assoc timeout (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: release deflink channel in error case (Íñigo Huguet) [2136123]
- wifi: mac80211: fix link warning in RX agg timer expiry (Íñigo Huguet) [2136123]
- bus: mhi: host: Fix up null pointer access in mhi_irq_handler (Íñigo Huguet) [2136123]
- net: Use u64_stats_fetch_begin_irq() for stats fetch. (Íñigo Huguet) [2136123]
- wifi: mt76: mt7921e: fix crash in chip reset fail (Íñigo Huguet) [2136123]
- wifi: mac80211: potential NULL dereference in ieee80211_tx_control_port() (Íñigo Huguet) [2136123]
- wifi: cfg80211: debugfs: fix return type in ht40allow_map_read() (Íñigo Huguet) [2136123]
- wifi: mac80211: Don't finalize CSA in IBSS mode if state is disconnected (Íñigo Huguet) [2136123]
- wifi: mac80211: fix possible leak in ieee80211_tx_control_port() (Íñigo Huguet) [2136123]
- wifi: mac80211: always free sta in __sta_info_alloc in case of error (Íñigo Huguet) [2136123]
- wifi: mac80211: Fix UAF in ieee80211_scan_rx() (Íñigo Huguet) [2136123]
- net: qrtr: start MHI channel after endpoit creation (Íñigo Huguet) [2136123]
- wifi: cfg80211: Fix validating BSS pointers in __cfg80211_connect_result (Íñigo Huguet) [2136123]
- wifi: rtw88: check the return value of alloc_workqueue() (Íñigo Huguet) [2136123]
- wifi: rtw89: 8852a: adjust IMR for SER L1 (Íñigo Huguet) [2136123]
- wifi: rtw89: 8852a: update RF radio A/B R56 (Íñigo Huguet) [2136123]
- wifi: brcmfmac: prevent double-free on hardware-reset (Íñigo Huguet) [2136123]
- wifi: brcmfmac: support brcm,ccode-map-trivial DT property (Íñigo Huguet) [2136123]
- wifi: brcmfmac: Replace default (not configured) MAC with a random MAC (Íñigo Huguet) [2136123]
- wifi: brcmfmac: Add brcmf_c_set_cur_etheraddr() helper (Íñigo Huguet) [2136123]
- wifi: brcmfmac: Remove #ifdef guards for PM related functions (Íñigo Huguet) [2136123]
- wifi: brcmfmac: use strreplace() in brcmf_of_probe() (Íñigo Huguet) [2136123]
- wifi: rtl8xxxu: Fix the error handling of the probe function (Íñigo Huguet) [2136123]
- wifi: mwifiex: clean up one inconsistent indenting (Íñigo Huguet) [2136123]
- wifi: rtlwifi: Remove duplicate word and Fix typo (Íñigo Huguet) [2136123]
- wifi: mwifiex: Fix comment typo (Íñigo Huguet) [2136123]
- wifi: iwlwifi: mvm: fix clang -Wformat warnings (Íñigo Huguet) [2136123]
- Revert "ath11k: add support for hardware rfkill for QCA6390" (Íñigo Huguet) [2136123]
- wifi: ath11k: Fix register write failure on QCN9074 (Íñigo Huguet) [2136123]
- wifi: mac80211: fix link data leak (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: fix disassoc with MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: add macros to loop over active links (Íñigo Huguet) [2136123]
- wifi: mac80211: remove erroneous sband/link validation (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: transmit assoc frame with address translation (Íñigo Huguet) [2136123]
- wifi: mac80211: verify link addresses are different (Íñigo Huguet) [2136123]
- wifi: mac80211: rx: track link in RX data (Íñigo Huguet) [2136123]
- wifi: mac80211: optionally implement MLO multicast TX (Íñigo Huguet) [2136123]
- wifi: mac80211: expand ieee80211_mgmt_tx() for MLO (Íñigo Huguet) [2136123]
- wifi: nl80211: add MLO link ID to the NL80211_CMD_FRAME TX API (Íñigo Huguet) [2136123]
- wifi: mac80211: report link ID to cfg80211 on mgmt RX (Íñigo Huguet) [2136123]
- wifi: cfg80211: report link ID in NL80211_CMD_FRAME (Íñigo Huguet) [2136123]
- wifi: mac80211: add hardware timestamps for RX and TX (Íñigo Huguet) [2136123]
- wifi: cfg80211: add hardware timestamps to frame RX info (Íñigo Huguet) [2136123]
- wifi: cfg80211/nl80211: move rx management data into a struct (Íñigo Huguet) [2136123]
- wifi: cfg80211: add a function for reporting TX status with hardware timestamps (Íñigo Huguet) [2136123]
- wifi: nl80211: add RX and TX timestamp attributes (Íñigo Huguet) [2136123]
- nl80211: document uapi for CMD_FRAME_WAIT_CANCEL (Íñigo Huguet) [2136123]
- wifi: ieee80211: add helper functions for detecting TM/FTM frames (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: handle links for wmediumd/virtio (Íñigo Huguet) [2136123]
- wifi: mac80211: sta_info: fix link_sta insertion (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: fix link_sta setup (Íñigo Huguet) [2136123]
- wifi: nl80211/mac80211: clarify link ID in control port TX (Íñigo Huguet) [2136123]
- wifi: mac80211: return error from control port TX for drops (Íñigo Huguet) [2136123]
- wifi: nl80211: require MLD address on link STA add/modify (Íñigo Huguet) [2136123]
- wifi: mac80211: more station handling sanity checks (Íñigo Huguet) [2136123]
- wifi: mac80211: fix link sta hash table handling (Íñigo Huguet) [2136123]
- wifi: mac80211: validate link address doesn't change (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: set sta.mlo to mlo state (Íñigo Huguet) [2136123]
- wifi: mac80211: fast-xmit: handle non-MLO clients (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: fix address translation for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: fix RX MLD address translation (Íñigo Huguet) [2136123]
- wifi: mac80211: fix NULL pointer deref with non-MLD STA (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: fix override calculation (Íñigo Huguet) [2136123]
- wifi: mac80211: tx: use AP address in some places for MLO (Íñigo Huguet) [2136123]
- net: add missing includes and forward declarations under net/ (Íñigo Huguet) [2136123]
- wifi: rtl8192se: fix repeated words in comments (Íñigo Huguet) [2136123]
- wifi: rtlwifi: fix repeated words in comments (Íñigo Huguet) [2136123]
- wifi: rt2x00: fix repeated words in comments (Íñigo Huguet) [2136123]
- wifi: brcmsmac: fix repeated words in comments (Íñigo Huguet) [2136123]
- wifi: brcmfmac: fix repeated words in comments (Íñigo Huguet) [2136123]
- wifi: mac80211: do not abuse fq.lock in ieee80211_do_stop() (Íñigo Huguet) [2136123]
- wifi: mt7601u: fix clang -Wformat warning (Íñigo Huguet) [2136123]
- wifi: mt7601u: eeprom: fix clang -Wformat warning (Íñigo Huguet) [2136123]
- wifi: ath: fix repeated words in comments (Íñigo Huguet) [2136123]
- wifi: ath11k: mac: fix long line (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: set sta.mlo correctly (Íñigo Huguet) [2136123]
- wifi: mac80211: remove stray printk (Íñigo Huguet) [2136123]
- wifi: mac80211: support MLO authentication/association with one link (Íñigo Huguet) [2136123]
- wifi: mac80211: add API to parse multi-link element (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: fix TX link selection (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: use MLO link ID for TX (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: do rc update per link (Íñigo Huguet) [2136123]
- wifi: mac80211: do link->MLD address translation on RX (Íñigo Huguet) [2136123]
- wifi: mac80211: select link when transmitting to non-MLO stations (Íñigo Huguet) [2136123]
- wifi: mac80211: fix up link station creation/insertion (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: implement sta_state for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: limit A-MSDU subframes for client too (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: refactor ieee80211_set_associated() (Íñigo Huguet) [2136123]
- wifi: cfg80211: add cfg80211_get_iftype_ext_capa() (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: look up beacon elems only if needed (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: refactor assoc link setup (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: remove address arg to ieee80211_mark_sta_auth() (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: refactor assoc success handling (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: refactor ieee80211_prep_channel() a bit (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: refactor assoc req element building (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: switch some things back to deflink (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: change flags in ieee80211_determine_chantype() (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: shift some code around (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: refactor link station setup (Íñigo Huguet) [2136123]
- wifi: mac80211: move IEEE80211_SDATA_OPERATING_GMODE to link (Íñigo Huguet) [2136123]
- wifi: mac80211: make ieee80211_check_rate_mask() link-aware (Íñigo Huguet) [2136123]
- wifi: mac80211: add multi-link element to AUTH frames (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: clean up supported channels element code (Íñigo Huguet) [2136123]
- wifi: mac80211: release channel context on link stop (Íñigo Huguet) [2136123]
- wifi: mac80211: prohibit DEAUTH_NEED_MGD_TX_PREP in MLO (Íñigo Huguet) [2136123]
- wifi: nl80211: fix some attribute policy entries (Íñigo Huguet) [2136123]
- wifi: nl80211: reject fragmented and non-inheritance elements (Íñigo Huguet) [2136123]
- wifi: nl80211: reject link specific elements on assoc link (Íñigo Huguet) [2136123]
- wifi: cfg80211: set country_elem to NULL (Íñigo Huguet) [2136123]
- wifi: mac80211: remove link_id parameter from link_info_changed() (Íñigo Huguet) [2136123]
- wifi: mac80211: replace link_id with link_conf in switch/(un)assign_vif_chanctx() (Íñigo Huguet) [2136123]
- wifi: nl80211: advertise MLO support (Íñigo Huguet) [2136123]
- wifi: mac80211: Support multi link in ieee80211_recalc_min_chandef() (Íñigo Huguet) [2136123]
- wifi: mac80211: don't check carrier in chanctx code (Íñigo Huguet) [2136123]
- wifi: nl80211: allow link ID in set_wiphy with frequency (Íñigo Huguet) [2136123]
- wifi: mac80211: Allow EAPOL tx from specific link (Íñigo Huguet) [2136123]
- wifi: mac80211: Allow EAPOL frames from link addresses (Íñigo Huguet) [2136123]
- wifi: cfg80211/mac80211: Support control port TX from specific link (Íñigo Huguet) [2136123]
- wifi: nl80211: Support MLD parameters in nl80211_set_station() (Íñigo Huguet) [2136123]
- wifi: nl80211: check MLO support in authenticate (Íñigo Huguet) [2136123]
- wifi: mac80211: add a helper to fragment an element (Íñigo Huguet) [2136123]
- wifi: mac80211: skip rate statistics for MLD STAs (Íñigo Huguet) [2136123]
- wifi: nl80211: set BSS to NULL if IS_ERR() (Íñigo Huguet) [2136123]
- wifi: nl80211: add EML/MLD capabilities to per-iftype capabilities (Íñigo Huguet) [2136123]
- wifi: nl80211: better validate link ID for stations (Íñigo Huguet) [2136123]
- wifi: mac80211: fix link manipulation (Íñigo Huguet) [2136123]
- wifi: mac80211: tighten locking check (Íñigo Huguet) [2136123]
- wifi: cfg80211: clean up links appropriately (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: simplify adding ht/vht/he/eht elements (Íñigo Huguet) [2136123]
- wifi: mac80211: refactor adding custom elements (Íñigo Huguet) [2136123]
- wifi: mac80211: refactor adding rates to assoc request (Íñigo Huguet) [2136123]
- wifi: mac80211: use only channel width in ieee80211_parse_bitrates() (Íñigo Huguet) [2136123]
- wifi: cfg80211: add ieee80211_chanwidth_rate_flags() (Íñigo Huguet) [2136123]
- wifi: mac80211: remove redundant condition (Íñigo Huguet) [2136123]
- wifi: mac80211: don't set link address for station (Íñigo Huguet) [2136123]
- wifi: mac80211: fix multi-BSSID element parsing (Íñigo Huguet) [2136123]
- wifi: mac80211: move tdls_chan_switch_prohibited to link data (Íñigo Huguet) [2136123]
- wifi: mac80211: don't re-parse elems in ieee80211_assoc_success() (Íñigo Huguet) [2136123]
- wifi: mac80211: replace link_id with link_conf in start/stop_ap() (Íñigo Huguet) [2136123]
- wifi: mac80211: refactor elements parsing with parameter struct (Íñigo Huguet) [2136123]
- wifi: cfg80211: extend cfg80211_rx_assoc_resp() for MLO (Íñigo Huguet) [2136123]
- wifi: cfg80211: put cfg80211_rx_assoc_resp() arguments into a struct (Íñigo Huguet) [2136123]
- wifi: cfg80211: adjust assoc comeback for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: unify assoc data event sending (Íñigo Huguet) [2136123]
- wifi: cfg80211: prepare association failure APIs for MLO (Íñigo Huguet) [2136123]
- wifi: cfg80211: remove BSS pointer from cfg80211_disassoc_request (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: use correct link_sta (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: remove sta argument from ieee80211_config_bw (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: use ieee80211_get_link_sband() (Íñigo Huguet) [2136123]
- wifi: mac80211: split IEEE80211_STA_DISABLE_WMM to link data (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: first adjustments for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: do IEEE80211_STA_RESET_SIGNAL_AVE per link (Íñigo Huguet) [2136123]
- wifi: mac80211: mlme: track AP (MLD) address separately (Íñigo Huguet) [2136123]
- wifi: mac80211: remove unused bssid variable (Íñigo Huguet) [2136123]
- wifi: mac80211: change QoS settings API to take link into account (Íñigo Huguet) [2136123]
- wifi: mac80211: expect powersave handling in driver for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: move ps setting to vif config (Íñigo Huguet) [2136123]
- wifi: mac80211: provide link ID in link_conf (Íñigo Huguet) [2136123]
- wifi: mac80211: set up/tear down client vif links properly (Íñigo Huguet) [2136123]
- wifi: mac80211: move ieee80211_request_smps_mgd_work (Íñigo Huguet) [2136123]
- wifi: nl80211: acquire wdev mutex for dump_survey (Íñigo Huguet) [2136123]
- wifi: mac80211: fix key lookup (Íñigo Huguet) [2136123]
- wifi: mac80211: separate out connection downgrade flags (Íñigo Huguet) [2136123]
- wifi: mac80211: Align with Draft P802.11be_D2.0 (Íñigo Huguet) [2136123]
- wifi: mac80211: Align with Draft P802.11be_D1.5 (Íñigo Huguet) [2136123]
- wifi: mac80211: skip powersave recalc if driver SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2136123]
- wifi: mac80211: debug: omit link if non-MLO connection (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: Ack link addressed frames (Íñigo Huguet) [2136123]
- wifi: cfg80211: drop BSS elements from assoc trace for now (Íñigo Huguet) [2136123]
- wifi: cfg80211: make cfg80211_auth_request::key_idx signed (Íñigo Huguet) [2136123]
- wifi: nl80211: enable setting the link address at new station (Íñigo Huguet) [2136123]
- wifi: mac80211: RCU-ify link/link_conf pointers (Íñigo Huguet) [2136123]
- wifi: nl80211: hold wdev mutex for station APIs (Íñigo Huguet) [2136123]
- wifi: nl80211: hold wdev mutex for channel switch APIs (Íñigo Huguet) [2136123]
- wifi: nl80211: hold wdev mutex in add/mod/del link station (Íñigo Huguet) [2136123]
- wifi: mac80211: implement callbacks for <add/mod/del>_link_station (Íñigo Huguet) [2136123]
- wifi: cfg80211/mac80211: separate link params from station params (Íñigo Huguet) [2136123]
- wifi: cfg80211: add API to add/modify/remove a link station (Íñigo Huguet) [2136123]
- wifi: mac80211: add an ieee80211_get_link_sband (Íñigo Huguet) [2136123]
- wifi: mac80211: Remove AP SMPS leftovers (Íñigo Huguet) [2136123]
- wifi: cfg80211: Allow MLO TX with link source address (Íñigo Huguet) [2136123]
- wifi: mac80211: Consider MLO links in offchannel logic (Íñigo Huguet) [2136123]
- wifi: mac80211: rx: accept link-addressed frames (Íñigo Huguet) [2136123]
- wifi: mac80211: consistently use sdata_dereference() (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: Support link channel matching on rx (Íñigo Huguet) [2136123]
- wifi: mac80211: fix mesh airtime link metric estimating (Íñigo Huguet) [2136123]
- wifi: mac80211: make 4addr null frames using min_rate for WDS (Íñigo Huguet) [2136123]
- wifi: cfg80211: use strscpy to replace strlcpy (Íñigo Huguet) [2136123]
- wifi: mac80211: exclude multicast packets from AQL pending airtime (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: use 32-bit skb cookie (Íñigo Huguet) [2136123]
- mt76: mt7921: Let PCI core handle power state and use pm_sleep_ptr() (Íñigo Huguet) [2136123]
- mediatek: mt76: mac80211: Fix missing of_node_put() in mt76_led_init() (Íñigo Huguet) [2136123]
- mt76: get rid of mt76_wcid_hw routine (Íñigo Huguet) [2136123]
- mt76: convert MT_TX_HW_QUEUE_EXT_PHY to MT_TX_HW_QUEUE_PHY (Íñigo Huguet) [2136123]
- mt76: add phy_idx to mt76_wcid (Íñigo Huguet) [2136123]
- mt76: introduce phys array in mt76_dev structure (Íñigo Huguet) [2136123]
- mt76: add phy_idx in mt76_rx_status (Íñigo Huguet) [2136123]
- mt76: introduce MT_RXQ_BAND2 and MT_RXQ_BAND2_WA in mt76_rxq_id (Íñigo Huguet) [2136123]
- mt76: add len parameter to __mt76_mcu_msg_alloc signature (Íñigo Huguet) [2136123]
- mt76: mt7915 add ht mpdu density (Íñigo Huguet) [2136123]
- mt76: mt7921: reduce the mutex lock scope during reset (Íñigo Huguet) [2136123]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2136123]
- mt76: connac: move tx initialization/cleanup in mt76_connac module (Íñigo Huguet) [2136123]
- mt76: mt7921: make mt7921_pci_driver static (Íñigo Huguet) [2136123]
- mt76: mt7921: enable HW beacon filter in the initialization stage (Íñigo Huguet) [2136123]
- mt76: mt7921: enable HW beacon filter not depending on PM flag (Íñigo Huguet) [2136123]
- mt76: remove q->qid (Íñigo Huguet) [2136123]
- mt76: do not use skb_set_queue_mapping for internal purposes (Íñigo Huguet) [2136123]
- mt76: pass original queue id from __mt76_tx_queue_skb to the driver (Íñigo Huguet) [2136123]
- mt76: allow receiving frames with invalid CCMP PN via monitor interfaces (Íñigo Huguet) [2136123]
- mt76: mt76x02: improve reliability of the beacon hang check (Íñigo Huguet) [2136123]
- mt76: mt7615: add sta_rec with EXTRA_INFO_NEW for the first time only (Íñigo Huguet) [2136123]
- mt76: mt7915: update the maximum size of beacon offload (Íñigo Huguet) [2136123]
- mt76: do not check the ccmp pn for ONLY_MONITOR frame (Íñigo Huguet) [2136123]
- mt76: mt7915: add sta_rec with EXTRA_INFO_NEW for the first time only (Íñigo Huguet) [2136123]
- mt76: mt7915: update mpdu density in 6g capability (Íñigo Huguet) [2136123]
- mt76: mt7915: do not copy ieee80211_ops pointer in mt7915_mmio_probe (Íñigo Huguet) [2136123]
- mt76: mt7915: disable UL MU-MIMO for mt7915 (Íñigo Huguet) [2136123]
- mt76: move mt76_connac2_mcu_fill_message in mt76_connac module (Íñigo Huguet) [2136123]
- mt76: move mcu_txd/mcu_rxd structures in shared code (Íñigo Huguet) [2136123]
- mt76: mt7915: rely on mt76_connac_tx_free (Íñigo Huguet) [2136123]
- mt76: connac: move mt7615_txp_skb_unmap in common code (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac_write_hw_txp in shared code (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac_tx_complete_skb in shared code (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac_tx_free in shared code (Íñigo Huguet) [2136123]
- mt76: move mt7615_txp_ptr in mt76_connac module (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac_fw_txp in common module (Íñigo Huguet) [2136123]
- mt76: mt7915: get rid of unnecessary new line in mt7915_mac_write_txwi (Íñigo Huguet) [2136123]
- mt76: mt7921s: remove unnecessary goto in mt7921s_mcu_drv_pmctrl (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac2_mac_fill_rx_rate in connac module (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac2_reverse_frag0_hdr_trans in mt76-connac module (Íñigo Huguet) [2136123]
- mt76: connac: move HE radiotap parsing in connac module (Íñigo Huguet) [2136123]
- mt76: mt7921: fix command timeout in AP stop period (Íñigo Huguet) [2136123]
- mt76: mt7921: not support beacon offload disable command (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac2_mac_add_txs_skb in connac module (Íñigo Huguet) [2136123]
- mt76: connac: move connac2_mac_write_txwi in mt76_connac module (Íñigo Huguet) [2136123]
- mt76: connac: move mac connac2 defs in mt76_connac2_mac.h (Íñigo Huguet) [2136123]
- mt76: mt7915: rely on mt76_dev in mt7915_mac_write_txwi signature (Íñigo Huguet) [2136123]
- mt76: mt7921: rely on mt76_dev in mt7921_mac_write_txwi signature (Íñigo Huguet) [2136123]
- mt76: enable the VHT extended NSS BW feature (Íñigo Huguet) [2136123]
- mt76: mt7663: rely on mt76_connac2_fw_trailer (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac2_load_patch in connac module (Íñigo Huguet) [2136123]
- mt76: connac: move mt76_connac2_load_ram in connac module (Íñigo Huguet) [2136123]
- mt76: mt7921: move fw toggle in mt7921_load_firmware (Íñigo Huguet) [2136123]
- mt76: connac: move shared fw structures in connac module (Íñigo Huguet) [2136123]
- mt76: mt7921: get rid of mt7921_mcu_exit (Íñigo Huguet) [2136123]
- mt76: mt7921: add missing bh-disable around rx napi schedule (Íñigo Huguet) [2136123]
- mt76: mt7615: add missing bh-disable around rx napi schedule (Íñigo Huguet) [2136123]
- mt76: mt7915: add missing bh-disable around tx napi enable/schedule (Íñigo Huguet) [2136123]
- mt76: mt7921: add PATCH_FINISH_REQ cmd response handling (Íñigo Huguet) [2136123]
- mt76: add DBDC rxq handlings into mac_reset_work (Íñigo Huguet) [2136123]
- mt76: mt7915: add more ethtool stats (Íñigo Huguet) [2136123]
- mt76: mt7921: introduce ACPI SAR config in tx power (Íñigo Huguet) [2136123]
- mt76: mt7921: introduce ACPI SAR support (Íñigo Huguet) [2136123]
- mt76: add 6 GHz band support in mt76_sar_freq_ranges (Íñigo Huguet) [2136123]
- mt76: mt7915: fix endian bug in mt7915_rf_regval_set() (Íñigo Huguet) [2136123]
- mt76: mt76x02u: fix possible memory leak in __mt76x02u_mcu_send_msg (Íñigo Huguet) [2136123]
- mt76: mt7915: fix endianness in mt7915_rf_regval_get (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: add back erroneously removed cast (Íñigo Huguet) [2136123]
- wifi: mac80211: fix queue selection for mesh/OCB interfaces (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: fix race condition in pending packet (Íñigo Huguet) [2136123]
- wifi: mac80211: Use the bitmap API to allocate bitmaps (Íñigo Huguet) [2136123]
- wifi: mac80211: fix center freq calculation in ieee80211_chandef_downgrade (Íñigo Huguet) [2136123]
- wifi: nl80211: fix sending link ID info of associated BSS (Íñigo Huguet) [2136123]
- wifi: cfg80211: fix a comment in cfg80211_mlme_mgmt_tx() (Íñigo Huguet) [2136123]
- wifi: nl80211: Fix reading NL80211_ATTR_MLO_LINK_ID in nl80211_pre_doit (Íñigo Huguet) [2136123]
- bus: mhi: ep: Check dev_set_name() return value (Íñigo Huguet) [2136123]
- ath9k: remove unexpected words "the" in comments (Íñigo Huguet) [2136123]
- ath11k: Fix typo in comments (Íñigo Huguet) [2136123]
- wifi: nl80211: retrieve EHT related elements in AP mode (Íñigo Huguet) [2136123]
- wifi: cfg80211: Increase akm_suites array size in cfg80211_crypto_settings (Íñigo Huguet) [2136123]
- wifi: cfg80211: remove chandef check in cfg80211_cac_event() (Íñigo Huguet) [2136123]
- wifi: nl80211: relax wdev mutex check in wdev_chandef() (Íñigo Huguet) [2136123]
- wifi: nl80211: acquire wdev mutex earlier in start_ap (Íñigo Huguet) [2136123]
- wifi: nl80211: hold wdev mutex for tid config (Íñigo Huguet) [2136123]
- wifi: cfg80211: handle IBSS in channel switch (Íñigo Huguet) [2136123]
- wifi: mac80211: properly skip link info driver update (Íñigo Huguet) [2136123]
- wifi: mac80211: only accumulate airtime deficit for active clients (Íñigo Huguet) [2136123]
- wifi: mac80211: add debugfs file to display per-phy AQL pending airtime (Íñigo Huguet) [2136123]
- wifi: mac80211: add a per-PHY AQL limit to improve fairness (Íñigo Huguet) [2136123]
- wifi: mac80211: keep recently active tx queues in scheduling list (Íñigo Huguet) [2136123]
- wifi: mac80211: consider aql_tx_pending when checking airtime deficit (Íñigo Huguet) [2136123]
- wifi: mac80211: make sta airtime deficit field s32 instead of s64 (Íñigo Huguet) [2136123]
- wifi: mac80211: fix a kernel-doc complaint (Íñigo Huguet) [2136123]
- wifi: cfg80211: remove redundant documentation (Íñigo Huguet) [2136123]
- wifi: mac80211: sta_info: fix a missing kernel-doc struct element (Íñigo Huguet) [2136123]
- wifi: mac80211: add a missing comma at kernel-doc markup (Íñigo Huguet) [2136123]
- wifi: cfg80211: fix kernel-doc warnings all over the file (Íñigo Huguet) [2136123]
- wifi: ieee80211: s1g action frames are not robust (Íñigo Huguet) [2136123]
- bus: mhi: host: pci_generic: Add another Foxconn T99W175 (Íñigo Huguet) [2136123]
- wifi: cfg80211: Allow P2P client interface to indicate port authorization (Íñigo Huguet) [2136123]
- wifi: mac80211: do not wake queues on a vif that is being stopped (Íñigo Huguet) [2136123]
- wifi: mac80211: check skb_shared in ieee80211_8023_xmit() (Íñigo Huguet) [2136123]
- wifi: mac80211: add gfp_t parameter to ieeee80211_obss_color_collision_notify (Íñigo Huguet) [2136123]
- bus: mhi: host: Move IRQ allocation to controller registration phase (Íñigo Huguet) [2136123]
- bus: mhi: host: pci_generic: Add Cinterion MV31-W with new baseline (Íñigo Huguet) [2136123]
- bus: mhi: host: pci_generic: Add support for Quectel EM120 FCCL modem (Íñigo Huguet) [2136123]
- wifi: rtw89: disable invalid phy reports for all ICs (Íñigo Huguet) [2136123]
- wifi: rtw89: pci: fix PCI doesn't reclaim TX BD properly (Íñigo Huguet) [2136123]
- wifi: rtw89: fix long RX latency in low power mode (Íñigo Huguet) [2136123]
- wifi: rtw89: drop invalid TX rate report of legacy rate (Íñigo Huguet) [2136123]
- wifi: rtw89: add UNEXP debug mask to keep monitor messages unexpected to happen frequently (Íñigo Huguet) [2136123]
- wifi: rtw89: enable VO TX AMPDU (Íñigo Huguet) [2136123]
- wifi: rtw89: fix potential TX stuck (Íñigo Huguet) [2136123]
- wifi: rtw89: support TDLS (Íñigo Huguet) [2136123]
- wifi: rtw89: allocate BSSID CAM per TDLS peer (Íñigo Huguet) [2136123]
- wifi: rtw89: separate BSSID CAM operations (Íñigo Huguet) [2136123]
- wifi: rtw89: allocate address CAM and MAC ID to TDLS peer (Íñigo Huguet) [2136123]
- cfg80211: Indicate MLO connection info in connect and roam callbacks (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: print the link id (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: support creating MLO-capable radios (Íñigo Huguet) [2136123]
- wifi: nl80211: expose link ID for associated BSSes (Íñigo Huguet) [2136123]
- wifi: nl80211: expose link information for interfaces (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: send a beacon per link (Íñigo Huguet) [2136123]
- wifi: mac80211: set STA deflink addresses (Íñigo Huguet) [2136123]
- wifi: mac80211: maintain link-sta hash table (Íñigo Huguet) [2136123]
- wifi: mac80211: RCU-ify link STA pointers (Íñigo Huguet) [2136123]
- wifi: mac80211: ethtool: use deflink for now (Íñigo Huguet) [2136123]
- wifi: mac80211: move ieee80211_bssid_match() function (Íñigo Huguet) [2136123]
- wifi: mac80211: return a beacon for a specific link (Íñigo Huguet) [2136123]
- wifi: mac80211: pass the link id in start/stop ap (Íñigo Huguet) [2136123]
- wifi: mac80211: use link in start/stop ap (Íñigo Huguet) [2136123]
- wifi: mac80211: implement add/del interface link callbacks (Íñigo Huguet) [2136123]
- wifi: cfg80211: add optional link add/remove callbacks (Íñigo Huguet) [2136123]
- wifi: cfg80211: sort trace.h (Íñigo Huguet) [2136123]
- wifi: mac80211: add sta link addition/removal (Íñigo Huguet) [2136123]
- wifi: mac80211: add MLO link ID to TX frame metadata (Íñigo Huguet) [2136123]
- wifi: mac80211: remove band from TX info in MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: add vif link addition/removal (Íñigo Huguet) [2136123]
- wifi: nl80211: support MLO in auth/assoc (Íñigo Huguet) [2136123]
- wifi: mac80211: ignore IEEE80211_CONF_CHANGE_SMPS in chanctx mode (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: split bss_info_changed to vif/link info_changed (Íñigo Huguet) [2136123]
- wifi: cfg80211: simplify cfg80211_mlme_auth() prototype (Íñigo Huguet) [2136123]
- wifi: ieee80211: add definitions for multi-link element (Íñigo Huguet) [2136123]
- wifi: nl80211: refactor BSS lookup in nl80211_associate() (Íñigo Huguet) [2136123]
- wifi: cfg80211: mlme: get BSS entry outside cfg80211_mlme_assoc() (Íñigo Huguet) [2136123]
- wifi: mac80211: tx: simplify chanctx_conf handling (Íñigo Huguet) [2136123]
- wifi: mac80211: status: look up band only where needed (Íñigo Huguet) [2136123]
- wifi: mac80211: sort trace.h file (Íñigo Huguet) [2136123]
- wifi: mac80211: correct link config data in tracing (Íñigo Huguet) [2136123]
- wifi: mac80211: make ieee80211_he_cap_ie_to_sta_he_cap() MLO-aware (Íñigo Huguet) [2136123]
- wifi: mac80211: make some SMPS code MLD-aware (Íñigo Huguet) [2136123]
- wifi: mac80211: HT: make ieee80211_ht_cap_ie_to_sta_ht_cap() MLO-aware (Íñigo Huguet) [2136123]
- wifi: mac80211: add link_id to eht.c code for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: add link_id to vht.c code for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: refactor some link setup code (Íñigo Huguet) [2136123]
- wifi: mac80211: validate some driver features for MLO (Íñigo Huguet) [2136123]
- wifi: mac80211: use IEEE80211_MLD_MAX_NUM_LINKS (Íñigo Huguet) [2136123]
- wifi: mac80211: refactor some sta_info link handling (Íñigo Huguet) [2136123]
- wifi: mac80211: remove sta_info_tx_streams() (Íñigo Huguet) [2136123]
- wifi: mac80211: make channel context code MLO-aware (Íñigo Huguet) [2136123]
- wifi: mac80211: pass link ID where already present (Íñigo Huguet) [2136123]
- wifi: mac80211: add per-link configuration pointer (Íñigo Huguet) [2136123]
- wifi: mac80211: split bss_info_changed method (Íñigo Huguet) [2136123]
- mac80211: fix maybe-unused warning (Íñigo Huguet) [2136123]
- wifi: mac80211: reorg some iface data structs for MLD (Íñigo Huguet) [2136123]
- wifi: mac80211: move interface config to new struct (Íñigo Huguet) [2136123]
- wifi: mac80211: move some future per-link data to bss_conf (Íñigo Huguet) [2136123]
- wifi: cfg80211: do some rework towards MLO link APIs (Íñigo Huguet) [2136123]
- wifi: mac80211: reject WEP or pairwise keys with key ID > 3 (Íñigo Huguet) [2136123]
- wifi: mac80211_hwsim: Directly use ida_alloc()/free() (Íñigo Huguet) [2136123]
- wifi: mac80211: refactor some key code (Íñigo Huguet) [2136123]
- wifi: mac80211: remove cipher scheme support (Íñigo Huguet) [2136123]
- wifi: nl80211: fix typo in comment (Íñigo Huguet) [2136123]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_391.RULE (Íñigo Huguet) [2136123]
- rtw88: 8821c: fix access const table of channel parameters (Íñigo Huguet) [2136123]
- rtw89: add new state to CFO state machine for UL-OFDMA (Íñigo Huguet) [2136123]
- rtw89: 8852c: add trigger frame counter (Íñigo Huguet) [2136123]
- ieee80211: add trigger frame definition (Íñigo Huguet) [2136123]
- ath10k: fix recently introduced checkpatch warning (Íñigo Huguet) [2136123]
- wifi: rtw89: support MULTI_BSSID and correct BSSID mask of H2C (Íñigo Huguet) [2136123]
- wifi: ray_cs: Drop useless status variable in parse_addr() (Íñigo Huguet) [2136123]
- wifi: ray_cs: Utilize strnlen() in parse_addr() (Íñigo Huguet) [2136123]
- wifi: rtw88: use *ph to print small buffer (Íñigo Huguet) [2136123]
- ath11k: Fix warnings reported by checkpatch (Íñigo Huguet) [2136123]
- ath11k: Fix LDPC config in set_bitrate_mask hook (Íñigo Huguet) [2136123]
- wifi: mac80211: fix use-after-free in chanctx code (Íñigo Huguet) [2136123]
- ath10k: fix regdomain info of iw reg set/get (Íñigo Huguet) [2136123]
- ath11k: support avg signal in station dump (Íñigo Huguet) [2136123]
- wifi: rtlwifi: fix error codes in rtl_debugfs_set_write_h2c() (Íñigo Huguet) [2136123]
- wifi: rtw88: Fix Sparse warning for rtw8821c_hw_spec (Íñigo Huguet) [2136123]
- wifi: rtw88: Fix Sparse warning for rtw8723d_hw_spec (Íñigo Huguet) [2136123]
- wifi: rtw88: Fix Sparse warning for rtw8822c_hw_spec (Íñigo Huguet) [2136123]
- wifi: rtw88: Fix sparse warning for rtw8822b_hw_spec (Íñigo Huguet) [2136123]
- rtw88: fix null vif pointer when hw_scan fails (Íñigo Huguet) [2136123]
- rtw89: sar: adjust and support SAR on 6GHz band (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: re-calibrate RX DCK once thermal changes a lot (Íñigo Huguet) [2136123]
- rtw89: pci: handle hardware watchdog timeout interrupt status (Íñigo Huguet) [2136123]
- rtw89: fix null vif pointer when hw_scan fails (Íñigo Huguet) [2136123]
- rtw89: fix channel inconsistency during hw_scan (Íñigo Huguet) [2136123]
- wifi: rtw88: add a work to correct atomic scheduling warning of ::set_tim (Íñigo Huguet) [2136123]
- wifi: iwlwifi: pcie: rename CAUSE macro (Íñigo Huguet) [2136123]
- wifi: brcmfmac: work around a GCC 12 -Warray-bounds warning (Íñigo Huguet) [2136123]
- wifi: iwlwifi: use unsigned to silence a GCC 12 warning (Íñigo Huguet) [2136123]
- wifi: rtlwifi: remove always-true condition pointed out by GCC 12 (Íñigo Huguet) [2136123]
- wifi: ath9k: silence array-bounds warning on GCC 12 (Íñigo Huguet) [2136123]
- ath9k: replace ternary operator with max() (Íñigo Huguet) [2136123]
- ath11k: Init hw_params before setting up AHB resources (Íñigo Huguet) [2136123]
- ath11k: Fix warning on variable 'sar' dereference before check (Íñigo Huguet) [2136123]
- ath10k: fix misreported tx bandwidth for 160Mhz (Íñigo Huguet) [2136123]
- ath10k: add encapsulation offloading support (Íñigo Huguet) [2136123]
- ath10k: turn rawmode into frame_mode (Íñigo Huguet) [2136123]
- ath10k: improve tx status reporting (Íñigo Huguet) [2136123]
- ath10k: do not enforce interrupt trigger type (Íñigo Huguet) [2136123]
- iwlwifi: mei: fix potential NULL-ptr deref (Íñigo Huguet) [2136123]
- iwlwifi: mei: clear the sap data header before sending (Íñigo Huguet) [2136123]
- iwlwifi: mvm: remove vif_count (Íñigo Huguet) [2136123]
- iwlwifi: mvm: always tell the firmware to accept MCAST frames in BSS (Íñigo Huguet) [2136123]
- iwlwifi: mvm: add OTP info in case of init failure (Íñigo Huguet) [2136123]
- iwlwifi: mvm: fix assert 1F04 upon reconfig (Íñigo Huguet) [2136123]
- iwlwifi: mvm: clean up authorized condition (Íñigo Huguet) [2136123]
- iwlwifi: mvm: use NULL instead of ERR_PTR when parsing wowlan status (Íñigo Huguet) [2136123]
- iwlwifi: pcie: simplify MSI-X cause mapping (Íñigo Huguet) [2136123]
- ath11k: update missing MU-MIMO and OFDMA stats (Íñigo Huguet) [2136123]
- rtw89: pci: only mask out INT indicator register for disable interrupt v1 (Íñigo Huguet) [2136123]
- rtw89: convert rtw89_band to nl80211_band precisely (Íñigo Huguet) [2136123]
- rtw89: 8852c: update txpwr tables to HALRF_027_00_052 (Íñigo Huguet) [2136123]
- rtw89: cfo: check mac_id to avoid out-of-bounds (Íñigo Huguet) [2136123]
- rtw89: 8852c: set TX antenna path (Íñigo Huguet) [2136123]
- rtw89: add ieee80211::sta_rc_update ops (Íñigo Huguet) [2136123]
- wireless: Fix Makefile to be in alphabetical order (Íñigo Huguet) [2136123]
- mac80211: refactor freeing the next_beacon (Íñigo Huguet) [2136123]
- cfg80211: fix kernel-doc for cfg80211_beacon_data (Íñigo Huguet) [2136123]
- mac80211: minstrel_ht: support ieee80211_rate_status (Íñigo Huguet) [2136123]
- mac80211: extend current rate control tx status API (Íñigo Huguet) [2136123]
- mac80211: minstrel_ht: fill all requested rates (Íñigo Huguet) [2136123]
- mac80211: disable BSS color collision detection in case of no free colors (Íñigo Huguet) [2136123]
- nl80211: Parse NL80211_ATTR_HE_BSS_COLOR as a part of nl80211_parse_beacon (Íñigo Huguet) [2136123]
- mac80211: mlme: track assoc_bss/associated separately (Íñigo Huguet) [2136123]
- mac80211: remove useless bssid copy (Íñigo Huguet) [2136123]
- mac80211: remove unused argument to ieee80211_sta_connection_lost() (Íñigo Huguet) [2136123]
- mac80211: mlme: use local SSID copy (Íñigo Huguet) [2136123]
- mac80211: use ifmgd->bssid instead of ifmgd->associated->bssid (Íñigo Huguet) [2136123]
- mac80211: mlme: move in RSSI reporting code (Íñigo Huguet) [2136123]
- mac80211: remove stray multi_sta_back_32bit docs (Íñigo Huguet) [2136123]
- mac80211: fix typo in documentation (Íñigo Huguet) [2136123]
- mac80211: unify CCMP/GCMP AAD construction (Íñigo Huguet) [2136123]
- mt76: mt7921: add ipv6 NS offload support (Íñigo Huguet) [2136123]
- mt76: add gfp to mt76_mcu_msg_alloc signature (Íñigo Huguet) [2136123]
- mt76: mt7915: add more statistics from fw_util debugfs knobs (Íñigo Huguet) [2136123]
- mt76: mt7915: improve error handling for fw_debug knobs (Íñigo Huguet) [2136123]
- mt76: mt7615/mt7915: do reset_work with mt76's work queue (Íñigo Huguet) [2136123]
- mt76: mt7915: add support for 6G in-band discovery (Íñigo Huguet) [2136123]
- mt76: mt7915: add Wireless Ethernet Dispatch support (Íñigo Huguet) [2136123]
- net: ethernet: mtk_eth_soc: add support for Wireless Ethernet Dispatch (WED) (Íñigo Huguet) [2136123]
- mt76: make number of tokens configurable dynamically (Íñigo Huguet) [2136123]
- mt76: add support for overriding the device used for DMA mapping (Íñigo Huguet) [2136123]
- mt76: dma: add wrapper macro for accessing queue registers (Íñigo Huguet) [2136123]
- mt76: mt7915: move MT_INT_MASK_CSR to init.c (Íñigo Huguet) [2136123]
- mt76: mt7915: introduce mt7915_mac_severe_check() (Íñigo Huguet) [2136123]
- mt76: mt7915: rework SER debugfs knob (Íñigo Huguet) [2136123]
- mt76: mt7915: limit minimum twt duration (Íñigo Huguet) [2136123]
- mt76: mt7915: reject duplicated twt flows (Íñigo Huguet) [2136123]
- mt76: mt7915: update mt7986 patch in mt7986_wmac_adie_patch_7976() (Íñigo Huguet) [2136123]
- mt76: connac: use skb_put_data instead of open coding (Íñigo Huguet) [2136123]
- mt76: mt7915: configure soc clocks in mt7986_wmac_init (Íñigo Huguet) [2136123]
- mt76: fix encap offload ethernet type check (Íñigo Huguet) [2136123]
- mt76: mt7915: disable RX_HDR_TRANS_SHORT (Íñigo Huguet) [2136123]
- mt76: mt7603: move spin_lock_bh() to spin_lock() (Íñigo Huguet) [2136123]
- mt76: mt7915: add debugfs knob for RF registers read/write (Íñigo Huguet) [2136123]
- mt76: mt7921: make read-only array ppet16_ppet8_ru3_ru0 static const (Íñigo Huguet) [2136123]
- mt76: mt7915: make read-only array ppet16_ppet8_ru3_ru0 static const (Íñigo Huguet) [2136123]
- mt76: mt7915: remove SCS feature (Íñigo Huguet) [2136123]
- mt76: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2136123]
- mt76: mt7921: Add AP mode support (Íñigo Huguet) [2136123]
- mt76: mt7915: use 0xff to initialize bitrate_mask in mt7915_init_bitrate_mask (Íñigo Huguet) [2136123]
- mt76: mt7915: always call mt7915_wfsys_reset() during init (Íñigo Huguet) [2136123]
- mt76: mt7921: rely on mt76_dev rxfilter in mt7921_configure_filter (Íñigo Huguet) [2136123]
- mt76: mt7921u: add suspend/resume support (Íñigo Huguet) [2136123]
- mt76: fix MBSS index condition in DBDC mode (Íñigo Huguet) [2136123]
- mt76: fix use-after-free by removing a non-RCU wcid pointer (Íñigo Huguet) [2136123]
- mt76: mt7921: accept rx frames with non-standard VHT MCS10-11 (Íñigo Huguet) [2136123]
- mt76: mt7915: accept rx frames with non-standard VHT MCS10-11 (Íñigo Huguet) [2136123]
- mt76: dma: use kzalloc instead of devm_kzalloc for txwi (Íñigo Huguet) [2136123]
- mt76: reduce tx queue lock hold time (Íñigo Huguet) [2136123]
- mt76: mt7915: rework hardware/phy initialization (Íñigo Huguet) [2136123]
- rtlwifi: Use pr_warn instead of WARN_ONCE (Íñigo Huguet) [2136123]
- rtw89: add debug entry to dump BSSID CAM (Íñigo Huguet) [2136123]
- rtw89: add debug select to dump MAC pages 0x30 to 0x33 (Íñigo Huguet) [2136123]
- rtw89: correct CCA control (Íñigo Huguet) [2136123]
- rtw89: correct setting of RX MPDU length (Íñigo Huguet) [2136123]
- rtw89: 8852c: add settings to decrease the effect of DC (Íñigo Huguet) [2136123]
- brcmfmac: allow setting wlan MAC address using device tree (Íñigo Huguet) [2136123]
- ath11k: remove redundant assignment to variables vht_mcs and he_mcs (Íñigo Huguet) [2136123]
- ath11k: Reuse the available memory after firmware reload (Íñigo Huguet) [2136123]
- ath11k: Designating channel frequency when sending management frames (Íñigo Huguet) [2136123]
- ath11k: Implement remain-on-channel support (Íñigo Huguet) [2136123]
- ath11k: Handle keepalive during WoWLAN suspend and resume (Íñigo Huguet) [2136123]
- bus: mhi: host: Add support for Foxconn T99W373 and T99W368 (Íñigo Huguet) [2136123]
- bus: mhi: host: pci_generic: add Telit FN990 (Íñigo Huguet) [2136123]
- bus: mhi: host: pci_generic: add Telit FN980 v1 hardware revision (Íñigo Huguet) [2136123]
- bus: mhi: replace snprintf with sysfs_emit (Íñigo Huguet) [2136123]
- rtw88: adjust adaptivity option to 1 (Íñigo Huguet) [2136123]
- ath11k: Fix RX de-fragmentation issue on WCN6750 (Íñigo Huguet) [2136123]
- ath10k: support bus and device specific API 1 BDF selection (Íñigo Huguet) [2136123]
- ath10k: mac: fix too long lines (Íñigo Huguet) [2136123]
- ath11k: mac: fix too long line (Íñigo Huguet) [2136123]
- mac80211: support disabling EHT mode (Íñigo Huguet) [2136123]
- cfg80211: support disabling EHT mode (Íñigo Huguet) [2136123]
- mac80211: upgrade passive scan to active scan on DFS channels after beacon rx (Íñigo Huguet) [2136123]
- mac80211: tx: delete a redundant if statement in ieee80211_check_fast_xmit() (Íñigo Huguet) [2136123]
- mac80211: consider Order bit to fill CCMP AAD (Íñigo Huguet) [2136123]
- cfg80211: declare MODULE_FIRMWARE for regulatory.db (Íñigo Huguet) [2136123]
- nl80211: rework internal_flags usage (Íñigo Huguet) [2136123]
- nl80211: don't hold RTNL in color change request (Íñigo Huguet) [2136123]
- cfg80211: remove cfg80211_get_chan_state() (Íñigo Huguet) [2136123]
- ath11k: Add support for targets without trustzone (Íñigo Huguet) [2136123]
- rtw89: 8852c: add 8852ce to Makefile and Kconfig (Íñigo Huguet) [2136123]
- rtw89: 8852c: fix warning of FIELD_PREP() mask type (Íñigo Huguet) [2136123]
- rtw89: 8852c: correct register definitions used by 8852c (Íñigo Huguet) [2136123]
- rtw89: correct AID settings of beamformee (Íñigo Huguet) [2136123]
- rtw89: ps: fine tune polling interval while changing low power mode (Íñigo Huguet) [2136123]
- rtw89: 8852c: add basic and remaining chip_info (Íñigo Huguet) [2136123]
- rtw89: 8852c: add chip_ops::bb_ctrl_btc_preagc (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: get calibrated channels to notify firmware (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add DPK (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add IQK (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add RX DCK (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add RCK (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add TSSI (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add LCK (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add DACK (Íñigo Huguet) [2136123]
- rtw89: 8852c: rfk: add RFK tables (Íñigo Huguet) [2136123]
- rtw88: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2136123]
- ath10k: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2136123]
- ath11k: Add support for WCN6750 device (Íñigo Huguet) [2136123]
- ath11k: Datapath changes to support WCN6750 (Íñigo Huguet) [2136123]
- ath11k: HAL changes to support WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Add QMI changes for WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Fetch device information via QMI for WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Add register access logic for WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Add HW params for WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Move parameters in bus_params to hw_params (Íñigo Huguet) [2136123]
- ath11k: change management tx queue to avoid connection timed out (Íñigo Huguet) [2136123]
- ath11k: fix warning of not found station for bssid in message (Íñigo Huguet) [2136123]
- rtw88: fix hw scan may cause disconnect issue (Íñigo Huguet) [2136123]
- rtw88: fix not disabling beacon filter after disconnection (Íñigo Huguet) [2136123]
- rtw88: add HT MPDU density value for each chip (Íñigo Huguet) [2136123]
- ath11k: Don't use GFP_KERNEL in atomic context (Íñigo Huguet) [2136123]
- ath10k: skip ath10k_halt during suspend for driver state RESTARTING (Íñigo Huguet) [2136123]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2136123]
- ath10k: simplify if-if to if-else (Íñigo Huguet) [2136123]
- ath11k: read country code from SMBIOS for WCN6855/QCA6390 (Íñigo Huguet) [2136123]
- ath11k: disable spectral scan during spectral deinit (Íñigo Huguet) [2136123]
- ath11k: Update WBM idle ring HP after FW mode on (Íñigo Huguet) [2136123]
- ath11k: WMI changes to support WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Do not put HW in DBS mode for WCN6750 (Íñigo Huguet) [2136123]
- rtlwifi: btcoex: fix if == else warning (Íñigo Huguet) [2136123]
- rtw88: use the correct bit in the REG_HCI_OPT_CTRL register (Íñigo Huguet) [2136123]
- mwifiex: Add SD8997 SDIO-UART firmware (Íñigo Huguet) [2136123]
- mwifiex: Select firmware based on strapping (Íñigo Huguet) [2136123]
- rtw89: 8852c: add chip_ops related to BTC (Íñigo Huguet) [2136123]
- rtw89: 8852c: fill freq and band of RX status by PPDU report (Íñigo Huguet) [2136123]
- rtw89: 8852c: implement chip_ops::get_thermal (Íñigo Huguet) [2136123]
- rtw89: 8852c: implement chip_ops related to TX power (Íñigo Huguet) [2136123]
- rtw89: 8852c: configure default BB TX/RX path (Íñigo Huguet) [2136123]
- rtw89: add RF H2C to notify firmware (Íñigo Huguet) [2136123]
- rtw89: don't flush hci queues and send h2c if power is off (Íñigo Huguet) [2136123]
- rtw89: pci: allow to process RPP prior to TX BD (Íñigo Huguet) [2136123]
- rtw89: ps: access TX/RX rings via another registers in low power mode (Íñigo Huguet) [2136123]
- rtw89: ser: re-enable interrupt in threadfn if under_recovery (Íñigo Huguet) [2136123]
- rtw89: pci: add a separate interrupt handler for low power mode (Íñigo Huguet) [2136123]
- rtw89: pci: reclaim TX BD only if it really need (Íñigo Huguet) [2136123]
- rtw89: pci: add variant RPWM/CPWM to enter low power mode (Íñigo Huguet) [2136123]
- rtw89: pci: add variant IMR/ISR and configure functions (Íñigo Huguet) [2136123]
- bus: mhi: host: Add support for Cinterion MV32-WA/MV32-WB (Íñigo Huguet) [2136123]
- bus: mhi: host: Optimize and update MMIO register write method (Íñigo Huguet) [2136123]
- bus: mhi: host: Bail on writing register fields if read fails (Íñigo Huguet) [2136123]
- bus: mhi: host: Wait for ready state after reset (Íñigo Huguet) [2136123]
- bus: mhi: host: Add soc_reset sysfs (Íñigo Huguet) [2136123]
- bus: mhi: host: pci_generic: Sort mhi_pci_id_table based on the PID (Íñigo Huguet) [2136123]
- bus: mhi: host: Use cached values for calculating the shared write pointer (Íñigo Huguet) [2136123]
- rtw88: pci: 8821c: Disable 21ce completion timeout (Íñigo Huguet) [2136123]
- rtw88: fix uninitialized 'tim_offset' warning (Íñigo Huguet) [2136123]
- rtw89: 8852c: add help function of set channel (Íñigo Huguet) [2136123]
- rtw89: 8852c: add set channel of BB part (Íñigo Huguet) [2136123]
- rtw89: 8852c: set channel of MAC part (Íñigo Huguet) [2136123]
- rtw89: 8852c: add set channel function of RF part (Íñigo Huguet) [2136123]
- rtw89: 8852c: add HFC parameters (Íñigo Huguet) [2136123]
- rtw89: 8852c: add efuse gain offset parser (Íñigo Huguet) [2136123]
- rtw89: 8852c: support bb gain info (Íñigo Huguet) [2136123]
- rtw89: 8852c: add BB initial and reset functions (Íñigo Huguet) [2136123]
- rtw89: 8852c: phy: configure TSSI bandedge (Íñigo Huguet) [2136123]
- rtw89: 8852c: add TX power track tables (Íñigo Huguet) [2136123]
- rtw89: 8852c: add TX power by rate and limit tables (Íñigo Huguet) [2136123]
- rtw89: 8852c: add BB and RF parameters tables (Íñigo Huguet) [2136123]
- ath9k: fix QCA9561 PA bias level (Íñigo Huguet) [2136123]
- ath9k_htc: fix potential out of bounds access with invalid rxstatus->rs_keyix (Íñigo Huguet) [2136123]
- ath11k: Fix build warning without CONFIG_IPV6 (Íñigo Huguet) [2136123]
- ath11k: fix missing unlock on error in ath11k_wow_op_resume() (Íñigo Huguet) [2136123]
- ath11k: Add support for SAR (Íñigo Huguet) [2136123]
- ath11k: add support for extended wmi service bit (Íñigo Huguet) [2136123]
- rtw89: pci: correct return value handling of rtw89_write16_mdio_mask() (Íñigo Huguet) [2136123]
- rtw89: configure security CAM for V1 chip (Íñigo Huguet) [2136123]
- rtw89: add new H2C to configure security CAM via DCTL for V1 chip (Íñigo Huguet) [2136123]
- rtw89: extend H2C of CMAC control info (Íñigo Huguet) [2136123]
- rtlwifi: rtl8192cu: Fix spelling mistake "writting" -> "writing" (Íñigo Huguet) [2136123]
- rtlwifi: Fix spelling mistake "cacluated" -> "calculated" (Íñigo Huguet) [2136123]
- rtw88: 8821ce: Disable PCIe ASPM L1 for 8821CE using chip ID (Íñigo Huguet) [2136123]
- rtw88: 8821ce: add support for device ID 0xb821 (Íñigo Huguet) [2136123]
- rtw88: 8821c: fix debugfs rssi value (Íñigo Huguet) [2136123]
- rtw88: do PHY calibration while starting AP (Íñigo Huguet) [2136123]
- rtw88: 8821c: Enable TX report for management frames (Íñigo Huguet) [2136123]
- rtw88: Add update beacon flow for AP mode (Íñigo Huguet) [2136123]
- rtw88: fix incorrect frequency reported (Íñigo Huguet) [2136123]
- rtw88: add ieee80211:sta_rc_update ops (Íñigo Huguet) [2136123]
- rtw89: rtw89_ser: add const to struct state_ent and event_ent (Íñigo Huguet) [2136123]
- rtw89: 8852c: add 8852c specific BT-coexistence initial function (Íñigo Huguet) [2136123]
- rtw89: Skip useless dig gain and igi related settings for 8852C (Íñigo Huguet) [2136123]
- rtw89: 8852c: disable firmware watchdog if CPU disabled (Íñigo Huguet) [2136123]
- rtw89: reset BA CAM (Íñigo Huguet) [2136123]
- rtw89: change station scheduler setting for hardware TX mode (Íñigo Huguet) [2136123]
- rtw89: ser: configure top ERR IMR for firmware to recover (Íñigo Huguet) [2136123]
- rtw89: ser: configure C-MAC interrupt mask (Íñigo Huguet) [2136123]
- rtw89: ser: configure D-MAC interrupt mask (Íñigo Huguet) [2136123]
- rtw89: ser: fix unannotated fall-through (Íñigo Huguet) [2136123]
- ath9k: Remove unnecessary print function dev_err() (Íñigo Huguet) [2136123]
- ath11k: Fix spelling mistake "reseting" -> "resetting" (Íñigo Huguet) [2136123]
- ath9k: fix ath_get_rate_txpower() to respect the rate list end tag (Íñigo Huguet) [2136123]
- mac80211: prepare sta handling for MLO support (Íñigo Huguet) [2136123]
- mac80211: minstrel_ht: fix where rate stats are stored (fixes debugfs output) (Íñigo Huguet) [2136123]
- nl80211: show SSID for P2P_GO interfaces (Íñigo Huguet) [2136123]
- mac80211: introduce BSS color collision detection (Íñigo Huguet) [2136123]
- mac80211: Improve confusing comment around tx_info clearing (Íñigo Huguet) [2136123]
- mac80211: protect ieee80211_assign_beacon with next_beacon check (Íñigo Huguet) [2136123]
- rtl8xxxu: fill up txrate info for gen1 chips (Íñigo Huguet) [2136123]
- rtl8xxxu: feed antenna information for cfg80211 (Íñigo Huguet) [2136123]
- rtlwifi: replace usage of found with dedicated list iterator variable (Íñigo Huguet) [2136123]
- brcmfmac: Avoid keeping power to SDIO card unless WOWL is used (Íñigo Huguet) [2136123]
- mwifiex: add mutex lock for call in mwifiex_dfs_chan_sw_work_queue (Íñigo Huguet) [2136123]
- rtw89: fix misconfiguration on hw_scan channel time (Íñigo Huguet) [2136123]
- rtw89: coex: Add case for scan offload (Íñigo Huguet) [2136123]
- rtw89: packet offload handler to avoid warning (Íñigo Huguet) [2136123]
- rtw89: change idle mode condition during hw_scan (Íñigo Huguet) [2136123]
- rtw89: update ptcl_init (Íñigo Huguet) [2136123]
- rtw89: update TMAC parameters (Íñigo Huguet) [2136123]
- rtw89: initialize NAV control (Íñigo Huguet) [2136123]
- rtw89: update scheduler setting (Íñigo Huguet) [2136123]
- rtw89: 8852c: update security engine setting (Íñigo Huguet) [2136123]
- rtw89: Turn on CR protection of CMAC (Íñigo Huguet) [2136123]
- rtw89: add chip_ops::{enable,disable}_bb_rf to support v1 chip (Íñigo Huguet) [2136123]
- rtw89: update STA scheduler parameters for v1 chip (Íñigo Huguet) [2136123]
- rtw89: extend dmac_pre_init to support 8852C (Íñigo Huguet) [2136123]
- rtw89: pci: add L1 settings (Íñigo Huguet) [2136123]
- rtw89: pci: add deglitch setting (Íñigo Huguet) [2136123]
- rtw89: pci: set address info registers depends on chips (Íñigo Huguet) [2136123]
- rtw89: pci: add LTR setting for v1 chip (Íñigo Huguet) [2136123]
- rtw89: pci: refine pci pre_init function (Íñigo Huguet) [2136123]
- rtw89: pci: add pci attributes to configure operating mode (Íñigo Huguet) [2136123]
- rtw89: pci: add register definition to rtw89_pci_info to generalize pci code (Íñigo Huguet) [2136123]
- ath11k: mhi: remove unnecessary goto from ath11k_mhi_start() (Íñigo Huguet) [2136123]
- ath11k: mhi: add error handling for suspend and resume (Íñigo Huguet) [2136123]
- ath11k: mhi: remove state machine (Íñigo Huguet) [2136123]
- rtw89: handle potential uninitialized variable (Íñigo Huguet) [2136123]
- rtw89: read RX bandwidth from v1 type RX descriptor (Íñigo Huguet) [2136123]
- rtw89: support hardware generate security header (Íñigo Huguet) [2136123]
- rtw89: support variant of fill_txdesc (Íñigo Huguet) [2136123]
- rtw89: pci: support variant of fill_txaddr_info (Íñigo Huguet) [2136123]
- rtw89: add chip_info::h2c_desc_size/fill_txdesc_fwcmd to support new chips (Íñigo Huguet) [2136123]
- rtw89: disabled IGI configuration for unsupported hardware (Íñigo Huguet) [2136123]
- rtw89: packed IGI configuration flow into function for DIG feature (Íñigo Huguet) [2136123]
- rtw89: regd: update mapping table to R59-R32 (Íñigo Huguet) [2136123]
- rtw89: regd: consider 6G band (Íñigo Huguet) [2136123]
- rtw89: 8852a: update txpwr tables to HALRF_027_00_038 (Íñigo Huguet) [2136123]
- rtw89: add UK to regulation type (Íñigo Huguet) [2136123]
- rtw89: reduce export symbol number of mac size and quota (Íñigo Huguet) [2136123]
- rtw89: support FW crash simulation (Íñigo Huguet) [2136123]
- rtw89: reconstruct fw feature (Íñigo Huguet) [2136123]
- rtw89: ser: dump fw backtrace while L2 reset (Íñigo Huguet) [2136123]
- rtw89: ser: dump memory for fw payload engine while L2 reset (Íñigo Huguet) [2136123]
- rtw89: ser: control hci interrupts on/off by state (Íñigo Huguet) [2136123]
- rtw89: mac: correct decision on error status by scenario (Íñigo Huguet) [2136123]
- rtw89: mac: move table of mem base addr to common (Íñigo Huguet) [2136123]
- rtw89: ser: fix CAM leaks occurring in L2 reset (Íñigo Huguet) [2136123]
- rtw88: change idle mode condition during hw_scan (Íñigo Huguet) [2136123]
- iwlwifi: mei: Replace zero-length array with flexible-array member (Íñigo Huguet) [2136123]
- iwlwifi: fw: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2136123]
- ath11k: fix driver initialization failure with WoW unsupported hw (Íñigo Huguet) [2136123]
- ath11k: Remove unnecessary delay in ath11k_core_suspend (Íñigo Huguet) [2136123]
- ath11k: Change max no of active probe SSID and BSSID to fw capability (Íñigo Huguet) [2136123]
- ath11k: Remove core PCI references from PCI common code (Íñigo Huguet) [2136123]
- ath11k: Refactor MSI logic to support WCN6750 (Íñigo Huguet) [2136123]
- ath11k: Choose MSI config based on HW revision (Íñigo Huguet) [2136123]
- ath11k: Refactor PCI code to support WCN6750 (Íñigo Huguet) [2136123]
- ath11k: PCI changes to support WCN6750 (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add uevent support for module autoloading (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for suspending and resuming channels (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for queueing SKBs to the host (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for processing channel rings (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for reading from the host (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for processing command rings (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for handling SYS_ERR condition (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for handling MHI_RESET (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for powering down the MHI endpoint stack (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for powering up the MHI endpoint stack (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for processing MHI endpoint interrupts (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for managing MHI state machine (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for sending events to the host (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for ring management (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for managing MMIO registers (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for creating and destroying MHI EP devices (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for registering MHI endpoint client drivers (Íñigo Huguet) [2136123]
- bus: mhi: ep: Add support for registering MHI endpoint controllers (Íñigo Huguet) [2136123]
- ath9k: make is2ghz consistent in ar9003_eeprom (Íñigo Huguet) [2136123]
- ath10k: add support for MSDU IDs for USB devices (Íñigo Huguet) [2136123]
- ath11k: add support to search regdb data in board-2.bin for WCN6855 (Íñigo Huguet) [2136123]
- ath11k: store and send country code to firmware after recovery (Íñigo Huguet) [2136123]
- ath9k: add functions to get paprd rate mask (Íñigo Huguet) [2136123]
- ath9k: refactor ar9003_hw_spur_mitigate_ofdm (Íñigo Huguet) [2136123]
- ath9k: fix ar9003_get_eepmisc (Íñigo Huguet) [2136123]
- ath9k: use AR9300_MAX_CHAINS when appropriate (Íñigo Huguet) [2136123]
- ath9k: split set11nRateFlags and set11nChainSel (Íñigo Huguet) [2136123]
- ath9k: make ATH_SREV macros more consistent (Íñigo Huguet) [2136123]
- ath11k: Add peer rhash table support (Íñigo Huguet) [2136123]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2136123]
- ath11k: add fallback board name without variant while searching board-2.bin (Íñigo Huguet) [2136123]
- ath11k: enable PLATFORM_CAP_PCIE_GLOBAL_RESET QMI host capability (Íñigo Huguet) [2136123]
- ath11k: Add hw-restart option to simulate_fw_crash (Íñigo Huguet) [2136123]
- ath11k: add synchronization operation between reconfigure of mac80211 and ath11k_base (Íñigo Huguet) [2136123]
- ath11k: add support for device recovery for QCA6390/WCN6855 (Íñigo Huguet) [2136123]
- ath11k: disable regdb support for QCA6390 (Íñigo Huguet) [2136123]
- ath11k: remove unused ATH11K_BD_IE_BOARD_EXT (Íñigo Huguet) [2136123]
- ath11k: change fw build id format in driver init log (Íñigo Huguet) [2136123]
- ath11k: Refactor the peer delete (Íñigo Huguet) [2136123]
- ath10k: Use of_device_get_match_data() helper (Íñigo Huguet) [2136123]
- ath10k: Trigger sta disconnect on hardware restart (Íñigo Huguet) [2136123]
- ath9k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2136123]
- ath11k: support GTK rekey offload (Íñigo Huguet) [2136123]
- ath11k: support ARP and NS offload (Íñigo Huguet) [2136123]
- ath11k: purge rx pktlog when entering WoW (Íñigo Huguet) [2136123]
- ath11k: implement hardware data filter (Íñigo Huguet) [2136123]
- ath11k: Add WoW net-detect functionality (Íñigo Huguet) [2136123]
- ath11k: Add basic WoW functionalities (Íñigo Huguet) [2136123]
- x86/cpu: Add several Intel server CPU model numbers (Prarit Bhargava) [2158037]
- ice: Implement devlink port split operations (Petr Oros) [2009705]
- ice: Add additional flags to ice_nvm_write_activate (Petr Oros) [2009705]
- ice: Add port option admin queue commands (Petr Oros) [2009705]
- hwmon: (coretemp) Check for null before removing sysfs attrs (Phil Auld) [2152429]
- KVM: x86/mmu: fix NULL pointer dereference on guest INVPCID (Jon Maloy) [2099301] {CVE-2022-1789}
- redhat/configs: enable HP_WATCHDOG for aarch64 (Mark Salter) [2113079]
- watchdog/hpwdt: Enable HP_WATCHDOG for ARM64 systems. (Mark Salter) [2113079]
- watchdog: Improve Kconfig entry ordering and dependencies (Mark Salter) [2113079]
- watchdog/hpwdt: Include nmi.h only if CONFIG_HPWDT_NMI_DECODING (Mark Salter) [2113079]
- uprobes/x86: Allow to probe a NOP instruction with 0x66 prefix (Oleg Nesterov) [2133797]
- platform/mellanox: Remove redundant 'NULL' check (Mark Langsdorf) [2122314]
- platform/mellanox: Remove unnecessary code (Mark Langsdorf) [2122314]
- platform/mellanox: mlxreg-lc: Fix locking issue (Mark Langsdorf) [2122314]
- platform/mellanox: mlxreg-lc: Fix coverity warning (Mark Langsdorf) [2122314]
- platform/mellanox: mlxreg-lc: Fix error flow and extend verbosity (Mark Langsdorf) [2122314]
- platform/mellanox: mlxreg-io: Add locking for io operations (Mark Langsdorf) [2122314]
- platform/mellanox: nvsw-sn2201: fix error code in nvsw_sn2201_create_static_devices() (Mark Langsdorf) [2122314]
- platform/mellanox: Add static in struct declaration. (Mark Langsdorf) [2122314]
- platform/mellanox: Spelling s/platfom/platform/ (Mark Langsdorf) [2122314]
- redhat/configs: Enable Mellanox SN2201 management device (Mark Langsdorf) [2122314]
- platform/mellanox: Add support for new SN2201 system (Mark Langsdorf) [2122314]
- platform_data/mlxreg: Add field for notification callback (Mark Langsdorf) [2122314]
- Bluetooth: btintel: Fix WBS setting for Intel legacy ROM products (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Fix broken LED quirk for legacy ROM  devices (Gopal Tiwari) [2129295]
- Bluetooth: Add support hdev to allocate private data (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Fix the legacy bootloader returns tlv based version (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Clean the exported function to static (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Move hci quirks to setup routine (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Refactoring setup routine for bootloader devices (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Add combined set_diag functions (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Fix the LED is not turning off immediately (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Fix the first HCI command not work with ROM device (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Add btintel data struct (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Refactoring setup routine for legacy ROM sku (Gopal Tiwari) [2129295]
- Bluetooth: btintel: Add combined setup and shutdown functions (Gopal Tiwari) [2129295]
- EDAC/mc_sysfs: Increase legacy channel support to 12 (Aristeu Rozanski) [2139861]
- NFS: Trigger the "ls -l" readdir heuristic sooner (Benjamin Coddington) [2025991]
- NFS: Cache all entries in the readdirplus reply (Benjamin Coddington) [2025991]
- NFS: Optimise away the previous cookie field (Benjamin Coddington) [2025991]
- NFS: Fix up forced readdirplus (Benjamin Coddington) [2025991]
- NFS: Convert readdir page cache to use a cookie based index (Benjamin Coddington) [2025991]
- NFS: Clean up page array initialisation/free (Benjamin Coddington) [2025991]
- NFS: Trace effects of the readdirplus heuristic (Benjamin Coddington) [2025991]
- NFS: Trace effects of readdirplus on the dcache (Benjamin Coddington) [2025991]
- NFS: Add basic readdir tracing (Benjamin Coddington) [2025991]
- NFS: Don't request readdirplus when revalidation was forced (Benjamin Coddington) [2025991]
- NFSv4: Ask for a full XDR buffer of readdir goodness (Benjamin Coddington) [2025991]
- NFS: Don't ask for readdirplus unless it can help nfs_getattr() (Benjamin Coddington) [2025991]
- NFS: Improve heuristic for readdirplus (Benjamin Coddington) [2025991]
- NFS: Reduce use of uncached readdir (Benjamin Coddington) [2025991]
- NFS: Simplify nfs_readdir_xdr_to_array() (Benjamin Coddington) [2025991]
- NFS: If the cookie verifier changes, we must invalidate the page cache (Benjamin Coddington) [2025991]
- NFS: Adjust the amount of readahead performed by NFS readdir (Benjamin Coddington) [2025991]
- NFS: Don't advance the page pointer unless the page is full (Benjamin Coddington) [2025991]
- NFS: Don't re-read the entire page cache to find the next cookie (Benjamin Coddington) [2025991]
- NFS: Store the change attribute in the directory page cache (Benjamin Coddington) [2025991]
- NFS: Calculate page offsets algorithmically (Benjamin Coddington) [2025991]
- NFS: Use kzalloc() to avoid initialising the nfs_open_dir_context (Benjamin Coddington) [2025991]
- NFS: Initialise the readdir verifier as best we can in nfs_opendir() (Benjamin Coddington) [2025991]
- NFS: Trace lookup revalidation failure (Benjamin Coddington) [2025991]
- NFS: constify nfs_server_capable() and nfs_have_writebacks() (Benjamin Coddington) [2025991]
- NFS: Return valid errors from nfs2/3_decode_dirent() (Benjamin Coddington) [2025991]
- NFS: Avoid duplicate uncached readdir calls on eof (Benjamin Coddington) [2025991]
- NFS: Don't skip directory entries when doing uncached readdir (Benjamin Coddington) [2025991]
- NFS: Don't overfill uncached readdir pages (Benjamin Coddington) [2025991]
- block: unhash blkdev part inode when the part is deleted (Ming Lei) [2148497]

* Thu Dec 22 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-447.el8]
- x86/fpu: Drop fpregs lock before inheriting FPU permissions (Eder Zulian) [2153549]
- cpufreq: amd-pstate: Add resume and suspend callbacks (Mark Langsdorf) [2122310]
- cpufreq: CPPC: Enable dvfs_possible_from_any_cpu (Mark Langsdorf) [2122310]
- cpufreq: check only freq_table in __resolve_freq() (Mark Langsdorf) [2122310]
- cpufreq: ondemand: Use cpumask_var_t for on-stack cpu mask (Mark Langsdorf) [2122310]
- cpufreq: Change order of online() CB and policy->cpus modification (Mark Langsdorf) [2122310]
- cpufreq: Warn users while freeing active policy (Mark Langsdorf) [2122310]
- cpufreq: Drop unnecessary cpus locking from store() (Mark Langsdorf) [2122310]
- cpufreq: Optimize cpufreq_show_cpus() (Mark Langsdorf) [2122310]
- cpufreq: make interface functions and lock holding state clear (Mark Langsdorf) [2122310]
- cpufreq: Abort show()/store() for half-initialized policies (Mark Langsdorf) [2122310]
- cpufreq: Rearrange locking in cpufreq_remove_dev() (Mark Langsdorf) [2122310]
- cpufreq: Split cpufreq_offline() (Mark Langsdorf) [2122310]
- cpufreq: Reorganize checks in cpufreq_offline() (Mark Langsdorf) [2122310]
- cpufreq: Clear real_cpus mask from remove_cpu_dev_symlink() (Mark Langsdorf) [2122310]
- cpufreq: Prepare cleanup of powerpc's asm/prom.h (Mark Langsdorf) [2122310]
- cpufreq: governor: Use kobject release() method to free dbs_data (Mark Langsdorf) [2122310]
- ipv6: fix panic when fib_lookup_arg->result is fib6_info (Jiri Benc) [2140599]
- tipc: re-fetch skb cb after tipc_msg_validate (Xin Long) [2142732]
- Documentation: bonding: correct xmit hash steps (Jonathan Toppins) [2150390]
- Documentation: bonding: update miimon default to 100 (Jonathan Toppins) [2150390]
- selftests: bonding: up/down delay w/ slave link flapping (Jonathan Toppins) [2150390]
- bonding (gcc13): synchronize bond_{a,t}lb_xmit() types (Jonathan Toppins) [2150390]
- selftests: net: Fix cross-tree inclusion of scripts (Jonathan Toppins) [2150390]
- treewide: use get_random_u32() when possible (Jonathan Toppins) [2150390]
- selftests/bonding: re-add lladdr target test (Jonathan Toppins) [2150390]
- selftests: bonding: cause oops in bond_rr_gen_slave_id (Jonathan Toppins) [2150390]
- selftests/bonding: add a test for bonding lladdr target (Jonathan Toppins) [2150390]
- net: Add tests for bonding and team address list management (Jonathan Toppins) [2150390]
- net: bonding: Unsync device addresses on ndo_stop (Jonathan Toppins) [2150390]
- net: bonding: Share lacpdu_mcast_addr definition (Jonathan Toppins) [2150390]
- Documentation: bonding: clarify supported modes for tlb_dynamic_lb (Jonathan Toppins) [2150390]
- selftests: include bonding tests into the kselftest infra (Jonathan Toppins) [2150390]
- bonding: fix reference count leak in balance-alb mode (Jonathan Toppins) [2150390]
- net:bonding:support balance-alb interface with vlan to bridge (Jonathan Toppins) [2150390]
- bonding: cleanup bond_create (Jonathan Toppins) [2150390]
- bonding: netlink error message support for options (Jonathan Toppins) [2150390]
- bonding: Update layer2 and layer2+3 hash formula documentation (Jonathan Toppins) [2150390]
- net: bonding: Add support for IPV6 ns/na to balance-alb/balance-tlb mode (Jonathan Toppins) [2150390]
- net: remove bond_slave_has_mac_rcu() (Jonathan Toppins) [2150390]
- net: bonding: debug: avoid printing debug logs when bond is not notifying peers (Jonathan Toppins) [2150390]
- net: bonding: constify and use dev_addr_set() (Jonathan Toppins) [2150390]
- net: use dev_addr_set() (Jonathan Toppins) [2150390]
- bonding: remove extraneous definitions from bonding.h (Jonathan Toppins) [2150390]
- net: bonding: bond_alb: Fix some typos in bond_alb.c (Jonathan Toppins) [2150390]
- net: bonding: use tabs instead of space for code indent (Jonathan Toppins) [2150390]
- net: bonding: remove unnecessary braces (Jonathan Toppins) [2150390]
- net: bonding: fix code indent for conditional statements (Jonathan Toppins) [2150390]
- net: bonding: add some required blank lines (Jonathan Toppins) [2150390]
- docs: networking: bonding.rst Fix a typo in bonding.rst (Jonathan Toppins) [2150390]
- docs: networking: bonding.rst resources section cleanup (Jonathan Toppins) [2150390]
- bonding: Replace zero-length array with flexible-array member (Jonathan Toppins) [2150390]
- include/net/bond_3ad: Simplify the code by using the ARRAY_SIZE (Jonathan Toppins) [2150390]
- vmxnet3: use correct intrConf reference when using extended queues (Izabela Bakollari) [2150917]
- vmxnet3: correctly report encapsulated LRO packet (Izabela Bakollari) [2150917]
- net: move from strlcpy with unused retval to strscpy (Izabela Bakollari) [2150917]
- vmxnet3: Implement ethtool's get_channels command (Izabela Bakollari) [2150917]
- vmxnet3: Record queue number to incoming packets (Izabela Bakollari) [2150917]
- [rt] Revert "mm/memcg: disable threshold event handlers on PREEMPT_RT" (Chris White) [2152035]
- s390/pci: allow zPCI zbus without a function zero (Tobias Huschle) [2043829]
- PCI: Extend isolated function probing to s390 (Tobias Huschle) [2043829]
- PCI: Move jailhouse's isolated function handling to pci_scan_slot() (Tobias Huschle) [2043829]
- PCI: Split out next_ari_fn() from next_fn() (Tobias Huschle) [2043829]
- PCI: Clean up pci_scan_slot() (Tobias Huschle) [2043829]
- KVM: selftests: Build the memslot tests for arm64 (Gavin Shan) [2134650]
- KVM: selftests: memslot_perf_test: Report optimal memory slots (Gavin Shan) [2134650]
- KVM: selftests: memslot_perf_test: Consolidate memory (Gavin Shan) [2134650]
- KVM: selftests: memslot_perf_test: Support variable guest page size (Gavin Shan) [2134650]
- KVM: selftests: memslot_perf_test: Probe memory slots for once (Gavin Shan) [2134650]
- KVM: selftests: memslot_perf_test: Consolidate loop conditions in prepare_vm() (Gavin Shan) [2134650]
- KVM: selftests: memslot_perf_test: Use data->nslots in prepare_vm() (Gavin Shan) [2134650]
- KVM: selftests: Make memslot_perf_test arch independent (Gavin Shan) [2134650]
- selftests: netfilter: Fix and review rpath.sh (Phil Sutter) [1961152]
- netfilter: Use l3mdev flow key when re-routing mangled packets (Phil Sutter) [1961152]
- netfilter: Update ip6_route_me_harder to consider L3 domain (Phil Sutter) [1961152]
- netfilter: Dissect flow after packet mangling (Phil Sutter) [1961152]
- netfilter: rpfilter/fib: Populate flowic_l3mdev field (Phil Sutter) [1961152]
- selftests: netfilter: Test reverse path filtering (Phil Sutter) [1961152]
- netfilter: nft_fib: Fix for rpath check with VRF devices (Phil Sutter) [1961152]
- net: seg6: fix seg6_lookup_any_nexthop() to handle VRFs using flowi_l3mdev (Phil Sutter) [1961152]
- net: Handle l3mdev in ip_tunnel_init_flow (Phil Sutter) [1961152]
- xfrm: Pass flowi_oif or l3mdev as oif to xfrm_dst_lookup (Phil Sutter) [1961152]
- net: Add l3mdev index to flow struct and avoid oif reset for port devices (Phil Sutter) [1961152]
- l3mdev: l3mdev_master_upper_ifindex_by_index_rcu should be using netdev_master_upper_dev_get_rcu (Phil Sutter) [1961152]
- l3mdev: add function to retreive upper master (Phil Sutter) [1961152]
- sfc: move deprecation message to sfc_siena (Íñigo Huguet) [2112205 2136107]
- sfc/siena: add entries for new CONFIG_SFC_SIENA* configs (Íñigo Huguet) [2112205 2136107]
- sfc: Fix an error handling path in efx_pci_probe() (Íñigo Huguet) [2112205]
- sfc: support PTP over Ethernet (Íñigo Huguet) [2112205 2065017]
- sfc: support PTP over IPv6/UDP (Íñigo Huguet) [2112205 2065017]
- sfc: allow more flexible way of adding filters for PTP (Íñigo Huguet) [2112205 2065017]
- sfc: correct filter_table_remove method for EF10 PFs (Íñigo Huguet) [2112205]
- sfc/siena: fix null pointer dereference in efx_hard_start_xmit (Íñigo Huguet) [2112205]
- sfc/siena: fix TX channel offset when using legacy interrupts (Íñigo Huguet) [2112205]
- sfc: implement ethtool get/set RX ring size for EF100 reps (Íñigo Huguet) [2112205]
- sfc: use a dynamic m-port for representor RX and set it promisc (Íñigo Huguet) [2112205]
- sfc: move table locking into filter_table_{probe,remove} methods (Íñigo Huguet) [2112205]
- sfc: insert default MAE rules to connect VFs to representors (Íñigo Huguet) [2112205]
- sfc: receive packets from EF100 VFs into representors (Íñigo Huguet) [2112205]
- sfc: check ef100 RX packets are from the wire (Íñigo Huguet) [2112205]
- sfc: determine wire m-port at EF100 PF probe time (Íñigo Huguet) [2112205]
- sfc: ef100 representor RX top half (Íñigo Huguet) [2112205]
- sfc: ef100 representor RX NAPI poll (Íñigo Huguet) [2112205]
- sfc: plumb ef100 representor stats (Íñigo Huguet) [2112205]
- sfc: disable softirqs for ptp TX (Íñigo Huguet) [2112205]
- sfc/siena: fix repeated words in comments (Íñigo Huguet) [2112205]
- sfc: attach/detach EF100 representors along with their owning PF (Íñigo Huguet) [2112205]
- sfc: hook up ef100 representor TX (Íñigo Huguet) [2112205]
- sfc: support passing a representor to the EF100 TX path (Íñigo Huguet) [2112205]
- sfc: determine representee m-port for EF100 representors (Íñigo Huguet) [2112205]
- sfc: phys port/switch identification for ef100 reps (Íñigo Huguet) [2112205]
- sfc: add basic ethtool ops to ef100 reps (Íñigo Huguet) [2112205]
- sfc: add skeleton ef100 VF representors (Íñigo Huguet) [2112205]
- sfc: detect ef100 MAE admin privilege/capability at probe time (Íñigo Huguet) [2112205]
- sfc: update EF100 register descriptions (Íñigo Huguet) [2112205]
- sfc: update MCDI protocol headers (Íñigo Huguet) [2112205]
- sfc/siena: Use the bitmap API to allocate bitmaps (Íñigo Huguet) [2112205]
- sfc: Separate netdev probe/remove from PCI probe/remove (Íñigo Huguet) [2112205]
- sfc: replace function name in string with __func__ (Íñigo Huguet) [2112205]
- sfc: Unsplit literal string. (Íñigo Huguet) [2112205]
- sfc: Move EF100 efx_nic_type structs to the end of the file (Íñigo Huguet) [2112205]
- sfc: Separate efx_nic memory from net_device memory (Íñigo Huguet) [2112205]
- sfc: Encapsulate access to netdev_priv() (Íñigo Huguet) [2112205]
- sfc: Change BUG_ON to WARN_ON and recovery code. (Íñigo Huguet) [2112205]
- sfc: Remove netdev init from efx_init_struct (Íñigo Huguet) [2112205]
- sfc: Add a PROBED state for EF100 VDPA use. (Íñigo Huguet) [2112205]
- sfc: Split STATE_READY in to STATE_NET_DOWN and STATE_NET_UP. (Íñigo Huguet) [2112205]
- sfc: fix repeated words in comments (Íñigo Huguet) [2112205]
- sfc: siena: fix repeated words in comments (Íñigo Huguet) [2112205]
- sfc/siena: Fix typo in comment (Íñigo Huguet) [2112205]
- sfc: Fix typo in comment (Íñigo Huguet) [2112205]
- sfc/siena: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [2112205]
- sfc/siena: fix considering that all channels have TX queues (Íñigo Huguet) [2112205]
- sfc/siena: Remove duplicate check on segments (Íñigo Huguet) [2112205 2136107]
- sfc: siena: Have a unique wrapper ifndef for efx channels header (Íñigo Huguet) [2112205 2136107]
- eth: sfc: remove remnants of the out-of-tree napi_weight module param (Íñigo Huguet) [2112205]
- sfc: siena: Fix Kconfig dependencies (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Reinstate SRIOV init/fini function calls (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Make PTP and reset support specific for Siena (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Make MCDI logging support specific for Siena (Íñigo Huguet) [2112205 2136107]
- siena: Make HWMON support specific for Siena (Íñigo Huguet) [2112205 2136107]
- siena: Make SRIOV support specific for Siena (Íñigo Huguet) [2112205 2136107]
- siena: Make MTD support specific for Siena (Íñigo Huguet) [2112205 2136107]
- sfc: Add a basic Siena module (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Inline functions in sriov.h to avoid conflicts with sfc (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Rename functions in nic_common.h to avoid conflicts with sfc (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Rename functions in mcdi headers to avoid conflicts with sfc (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Rename peripheral functions to avoid conflicts with sfc (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Rename RX/TX functions to avoid conflicts with sfc (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Rename functions in efx headers to avoid conflicts with sfc (Íñigo Huguet) [2112205 2136107]
- sfc/siena: Remove build references to missing functionality (Íñigo Huguet) [2112205 2136107]
- sfc: Copy shared files needed for Siena (part 2) (Íñigo Huguet) [2112205 2136107]
- sfc: Copy shared files needed for Siena (part 1) (Íñigo Huguet) [2112205 2136107]
- sfc: Move Siena specific files (Íñigo Huguet) [2112205 2136107]
- sfc: Copy a subset of mcdi_pcol.h to siena (Íñigo Huguet) [2112205 2136107]
- sfc: Disable Siena support (Íñigo Huguet) [2112205 2136107]
- sfc: add EF100 VF support via a write to sriov_numvfs (Íñigo Huguet) [2112205]
- sfc: Remove global definition of efx_reset_type_names (Íñigo Huguet) [2112205]
- sfc: Remove duplicate definition of efx_xmit_done (Íñigo Huguet) [2112205]
- sfc: efx_default_channel_type APIs can be static (Íñigo Huguet) [2112205]
- sfc: Fix spelling mistake "writting" -> "writing" (Íñigo Huguet) [2112205]
- sfc: ef10: Fix assigning negative value to unsigned variable (Íñigo Huguet) [2112205]
- sfc: use hardware tx timestamps for more than PTP (Íñigo Huguet) [2112205 2065017]
- net: ethernet: sfc: Make subdir logic consistent with other vendors (Íñigo Huguet) [2112205 2136107]
- hugetlbfs: fix mount mode command line processing (Bill O'Donnell) [2148876]
- igc: Correct the launchtime offset (Corinna Vinschen) [2103954]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Corinna Vinschen) [2103954]
- igc: Remove IGC_MDIC_INT_EN definition (Corinna Vinschen) [2103954]
- igc: Remove forced_speed_duplex value (Corinna Vinschen) [2103954]
- igc: Remove MSI-X PBA Clear register (Corinna Vinschen) [2103954]
- igc: Lift TAPRIO schedule restriction (Corinna Vinschen) [2103954]
- wifi: brcmfmac: Fix potential buffer overflow in brcmf_fweh_event_worker() (Wander Lairson Costa) [2150964] {CVE-2022-3628}
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2103949]
- tipc: call tipc_lxc_xmit without holding node_read_lock (Xin Long) [2141640]
- mptcp: fix sleep in atomic at close time (Davide Caratti) [2150361]
- mptcp: don't orphan ssk in mptcp_close() (Davide Caratti) [2150361]
- net: Avoid overwriting valid skb->napi_id (Antoine Tenart) [2142593]
- x86/microcode/AMD: Apply the patch early on every logical thread (Waiman Long) [2139856]
- x86/bugs: Enable STIBP for IBPB mitigated RETBleed (Waiman Long) [2139856]
- x86/bugs: Add "unknown" reporting for MMIO Stale Data (Waiman Long) [2139856]
- tracing: Use a copy of the va_list for __assign_vstr() (Íñigo Huguet) [2143356]
- tracing/events: Add __vstring() and __assign_vstr() helper macros (Íñigo Huguet) [2143356]
- rtnetlink: add IFLA_PARENT_[DEV|DEV_BUS]_NAME (Jose Ignacio Tornos Martinez) [2144853]
- rtnetlink: add alloc() method to rtnl_link_ops (Jose Ignacio Tornos Martinez) [2144853]
- ipv6: Fix data races around sk->sk_prot. (Guillaume Nault) [2144805] {CVE-2022-3567}
- ipv6: annotate some data-races around sk->sk_prot (Guillaume Nault) [2144805] {CVE-2022-3567}
- ipv6: use indirect call wrappers for {tcp, udpv6}_{recv, send}msg() (Guillaume Nault) [2144805] {CVE-2022-3567}
- mm/mremap: hold the rmap lock in write mode when moving page table entries. (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: use pmd/pud_poplulate to update page table entries (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: don't enable optimized PUD move if page table levels is 2 (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: convert huge PUD move to separate helper (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: fix BUILD_BUG_ON() error in get_extent (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap.c: fix extent calculation (Waiman Long) [2140945] {CVE-2022-41222}
- x86: mremap speedup - Enable HAVE_MOVE_PUD (Waiman Long) [2140945] {CVE-2022-41222}
- mm: speedup mremap on 1GB or larger regions (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: start addresses are properly aligned (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: calculate extent in one place (Waiman Long) [2140945] {CVE-2022-41222}
- mm/mremap: it is sure to have enough space when extent meets requirement (Waiman Long) [2140945] {CVE-2022-41222}

* Mon Dec 19 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-446.el8]
- irqchip/gic, gic-v3: Make SGIs use handle_percpu_devid_irq() (Charles Mirabile) [2133892]
- irqchip/gic-common: Don't enable SGIs by default (Charles Mirabile) [2133892]
- irqchip/gic: Configure SGIs as standard interrupts (Charles Mirabile) [2133892]
- irqchip/gic: Refactor SMP configuration (Charles Mirabile) [2133892]
- irqchip/gic-v3: Configure SGIs as standard interrupts (Charles Mirabile) [2133892]
- irqchip/gic-v3: Describe the SGI range (Charles Mirabile) [2133892]
- arm64: Allow IPIs to be handled as normal interrupts (Charles Mirabile) [2133892]
- irqchip/gic, gic-v3: Prevent GSI to SGI translations (Charles Mirabile) [2133892]
- Workaround to enable support for IPI (Charles Mirabile) [2133892]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2112182]
- tg3: Disable tg3 device on system reboot to avoid triggering AER (Ken Cox) [2112182]
- aquantia: Do not purge addresses when setting the number of rings (Izabela Bakollari) [2122571]
- openvswitch: add nf_ct_is_confirmed check before assigning the helper (Antoine Tenart) [2135414]
- net: openvswitch: allow conntrack in non-initial user namespace (Antoine Tenart) [2135414]
- net: openvswitch: allow metering in non-initial user namespace (Antoine Tenart) [2135414]
- openvswitch: Change the return type for vport_ops.send function hook to int (Antoine Tenart) [2135414]
- net: openvswitch: fix repeated words in comments (Antoine Tenart) [2135414]
- openvswitch: add OVS_DP_ATTR_PER_CPU_PIDS to get requests (Antoine Tenart) [2135414]
- openvswitch: allow specifying ifindex of new interfaces (Antoine Tenart) [2135414]
- openvswitch: move from strlcpy with unused retval to strscpy (Antoine Tenart) [2135414]
- openvswitch: Fix overreporting of drops in dropwatch (Antoine Tenart) [2135414]
- openvswitch: Fix double reporting of drops in dropwatch (Antoine Tenart) [2135414]
- openvswitch: fix memory leak at failed datapath creation (Antoine Tenart) [2135414]
- net: remove noblock parameter from skb_recv_datagram() (Íñigo Huguet) [2143359]
- i40e: Fix error handling in i40e_init_module() (Stefan Assmann) [2103661]
- i40e: Add appropriate error message logged for incorrect duplex setting (Stefan Assmann) [2103661]
- i40e: Add i40e_napi_poll tracepoint (Stefan Assmann) [2103661]
- i40e: Record number of RXes cleaned during NAPI (Stefan Assmann) [2103661]
- i40e: Record number TXes cleaned during NAPI (Stefan Assmann) [2103661]
- i40e: Store the irq number in i40e_q_vector (Stefan Assmann) [2103661]
- ptp: introduce helpers to adjust by scaled parts per million (Stefan Assmann) [2103661]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Stefan Assmann) [2103661]
- i40e: Fix flow-type by setting GL_HASH_INSET registers (Stefan Assmann) [2103661]
- i40e: Fix ethtool rx-flow-hash setting for X722 (Stefan Assmann) [2103661]
- i40e: Fix ADQ rate limiting for PF (Stefan Assmann) [2103661]
- i40e: add description and modify interrupts configuration procedure (Stefan Assmann) [2103661]
- i40e: Add basic support for I710 devices (Stefan Assmann) [2103661]
- net: ethernet: move from strlcpy with unused retval to strscpy (Stefan Assmann) [2103661]
- i40e: Fix incorrect address type for IPv6 flow rules (Stefan Assmann) [2103661]
- i40e: Fix to stop tx_timeout recovery if GLOBR fails (Stefan Assmann) [2103661]
- i40e: convert .adjfreq to .adjfine (Stefan Assmann) [2103661]
- i40e: use mul_u64_u64_div_u64 for PTP frequency calculation (Stefan Assmann) [2103661]
- i40e: Fix interface init with MSI interrupts (no MSI-X) (Stefan Assmann) [2103661]
- i40e: Refactor tc mqprio checks (Stefan Assmann) [2103661]
- i40e: Fix erroneous adapter reinitialization during recovery process (Stefan Assmann) [2103661]
- i40e: Fix VF's MAC Address change on VM (Stefan Assmann) [2103661]
- i40e: Fix dropped jumbo frames statistics (Stefan Assmann) [2103661]
- intel/i40e:fix repeated words in comments (Stefan Assmann) [2103661]
- intel: remove unused macros (Stefan Assmann) [2103661]
- i40e: read the XDP program once per NAPI (Stefan Assmann) [2103661]
- intel/i40e: delete if NULL check before dev_kfree_skb (Stefan Assmann) [2103661]
- i40e: Remove unnecessary synchronize_irq() before free_irq() (Stefan Assmann) [2103661]
- i40e: Add support for ethtool -s <interface> speed <speed in Mb> (Stefan Assmann) [2103661]
- i40e: Add VF VLAN pruning (Stefan Assmann) [2103661]
- xsk: Wipe out dead zero_copy_allocator declarations (Stefan Assmann) [2103661]
- gpio: amdpt: add new device ID and 24-pin support (Prarit Bhargava) [2097868]
- platform/x86/intel: pmc/core: Add Raptor Lake support to pmc core driver (Prarit Bhargava) [2076732]
- HID: hyperv: fix possible memory leak in mousevsc_probe() (Mohammed Gamal) [2139468]
- HID: hyperv: Correctly access fields declared as __le16 (Mohammed Gamal) [2139468]
- Drivers: hv: vmbus: fix possible memory leak in vmbus_device_register() (Mohammed Gamal) [2139473]
- Drivers: hv: vmbus: fix double free in the error path of vmbus_add_channel_work() (Mohammed Gamal) [2139473]
- Drivers: hv: fix repeated words in comments (Mohammed Gamal) [2139473]
- Drivers: hv: vmbus: Split memcpy of flex-array (Mohammed Gamal) [2139473]
- Drivers: hv: vmbus: Don't wait for the ACPI device upon initialization (Mohammed Gamal) [2139473]
- Drivers: hv: vmbus: Use PCI_VENDOR_ID_MICROSOFT for better discoverability (Mohammed Gamal) [2139473]
- PCI: Move PCI_VENDOR_ID_MICROSOFT/PCI_DEVICE_ID_HYPERV_VIDEO definitions to pci_ids.h (Mohammed Gamal) [2139473]
- Drivers: hv: vmbus: Fix kernel-doc (Mohammed Gamal) [2139473]
- Drivers: hv: vmbus: Optimize vmbus_on_event (Mohammed Gamal) [2139473]
- Drivers: hv: Never allocate anything besides framebuffer from framebuffer memory region (Mohammed Gamal) [2139473]
- Drivers: hv: Always reserve framebuffer region for Gen1 VMs (Mohammed Gamal) [2139473]
- Drivers: hv: remove duplicate word in a comment (Mohammed Gamal) [2139473]
- Drivers: hv: Create debugfs file with hyper-v balloon usage information (Mohammed Gamal) [2139473]
- Drivers: hv: vm_bus: Handle vmbus rescind calls after vmbus is suspended (Mohammed Gamal) [2139473]
- scsi: storvsc: remove an extraneous "to" in a comment (Cathy Avery) [2143320]
- Drivers: hv: vmbus: Optimize vmbus_on_event (Cathy Avery) [2143320]
- scsi: storvsc: Drop DID_TARGET_FAILURE use (Cathy Avery) [2143320]
- scsi: storvsc: Remove WQ_MEM_RECLAIM from storvsc_error_wq (Cathy Avery) [2143320]
- scsi: storvsc: Correct reporting of Hyper-V I/O size limits (Cathy Avery) [2143320]
- scsi: storvsc: Removing Pre Win8 related logic (Cathy Avery) [2143320]
- scsi: storvsc: Fix typo in comment (Cathy Avery) [2143320]
- scsi: storvsc: Remove support for Hyper-V 2008 and 2008R2/Win7 (Cathy Avery) [2143320]
- vdpa/mlx5: re-create forwarding rules after mac modified (Laurent Vivier) [2145136]
- ipv6: Fix crash when IPv6 is administratively disabled (Guillaume Nault) [2140779]
- raw: fix a typo in raw_icmp_error() (Guillaume Nault) [2140779]
- raw: remove unused variables from raw6_icmp_error() (Guillaume Nault) [2140779]
- raw: complete rcu conversion (Guillaume Nault) [2140779]
- raw: Use helpers for the hlist_nulls variant. (Guillaume Nault) [2140779]
- raw: Fix mixed declarations error in raw_icmp_error(). (Guillaume Nault) [2140779]
- raw: convert raw sockets to RCU (Guillaume Nault) [2140779]
- raw: use more conventional iterators (Guillaume Nault) [2140779]
- raw: Add missing annotations to raw_seq_start() and raw_seq_stop() (Guillaume Nault) [2140779]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2103941]
- e1000e: convert .adjfreq to .adjfine (Ken Cox) [2103941]
- e1000e: remove unnecessary range check in e1000e_phc_adjfreq (Ken Cox) [2103941]
- Revert "e1000e: Fix possible HW unit hang after an s0ix exit" (Ken Cox) [2103941]
- e1000e: Enable GPT clock before sending message to CSME (Ken Cox) [2103941]
- intel/e1000e:fix repeated words in comments (Ken Cox) [2103941]
- intel: remove unused macros (Ken Cox) [2103941]
- net: move netif_set_gso_max helpers (Ivan Vecera) [2137564]
- net: make drivers set the TSO limit not the GSO limit (Ivan Vecera) [2137564]
- net: don't allow user space to lift the device limits (Ivan Vecera) [2137564]
- net: add netif_inherit_tso_max() (Ivan Vecera) [2137564]
- net: extract a few internals from netdevice.h (Ivan Vecera) [2137564]
- net: unexport a handful of dev_* functions (Ivan Vecera) [2137564]
- bpf: Fix extable address check. (Felix Maurer) [2138532]
- bpf, x64: Factor out emission of REX byte in more cases (Felix Maurer) [2138532]
- bpf: Support dual-stack sockets in bpf_tcp_check_syncookie (Felix Maurer) [2138532]
- bpf: Fix extable fixup offset. (Felix Maurer) [2138532]
- bpf: Fix the off-by-two error in range markings (Felix Maurer) [2138532]
- bpf: Fix potential race in tail call compatibility check (Felix Maurer) [2138532]
- bpf: Fix possible out of bound write in narrow load handling (Felix Maurer) [2138532]
- bpf: Fix potential memleak and UAF in the verifier. (Felix Maurer) [2138532]
- KVM: s390: vsie: Fix the initialization of the epoch extension (epdx) field (Thomas Huth) [2151854]
- PM: core: Remove static qualifier in DEFINE_SIMPLE_DEV_PM_OPS macro (Íñigo Huguet) [2143354]
- PM: core: Add new *_PM_OPS macros, deprecate old ones (Íñigo Huguet) [2143354]
- PM: Make *_DEV_PM_OPS macros use __maybe_unused (Íñigo Huguet) [2143354]
- PM: core: Redefine pm_ptr() macro (Íñigo Huguet) [2143354]
- linux/kconfig.h: replace IF_ENABLED() with PTR_IF() in <linux/kernel.h> (Íñigo Huguet) [2143354]
- net: Remove unused inline function sk_nulls_node_init() (Guillaume Nault) [2143239]
- ping: convert to RCU lookups, get rid of rwlock (Guillaume Nault) [2143239]
- mm/cgroup/reclaim: fix dirty pages throttling on cgroup v1 (Waiman Long) [2149544]
- mm: vmscan: remove deadlock due to throttling failing to make progress (Waiman Long) [2149544]
- mm: vmscan: reduce throttling due to a failure to make progress -fix (Waiman Long) [2149544]
- mm: vmscan: Reduce throttling due to a failure to make progress (Waiman Long) [2149544]
- mm/vmscan: delay waking of tasks throttled on NOPROGRESS (Waiman Long) [2149544]
- mm/vmscan: increase the timeout if page reclaim is not making progress (Waiman Long) [2149544]
- mm/vmscan: centralise timeout values for reclaim_throttle (Waiman Long) [2149544]
- mm/page_alloc: remove the throttling logic from the page allocator (Waiman Long) [2149544]
- mm/writeback: throttle based on page writeback instead of congestion (Waiman Long) [2149544]
- mm/vmscan: throttle reclaim when no progress is being made (Waiman Long) [2149544]
- mm/vmscan: throttle reclaim and compaction when too may pages are isolated (Waiman Long) [2149544]
- mm/vmscan: throttle reclaim until some writeback completes if congested (Waiman Long) [2149544]
- mm/vmscan.c: delete or fix duplicated words (Waiman Long) [2149544]
- powerpc/pseries/vas: Add VAS IRQ primary handler (Mamatha Inamdar) [2131675]
- powerpc: Ignore DSI error caused by the copy/paste instruction (Mamatha Inamdar) [2131675]
- powerpc/pseries: Move vas_migration_handler early during migration (Mamatha Inamdar) [2131675]
- vt: drop old FONT ioctls (Wander Lairson Costa) [2109164] {CVE-2021-33656}

* Wed Dec 14 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-445.el8]
- x86/mce: Reduce number of machine checks taken during recovery (Prarit Bhargava) [2104388]
- scsi: storvsc: Fix handling of srb_status and capacity change events (Mohammed Gamal) [2139728]
- clocksource: hyper-v: unexport __init-annotated hv_init_clocksource() (Mohammed Gamal) [2139463]
- hv_netvsc: Fix race between VF offering and VF association message from host (Mohammed Gamal) [2139475]
- sbitmap: fix lockup while swapping (Ming Lei) [2140214]
- sbitmap: fix batched wait_cnt accounting (Ming Lei) [2140214]
- sbitmap: Avoid leaving waitqueue in invalid state in __sbq_wake_up() (Ming Lei) [2140214]
- sbitmap: fix possible io hung due to lost wakeup (Ming Lei) [2140214]
- sbitmap: add helper to clear a batch of tags (Ming Lei) [2140214]
- x86/hyperv: Restore VP assist page after cpu offlining/onlining (Mohammed Gamal) [2139454]
- clocksource/drivers/hyperv: add data structure for reference TSC MSR (Mohammed Gamal) [2139454]
- x86/hyperv: fix root partition faults when writing to VP assist page MSR (Mohammed Gamal) [2139454]
- x86/hyperv: fix invalid writes to MSRs during root partition kexec (Mohammed Gamal) [2139454]
- x86/hyperv: Remove BUG_ON() for kmap_local_page() (Mohammed Gamal) [2139454]
- x86/hyperv: Disable hardlockup detector by default in Hyper-V guests (Mohammed Gamal) [2139454]
- x86/hyperv: Update 'struct hv_enlightened_vmcs' definition (Mohammed Gamal) [2139454]
- x86/hyperv: Fix 'struct hv_enlightened_vmcs' definition (Mohammed Gamal) [2139454]
- x86/hyperv: Replace kmap() with kmap_local_page() (Mohammed Gamal) [2139454]
- hyperv: simplify and rename generate_guest_id (Mohammed Gamal) [2139454]
- x86/Hyper-V: Add SEV negotiate protocol support in Isolation VM (Mohammed Gamal) [2139454]
- x86/sev: Define the Linux-specific guest termination reasons (Mohammed Gamal) [2139454]
- x86/sev: Shorten GHCB terminate macro names (Mohammed Gamal) [2139454]
- x86/sev: Save the negotiated GHCB version (Mohammed Gamal) [2139454]
- locking: Add __sched to semaphore functions (Waiman Long) [2141429]
- locking/rwsem: Disable preemption while trying for rwsem lock (Waiman Long) [2141429]
- locking/percpu-rwsem: Add percpu_is_write_locked() and percpu_is_read_locked() (Waiman Long) [2141429]
- locking/rwsem: Conditionally wake waiters in reader/writer slowpaths (Waiman Long) [2141429]
- locking: Mark racy reads of owner->on_cpu (Waiman Long) [2141429]
- locking: Make owner_on_cpu() into <linux/sched.h> (Waiman Long) [2141429]
- locking/rwsem: Optimize down_read_trylock() under highly contended case (Waiman Long) [2141429]
- locking/rwsem: Fix comments about reader optimistic lock stealing conditions (Waiman Long) [2141429]
- locking/rwsem: Disable preemption for spinning region (Waiman Long) [2141429]
- locking: Remove rcu_read_{,un}lock() for preempt_{dis,en}able() (Waiman Long) [2141429]
- NFSD: Mark exports of NFS as unsupported (Benjamin Coddington) [2150902]
- fuse: lock inode unconditionally in fuse_fallocate() (Miklos Szeredi) [2110883]
- fuse: add file_modified() to fallocate (Miklos Szeredi) [2110883]
- mei: me: add adler lake point S DID (Prarit Bhargava) [2141602]
- ocfs2/dlm: move BITS_TO_BYTES() to bitops.h for wider use (Izabela Bakollari) [2144858]
- libnvdimm/namespace: Fix visibility of namespace resource attribute (Jeff Moyer) [2016347]
- PCI: hv: Only reuse existing IRTE allocation for Multi-MSI (Mohammed Gamal) [2139458]
- PCI: hv: Fix the definition of vector in hv_compose_msi_msg() (Mohammed Gamal) [2139458]
- PCI: hv: Take a const cpumask in hv_compose_msi_req_get_cpu() (Mohammed Gamal) [2139458]
- PCI: hv: Fix synchronization between channel callback and hv_pci_bus_exit() (Mohammed Gamal) [2139458]
- PCI: hv: Add validation for untrusted Hyper-V values (Mohammed Gamal) [2139458]
- PCI: hv: Fix interrupt mapping for multi-MSI (Mohammed Gamal) [2139458]
- PCI: hv: Reuse existing IRTE allocation in compose_msi_msg() (Mohammed Gamal) [2139458]
- PCI: hv: Fix hv_arch_irq_unmask() for multi-MSI (Mohammed Gamal) [2139458]
- PCI: hv: Fix synchronization between channel callback and hv_compose_msi_msg() (Mohammed Gamal) [2139458]
- PCI: hv: Use vmbus_requestor to generate transaction IDs for VMbus hardening (Mohammed Gamal) [2139458]
- PCI: hv: Fix multi-MSI to allow more than one MSI vector (Mohammed Gamal) [2139458]
- net: mana: Add rmb after checking owner bits (Mohammed Gamal) [2139462]
- net: mana: Add support of XDP_REDIRECT action (Mohammed Gamal) [2139462]
- net: mana: Add the Linux MANA PF driver (Mohammed Gamal) [2139462]
- NFSD: Protect against send buffer overflow in NFSv3 READ (Scott Mayhew) [2141774] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READ (Scott Mayhew) [2141774] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv3 READDIR (Scott Mayhew) [2141774] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READDIR (Scott Mayhew) [2141774] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_encode's buflen calculation (Scott Mayhew) [2141774] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_decode's end-of-buffer calculation (Scott Mayhew) [2141774] {CVE-2022-43945}
- KVM: VMX: fully disable SGX if SECONDARY_EXEC_ENCLS_EXITING unavailable (Emanuele Giuseppe Esposito) [2127128]
- cgroup/cpuset: Reduce cpuset_rwsem writer latency (Waiman Long) [2149031]
- rcu/exp: Mark current CPU as exp-QS in IPI loop second pass (Waiman Long) [2149031]
- rcu: Always inline rcu_dynticks_task*_{enter,exit}() (Waiman Long) [2149031]
- rcu: Fix existing exp request check in sync_sched_exp_online_cleanup() (Waiman Long) [2149031]
- rcu: Fix macro name CONFIG_TASKS_RCU_TRACE (Waiman Long) [2149031]
- rcu: Fix stall-warning deadlock due to non-release of rcu_node ->lock (Waiman Long) [2149031]
- rcu: Fix to include first blocked task in stall warning (Waiman Long) [2149031]
- cgroup: Use cgroup_attach_{lock,unlock}() from cgroup_attach_task_all() (Waiman Long) [2149031]
- cgroup: Add missing cpus_read_lock() to cgroup_attach_task_all() (Waiman Long) [2149031]
- cgroup: Fix threadgroup_rwsem <-> cpus_read_lock() deadlock (Waiman Long) [2149031]
- cgroup: Elide write-locking threadgroup_rwsem when updating csses on an empty subtree (Waiman Long) [2149031]
- cgroup/cpuset: Fix a race between cpuset_attach() and cpu hotplug (Waiman Long) [2149031]
- cgroup: reduce dependency on cgroup_mutex (Waiman Long) [2149031]

* Mon Dec 12 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-444.el8]
- drm/i915: fix TLB invalidation for Gen12 video and compute engines (Wander Lairson Costa) [2148150] {CVE-2022-4139}
- redhat/configs: Set CONFIG_X86_AMD_PSTATE to 'm' (Prarit Bhargava) [2145246]
- bonding: uninitialized variable in bond_miimon_inspect() (Jonathan Toppins) [1973124]
- bonding: fix link recovery in mode 2 when updelay is nonzero (Jonathan Toppins) [1973124]
- RHEL: ALSA: update configuration (Jaroslav Kysela) [2125544]
- RHEL: ALSA: fix compilation issues (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: pci-mtl: fix firmware name (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Correct pin configs for ASUS G533Z (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: remove ALC289_FIXUP_DUAL_SPK for Dell 5530 (Jaroslav Kysela) [2125544]
- ALSA: ac97: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125544]
- ALSA: ca0106: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125544]
- ALSA: emu10k1: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125544]
- ALSA: control: add snd_ctl_rename() (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: Use only dynamic PCM device allocation (Jaroslav Kysela) [2125544]
- regmap: add reg_sequence helpers (Jaroslav Kysela) [2125544]
- regmap: fix the kerneldoc for regmap_test_bits() (Jaroslav Kysela) [2125544]
- regmap: provide helpers for simple bit operations (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Free the ida when IPC fails in sof_ipc4_widget_setup() (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic31xx: Handle BCLK set as PLL input configuration (Jaroslav Kysela) [2125544]
- ASoC: test-component: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic31xx: Add support for pll_r coefficient (Jaroslav Kysela) [2125544]
- ASoC: ssm4567: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: rk3328: fix disabling mclk on pclk probe failure (Jaroslav Kysela) [2125544]
- ASoC: pcm3060: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: cs42l42: remove redundant test (Jaroslav Kysela) [2125544]
- ALSA: ppc: beep: fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2125544]
- ASoC: soc-component: Add comment for the endianness flag (Jaroslav Kysela) [2125544]
- ASoC: codecs: wsa881x: handle timeouts in resume path (Jaroslav Kysela) [2125544]
- ASoC: wsa881x: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: codecs: wsa881x: add runtime pm support (Jaroslav Kysela) [2125544]
- ASoC: wm_adsp: Fix event generation for wm_adsp_fw_put() (Jaroslav Kysela) [2125544]
- ASoC: wm_adsp: Minor clean and redundant code removal (Jaroslav Kysela) [2125544]
- ASoC: wm_adsp: Compressed stream DSP memory structs should be __packed (Jaroslav Kysela) [2125544]
- ASoC: wm8998: Fix event generation for input mux (Jaroslav Kysela) [2125544]
- ASoC: arizona: Fix a wrong free in wm8997_probe (Jaroslav Kysela) [2125544]
- ASoC: wm8962: Allow switching between analog and digital inputs (Jaroslav Kysela) [2125544]
- ASoC: wm8960: Fix clock configuration on slave mode (Jaroslav Kysela) [2125544]
- ASoC: wm8962: Fix suspend while playing music (Jaroslav Kysela) [2125544]
- ASoC: codecs: wm8962: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125544]
- ASoC: wm8960: Add ACPI support (Jaroslav Kysela) [2125544]
- ASoC: wm8958: Fix change notifications for DSP controls (Jaroslav Kysela) [2125544]
- ASoC: wm8940: add devicetree support (Jaroslav Kysela) [2125544]
- ASoC: wm*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: wm8903: Fix the error handling of wm8903_i2c_probe() (Jaroslav Kysela) [2125544]
- ASoC: wm8731: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: arizona: Make the wm5102, wm5110, wm8997 and wm8998 drivers use the new jack library (Jaroslav Kysela) [2125544]
- ASoC: wm5102: Fix event generation for output compensation (Jaroslav Kysela) [2125544]
- ASoC: wcd9335: Use int array instead of bitmask for TX mixers (Jaroslav Kysela) [2125544]
- ASoC: wcd9335: Use DT bindings instead of local DAI definitions (Jaroslav Kysela) [2125544]
- ASoC: wcd9335: Fix spurious event generation (Jaroslav Kysela) [2125544]
- ASoC: wcd9335: Remove RX channel from old list before adding it to a new one (Jaroslav Kysela) [2125544]
- ASoC: codecs: wcd9335: move gains from SX_TLV to S8_TLV (Jaroslav Kysela) [2125544]
- ASoC: wcd9335: remove redundant tests (Jaroslav Kysela) [2125544]
- ASoC: uda1380: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: twl4030: Drop legacy, non DT boot support (Jaroslav Kysela) [2125544]
- ASoC: tscs*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: ts3a227e: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: tpa6130: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: tlv320dac3x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic33: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: codec: tlv320aic32x4: fix mono playback via I2S (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic32x4: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic31xx: Fix typo in BCLK clock name (Jaroslav Kysela) [2125544]
- ASoC: tlv320*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: Rename tlv320aic31xx-micbias.h as tlv320aic31xx.h (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic31xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic26: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tlv320aic23: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tlv320*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: tas6424: Return zero in remove callback (Jaroslav Kysela) [2125544]
- ASoC: tda7419: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: tas6424: Fix the error handling of tas6424_i2c_probe() (Jaroslav Kysela) [2125544]
- ASoC: tas6424: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tas5720: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tas571x: Fix the error handling of tas571x_i2c_probe() (Jaroslav Kysela) [2125544]
- ASoC: tas5086: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tas2552: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: tas2770: Reinit regcache on reset (Jaroslav Kysela) [2125544]
- ASoC: tas2562: Propagate the error in tas2562_dac_event() (Jaroslav Kysela) [2125544]
- ASoC: tas2562: Fix mute/unmute (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Fix mute/unmute (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Allow mono streams (Jaroslav Kysela) [2125544]
- ASoC: tas2770: Fix handling of mute/unmute (Jaroslav Kysela) [2125544]
- ASoC: tas2770: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2125544]
- ASoC: tas2770: Allow mono streams (Jaroslav Kysela) [2125544]
- ASoC: tas2770: Set correct FSYNC polarity (Jaroslav Kysela) [2125544]
- ASoC: tas2770: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tas*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: tas2552: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: sta350: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: sta350: Remove redundant big endian formats (Jaroslav Kysela) [2125544]
- ASoC: sta*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: sta32x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: sta32x: Remove redundant big endian formats (Jaroslav Kysela) [2125544]
- ASoC: ssm2602: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: ssm2518: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: sgtl5000: Fix noise on shutdown/remove (Jaroslav Kysela) [2125544]
- ASoC: rt9120: Fix 3byte read, valule offset typo (Jaroslav Kysela) [2125544]
- ASoC: rt9120: Use pm_runtime and regcache to optimize 'pwdnn' logic (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt715-sdca: remove useless assignment of ops (Jaroslav Kysela) [2125544]
- ASoC: rt5682s: Separate the regulator consumer controls (Jaroslav Kysela) [2125544]
- ASoC: rt5645: Fix the error handling of rt5645_i2c_probe() (Jaroslav Kysela) [2125544]
- ASoC: rt5640: Fix the issue of the abnormal JD2 status (Jaroslav Kysela) [2125544]
- ASoC: rt5640: Fix the JD voltage dropping issue (Jaroslav Kysela) [2125544]
- ASoC: rt5640: Fix the wrong state of JD1 and JD2 (Jaroslav Kysela) [2125544]
- ASoC: rt5640: Add the MICBIAS1 to the dapm routing (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt298: Fix jack detection (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt298: Fix NULL jack in interrupt (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt298: Set component to NULL on remove (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt286: Set component to NULL on remove (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt274: Set component to NULL on remove (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt274: Always init jack_detect_work (Jaroslav Kysela) [2125544]
- ASoC: rt1308-sdw: add the default value of register 0xc320 (Jaroslav Kysela) [2125544]
- ASoC: rk3328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: pcm1789: Make pcm1789_common_exit() return void (Jaroslav Kysela) [2125544]
- ASoC: pcm186x: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: pcm186x: simplify the return expression of pcm186x_power_off() (Jaroslav Kysela) [2125544]
- ASoC: pcm*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: nau8825: Implement hw constraint for rates (Jaroslav Kysela) [2125544]
- ASoC: nau8825: Declare 2 channels for DAI of capture stream (Jaroslav Kysela) [2125544]
- ASoC: nau8824: Fix semaphore is released unexpectedly (Jaroslav Kysela) [2125544]
- ASoC: nau8824: Implement hw constraint for rates (Jaroslav Kysela) [2125544]
- ASoC: nau8824: Fix semaphore unbalance at error paths (Jaroslav Kysela) [2125544]
- ASoC: nau8822: Don't reconfigure PLL to the same values (Jaroslav Kysela) [2125544]
- ASoC: nau8822: Disable internal PLL if freq_out is zero (Jaroslav Kysela) [2125544]
- ASoC: nau8821: Implement hw constraint for rates (Jaroslav Kysela) [2125544]
- ASoC: nau8821: Don't unconditionally free interrupt (Jaroslav Kysela) [2125544]
- ASoC: nau8821: add new widget to control system clock (Jaroslav Kysela) [2125544]
- ASoC: nau8821: Add headset button detection (Jaroslav Kysela) [2125544]
- ASoC: codecs: mt6359-accdet: remove useless initialization (Jaroslav Kysela) [2125544]
- ASoC: mediatek: mt6366: support for mt6366 codec (Jaroslav Kysela) [2125544]
- ASoC: msm8916-wcd-digital: Check failure for devm_snd_soc_register_component (Jaroslav Kysela) [2125544]
- ASoC: nau8540: Implement hw constraint for rates (Jaroslav Kysela) [2125544]
- ASoC: nau8*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: mt6660: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: mt6359: Fix refcount leak bug (Jaroslav Kysela) [2125544]
- ASoC: mediatek: mt6358: add missing EXPORT_SYMBOLs (Jaroslav Kysela) [2125544]
- ASoC: msm8916-wcd-digital: Fix missing clk_disable_unprepare() in msm8916_wcd_digital_probe (Jaroslav Kysela) [2125544]
- ASoC: codecs: msm8916-wcd-digital: move gains from SX_TLV to S8_TLV (Jaroslav Kysela) [2125544]
- ASoC: ml26124: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: max98390: use linux/gpio/consumer.h to fix build (Jaroslav Kysela) [2125544]
- ASoC: max98390: Add reset gpio control (Jaroslav Kysela) [2125544]
- ASoC: codecs: soundwire: call pm_runtime_resume() in component probe (Jaroslav Kysela) [2125544]
- ASoC: max98373: Removing 0x203E from the volatile reg (Jaroslav Kysela) [2125544]
- ASoC: max98090: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: max98090: Fix event generation for custom controls (Jaroslav Kysela) [2125544]
- ASoC: codecs: max98088: Clean up some inconsistent indenting (Jaroslav Kysela) [2125544]
- ASoC: max980*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: lm4857: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: da732x: Drop no-op remove function (Jaroslav Kysela) [2125544]
- ASoC: da7219: Drop no-op remove function (Jaroslav Kysela) [2125544]
- ASoC: max9*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: lm49xxx: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: hdmi-codec: Remove redundant big endian formats (Jaroslav Kysela) [2125544]
- ASoC: es83*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: codes: Add support for ES8316 producer mode (Jaroslav Kysela) [2125544]
- ASoC: dmic: Add support for DSD data format (Jaroslav Kysela) [2125544]
- ASoC: da[79]*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: da7219: cancel AAD related work earlier for jack removal (Jaroslav Kysela) [2125544]
- ASoC: da7219: Fix pole orientation detection on certain headsets (Jaroslav Kysela) [2125544]
- ASoC: da7218: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: cx2072x: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: cx2072x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: cs4349: Remove redundant big endian formats (Jaroslav Kysela) [2125544]
- ASoC: cs42l56: Fix the error handling of cs42l56_i2c_probe() (Jaroslav Kysela) [2125544]
- ASoC: cs42l51: Remove redundant big endian formats (Jaroslav Kysela) [2125544]
- ASoC: cs42l42: Only report button state if there was a button interrupt (Jaroslav Kysela) [2125544]
- ASoC: cs4270: update kernel-doc (Jaroslav Kysela) [2125544]
- ASoC: cs4270: Remove redundant big endian formats (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Add support for CLSA3541 ACPI device ID (Jaroslav Kysela) [2125544]
- ALSA: cs35l41: Enable Internal Boost in shared lib (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Do not print error when waking from hibernation (Jaroslav Kysela) [2125544]
- ASoC: cs35l36: Fix the error handling of cs35l36_i2c_probe() (Jaroslav Kysela) [2125544]
- ASoC: cs*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: arizona: Update arizona_aif_cfg_changed to use RX_BCLK_RATE (Jaroslav Kysela) [2125544]
- ASoC: alc56*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: ak4613: cares Simple-Audio-Card case for TDM (Jaroslav Kysela) [2125544]
- ASoC: ak4613: add TDM256 support (Jaroslav Kysela) [2125544]
- ASoC: ak4613: rename constraint to constraint_rates (Jaroslav Kysela) [2125544]
- ASoC: ak4613: priv has ctrl1 instead of iface (Jaroslav Kysela) [2125544]
- ASoC: ak4613: return error if it was setup as clock provider (Jaroslav Kysela) [2125544]
- ASoC: ak4613: tidyup ak4613_interface (Jaroslav Kysela) [2125544]
- ASoC: ak4613: add missing mutex_lock() (Jaroslav Kysela) [2125544]
- ASoC: ak4642: Drop no-op remove function (Jaroslav Kysela) [2125544]
- ASoC: ak*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: ak4*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: adau1761: Add ADAU1761-as-ADAU1361 compatibility mode (Jaroslav Kysela) [2125544]
- ASoC: ada*, ssm*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: ab8500: Remove some leftover from the "Replace GPLv2 boilerplate/reference with SPDX" rules (Jaroslav Kysela) [2125544]
- ASoC: ad1*, ada*, ssm*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125544]
- ASoC: test-component: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125544]
- ASoC: simple-card-utils: rename asoc_simple_init_dai_link_params() to asoc_simple_init_for_codec2codec() (Jaroslav Kysela) [2125544]
- ASoC: simple-card-utils.c: care Codec2Codec vs DPCM:BE (Jaroslav Kysela) [2125544]
- ASoC: simple-card-utils.c: ignore Codec2Codec setting if it already have (Jaroslav Kysela) [2125544]
- ASoC: simple-card-utils: Make asoc_simple_clean_reference() return void (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card2: indicate "Experimental stage" warning only when successed (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card2: Add of_node_put() in fail path (Jaroslav Kysela) [2125544]
- ASoc: audio-graph-card2: Fix refcount leak bug in __graph_get_type() (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card2.c: remove pre-alloced Codec2Codec space (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card2.c: make Codec2Codec settings optional (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card2.c: use of_property_read_u32() for rate (Jaroslav Kysela) [2125544]
- ASoC: audio_graph_card2: Fix port numbers in example (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card2-custom-sample.dtsi: add verbose explanation (Jaroslav Kysela) [2125544]
- ASoC: audio-graph-card: Add of_node_put() in fail path (Jaroslav Kysela) [2125544]
- ASoC: test-component: Update to use set_fmt_new callback (Jaroslav Kysela) [2125544]
- ASoC: Intel: boards: use software node API in Atom boards (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_ssp_amp: remove 'set-but-not-used' warning (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_sdw: avoid oops in error handling (Jaroslav Kysela) [2125544]
- ASoC: Intel: use software node API in SoundWire machines (Jaroslav Kysela) [2125544]
- ASoC: Intel: boards: sof_sdw: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: Intel: catpt: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: Intel: catpt: Drop redundant enum constant (Jaroslav Kysela) [2125544]
- ASoC: Intel: catpt: remove duplicating driver data retrieval (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_ssp_amp: enable capture stream from cs35l41 (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_sdw: allow HDaudio/HDMI disable (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_sdw: add quirk for HP Omen 16-k0005TX (Jaroslav Kysela) [2125544]
- ASoC: intel: sof_sdw: add RT711 SDCA card for MTL platform (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_pcm512x: remove unnecessary init (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_nau8825: Move quirk check to the front in late probe (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_sdw: add support for Dell SKU 0AFF (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_sdw: add support for Dell SKU 0AF0 (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_rt5682: Perform quirk check first in card late probe (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_rt5682: Add support for mtl_mx98357_rt5682 (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_rt5682: fix out-of-bounds array access (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_rt5682: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: boards: rename RTL1019 compatible driver to rt1019p (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_nau8825: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: kbl_da7219_max98927: remap jack pins (Jaroslav Kysela) [2125544]
- ALSA: x86: intel_hdmi_audio: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ALSA: x86: intel_hdmi_audio: enable pm_runtime and set autosuspend delay (Jaroslav Kysela) [2125544]
- ASoC: xtensa: Update to use set_fmt_new callback (Jaroslav Kysela) [2125544]
- ASoC: xtensa: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: uniphier: make arrays mul and div static const, makes object smaller (Jaroslav Kysela) [2125544]
- ASoC: uniphier: simplify the return expression of uniphier_aio_compr_set_params() (Jaroslav Kysela) [2125544]
- ASoC: spear: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-topology: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-stream: test DMA buffer first in hw_params (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-stream: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-ipc: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dsp: report error on power-up/down (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: Drop misleading comment regarding dma_data (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: Intel: fix sof_es8336 probe (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_es8336: remove hard-coded SSP selection (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_es8336: reset the num_links during probe (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_es8336: add support for HDMI_In capture (Jaroslav Kysela) [2125544]
- ASoC: Intel: common: fix typo for tplg naming (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_rt5682: Add support for adl_rt1019_rt5682s (Jaroslav Kysela) [2125544]
- ASoC: Intel: soc-acpi: add table for HP Omen 16-k0005TX (Jaroslav Kysela) [2125544]
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in ADL match table (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_es8336: ignore GpioInt when looking for speaker/headset GPIO lines (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_es8336: Fix GPIO quirks set via module option (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_da7219_max98373: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_cs42l42: add adl_mx98360a_cs4242 board config (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_cs42l42: support BT offload audio (Jaroslav Kysela) [2125544]
- ASoC: Intel: sof_cs42l42: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: skl_nau88l25_ssm4567: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: skl_nau88l25_max98357a: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: kbl_rt5663_rt5514_max98927: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: kbl_rt5663_max98927: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: kbl_da7219_max98357a: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: boards: hda: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: Intel: glk_rt5682_max98357a: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: cml_rt1011_rt5682: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: boards: Use temporary variable for struct device (Jaroslav Kysela) [2125544]
- ASoC: Intel: boards: reset acpi_chan_package (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt298: Reorganize jack detect handling (Jaroslav Kysela) [2125544]
- ASoC: Intel: bxt_da7219_max98357a: remap jack pins (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Improve hw_params() debug-ability (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Improve probe() function quality (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Update file comments (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Update code indentation (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Reword driver name (Jaroslav Kysela) [2125544]
- ASoC: Intel: hsw_rt5640: Reword prefixes of all driver members (Jaroslav Kysela) [2125544]
- ASoC: Intel: Rename haswell source file to hsw_rt5640 (Jaroslav Kysela) [2125544]
- ASoC: Intel: atom: sst_ipc: remove redundant test (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Remove FE DAI ops (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Improve codec_init() quality (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Improve hw_params() debug-ability (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Improve probe() function quality (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Update file comments (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Update code indentation (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Reword driver name (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt286: Reword prefixes of all driver members (Jaroslav Kysela) [2125544]
- ASoC: Intel: Rename broadwell source file to bdw_rt286 (Jaroslav Kysela) [2125544]
- ASoC: codecs: rt286: Reorganize jack detect handling (Jaroslav Kysela) [2125544]
- ASoC: Intel: broadwell: Make broadwell_disable_jack() return void (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt5677: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125544]
- ASoC: Intel: bdw_rt5650: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125544]
- ASoC: Intel: atom: sst_ipc: remove useless initializations (Jaroslav Kysela) [2125544]
- ASoC: Intel: atom: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: Intel: atom: sst: remove useless initialization (Jaroslav Kysela) [2125544]
- ASoC: intel: atom: Remove superfluous flush_scheduled_work() (Jaroslav Kysela) [2125544]
- ASoC: Intel: Update to use set_fmt_new callback (Jaroslav Kysela) [2125544]
- ASoC: Intel: atom: controls: remove useless initializations (Jaroslav Kysela) [2125544]
- ASoC: Intel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: Intel: skylake: skl-pcm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: Intel: Skylake: remove redundant re-assignments to pointer array (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: bdw: remove duplicating driver data retrieval (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: byt: remove duplicating driver data retrieval (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: cnl: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: Do snd_hdac_ext_stream_decouple() only once (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: add sanity check on SSP index reported by NHLT (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: only fixup topology name if not set already (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: don't set fw_filename (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: enable dmic handling with 2 or fewer SoundWire links (Jaroslav Kysela) [2125544]
- ASoC: soc-core: accept zero format at snd_soc_runtime_set_dai_fmt() (Jaroslav Kysela) [2125544]
- ASoC: SOF: compress: Prevent current kernel running with older FW (Jaroslav Kysela) [2125544]
- ASoC: SOF: Copy compress parameters into extended data (Jaroslav Kysela) [2125544]
- ASoC: SOF: compress: Dynamically allocate pcm params struct (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: atom: don't keep a temporary string in fixup_tplg_name (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: add trigger callback into sdw_callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: Correct the ROM/FW state reporting code (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: MTL: remove redundant snd_sof_dsp_read() call (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: mtl: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: mtl: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: Introduce skip_imr_boot flag (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: disable IMR boot when resuming from ACPI S4 and S5 states (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: IPC4: enable IMR boot (Jaroslav Kysela) [2125544]
- ASoC: SOC: Intel: introduce cl_init callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: Do not (wrongly) assume positive return value in IMR path (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: Revisit IMR boot sequence (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-loader: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-loader: Print out the non matching ext_man magic number (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-topology: Fix clang -Wformat warning (Jaroslav Kysela) [2125544]
- ASoC: SOF: remove warning on ABI checks (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Fix error code in sof_ipc4_volume_put() (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-pcm: set pcm rate to dai setting (Jaroslav Kysela) [2125544]
- ASoC: SOF: reduce default verbosity of IPC logs (Jaroslav Kysela) [2125544]
- Revert "RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default" (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: fix alh_group_ida max value (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: fix wrong use of sizeof in sof_ipc4_widget_setup_comp_src() (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: set domain bit based on dp domain type (Jaroslav Kysela) [2125544]
- ASoC: SOF: add ipc4 SRC module support (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: move ida allocate/free to widget_setup/free (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: free memories allocated in sof_ipc4_get_audio_fmt (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: check dai->private in ipc_free() (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: add SoundWire/ALH aggregation support (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ASoC: SOF: Compile and runtime IPC version selection (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Align mt8186 clock names with dt-bindings (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Fix error code in probe (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Revise mt8195 boot flow (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: fix mt8195 StatvectorSel wrong setting (Jaroslav Kysela) [2125544]
- ASoC: SOF: pcm: use pm_resume_and_get() on component probe (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: fix copy in sof_msg_inject_ipc4_dfs_write() (Jaroslav Kysela) [2125544]
- ASoC: sof: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client-probes: Only load the driver if IPC3 is used (Jaroslav Kysela) [2125544]
- ASoC: SOF: probes: rename assign/free callbacks as startup/shutdown (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add cont_update_posn to platform parameters (Jaroslav Kysela) [2125544]
- ASoC: SOF: pm: add definitions for S4 and S5 states (Jaroslav Kysela) [2125544]
- ASoC: SOF: pm: add explicit behavior for ACPI S1 and S2 (Jaroslav Kysela) [2125544]
- ASoC: SOF: debug: Clarify the IPC timeout handling path (Jaroslav Kysela) [2125544]
- ASoC: SOF: topology: remove unused variable (Jaroslav Kysela) [2125544]
- ASoC: SOF: Switch to IPC generic firmware tracing (Jaroslav Kysela) [2125544]
- ALSA: sc6000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2125544]
- ALSA: gus: Fix memory leaks at memory allocator error paths (Jaroslav Kysela) [2125544]
- ALSA: sound/isa/gus: check the return value of kstrdup() (Jaroslav Kysela) [2125544]
- ALSA: gus: Fix erroneous memory allocation (Jaroslav Kysela) [2125544]
- ALSA: galaxy: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2125544]
- ALSA: cs4236: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2125544]
- ALSA: aloop: Fix random zeros in capture data when using jiffies timer (Jaroslav Kysela) [2125544]
- ALSA: Add generic serial MIDI driver using serial bus API (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Use lookup table to create modules (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Update AVS_FW_INIT_TIMEOUT_US declaration (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Lower UNLOAD_MULTIPLE_MODULES IPC timeout (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Replace hardcodes with SD_CTL_STREAM_RESET (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Recognize FW_CFG_RESERVED (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Use helper function to set up DMA (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Set max DMA segment size (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Block IPC channel on suspend (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Shield LARGE_CONFIG_GETs against zero payload_size (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Copy only as many RX bytes as necessary (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Relax DSP core transition timings (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Assign I2S gateway when parsing topology (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Fix i2s_test card name initialization (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: correct config reference for I2S test board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Fix parsing UUIDs in topology (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add da7219 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add max98373 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add max98357a machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add ssm4567 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add nau8825 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add rt5682 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add rt298 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add rt286 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add rt274 machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add I2S-test machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add DMIC machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Fix build error on arc, m68k and sparc (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: APL-based platforms support (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: SKL-based platforms support (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Power management (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Machine board registration (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Replace link_mask usage with i2s_link_mask (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Event tracing (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: D0ix power state support (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Prepare for firmware tracing (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Register HDAudio ext-bus operations (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add HDAudio machine board (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: PCI driver implementation (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Coredump and recovery flow (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Drop direct ACPI dependency (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Depend on SND_INTEL_DSP_CONFIG (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Enable AVS driver only on x86 platforms (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: HDA PCM BE operations (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: non-HDA PCM BE operations (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Generic PCM FE operations (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Generic soc component driver (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Account for libraries when booting basefw (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Configure modules according to their type (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Prepare modules before bindings them (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Arm paths after creating them (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Path state management (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Path creation and freeing (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Declare path and its components (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Support link_mask formatted string (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add topology loading operations (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Parse path and path templates tuples (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Parse pipeline and module tuples (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Parse pplcfg and binding tuples (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Parse module-extension tuples (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Add topology parsing infrastructure (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: add MeteorLake machines (Jaroslav Kysela) [2125544]
- ASoC: Intel: avs: Declare vendor tokens (Jaroslav Kysela) [2125544]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK_AON bit (Jaroslav Kysela) [2125544]
- uapi: sof: abi: Bump SOF ABI for ext_data_length (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add two new structures for topology manifest data (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: introduce cont_update_posn in sof_ipc_stream_params struct (Jaroslav Kysela) [2125544]
- ASoC: SOF: bump SOF_ABI_MINOR (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add header for IPC4 manifest (Jaroslav Kysela) [2125544]
- ASoC: SOF: topology: add code to parse config params for ACPDMIC dai (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add topology tokens for IPC4 (Jaroslav Kysela) [2125544]
- ASoC: hdac_hda: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: max98504: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: adau1372: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: cx2072x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: mt6351: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: mt6358: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: mt6359: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: mt6660: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: pcm3060: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt9120: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: wcd9335: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt700: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt715: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt715-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt1308-sdw: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt1316-sdw: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: wsa881x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: sdw-mockup: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: lochnagar: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: lochnagar: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: tfa*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: tfa9879: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125544]
- ASoC: tlv320*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: cs*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: wm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: wm9090: Remove redundant endianness flag (Jaroslav Kysela) [2125544]
- ASoC: wm8731: Factor out the I2C and SPI bus code into separate modules (Jaroslav Kysela) [2125544]
- ASoC: wm8731: Factor our MCLK and mutex initialisation (Jaroslav Kysela) [2125544]
- ASoC: wm8731: Move regulator request into wm8731_init() (Jaroslav Kysela) [2125544]
- ASoC: wm8731: Factor component init out of bus code (Jaroslav Kysela) [2125544]
- ASoC: wm8731: Update to modern DAI terminology (Jaroslav Kysela) [2125544]
- ASoC: wm2000: fix missing clk_disable_unprepare() on error in wm2000_anc_transition() (Jaroslav Kysela) [2125544]
- ASoC: wm2000: Remove redundant endianness flag (Jaroslav Kysela) [2125544]
- ASoC: wm*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Fix amp gain register offset & default (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Correct playback volume range (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Fix and extend FSYNC polarity handling (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Add post reset delays (Jaroslav Kysela) [2125544]
- ASoC: tas*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: tas*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: tas2764: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [2125544]
- ASoC: tas*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [2125544]
- ASoC: tas2764: Add the driver for the TAS2764 (Jaroslav Kysela) [2125544]
- ASoC: max98396: Fix TDM mode BSEL settings (Jaroslav Kysela) [2125544]
- ASoC: max*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: max98396: Implement DSP speaker monitor (Jaroslav Kysela) [2125544]
- ASoC: max98396: Fix register access for PCM format settings (Jaroslav Kysela) [2125544]
- ASoC: max98396: Improve some error prints (Jaroslav Kysela) [2125544]
- ASoC: max98396: add voltage regulators (Jaroslav Kysela) [2125544]
- ASoC: max98396: Fix build error for implicit function declaration (Jaroslav Kysela) [2125544]
- ASoC: max98396: add amplifier driver (Jaroslav Kysela) [2125544]
- ASoC: rt*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: rt1019: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: rt*: use simple i2c probe function (Jaroslav Kysela) [2125544]
- ASoC: fsl: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: pistachio: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: samsung: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: sunxi: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: tegra: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: test-component: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: uniphier: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ad*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ak*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: alc*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: da*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: es*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: msm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: nau*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: pcm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: spdif: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ssm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: sta*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: twl*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: uda*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: 88pm860x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ab8500: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ac97: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ads117x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: bd28623: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: bt-sco: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: cpcap: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: cq93vc: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: cx20442: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: dmic: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: gtm601: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: hdac_hdmi: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: hdmi-codec: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ics43432: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: inno_rk3036: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: isabelle: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: jz4740: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: lm49453: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: mc13783: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: ml26124: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: sgtl5000: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: si476x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: stac9766: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: sti-sas: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: tscs42xx: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: wl1273: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: zl38060: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: fsl_micfil: Add legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: fsl_asrc_dma: Add legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: soc-component: Remove non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: simple-card-utils: Move snd_soc_component_is_codec to be local (Jaroslav Kysela) [2125544]
- ASoC: soc-component: Add legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: core: Add new SOC_DOUBLE_SX_TLV macro (Jaroslav Kysela) [2125544]
- ASoC: Remove unused hw_write_t type (Jaroslav Kysela) [2125544]
- ASoC: soc.h: Add SOC_SINGLE_S_EXT_TLV macro (Jaroslav Kysela) [2125544]
- ASoC: soc.h: Introduce SOC_DOUBLE_R_S_EXT_TLV() macro (Jaroslav Kysela) [2125544]
- ASoC: soc.h: Add SOC_SINGLE_S_TLV() macro (Jaroslav Kysela) [2125544]
- ASoC: hdmi-codec: Update to modern DAI terminology (Jaroslav Kysela) [2125544]
- ALSA: hda: Skip event processing for unregistered codecs (Jaroslav Kysela) [2125544]
- ASoC: codecs: Add HD-Audio codec driver (Jaroslav Kysela) [2125544]
- ASoC: cs42l42: Move CS42L42 register descriptions to general include (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Read System Name from ACPI _SUB to identify firmware (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Add common cs35l41 enter hibernate function (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Move cs35l41 exit hibernate function into shared code (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Move cs_dsp config struct into shared code (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Move cs35l41 fs errata into shared code (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Move cs35l41_set_cspl_mbox_cmd to shared code (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125544]
- ASoC: cs35l41: Support external boost (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: Add support for MeteorLake (MTL) (Jaroslav Kysela) [2125544]
- treewide: Replace zero-length arrays with flexible-array members (Jaroslav Kysela) [2125544]
- ASoC: SOF: add definitions for different IPC types (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: enhance debug messages (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: SOF: IPC4: add sdw blob (Jaroslav Kysela) [2125544]
- AsoC: SOF: ipc4-topology: Add dai_get_clk op (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add support for SSP/DMIC DAI's (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add a new IPC op for parsing topology manifest (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: init NHLT for IPC4 (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add ops_free (Jaroslav Kysela) [2125544]
- ASoC: SOF: IPC4: set the BE DAI ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-pcm: Expose sof_ipc4_set_pipeline_state() (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add the dai_config op (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add route_setup/route_free ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add widget_setup/widget_free ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: IPC4: Add pcm ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add control IO ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add control_setup op (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add support for parsing mixer widgets (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add support for parsing and preparing pga widgets (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add prepare op for DAI type widgets (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add prepare op for AIF type widgets (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add support for parsing DAI_IN/DAI_OUT widgets (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4-topology: Add support for parsing AIF_IN/AIF_OUT widgets (Jaroslav Kysela) [2125544]
- ASoC: SOF: IPC4: Introduce topology ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: Return from dtrace_read if there is no new data available (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: Add helper function to update the sdev->host_offset (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: Introduce SOF_DTRACE_INITIALIZING state (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4: implement pm ctx_save callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: Switch to use the generic pm_ops.set_core_state (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4: Add set_core_state pm_ops implementation (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add initial header file for ipc4 (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Add set_core_state pm_ops implementation (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof_ipc_pm_ops: Add support for DSP core power management (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: mt8195 suspend check dsp idle (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: mt8195 modify dram type as non-cache (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add shared_size for mediatek common chip information (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: revise mt8195 clock sequence (Jaroslav Kysela) [2125544]
- ASoC: SOF: amd: Add SOF pm ops callback for Renoir (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: Fix reversed if statement (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: Propagate write errors correctly (Jaroslav Kysela) [2125544]
- ASoC: SOF: Fix potential NULL pointer dereference (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client-ipc-flood-test: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: remove duplicate include in mt8195.c (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add mt8195 debug dump (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add mediatek common debug dump (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: Move dtrace related variables local from sof_dev (Jaroslav Kysela) [2125544]
- ASoC: SOF: Introduce opaque storage of private data for firmware tracing (Jaroslav Kysela) [2125544]
- ASoC: SOF: Modify the host trace_init parameter list to include dmab (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-dtrace: Move host ops wrappers from generic header to private (Jaroslav Kysela) [2125544]
- ASoC: SOF: Clone the trace code to ipc3-dtrace as fw_tracing implementation (Jaroslav Kysela) [2125544]
- ASoC: SOF: Rename dtrace_is_supported flag to fw_trace_is_supported (Jaroslav Kysela) [2125544]
- ASoC: SOF: Introduce IPC independent ops for firmware tracing support (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: Cap the rmaining to count in IPC4 mode (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add mt8186 ipc support (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add ipc support for mt8195 (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: HDA: Set up sof_ipc4_fw_data for IPC4 (Jaroslav Kysela) [2125544]
- ASoC: SOF: IPC4: Add FW loader ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add IPC4 private header (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: HDA: Set IPC4-specific DSP ops for CaVS platforms (Jaroslav Kysela) [2125544]
- ASoC: SOF: trace: The dtrace is only available with SOF_IPC (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client: IPC flood test can only work with SOF_IPC (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: Add support for IPC4 messages (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: Separate the message sending (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client: Add support IPC4 message sending (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client: Add API to get the ipc_type (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client-probes: Query the maximum IPC payload size (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc-msg-injector: Query the maximum IPC payload size (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client: Add API to get the maximum IPC payload size (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc4: Add support for mandatory message handling functionality (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add rx_data pointer to snd_sof_ipc_msg struct (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Remove the ipc3-ops.h header file (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-pci-dev: fix missing pci_release_regions() on error in sof_pci_probe() (Jaroslav Kysela) [2125544]
- ASoC: SOF: loader: Call optional query_fw_configuration on first boot (Jaroslav Kysela) [2125544]
- ASoC: SOF: loader: Remove snd_sof_parse_module_memcpy() as it is not used (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: mt8195: Do not set the load_module ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: bdw/byt/pci-tng: Do not set the load_module ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: imx: Do not set the load_module ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: amd: renoir: Do not set the load_module ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: loader: Switch to use the fw_loader ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Add check for fw_loader ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3-loader: Implement firmware parsing and loading (Jaroslav Kysela) [2125544]
- ASoC: SOF: Introduce IPC dependent ops for firmware handling, loading (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add a prepare op to IPC topology widget ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: clarify use of widget complete flag (Jaroslav Kysela) [2125544]
- ASoC: SOF: topology: Skip parsing DAI link tokens if not needed (Jaroslav Kysela) [2125544]
- ASoC: SOF: pcm: remove unnecessary function declaration (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add two new fields to struct snd_sof_widget (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add a route_free op in struct sof_ipc_tplg_ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: expose a couple of functions (Jaroslav Kysela) [2125544]
- ASoC: SOF: pcm: Move the call to snd_sof_pcm_platform_hw_params() (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-audio: Set up widgets from source to sink (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-audio: reset route status before freeing widget (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add a new op to set up volume table (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Fix allyesconfig build error (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: mt8195 change ipc timeout as 1 second (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-client-ipc-msg-injector: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: SOF: debug: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: SOF: control: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8186 (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add mt8186 dsp clock support (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add mt8186 sof fw loader and dsp ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: Add mt8186 hardware support (Jaroslav Kysela) [2125544]
- ASoC: SOF: loader: Remove the old fw_ready related code (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: Do not set fw_ready callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: imx: Do not set fw_ready callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: amd: Do not set fw_ready callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: Do not check for the fw_ready callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Add local implementation for handling fw_ready message (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: protect hw_params against successive calls (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: add helper for link DMA cleanups (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: reset dma_data and release stream (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: improve suspend case (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: move code to deal with hda dai/dailink suspend (Jaroslav Kysela) [2125544]
- ASOC: SOF: Intel: hda-dai: add hda_dai_hw_free_ipc() helper (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-audio: flag errors on pipeline teardown (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: regroup dai and link DMA operations (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: split link DMA and dai operations (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: use snd_soc_dai_get_widget() helper (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-dai: simplify hda_dai_widget_update() prototype (Jaroslav Kysela) [2125544]
- ASOC: SOF: Intel: hda-dai: consistent naming for HDA DAI and HDA link DMA (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: Add IPC-specific dai ops for IPC3 (Jaroslav Kysela) [2125544]
- ASoC: SOF: remove incorrect clearing of prepared flag (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: simplify NHLT handling (Jaroslav Kysela) [2125544]
- ASoC: SOF: topology: Check w->sname validity once in sof_connect_dai_widget() (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-audio: remove useless assignment (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: pci-tgl: add RPL-P support (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: pci-tgl: add ADL-PS support (Jaroslav Kysela) [2125544]
- ASOC: SOF: pci: add ipc_type override for Intel IPC4 tests (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-pci-dev: don't use the community key on APL Chromebooks (Jaroslav Kysela) [2125544]
- ASoC: SOF: amd: Use dedicated MBOX for ACP and PSP communication (Jaroslav Kysela) [2125544]
- ASoC: SOF: amd: Add psp_mbox_ready() and psp_send_cmd() callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125544]
- ASoC: SOF: Kconfig: Make SND_SOC_SOF_HDA_PROBES tristate (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: add IP identifier (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: expose some codeloader functions (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: Define rom_status_reg in sof_intel_dsp_desc (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: define check_ipc_irq op (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: use BIT() macros for consistency (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: move HDA_CL_STREAM_FORMAT definition to header (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda: use common ops across platforms (Jaroslav Kysela) [2125544]
- ASoC: SOF: remove const qualifier for 'struct snd_sof_dsp_ops' (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-audio: preserve topology filename override in nocodec mode (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-pci-dev: add parameter to override topology filename (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-pci-dev: add parameter to override firmware filename (Jaroslav Kysela) [2125544]
- ASoC: SOF: add IPC-dependent file names (Jaroslav Kysela) [2125544]
- ASoC: SOF: add default IPC capability and file paths (Jaroslav Kysela) [2125544]
- ASoC: SOF: add path indirection to each IPC type (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: Check the bar size before remapping (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Move the ipc_set_get_comp_data() local to ipc3-control (Jaroslav Kysela) [2125544]
- ASoC: SOF: sof-audio: Use the widget_kcontrol_setup ops for kcontrol set up (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add widget_kcontrol_setup control ops for IPC3 (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Switch over to use the rx_msg ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Switch over to use the tx_msg and set_get_data ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Use the get_reply ops in snd_sof_ipc_get_reply() (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Add check for mandatory IPC message handling ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Separate the ops checks by functions/topics (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Implement rx_msg IPC ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Implement the get_reply IPC ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Implement the set_get_data IPC ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Use sof_ipc3_tx_msg() internally for message sending (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc3: Implement the tx_msg IPC ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add high level IPC IO callback definitions to ipc_ops (Jaroslav Kysela) [2125544]
- ASoC: SOF: Add helper function to prepare and send an IPC message (Jaroslav Kysela) [2125544]
- ASoC: SOF: mediatek: mt8195 add shutdown callback (Jaroslav Kysela) [2125544]
- ASoC: SOF: OF: Add shutdown callback for SOF OF device (Jaroslav Kysela) [2125544]
- ASoC: SOF: topology: Avoid open coded arithmetic in memory allocation (Jaroslav Kysela) [2125544]
- ASoC: SOF: topology: use new sound control LED layer (Jaroslav Kysela) [2125544]
- ASoC: SOF: Remove redundant return statements (Jaroslav Kysela) [2125544]
- ASoC: SOF: Remove header from struct snd_sof_ipc_msg (Jaroslav Kysela) [2125544]
- ASoC: SOF: Drop 'header' parameter from tx_message() API (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Use msg->reply_data directly in snd_sof_ipc_get_reply() (Jaroslav Kysela) [2125544]
- ASoC: SOF: disable dma trace in s0ix (Jaroslav Kysela) [2125544]
- ASoC: SOF: extend the interface to stop DMA trace (Jaroslav Kysela) [2125544]
- ASoC: SOF: Drop support for mapped control data (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Use ipc->max_payload_size for message/reply size checking (Jaroslav Kysela) [2125544]
- ASoC: SOF: ipc: Add max_payload_size field in struct snd_sof_ipc (Jaroslav Kysela) [2125544]
- ASoC: SOF: Remove dmab and dmab_bdl from snd_sof_dev struct (Jaroslav Kysela) [2125544]
- ASoC: SOF: Intel: hda-loader: Use local snd_dma_buffer (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: add missing platform_device_unregister() in acp_pci_probe() (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Fix initialization of ext_intr_stat1 in i2s_irq_handler() (Jaroslav Kysela) [2125544]
- ASoC: amd: vangogh: Use non-legacy DAI naming for cs35l41 (Jaroslav Kysela) [2125544]
- ASoC: amd: enable RPL Platform acp drivers build (Jaroslav Kysela) [2125544]
- ASoC: amd: add RPL Platform pci driver pm-ops (Jaroslav Kysela) [2125544]
- ASoC: amd: add RPL Platform init/de-init functions (Jaroslav Kysela) [2125544]
- ASoC: amd: add ACP PCI driver for RPL platform (Jaroslav Kysela) [2125544]
- ASoC: amd: add RPL Platform acp header file (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Add error handling cases (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Modify const resource struct variable to generic (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Drop superfluous mmap callback (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Modify local variables name to generic (Jaroslav Kysela) [2125544]
- ASoC: amd: yc: Decrease level of error message (Jaroslav Kysela) [2125544]
- ASoC: amd: yc: add new YC platform varaint support (Jaroslav Kysela) [2125544]
- ASoC: amd: fix Jadeite kconfig warning and build errors (Jaroslav Kysela) [2125544]
- ASoC: amd: Fix error pointer dereference (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Add legacy audio driver support for Rembrandt platform (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: ACP code generic to support newer platforms (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Remove rt1019_1 codec conf from machine driver (Jaroslav Kysela) [2125544]
- ASoC: amd: Remove duplicated include in acp-es8336.c (Jaroslav Kysela) [2125544]
- ASoC: amd: fix for variable set but not used warning (Jaroslav Kysela) [2125544]
- ASoC: amd: drop machine driver remove function (Jaroslav Kysela) [2125544]
- ASoC: amd: remove unused header file inclusion (Jaroslav Kysela) [2125544]
- ASoC: amd: acp-es8336: use static variables (Jaroslav Kysela) [2125544]
- ASoC: amd: fix ACPI dependency compile errors and warnings (Jaroslav Kysela) [2125544]
- ASoC: amd: enable machine driver build for Jadeite platform (Jaroslav Kysela) [2125544]
- ASoC: amd: add Machine driver for Jadeite platform (Jaroslav Kysela) [2125544]
- ASoC: amd: add I2S MICSP instance support (Jaroslav Kysela) [2125544]
- ASoC: amd: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Fix error handling in .remove() (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: fix typo in comment (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Add support for rt5682s and rt1019 card with hs instance (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Add support for nau8825 and max98360 card (Jaroslav Kysela) [2125544]
- ASoC: amd: vangogh: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125544]
- ASoC: amd: vangogh: Update to use set_fmt_new callback (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Set Speaker enable/disable pin through rt1019 codec driver. (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Set Speaker enable/disable pin through rt1019 codec driver (Jaroslav Kysela) [2125544]
- ASoC: amd: vangogh: Remove duplicate include files (Jaroslav Kysela) [2125544]
- ASoC: amd: acp: Add pm ops callback in machine driver (Jaroslav Kysela) [2125544]
- ASoC: soc-utils: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: topology: Drop superfluous check of CONFIG_SND_CTL_VALIDATION (Jaroslav Kysela) [2125544]
- ASoC: topology: Rename soc_tplg_init_kcontrol() function (Jaroslav Kysela) [2125544]
- ASoC: topology: Correct error message (Jaroslav Kysela) [2125544]
- ASoC: topology: Rename SOC_TPLG_PASS_MIXER to _CONTROL (Jaroslav Kysela) [2125544]
- ASoC: topology: Return bool instead of int (Jaroslav Kysela) [2125544]
- ASoC: topology: Remove unnecessary looping (Jaroslav Kysela) [2125544]
- ASoC: topology: Use for loop instead of while (Jaroslav Kysela) [2125544]
- ASoC: topology: KUnit: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125544]
- ASoC: topology: KUnit: Followup prototype change of snd_soc_unregister_card() (Jaroslav Kysela) [2125544]
- ASoC: DPCM: Don't pick up BE without substream (Jaroslav Kysela) [2125544]
- ASoC: soc-pcm: demote warnings on non-atomic BE connection (Jaroslav Kysela) [2125544]
- ASoC: soc-pcm: fix BE transition for TRIGGER_START (Jaroslav Kysela) [2125544]
- ASoC: soc-pcm: improve BE transition for TRIGGER_START (Jaroslav Kysela) [2125544]
- ASoC: soc-pcm: improve BE transition for PAUSE_RELEASE (Jaroslav Kysela) [2125544]
- ASoC: ops: Fix integer detection for when max possible values > 1 (Jaroslav Kysela) [2125544]
- ASoC: ops: Fix boolean/integer detection for simple controls (Jaroslav Kysela) [2125544]
- ASoC: ops: Don't modify the driver's plaform_max when reading state (Jaroslav Kysela) [2125544]
- ASoC: ops: Remove unneeded delay.h inclusion (Jaroslav Kysela) [2125544]
- ASoC: ops: Clarify snd_soc_info_volsw_sx() (Jaroslav Kysela) [2125544]
- ASoC: soc-generic-dmaengine-pcm: Use default config when none is given (Jaroslav Kysela) [2125544]
- ASoC: dapm: Move stereo autodisable check (Jaroslav Kysela) [2125544]
- ASoC: soc-dai: Remove set_fmt_new callback (Jaroslav Kysela) [2125544]
- ASoC: soc-core.c: share code for snd_soc_of_get_dai_link_cpus/codecs() (Jaroslav Kysela) [2125544]
- ASoC: soc-core.c: fixup snd_soc_of_get_dai_link_cpus() (Jaroslav Kysela) [2125544]
- ASoC: core: Switch core to new DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: core: Make snd_soc_unregister_card() return void (Jaroslav Kysela) [2125544]
- ASoC: core: Always send the CPU DAI a direct clock specifier (Jaroslav Kysela) [2125544]
- ASoC: core: Add set_fmt_new callback that directly specifies provider (Jaroslav Kysela) [2125544]
- ASoC: core: Pass legacy_dai_naming flag directly (Jaroslav Kysela) [2125544]
- ASoC: core: Correct spelling fliped -> flipped (Jaroslav Kysela) [2125544]
- ASoC: soc-core: remove always-false path (Jaroslav Kysela) [2125544]
- ASoC: Introduce snd_soc_of_get_dai_link_cpus (Jaroslav Kysela) [2125544]
- ASoC: soc-component: Update handling to component delays (Jaroslav Kysela) [2125544]
- ASoC: Introduce 'fixup_controls' card method (Jaroslav Kysela) [2125544]
- ASoC: soc-card: Create jack kcontrol without pins (Jaroslav Kysela) [2125544]
- ALSA: Replace acpi_bus_get_device() (Jaroslav Kysela) [2125544]
- Revert "ALSA: hda: cs35l41: Allow compilation test on non-ACPI configurations" (Jaroslav Kysela) [2125544]
- ALSA: hda: beep: Simplify keep-power-at-enable behavior (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: Don't skip notification handling during PM operation (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: Limit the maximal count of PCM devices to 8 (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: ELD procfs - print the codec NIDs (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: Simplify the pcm_idx condition in hdmi_pcm_setup_pin() (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: Fix the converter allocation for the silent stream (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: change type for the 'assigned' variable (Jaroslav Kysela) [2125544]
- ALSA: hda: intel-nhlt: Move structs out of #define block (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add a quirk for HP OMEN 16 (8902) mute LED (Jaroslav Kysela) [2125544]
- ALSA: hda/hdmi: Fix the converter reuse for the silent stream (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for ASUS GA503R laptop (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add pincfg for ASUS G533Z HP jack (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add pincfg for ASUS G513 HP jack (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Re-arrange quirk table entries (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5530 laptop (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5570 laptop (Jaroslav Kysela) [2125544]
- ALSA: hda: Fix Nvidia dp infoframe (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for Huawei WRT-WX9 (Jaroslav Kysela) [2125544]
- ALSA: hda/tegra: set depop delay for tegra (Jaroslav Kysela) [2125544]
- ALSA: hda: add Intel 5 Series / 3400 PCI DID (Jaroslav Kysela) [2125544]
- ALSA: hda: Fix hang at HD-audio codec unbinding due to refcount saturation (Jaroslav Kysela) [2125544]
- ALSA: emu10k1: Fix out of bounds access in snd_emu10k1_pcm_channel_alloc() (Jaroslav Kysela) [2125544]
- ALSA: hda/tegra: Align BDL entry to 4KB boundary (Jaroslav Kysela) [2125544]
- ALSA: hda/sigmatel: Fix unused variable warning for beep power change (Jaroslav Kysela) [2125544]
- ALSA: hda/sigmatel: Keep power up while beep is enabled (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add speaker AMP init for Samsung laptops with ALC298 (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU, NS70PU (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: Support new Dolphin Variants (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for Lenovo Yoga7 14IAL7 (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Clarify support for CSC3551 without _DSD Properties (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirks for ASUS Zenbooks using CS35L41 (Jaroslav Kysela) [2125544]
- ALSA: hda: Fix crash due to jack poll in suspend (Jaroslav Kysela) [2125544]
- ALSA: hda/cirrus - support for iMac 12,1 model (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 (8786) mute LED (Jaroslav Kysela) [2125544]
- ALSA: hda/conexant: Add quirk for LENOVO 20149 Notebook model (Jaroslav Kysela) [2125544]
- ALSA: ice1712: remove redundant assignment to new (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for another Asus K42JZ model (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for HP Spectre x360 15-eb0xxx (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for Clevo NV45PZ (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Add quirk for Lenovo Yoga9 14IAP7 (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Support CLSA0101 (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Use the CS35L41 HDA internal define (Jaroslav Kysela) [2125544]
- ALSA: hda/realtek: Enable speaker and mute LEDs for HP laptops (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Fix build error unused-function (Jaroslav Kysela) [2125544]
- ALSA: asihpi: fix repeated words in comments (Jaroslav Kysela) [2125544]
- ALSA: asihpi: Fix typo in comments (Jaroslav Kysela) [2125544]
- ALSA: emu10k1: Fix typo in comments (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Add module parameter to control firmware load (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Support Firmware switching and reloading (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Add defaulted values into dsp bypass config sequence (Jaroslav Kysela) [2125544]
- ALSA: hda: hda_cs_dsp_ctl: Add fw id strings (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Read Speaker Calibration data from UEFI variables (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Support Hibernation during Suspend (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Support Speaker ID for laptops (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Support multiple load paths for firmware (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Support reading subsystem id from ACPI (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Save Subsystem ID inside CS35L41 Driver (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Add initial DSP support and firmware loading (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Save codec object inside component struct (Jaroslav Kysela) [2125544]
- ALSA: hda: hda_cs_dsp_ctl: Add apis to write the controls directly (Jaroslav Kysela) [2125544]
- ALSA: hda: hda_cs_dsp_ctl: Add Library to support CS_DSP ALSA controls (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Consolidate selections under SND_HDA_SCODEC_CS35L41 (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Drop wrong use of ACPI_PTR() (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Allow compilation test on non-ACPI configurations (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Don't dereference fwnode handle (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Improve dev_err_probe() messaging (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Fix comments wrt serial-multi-instantiate reference (Jaroslav Kysela) [2125544]
- ALSA: hda: Fix put_device() inconsistency in error path (Jaroslav Kysela) [2125544]
- ALSA: hda: Make device usage_count consistent across subsequent probing (Jaroslav Kysela) [2125544]
- ALSA: hda: Fix null-ptr-deref when i915 fails and hdmi is denylisted (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: change cs8409_fixups v.pins initializers to static (Jaroslav Kysela) [2125544]
- ASoC: doc: Update dead links (Jaroslav Kysela) [2125544]
- ALSA: hda/via: Delete does not require return (Jaroslav Kysela) [2125544]
- ALSA: ctxfi: fix typo in comment (Jaroslav Kysela) [2125544]
- ALSA: cs5535audio: fix typo in comment (Jaroslav Kysela) [2125544]
- ALSA: lola: Bounds check loop iterator against streams array size (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Add Amp Name based on channel and index (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Enable GPIO2 Interrupt for CLSA0100 laptops (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Add Support for Interrupts (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Remove Set Channel Map api from binding (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Set Speaker Position for CLSA0100 Laptop (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Fix error in spi cs35l41 hda driver name (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: Add Speaker Playback Switch for Warlock (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: Add Speaker Playback Switch for Cyborg (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: Support new Odin Variants (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: Support manual mode detection for CS42L42 (Jaroslav Kysela) [2125544]
- ALSA: hda/cs8409: Use general cs42l42 include in cs8409 hda driver (Jaroslav Kysela) [2125544]
- ALSA: hdsp: remove redundant assignment to pointer kctl (Jaroslav Kysela) [2125544]
- ALSA: hda/conexant: add a new hda codec SN6140 (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Move external boost handling to lib for ASoC use (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Handle all external boost setups the same way (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Reorganize log for playback actions (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Remove cs35l41_hda_reg_sequence struct (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Move boost config to initialization code (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Mute the device before shutdown (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Put the device into safe mode for external boost (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Add Boost type flag (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Always configure the DAI (Jaroslav Kysela) [2125544]
- ALSA: hda: cs35l41: Fix I2S params comments (Jaroslav Kysela) [2125544]
- ALSA: cs35l41: Move cs35l41_gpio_config to shared lib (Jaroslav Kysela) [2125544]
- ALSA: cs35l41: Check hw_config before using it (Jaroslav Kysela) [2125544]
- ALSA: cs35l41: Unify hardware configuration (Jaroslav Kysela) [2125544]
- ALSA: hda/tegra: Enable Jack poll for tegra (Jaroslav Kysela) [2125544]
- ALSA: hda: Jack detection poll in suspend state (Jaroslav Kysela) [2125544]
- ALSA: echoaudio: remove redundant assignment to variable i (Jaroslav Kysela) [2125544]
- ALSA: emu10k1: Stop using iommu_present() (Jaroslav Kysela) [2125544]
- ALSA: hda: intel-dsp-config: add missing RaptorLake PCI IDs (Jaroslav Kysela) [2125544]
- ALSA: hda: intel-nhlt: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2125544]
- ALSA: hda: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125544]
- ALSA: hda: Remove unused macro definition (Jaroslav Kysela) [2125544]
- ALSA: hda: Reset all SIE bits in INTCTL (Jaroslav Kysela) [2125544]
- tracing: ALSA: hda: Remove string manipulation out of the fast path (Jaroslav Kysela) [2125544]
- ALSA: hda: intel-nhlt: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125544]
- ALSA: hda: intel-dspcfg: use SOF for UpExtreme and UpExtreme11 boards (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Properly refcounting clock rate (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Clear fixed clock rate at closing EP (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Fix an out-of-bounds bug in __snd_usb_parse_audio_interface() (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Register card again for iface over delayed_register option (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Inform the delayed registration more properly (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Add quirk for LH Labs Geek Out HD Audio 1V5 (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: make read-only array marker static const (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: More comprehensive mixer map for ASUS ROG Zenith II (Jaroslav Kysela) [2125544]
- ALSA: scarlett2: Add Focusrite Clarett+ 8Pre support (Jaroslav Kysela) [2125544]
- ALSA: line6: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125544]
- ALSA: hiface: fix repeated words in comments (Jaroslav Kysela) [2125544]
- ALSA: usb/6fire: fix repeated words in comments (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Add quirk for Behringer UMC202HD (Jaroslav Kysela) [2125544]
- ALSA: bcd2000: Fix a UAF bug on the error path of probing (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Use atomic_try_cmpxchg in ep_state_update (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Add endianness annotations (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Turn off 'manual mode' on Dell dock (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Support jack detection on Dell dock (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: US16x08: Move overflow check before array access (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Cancel pending work at closing a MIDI substream (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Add mixer mapping for Gigabyte B450/550 Mobos (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Fix wrong kfree issue in snd_usb_endpoint_free_all (Jaroslav Kysela) [2125544]
- ALSA: usb-audio: Refcount multiple accesses on the single clock (Jaroslav Kysela) [2125544]
- mfd: arizona-spi: Add Android board ACPI table handling (Jaroslav Kysela) [2125544]
- mfd: arizona-spi: Split Windows ACPI init code into its own function (Jaroslav Kysela) [2125544]
- mfd: arizona: Add missing statics to the of_match_tables (Jaroslav Kysela) [2125544]
- firmware: cs_dsp: Add memory chunk helpers (Jaroslav Kysela) [2125544]
- firmware: cs_dsp: Add pre_stop callback (Jaroslav Kysela) [2125544]
- regmap: sdw: add required header files (Jaroslav Kysela) [2125544]
- regmap: soundwire: remove unused header mod_devicetable.h (Jaroslav Kysela) [2125544]
- regmap: Constify static regmap_bus structs (Jaroslav Kysela) [2125544]
- soundwire: peripheral: remove useless ops pointer (Jaroslav Kysela) [2125544]
- soundwire: intel: use pm_runtime_resume() on component probe (Jaroslav Kysela) [2125544]
- soundwire: qcom: fix device status array range (Jaroslav Kysela) [2125544]
- soundwire: qcom: remove duplicate reset control get (Jaroslav Kysela) [2125544]
- soundwire: Intel: add trigger callback (Jaroslav Kysela) [2125544]
- soundwire: qcom: Enable software clock gating requirement flag (Jaroslav Kysela) [2125544]
- soundwire: qcom: Check device status before reading devid (Jaroslav Kysela) [2125544]
- soundwire: qcom: Add flag for software clock gating check (Jaroslav Kysela) [2125544]
- soundwire: revisit driver bind/unbind and callbacks (Jaroslav Kysela) [2125544]
- soundwire: bus_type: fix remove and shutdown support (Jaroslav Kysela) [2125544]
- soundwire: intel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125544]
- ASoC: qcom: soundwire: Add support for controlling audio CGCR from HLOS (Jaroslav Kysela) [2125544]
- soundwire: qcom: adjust autoenumeration timeout (Jaroslav Kysela) [2125544]
- soundwire: qcom: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- soundwire: intel: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- soundwire: cadence: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- soundwire: bus: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125544]
- soundwire: qcom: return error when pm_runtime_get_sync fails (Jaroslav Kysela) [2125544]
- soundwire: bus: pm_runtime_request_resume on peripheral attachment (Jaroslav Kysela) [2125544]
- soundwire: intel: disable WAKEEN in pm_runtime resume (Jaroslav Kysela) [2125544]
- soundwire: cadence: recheck device0 attachment after status change (Jaroslav Kysela) [2125544]
- soundwire: qcom: Add compatible name for v1.6.0 (Jaroslav Kysela) [2125544]
- soundwire: stream: Fix error return code in do_bank_switch() (Jaroslav Kysela) [2125544]
- soundwire: qcom: fix an error message in swrm_wait_for_frame_gen_enabled() (Jaroslav Kysela) [2125544]
- soundwire: qcom: use __maybe_unused for swrm_runtime_resume() (Jaroslav Kysela) [2125544]
- soundwire: qcom: constify static struct qcom_swrm_data global variables (Jaroslav Kysela) [2125544]
- soundwire: qcom: add in-band wake up interrupt support (Jaroslav Kysela) [2125544]
- soundwire: qcom: add runtime pm support (Jaroslav Kysela) [2125544]
- soundwire: Replace acpi_bus_get_device() (Jaroslav Kysela) [2125544]
- ALSA: Add snd_pcm_direction_name() helper (Jaroslav Kysela) [2125544]
- ALSA: core: Fix double-free at snd_card_new() (Jaroslav Kysela) [2125544]
- ALSA: hda: Once again fix regression of page allocations with IOMMU (Jaroslav Kysela) [2125544]
- ALSA: pcm: oss: Fix race at SNDCTL_DSP_SYNC (Jaroslav Kysela) [2125544]
- ALSA: control: Re-order bounds checking in get_ctl_id_hash() (Jaroslav Kysela) [2125544]
- ALSA: control: Fix an out-of-bounds bug in get_ctl_id_hash() (Jaroslav Kysela) [2125544]
- ALSA: seq: Fix data-race at module auto-loading (Jaroslav Kysela) [2125544]
- ALSA: seq: oss: Fix data-race for max_midi_devs access (Jaroslav Kysela) [2125544]
- ALSA: memalloc: Revive x86-specific WC page allocations again (Jaroslav Kysela) [2125544]
- ALSA: info: Fix llseek return value when using callback (Jaroslav Kysela) [2125544]
- ALSA: pcm: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125544]
- ALSA: core: Replace scnprintf() with sysfs_emit() (Jaroslav Kysela) [2125544]
- ALSA: control-led: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125544]
- ALSA: control: Use deferred fasync helper (Jaroslav Kysela) [2125544]
- ALSA: pcm: Use deferred fasync helper (Jaroslav Kysela) [2125544]
- ALSA: timer: Use deferred fasync helper (Jaroslav Kysela) [2125544]
- ALSA: core: Add async signal helpers (Jaroslav Kysela) [2125544]
- ALSA: core: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125544]
- ALSA: memalloc: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125544]
- ALSA: control: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125544]
- ALSA: compress: Fix kernel doc warnings (Jaroslav Kysela) [2125544]
- ALSA: dmaengine: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125544]
- ALSA: pcm: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125544]
- ALSA: compress: Enable kernel doc markers for some functions (Jaroslav Kysela) [2125544]
- ALSA: rawmidi: Take buffer refcount while draining output (Jaroslav Kysela) [2125544]
- ALSA: rawmidi: Check stream state at exported functions (Jaroslav Kysela) [2125544]
- ALSA: rawmidi: Take open_mutex around parameter changes (Jaroslav Kysela) [2125544]
- ALSA: rawmidi: Move lock to snd_rawmidi_substream (Jaroslav Kysela) [2125544]
- ALSA: rawmidi: Make internal functions local static (Jaroslav Kysela) [2125544]
- ALSA: control: Add input validation (Jaroslav Kysela) [2125544]
- ALSA: control: Drop superfluous ifdef CONFIG_SND_CTL_DEBUG (Jaroslav Kysela) [2125544]
- ALSA: control: Rename CONFIG_SND_CTL_VALIDATION to CONFIG_SND_CTL_DEBUG (Jaroslav Kysela) [2125544]
- ALSA: control: Use xarray for faster lookups (Jaroslav Kysela) [2125544]
- ALSA: seq: replace ternary operator with max() (Jaroslav Kysela) [2125544]
- ALSA: pcm: use DEVICE_ATTR_RO macro (Jaroslav Kysela) [2125544]
- pinctrl: amd: Don't save/restore interrupt status and wake status bits (Prarit Bhargava) [2130059]
- x86/paravirt: Add a dummy __x86_paravirt_patch_template() function (Waiman Long) [2144161]
- x86/paravirt: Fix kABI breakage in struct pv_mmu_ops (Waiman Long) [2144161]

* Mon Dec 05 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-442.el8.v2.g6f5f]
- can: af_can: fix NULL pointer dereference in can_rx_register() (Ivan Vecera) [2136823]
- net: disable preemption in dev_core_stats_XXX_inc() helpers (Ivan Vecera) [2136823]
- net: introduce CAN specific pointer in the struct net_device (Ivan Vecera) [2136823]
- can: af_can: can_pernet_exit(): no need to iterate over and cleanup registered CAN devices (Ivan Vecera) [2136823]
- net: add per-cpu storage and net->core_stats (Ivan Vecera) [2136823]
- tun: switch to net core provided statistics counters (Ivan Vecera) [2136823]
- tun: switch to u64_stats_t (Ivan Vecera) [2136823]
- ceph: avoid putting the realm twice when decoding snaps fails (Xiubo Li) [2139881]
- powerpc/64/kdump: Limit kdump base to 512MB (Mamatha Inamdar) [2132921]
- ice: virtchnl rss hena support (Petr Oros) [2136516]
- Documentation/admin-guide: Document nomodeset kernel parameter (Jocelyn Falempe) [2143952]
- drm: Move nomodeset kernel parameter to the DRM subsystem (Jocelyn Falempe) [2143952]
- usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- sound: usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- net: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- media: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- Input: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- HID: usbhid: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- usb: deprecate the third argument of usb_maxpacket() (Íñigo Huguet) [2143362]
- scsi: smartpqi: Change version to 2.1.20-035 (Don Brace) [2116976]
- scsi: smartpqi: Initialize feature section info (Don Brace) [2116976]
- scsi: smartpqi: Add controller cache flush during rmmod (Don Brace) [2116976]
- scsi: smartpqi: Correct device removal for multi-actuator devices (Don Brace) [2116976]
- scsi: smartpqi: Change sysfs raid_level attribute to N/A for controllers (Don Brace) [2116976]
- scsi: smartpqi: Correct max LUN number (Don Brace) [2116976]
- scsi: smartpqi: Add new controller PCI IDs (Don Brace) [2116976]
- scsi: smartpqi: Convert to host_tagset (Don Brace) [2116976]
- scsi: smartpqi: Stop using the SCSI pointer (Don Brace) [2116976]
- smartpqi: Change request pointer to scsi_cmd_to_rq (Don Brace) [2116976]
- scsi: smartpqi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Don Brace) [2116976]
- EDAC/skx_common: Make output format similar (Aristeu Rozanski) [2124915]
- EDAC/skx_common: Use driver decoder first (Aristeu Rozanski) [2124915]
- ptp: introduce helpers to adjust by scaled parts per million (Izabela Bakollari) [2141639]
- ptp: add missing documentation for parameters (Izabela Bakollari) [2141639]
- mm: slub: fix flush_cpu_slab()/__free_slab() invocations in task context. (Nico Pache) [2144559]
- scsi: target: loop: Fix handling of aborted TMRs (Maurizio Lombardi) [2141713]
- ceph: fix NULL pointer dereference for req->r_session (Xiubo Li) [2137955]
- ceph: Use kcalloc for allocating multiple elements (Xiubo Li) [2137955]
- net/mlx5e: TC, Reject forwarding from internal port to internal port (Mohammad Kabat) [2131345]
- md/raid1: stop mdx_raid1 thread when raid1 array run failed (Nigel Croxon) [2143270]
- md: fix a crash in mempool_free (Nigel Croxon) [2143257]
- md/raid0, raid10: Don't set discard sectors for request queue (Nigel Croxon) [2143250]
- sgx: use ->f_mapping... (Vladis Dronov) [2130210]
- x86/sgx: Improve comments for sgx_encl_lookup/alloc_backing() (Vladis Dronov) [2130210]
- x86/sgx: Handle VA page allocation failure for EAUG on PF. (Vladis Dronov) [2130210]
- x86/sgx: Do not fail on incomplete sanitization on premature stop of ksgxd (Vladis Dronov) [2130210]
- selftests/sgx: Ignore OpenSSL 3.0 deprecated functions warning (Vladis Dronov) [2130210]
- x86/sgx: Set active memcg prior to shmem allocation (Vladis Dronov) [2130210]
- x86/sgx: Drop 'page_index' from sgx_backing (Vladis Dronov) [2130210]
- selftests/sgx: Page removal stress test (Vladis Dronov) [2130210]
- selftests/sgx: Test reclaiming of untouched page (Vladis Dronov) [2130210]
- selftests/sgx: Test invalid access to removed enclave page (Vladis Dronov) [2130210]
- selftests/sgx: Test faulty enclave behavior (Vladis Dronov) [2130210]
- selftests/sgx: Test complete changing of page type flow (Vladis Dronov) [2130210]
- selftests/sgx: Introduce TCS initialization enclave operation (Vladis Dronov) [2130210]
- selftests/sgx: Introduce dynamic entry point (Vladis Dronov) [2130210]
- selftests/sgx: Test two different SGX2 EAUG flows (Vladis Dronov) [2130210]
- selftests/sgx: Add test for TCS page permission changes (Vladis Dronov) [2130210]
- selftests/sgx: Add test for EPCM permission changes (Vladis Dronov) [2130210]
- Documentation/x86: Introduce enclave runtime management section (Vladis Dronov) [2130210]
- x86/sgx: Free up EPC pages directly to support large page ranges (Vladis Dronov) [2130210]
- x86/sgx: Support complete page removal (Vladis Dronov) [2130210]
- x86/sgx: Support modifying SGX page type (Vladis Dronov) [2130210]
- x86/sgx: Tighten accessible memory range after enclave initialization (Vladis Dronov) [2130210]
- x86/sgx: Support adding of pages to an initialized enclave (Vladis Dronov) [2130210]
- x86/sgx: Support restricting of enclave page permissions (Vladis Dronov) [2130210]
- x86/sgx: Support VA page allocation without reclaiming (Vladis Dronov) [2130210]
- x86/sgx: Export sgx_encl_page_alloc() (Vladis Dronov) [2130210]
- x86/sgx: Export sgx_encl_{grow,shrink}() (Vladis Dronov) [2130210]
- x86/sgx: Keep record of SGX page type (Vladis Dronov) [2130210]
- x86/sgx: Create utility to validate user provided offset and length (Vladis Dronov) [2130210]
- x86/sgx: Make sgx_ipi_cb() available internally (Vladis Dronov) [2130210]
- x86/sgx: Move PTE zap code to new sgx_zap_enclave_ptes() (Vladis Dronov) [2130210]
- x86/sgx: Rename sgx_encl_ewb_cpumask() as sgx_encl_cpumask() (Vladis Dronov) [2130210]
- x86/sgx: Export sgx_encl_ewb_cpumask() (Vladis Dronov) [2130210]
- x86/sgx: Support loading enclave page without VMA permissions check (Vladis Dronov) [2130210]
- x86/sgx: Add wrapper for SGX2 EAUG function (Vladis Dronov) [2130210]
- x86/sgx: Add wrapper for SGX2 EMODT function (Vladis Dronov) [2130210]
- x86/sgx: Add wrapper for SGX2 EMODPR function (Vladis Dronov) [2130210]
- x86/sgx: Add short descriptions to ENCLS wrappers (Vladis Dronov) [2130210]
- x86/sgx: Ensure no data in PCMD page after truncate (Vladis Dronov) [2130210]
- x86/sgx: Fix race between reclaimer and page fault handler (Vladis Dronov) [2130210]
- x86/sgx: Obtain backing storage page with enclave mutex held (Vladis Dronov) [2130210]
- x86/sgx: Mark PCMD page as dirty when modifying contents (Vladis Dronov) [2130210]
- x86/sgx: Disconnect backing page references from dirty status (Vladis Dronov) [2130210]
- HID: intel-ish-hid: ipc: Add Meteor Lake PCI device ID (Tony Camuso) [2132441]
- hid: intel-ish-hid: ishtp: Fix ishtp client sending disordered message (Tony Camuso) [2132441]
- HID: ishtp-hid-clientHID: ishtp-hid-client: Fix comment typo (Tony Camuso) [2132441]
- ID: intel-ish-hid: hid-client: drop unexpected word "the" in the comments (Tony Camuso) [2132441]
- HID: intel-ish-hid: ipc: use time_before to replace "jiffies < a" (Tony Camuso) [2132441]
- HID: intel-ish-hid: ipc: add ADL and RPL device id (Tony Camuso) [2132441]
- HID: intel-ish-hid: Use dma_alloc_coherent for firmware update (Tony Camuso) [2132441]
- HID: intel-ish-hid: ishtp-fw-loader: Fix a kernel-doc formatting issue (Tony Camuso) [2132441]
- HID: intel-ish-hid: ipc: Specify no cache snooping on TGL and ADL (Tony Camuso) [2132441]
- HID: intel-ish-hid: ipc: only enable IRQ wakeup when requested (Tony Camuso) [2132441]
- HID: intel-ish-hid: fix module device-id handling (Tony Camuso) [2132441]
- HID: intel-ish-hid: hid-client: only load for matching devices (Tony Camuso) [2132441]
- HID: intel-ish-hid: fw-loader: only load for matching devices (Tony Camuso) [2132441]
- HID: intel-ish-hid: use constants for modaliases (Tony Camuso) [2132441]
- s390/pci: add missing EX_TABLE entries to __pcistg_mio_inuser()/__pcilg_mio_inuser() (Tobias Huschle) [2141963]
- s390/futex: add missing EX_TABLE entry to __futex_atomic_op() (Tobias Huschle) [2141963]
- s390/uaccess: add missing EX_TABLE entries to __clear_user() (Tobias Huschle) [2141963]
- net: usb: ax88179_178a: Fix packet receiving (Jose Ignacio Tornos Martinez) [2142725] {CVE-2022-2964}
- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup (Jose Ignacio Tornos Martinez) [2142725] {CVE-2022-2964}
- drm/i915/rpl-p: Add PCI IDs (Jocelyn Falempe) [2115880]
- Revert "dma-buf: remove useless FMODE_LSEEK flag" (Jocelyn Falempe) [2115880]
- drm/amd/display: Increase stack frame size limit for a few files. (Jocelyn Falempe) [2115880]
- drm_crtc.h is missing include/linux/slab.h (Jocelyn Falempe) [2115880]
- drm/amd/display: remove a duplicated declaration (Jocelyn Falempe) [2115880]
- Revert "mm: shrinkers: provide shrinkers with names" (Jocelyn Falempe) [2115880]
- Revert "drm/amdkfd: add SPM support for SVM" (Jocelyn Falempe) [2115880]
- Merge DRM changes from upstream v5.19..v6.0 (Jocelyn Falempe) [2115880]
- drm/i915/gvt: IMPORT_MODULE_NS workaround (Jocelyn Falempe) [2115880]
- Replace EXPORT_SYMBOL_NS_GPL with EXPORT_SYMBOL_GPL (Jocelyn Falempe) [2115880]
- Revert "vfio/gvt: Fix open/close when multiple device FDs are open" (Michel Dänzer) [2115880]
- Revert "vfio/mdev: Pass in a struct vfio_device * to vfio_dma_rw()" (Jocelyn Falempe) [2115880]
- Revert "drm/i915/gvt: convert to use vfio_register_emulated_iommu_dev" (Jocelyn Falempe) [2115880]
- Revert "drm/i915/gvt: merge gvt.c into kvmgvt.c" (Jocelyn Falempe) [2115880]
- Revert "vfio/mdev: Remove mdev_parent_ops" (Jocelyn Falempe) [2115880]
- Revert "vfio: Make vfio_(un)register_notifier accept a vfio_device" (Jocelyn Falempe) [2115880]
- Revert "drm/i915/gvt: Change from vfio_group_(un)pin_pages to vfio_(un)pin_pages" (Jocelyn Falempe) [2115880]
- Revert "vfio: remove VFIO_GROUP_NOTIFY_SET_KVM" (Jocelyn Falempe) [2115880]
- Revert "i915: Call aops write_begin() and write_end() directly" (Jocelyn Falempe) [2115880]
- Merge DRM changes from upstream v5.18..v5.19 (Jocelyn Falempe) [2115880]
- crypto: testmgr - disallow plain cbcmac(aes) and ghash in FIPS mode (Vladis Dronov) [2107595]
- crypto: set the required FIPS_INTERNAL flag for gcm and ccm (Vladis Dronov) [2107595]
- crypto: seqiv - flag instantiations as FIPS compliant (Vladis Dronov) [2107595]
- crypto: xts - restrict key lengths to approved values in FIPS mode (Vladis Dronov) [2107595]
- crypto: api - allow algs only in specific constructions in FIPS mode (Vladis Dronov) [2107595]
- crypto: api - check for ERR pointers in crypto_destroy_tfm() (Vladis Dronov) [2107595]
- crypto: api - Fix use-after-free and race in crypto_spawn_alg (Vladis Dronov) [2107595]
- crypto: algapi - Avoid spurious modprobe on LOADED (Vladis Dronov) [2107595]
- crypto: api - Retain alg refcount in crypto_grab_spawn (Vladis Dronov) [2107595]
- crypto: api - Do not zap spawn->alg (Vladis Dronov) [2107595]
- crypto: api - Fix race condition in crypto_spawn_alg (Vladis Dronov) [2107595]
- crypto: api - Check spawn->alg under lock in crypto_drop_spawn (Vladis Dronov) [2107595]
- crypto: algapi - reject NULL crypto_spawn::inst (Vladis Dronov) [2107595]
- iavf: remove INITIAL_MAC_SET to allow gARP to work properly (Stefan Assmann) [1938635]
- mm, slab: remove duplicate kernel-doc comment for ksize() (Michal Schmidt) [2143367]
- slab: Introduce kmalloc_size_roundup() (Michal Schmidt) [2143367]
- thermal: int340x: Mode setting with new OS handshake (Prarit Bhargava) [2072652]
- thermal: int340x: Update OS policy capability handshake (Prarit Bhargava) [2072652]
- hugetlb: remove unnecessary set_page_count in prep_compound_gigantic_page (Chris von Recklinghausen) [2143631]
- mm/hugetlb: clear compound_nr before freeing gigantic pages (Chris von Recklinghausen) [2143631]
- uprobes: __replace_page() avoid BUG in munlock_vma_page() (Chris von Recklinghausen) [2143631]
- s390/boot: add secure boot trailer (Tobias Huschle) [2141967]
- ice: Fix configuring VIRTCHNL_OP_CONFIG_VSI_QUEUES with unbalanced queues (Michal Schmidt) [2137378]
- nvme: wait until quiesce is done (Ming Lei) [2144258]
- scsi: make sure that request queue queiesce and unquiesce balanced (Ming Lei) [2144258]
- scsi: avoid to quiesce sdev->request_queue two times (Ming Lei) [2144258]
- dm: don't stop request queue after the dm device is suspended (Ming Lei) [2144258]

* Tue Nov 29 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-441.el8]
- ata: libata-core: Print timeout value when internal command times (Ewan D. Milne) [1823688]
- ata: libata-core: fix sloppy parameter type in ata_exec_internal[_sg]() (Ewan D. Milne) [1823688]
- ata: libata-core: make ata_exec_internal_sg() *static* (Ewan D. Milne) [1823688]
- perf/x86/intel: Fix unchecked MSR access error for Alder Lake N (Michael Petlan) [2104807]
- perf/x86/intel: Fix PEBS data source encoding for ADL (Michael Petlan) [2104807]
- perf/x86/intel: Fix PEBS memory access info encoding for ADL (Michael Petlan) [2104807]
- i40e: Fix DMA mappings leak (Ivan Vecera) [2077847]
- fbcon: Fix delayed takeover locking (Jocelyn Falempe) [2134795]
- fbcon: use min() to make code cleaner (Jocelyn Falempe) [2134795]
- fbcon: Use array3_size() helper in scr_memcpyw() (Jocelyn Falempe) [2134795]
- fbcon: Maintain a private array of fb_info (Jocelyn Falempe) [2134795]
- fbcon: untangle fbcon_exit (Jocelyn Falempe) [2134795]
- fbcon: Move more code into fbcon_release (Jocelyn Falempe) [2134795]
- fbcon: Move console_lock for register/unlink/unregister (Jocelyn Falempe) [2134795]
- fbcon: Consistently protect deferred_takeover with console_lock() (Jocelyn Falempe) [2134795]
- fbcon: use lock_fb_info in fbcon_open/release (Jocelyn Falempe) [2134795]
- fbcon: move more common code into fb_open() (Jocelyn Falempe) [2134795]
- fbcon: Ditch error handling for con2fb_release_oldinfo (Jocelyn Falempe) [2134795]
- fbcon: Extract fbcon_open/release helpers (Jocelyn Falempe) [2134795]
- fb: Delete fb_info->queue (Jocelyn Falempe) [2134795]
- fbcon: Replace FBCON_FLAGS_INIT with a boolean (Jocelyn Falempe) [2134795]
- fbcon: Use delayed work for cursor (Jocelyn Falempe) [2134795]
- fbdev/sysfs: Fix locking (Jocelyn Falempe) [2134795]
- fbcon: delete delayed loading code (Jocelyn Falempe) [2134795]
- fbcon: Introduce wrapper for console->fb_info lookup (Jocelyn Falempe) [2134795]
- fbcon: Move fbcon_bmove(_rec) functions (Jocelyn Falempe) [2134795]
- fbcon: delete a few unneeded forward decl (Jocelyn Falempe) [2134795]
- fbcon: Avoid 'cap' set but not used warning (Jocelyn Falempe) [2134795]
- video: fbcon: Fix warnings by using pr_debug() in fbcon (Jocelyn Falempe) [2134795]
- fbcon: Fix user font detection test at fbcon_resize(). (Jocelyn Falempe) [2134795]
- fbcon: remove now unusued 'softback_lines' cursor() argument (Jocelyn Falempe) [2134795]
- fbcon: remove soft scrollback code (Jocelyn Falempe) [2134795]
- fbcon: prevent user font height or width change from causing potential out-of-bounds access (Jocelyn Falempe) [2134795]
- fbmem: pull fbcon_update_vcs() out of fb_set_var() (Jocelyn Falempe) [2134795]
- fbcon: fix null-ptr-deref in fbcon_switch (Jocelyn Falempe) [2134795]
- fbcon: Adjust indentation in set_con2fb_map (Jocelyn Falempe) [2134795]
- fbdev: Unexport unlink_framebuffer() (Jocelyn Falempe) [2134795]
- backlight: drop EARLY_EVENT_BLANK support (Jocelyn Falempe) [2134795]
- fbcon: Export fbcon_update_vcs (Jocelyn Falempe) [2134795]
- backlight: simplify lcd notifier (Jocelyn Falempe) [2134795]
- fbcon: Document what I learned about fbcon locking (Jocelyn Falempe) [2134795]
- fbcon: Call con2fb_map functions directly (Jocelyn Falempe) [2134795]
- fbcon: replace FB_EVENT_MODE_CHANGE/_ALL with direct calls (Jocelyn Falempe) [2134795]
- fb: Flatten control flow in fb_set_var (Jocelyn Falempe) [2134795]
- fbdev: remove FBINFO_MISC_USEREVENT around fb_blank (Jocelyn Falempe) [2134795]
- fbmem: pull fbcon_fb_blanked out of fb_blank (Jocelyn Falempe) [2134795]
- Revert "backlight/fbcon: Add FB_EVENT_CONBLANK" (Jocelyn Falempe) [2134795]
- fbdev: Call fbcon_get_requirement directly (Jocelyn Falempe) [2134795]
- fbcon: Call fbcon_mode_deleted/new_modelist directly (Jocelyn Falempe) [2134795]
- fbdev: directly call fbcon_suspended/resumed (Jocelyn Falempe) [2134795]
- fbdev: unify unlink_framebuffer paths (Jocelyn Falempe) [2134795]
- fbdev: make unregister/unlink functions not fail (Jocelyn Falempe) [2134795]
- fbcon: call fbcon_fb_bind directly (Jocelyn Falempe) [2134795]
- fbcon: call fbcon_fb_(un)registered directly (Jocelyn Falempe) [2134795]
- fbdev: fbmem: fix memory access if logo is bigger than the screen (Jocelyn Falempe) [2134795]
- fbdev: add kerneldoc do remove_conflicting_framebuffers() (Jocelyn Falempe) [2134795]
- fbdev: allow apertures == NULL in remove_conflicting_framebuffers() (Jocelyn Falempe) [2134795]
- fbdev: show fbdev number for debugging (Jocelyn Falempe) [2134795]
- fbcon: use kvmalloc() for scrollback buffer (Jocelyn Falempe) [2134795]
- fbdev: fbcon: Fix unregister crash when more than one framebuffer (Jocelyn Falempe) [2134795]
- fb: fix lost console when the user unplugs a USB adapter (Jocelyn Falempe) [2134795]
- fbcon: introduce for_each_registered_fb() helper (Jocelyn Falempe) [2134795]
- timers/nohz: Last resort update jiffies on nohz_full IRQ entry (Waiman Long) [2108387]
- irq: Call tick_irq_enter() inside HARDIRQ_OFFSET (Waiman Long) [2108387]
- irqtime: Move irqtime entry accounting after irq offset incrementation (Waiman Long) [2108387]
- sched/vtime: Consolidate IRQ time accounting (Waiman Long) [2108387]
- s390/vtime: Use the generic IRQ entry accounting (Waiman Long) [2108387]
- sched/cputime: Remove symbol exports from IRQ time accounting (Waiman Long) [2108387]
- genirq/irqdomain: Don't try to free an interrupt that has no mapping (Waiman Long) [2108387]
- genirq: Provide __irq_enter/exit_raw() (Waiman Long) [2108387]
- powerpc/time: Only set CONFIG_ARCH_HAS_SCALED_CPUTIME on PPC64 (Waiman Long) [2108387]
- powerpc/time: isolate scaled cputime accounting in dedicated functions. (Waiman Long) [2108387]
- perf: Fix list corruption in perf_cgroup_switch() (Aaron Tomlin) [2136548]
- gen_compile_commands: fix issues in RHEL-8 (Íñigo Huguet) [2136840]
- .gitignore: Add compilation database file (Íñigo Huguet) [2136840]
- gen_compile_commands: fix missing 'sys' package (Íñigo Huguet) [2136840]
- gen_compile_commands: extract compiler command from a series of commands (Íñigo Huguet) [2136840]
- gen_compile_commands: prune some directories (Íñigo Huguet) [2136840]
- scripts/clang-tools: switch explicitly to Python 3 (Íñigo Huguet) [2136840]
- Makefile: Add clang-tidy and static analyzer support to makefile (Íñigo Huguet) [2136840]
- kbuild: wire up the build rule of compile_commands.json to Makefile (Íñigo Huguet) [2136840]
- gen_compile_commands: remove the warning about too few .cmd files (Íñigo Huguet) [2136840]
- gen_compile_commands: support *.o, *.a, modules.order in positional argument (Íñigo Huguet) [2136840]
- gen_compile_commands: move directory walk to a generator function (Íñigo Huguet) [2136840]
- gen_compile_commands: make -o option independent of -d option (Íñigo Huguet) [2136840]
- gen_compile_commands: reword the help message of -d option (Íñigo Huguet) [2136840]
- gen_compile_commands: do not support .cmd files under tools/ directory (Íñigo Huguet) [2136840]
- gen_compile_commands: use choices for --log_levels option (Íñigo Huguet) [2136840]
- gen_compile_commands: parse only the first line of .*.cmd files (Íñigo Huguet) [2136840]
- gen_compile_commands: lower the entry count threshold (Íñigo Huguet) [2136840]
- scripts: add a tool to produce a compile_commands.json file (Íñigo Huguet) [2136840]
- iavf: Do not restart Tx queues after reset task failure (Petr Oros) [2134005]
- iavf: Fix a crash during reset task (Petr Oros) [2134005]
- spec: add bpf_testmod.ko to kselftests/bpf (Yauheni Kaliuta) [2140082]
- fuse: fix readdir cache race (Miklos Szeredi) [2131391]
- ice: config netdev tc before setting queues number (Petr Oros) [2103946]
- ice: Fix ice_xdp_xmit() when XDP TX queue number is not sufficient (Petr Oros) [2103946]
- ice: Don't double unplug aux on peer initiated reset (Petr Oros) [2103946]
- ice: use bitmap_free instead of devm_kfree (Petr Oros) [2103946]
- ice: Fix DMA mappings leak (Petr Oros) [2103946]
- ice: Fix call trace with null VSI during VF reset (Petr Oros) [2103946]
- ice: Fix VSI rebuild WARN_ON check for VF (Petr Oros) [2103946]
- net/ice: fix initializing the bitmap in the switch code (Petr Oros) [2103946]
- net: ice: fix error NETIF_F_HW_VLAN_CTAG_FILTER check in ice_vsi_sync_fltr() (Petr Oros) [2103946]
- ice: allow toggling loopback mode via ndo_set_features callback (Petr Oros) [2103946]
- ice: compress branches in ice_set_features() (Petr Oros) [2103946]
- ice: Add support for PPPoE hardware offload (Petr Oros) [2103946]
- ice: add i2c write command (Petr Oros) [2103946]
- ice: Remove pci_aer_clear_nonfatal_status() call (Petr Oros) [2103946]
- ice: Remove unnecessary NULL check before dev_put (Petr Oros) [2103946]
- ice: use eth_broadcast_addr() to set broadcast address (Petr Oros) [2103946]
- ice: switch: dynamically add VLAN headers to dummy packets (Petr Oros) [2103946]
- ice: Add support for VLAN TPID filters in switchdev (Petr Oros) [2103946]
- ice: Add support for double VLAN in switchdev (Petr Oros) [2103946]
- intel/ice:fix repeated words in comments (Petr Oros) [2103946]
- drivers/net/ethernet/intel: fix typos in comments (Petr Oros) [2103946]
- ice: Use correct order for the parameters of devm_kcalloc() (Petr Oros) [2103946]
- ice: remove u16 arithmetic in ice_gnss (Petr Oros) [2103946]
- ice: remove VLAN representor specific ops (Petr Oros) [2103946]
- ice: don't set VF VLAN caps in switchdev (Petr Oros) [2103946]
- kernel-doc: fix undefined args variable (Jan Stancek) [2134954]

* Tue Nov 22 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-440.el8]
- sunrpc: Set sk_allocation to GFP_NOFS to avoid using current->task_frag. (Guillaume Nault) [2089660]
- selftests/vm: enable running select groups of tests (Joel Savitz) [2089502]
- selftests: make use of GUP_TEST_FILE macro (Nico Pache) [2089502]
- selftests: clarify common error when running gup_test (Nico Pache) [2089502]
- tools/testing/selftests/vm/gup_test.c: clarify error statement (Nico Pache) [2089502]
- mm: remove the extra ZONE_DEVICE struct page refcount (Chris von Recklinghausen) [2082247]
- mm: simplify freeing of devmap managed pages (Chris von Recklinghausen) [2082247]
- mm: move free_devmap_managed_page to memremap.c (Chris von Recklinghausen) [2082247]
- mm/memremap: add ZONE_DEVICE support for compound pages (Chris von Recklinghausen) [2082247]
- mm/page_alloc: refactor memmap_init_zone_device() page init (Chris von Recklinghausen) [2082247]
- mm/page_alloc: split prep_compound_page into head and tail subparts (Chris von Recklinghausen) [2082247]
- mm/debug: sync up MR_CONTIG_RANGE and MR_LONGTERM_PIN (Chris von Recklinghausen) [2082247]
- mm: gup: use helper PAGE_ALIGNED in populate_vma_page_range() (Chris von Recklinghausen) [2082247]
- mm: gup: remove useless BUG_ON in __get_user_pages() (Chris von Recklinghausen) [2082247]
- mm: gup: remove unneed local variable orig_refs (Chris von Recklinghausen) [2082247]
- mm: gup: remove set but unused local variable major (Chris von Recklinghausen) [2082247]
- writeback: make the laptop_mode prototypes available unconditionally (Chris von Recklinghausen) [2082247]
- mm: hide laptop_mode_wb_timer entirely behind the BDI API (Chris von Recklinghausen) [2082247]
- mm: remove special swap entry functions (Chris von Recklinghausen) [2082247]
- hugetlb: address ref count racing in prep_compound_gigantic_page (Chris von Recklinghausen) [2082247]
- hugetlb: remove prep_compound_huge_page cleanup (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): get vma_address_end() earlier (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): use goto instead of while (1) (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): add a level of indentation (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): crossing page table boundary (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): prettify PVMW_MIGRATION block (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): use pmde for *pvmw->pmd (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): settle PageHuge on entry (Chris von Recklinghausen) [2082247]
- mm: page_vma_mapped_walk(): use page for pvmw->page (Chris von Recklinghausen) [2082247]
- mm/gup: longterm pin migration cleanup (Chris von Recklinghausen) [2082247]
- mm/gup: change index type to long as it counts pages (Chris von Recklinghausen) [2082247]
- mm/gup: migrate pinned pages out of movable zone (Chris von Recklinghausen) [2082247]
- mm: honor PF_MEMALLOC_PIN for all movable pages (Chris von Recklinghausen) [2082247]
- mm cma: rename PF_MEMALLOC_NOCMA to PF_MEMALLOC_PIN (Chris von Recklinghausen) [2082247]
- mm/huge_memory.c: use helper function migration_entry_to_page() (Chris von Recklinghausen) [2082247]
- block: add queue_to_disk() to get gendisk from request_queue (Chris von Recklinghausen) [2082247]
- mm/hugetlb: remove redundant check in preparing and destroying gigantic page (Chris von Recklinghausen) [2082247]
- mm/hugetlb: use helper huge_page_order and pages_per_huge_page (Chris von Recklinghausen) [2082247]
- mm: handle zone device pages in release_pages() (Chris von Recklinghausen) [2082247]
- mm/gup: remove the vma allocation from gup_longterm_locked() (Chris von Recklinghausen) [2082247]
- mm/mremap_pages: fix static key devmap_managed_key updates (Chris von Recklinghausen) [2082247]
- mm/memremap.c: convert devmap static branch to {inc,dec} (Chris von Recklinghausen) [2082247]
- mm/page_alloc: handle a missing case for memalloc_nocma_{save/restore} APIs (Chris von Recklinghausen) [2082247]
- mm: store compound_nr as well as compound_order (Chris von Recklinghausen) [2082247]
- mm: clean up the last pieces of page fault accountings (Chris von Recklinghausen) [2082247]
- mm/x86: use general page fault accounting (Chris von Recklinghausen) [2082247]
- mm/s390: use general page fault accounting (Chris von Recklinghausen) [2082247]
- mm/powerpc: use general page fault accounting (Chris von Recklinghausen) [2082247]
- mm/arm64: use general page fault accounting (Chris von Recklinghausen) [2082247]
- mm: do page fault accounting in handle_mm_fault (Chris von Recklinghausen) [2082247]
- include/linux/sched/mm.h: optimize current_gfp_context() (Chris von Recklinghausen) [2082247]
- mm/page_alloc: fix memalloc_nocma_{save/restore} APIs (Chris von Recklinghausen) [2082247]
- mm: remove redundant check non_swap_entry() (Chris von Recklinghausen) [2082247]
- mm: rename gfpflags_to_migratetype to gfp_migratetype for same convention (Chris von Recklinghausen) [2082247]
- mm,page_alloc,cma: conditionally prefer cma pageblocks for movable allocations (Chris von Recklinghausen) [2082247]
- mm/vma: introduce VM_ACCESS_FLAGS (Chris von Recklinghausen) [2082247]
- mm/vma: make vma_is_accessible() available for general use (Chris von Recklinghausen) [2082247]
- kernel/events/uprobes.c: only do FOLL_SPLIT_PMD for uprobe register (Chris von Recklinghausen) [2082247]
- uprobe: collapse THP pmd after removing all uprobes (Chris von Recklinghausen) [2082247]
- uprobe: use FOLL_SPLIT_PMD instead of FOLL_SPLIT (Chris von Recklinghausen) [2082247]
- mm, thp: introduce FOLL_SPLIT_PMD (Chris von Recklinghausen) [2082247]
- mm: clean up is_device_*_page() definitions (Chris von Recklinghausen) [2082247]
- driver core: Add helper device_find_child_by_name() (Chris von Recklinghausen) [2082247]
- mm/page_alloc.c: remove unnecessary parameter in rmqueue_pcplist (Chris von Recklinghausen) [2082247]
- sctp: handle the error returned from sctp_auth_asoc_init_active_key (Xin Long) [2134892]
- sctp: leave the err path free in sctp_stream_init to sctp_stream_free (Xin Long) [2134892]
- sctp: fix sleep in atomic context bug in timer handlers (Xin Long) [2134892]
- stcp: Use memset_after() to zero sctp_stream_out_ext (Xin Long) [2134892]
- sctp: read sk->sk_bound_dev_if once in sctp_rcv() (Xin Long) [2134892]
- ethtool: add header/data split indication (Ivan Vecera) [2135624]
- xfrm: store and rely on direction to construct offload flags (Sabrina Dubroca) [2137562]
- platform/x86/intel: pmc: Support Intel Raptorlake P (Prarit Bhargava) [2076736]

* Fri Nov 18 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-439.el8]
- KVM: selftests: Build the memslot tests for arm64 (Gavin Shan) [2132161]
- KVM: selftests: Fix number of pages for memory slot in memslot_modification_stress_test (Gavin Shan) [2132161]
- tools/include: Add _RET_IP_ and math definitions to kernel.h (Gavin Shan) [2132161]
- tcp: fix early ETIMEDOUT after spurious non-SACK RTO (Davide Caratti) [2136409]
- tcp: add a missing nf_reset_ct() in 3WHS handling (Davide Caratti) [2136409]
- sock: redo the psock vs ULP protection check (Davide Caratti) [2136409]
- tcp: tcp_rtx_synack() can be called from process context (Davide Caratti) [2136409]
- tcp: fix tcp_mtup_probe_success vs wrong snd_cwnd (Davide Caratti) [2136409]
- tcp: fix F-RTO may not work correctly when receiving DSACK (Davide Caratti) [2136409]
- selftests: xsk: do not send zero-length packets (Ivan Vecera) [2135634]
- selftests/xsk: Introduce XDP prog load based on existing AF_XDP socket (Ivan Vecera) [2135634]
- selftests, xsk: Fix rx_full stats test (Ivan Vecera) [2135634]
- selftests/bpf: Fix xdpxceiver failures for no hugepages (Ivan Vecera) [2135634]
- selftests/xsk: Add missing close() on netns fd (Ivan Vecera) [2135634]
- selftests, xsk: Fix bpf_res cleanup test (Ivan Vecera) [2135634]
- selftests: xsk: Add frame_headroom test (Ivan Vecera) [2135634]
- selftests: xsk: Change interleaving of packets in unaligned mode (Ivan Vecera) [2135634]
- selftests: xsk: Add single packet test (Ivan Vecera) [2135634]
- selftests: xsk: Introduce pacing of traffic (Ivan Vecera) [2135634]
- selftests: xsk: Fix socket creation retry (Ivan Vecera) [2135634]
- selftests: xsk: Put the same buffer only once in the fill ring (Ivan Vecera) [2135634]
- selftests: xsk: Fix missing initialization (Ivan Vecera) [2135634]
- selftests: xsk: Add tests for 2K frame size (Ivan Vecera) [2135634]
- selftests: xsk: Add tests for invalid xsk descriptors (Ivan Vecera) [2135634]
- selftests: xsk: Eliminate test specific if-statement in test runner (Ivan Vecera) [2135634]
- selftests: xsk: Add test for unaligned mode (Ivan Vecera) [2135634]
- selftests: xsk: Introduce replacing the default packet stream (Ivan Vecera) [2135634]
- selftests: xsk: Allow for invalid packets (Ivan Vecera) [2135634]
- selftests: xsk: Eliminate MAX_SOCKS define (Ivan Vecera) [2135634]
- selftests: xsx: Make pthreads local scope (Ivan Vecera) [2135634]
- selftests: xsk: Make xdp_flags and bind_flags local (Ivan Vecera) [2135634]
- selftests: xsk: Specify number of sockets to create (Ivan Vecera) [2135634]
- selftests: xsk: Replace second_step global variable (Ivan Vecera) [2135634]
- selftests: xsk: Introduce rx_on and tx_on in ifobject (Ivan Vecera) [2135634]
- selftests: xsk: Add use_poll to ifobject (Ivan Vecera) [2135634]
- selftests: xsx: Introduce test name in test spec (Ivan Vecera) [2135634]
- selftests: xsk: Make frame_size configurable (Ivan Vecera) [2135634]
- selftests: xsk: Move rxqsize into xsk_socket_info (Ivan Vecera) [2135634]
- selftests: xsk: Move num_frames and frame_headroom to xsk_umem_info (Ivan Vecera) [2135634]
- selftests: xsk: Introduce test specifications (Ivan Vecera) [2135634]
- selftests: xsk: Introduce type for thread function (Ivan Vecera) [2135634]
- selftests: xsk: Simplify xsk and umem arrays (Ivan Vecera) [2135634]
- selftests: xsk: Preface options with opt (Ivan Vecera) [2135634]
- selftests: xsk: Make enums lower case (Ivan Vecera) [2135634]
- selftests: xsk: Generate packets from specification (Ivan Vecera) [2135634]
- selftests: xsk: Generate packet directly in umem (Ivan Vecera) [2135634]
- selftests: xsk: Simplify cleanup of ifobjects (Ivan Vecera) [2135634]
- selftests: xsk: Decrease sending speed (Ivan Vecera) [2135634]
- selftests: xsk: Validate tx stats on tx thread (Ivan Vecera) [2135634]
- selftests: xsk: Simplify packet validation in xsk tests (Ivan Vecera) [2135634]
- selftests: xsk: Rename worker_* functions that are not thread entry points (Ivan Vecera) [2135634]
- selftests: xsk: Disassociate umem size with packets sent (Ivan Vecera) [2135634]
- selftests: xsk: Remove end-of-test packet (Ivan Vecera) [2135634]
- selftests: xsk: Simplify the retry code (Ivan Vecera) [2135634]
- selftests: xsk: Return correct error codes (Ivan Vecera) [2135634]
- selftests: xsk: Remove unused variables (Ivan Vecera) [2135634]
- selftests: xsk: Remove the num_tx_packets option (Ivan Vecera) [2135634]
- selftests: xsk: Remove color mode (Ivan Vecera) [2135634]
- xsk: Fix possible crash when multiple sockets are created (Ivan Vecera) [2135634]
- i40e: xsk: Move tmp desc array from driver to pool (Ivan Vecera) [2135634]
- xsk: Initialise xskb free_list_node (Ivan Vecera) [2135634]
- xsk: Fix corrupted packets for XDP_SHARED_UMEM (Ivan Vecera) [2135634]
- xsk: Fix clang build error in __xp_alloc (Ivan Vecera) [2135634]
- xsk: Do not write NULL in SW ring at allocation failure (Ivan Vecera) [2135634]
- xsk: Fix crash on double free in buffer pool (Ivan Vecera) [2135634]
- xsk: Optimize for aligned case (Ivan Vecera) [2135634]
- xsk: Batched buffer allocation for the pool (Ivan Vecera) [2135634]
- xsk: Get rid of unused entry in struct xdp_buff_xsk (Ivan Vecera) [2135634]
- redhat/configs: Move config files under common/generic/x86 to generic/x86_64 (Waiman Long) [2139172]
- fbmem: Check virtual screen sizes in fb_set_var() (Wander Lairson Costa) [2109116] {CVE-2021-33655}
- fbcon: Prevent that screen size is smaller than font size (Wander Lairson Costa) [2109116] {CVE-2021-33655}
- fbcon: Disallow setting font bigger than screen size (Wander Lairson Costa) [2109116] {CVE-2021-33655}
- video: of_display_timing.h: include errno.h (Wander Lairson Costa) [2109116] {CVE-2021-33655}
- MAINTAINERS: pick up all vfio_ap docs for VFIO AP maintainers (Cédric Le Goater) [1660908]
- s390/docs: fix warnings for vfio_ap driver doc (Cédric Le Goater) [1660908]
- s390/docs: fix warnings for vfio_ap driver lock usage doc (Cédric Le Goater) [1660908]
- s390/Docs: new doc describing lock usage by the vfio_ap device driver (Cédric Le Goater) [1660908]
- s390/vfio-ap: bypass unnecessary processing of AP resources (Cédric Le Goater) [1660908]
- s390/vfio-ap: update docs to include dynamic config support (Cédric Le Goater) [1660908]
- s390/vfio-ap: handle config changed and scan complete notification (Cédric Le Goater) [1660908]
- s390/vfio-ap: sysfs attribute to display the guest's matrix (Cédric Le Goater) [1660908]
- s390/vfio-ap: implement in-use callback for vfio_ap driver (Cédric Le Goater) [1660908]
- s390/vfio-ap: reset queues after adapter/domain unassignment (Cédric Le Goater) [1660908]
- s390/vfio-ap: hot plug/unplug of AP devices when probed/removed (Cédric Le Goater) [1660908]
- s390/vfio-ap: allow hot plug/unplug of AP devices when assigned/unassigned (Cédric Le Goater) [1660908]
- s390/vfio-ap: prepare for dynamic update of guest's APCB on queue probe/remove (Cédric Le Goater) [1660908]
- s390/vfio-ap: prepare for dynamic update of guest's APCB on assign/unassign (Cédric Le Goater) [1660908]
- s390/vfio-ap: use proper locking order when setting/clearing KVM pointer (Cédric Le Goater) [1660908]
- s390/vfio-ap: introduce new mutex to control access to the KVM pointer (Cédric Le Goater) [1660908]
- s390/vfio-ap: rename matrix_dev->lock mutex to matrix_dev->mdevs_lock (Cédric Le Goater) [1660908]
- s390/vfio-ap: allow assignment of unavailable AP queues to mdev device (Cédric Le Goater) [1660908]
- s390/vfio-ap: refresh guest's APCB by filtering AP resources assigned to mdev (Cédric Le Goater) [1660908]
- s390/vfio-ap: introduce shadow APCB (Cédric Le Goater) [1660908]
- s390/vfio-ap: manage link between queue struct and matrix mdev (Cédric Le Goater) [1660908]
- s390/vfio-ap: move probe and remove callbacks to vfio_ap_ops.c (Cédric Le Goater) [1660908]
- s390/vfio-ap: use new AP bus interface to search for queue devices (Cédric Le Goater) [1660908]
- s390/ap: fix error handling in __verify_queue_reservations() (Cédric Le Goater) [1660908]
- s390/zcrypt: code cleanup (Cédric Le Goater) [1660908]
- s390/zcrypt: fix wrong offset index for APKA master key valid state (Cédric Le Goater) [1660908]
- s390/ap: uevent on apmask/aqpmask change (Cédric Le Goater) [1660908]
- s390/vfio-ap: fix kernel doc and signature of group notifier functions (Cédric Le Goater) [1660908]
- s390/ap: enable sysfs attribute scans to force AP bus rescan (Cédric Le Goater) [1660908]
- s390/ap: fix crash on older machines based on QCI info missing (Cédric Le Goater) [1660908]
- s390/ap: notify drivers on config changed and scan complete callbacks (Cédric Le Goater) [1660908]
- s390/ap: driver callback to indicate resource in use (Cédric Le Goater) [1660908]
- MAINTAINERS: update file path for S390 VFIO AP DRIVER (Cédric Le Goater) [1660908]
- s390/vfio-ap: add status attribute to AP queue device's sysfs dir (Cédric Le Goater) [1660908]
- s390/ap: function rework based on compiler warning (Cédric Le Goater) [1660908]
- s390/vfio-ap: s390/crypto: fix all kernel-doc warnings (Cédric Le Goater) [1660908]
- s390/ap: new module option ap.useirq (Cédric Le Goater) [1660908]
- s390/ap: fix state machine hang after failure to enable irq (Cédric Le Goater) [1660908]
- s390/crypto: fix all kernel-doc warnings in vfio_ap_ops.c (Cédric Le Goater) [1660908]
- s390/ap: use the common device_driver pointer (Cédric Le Goater) [1660908]
- s390/vfio-ap: replace open coded locks for VFIO_GROUP_NOTIFY_SET_KVM notification (Cédric Le Goater) [1660908]
- s390/vfio-ap: r/w lock for PQAP interception handler function pointer (Cédric Le Goater) [1660908]
- s390/vfio-ap: clean up mdev resources when remove callback invoked (Cédric Le Goater) [1660908]
- s390/vfio-ap: clean up vfio_ap_drv's definition (Cédric Le Goater) [1660908]
- s390/vfio-ap: fix circular lockdep when setting/clearing crypto masks (Cédric Le Goater) [1660908]
- s390/vfio-ap: clean up vfio_ap resources when KVM pointer invalidated (Cédric Le Goater) [1660908]
- s390/vfio-ap: No need to disable IRQ after queue reset (Cédric Le Goater) [1660908]
- Documentation: s390/vfio-ap: eliminate duplicated word (Cédric Le Goater) [1660908]
- docs: s390: Fix wrong label Guest2 instead of Guest3 (Cédric Le Goater) [1660908]
- s390: vfio-ap: make local functions and data static (Cédric Le Goater) [1660908]
- i40e: Fix set max_tx_rate when it is lower than 1 Mbps (Petr Oros) [2106964]
- i40e: Fix VF set max MTU size (Petr Oros) [2106964]
- iavf: Fix set max MTU size with port VLAN and jumbo frames (Petr Oros) [2106964]
- iavf: Fix bad page state (Petr Oros) [2106964]
- i40e: Fix VF hang when reset is triggered on another VF (Ivan Vecera) [2103801]
- mpi3mr: a minor change (Tomas Henzl) [2115748]
- scsi: mpi3mr: Select CONFIG_SCSI_SAS_ATTRS (Tomas Henzl) [2115748]
- scsi: mpi3mr: Remove unnecessary cast (Tomas Henzl) [2115748]
- scsi: mpi3mr: Update driver version to 8.2.0.3.0 (Tomas Henzl) [2115748]
- scsi: mpi3mr: Fix scheduling while atomic type bug (Tomas Henzl) [2115748]
- scsi: mpi3mr: Scan the devices during resume time (Tomas Henzl) [2115748]
- scsi: mpi3mr: Free enclosure objects during driver unload (Tomas Henzl) [2115748]
- scsi: mpi3mr: Handle 0xF003 Fault Code (Tomas Henzl) [2115748]
- scsi: mpi3mr: Graceful handling of surprise removal of PCIe HBA (Tomas Henzl) [2115748]
- scsi: mpi3mr: Support new power management framework (Tomas Henzl) [2115748]
- scsi: mpi3mr: Update mpi3 header files (Tomas Henzl) [2115748]
- scsi: mpi3mr: Fix error code in mpi3mr_transport_smp_handler() (Tomas Henzl) [2115748]
- scsi: mpi3mr: Fix error codes in mpi3mr_report_manufacture() (Tomas Henzl) [2115748]
- scsi: mpi3mr: Block I/Os while refreshing target dev objects (Tomas Henzl) [2115748]
- scsi: mpi3mr: Refresh SAS ports during soft reset (Tomas Henzl) [2115748]
- scsi: mpi3mr: Support SAS transport class callbacks (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add framework to issue MPT transport cmds (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add SAS SATA end devices to STL (Tomas Henzl) [2115748]
- scsi: mpi3mr: Get target object based on rphy (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add expander devices to STL (Tomas Henzl) [2115748]
- scsi: mpi3mr: Enable STL on HBAs where multipath is disabled (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add helper functions to manage device's port (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add helper functions to retrieve device objects (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add framework to add phys to STL (Tomas Henzl) [2115748]
- scsi: mpi3mr: Enable Enclosure device add event (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add helper functions to retrieve config pages (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add framework to issue config requests (Tomas Henzl) [2115748]
- scsi: mpi3mr: Add config and transport related debug flags (Tomas Henzl) [2115748]
- scsi: mpi3mr: Delete a stray tab (Tomas Henzl) [2115748]
- scsi: mpi3mr: Unlock on error path (Tomas Henzl) [2115748]
- scsi: mpi3mr: Reduce VD queue depth on detecting throttling (Tomas Henzl) [2115748]
- scsi: mpi3mr: Resource Based Metering (Tomas Henzl) [2115748]
- scsi: mpi3mr: Increase cmd_per_lun to 128 (Tomas Henzl) [2115748]
- scsi: mpi3mr: Enable shared host tagset (Tomas Henzl) [2115748]
- lpfc version to 14.0.0.18. (Dick Kennedy) [2114050]
- scsi: lpfc: Create a sysfs entry called lpfc_xcvr_data for transceiver info (Dick Kennedy) [2114050]
- scsi: lpfc: Log when congestion management limits are in effect (Dick Kennedy) [2114050]
- scsi: lpfc: Fix hard lockup when reading the rx_monitor from debugfs (Dick Kennedy) [2114050]
- scsi: lpfc: Set sli4_param's cmf option to zero when CMF is turned off (Dick Kennedy) [2114050]
- scsi: lpfc: Fix various issues reported by tools (Dick Kennedy) [2114050]
- scsi: lpfc: Add reporting capability for Link Degrade Signaling (Dick Kennedy) [2114050]
- scsi: lpfc: Rework FDMI attribute registration for unintential padding (Dick Kennedy) [2114050]
- scsi: lpfc: Rework lpfc_fdmi_cmd() routine for cleanup and consistency (Dick Kennedy) [2114050]
- scsi: lpfc: Update congestion mode logging for Emulex SAN Manager application (Dick Kennedy) [2114050]
- scsi: lpfc: Fix multiple NVMe remoteport registration calls for the same NPort ID (Dick Kennedy) [2114050]
- scsi: lpfc: Add missing free iocb and nlp kref put for early return VMID cases (Dick Kennedy) [2114050]
- scsi: lpfc: Fix mbuf pool resource detected as busy at driver unload (Dick Kennedy) [2114050]
- scsi: lpfc: Fix FLOGI ACC with wrong SID in PT2PT topology (Dick Kennedy) [2114050]
- scsi: lpfc: Fix prli_fc4_req checks in PRLI handling (Dick Kennedy) [2114050]
- scsi: lpfc: Remove unneeded result variable (Dick Kennedy) [2114050]
- scsi: lpfc: Remove the unneeded result variable (Dick Kennedy) [2114050]
- scsi: lpfc: Copyright updates for 14.2.0.6 patches (Dick Kennedy) [2114050]
- scsi: lpfc: Add warning notification period to CMF_SYNC_WQE (Dick Kennedy) [2114050]
- scsi: lpfc: Rework MIB Rx Monitor debug info logic (Dick Kennedy) [2114050]
- scsi: lpfc: Fix null ndlp ptr dereference in abnormal exit path for GFT_ID (Dick Kennedy) [2114050]
- scsi: lpfc: Fix unsolicited FLOGI receive handling during PT2PT discovery (Dick Kennedy) [2114050]
- scsi: lpfc: Check the return value of alloc_workqueue() (Dick Kennedy) [2114050]
- scsi: lpfc: Rework FDMI initialization after link up (Dick Kennedy) [2114050]
- scsi: mpt3sas: Revert "scsi: mpt3sas: Fix ioc->base_readl() use" (Tomas Henzl) [2115763]
- scsi: mpt3sas: Revert "scsi: mpt3sas: Fix writel() use" (Tomas Henzl) [2115763]
- scsi: mpt3sas: Fix return value check of dma_get_required_mask() (Tomas Henzl) [2115763]
- scsi: mpt3sas: Fix use-after-free warning (Tomas Henzl) [2115763]
- scsi: mpt3sas: Update driver version to 43.100.00.00 (Tomas Henzl) [2115763]
- scsi: mpt3sas: Increase cmd_per_lun to 128 (Tomas Henzl) [2115763]
- scsi: mpt3sas: Fix trace buffer registration failed (Tomas Henzl) [2115763]
- scsi: mpt3sas: Don't change DMA mask while reallocating pools (Tomas Henzl) [2115763]
- scsi: mpt3sas: Prevent error handler escalation when device removed (Tomas Henzl) [2115763]
- scsi: mpt3sas: Disable MPI2_FUNCTION_FW_DOWNLOAD for ATTO devices (Tomas Henzl) [2115763]
- scsi: mpt3sas: Add support for ATTO ExpressSAS H12xx GT devices (Tomas Henzl) [2115763]
- scsi: mpt3sas: Remove flush_scheduled_work() call (Tomas Henzl) [2115763]
- scsi: mpt3sas: Fix whitespace and spelling mistake (Tomas Henzl) [2115763]
- scsi: mpt3sas: Fix typo in comment (Tomas Henzl) [2115763]
- scsi: mpt3sas: Fix out-of-bounds compiler warning (Tomas Henzl) [2115763]
- media: em28xx: initialize refcount before kref_get (Dean Nelson) [2128003] {CVE-2022-3239}
- gfs2: Register fs after creating workqueues (Bob Peterson) [2121201]
- sysctl: returns -EINVAL when a negative value is passed to proc_doulongvec_minmax (Vratislav Bendel) [2139096]
- mm/rmap: Fix anon_vma->degree ambiguity leading to double-reuse (Waiman Long) [2137585] {CVE-2022-42703}
- mm: rmap: explicitly reset vma->anon_vma in unlink_anon_vmas() (Waiman Long) [2137585] {CVE-2022-42703}
- mm/rmap: Fix typos in comments (Waiman Long) [2137585] {CVE-2022-42703}
- iavf: Fix set max MTU size with port VLAN and jumbo frames (Stefan Assmann) [2103944]
- iavf: Fix bad page state (Stefan Assmann) [2103944]
- iavf: Fix cached head and tail value for iavf_get_tx_pending (Stefan Assmann) [2103944]
- iavf: Fix change VF's mac address (Stefan Assmann) [2103944]
- iavf: Fix race between iavf_close and iavf_reset_task (Stefan Assmann) [2103944]
- net: ethernet: move from strlcpy with unused retval to strscpy (Stefan Assmann) [2103944]
- iavf: Fix 'tc qdisc show' listing too many queues (Stefan Assmann) [2103944]
- iavf: Fix max_rate limiting (Stefan Assmann) [2103944]
- iavf: Check for duplicate TC flower filter before parsing (Stefan Assmann) [2103944]
- iavf: Fix handling of dummy receive descriptors (Stefan Assmann) [2103944]
- iavf: Disallow changing rx/tx-frames and rx/tx-frames-irq (Stefan Assmann) [2103944]
- intel/iavf:fix repeated words in comments (Stefan Assmann) [2103944]
- intel: remove unused macros (Stefan Assmann) [2103944]
- iavf: Add waiting for response from PF in set mac (Stefan Assmann) [2103944]
- iavf: Use irq_update_affinity_hint() (Stefan Assmann) [2103944]
- net: Fix return value of qdisc ingress handling on success (Ivan Vecera) [2131361]

* Mon Nov 14 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-438.el8]
- PCI: hv: Do not set PCI_COMMAND_MEMORY to reduce VM boot time (Emanuele Giuseppe Esposito) [2082836]
- megaraid_sas: add #ifdef CONFIG_RHEL_DIFFERENCES (Tomas Henzl) [2119096]
- mpt3sas: add #ifdef CONFIG_RHEL_DIFFERENCES (Tomas Henzl) [2119096]
- mptcp: fix unreleased socket in accept queue (Paolo Abeni) [2135884]
- mptcp: factor out __mptcp_close() without socket lock (Paolo Abeni) [2135884]
- mptcp: do not queue data on closed subflows (Paolo Abeni) [2135884]
- mptcp: move subflow cleanup in mptcp_destroy_common() (Paolo Abeni) [2135884]
- mptcp: fix msk traversal in mptcp_nl_cmd_set_flags() (Paolo Abeni) [2135884]
- xfs: fix perag reference leak on iteration race with growfs (Brian Foster) [2081105]
- xfs: terminate perag iteration reliably on agcount (Brian Foster) [2081105]
- xfs: rename the next_agno perag iteration variable (Brian Foster) [2081105]
- xfs: fold perag loop iteration logic into helper function (Brian Foster) [2081105]
- xfs: prevent spoofing of rtbitmap blocks when recovering buffers (Brian Foster) [2081105]
- xfs: Enforce attr3 buffer recovery order (Brian Foster) [2081105]
- xfs: avoid unnecessary waits in xfs_log_force_lsn() (Brian Foster) [2081105]
- xfs: factor out forced iclog flushes (Brian Foster) [2081105]
- xfs: detect misaligned rtinherit directory extent size hints (Brian Foster) [2081105]
- xfs: fix an integer overflow error in xfs_growfs_rt (Brian Foster) [2081105]
- xfs: improve FSGROWFSRT precondition checking (Brian Foster) [2081105]
- xfs: reset child dir '..' entry when unlinking child (Brian Foster) [2081105]
- xfs: check for sparse inode clusters that cross new EOAG when shrinking (Brian Foster) [2081105]
- xfs: Fix multiple fall-through warnings for Clang (Brian Foster) [2081105]
- xfs: remove callback dequeue loop from xlog_state_do_iclog_callbacks (Brian Foster) [2081105]
- xfs: don't nest icloglock inside ic_callback_lock (Brian Foster) [2081105]
- xfs: Initialize error in xfs_attr_remove_iter (Brian Foster) [2081105]
- xfs: remove dead stale buf unpin handling code (Brian Foster) [2081105]
- xfs: hold buffer across unpin and potential shutdown processing (Brian Foster) [2081105]
- xfs: force the log offline when log intent item recovery fails (Brian Foster) [2081105]
- xfs: shorten the shutdown messages to a single line (Brian Foster) [2081105]
- xfs: print name of function causing fs shutdown instead of hex pointer (Brian Foster) [2081105]
- xfs: fix type mismatches in the inode reclaim functions (Brian Foster) [2081105]
- xfs: separate primary inode selection criteria in xfs_iget_cache_hit (Brian Foster) [2081105]
- xfs: refactor the inode recycling code (Brian Foster) [2081105]
- xfs: add iclog state trace events (Brian Foster) [2081105]
- xfs: xfs_log_force_lsn isn't passed a LSN (Brian Foster) [2081105]
- xfs: remove need_start_rec parameter from xlog_write() (Brian Foster) [2081105]
- xfs: remove xfs_blkdev_issue_flush (Brian Foster) [2081105]
- xfs: Fix 64-bit division on 32-bit in xlog_state_switch_iclogs() (Brian Foster) [2081105]
- xfs: log stripe roundoff is a property of the log (Brian Foster) [2081105]
- xfs: remove redundant initialization of variable error (Brian Foster) [2081105]
- xfs: perag may be null in xfs_imap() (Brian Foster) [2081105]
- xfs: Make attr name schemes consistent (Brian Foster) [2081105]
- xfs: Fix default ASSERT in xfs_attr_set_iter (Brian Foster) [2081105]
- xfs: rename struct xfs_eofblocks to xfs_icwalk (Brian Foster) [2081105]
- xfs: change the prefix of XFS_EOF_FLAGS_* to XFS_ICWALK_FLAG_ (Brian Foster) [2081105]
- xfs: selectively keep sick inodes in memory (Brian Foster) [2081105]
- xfs: drop IDONTCACHE on inodes when we mark them sick (Brian Foster) [2081105]
- xfs: drop the AGI being passed to xfs_check_agi_freecount (Brian Foster) [2081105]
- xfs: cleanup error handling in xfs_buf_get_map (Brian Foster) [2081105]
- xfs: remove ->b_offset handling for page backed buffers (Brian Foster) [2081105]
- xfs: refactor per-AG inode tagging functions (Brian Foster) [2081105]
- xfs: merge xfs_reclaim_inodes_ag into xfs_inode_walk_ag (Brian Foster) [2081105]
- xfs: pass struct xfs_eofblocks to the inode scan callback (Brian Foster) [2081105]
- xfs: make the icwalk processing functions clean up the grab state (Brian Foster) [2081105]
- xfs: clean up inode state flag tests in xfs_blockgc_igrab (Brian Foster) [2081105]
- xfs: remove indirect calls from xfs_inode_walk{,_ag} (Brian Foster) [2081105]
- xfs: remove iter_flags parameter from xfs_inode_walk_* (Brian Foster) [2081105]
- xfs: move xfs_inew_wait call into xfs_dqrele_inode (Brian Foster) [2081105]
- xfs: separate the dqrele_all inode grab logic from xfs_inode_walk_ag_grab (Brian Foster) [2081105]
- xfs: pass the goal of the incore inode walk to xfs_inode_walk() (Brian Foster) [2081105]
- xfs: rename xfs_inode_walk functions to xfs_icwalk (Brian Foster) [2081105]
- xfs: move the inode walk functions further down (Brian Foster) [2081105]
- xfs: detach inode dquots at the end of inactivation (Brian Foster) [2081105]
- xfs: move the quotaoff dqrele inode walk into xfs_icache.c (Brian Foster) [2081105]
- xfs: don't take a spinlock unconditionally in the DIO fastpath (Brian Foster) [2081105]
- xfs: mark xfs_bmap_set_attrforkoff static (Brian Foster) [2081105]
- xfs: Remove redundant assignment to busy (Brian Foster) [2081105]
- xfs: sort variable alphabetically to avoid repeated declaration (Brian Foster) [2081105]
- xfs: remove xfs_perag_t (Brian Foster) [2081105]
- xfs: use perag through unlink processing (Brian Foster) [2081105]
- xfs: clean up and simplify xfs_dialloc() (Brian Foster) [2081105]
- xfs: inode allocation can use a single perag instance (Brian Foster) [2081105]
- xfs: get rid of xfs_dir_ialloc() (Brian Foster) [2081105]
- xfs: collapse AG selection for inode allocation (Brian Foster) [2081105]
- xfs: simplify xfs_dialloc_select_ag() return values (Brian Foster) [2081105]
- xfs: remove agno from btree cursor (Brian Foster) [2081105]
- xfs: use perag for ialloc btree cursors (Brian Foster) [2081105]
- xfs: convert allocbt cursors to use perags (Brian Foster) [2081105]
- xfs: convert refcount btree cursor to use perags (Brian Foster) [2081105]
- xfs: convert rmap btree cursor to using a perag (Brian Foster) [2081105]
- xfs: add a perag to the btree cursor (Brian Foster) [2081105]
- xfs: pass perags around in fsmap data dev functions (Brian Foster) [2081105]
- xfs: push perags through the ag reservation callouts (Brian Foster) [2081105]
- xfs: pass perags through to the busy extent code (Brian Foster) [2081105]
- xfs: convert secondary superblock walk to use perags (Brian Foster) [2081105]
- xfs: convert xfs_iwalk to use perag references (Brian Foster) [2081105]
- xfs: convert raw ag walks to use for_each_perag (Brian Foster) [2081105]
- xfs: make for_each_perag... a first class citizen (Brian Foster) [2081105]
- xfs: move perag structure and setup to libxfs/xfs_ag.[ch] (Brian Foster) [2081105]
- xfs: prepare for moving perag definitions and support to libxfs (Brian Foster) [2081105]
- xfs: move xfs_perag_get/put to xfs_ag.[ch] (Brian Foster) [2081105]
- xfs: remove unnecessary shifts (Brian Foster) [2081105]
- xfs: clean up open-coded fs block unit conversions (Brian Foster) [2081105]
- xfs: Clean up xfs_attr_node_addname_clear_incomplete (Brian Foster) [2081105]
- xfs: Remove xfs_attr_rmtval_set (Brian Foster) [2081105]
- xfs: Add delay ready attr set routines (Brian Foster) [2081105]
- xfs: Add delay ready attr remove routines (Brian Foster) [2081105]
- xfs: Hoist node transaction handling (Brian Foster) [2081105]
- xfs: Hoist xfs_attr_leaf_addname (Brian Foster) [2081105]
- xfs: Hoist xfs_attr_node_addname (Brian Foster) [2081105]
- xfs: Add helper xfs_attr_node_addname_find_attr (Brian Foster) [2081105]
- xfs: Separate xfs_attr_node_addname and xfs_attr_node_addname_clear_incomplete (Brian Foster) [2081105]
- xfs: Refactor xfs_attr_set_shortform (Brian Foster) [2081105]
- xfs: Add xfs_attr_node_remove_name (Brian Foster) [2081105]
- xfs: Reverse apply 72b97ea40d (Brian Foster) [2081105]
- xfs: use xfs_buf_alloc_pages for uncached buffers (Brian Foster) [2081105]
- xfs: split up xfs_buf_allocate_memory (Brian Foster) [2081105]
- xfs: Fix fall-through warnings for Clang (Brian Foster) [2081105]
- scsi: qla2xxx: Use transport-defined speed mask for supported_speeds (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix serialization of DCBX TLV data request (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove unused declarations for qla2xxx (Nilesh Javali) [2109830]
- scsi: qla2xxx: Drop DID_TARGET_FAILURE use (Nilesh Javali) [2109830]
- scsi: qla2xxx: Update version to 10.02.07.900-k (Nilesh Javali) [2109830]
- scsi: qla2xxx: Add NVMe parameters support in Auxiliary Image Status (Nilesh Javali) [2109830]
- scsi: qla2xxx: Add debugfs create/delete helpers (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix response queue handler reading stale packets (Nilesh Javali) [2109830]
- scsi: qla2xxx: Revert "scsi: qla2xxx: Fix response queue handler reading stale packets" (Nilesh Javali) [2109830]
- scsi: qla2xxx: Log message "skipping scsi_scan_host()" as informational (Nilesh Javali) [2109830]
- scsi: qla2xxx: Avoid flush_scheduled_work() usage (Nilesh Javali) [2109830]
- scsi: qla2xxx: Always wait for qlt_sess_work_fn() from qlt_stop_phase1() (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove unused del_sess_list field (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove unused qlt_tmr_work() (Nilesh Javali) [2109830]
- scsi: qla2xxx: Update version to 10.02.07.800-k (Nilesh Javali) [2109830]
- scsi: qla2xxx: Update manufacturer details (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix discovery issues in FC-AL topology (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix dropped IKE message (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix response queue handler reading stale packets (Nilesh Javali) [2109830]
- scsi: qla2xxx: Zero undefined mailbox IN registers (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix incorrect display of max frame size (Nilesh Javali) [2109830]
- scsi: qla2xxx: Check correct variable in qla24xx_async_gffid() (Nilesh Javali) [2109830]
- scsi: qla2xxx: Update version to 10.02.07.700-k (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix losing FCP-2 targets on long port disable with I/Os (Nilesh Javali) [2109830]
- scsi: qla2xxx: Add debug prints in the device remove path (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix losing target when it reappears during delete (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix losing FCP-2 targets during port perturbation tests (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix crash due to stale SRB access around I/O timeouts (Nilesh Javali) [2109830]
- scsi: qla2xxx: Turn off multi-queue for 8G adapters (Nilesh Javali) [2109830]
- scsi: qla2xxx: Wind down adapter after PCIe error (Nilesh Javali) [2109830]
- scsi: qla2xxx: Update version to 10.02.07.600-k (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix slow session teardown (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Reduce N2N thrashing at app_start time (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix no logout on delete for N2N (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix session thrash (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Tear down session if keys have been removed (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix no login after app start (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Reduce disruption due to multiple app start (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Send LOGO for unexpected IKE message (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix I/O timeout due to over-subscription (Nilesh Javali) [2109830]
- scsi: qla2xxx: Update version to 10.02.07.500-k (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix n2n login retry for secure device (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix n2n discovery issue with secure target (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Remove old doorbell interface (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Add retry for ELS passthrough (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Synchronize NPIV deletion with authentication application (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Fix potential stuck session in sa update (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Add bsg interface to read doorbell events (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Wait for app to ack on sess down (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: bsg refactor (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Reduce Initiator-Initiator thrashing (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove unused 'ql_dm_tgt_ex_pct' parameter (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove setting of 'req' and 'rsp' parameters (Nilesh Javali) [2109830]
- scsi: qla2xxx: Fix missed DMA unmap for aborted commands (Nilesh Javali) [2109830]
- scsi: qla2xxx: edif: Remove unneeded variable (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove unneeded flush_workqueue() (Nilesh Javali) [2109830]
- scsi: qla2xxx: Remove free_sg command flag (Nilesh Javali) [2109830]
- scsi: megaraid_sas: Clean up some inconsistent indenting (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Move megasas_dbg_lvl init to megasas_init() (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Remove unnecessary memset() (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Simplify megasas_update_device_list (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Correct an error message (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Correct value passed to scsi_device_lookup() (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Use struct_size() in code related to struct MR_PD_CFG_SEQ_NUM_SYNC (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Use struct_size() in code related to struct MR_FW_RAID_MAP (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_PD_CFG_SEQ_NUM_SYNC (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_DRV_RAID_MAP (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_FW_RAID_MAP_DYNAMIC (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_FW_RAID_MAP (Tomas Henzl) [2120070]
- scsi: megaraid: Remove redundant assignment to variable mfiStatus (Tomas Henzl) [2120070]
- scsi: megaraid_sas: Remove redundant variable cmd_type (Tomas Henzl) [2120070]
- platform/x86/intel/vsec: Fix wrong type for local status variables (Prarit Bhargava) [2076744]
- platform/x86/intel/vsec: Add PCI error recovery support to Intel PMT (Prarit Bhargava) [2076744]
- platform/x86/intel/vsec: Add support for Raptor Lake (Prarit Bhargava) [2076744]
- platform/x86/intel/pmt: telemetry: Fix fixed region handling (Prarit Bhargava) [2076744]
- platform/x86/intel/vsec: Rework early hardware code (Prarit Bhargava) [2076744]
- platform/x86/intel: Fix pmt_crashlog array reference (Prarit Bhargava) [2076744]
- powerpc/kexec_file: Use current CPU info while setting up FDT (Mamatha Inamdar) [2126520]
- mm/kmemleak: prevent soft lockup in kmemleak_scan()'s object iteration loops (Waiman Long) [2095075]
- mm/kmemleak: prevent soft lockup in first object iteration loop of kmemleak_scan() (Waiman Long) [2095075]
- mm/kmemleak: skip unlikely objects in kmemleak_scan() without taking lock (Waiman Long) [2095075]
- mm/kmemleak: use _irq lock/unlock variants in kmemleak_scan/_clear() (Waiman Long) [2095075]
- mm/kmemleak: avoid scanning potential huge holes (Waiman Long) [2095075]
- KVM: s390: pci: fix GAIT physical vs virtual pointers usage (Thomas Huth) [1664379]
- KVM: s390: pci: fix plain integer as NULL pointer warnings (Thomas Huth) [1664379]
- KVM: s390/pci: fix include duplicates (Thomas Huth) [1664379]
- redhat: Use group notifier to get the KVM pointer in the vfio_pci_zdev code (Thomas Huth) [1664379]
- KVM: s390: pci: register pci hooks without interpretation (Thomas Huth) [1664379]
- KVM: s390: pci: Hook to access KVM lowlevel from VFIO (Thomas Huth) [1664379]
- Documentation: kvm: extend KVM_S390_ZPCI_OP subheading underline (Thomas Huth) [1664379]
- KVM: s390: add KVM_S390_ZPCI_OP to manage guest zPCI devices (Thomas Huth) [1664379]
- vfio-pci/zdev: different maxstbl for interpreted devices (Thomas Huth) [1664379]
- vfio-pci/zdev: add function handle to clp base capability (Thomas Huth) [1664379]
- vfio-pci/zdev: add open/close device hooks (Thomas Huth) [1664379]
- KVM: s390: pci: add routines to start/stop interpretive execution (Thomas Huth) [1664379]
- KVM: s390: pci: provide routines for enabling/disabling interrupt forwarding (Thomas Huth) [1664379]
- KVM: s390: mechanism to enable guest zPCI Interpretation (Thomas Huth) [1664379]
- KVM: s390: pci: enable host forwarding of Adapter Event Notifications (Thomas Huth) [1664379]
- KVM: s390: pci: do initial setup for AEN interpretation (Thomas Huth) [1664379]
- KVM: s390: pci: add basic kvm_zdev structure (Thomas Huth) [1664379]
- redhat: Enable the new CONFIG_VFIO_PCI_ZDEV_KVM switch (Thomas Huth) [1664379]
- vfio/pci: introduce CONFIG_VFIO_PCI_ZDEV_KVM (Thomas Huth) [1664379]
- vfio/pci: remove CONFIG_VFIO_PCI_ZDEV from Kconfig (Thomas Huth) [1664379]
- vfio-pci/zdev: fix possible segmentation fault issue (Thomas Huth) [1664379]
- s390/pci: stash dtsm and maxstbl (Thomas Huth) [1664379]
- s390/pci: stash associated GISA designation (Thomas Huth) [1664379]
- s390/pci: externalize the SIC operation controls and routine (Thomas Huth) [1664379]
- s390/airq: allow for airq structure that uses an input vector (Thomas Huth) [1664379]
- s390/airq: pass more TPI info to airq handlers (Thomas Huth) [1664379]
- s390/cio: add tpi.h header file (Thomas Huth) [1664379]
- s390/ap: fix kernel doc comments (Thomas Huth) [1664379]
- s390/sclp: detect the AISI facility (Thomas Huth) [1664379]
- s390/sclp: detect the AENI facility (Thomas Huth) [1664379]
- s390/sclp: detect the AISII facility (Thomas Huth) [1664379]
- s390/sclp: detect the zPCI load/store interpretation facility (Thomas Huth) [1664379]
- s390/sclp: add detection of IPL-complete-control facility (Thomas Huth) [1664379]
- s390/pci: add error record for CC 2 retries (Thomas Huth) [2134399]
- s390/pci: add PCI access type and length to error records (Thomas Huth) [2134399]
- s390/pci: don't log availability events as errors (Thomas Huth) [2134399]
- s390/pci: make better use of zpci_dbg() levels (Thomas Huth) [2134399]
- s390/pci: rename get_zdev_by_bus() to zdev_from_bus() (Thomas Huth) [2134399]
- redhat: Restore clp_rescan_pci_devices_simple() function (Thomas Huth) [2134399]
- s390/pci: improve zpci_dev reference counting (Thomas Huth) [2134399]
- s390/pci: make zpci_set_irq()/zpci_clear_irq() static (Thomas Huth) [2134399]
- s390/pci: simplify __pciwb_mio() inline asm (Thomas Huth) [2134399]
- s390/pci: use physical addresses in DMA tables (Thomas Huth) [2134399]
- s390/pci: use phys_to_virt() for AIBVs/DIBVs (Thomas Huth) [2134399]
- s390/pci: implement minimal PCI error recovery (Thomas Huth) [2134399]
- PCI: Export pci_dev_lock() (Thomas Huth) [2134399]
- PCI: Export pci_dev_trylock() and pci_dev_unlock() (Thomas Huth) [2134399]
- s390/pci: implement reset_slot for hotplug slot (Thomas Huth) [2134399]
- s390/pci: refresh function handle in iomap (Thomas Huth) [2134399]
- s390/pci: add simpler s390dbf traces for events (Thomas Huth) [2134399]
- s390/pci: tolerate inconsistent handle in recover (Thomas Huth) [2134399]
- s390/pci_mmio: fully validate the VMA before calling follow_pte() (Thomas Huth) [2134399]
- s390/pci: read clp_list_pci_req only once (Thomas Huth) [2134399]
- s390/pci: fix clp_get_state() handling of -ENODEV (Thomas Huth) [2134399]
- s390/pci: improve DMA translation init and exit (Thomas Huth) [2134399]
- s390/pci: simplify CLP List PCI handling (Thomas Huth) [2134399]
- s390/pci: handle FH state mismatch only on disable (Thomas Huth) [2134399]
- s390/pci: fix misleading rc in clp_set_pci_fn() (Thomas Huth) [2134399]
- s390/pci: reset zdev->zbus on registration failure (Thomas Huth) [2134399]
- s390/pci: cleanup resources only if necessary (Thomas Huth) [2134399]
- s390/pci: add zpci_set_irq()/zpci_clear_irq() (Thomas Huth) [2134399]
- s390/pci: use register pair instead of register asm (Thomas Huth) [2134399]
- s390: introduce register pair union (Thomas Huth) [2134399]
- s390/pci: handle stale deconfiguration events (Thomas Huth) [2134399]
- s390/pci: rename zpci_configure_device() (Thomas Huth) [2134399]
- s390/pci: narrow scope of zpci_configure_device() (Thomas Huth) [2134399]
- s390/pci: separate zbus registration from scanning (Thomas Huth) [2134399]
- s390/pci: use mutex not spinlock for zbus list (Thomas Huth) [2134399]
- s390/pci: separate zbus creation from scanning (Thomas Huth) [2134399]
- s390/pci: do more bus setup in zpci_bus_scan() (Thomas Huth) [2134399]
- s390/pci: introduce zpci_bus_scan_device() (Thomas Huth) [2134399]
- s390/pci: fix DMA cleanup on hard deconfigure (Thomas Huth) [2134399]
- s390/pci: move zpci_remove_device() to bus code (Thomas Huth) [2134399]
- s390/pci: unify de-/configure for slots and events (Thomas Huth) [2134399]
- s390/pci: add zpci_event_hard_deconfigured() (Thomas Huth) [2134399]
- s390/pci: deconfigure device on release (Thomas Huth) [2134399]
- s390/pci: refactor zpci function states (Thomas Huth) [2134399]
- s390/pci: inform when missing required facilities (Thomas Huth) [2134399]
- s390/pci: remove races against pte updates (Thomas Huth) [2134399]
- s390: remove orphaned function declarations (Thomas Huth) [2134399]
- s390/pci: add missing pci_iov.h include (Thomas Huth) [2134399]
- s390/pci: remove clp_rescan_pci_devices_simple() (Thomas Huth) [2134399]
- s390/pci: remove clp_rescan_pci_devices() (Thomas Huth) [2134399]
- s390/pci: consolidate SR-IOV specific code (Thomas Huth) [2134399]
- s390/pci: Implement ioremap_wc/prot() with MIO (Thomas Huth) [2134399]
- s390/mm: properly clear _PAGE_NOEXEC bit when it is not supported (Thomas Huth) [2134399]
- s390/pci: clarify comment in s390_mmio_read/write (Thomas Huth) [2134399]
- s390/pci: remove unused functions (Thomas Huth) [2134399]
- s390/pci: Log new handle in clp_disable_fh() (Thomas Huth) [2134399]
- s390/pci: ioremap() align with generic code (Thomas Huth) [2134399]
- s390: enforce CONFIG_SMP (Thomas Huth) [2134399]
- s390/pci: mark function(s) __always_inline (Thomas Huth) [2134399]
- s390/pci: avoid using strncmp with hardcoded length (Thomas Huth) [2134399]
- s390/pci: PCI_IOV_RESOURCES loop refactoring in zpci_map_resources (Thomas Huth) [2134399]
- s390: pci: no need to check return value of debugfs_create functions (Thomas Huth) [2134399]
- s390/pci: fix sleeping in atomic during hotplug (Thomas Huth) [2134399]
- s390/pci: remove fmb address from debug output (Thomas Huth) [2134399]
- s390/pci: add fmt3 fmb (Thomas Huth) [2134399]
- tools headers kvm s390: Sync headers with the kernel sources (Thomas Huth) [2111063]
- KVM: s390: resetting the Topology-Change-Report (Thomas Huth) [2111063]
- KVM: s390: guest support for topology function (Thomas Huth) [2111063]
- KVM: s390: Cleanup ipte lock access and SIIF facility checks (Thomas Huth) [2111063]
- KVM: s390: drop unexpected word 'and' in the comments (Thomas Huth) [2111063]
- Documentation: KVM: update s390-diag.rst reference (Thomas Huth) [2043872]
- Documentation: KVM: update msr.rst reference (Thomas Huth) [2043872]
- Documentation: KVM: update amd-memory-encryption.rst references (Thomas Huth) [2043872]
- Documentation: KVM: update s390-pv.rst reference (Thomas Huth) [2043872]
- Documentation/virt/kvm/api.rst: Explain rc/rrc delivery (Thomas Huth) [2043872]
- Documentation/virt/kvm/api.rst: Add protvirt dump/info api descriptions (Thomas Huth) [2043872]
- Documentation: KVM: add API issues section (Thomas Huth) [2043872]
- Documentation: virt: Protected virtual machine dumps (Thomas Huth) [2043872]
- Documentation: KVM: add separate directories for architecture-specific documentation (Thomas Huth) [2043872]
- KVM: s390: Add KVM_CAP_S390_PROTECTED_DUMP (Thomas Huth) [2043872]
- KVM: s390: Add CPU dump functionality (Thomas Huth) [2043872]
- KVM: s390: Add configuration dump functionality (Thomas Huth) [2043872]
- KVM: s390: pv: Add query dump information (Thomas Huth) [2043872]
- KVM: s390: pv: Add dump support definitions (Thomas Huth) [2043872]
- KVM: s390: pv: Add query interface (Thomas Huth) [2043872]
- s390/uv: Add dump fields to query (Thomas Huth) [2043872]
- s390/uv: Add SE hdr query information (Thomas Huth) [2043872]
- kvm: Move KVM_GET_XSAVE2 IOCTL definition at the end of kvm.h (Thomas Huth) [2043872]
- docs: kvm: fix WARNINGs from api.rst (Thomas Huth) [2043872]
- s390/mm: use non-quiescing sske for KVM switch to keyed guest (Thomas Huth) [2043872]
- s390/gmap: voluntarily schedule during key setting (Thomas Huth) [2043872]
- KVM: s390: Don't indicate suppression on dirtying, failing memop (Thomas Huth) [2043872]
- s390: uv: Add offset comments to UV query struct and fix naming (Thomas Huth) [2043872]
- KVM: s390: Use Makefile.kvm for common files (Thomas Huth) [2043872]
- KVM: s390: Skip gfn/size sanity checks on memslot DELETE or FLAGS_ONLY (Thomas Huth) [2043872]
- fs: dlm: fix invalid derefence of sb_lvbptr (Alexander Aring) [2121790]
- fs: dlm: handle -EBUSY first in unlock validation (Alexander Aring) [2121790]
- fs: dlm: handle -EBUSY first in lock arg validation (Alexander Aring) [2121790]
- fs: dlm: fix race between test_bit() and queue_work() (Alexander Aring) [2121790]
- scsi: core: Fix a use-after-free (Ming Lei) [1961010]
- net/mlx5e: Fix wrong use of skb_tcp_all_headers() with encapsulation (Petr Oros) [2135685]
- net: add skb_[inner_]tcp_all_headers helpers (Petr Oros) [2135685]
- net: marvell: clean up trigraph warning on ??! string (Petr Oros) [2135685]
- powerpc/pseries: Use lparcfg to reconfig VAS windows for DLPAR CPU (Steve Best) [2133103]
- flow_dissector: Do not count vlan tags inside tunnel payload (Ivan Vecera) [2136875]
- flow_offload: Introduce flow_match_pppoe (Ivan Vecera) [2136875]
- net/sched: flower: Add PPPoE filter (Ivan Vecera) [2136875]
- flow_dissector: Add PPPoE dissectors (Ivan Vecera) [2136875]
- net/sched: flower: Consider the number of tags for vlan filters (Ivan Vecera) [2136875]
- net/sched: flower: Add number of vlan tags filter (Ivan Vecera) [2136875]
- flow_dissector: Add number of vlan tags dissector (Ivan Vecera) [2136875]
- net/sched: flower: Reduce identation after is_key_vlan refactoring (Ivan Vecera) [2136875]
- net/sched: flower: Helper function for vlan ethtype checks (Ivan Vecera) [2136875]
- dissector: do not set invalid PPP protocol (Ivan Vecera) [2136875]
- dm bufio: use the acquire memory barrier when testing for B_READING (Benjamin Marzinski) [2139161]
- provide arch_test_bit_acquire for architectures that define test_bit (Benjamin Marzinski) [2139161]
- wait_on_bit: add an acquire memory barrier (Benjamin Marzinski) [2139161]
- add barriers to buffer_uptodate and set_buffer_uptodate (Benjamin Marzinski) [2139161]
- dm verity: Add documentation for try_verify_in_tasklet option (Benjamin Marzinski) [2139161]
- dm cache: delete the redundant word 'each' in comment (Benjamin Marzinski) [2139161]
- dm raid: fix typo in analyse_superblocks code comment (Benjamin Marzinski) [2139161]
- dm verity: enable WQ_HIGHPRI on verify_wq (Benjamin Marzinski) [2139161]
- dm raid: delete the redundant word 'that' in comment (Benjamin Marzinski) [2139161]
- dm: change from DMWARN to DMERR or DMCRIT for fatal errors (Benjamin Marzinski) [2139161]
- dm bufio: fix some cases where the code sleeps with spinlock held (Benjamin Marzinski) [2139161]
- dm writecache: fix smatch warning about invalid return from writecache_map (Benjamin Marzinski) [2139161]
- dm verity: fix verity_parse_opt_args parsing (Benjamin Marzinski) [2139161]
- dm verity: fix DM_VERITY_OPTS_MAX value yet again (Benjamin Marzinski) [2139161]
- dm bufio: simplify DM_BUFIO_CLIENT_NO_SLEEP locking (Benjamin Marzinski) [2139161]
- dm verity: have verify_wq use WQ_HIGHPRI if "try_verify_in_tasklet" (Benjamin Marzinski) [2139161]
- dm verity: remove WQ_CPU_INTENSIVE flag since using WQ_UNBOUND (Benjamin Marzinski) [2139161]
- dm verity: only copy bvec_iter in verity_verify_io if in_tasklet (Benjamin Marzinski) [2139161]
- dm verity: optimize verity_verify_io if FEC not configured (Benjamin Marzinski) [2139161]
- dm verity: conditionally enable branching for "try_verify_in_tasklet" (Benjamin Marzinski) [2139161]
- dm bufio: conditionally enable branching for DM_BUFIO_CLIENT_NO_SLEEP (Benjamin Marzinski) [2139161]
- dm verity: allow optional args to alter primary args handling (Benjamin Marzinski) [2139161]
- dm verity: Add optional "try_verify_in_tasklet" feature (Benjamin Marzinski) [2139161]
- dm bufio: Add DM_BUFIO_CLIENT_NO_SLEEP flag (Benjamin Marzinski) [2139161]
- dm bufio: Add flags argument to dm_bufio_client_create (Benjamin Marzinski) [2139161]
- dm: Start pr_preempt from the same starting path (Benjamin Marzinski) [2139161]
- dm: Fix PR release handling for non All Registrants (Benjamin Marzinski) [2139161]
- dm: Start pr_reserve from the same starting path (Benjamin Marzinski) [2139161]
- dm: Allow dm_call_pr to be used for path searches (Benjamin Marzinski) [2139161]
- Documentation: dm writecache: Render status list as list (Benjamin Marzinski) [2139161]
- Documentation: dm writecache: add blank line before optional parameters (Benjamin Marzinski) [2139161]
- dm snapshot: fix typo in snapshot_map() comment (Benjamin Marzinski) [2139161]
- dm raid: remove redundant "the" in parse_raid_params() comment (Benjamin Marzinski) [2139161]
- dm cache: fix typo in 2 comment blocks (Benjamin Marzinski) [2139161]
- dm verity: fix checkpatch close brace error (Benjamin Marzinski) [2139161]
- dm table: rename dm_target variable in dm_table_add_target() (Benjamin Marzinski) [2139161]
- dm table: audit all dm_table_get_target() callers (Benjamin Marzinski) [2139161]
- dm table: remove dm_table_get_num_targets() wrapper (Benjamin Marzinski) [2139161]
- writeback: Avoid skipping inode writeback (Waiman Long) [2138886]
- writeback: fix obtain a reference to a freeing memcg css (Waiman Long) [2138886]
- mm/memcg: disable threshold event handlers on PREEMPT_RT (Waiman Long) [2138886]
- memcg: increase MEMCG_CHARGE_BATCH to 64 (Waiman Long) [2138886]
- mm: page_counter: rearrange struct page_counter fields (Waiman Long) [2138886]
- mm: page_counter: remove unneeded atomic ops for low/min (Waiman Long) [2138886]
- memcg: reduce size of memcg vmstats structures (Waiman Long) [2138886]
- memcg: rearrange code (Waiman Long) [2138886]
- memcg: extract memcg_vmstats from struct mem_cgroup (Waiman Long) [2138886]
- mm: memcontrol: fix potential oom_lock recursion deadlock (Waiman Long) [2138886]
- mm: memcontrol: add {pgscan,pgsteal}_{kswapd,direct} items in memory.stat of cgroup v2 (Waiman Long) [2138886]
- mm/memcg: protect per-CPU counter by disabling preemption on PREEMPT_RT where needed. (Waiman Long) [2138886]
- writeback: memcg: simplify cgroup_writeback_by_id (Waiman Long) [2138886]
- writeback, cgroup: do not reparent dax inodes (Waiman Long) [2138886]
- writeback, cgroup: remove wb from offline list before releasing refcnt (Waiman Long) [2138886]
- writeback, cgroup: release dying cgwbs by switching attached inodes (Waiman Long) [2138886]
- writeback, cgroup: support switching multiple inodes at once (Waiman Long) [2138886]
- writeback, cgroup: split out the functional part of inode_switch_wbs_work_fn() (Waiman Long) [2138886]
- writeback, cgroup: keep list of inodes attached to bdi_writeback (Waiman Long) [2138886]
- writeback, cgroup: switch to rcu_work API in inode_switch_wbs() (Waiman Long) [2138886]
- writeback, cgroup: increment isw_nr_in_flight before grabbing an inode (Waiman Long) [2138886]
- writeback, cgroup: add smp_mb() to cgroup_writeback_umount() (Waiman Long) [2138886]
- writeback, cgroup: do not switch inodes with I_WILL_FREE flag (Waiman Long) [2138886]
- docs/admin-guide: cgroup-v2: typos and spaces (Waiman Long) [2138886]
- fs: improve comments for writeback_single_inode() (Waiman Long) [2138886]
- writeback: remove struct bdi_writeback_congested (Waiman Long) [2138886]
- writeback: remove {set,clear}_wb_congested (Waiman Long) [2138886]
- fs/writeback.c: use rcu_barrier() to wait for inflight wb switches going into workqueue when umount (Waiman Long) [2138886]
- blkcg: remove unused __blkg_release_rcu() (Waiman Long) [2138886]
- writeback: Add a bdi_writeback_rh extension to struct bdi_writeback (Waiman Long) [2138886]
- RDMA/irdma: Report the correct link speed (Kamal Heib) [2125102]
- blk-mq: avoid double ->queue_rq() because of early timeout (Ming Lei) [2132438]
- blk-mq: add one API for waiting until quiesce is done (Ming Lei) [2132438]
- blk-mq: support concurrent queue quiesce/unquiesce (Ming Lei) [2132438]
- bridge: Do not send empty IFLA_AF_SPEC attribute (Ivan Vecera) [2139133]
- net: bridge: Clear offload_fwd_mark when passing frame up bridge interface. (Ivan Vecera) [2139133]
- net: bridge: vlan: fix memory leak in __allowed_ingress (Ivan Vecera) [2139133]

* Fri Nov 11 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-437.el8]
- ice: Add additional CSR registers to ETHTOOL_GREGS (Petr Oros) [2131024]
- udp: Update reuse->has_conns under reuseport_lock. (Xin Long) [2135937]
- udp: Remove redundant __udp_sysctl_init() call from udp_init(). (Xin Long) [2135937]
- udp: Fix a data-race around sysctl_udp_l3mdev_accept. (Xin Long) [2135937]
- Documentation: fix udp_wmem_min in ip-sysctl.rst (Xin Long) [2135937]
- be2net: Fix buffer overflow in be_get_module_eeprom (Josef Oskera) [2126917]
- iommu/vt-d: Clean up si_domain in the init_dmars() error path (Jerry Snitselaar) [2133331]

* Wed Nov 09 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-436.el8]
- md: Fix spelling mistake in comments of r5l_log (Nigel Croxon) [2112935]
- md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d (Nigel Croxon) [2112935]
- md/raid10: convert resync_lock to use seqlock (Nigel Croxon) [2112935]
- md/raid10: fix improper BUG_ON() in raise_barrier() (Nigel Croxon) [2112935]
- md/raid10: prevent unnecessary calls to wake_up() in fast path (Nigel Croxon) [2112935]
- md/raid10: don't modify 'nr_waitng' in wait_barrier() for the case nowait (Nigel Croxon) [2112935]
- md/raid10: factor out code from wait_barrier() to stop_waiting_barrier() (Nigel Croxon) [2112935]
- md: Remove extra mddev_get() in md_seq_start() (Nigel Croxon) [2112935]
- md/raid5: Remove unnecessary bio_put() in raid5_read_one_chunk() (Nigel Croxon) [2112935 2111563]
- md/raid5: Ensure stripe_fill happens on non-read IO with journal (Nigel Croxon) [2112935]
- md/raid5: Don't read ->active_stripes if it's not needed (Nigel Croxon) [2112935]
- md/raid5: Cleanup prototype of raid5_get_active_stripe() (Nigel Croxon) [2112935]
- md/raid5: Drop extern on function declarations in raid5.h (Nigel Croxon) [2112935]
- md/raid5: Refactor raid5_get_active_stripe() (Nigel Croxon) [2112935]
- md: Replace snprintf with scnprintf (Nigel Croxon) [2112935]
- md/raid10: fix compile warning (Nigel Croxon) [2112935]
- md/raid5: Fix spelling mistakes in comments (Nigel Croxon) [2112935]
- md: call __md_stop_writes in md_stop (Nigel Croxon) [2112935]
- md: Flush workqueue md_rdev_misc_wq in md_alloc() (Nigel Croxon) [2112935]
- drivers:md:fix a potential use-after-free bug (Nigel Croxon) [2112935]
- md/raid5: Ensure batch_last is released before sleeping for quiesce (Nigel Croxon) [2112935]
- md/raid5: Move stripe_request_ctx up (Nigel Croxon) [2112935]
- md/raid5: Drop unnecessary call to r5c_check_stripe_cache_usage() (Nigel Croxon) [2112935]
- md/raid5: Make is_inactive_blocked() helper (Nigel Croxon) [2112935]
- md/raid5: Refactor raid5_get_active_stripe() (Nigel Croxon) [2112935]
- md-raid10: fix KASAN warning (Nigel Croxon) [2112935]
- md: fix build failure for !MODULE (Nigel Croxon) [2112935]
- raid5: fix duplicate checks for rdev->saved_raid_disk (Nigel Croxon) [2112935]
- md/raid5: Convert prepare_to_wait() to wait_woken() api (Nigel Croxon) [2112935]
- md/raid5: Fix sectors_to_do bitmap overflow in raid5_make_request() (Nigel Croxon) [2112935]
- md: Fix spelling mistake in comments (Nigel Croxon) [2112935]
- md/raid5: Increase restriction on max segments per request (Nigel Croxon) [2112935]
- md/raid5: Improve debug prints (Nigel Croxon) [2112935]
- md/raid5: Pivot raid5_make_request() (Nigel Croxon) [2112935]
- md/raid5: Check all disks in a stripe_head for reshape progress (Nigel Croxon) [2112935]
- md/raid5: Refactor add_stripe_bio() (Nigel Croxon) [2112935]
- md/raid5: Keep a reference to last stripe_head for batch (Nigel Croxon) [2112935]
- md/raid5: Refactor for loop in raid5_make_request() into while loop (Nigel Croxon) [2112935]
- md/raid5: Move read_seqcount_begin() into make_stripe_request() (Nigel Croxon) [2112935]
- md/raid5: Drop the do_prepare flag in raid5_make_request() (Nigel Croxon) [2112935]
- md/raid5: Factor out helper from raid5_make_request() loop (Nigel Croxon) [2112935]
- md/raid5: Move common stripe get code into new find_get_stripe() helper (Nigel Croxon) [2112935]
- md/raid5: Move stripe_add_to_batch_list() call out of add_stripe_bio() (Nigel Croxon) [2112935]
- md/raid5: Refactor raid5_make_request loop (Nigel Croxon) [2112935]
- md/raid5: Factor out ahead_of_reshape() function (Nigel Croxon) [2112935]
- md/raid5: Make logic blocking check consistent with logic that blocks (Nigel Croxon) [2112935]
- md: unlock mddev before reap sync_thread in action_store (Nigel Croxon) [2112935]
- md: Explicitly create command-line configured devices (Nigel Croxon) [2112935]
- md: Notify sysfs sync_completed in md_reap_sync_thread() (Nigel Croxon) [2112935]
- md: Ensure resync is reported after it starts (Nigel Croxon) [2112935]
- md: Use enum for overloaded magic numbers used by mddev->curr_resync (Nigel Croxon) [2112935]
- md/raid5-cache: Annotate pslot with __rcu notation (Nigel Croxon) [2112935]
- md/raid5-cache: Clear conf->log after finishing work (Nigel Croxon) [2112935]
- md/raid5-cache: Drop RCU usage of conf->log (Nigel Croxon) [2112935]
- md/raid5-cache: Take mddev_lock in r5c_journal_mode_show() (Nigel Croxon) [2112935]
- md/raid5: suspend the array for calls to log_exit() (Nigel Croxon) [2112935]
- md/raid5-ppl: Drop unused argument from ppl_handle_flush_request() (Nigel Croxon) [2112935]
- md/raid5-log: Drop extern decorators for function prototypes (Nigel Croxon) [2112935]
- md/raid5: missing error code in setup_conf() (Nigel Croxon) [2112935]
- Revert "md: don't unregister sync_thread with reconfig_mutex held" (Nigel Croxon) [2112935]
- qed: fix typos in comments (Manish Chopra) [2111885]
- net: qede: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2111885]
- RDMA/qedr: Fix potential memory leak in __qedr_alloc_mr() (Manish Chopra) [2111885]
- qlogic: qed: fix clang -Wformat warnings (Manish Chopra) [2111885]
- qed: Use bitmap_empty() (Manish Chopra) [2111885]
- qed: Use the bitmap API to allocate bitmaps (Manish Chopra) [2111885]
- qlogic/qed: fix repeated words in comments (Manish Chopra) [2111885]
- net: qed: fix typos in comments (Manish Chopra) [2111885]
- RDMA/qedr: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2111885]
- qed: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2111885]
- qed: replace bitmap_weight with bitmap_empty in qed_roce_stop() (Manish Chopra) [2111885]
- qed: rework qed_rdma_bmap_free() (Manish Chopra) [2111885]
- qed: Remove IP services API. (Manish Chopra) [2111885]
- qed: remove an unneed NULL check on list iterator (Manish Chopra) [2111885]
- RDMA/irdma: Report RNR NAK generation in device caps (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Use s/g array in post send only when its valid (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Return correct WC error for bind operation failure (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Return error on MR deregister CQP failure (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Report the correct max cqes from query device (Kamal Heib) [2120676 2103957]
- RDMA/siw: Pass a pointer to virt_to_page() (Kamal Heib) [2120676]
- RDMA/cma: Fix arguments order in net device validation (Kamal Heib) [2120676]
- RDMA/irdma: Fix drain SQ hang with no completion (Kamal Heib) [2120676 2103957 2033244 2053376]
- IB/iser: Fix login with authentication (Kamal Heib) [2120676]
- RDMA/ib_srpt: Unify checking rdma_cm_id condition in srpt_cm_req_recv() (Kamal Heib) [2120676]
- RDMA/rxe: Fix error unwind in rxe_create_qp() (Kamal Heib) [2120676]
- RDMA/rxe: Split qp state for requester and completer (Kamal Heib) [2120676]
- RDMA/rxe: Generate error completion for error requester QP state (Kamal Heib) [2120676]
- RDMA/rxe: Update wqe_index for each wqe error completion (Kamal Heib) [2120676]
- RDMA/srpt: Fix a use-after-free (Kamal Heib) [2120676]
- RDMA/srpt: Introduce a reference count in struct srpt_device (Kamal Heib) [2120676]
- RDMA/srpt: Duplicate port name members (Kamal Heib) [2120676]
- Revert "RDMA/rxe: Create duplicate mapping tables for FMRs" (Kamal Heib) [2120676]
- RDMA/rxe: Replace __rxe_do_task by rxe_run_task (Kamal Heib) [2120676]
- RDMA/rxe: Limit the number of calls to each tasklet (Kamal Heib) [2120676]
- RDMA/rxe: Make the tasklet exits the same (Kamal Heib) [2120676]
- RDMA/rxe: Fix rnr retry behavior (Kamal Heib) [2120676]
- RDMA/rxe: Add rxe_is_fenced() subroutine (Kamal Heib) [2120676]
- RDMA/rxe: For invalidate compare according to set keys in mr (Kamal Heib) [2120676]
- RDMA: Fix comment typo (Kamal Heib) [2120676]
- IB: Fix repeated words 'the the' comments (Kamal Heib) [2120676]
- RDMA/rxe: Fix mw bind to allow any consumer key portion (Kamal Heib) [2120676]
- RDMA/rxe: Fix spelling mistake in error print (Kamal Heib) [2120676]
- RDMA/rxe: Remove unused qp parameter (Kamal Heib) [2120676]
- RDMA/hfi1: fix potential memory leak in setup_base_ctxt() (Kamal Heib) [2120676]
- RDMA/rxe: Remove unused mask parameter (Kamal Heib) [2120676]
- RDMA/rxe: Rename rxe_atomic_reply to atomic_reply (Kamal Heib) [2120676]
- RDMA/rxe: Add common rxe_prepare_res() (Kamal Heib) [2120676]
- RDMA/rxe: Fix BUG: KASAN: null-ptr-deref in rxe_qp_do_cleanup (Kamal Heib) [2120676]
- RDMA/siw: Fix duplicated reported IW_CM_EVENT_CONNECT_REPLY event (Kamal Heib) [2120676]
- RDMA/hfi1: Depend on !UML (Kamal Heib) [2120676]
- RDMA/irdma: Use the bitmap API to allocate bitmaps (Kamal Heib) [2120676 2103957]
- RDMA: remove useless condition in siw_create_cq() (Kamal Heib) [2120676]
- RDMA/irdma: Fix setting of QP context err_rq_idx_valid field (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Fix VLAN connection with wildcard address (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Fix a window for use-after-free (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Make resource distribution algorithm more QP oriented (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Make CQP invalid state error non-critical (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Add AE source to error log (Kamal Heib) [2120676 2103957]
- RDMA/irdma: Add 2 level PBLE support for FMR (Kamal Heib) [2120676 2103957]
- IB: Fix spelling of 'writable' (Kamal Heib) [2120676]
- RDMA/rxe: Remove unnecessary include statement (Kamal Heib) [2120676]
- RDMA/rxe: Replace include statement (Kamal Heib) [2120676]
- RDMA/rxe: Convert pr_warn/err to pr_debug in pyverbs (Kamal Heib) [2120676]
- RDMA/rxe: Fix deadlock in rxe_do_local_ops() (Kamal Heib) [2120676]
- RDMA/rxe: Merge normal and retry atomic flows (Kamal Heib) [2120676]
- RDMA/rxe: Move atomic original value to res (Kamal Heib) [2120676]
- RDMA/rxe: Move atomic responder res to atomic_reply (Kamal Heib) [2120676]
- RDMA/rxe: Add a responder state for atomic reply (Kamal Heib) [2120676]
- RDMA/rxe: Move code to rxe_prepare_atomic_res() (Kamal Heib) [2120676]
- RDMA/rxe: Convert read side locking to rcu (Kamal Heib) [2120676]
- RDMA/rxe: Stop lookup of partially built objects (Kamal Heib) [2120676]
- RDMA/rxe: Remove useless pkt parameters (Kamal Heib) [2120676]
- RDMA: Correct duplicated words in comments (Kamal Heib) [2120676]
- IB/iser: Drain the entire QP during destruction flow (Kamal Heib) [2120676]
- RDMA/rxe: fix xa_alloc_cycle() error return value check again (Kamal Heib) [2120676]
- RDMA/core: Add a netevent notifier to cma (Kamal Heib) [2120676 2117912]
- RDMA/core: Add an rb_tree that stores cm_ids sorted by ifindex and remote IP (Kamal Heib) [2120676 2117912]
- RDMA/hfi1: Fix typo in comment (Kamal Heib) [2120676]
- RDMA: Split kernel-only global device caps from uverbs device caps (Kamal Heib) [2120675]
- RDMA/hfi1: Remove all traces of diagpkt support (Kamal Heib) [2120675]
- RDMA/hfi1: Consolidate software versions (Kamal Heib) [2120675]
- RDMA/hfi1: Remove pointless driver version (Kamal Heib) [2120675]
- RDMA/hfi1: Prevent panic when SDMA is disabled (Kamal Heib) [2120675]
- RDMA/core: Fix typo in comment (Kamal Heib) [2120675]
- IB/hf1: Fix typo in comment (Kamal Heib) [2120675]
- IB/iser: Fix typo in comment (Kamal Heib) [2120675]
- IB/isert: Avoid flush_scheduled_work() usage (Kamal Heib) [2120675]
- RDMA/siw: Enable siw on tunnel devices (Kamal Heib) [2120675]
- RDMA/rxe: Enforce IBA C11-17 (Kamal Heib) [2120675]
- RDMA/rxe: Move mw cleanup code to rxe_mw_cleanup() (Kamal Heib) [2120675]
- RDMA/rxe: Move mr cleanup code to rxe_mr_cleanup() (Kamal Heib) [2120675]
- RDMA/rxe: Move qp cleanup code to rxe_qp_do_cleanup() (Kamal Heib) [2120675]
- RDMA/rxe: Check rxe_get() return value (Kamal Heib) [2120675]
- RDMA/rxe: Add rxe_srq_cleanup() (Kamal Heib) [2120675]
- RDMA/rxe: Remove IB_SRQ_INIT_MASK (Kamal Heib) [2120675]
- RDMA/rxe: Skip adjusting remote addr for write in retry operation (Kamal Heib) [2120675]
- RDMA/rxe: Optimize the mr pool struct (Kamal Heib) [2120675]
- RDMA/rxe: Replace paylen by payload (Kamal Heib) [2120675]
- RDMA/core: Avoid flush_workqueue(system_unbound_wq) usage (Kamal Heib) [2120675]
- RDMA/rxe: Remove useless parameters for update_state() (Kamal Heib) [2120675]
- RDMA/rxe: Remove reliable datagram support (Kamal Heib) [2120675]
- RDMA/rxe: Remove support for SMI QPs from rdma_rxe (Kamal Heib) [2120675]
- RDMA/rxe: Remove mc_grp_pool from struct rxe_dev (Kamal Heib) [2120675]
- RDMA/rxe: Remove type 2A memory window capability (Kamal Heib) [2120675]
- RDMA/usnic: Refactor usnic_uiom_alloc_pd() (Kamal Heib) [2120675]
- RDMA/usnic: Stop using iommu_present() (Kamal Heib) [2120675]
- IB/SA: Replace usage of found with dedicated list iterator variable (Kamal Heib) [2120675]
- IB/rdmavt: add missing locks in rvt_ruc_loopback (Kamal Heib) [2120675]
- IB/uverbs: Move part of enum ib_device_cap_flags to uapi (Kamal Heib) [2120675]
- IB/uverbs: Move enum ib_raw_packet_caps to uapi (Kamal Heib) [2120675]
- RDMA/pvrdma: Remove useless DMA-32 fallback configuration (Kamal Heib) [2120675]
- RDMA: switch from 'pci_' to 'dma_' API (Kamal Heib) [2120675]
- scsi: RDMA/srp: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Kamal Heib) [2120675]
- scsi: RDMA/iser: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Kamal Heib) [2120675]
- x86/fpu: Prevent FPU state corruption (Oleksandr Natalenko) [2130890]
- net: team: Unsync device addresses on ndo_stop (Hangbin Liu) [2135240]
- mmu_gather: fix the CONFIG_MMU_GATHER_NO_RANGE case (Waiman Long) [2130166] {CVE-2022-39188}
- mmu_gather: Force tlb-flush VM_PFNMAP vmas (Waiman Long) [2130166] {CVE-2022-39188}
- mmu_gather: Let there be one tlb_{start,end}_vma() implementation (Waiman Long) [2130166] {CVE-2022-39188}
- mmu_gather: Remove per arch tlb_{start,end}_vma() (Waiman Long) [2130166] {CVE-2022-39188}
- x86/ldt: Use tlb_gather_mmu_fullmm() when freeing LDT page-tables (Waiman Long) [2130166] {CVE-2022-39188}
- tlb: arch: Remove empty __tlb_remove_tlb_entry() stubs (Waiman Long) [2130166] {CVE-2022-39188}
- tlb: mmu_gather: Remove start/end arguments from tlb_gather_mmu() (Waiman Long) [2130166] {CVE-2022-39188}
- tlb: mmu_gather: Introduce tlb_gather_mmu_fullmm() (Waiman Long) [2130166] {CVE-2022-39188}
- tlb: mmu_gather: Remove unused start/end arguments from tlb_finish_mmu() (Waiman Long) [2130166] {CVE-2022-39188}
- mm: proc: Invalidate TLB after clearing soft-dirty page state (Waiman Long) [2130166] {CVE-2022-39188}
- mm: fix clear_refs_write locking (Waiman Long) [2130166] {CVE-2022-39188}
- s390/Kconfig: sort config S390 select list once again (Waiman Long) [2130166] {CVE-2022-39188}
- asm-generic/tlb: provide MMU_GATHER_TABLE_FREE (Waiman Long) [2130166] {CVE-2022-39188}
- asm-generic/tlb: rename HAVE_MMU_GATHER_NO_GATHER (Waiman Long) [2130166] {CVE-2022-39188}
- asm-generic/tlb: rename HAVE_MMU_GATHER_PAGE_SIZE (Waiman Long) [2130166] {CVE-2022-39188}
- asm-generic/tlb: rename HAVE_RCU_TABLE_FREE (Waiman Long) [2130166] {CVE-2022-39188}
- asm-generic/tlb: avoid potential double flush (Waiman Long) [2130166] {CVE-2022-39188}
- powerpc/mm/book3s64/radix: Flush the full mm even when need_flush_all is set (Waiman Long) [2130166] {CVE-2022-39188}
- powerpc/mm/book3s64/radix: Use freed_tables instead of need_flush_all (Waiman Long) [2130166] {CVE-2022-39188}
- mm/tlb: Remove CONFIG_HAVE_RCU_TABLE_INVALIDATE (Waiman Long) [2130166] {CVE-2022-39188}
- Add skb drop reasons to IPv6 UDP receive path (Antoine Tenart) [2059158]
- net: skb: export skb drop reaons to user by TRACE_DEFINE_ENUM (Antoine Tenart) [2059158]
- net: skb: prevent the split of kfree_skb_reason() by gcc (Antoine Tenart) [2059158]
- tcp: md5: fix IPv4-mapped support (Antoine Tenart) [2059158]
- net: dropreason: reformat the comment fo skb drop reasons (Antoine Tenart) [2059158]
- net: skb: use auto-generation to convert skb drop reason to string (Antoine Tenart) [2059158]
- net: skb: move enum skb_drop_reason to standalone header file (Antoine Tenart) [2059158]
- tcp_ipv6: set the drop_reason in the right place (Antoine Tenart) [2059158]
- net: tcp: reset 'drop_reason' to NOT_SPCIFIED in tcp_v{4,6}_rcv() (Antoine Tenart) [2059158]
- net: skb: change the definition SKB_DR_SET() (Antoine Tenart) [2059158]
- net: skb: check the boundrary of drop reason in kfree_skb_reason() (Antoine Tenart) [2059158]
- net: dm: check the boundary of skb drop reasons (Antoine Tenart) [2059158]
- tcp: fix signed/unsigned comparison (Antoine Tenart) [2059158]
- tcp: add drop reason support to tcp_ofo_queue() (Antoine Tenart) [2059158]
- tcp: add drop reasons to tcp_rcv_synsent_state_process() (Antoine Tenart) [2059158]
- tcp: make tcp_rcv_synsent_state_process() drop monitor friend (Antoine Tenart) [2059158]
- tcp: add drop reason support to tcp_prune_ofo_queue() (Antoine Tenart) [2059158]
- tcp: add two drop reasons for tcp_ack() (Antoine Tenart) [2059158]
- tcp: add drop reasons to tcp_rcv_state_process() (Antoine Tenart) [2059158]
- tcp: make tcp_rcv_state_process() drop monitor friendly (Antoine Tenart) [2059158]
- tcp: add drop reason support to tcp_validate_incoming() (Antoine Tenart) [2059158]
- tcp: get rid of rst_seq_match (Antoine Tenart) [2059158]
- tcp: consume incoming skb leading to a reset (Antoine Tenart) [2059158]
- tcp: tcp_send_challenge_ack delete useless param `skb` (Antoine Tenart) [2059158]
- ipv6: fix NULL deref in ip6_rcv_core() (Antoine Tenart) [2059158]
- net: ipv6: add skb drop reasons to ip6_protocol_deliver_rcu() (Antoine Tenart) [2059158]
- net: ipv6: add skb drop reasons to ip6_rcv_core() (Antoine Tenart) [2059158]
- net: ipv6: add skb drop reasons to TLV parse (Antoine Tenart) [2059158]
- net: ipv6: remove redundant statistics in ipv6_hop_jumbo() (Antoine Tenart) [2059158]
- net: icmp: introduce function icmpv6_param_prob_reason() (Antoine Tenart) [2059158]
- net: ip: add skb drop reasons to ip forwarding (Antoine Tenart) [2059158]
- net: ipv6: add skb drop reasons to ip6_pkt_drop() (Antoine Tenart) [2059158]
- net: ipv4: add skb drop reasons to ip_error() (Antoine Tenart) [2059158]
- skb: add some helpers for skb drop reasons (Antoine Tenart) [2059158]
- net: icmp: add skb drop reasons to icmp protocol (Antoine Tenart) [2059158]
- ping: Check return value of function 'ping_queue_rcv_skb' (Antoine Tenart) [2059158]
- net: icmp: introduce __ping_queue_rcv_skb() to report drop reasons (Antoine Tenart) [2059158]
- net: skb: rename SKB_DROP_REASON_PTYPE_ABSENT (Antoine Tenart) [2059158]
- net: sock: introduce sock_queue_rcv_skb_reason() (Antoine Tenart) [2059158]
- net: tcp: fix shim definition of tcp_inbound_md5_hash (Antoine Tenart) [2059158]
- skb: make drop reason booleanable (Antoine Tenart) [2059158]
- net/tcp: Merge TCP-MD5 inbound callbacks (Antoine Tenart) [2059158]
- tcp: md5: add tcp_md5_needed jump label (Antoine Tenart) [2059158]
- net: tun: track dropped skb via kfree_skb_reason() (Antoine Tenart) [2059158]
- net: tun: split run_ebpf_filter() and pskb_trim() into different "if statement" (Antoine Tenart) [2059158]
- net: tap: track dropped skb via kfree_skb_reason() (Antoine Tenart) [2059158]
- net: dev: use kfree_skb_reason() for __netif_receive_skb_core() (Antoine Tenart) [2059158]
- net: dev: use kfree_skb_reason() for sch_handle_ingress() (Antoine Tenart) [2059158]
- net: dev: use kfree_skb_reason() for do_xdp_generic() (Antoine Tenart) [2059158]
- net: dev: use kfree_skb_reason() for enqueue_to_backlog() (Antoine Tenart) [2059158]
- net: dev: add skb drop reasons to __dev_xmit_skb() (Antoine Tenart) [2059158]
- net: skb: introduce the function kfree_skb_list_reason() (Antoine Tenart) [2059158]
- net: dev: use kfree_skb_reason() for sch_handle_egress() (Antoine Tenart) [2059158]
- net: neigh: add skb drop reasons to arp_error_report() (Antoine Tenart) [2059158]
- net: neigh: use kfree_skb_reason() for __neigh_event_send() (Antoine Tenart) [2059158]
- net: ip: add skb drop reasons for ip egress path (Antoine Tenart) [2059158]
- net: tcp: use tcp_drop_reason() for tcp_data_queue_ofo() (Antoine Tenart) [2059158]
- net: tcp: use tcp_drop_reason() for tcp_data_queue() (Antoine Tenart) [2059158]
- net: tcp: use tcp_drop_reason() for tcp_rcv_established() (Antoine Tenart) [2059158]
- net: tcp: use kfree_skb_reason() for tcp_v{4,6}_do_rcv() (Antoine Tenart) [2059158]
- net: tcp: add skb drop reasons to tcp_add_backlog() (Antoine Tenart) [2059158]
- net: tcp: add skb drop reasons to tcp_v{4,6}_inbound_md5_hash() (Antoine Tenart) [2059158]
- ipv4/tcp: Pass dif and sdif to tcp_v4_inbound_md5_hash (Antoine Tenart) [2059158]
- ipv6/tcp: Pass dif and sdif to tcp_v6_inbound_md5_hash (Antoine Tenart) [2059158]
- ipv4/tcp: Use local variable for tcp_md5_addr (Antoine Tenart) [2059158]
- net: tcp: use kfree_skb_reason() for tcp_v6_rcv() (Antoine Tenart) [2059158]
- net: tcp: add skb drop reasons to tcp_v4_rcv() (Antoine Tenart) [2059158]
- net: tcp: introduce tcp_drop_reason() (Antoine Tenart) [2059158]
- ipv6: Add reasons for skb drops to __udp6_lib_rcv (Antoine Tenart) [2059158]
- net: drop_monitor: support drop reason (Antoine Tenart) [2059158]
- net: udp: use kfree_skb_reason() in __udp_queue_rcv_skb() (Antoine Tenart) [2059158]
- net: udp: use kfree_skb_reason() in udp_queue_rcv_one_skb() (Antoine Tenart) [2059158]
- net: ipv4: use kfree_skb_reason() in ip_protocol_deliver_rcu() (Antoine Tenart) [2059158]
- net: ipv4: use kfree_skb_reason() in ip_rcv_finish_core() (Antoine Tenart) [2059158]
- net: ipv4: use kfree_skb_reason() in ip_rcv_core() (Antoine Tenart) [2059158]
- net: netfilter: use kfree_drop_reason() for NF_DROP (Antoine Tenart) [2059158]
- net: skb_drop_reason: add document for drop reasons (Antoine Tenart) [2059158]
- net: socket: rename SKB_DROP_REASON_SOCKET_FILTER (Antoine Tenart) [2059158]
- net: skb: use kfree_skb_reason() in __udp4_lib_rcv() (Antoine Tenart) [2059158]
- net: skb: use kfree_skb_reason() in tcp_v4_rcv() (Antoine Tenart) [2059158]
- net: skb: introduce kfree_skb_reason() (Antoine Tenart) [2059158]
- bnx2x: Fix comment typo (Manish Chopra) [2111882]
- bnx2x: Fix spelling mistake "regiser" -> "register" (Manish Chopra) [2111882]
- bnx2x: Fix undefined behavior due to shift overflowing the constant (Manish Chopra) [2111882]
- net: sched: act_ct: fix possible refcount leak in tcf_ct_init() (Davide Caratti) [2133741]
- net: sched: fix possible refcount leak in tc_new_tfilter() (Davide Caratti) [2133741]
- sch_sfb: Also store skb len before calling child enqueue (Davide Caratti) [2133741]
- sch_sfb: Don't assume the skb is still around after enqueueing to child (Davide Caratti) [2133741]
- net/sched: fix netdevice reference leaks in attach_default_qdiscs() (Davide Caratti) [2133741]
- net: sched: tbf: don't call qdisc_put() while holding tree lock (Davide Caratti) [2133741]
- net: Fix data-races around weight_p and dev_weight_[rt]x_bias. (Davide Caratti) [2133741]
- net/sched: act_api: Notify user space if any actions were flushed before error (Davide Caratti) [2133741]
- tipc: fix an information leak in tipc_topsrv_kern_subscr (Xin Long) [2134962]
- tipc: Fix recognition of trial period (Xin Long) [2134962]
- tipc: fix shift wrapping bug in map_get() (Xin Long) [2134962]
- PCI/ASPM: Make Intel DG2 L1 acceptable latency unlimited (Myron Stowe) [2072656]
- x86/pci/xen: Use msi_msg shadow structs (Jerry Snitselaar) [2133518]
- iommu/intel: Use msi_msg shadow structs (Jerry Snitselaar) [2133518]
- PCI: MSI: Fix Kconfig dependencies for PCI_MSI_ARCH_FALLBACKS (Jerry Snitselaar) [2133518]
- x86/apic/msi: Unbreak DMAR and HPET MSI (Jerry Snitselaar) [2133518]
- iommu/amd: Remove domain search for PCI/MSI (Jerry Snitselaar) [2133518]
- iommu/vt-d: Remove domain search for PCI/MSI[X] (Jerry Snitselaar) [2133518]
- x86/irq: Make most MSI ops XEN private (Jerry Snitselaar) [2133518]
- x86/irq: Cleanup the arch_*_msi_irqs() leftovers (Jerry Snitselaar) [2133518]
- PCI/MSI: Make arch_.*_msi_irq[s] fallbacks selectable (Jerry Snitselaar) [2133518]
- x86/xen: Wrap XEN MSI management into irqdomain (Jerry Snitselaar) [2133518]
- x86/xen: Consolidate XEN-MSI init (Jerry Snitselaar) [2133518]
- x86/xen: Rework MSI teardown (Jerry Snitselaar) [2133518]
- x86/xen: Make xen_msi_init() static and rename it to xen_hvm_msi_init() (Jerry Snitselaar) [2133518]
- x86/irq: Move apic_post_init() invocation to one place (Jerry Snitselaar) [2133518]
- x86/msi: Use generic MSI domain ops (Jerry Snitselaar) [2133518]
- x86/msi: Remove pointless vcpu_affinity callback (Jerry Snitselaar) [2133518]
- netfilter: nf_conntrack_irc: Tighten matching on DCC message (Wander Lairson Costa) [2124092] {CVE-2022-2663}
- netfilter: nf_conntrack_irc: Fix forged IP logic (Wander Lairson Costa) [2124092] {CVE-2022-2663}
- ice: Add support Flex RXD (Michal Schmidt) [2131310]
- asm-generic: sections: refactor memory_intersects (Jerry Snitselaar) [2112119]
- swiotlb: fix passing local variable to debugfs_create_ulong() (Jerry Snitselaar) [2112119]
- swiotlb: move struct io_tlb_slot to swiotlb.c (Jerry Snitselaar) [2112119]
- swiotlb: ensure a segment doesn't cross the area boundary (Jerry Snitselaar) [2112119]
- swiotlb: consolidate rounding up default_nslabs (Jerry Snitselaar) [2112119]
- swiotlb: remove unused fields in io_tlb_mem (Jerry Snitselaar) [2112119]
- swiotlb: fix use after free on error handling path (Jerry Snitselaar) [2112119]
- swiotlb: split up the global swiotlb lock (Jerry Snitselaar) [2112119]
- swiotlb: fail map correctly with failed io_tlb_default_mem (Jerry Snitselaar) [2112119]
- swiotlb: remove a useless return in swiotlb_init (Jerry Snitselaar) [2112119]
- swiotlb: remove the unused swiotlb_force declaration (Jerry Snitselaar) [2112119]
- iommu/dma: Fix race condition during iova_domain initialization (Jerry Snitselaar) [2112119]
- iommu/amd: Fix compile warning in init code (Jerry Snitselaar) [2106599]
- iommu/amd: Simplify and Consolidate Virtual APIC (AVIC) Enablement (Jerry Snitselaar) [2106599]
- iommu/vt-d: Check correct capability for sagaw determination (Jerry Snitselaar) [2112119]
- iommu/vt-d: Correctly calculate sagaw value of IOMMU (Jerry Snitselaar) [2112119]
- iommu/vt-d: Fix kdump kernels boot failure with scalable mode (Jerry Snitselaar) [2080413]
- iommu/amd: use full 64-bit value in build_completion_wait() (Jerry Snitselaar) [2112119]
- swiotlb: avoid potential left shift overflow (Jerry Snitselaar) [2112119]
- dma-debug: improve search for partial syncs (Jerry Snitselaar) [2112119]
- iommu/iova: Improve 32-bit free space estimate (Jerry Snitselaar) [2112119]
- iommu/amd: Handle return of iommu_device_sysfs_add (Jerry Snitselaar) [2112119]
- swiotlb: fix setting ->force_bounce (Jerry Snitselaar) [2112119]
- swiotlb: use the right nslabs-derived sizes in swiotlb_init_late (Jerry Snitselaar) [2112119]
- swiotlb: use the right nslabs value in swiotlb_init_remap (Jerry Snitselaar) [2112119]
- swiotlb: don't panic when the swiotlb buffer can't be allocated (Jerry Snitselaar) [2112119]
- x86: remove cruft from <asm/dma-mapping.h> (Jerry Snitselaar) [2112119]
- swiotlb: remove swiotlb_init_with_tbl and swiotlb_init_late_with_tbl (Jerry Snitselaar) [2112119]
- swiotlb: provide swiotlb_init variants that remap the buffer (Jerry Snitselaar) [2112119]
- swiotlb: pass a gfp_mask argument to swiotlb_init_late (Jerry Snitselaar) [2112119]
- swiotlb: add a SWIOTLB_ANY flag to lift the low memory restriction (Jerry Snitselaar) [2112119]
- swiotlb: make the swiotlb_init interface more useful (Jerry Snitselaar) [2112119]
- x86: centralize setting SWIOTLB_FORCE when guest memory encryption is enabled (Jerry Snitselaar) [2112119]
- x86: remove the IOMMU table infrastructure (Jerry Snitselaar) [2112119]
- swiotlb: rename swiotlb_late_init_with_default_size (Jerry Snitselaar) [2112119]
- swiotlb: simplify swiotlb_max_segment (Jerry Snitselaar) [2112119]
- iommu/vt-d: avoid invalid memory access via node_online(NUMA_NO_NODE) (Jerry Snitselaar) [2112119]
- iommu/arm-smmu-v3: check return value after calling platform_get_resource() (Jerry Snitselaar) [2112119]
- iommu/arm-smmu: fix possible null-ptr-deref in arm_smmu_device_probe() (Jerry Snitselaar) [2112119]
- iommu/amd: Increase timeout waiting for GA log enablement (Jerry Snitselaar) [2112119]
- iommu/amd: Do not call sleep while holding spinlock (Jerry Snitselaar) [2112119]
- iommu/amd: Remove redundant check (Jerry Snitselaar) [2112119]
- swiotlb: simplify array allocation (Jerry Snitselaar) [2112119]
- swiotlb: tidy up includes (Jerry Snitselaar) [2112119]
- treewide: Replace the use of mem_encrypt_active() with cc_platform_has() (Jerry Snitselaar) [2112119]
- swiotlb: simplify debugfs setup (Jerry Snitselaar) [2112119]
- iommu: Log iova range in map/unmap trace events (Jerry Snitselaar) [2112119]
- iommu/amd: Improve amd_iommu_v2_exit() (Jerry Snitselaar) [2112119]
- iommu/amd: Remove unused struct fault.devid (Jerry Snitselaar) [2112119]
- iommu/amd: Clean up function declarations (Jerry Snitselaar) [2112119]
- iommu/amd: Improve error handling for amd_iommu_init_pci (Jerry Snitselaar) [2112119]
- iommu/iova: Separate out rcache init (Jerry Snitselaar) [2112119]
- iommu/iova: Temporarily include dma-mapping.h from iova.h (Jerry Snitselaar) [2112119]
- iommu: Move flush queue data into iommu_dma_cookie (Jerry Snitselaar) [2112119]
- iommu/iova: Move flush queue code to iommu-dma (Jerry Snitselaar) [2112119]
- iommu/iova: Consolidate flush queue code (Jerry Snitselaar) [2112119]
- iommu/vt-d: Use put_pages_list (Jerry Snitselaar) [2112119]
- iommu/amd: Use put_pages_list (Jerry Snitselaar) [2112119]
- iommu/amd: Simplify pagetable freeing (Jerry Snitselaar) [2112119]
- iommu/iova: Squash flush_cb abstraction (Jerry Snitselaar) [2112119]
- iommu/iova: Squash entry_dtor abstraction (Jerry Snitselaar) [2112119]
- iommu/iova: Move fast alloc size roundup into alloc_iova_fast() (Jerry Snitselaar) [2112119]
- iommu/arm-smmu-v3: fix event handling soft lockup (Jerry Snitselaar) [2112119]
- iommu/arm-smmu-v3: Avoid open coded arithmetic in memory allocation (Jerry Snitselaar) [2112119]
- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable() (Jerry Snitselaar) [2112119]
- iommu/intel: Use msi_msg shadow structs (Jerry Snitselaar) [2112119]
- dma-mapping: use 'bitmap_zalloc()' when applicable (Jerry Snitselaar) [2112119]
- iommu/dma: Use kvcalloc() instead of kvzalloc() (Jerry Snitselaar) [2112119]
- iommu/vt-d: Convert the return type of first_pte_in_page to bool (Jerry Snitselaar) [2112119]
- iommu/vt-d: Use second level for GPA->HPA translation (Jerry Snitselaar) [2112119]
- iommu/vt-d: Remove duplicate identity domain flag (Jerry Snitselaar) [2112119]
- iommu/vt-d: Do not falsely log intel_iommu is unsupported kernel option (Jerry Snitselaar) [2112119]
- iommu/dma: Unexport IOVA cookie management (Jerry Snitselaar) [2112119]
- iommu/amd: Use struct_group() for memcpy() region (Jerry Snitselaar) [2112119]
- dma-mapping: remove bogus test for pfn_valid from dma_map_resource (Jerry Snitselaar) [2112119]
- iommu/vt-d: Use pci_dev_id() helper (Jerry Snitselaar) [2112119]
- swiotlb-xen: this is PV-only on x86 (Jerry Snitselaar) [2112119]
- xen/pci-swiotlb: reduce visibility of symbols (Jerry Snitselaar) [2112119]
- iova: Export alloc_iova_fast() and free_iova_fast() (Jerry Snitselaar) [2112119]
- iommu: Clarify default domain Kconfig (Jerry Snitselaar) [2112119]
- iommu/io-pgtable: Abstract iommu_iotlb_gather access (Jerry Snitselaar) [2112119]
- iommu/vt-d: Refactor Kconfig a bit (Jerry Snitselaar) [2112119]
- iommu: Allow enabling non-strict mode dynamically (Jerry Snitselaar) [2112119]
- iommu: Merge strictness and domain type configs (Jerry Snitselaar) [2112119]
- iommu: Only log strictness for DMA domains (Jerry Snitselaar) [2112119]
- iommu: Expose DMA domain strictness via sysfs (Jerry Snitselaar) [2112119]
- iommu: Express DMA strictness via the domain type (Jerry Snitselaar) [2112119]
- iommu/vt-d: Prepare for multiple DMA domain types (Jerry Snitselaar) [2112119]
- iommu/arm-smmu: Prepare for multiple DMA domain types (Jerry Snitselaar) [2112119]
- iommu/amd: Prepare for multiple DMA domain types (Jerry Snitselaar) [2112119]
- iommu: Introduce explicit type for non-strict DMA domains (Jerry Snitselaar) [2112119]
- iommu/io-pgtable: Remove non-strict quirk (Jerry Snitselaar) [2112119]
- iommu: Indicate queued flushes via gather data (Jerry Snitselaar) [2112119]
- iommu/amd: Remove stale amd_iommu_unmap_flush usage (Jerry Snitselaar) [2112119]
- iommu: Remove mode argument from iommu_set_dma_strict() (Jerry Snitselaar) [2112119]
- iommu/amd: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2112119]
- iommu/vt-d: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2112119]
- iommu: Enhance IOMMU default DMA mode build options (Jerry Snitselaar) [2112119]
- iommu: Print strict or lazy mode at init time (Jerry Snitselaar) [2112119]
- iommu: Deprecate Intel and AMD cmdline methods to enable strict mode (Jerry Snitselaar) [2112119]
- dma-debug: use memory_intersects() directly (Jerry Snitselaar) [2112119]
- dma-debug: fix return value of __setup handlers (Jerry Snitselaar) [2112119]
- arm-smmu-qcom: Ensure the qcom_scm driver has finished probing (Jerry Snitselaar) [2112119]
- iommu/io-pgtable-arm: Clean up faulty sanity check (Jerry Snitselaar) [2112119]
- iommu/vt-d: Fix RCU list debugging warnings (Jerry Snitselaar) [2112119]
- iommu/dma: add a new dma_map_ops of get_merge_boundary() (Jerry Snitselaar) [2112119]
- swiotlb: do not zero buffer in set_memory_decrypted() (Jerry Snitselaar) [2112119]
- iommu: iommu_ops RH_KABI cleanup (Jerry Snitselaar) [2112119]
- device: Fix RH_KABI work around (Jerry Snitselaar) [2112357]
- iommu/vt-d: Drop stop marker messages (Jerry Snitselaar) [2112119]
- iommu/vt-d: Remove unused function intel_svm_capable() (Jerry Snitselaar) [2112119]
- iommu/arm-smmu-v3: Fix size calculation in arm_smmu_mm_invalidate_range() (Jerry Snitselaar) [2112119]
- iommu/vt-d: Delete dev_has_feat callback (Jerry Snitselaar) [2112119]
- iommu/amd: Remove useless irq affinity notifier (Jerry Snitselaar) [2112119]

* Mon Nov 07 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-435.el8]
- scsi: qedi: Fix ABBA deadlock in qedi_process_tmf_resp() and qedi_process_cmd_cleanup_resp() (Nilesh Javali) [2109890]
- scsi: qedi: Remove set but unused 'page' variable (Nilesh Javali) [2109890]
- x86/elf: Disable automatic READ_IMPLIES_EXEC on 64-bit (Wander Lairson Costa) [2070700] {CVE-2022-25265}
- x86/elf: Split READ_IMPLIES_EXEC from executable PT_GNU_STACK (Wander Lairson Costa) [2070700] {CVE-2022-25265}
- x86/elf: Add table to document READ_IMPLIES_EXEC (Wander Lairson Costa) [2070700] {CVE-2022-25265}
- RHEL-only: KVM: selftests: Enable rseq_test on aarch64 (Gavin Shan) [2128974]
- KVM: selftests: Use getcpu() instead of sched_getcpu() in rseq_test (Gavin Shan) [2128974]
- selftests: kvm: Fix a compile error in selftests/kvm/rseq_test.c (Gavin Shan) [2128974]
- KVM: selftests: Fix target thread to be migrated in rseq_test (Gavin Shan) [2128974]
- selftests: KVM: Handle compiler optimizations in ucall (Gavin Shan) [2128974]
- selftests: kvm: replace ternary operator with min() (Gavin Shan) [2128974]
- KVM: selftests: Fix typo in vgic_init test (Gavin Shan) [2128974]
- KVM: selftests: Fix buggy-but-benign check in test_v3_new_redist_regions() (Gavin Shan) [2128974]
- KVM: arm64: vgic: Fix exit condition in scan_its_table() (Gavin Shan) [2128974]
- KVM: arm64: selftests: Add support for GICv2 on v3 (Gavin Shan) [2128974]
- KVM: arm64: Fix comment typo in nvhe/switch.c (Gavin Shan) [2128974]
- KVM: arm64: vgic: Remove duplicate check in update_affinity_collection() (Gavin Shan) [2128974]
- KVM: arm64: Don't return from void function (Gavin Shan) [2128974]
- KVM: arm64: Drop stale comment (Gavin Shan) [2128974]
- KVM: arm64: Warn if accessing timer pending state outside of vcpu context (Gavin Shan) [2128974]
- KVM: arm64: Replace vgic_v3_uaccess_read_pending with vgic_uaccess_read_pending (Gavin Shan) [2128974]
- KVM: arm64: vgic: Undo work in failed ITS restores (Gavin Shan) [2128974]
- KVM: arm64: vgic: Do not ignore vgic_its_restore_cte failures (Gavin Shan) [2128974]
- KVM: arm64: vgic: Add more checks when restoring ITS tables (Gavin Shan) [2128974]
- KVM: arm64: vgic: Check that new ITEs could be saved in guest memory (Gavin Shan) [2128974]
- KVM: arm64: nvhe: Eliminate kernel-doc warnings (Gavin Shan) [2128974]
- KVM: arm64: Print emulated register table name when it is unsorted (Gavin Shan) [2128974]
- KVM: arm64: Don't BUG_ON() if emulated register table is unsorted (Gavin Shan) [2128974]
- KVM: arm64: Inject exception on out-of-IPA-range translation fault (Gavin Shan) [2128974]
- KVM: arm64: vgic: Remove unnecessary type castings (Gavin Shan) [2128974]
- KVM: arm64: Drop unused param from kvm_psci_version() (Gavin Shan) [2128974]
- KVM: arm64: vgic: Add memcg accounting to vgic allocations (Gavin Shan) [2128974]
- x86/split_lock: Enable the split lock feature on Raptor Lake (Prarit Bhargava) [2076738]
- mm: prevent page_frag_alloc() from corrupting the memory (Izabela Bakollari) [2132265]
- RDMA/mlx5: Set local port to one when accessing counters (Mohammad Kabat) [2077119]
- scsi: ch: Do not initialise statics to 0 (Ewan D. Milne) [2132458]
- scsi: core: Fix warning in scsi_alloc_sgtables() (Ewan D. Milne) [2132458]
- scsi: core: Move the definition of SCSI_QUEUE_DELAY (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Fix zone transition to full condition (Ewan D. Milne) [2132458]
- scsi: sd_zbc: Prevent zone information memory leak (Ewan D. Milne) [2132458]
- scsi: sd: Fix potential NULL pointer dereference (Ewan D. Milne) [2132458]
- scsi: sr: Add memory allocation failure handling for get_capabilities() (Ewan D. Milne) [2132458]
- scsi: sd: Use cached ATA Information VPD page (Ewan D. Milne) [2132458]
- scsi: core: Do not truncate INQUIRY data on modern devices (Ewan D. Milne) [2132458]
- scsi: core: Pick suitable allocation length in scsi_report_opcode() (Ewan D. Milne) [2132458]
- scsi: core: Query VPD size before getting full page (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Add gap zone support (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Rename zone type constants (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Fix a typo (Ewan D. Milne) [2132458]
- scsi: sd: sd_zbc: Hide gap zones (Ewan D. Milne) [2132458]
- scsi: sd: sd_zbc: Return early in sd_zbc_check_zoned_characteristics() (Ewan D. Milne) [2132458]
- scsi: sd: sd_zbc: Introduce struct zoned_disk_info (Ewan D. Milne) [2132458]
- scsi: sd: sd_zbc: Use logical blocks as unit when querying zones (Ewan D. Milne) [2132458]
- scsi: sd: sd_zbc: Verify that the zone size is a power of two (Ewan D. Milne) [2132458]
- scsi: sd: sd_zbc: Improve source code documentation (Ewan D. Milne) [2132458]
- scsi: sr: Do not leak information in ioctl (Ewan D. Milne) [2132458]
- scsi: core: Remove unreachable code warning (Ewan D. Milne) [2132458]
- scsi: libfc: Fix use after free in fc_exch_abts_resp() (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Silence unexpected unlock warnings (Ewan D. Milne) [2132458]
- scsi: Remove unused member cmd_pool for structure scsi_host_template (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Add environmental reporting log subpage (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Add no_rwlock parameter (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Divide power on reset UNIT ATTENTION (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Use TASK SET FULL more (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Strengthen defer_t accesses (Ewan D. Milne) [2132458]
- scsi: ch: Don't use GFP_DMA (Ewan D. Milne) [2132458]
- scsi: scsi_transport_sas: Add 22.5 Gbps link rate definitions (Ewan D. Milne) [2132458]
- scsi: sd: Free scsi_disk device via put_device() (Ewan D. Milne) [2132458]
- scsi: scsi_debug: Adjust num_parts to create equally sized partitions (Ewan D. Milne) [2132458]
- scsi: ch: remove ch_mutex() (Ewan D. Milne) [2132458]
- scsi: ch: synchronize ch_probe() and ch_open() (Ewan D. Milne) [2132458]
- scsi: ch: fixup refcounting imbalance for SCSI devices (Ewan D. Milne) [2132458]
- scsi: mpi3mr: Schedule IRQ kthreads only on non-RT kernels (Tomas Henzl) [2134535]
- netfilter: flowtable: fix stuck flows on cleanup due to pending work (Phil Sutter) [2131370]
- netfilter: flowtable: add function to invoke garbage collection immediately (Phil Sutter) [2131370]
- netfilter: flowtable: pass flowtable to nf_flow_table_iterate() (Phil Sutter) [2131370]
- netfilter: flowtable: separate replace, destroy and stats to different workqueues (Phil Sutter) [2131370]
- drm/mgag200: Fix PLL setup for G200_SE_A rev >=4 (Jocelyn Falempe) [2130159]
- af_key: Do not call xfrm_probe_algs in parallel (Sabrina Dubroca) [2122369] {CVE-2022-3028}
- xfrm: Update ipcomp_scratches with NULL when freed (Sabrina Dubroca) [2136193]
- esp: choose the correct inner protocol for GSO on inter address family tunnels (Sabrina Dubroca) [2136193]
- xfrm: fix refcount leak in __xfrm_policy_check() (Sabrina Dubroca) [2136193]
- xfrm: xfrm_policy: fix a possible double xfrm_pols_put() in xfrm_bundle_lookup() (Sabrina Dubroca) [2136193]
- net: Fix esp GSO on inter address family tunnels. (Sabrina Dubroca) [2136193]
- esp: Fix BEET mode inter address family tunneling on GSO (Sabrina Dubroca) [2136193]
- cifs: fix check of dfs interlinks (Ronnie Sahlberg) [2132414]
- powerpc/pseries: Fix numa FORM2 parsing fallback code (Nico Pache) [2089496]
- powerpc/pseries: rename numa_dist_table to form2_distances (Nico Pache) [2089496]
- x86/pkey: Fix undefined behaviour with PKRU_WD_BIT (Nico Pache) [2089496]
- hugetlb: add lockdep check for i_mmap_rwsem held in huge_pmd_share (Nico Pache) [2089496]
- mm: page_io: fix psi memory pressure error on cold swapins (Nico Pache) [2089496]
- mm/memcg: Remove 'page' parameter to mem_cgroup_charge_statistics() (Nico Pache) [2089496]
- mm: workingset: replace IRQ-off check with a lockdep assert. (Nico Pache) [2089496]
- mm/madvise: fix potential pte_unmap_unlock pte error (Nico Pache) [2089496]
- mm/mmu_notifier.c: fix race in mmu_interval_notifier_remove() (Nico Pache) [2089496]
- mm/sparse.c: remove NULL check in clear_hwpoisoned_pages() (Nico Pache) [2089496]
- node: fix device cleanups in error handling code (Nico Pache) [2089496]
- x86/setup: Fix static memory detection (Nico Pache) [2089496]
- x86/fault: Don't send SIGSEGV twice on SEGV_PKUERR (Nico Pache) [2089496]
- s390/startup: round down "mem" option to page boundary (Nico Pache) [2089496]
- powerpc/64s: Remove 'dummy_copy_buffer' (Nico Pache) [2089496]
- page_alloc: fix invalid watermark check on a negative value (Nico Pache) [2089496]
- lib/radix-tree: remove unused argument of insert_entries (Nico Pache) [2089496]
- drm/radeon: fix incorrrect SPDX-License-Identifiers (Nico Pache) [2089496]
- mm/swap: fix the obsolete comment for SWP_TYPE_SHIFT (Nico Pache) [2089496]
- irq_work: use kasan_record_aux_stack_noalloc() record callstack (Nico Pache) [2089496]
- kdb: Fix the putarea helper function (Nico Pache) [2089496]
- mm: slab: Delete unused SLAB_DEACTIVATED flag (Nico Pache) [2089496]
- mm, kasan: use compare-exchange operation to set KASAN page tag (Nico Pache) [2089496]
- rcu: Avoid alloc_pages() when recording stack (Nico Pache) [2089496]
- workqueue, kasan: avoid alloc_pages() when recording stack (Nico Pache) [2089496]
- kasan: generic: introduce kasan_record_aux_stack_noalloc() (Nico Pache) [2089496]
- kasan: common: provide can_alloc in kasan_save_stack() (Nico Pache) [2089496]
- lib/stackdepot: remove unused function argument (Nico Pache) [2089496]
- lib/stackdepot: include gfp.h (Nico Pache) [2089496]
- blk-cgroup: blk_cgroup_bio_start() should use irq-safe operations on blkg->iostat_cpu (Nico Pache) [2089496]
- libnvdimm/pmem: Fix crash triggered when I/O in-flight during unbind (Nico Pache) [2089496]
- include/trace/events/vmscan.h: remove mm_vmscan_inactive_list_is_low (Nico Pache) [2089496]
- khugepaged: selftests: remove debug_cow (Nico Pache) [2089496]
- mm/mmzone.h: simplify is_highmem_idx() (Nico Pache) [2089496]
- mm/page-writeback: use __this_cpu_inc() in account_page_dirtied() (Nico Pache) [2089496]
- mm/page-writeback: update the comment of Dirty position control (Nico Pache) [2089496]
- mm/page-writeback: Fix performance when BDI's share of ratio is 0. (Nico Pache) [2089496]
- fuse: ignore PG_workingset after stealing (Nico Pache) [2089496]
- mm/slub: actually fix freelist pointer vs redzoning (Nico Pache) [2089496]
- mm/slub: clarify verification reporting (Nico Pache) [2089496]
- irq_work: Make irq_work_queue() NMI-safe again (Nico Pache) [2089496]
- mm/huge_memory.c: remove unused macro TRANSPARENT_HUGEPAGE_DEBUG_COW_FLAG (Nico Pache) [2089496]
- irq_work: record irq_work_queue() call stack (Nico Pache) [2089496]
- arm64: kasan: fix page_alloc tagging with DEBUG_VIRTUAL (Nico Pache) [2089496]
- mm/arm64: Correct obsolete comment in do_page_fault() (Nico Pache) [2089496]
- kernel: kexec: remove the lock operation of system_transition_mutex (Nico Pache) [2089496]
- libnvdimm/pmem: Remove unused header (Nico Pache) [2089496]
- workqueue: kasan: record workqueue stack (Nico Pache) [2089496]
- lib/test_kasan.c: add workqueue test case (Nico Pache) [2089496]
- page_frag: Recover from memory pressure (Nico Pache) [2089496]
- mm: use helper function put_write_access() (Nico Pache) [2089496]
- mm/swapfile.c: remove unnecessary goto out in _swap_info_get() (Nico Pache) [2089496]
- mm/swap.c: fix incomplete comment in lru_cache_add_inactive_or_unevictable() (Nico Pache) [2089496]
- mm/page_io.c: remove useless out label in __swap_writepage() (Nico Pache) [2089496]
- mm/swap_slots.c: remove always zero and unused return value of enable_swap_slots_cache() (Nico Pache) [2089496]
- mm/swap.c: fix confusing comment in release_pages() (Nico Pache) [2089496]
- mm: annotate a data race in page_zonenum() (Nico Pache) [2089496]
- mm/swap.c: annotate data races for lru_rotate_pvecs (Nico Pache) [2089496]
- mm/rmap: annotate a data race at tlb_flush_batched (Nico Pache) [2089496]
- mm/mempool: fix a data race in mempool_free() (Nico Pache) [2089496]
- mm/list_lru: fix a data race in list_lru_count_one (Nico Pache) [2089496]
- mm/memcontrol: fix a data race in scan count (Nico Pache) [2089496]
- mm/swapfile: fix and annotate various data races (Nico Pache) [2089496]
- mm: thp: remove debug_cow switch (Nico Pache) [2089496]
- page_alloc: consider highatomic reserve in watermark fast (Nico Pache) [2089496]
- mm: remove unnecessary wrapper function do_mmap_pgoff() (Nico Pache) [2089496]
- doc: don't use deprecated "---help---" markers in target docs (Nico Pache) [2089496]
- doc: cgroup: update note about conditions when oom killer is invoked (Nico Pache) [2089496]
- mm: add kvfree_sensitive() for freeing sensitive data objects (Nico Pache) [2089496]
- f2fs: fix retry logic in f2fs_write_cache_pages() (Nico Pache) [2089496]
- mm/hugetlb: avoid unnecessary check on pud and pmd entry in huge_pte_offset (Nico Pache) [2089496]
- mm/page-writeback.c: remove unused variable (Nico Pache) [2089496]
- zswap: docs/vm: Fix typo accept_threshold_percent in zswap.rst (Nico Pache) [2089496]
- tracing: Add a vmalloc_sync_mappings() for safe measure (Nico Pache) [2089496]
- mm/hugetlb: fix a addressing exception caused by huge_pte_offset (Nico Pache) [2089496]
- mm/page-writeback.c: write_cache_pages(): deduplicate identical checks (Nico Pache) [2089496]
- revert "topology: add support for node_to_mem_node() to determine the fallback node" (Nico Pache) [2089496]
- net: memcg: fix lockdep splat in inet_csk_accept() (Nico Pache) [2089496]
- net: memcg: late association of sock to memcg (Nico Pache) [2089496]
- tmpfs: deny and force are not huge mount options (Nico Pache) [2089496]
- mm/zswap.c: add allocation hysteresis if pool limit is hit (Nico Pache) [2089496]
- mm/swapfile.c: swap_next should increase position index (Nico Pache) [2089496]
- fat: use prandom_u32() for i_generation (Nico Pache) [2089496]
- mm/mmap.c: rb_parent is not necessary in __vma_link_list() (Nico Pache) [2089496]
- mm/mmap.c: __vma_unlink_prev() is not necessary now (Nico Pache) [2089496]
- docs: kmemleak: DEBUG_KMEMLEAK_EARLY_LOG_SIZE changed names (Nico Pache) [2089496]
- mm/mmap.c: prev could be retrieved from vma->vm_prev (Nico Pache) [2089496]
- mm/zsmalloc.c: fix a -Wunused-function warning (Nico Pache) [2089496]
- mm/rmap.c: remove set but not used variable 'cstart' (Nico Pache) [2089496]
- tools headers UAPI: Update tools's copy of mman.h headers (Nico Pache) [2089496]
- mm/mmap: move common defines to mman-common.h (Nico Pache) [2089496]
- mm: fix the MAP_UNINITIALIZED flag (Nico Pache) [2089496]
- mm: vmalloc: show number of vmalloc pages in /proc/meminfo (Nico Pache) [2089496]
- slab: remove /proc/slab_allocators (Nico Pache) [2089496]
- mm/huge_memory.c: fix "orig_pud" set but not used (Nico Pache) [2089496]
- mm: hwpoison: use do_send_sig_info() instead of force_sig() (Nico Pache) [2089496]
- mm, page_alloc: drop should_suppress_show_mem (Nico Pache) [2089496]
- mm,page_alloc: PF_WQ_WORKER threads must sleep at should_reclaim_retry() (Nico Pache) [2089496]
- powerpc/8xx: Use patch_site for perf counters setup (Nico Pache) [2089496]
- powerpc/8xx: Use patch_site for memory setup patching (Nico Pache) [2089496]
- Revert "powerpc/8xx: Use L1 entry APG to handle _PAGE_ACCESSED for CONFIG_SWAP" (Nico Pache) [2089496]
- mm/swapfile.c: put_swap_page: share more between huge/normal code path (Nico Pache) [2089496]
- mm, swap, get_swap_pages: use entry_size instead of cluster in parameter (Nico Pache) [2089496]
- mm/swapfile.c: add __swap_entry_free_locked() (Nico Pache) [2089496]
- mm/swapfile.c: unify normal/huge code path in put_swap_page() (Nico Pache) [2089496]
- mm/swapfile.c: unify normal/huge code path in swap_page_trans_huge_swapped() (Nico Pache) [2089496]
- mm/swapfile.c: replace some #ifdef with IS_ENABLED() (Nico Pache) [2089496]
- mm: swap: add comments to lock_cluster_or_swap_info() (Nico Pache) [2089496]
- mm/swapfile.c: use swap_count() in swap_page_trans_huge_swapped() (Nico Pache) [2089496]
- mm, oom: remove sleep from under oom_lock (Nico Pache) [2089496]
- mm/hugetlb: remove gigantic page support for HIGHMEM (Nico Pache) [2089496]
- mm/page-writeback.c: update stale account_page_redirty() comment (Nico Pache) [2089496]
- shmem: use monotonic time for i_generation (Nico Pache) [2089496]
- mptcp: increase default max additional subflows to 2 (Paolo Abeni) [2127136]
- ipv6/addrconf: fix a null-ptr-deref bug for ip6_ptr (Davide Caratti) [2103990]
- ipv6: Refactor fib6_ignore_linkdown (Davide Caratti) [2103990]
- Revert "net: af_key: add check for pfkey_broadcast in function pfkey_process" (Davide Caratti) [2103990]
- net: af_key: add check for pfkey_broadcast in function pfkey_process (Davide Caratti) [2103990]
- certs: Add FIPS selftests (Vladis Dronov) [2134828]
- certs: Move load_certificate_list() to be with the asymmetric keys code (Vladis Dronov) [2134828]

* Wed Nov 02 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-434.el8]
- selftests/bpf: Limit unroll_count for pyperf600 test (Viktor Malik) [2139128]

* Mon Oct 31 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-433.el8]
- perf affinity: Fix out of bound access to "sched_cpus" mask (Michael Petlan) [2125952]
- net: skb: introduce and use a single page frag cache (Paolo Abeni) [2063335]
- powerpc/pseries/vas: Pass hw_cpu_id to node associativity HCALL (Steve Best) [2131651]
- agp/intel: Rename intel-gtt symbols (Jocelyn Falempe) [2115871]
- drm/i915/gt: Split intel-gtt functions by arch (Jocelyn Falempe) [2115871]
- drm: Implement DRM aperture helpers under video/ (Jocelyn Falempe) [2115871]
- efi: Fix build error due to enum collision between efi.h and ima.h (Jocelyn Falempe) [2115871]
- Revert "workqueue: remove unused cancel_work()" (Jocelyn Falempe) [2115871]
- dma-buf: fix use of DMA_BUF_SET_NAME_{A,B} in userspace (Jocelyn Falempe) [2115871]
- drm/i915/gsc: add gsc as a mei auxiliary device (Jocelyn Falempe) [2115871]
- drm/i915: Prepare for multiple GTs (Jocelyn Falempe) [2115871]
- drm/i915/gt: add gt_is_root() helper (Jocelyn Falempe) [2115871]
- drm/i915: Rename INTEL_REGION_LMEM with INTEL_REGION_LMEM_0 (Jocelyn Falempe) [2115871]
- drm/i915: fixup the initial fb base on DGFX (Jocelyn Falempe) [2115871]
- drm/i915: add i915_gem_object_create_region_at() (Jocelyn Falempe) [2115871]
- drm/i915: Report steering details in debugfs (Jocelyn Falempe) [2115871]
- x86/gpu: include drm/i915_pciids.h directly in early quirks (Jocelyn Falempe) [2115871]
- staging: fbtft: core: set smem_len before fb_deferred_io_init call (Jocelyn Falempe) [2115871]
- fbdev: Put mmap for deferred I/O into drivers (Jocelyn Falempe) [2115871]
- fbdev: Track deferred-I/O pages in pageref struct (Jocelyn Falempe) [2115871]
- fbdev: defio: fix the pagelist corruption (Jocelyn Falempe) [2115871]
- fbdev: Don't sort deferred-I/O pages by default (Jocelyn Falempe) [2115871]
- staging: fbtft: Add spaces around / - Style (Jocelyn Falempe) [2115871]
- fbdev/defio: Early-out if page is already enlisted (Jocelyn Falempe) [2115871]
- panic, kexec: make __crash_kexec() NMI safe (Valentin Schneider) [2134126]
- kexec: turn all kexec_mutex acquisitions into trylocks (Valentin Schneider) [2134126]
- kexec: move locking into do_kexec_load (Valentin Schneider) [2134126]
- ice: Fix interface being down after reset with link-down-on-close flag on (Petr Oros) [2024110]
- ice: Add low latency Tx timestamp read (Petr Oros) [2092425]
- ice: introduce ice_ptp_reset_cached_phctime function (Petr Oros) [2092425]
- ice: re-arrange some static functions in ice_ptp.c (Petr Oros) [2092425]
- ice: track and warn when PHC update is late (Petr Oros) [2092425]
- ice: track Tx timestamp stats similar to other Intel drivers (Petr Oros) [2092425]
- ice: implement adjfine with mul_u64_u64_div_u64 (Petr Oros) [2092425]
- ice: Add EXTTS feature to the feature bitmap (Petr Oros) [2092425]
- math: Export mul_u64_u64_div_u64 (Petr Oros) [2092425]
- neighbour: allow NUD_NOARP entries to be forced GCed (Xin Long) [2076534]
- neighbour: Prevent Race condition in neighbour subsytem (Xin Long) [2076534]
- neighbour: Prevent a dead entry from updating gc_list (Xin Long) [2076534]
- net: Exempt multicast addresses from five-second neighbor lifetime (Xin Long) [2076534]
- neighbor: Reset gc_entries counter if new entry is released before insert (Xin Long) [2076534]
- neighbor: Remove externally learned entries from gc_list (Xin Long) [2076534]
- neighbor: Move neigh_update_ext_learned to core file (Xin Long) [2076534]
- neighbor: Remove state and flags arguments to neigh_del (Xin Long) [2076534]
- neighbor: Fix state check in neigh_forced_gc (Xin Long) [2076534]
- neighbor: Fix locking order for gc_list changes (Xin Long) [2076534]
- neighbor: gc_list changes should be protected by table lock (Xin Long) [2076534]
- neighbor: Improve garbage collection (Xin Long) [2076534]
- neighbour: send netlink notification if NTF_ROUTER changes (Xin Long) [2076534]
- neighbour: allow admin to set NTF_ROUTER (Xin Long) [2076534]
- s390/dasd: add device ping attribute (Tobias Huschle) [2043877]
- s390/dasd: suppress generic error messages for PPRC secondary devices (Tobias Huschle) [2043877]
- s390/dasd: add ioctl to perform a swap of the drivers copy pair (Tobias Huschle) [2043877]
- s390/dasd: add copy pair swap capability (Tobias Huschle) [2043877]
- s390/dasd: add copy pair setup (Tobias Huschle) [2043877]
- s390/dasd: add query PPRC function (Tobias Huschle) [2043877]
- s390/dasd: put block allocation in separate function (Tobias Huschle) [2043877]
- s390/dasd: fix Oops in dasd_alias_get_start_dev due to missing pavgroup (Tobias Huschle) [2043877]
- s390/qeth: Split memcpy() of struct qeth_ipacmd_addr_change flexible array (Tobias Huschle) [2110426]
- s390/qeth: Fix typo 'the the' in comment (Tobias Huschle) [2110426]
- s390/qdio: Fix spelling mistake (Tobias Huschle) [2110426]
- qeth: remove a copy of the NAPI_POLL_WEIGHT define (Tobias Huschle) [2110426]
- scsi: bnx2fc: Avoid using get_cpu() in bnx2fc_cmd_alloc() (Nilesh Javali) [2109895]
- scsi: bnx2fc: Fix spelling mistake "mis-match" -> "mismatch" (Nilesh Javali) [2109895]
- scsi: bnx2fc: Make use of the helper macro kthread_run() (Nilesh Javali) [2109895]
- scsi: bnx2fc: Fix typo in comments (Nilesh Javali) [2109895]
- scsi: qedf: Populate sysfs attributes for vport (Nilesh Javali) [2120219]
- scsi: qedf: Fix typo in comment (Nilesh Javali) [2109893]
- scsi: qedf: Remove redundant variable op (Nilesh Javali) [2109893]
- scsi: qedf: Remove an unneeded NULL check on list iterator (Nilesh Javali) [2109893]
- scsi: qedf: Remove unnecessary code (Nilesh Javali) [2109893]
- s390/sclp: reserve memory occupied by sclp early buffer (Mete Durlu) [2060830]
- s390: make command line configurable (Mete Durlu) [2060830]
- s390: support command lines longer than 896 bytes (Mete Durlu) [2060830]
- s390/kexec_file: move kernel image size check (Mete Durlu) [2060830]
- s390/boot: move sclp early buffer from fixed address in asm to C (Mete Durlu) [2060830]
- drivers/base: Fix unsigned comparison to -1 in CPUMAP_FILE_MAX_BYTES (Phil Auld) [2115518]
- sched/core: Do not requeue task on CPU excluded from cpus_mask (Phil Auld) [2115518]
- workqueue: Avoid a false warning in unbind_workers() (Phil Auld) [2115518]
- sched/core: Always flush pending blk_plug (Phil Auld) [2115518]
- sched/fair: fix case with reduced capacity CPU (Phil Auld) [2115518]
- sched: Remove unused function group_first_cpu() (Phil Auld) [2115518]
- sched/fair: Remove redundant word " *" (Phil Auld) [2115518]
- sched: only perform capability check on privileged operation (Phil Auld) [2115518]
- sched: Allow newidle balancing to bail out of load_balance (Phil Auld) [2115518]
- sched: Remove the limitation of WF_ON_CPU on wakelist if wakee cpu is idle (Phil Auld) [2115518]
- sched: Fix the check of nr_running at queue wakelist (Phil Auld) [2115518]
- sched: Fix balance_push() vs __sched_setscheduler() (Phil Auld) [2115518]
- sched/fair: Optimize and simplify rq leaf_cfs_rq_list (Phil Auld) [2115518]
- topology: Remove unused cpu_cluster_mask() (Phil Auld) [2115518]
- sched: Update task_tick_numa to ignore tasks without an mm (Phil Auld) [2115518]
- sched/deadline: Remove superfluous rq clock update in push_dl_task() (Phil Auld) [2115518]
- time/sched_clock: Fix formatting of frequency reporting code (Phil Auld) [2115518]
- time/sched_clock: Use Hz as the unit for clock rate reporting below 4kHz (Phil Auld) [2115518]
- time/sched_clock: Round the frequency reported to nearest rather than down (Phil Auld) [2115518]
- sched/fair: Delete useless condition in tg_unthrottle_up() (Phil Auld) [2115518]
- sched/fair: Fix cfs_rq_clock_pelt() for throttled cfs_rq (Phil Auld) [2115518]
- workqueue: Restrict kworker in the offline CPU pool running on housekeeping CPUs (Phil Auld) [2115518]
- kernel/sched: Remove dl_boosted flag comment (Phil Auld) [2115518]
- workqueue: Remove schedule() in unbind_workers() (Phil Auld) [2115518]
- workqueue: Remove outdated comment about exceptional workers in unbind_workers() (Phil Auld) [2115518]
- workqueue: Remove the advanced kicking of the idle workers in rebind_workers() (Phil Auld) [2115518]
- workqueue: Fix unbind_workers() VS wq_worker_running() race (Phil Auld) [2115518]
- sched/membarrier: fix missing local execution of ipi_sync_rq_state() (Phil Auld) [2115518]
- kthread: Move prio/affinite change into the newly created thread (Phil Auld) [2115518]

* Mon Oct 24 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-432.el8]
- dmaengine: idxd: Correct IAX operation code names (Jerry Snitselaar) [2112121]
- dmaengine: dmatest: use strscpy to replace strlcpy (Jerry Snitselaar) [2112121]
- dmaengine: remove DMA_MEMCPY_SG once again (Jerry Snitselaar) [2112121]
- MAINTAINERS: idxd driver maintainer update (Jerry Snitselaar) [2112121]
- dmaengine: dmatest: Replace symbolic permissions by octal permissions (Jerry Snitselaar) [2112121]
- dmaengine: dmatest: Remove spaces before tabs (Jerry Snitselaar) [2112121]
- dma:dw: remove reference to AVR32 architecture in core.c (Jerry Snitselaar) [2112121]
- dmaengine: idxd: Only call idxd_enable_system_pasid() if succeeded in enabling SVA feature (Jerry Snitselaar) [2112121]
- dmaengine: idxd: force wq context cleanup on device disable path (Jerry Snitselaar) [2112121]
- dmaengine: Revert "dmaengine: add verification of DMA_INTERRUPT capability for dmatest" (Jerry Snitselaar) [2112121]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2112121]
- dmaengine: ptdma: statify pt_tx_status (Jerry Snitselaar) [2112121]
- dmaengine: hidma: In hidma_prep_dma_memset treat value as a single byte (Jerry Snitselaar) [2112121]
- dmaengine: Document dmaengine_prep_dma_memset (Jerry Snitselaar) [2112121]
- dmaengine: PTDMA: support polled mode (Jerry Snitselaar) [2112121]
- dmaengine: Remove a useless mutex (Jerry Snitselaar) [2112121]
- dmaengine: idxd: update IAA definitions for user header (Jerry Snitselaar) [2112121]
- dmaengine: Clarify cyclic transfer residue documentation (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2112121]
- dmaengine: iot: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2112121]
- dmaengine: ioatdma: use default_groups in kobj_type (Jerry Snitselaar) [2112121]
- Documentation: dmaengine: Correctly describe dmatest with channel unset (Jerry Snitselaar) [2112121]
- Documentation: dmaengine: Add a description of what dmatest does (Jerry Snitselaar) [2112121]
- dmaengine: Add core function and capability check for DMA_MEMCPY_SG (Jerry Snitselaar) [2112121]
- dmaengine: Add documentation for new memcpy scatter-gather function (Jerry Snitselaar) [2112121]
- dmaengine: remove slave_id config field (Jerry Snitselaar) [2112121]
- dmaengine: ioat: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112121]
- dmaengine: hsu: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112121]
- dmaengine: dw: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112121]
- dmaengine: remove debugfs #ifdef (Jerry Snitselaar) [2112121]
- dmaengine: dmaengine_desc_callback_valid(): Check for `callback_result` (Jerry Snitselaar) [2112121]
- dmaengine: Remove redundant initialization of variable err (Jerry Snitselaar) [2112121]
- dmaengine: Extend the dma_slave_width for 128 bytes (Jerry Snitselaar) [2112121]
- dmaengine: ioat: depends on !UML (Jerry Snitselaar) [2112121]
- dmaengine: dw: Simplify DT property parser (Jerry Snitselaar) [2112121]
- dmaengine: dw: Convert members to u32 in platform data (Jerry Snitselaar) [2112121]
- dmaengine: dw: Remove error message from DT parsing code (Jerry Snitselaar) [2112121]
- dmaengine: of-dma: router_xlate to return -EPROBE_DEFER if controller is not yet available (Jerry Snitselaar) [2112121]
- dmaengine: hsu: Account transferred bytes (Jerry Snitselaar) [2112121]
- dmaengine: Move kdoc description of struct dma_chan_percpu closer to it (Jerry Snitselaar) [2112121]
- dmaengine: QCOM_HIDMA_MGMT depends on HAS_IOMEM (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: comment platform_driver_register call (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: remove unused code (Jerry Snitselaar) [2112121]
- dmaengine: Fix a double free in dma_async_device_register (Jerry Snitselaar) [2112121]
- dmaengine: hsu: disable spurious interrupt (Jerry Snitselaar) [2112121]
- dmaengine: Extend the dmaengine_alignment for 128 and 256 bytes (Jerry Snitselaar) [2112121]
- dmaengine: dmatest: Use dmaengine_get_dma_device (Jerry Snitselaar) [2112121]
- dmaengine: doc: client: Update for dmaengine_get_dma_device() usage (Jerry Snitselaar) [2112121]
- dmaengine: Add support for per channel coherency handling (Jerry Snitselaar) [2112121]
- dmaengine: of-dma: Add support for optional router configuration callback (Jerry Snitselaar) [2112121]
- dmaengine: add peripheral configuration (Jerry Snitselaar) [2112121]
- dmaengine: idma64: Switch to use __maybe_unused instead of ifdeffery (Jerry Snitselaar) [2112121]
- dmaengine: ioatdma: remove unused function missed during dma_v2 removal (Jerry Snitselaar) [2112121]
- dmaengine: Save few bytes and increase readability of dma_request_chan() (Jerry Snitselaar) [2112121]
- dmaengine: of-dma: Fix of_dma_router_xlate's of_dma_xlate handling (Jerry Snitselaar) [2112121]
- dmaengine: dw: Don't include unneeded header to platform data header (Jerry Snitselaar) [2112121]
- dmaengine: linux/dmaengine.h: drop duplicated word in a comment (Jerry Snitselaar) [2112121]
- dmaengine: ioat: Fix some parameter misspelling and provide description for phys_complete (Jerry Snitselaar) [2112121]
- dmaengine: of-dma: Fix misspellings/formatting issues in some function headers (Jerry Snitselaar) [2112121]
- Documentation/driver-api: dmaengine/provider: drop doubled word (Jerry Snitselaar) [2112121]
- dmaengine: Add support for repeating transactions (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: use true,false for bool variable (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: Simplify error handling path in hidma_probe (Jerry Snitselaar) [2112121]
- dmaengine: Fix misspelling of "Analog Devices" (Jerry Snitselaar) [2112121]
- docs: dmaengine: provider.rst: get rid of some warnings (Jerry Snitselaar) [2112121]
- dmaengine: doc: fix warnings/issues of client.rst (Jerry Snitselaar) [2112121]
- dmaengine: doc: Properly indent metadata title (Jerry Snitselaar) [2112121]
- dmaengine: doc: Add sections for per descriptor metadata support (Jerry Snitselaar) [2112121]
- dmaengine: Fix Kconfig indentation (Jerry Snitselaar) [2112121]
- dmaengine: qcom: hidma_mgmt: Add of_node_put() before goto (Jerry Snitselaar) [2112121]
- dmaengine: Remove dev_err() usage after platform_get_irq() (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: Remove call to memset after dmam_alloc_coherent (Jerry Snitselaar) [2112121]
- Documentation: dmaengine: clean up description of dmatest usage (Jerry Snitselaar) [2112121]
- dmaengine: hsu: Revert "set HSU_CH_MTSR to memory width" (Jerry Snitselaar) [2112121]
- dmaengine: qcom: hidma: no need to check return value of debugfs_create functions (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: assign channel cookie correctly (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: initialize tx flags in hidma_prep_dma_* (Jerry Snitselaar) [2112121]
- dmaengine: qcom_hidma: convert to DEFINE_SHOW_ATTRIBUTE (Jerry Snitselaar) [2112121]
- dmaengine: Documentation: Add documentation for multi chan testing (Jerry Snitselaar) [2112121]
- dmaengine: hsu: remove dma_slave_config direction usage (Jerry Snitselaar) [2112121]
- dmaengine: hsu: Support dmaengine_terminate_sync() (Jerry Snitselaar) [2112121]
- scsi: core: Allow the ALUA transitioning state enough time (Tomas Henzl) [2084250]
- scsi: core: Return BLK_STS_TRANSPORT for ALUA transitioning (Tomas Henzl) [2084250]
- macvlan: enforce a consistent minimal mtu (Davide Caratti) [2134032]
- ipvlan: Fix out-of-bound bugs caused by unset skb->mac_header (Davide Caratti) [2134032]
- net: ipvtap - add __init/__exit annotations to module init/exit funcs (Davide Caratti) [2134032]
- tunnels: do not assume mac header is set in skb_tunnel_check_pmtu() (Guillaume Nault) [2134099]
- erspan: do not assume transport header is always set (Guillaume Nault) [2134099]
- net: ip_gre: do not report erspan_ver for gre or gretap (Guillaume Nault) [2134099]
- selftests: Fix the if conditions of in test_extra_filter() (Hangbin Liu) [2135232]
- selftests: forwarding: add shebang for sch_red.sh (Hangbin Liu) [2135232]
- selftests: forwarding: fix error message in learning_test (Hangbin Liu) [2135232]
- selftests/net: pass ipv6_args to udpgso_bench's IPv6 TCP test (Hangbin Liu) [2135232]
- ping: remove pr_err from ping_lookup (Guillaume Nault) [2135424]
- ping: fix the dif and sdif check in ping_lookup (Guillaume Nault) [2135424]
- ping: fix the sk_bound_dev_if match in ping_lookup (Guillaume Nault) [2135424]
- tcp/udp: Call inet6_destroy_sock() in IPv6 sk->sk_destruct(). (Hangbin Liu) [2135259]
- udp: Call inet6_destroy_sock() in setsockopt(IPV6_ADDRFORM). (Hangbin Liu) [2135259]
- tcp/udp: Fix memory leak in ipv6_renew_options(). (Hangbin Liu) [2135259]
- ipv6: sr: fix out-of-bounds read when setting HMAC data. (Hangbin Liu) [2135259]
- ipv6: do not use RT_TOS for IPv6 flowlabel (Hangbin Liu) [2135259]
- ipv6/sit: fix ipip6_tunnel_get_prl return value (Hangbin Liu) [2135259]
- sit: use min (Hangbin Liu) [2135259]
- net: ipv6: unexport __init-annotated seg6_hmac_init() (Hangbin Liu) [2135259]
- sit: do not call ipip6_dev_free() from sit_init_net() (Hangbin Liu) [2135259]
- block: avoid sign extend problem with default queue flags mask (Nico Pache) [2131929]
- mm/hwpoison: do not lock page again when me_huge_page() successfully recovers (Aristeu Rozanski) [2110292]
- crypto: ccp - Remove the unneeded result variable (Vladis Dronov) [2130195]
- crypto: ccp - Release dma channels before dmaengine unrgister (Vladis Dronov) [2130195]
- crypto: ccp - Fail the PSP initialization when writing psp data file failed (Vladis Dronov) [2130195]
- crypto: ccp - Initialize PSP when reading psp data file failed (Vladis Dronov) [2130195]
- crypto: ccp - Add a quirk to firmware update (Vladis Dronov) [2130195]
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [2130195]
- crypto: ccp - During shutdown, check SEV data pointer before using (Vladis Dronov) [2130195]
- crypto: ccp - Fix device IRQ counting by using platform_irq_count() (Vladis Dronov) [2130195]
- crypto: ccp - fix typo in comment (Vladis Dronov) [2130195]
- crypto: ccp - Use kzalloc for sev ioctl interfaces to prevent kernel memory leak (Vladis Dronov) [2130195]
- crypto: ccp - Fix the INIT_EX data file open failure (Vladis Dronov) [2130195]
- crypto: ccp - Log when resetting PSP SEV state (Vladis Dronov) [2130195]
- crypto: ccp - When TSME and SME both detected notify user (Vladis Dronov) [2130195]
- crypto: ccp - Allow PSP driver to load without SEV/TEE support (Vladis Dronov) [2130195]
- crypto: ccp - Export PSP security bits to userspace (Vladis Dronov) [2130195]
- crypto: ccp - cache capability into psp device (Vladis Dronov) [2130195]
- PCI: Add support for dev_groups to struct pci_driver (Vladis Dronov) [2130195]
- ACPI: processor idle: Practically limit "Dummy wait" workaround to old Intel systems (Wei Huang) [2130653]
- blk-mq: fix io hung due to missing commit_rqs (Ming Lei) [2130028]
- block: schedule queue restart after BLK_STS_ZONE_RESOURCE (Ming Lei) [2130028]
- blk-mq: call commit_rqs while list empty but error happen (Ming Lei) [2130028]
- null_blk: fix ida error handling in null_add_dev() (Ming Lei) [2130028]
- blktrace: Trace remapped requests correctly (Ming Lei) [2130028]
- virtio_blk: fix the discard_granularity and discard_alignment queue limits (Ming Lei) [2130028]
- block: fix bio_clone_blkg_association() to associate with proper blkcg_gq (Ming Lei) [2130028]
- blk-mq: do not update io_ticks with passthrough requests (Ming Lei) [2130028]
- blk-mq: don't touch ->tagset in blk_mq_get_sq_hctx (Ming Lei) [2130028]
- ipmi:ipmb: Fix refcount leak in ipmi_ipmb_probe (Tony Camuso) [2130238]
- ipmi: remove unnecessary type castings (Tony Camuso) [2130238]
- ipmi: Make two logs unique (Tony Camuso) [2130238]
- ipmi:si: Convert pr_debug() to dev_dbg() (Tony Camuso) [2130238]
- ipmi: Convert pr_debug() to dev_dbg() (Tony Camuso) [2130238]
- ipmi: Fix pr_fmt to avoid compilation issues (Tony Camuso) [2130238]
- ipmi: Add an intializer for ipmi_recv_msg struct (Tony Camuso) [2130238]
- ipmi: Add an intializer for ipmi_smi_msg struct (Tony Camuso) [2130238]
- ipmi:ssif: Check for NULL msg when handling events and messages (Tony Camuso) [2130238]
- ipmi: use simple i2c probe function (Tony Camuso) [2130238]
- ipmi: Add a sysfs count of total outstanding messages for an interface (Tony Camuso) [2130238]
- ipmi: Add a sysfs interface to view the number of users (Tony Camuso) [2130238]
- ipmi: Limit the number of message a user may have outstanding (Tony Camuso) [2130238]
- ipmi: Add a limit on the number of users that may use IPMI (Tony Camuso) [2130238]
- ipmi:ipmi_ipmb: Fix null-ptr-deref in ipmi_unregister_smi() (Tony Camuso) [2130238]
- ipmi: When handling send message responses, don't process the message (Tony Camuso) [2130238]
- ipmi: fix IPMI_SMI_MSG_TYPE_IPMB_DIRECT response length checking (Tony Camuso) [2130238]
- ipmi: fix oob access due to uninit smi_msg type (Tony Camuso) [2130238]
- ipmi: Make kABI adjustments (Tony Camuso) [2130238]
- ipmi: Add support for IPMB direct messages (Tony Camuso) [2130238]
- ice: Fix crash by keep old cfg when update TCs more than queues (Petr Oros) [2129902]
- ice: Fix tunnel checksum offload with fragmented traffic (Petr Oros) [2129902]
- ice: handle E822 generic device ID in PLDM header (Petr Oros) [2129902]
- ice: ethtool: Prohibit improper channel config for DCB (Petr Oros) [2129902]
- ice: ethtool: advertise 1000M speeds properly (Petr Oros) [2129902]
- ice: Fix switchdev rules book keeping (Petr Oros) [2129902]
- ice: fix access-beyond-end in the switch code (Petr Oros) [2129902]
- eth: ice: silence the GCC 12 array-bounds warning (Petr Oros) [2129902]
- ice: Expose RSS indirection tables for queue groups via ethtool (Petr Oros) [2129902]
- Revert "ice: Hide bus-info in ethtool for PRs in switchdev mode" (Petr Oros) [2129902]
- ice: remove period on argument description in ice_for_each_vf (Petr Oros) [2129902]
- ice: add a function comment for ice_cfg_mac_antispoof (Petr Oros) [2129902]
- ice: fix wording in comment for ice_reset_vf (Petr Oros) [2129902]
- ice: remove return value comment for ice_reset_all_vfs (Petr Oros) [2129902]
- ice: always check VF VSI pointer values (Petr Oros) [2129902]
- ice: add newline to dev_dbg in ice_vf_fdir_dump_info (Petr Oros) [2129902]
- ice: get switch id on switchdev devices (Petr Oros) [2129902]
- ice: return ENOSPC when exceeding ICE_MAX_CHAIN_WORDS (Petr Oros) [2129902]
- ice: introduce common helper for retrieving VSI by vsi_num (Petr Oros) [2129902]
- ice: use min_t() to make code cleaner in ice_gnss (Petr Oros) [2129902]
- ice: Add mpls+tso support (Petr Oros) [2129902]
- ice: switch: convert packet template match code to rodata (Petr Oros) [2129902]
- ice: switch: use convenience macros to declare dummy pkt templates (Petr Oros) [2129902]
- ice: switch: use a struct to pass packet template params (Petr Oros) [2129902]
- ice: switch: unobscurify bitops loop in ice_fill_adv_dummy_packet() (Petr Oros) [2129902]
- ice: switch: add and use u16[] aliases to ice_adv_lkup_elem::{h, m}_u (Petr Oros) [2129902]
- ice: Support GTP-U and GTP-C offload in switchdev (Petr Oros) [2129902]
- ice: Remove useless DMA-32 fallback configuration (Petr Oros) [2129902]
- ice: switch to napi_build_skb() (Petr Oros) [2129902]
- nbd: fix race between nbd_alloc_config() and module removal (Ming Lei) [2127601]
- nbd: call genl_unregister_family() first in nbd_cleanup() (Ming Lei) [2127601]
- kselftests: memcg: speed up the memory.high test (Waiman Long) [1839057]
- tools/testing/selftests/cgroup/cgroup_util.c: cg_read_strcmp: fix null pointer dereference (Waiman Long) [1839057]
- kselftest/cgroup: fix incorrect test_core skip (Waiman Long) [1839057]
- kselftest/cgroup: fix unexpected testing failure on test_core (Waiman Long) [1839057]
- selftests: cgroup: fix cleanup path in test_memcg_subtree_control() (Waiman Long) [1839057]
- cgroup: fix an error handling path in alloc_pagecache_max_30M() (Waiman Long) [1839057]
- selftests: memcg: expect no low events in unprotected sibling (Waiman Long) [1839057]
- selftests: memcg: fix compilation (Waiman Long) [1839057]
- kseltest/cgroup: Make test_stress.sh work if run interactively (Waiman Long) [1839057]
- cgroup: fix racy check in alloc_pagecache_max_30M() helper function (Waiman Long) [1839057]
- cgroup: remove racy check in test_memcg_sock() (Waiman Long) [1839057]
- cgroup: account for memory_localevents in test_memcg_oom_group_leaf_events() (Waiman Long) [1839057]
- cgroup: account for memory_recursiveprot in test_memcg_low() (Waiman Long) [1839057]
- cgroups: refactor children cgroups in memcg tests (Waiman Long) [1839057]
- kselftest/cgroup: fix test_stress.sh to use OUTPUT dir (Waiman Long) [1839057]
- selftests: cgroup: add a selftest for memory.reclaim (Waiman Long) [1839057]
- selftests: cgroup: fix alloc_anon_noexit() instantly freeing memory (Waiman Long) [1839057]
- selftests: cgroup: return -errno from cg_read()/cg_write() on failure (Waiman Long) [1839057]
- memcg: introduce per-memcg reclaim interface (Waiman Long) [1839057]
- kselftests: memcg: update the oom group leaf events test (Waiman Long) [1839057]
- mm/memcontrol: return 1 from cgroup.memory __setup() handler (Waiman Long) [1839057]
- memcg: synchronously enforce memory.high for large overcharges (Waiman Long) [1839057]
- selftests: memcg: test high limit for single entry allocation (Waiman Long) [1839057]
- memcg: unify force charging conditions (Waiman Long) [1839057]
- memcg: refactor mem_cgroup_oom (Waiman Long) [1839057]
- memcg: prohibit unconditional exceeding the limit of dying tasks (Waiman Long) [1839057]
- mm, oom: do not trigger out_of_memory from the #PF (Waiman Long) [1839057]
- mm, oom: pagefault_out_of_memory: don't force global OOM for dying tasks (Waiman Long) [1839057]
- mm: memcontrol: fix root_mem_cgroup charging (Waiman Long) [1839057]
- tests/cgroup: move cg_wait_for(), cg_prepare_for_wait() (Waiman Long) [1839057]
- mm: memcontrol: don't count limit-setting reclaim as memory pressure (Waiman Long) [1839057]
- selftests: Uninitialized variable in test_cgcore_proc_migration() (Waiman Long) [1839057]
- kselftests: cgroup: Avoid the reuse of fd after it is deallocated (Waiman Long) [1839057]
- selftests: cgroup: Run test_core under interfering stress (Waiman Long) [1839057]
- selftests: cgroup: Add task migration tests (Waiman Long) [1839057]
- selftests: cgroup: Simplify task self migration (Waiman Long) [1839057]
- cgroup: kselftest: relax fs_spec checks (Waiman Long) [1839057]
- kselftests: cgroup: remove duplicated include from test_freezer.c (Waiman Long) [1839057]
- kselftest/cgroup: fix unexpected testing failure on test_memcontrol (Waiman Long) [1839057]
- kselftests: cgroup: add freezer controller self-tests (Waiman Long) [1839057]
- Add tests for memory.oom.group (Waiman Long) [1839057]
- Fix cg_read_strcmp() (Waiman Long) [1839057]
- cgroup: kselftests: add test_core to .gitignore (Waiman Long) [1839057]
- selftests: cgroup: add gitignore file (Waiman Long) [1839057]
- Add cgroup core selftests (Waiman Long) [1839057]
- devdax: Fix soft-reservation memory description (Mark Langsdorf) [2122316]
- arm64: cacheinfo: Fix incorrect assignment of signed error value to unsigned fw_level (Mark Langsdorf) [2122316]
- ACPI: property: Remove default association from integer maximum values (Mark Langsdorf) [2122316]
- ACPI: property: Ignore already existing data node tags (Mark Langsdorf) [2122316]
- ACPI: property: Fix type detection of unified integer reading functions (Mark Langsdorf) [2122316]
- ACPI: processor: Remove freq Qos request for all CPUs (Mark Langsdorf) [2122316]
- ACPI: property: Fix error handling in acpi_init_properties() (Mark Langsdorf) [2122316]
- ACPI/IORT: Fix build error implicit-function-declaration (Mark Langsdorf) [2122316]
- ACPI/PCI: Remove useless NULL pointer checks (Mark Langsdorf) [2122316]
- ACPI: property: Read buffer properties as integers (Mark Langsdorf) [2122316]
- ACPI: property: Add support for parsing buffer property UUID (Mark Langsdorf) [2122316]
- ACPI: property: Unify integer value reading functions (Mark Langsdorf) [2122316]
- ACPI: property: Switch node property referencing from ifs to a switch (Mark Langsdorf) [2122316]
- ACPI: property: Move property ref argument parsing into a new function (Mark Langsdorf) [2122316]
- ACPI: property: Use acpi_object_type consistently in property ref parsing (Mark Langsdorf) [2122316]
- ACPI: property: Tie data nodes to acpi handles (Mark Langsdorf) [2122316]
- ACPI: property: Return type of acpi_add_nondev_subnodes() should be bool (Mark Langsdorf) [2122316]
- ACPI: CPPC: Do not prevent CPPC from working in the future (Mark Langsdorf) [2122316]
- ACPI: PM: x86: Print messages regarding LPS0 idle support (Mark Langsdorf) [2122316]
- ACPI: PPTT: Leave the table mapped for the runtime usage (Mark Langsdorf) [2122316]
- ACPI: resource: skip IRQ override on AMD Zen platforms (Mark Langsdorf) [2122316]
- ACPI: irq: Allow acpi_gsi_to_irq() to have an arch-specific fallback (Mark Langsdorf) [2122316]
- APCI: irq: Add support for multiple GSI domains (Mark Langsdorf) [2122316]
- irqchip/gic: Drop support for secondary GIC in non-DT systems (Mark Langsdorf) [2122316]
- ACPI: video: Use native backlight on Dell Inspiron N4010 (Mark Langsdorf) [2122316]
- ACPI: PM: s2idle: Use LPS0 idle if ACPI_FADT_LOW_POWER_S0 is unset (Mark Langsdorf) [2122316]
- Revert "[acpi] ACPI / PM: LPIT: Register sysfs attributes based on FADT" (Mark Langsdorf) [2122316]
- ACPI: utils: Add api to read _SUB from ACPI (Mark Langsdorf) [2122316]
- ACPI: video: Shortening quirk list by identifying Clevo by board_name only (Mark Langsdorf) [2122316]
- ACPI: video: Force backlight native for some TongFang devices (Mark Langsdorf) [2122316]
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (Mark Langsdorf) [2122316]
- ACPI/IORT: Add a helper to retrieve RMR info directly (Mark Langsdorf) [2122316]
- ACPI/IORT: Add support to retrieve IORT RMR reserved regions (Mark Langsdorf) [2122316]
- ACPI/IORT: Provide a generic helper to retrieve reserve regions (Mark Langsdorf) [2122316]
- ACPI/IORT: Make iort_iommu_msi_get_resv_regions() return void (Mark Langsdorf) [2122316]
- iommu: Introduce a callback to struct iommu_resv_region (Mark Langsdorf) [2122316]
- ACPI: PM: s2idle: Add support for upcoming AMD uPEP HID AMDI008 (Mark Langsdorf) [2122316]
- ACPI: PPTT: Use table offset as fw_token instead of virtual address (Mark Langsdorf) [2122316]
- ACPI: Move PRM config option under the main ACPI config (Mark Langsdorf) [2122316]
- ACPI: Enable Platform Runtime Mechanism(PRM) support on ARM64 (Mark Langsdorf) [2122316]
- efi: Simplify arch_efi_call_virt() macro (Mark Langsdorf) [2122316]
- efi/x86: Avoid redundant cast of EFI firmware service pointer (Mark Langsdorf) [2122316]
- efi/libstub: Annotate firmware routines as __efiapi (Mark Langsdorf) [2122316]
- ACPI: PRM: Change handler_addr type to void pointer (Mark Langsdorf) [2122316]
- ACPI: bus: Drop driver member of struct acpi_device (Mark Langsdorf) [2122316]
- ACPI: bus: Drop redundant check in acpi_device_remove() (Mark Langsdorf) [2122316]
- ACPI: APEI: Fix _EINJ vs EFI_MEMORY_SP (Mark Langsdorf) [2122316]
- ACPI: LPSS: Fix missing check in register_device_clock() (Mark Langsdorf) [2122316]
- ACPI: APEI: Better fix to avoid spamming the console with old error logs (Mark Langsdorf) [2122316]
- ACPI: PM: save NVS memory for Lenovo G40-45 (Mark Langsdorf) [2122316]
- ACPI: EC: Drop unused ident initializers from dmi_system_id tables (Mark Langsdorf) [2122316]
- ACPI: EC: Re-use boot_ec when possible even when EC_FLAGS_TRUST_DSDT_GPE is set (Mark Langsdorf) [2122316]
- ACPI: EC: Drop the EC_FLAGS_IGNORE_DSDT_GPE quirk (Mark Langsdorf) [2122316]
- ACPI: EC: Remove duplicate ThinkPad X1 Carbon 6th entry from DMI quirks (Mark Langsdorf) [2122316]
- ACPI: processor: Drop leftover acpi_processor_get_limit_info() declaration (Mark Langsdorf) [2122316]
- ACPI: processor: Split out thermal initialization from ACPI PSS (Mark Langsdorf) [2122316]
- redhat/configs: move CONFIG_ACPI_VIDEO to common/generic (Mark Langsdorf) [2122316]
- ACPI: video: Drop X86 dependency from Kconfig (Mark Langsdorf) [2122316]
- ACPI: video: Fix acpi_video_handles_brightness_key_presses() (Mark Langsdorf) [2122316]
- ACPI: video: Change how we determine if brightness key-presses are handled (Mark Langsdorf) [2122316]
- ACPI / MMC: PM: Unify fixing up device power (Mark Langsdorf) [2122316]
- mmc: sdhci-acpi: Use the new soc_intel_is_byt() helper (Mark Langsdorf) [2122316]
- mmc: sdhci-acpi: Remove special handling for GPD win/pocket devices (Mark Langsdorf) [2122316]
- ACPI: scan: Walk ACPI device's children using driver core (Mark Langsdorf) [2122316]
- ACPI: bus: Introduce acpi_dev_for_each_child_reverse() (Mark Langsdorf) [2122316]
- ACPI: video: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122316]
- ACPI: property: Use acpi_dev_for_each_child() for child lookup (Mark Langsdorf) [2122316]
- ACPI: container: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122316]
- ACPI: bus: Export acpi_dev_for_each_child() to modules (Mark Langsdorf) [2122316]
- ACPI: glue: Introduce acpi_find_child_by_adr() (Mark Langsdorf) [2122316]
- ACPI: glue: Introduce acpi_dev_has_children() (Mark Langsdorf) [2122316]
- ACPI: glue: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122316]
- ACPI: APEI: Fix double word in a comment (Mark Langsdorf) [2122316]
- ACPI: processor/idle: Annotate more functions to live in cpuidle section (Mark Langsdorf) [2122316]
- ACPI: DPTF: Support Meteor Lake (Mark Langsdorf) [2122316]
- ACPI: CPPC: fix typo in comment (Mark Langsdorf) [2122316]
- ACPI: video: improve PM notifer callback (Mark Langsdorf) [2122316]
- ACPI: utils: include UUID in _DSM evaluation warning (Mark Langsdorf) [2122316]
- cpufreq: CPPC: Enable fast_switch (Mark Langsdorf) [2122316]
- acpi/nfit: rely on mce->misc to determine poison granularity (Mark Langsdorf) [2122316]
- ACPI: PM: Block ASUS B1400CEAE from suspend to idle by default (Mark Langsdorf) [2122316]
- ACPI: clean up white space in a few places for consistency (Mark Langsdorf) [2122316]
- ACPI: glue: Rearrange find_child_checks() (Mark Langsdorf) [2122316]
- ACPI: DPTF: Add support for high frequency impedance notification (Mark Langsdorf) [2122316]
- ACPI: processor: idle: Expose max_cstate/nocst/bm_check_disable read-only in sysfs (Mark Langsdorf) [2122316]
- ACPI: battery: Make "not-charging" the default on no charging or full info (Mark Langsdorf) [2122316]
- PCI/ACPI: negotiate CXL _OSC (Mark Langsdorf) [2122316]
- PCI/ACPI: Prefer CXL _OSC instead of PCIe _OSC for CXL host bridges (Mark Langsdorf) [2122316]
- PCI/ACPI: add a helper for retrieving _OSC Control DWORDs (Mark Langsdorf) [2122316]
- ACPI: bus: Avoid non-ACPI device objects in walks over children (Mark Langsdorf) [2122316]
- ACPI: DPTF: Correct description of INT3407 / INT3532 attributes (Mark Langsdorf) [2122316]
- ACPI: BGRT: use static for BGRT_SHOW kobj_attribute defines (Mark Langsdorf) [2122316]
- ACPI, APEI, EINJ: Refuse to inject into the zero page (Mark Langsdorf) [2122316]
- ACPI: PM: Always print final debug message in acpi_device_set_power() (Mark Langsdorf) [2122316]
- ACPI: SPCR: Add support for NVIDIA 16550-compatible port subtype (Mark Langsdorf) [2122316]
- ACPI: APEI: Fix missing ERST record id (Mark Langsdorf) [2122316]
- ACPICA: Update version to 20220331 (Mark Langsdorf) [2122316]
- ACPICA: IORT: Updates for revision E.d (Mark Langsdorf) [2122316]
- ACPICA: iASL/MADT: Add OEM-defined subtable (Mark Langsdorf) [2122316]
- ACPICA: Add support for ARM Performance Monitoring Unit Table. (Mark Langsdorf) [2122316]
- ACPICA: Headers: Replace zero-length array with flexible-array member (Mark Langsdorf) [2122316]
- ACPICA: Removed some tabs and // comments (Mark Langsdorf) [2122316]
- ACPICA: Update copyright notices to the year 2022 (Mark Langsdorf) [2122316]
- ACPICA: Clean up double word in comment (Mark Langsdorf) [2122316]
- ACPICA: Add new ACPI 6.4 semantics for LoadTable() operator (Mark Langsdorf) [2122316]
- ACPICA: Add new ACPI 6.4 semantics to the Load() operator (Mark Langsdorf) [2122316]
- ACPICA: iASL: NHLT: Rename linux specific strucures to device_info (Mark Langsdorf) [2122316]
- ACPICA: iASL: NHLT: Fix parsing undocumented bytes at the end of Endpoint Descriptor (Mark Langsdorf) [2122316]
- ACPICA: iASL: NHLT: Treat Terminator as specific_config (Mark Langsdorf) [2122316]
- ACPICA: Add the subtable CFMWS to the CEDT table (Mark Langsdorf) [2122316]
- ACPICA: Add support for the Windows 11 _OSI string (Mark Langsdorf) [2122316]
- ACPI: sysfs: Fix BERT error region memory mapping (Mark Langsdorf) [2122316]
- ACPI: property: Release subnode properties with data nodes (Mark Langsdorf) [2122316]
- PCI: ACPI: PM: Power up devices in D3cold before scanning them (Mark Langsdorf) [2122316]
- ACPI: PM: Introduce acpi_dev_power_up_children_with_adr() (Mark Langsdorf) [2122316]
- ACPI: bus: Introduce acpi_dev_for_each_child() (Mark Langsdorf) [2122316]
- ACPI: PM: Unify debug messages in acpi_device_set_power() (Mark Langsdorf) [2122316]
- ACPI: PM: Convert debug message in acpi_device_get_power() (Mark Langsdorf) [2122316]
- device property: Add irq_get to fwnode operation (Mark Langsdorf) [2122316]
- device property: Add iomap to fwnode operations (Mark Langsdorf) [2122316]
- ACPI: property: Move acpi_fwnode_device_get_match_data() up (Mark Langsdorf) [2122316]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Mark Langsdorf) [2122316]
- ACPI: Add perf low power callback (Mark Langsdorf) [2122316]
- s390: fix double free of GS and RI CBs on fork() failure (Brian Foster) [1944540]
- wifi: iwlwifi: mvm: fix double list_add at iwl_mvm_mac_wake_tx_queue (other cases) (Jose Ignacio Tornos Martinez) [2086480]
- wifi: iwlwifi: mvm: fix double list_add at iwl_mvm_mac_wake_tx_queue (Jose Ignacio Tornos Martinez) [2086480]

* Mon Oct 17 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-431.el8]
- crypto: ecdh - disallow plain "ecdh" usage in FIPS mode (Vladis Dronov) [2129392]
- crypto: dh - disallow plain "dh" usage in FIPS mode (Vladis Dronov) [2129392]
- x86/cpu: Add new Raptor Lake CPU model number (Prarit Bhargava) [2120361]
- mm, oom: fix missing tlb_finish_mmu() in __oom_reap_task_mm(). (Waiman Long) [2130954]
- net: atlantic: remove aq_nic_deinit() when resume (Íñigo Huguet) [2130839]
- net: atlantic: remove deep parameter on suspend/resume functions (Íñigo Huguet) [2130839]
- efi: Allow EFI_MEMORY_XP and EFI_MEMORY_RO both to be cleared (Lenny Szubowicz) [2128172]
- bonding: 3ad: make ad_ticks_per_sec a const (Jonathan Toppins) [2020773]
- bonding: 802.3ad: fix no transmission of LACPDUs (Jonathan Toppins) [2020773]
- redhat: workaround CKI cross compilation for scripts (Jan Stancek) [2123399]
- nohz/full, sched/rt: Fix missed tick-reenabling bug in dequeue_task_rt() (Phil Auld) [2107238]
- gfs2: Make sure FITRIM minlen is rounded up to fs block size (Andrew Price) [2118256]
- ceph: don't truncate file in atomic_open (Xiubo Li) [2120924]
- of: address: Work around missing device_type property in pcie nodes (Jerry Snitselaar) [2118732]
- dma-mapping: introduce DMA range map, supplanting dma_pfn_offset (Jerry Snitselaar) [2118732]
- of/address: check for invalid range.cpu_addr (Jerry Snitselaar) [2118732]
- of: address: Fix parser address/size cells initialization (Jerry Snitselaar) [2118732]
- of_address: Guard of_bus_pci_get_flags with CONFIG_PCI (Jerry Snitselaar) [2118732]
- of_address: Add bus type match for pci ranges parser (Jerry Snitselaar) [2118732]
- of/address: Support multiple 'dma-ranges' entries (Jerry Snitselaar) [2118732]
- of/address: use range parser for of_dma_get_range (Jerry Snitselaar) [2118732]
- of/address: Rework of_pci_range parsing for non-PCI buses (Jerry Snitselaar) [2118732]
- of: Drop struct of_pci_range.pci_space field (Jerry Snitselaar) [2118732]
- of/address: Move range parser code out of CONFIG_PCI (Jerry Snitselaar) [2118732]
- of: Make of_dma_get_range() work on bus nodes (Jerry Snitselaar) [2118732]
- Revert "arm64: dts: juno: add dma-ranges property" (Jerry Snitselaar) [2118732]
- of/address: Fix of_pci_range_parser_one translation of DMA addresses (Jerry Snitselaar) [2118732]
- of/address: Translate 'dma-ranges' for parent nodes missing 'dma-ranges' (Jerry Snitselaar) [2118732]
- of: address: Follow DMA parent for "dma-coherent" (Jerry Snitselaar) [2118732]
- of: Factor out #{addr,size}-cells parsing (Jerry Snitselaar) [2118732]
- of/address: Introduce of_get_next_dma_parent() helper (Jerry Snitselaar) [2118732]
- of: address: Report of_dma_get_range() errors meaningfully (Jerry Snitselaar) [2118732]
- of: address: Add support for the parent DMA bus (Jerry Snitselaar) [2118732]
- of: address: Retrieve a parent through a callback in __of_translate_address (Jerry Snitselaar) [2118732]
- of: reserved_mem: fix reserve memory leak (Jerry Snitselaar) [2118732]
- of: Use device_type helpers to access the node type (Jerry Snitselaar) [2118732]
- of: make PowerMac cache node search conditional on CONFIG_PPC_PMAC (Jerry Snitselaar) [2118732]

* Fri Oct 07 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-430.el8]
- crypto: qat - add limit to linked list parsing (Vladis Dronov) [2129897]
- crypto: qat - use reference to structure in dma_map_single() (Vladis Dronov) [2129897]
- Revert "crypto: qat - reduce size of mapped region" (Vladis Dronov) [2129897]
- crypto: qat - fix DMA transfer direction (Vladis Dronov) [2129897]
- crypto: qat - fix default value of WDT timer (Vladis Dronov) [2129897]
- crypto: drivers - move from strlcpy with unused retval to strscpy (Vladis Dronov) [2129897]
- crypto: qat - add check to validate firmware images (Vladis Dronov) [2129897]
- Documentation: qat: rewrite description (Vladis Dronov) [2129897]
- Documentation: qat: Use code block for qat sysfs example (Vladis Dronov) [2129897]
- KVM: x86: Inject #UD on emulated XSETBV if XSAVES isn't enabled (Dr. David Alan Gilbert) [2079311]
- KVM: x86: Always enable legacy FP/SSE in allowed user XFEATURES (Dr. David Alan Gilbert) [2079311]
- KVM: x86: Reinstate kvm_vcpu_arch.guest_supported_xcr0 (Dr. David Alan Gilbert) [2079311]
- bonding: fix NULL deref in bond_rr_gen_slave_id (Jonathan Toppins) [2051778]
- tty: use new tty_insert_flip_string_and_push_buffer() in pty_write() (Rafael Aquini) [2078869] {CVE-2022-1462}
- tty: extract tty_flip_buffer_commit() from tty_flip_buffer_push() (Rafael Aquini) [2078869] {CVE-2022-1462}
- tty: drop tty_schedule_flip() (Rafael Aquini) [2078869] {CVE-2022-1462}
- tty: the rest, stop using tty_schedule_flip() (Rafael Aquini) [2078869] {CVE-2022-1462}
- tty: drivers/tty/, stop using tty_schedule_flip() (Rafael Aquini) [2078869] {CVE-2022-1462}
- vt: keyboard, use tty_insert_flip_string in puts_queue (Rafael Aquini) [2078869] {CVE-2022-1462}
- vt: use tty_insert_flip_string in respond_string (Rafael Aquini) [2078869] {CVE-2022-1462}

* Mon Oct 03 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-429.el8]
- intel_th: pci: Add Raptor Lake-S CPU support (Michael Petlan) [2040035]
- intel_th: pci: Add Raptor Lake-S PCH support (Michael Petlan) [2040035]
- virtio-net: support XDP when not more queues (Eugenio Pérez) [2122225]
- virtio_net: Don't process redirected XDP frames when XDP is disabled (Eugenio Pérez) [2122225]
- virtio_net: Fix not restoring real_num_rx_queues (Eugenio Pérez) [2122225]
- x86,config: Enable straight-line-speculation fix (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- x86/alternative: Relax text_poke_bp() constraint (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- perf/x86: Add support for perf text poke event for text_poke_bp_batch() callers (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- objtool: Add straight-line-speculation validation (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- objtool: Support conditional retpolines (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- objtool: Refactor sibling call detection logic (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- objtool: Change dead_end_function() to return boolean (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- x86/lib/atomic64_386_32: Rename things (Wander Lairson Costa) [2062175] {CVE-2021-26341}
- KVM: arm64: Fix debug architecture version (Gavin Shan) [2123587]
- thunderbolt: Add support for Intel Raptor Lake (Torez Smith) [2040037]
- iommu/vt-d: Fix compile error with CONFIG_PCI_ATS not set (Myron Stowe) [2118428 2122515 2127028]
- iommu/vt-d: Cure VF irqdomain hickup (Myron Stowe) [2118428 2122515 2127028]
- x86/pci: Set default irq domain in pcibios_add_device() (Myron Stowe) [2118428 2122515 2127028]
- iommm/amd: Store irq domain in struct device (Myron Stowe) [2118428 2122515 2127028]
- iommm/vt-d: Store irq domain in struct device (Myron Stowe) [2118428 2122515 2127028]
- PCI/MSI: Provide pci_dev_has_special_msi_domain() helper (Myron Stowe) [2118428 2122515 2127028]
- x86/msi: Consolidate MSI allocation (Myron Stowe) [2118428 2122515 2127028]
- PCI/MSI: Rework pci_msi_domain_calc_hwirq() (Myron Stowe) [2118428 2122515 2127028]
- x86/irq: Consolidate UV domain allocation (Myron Stowe) [2118428 2122515 2127028]
- x86/irq: Consolidate DMAR irq allocation (Myron Stowe) [2118428 2122515 2127028]
- x86_ioapic_Consolidate_IOAPIC_allocation (Myron Stowe) [2118428 2122515 2127028]
- x86/msi: Consolidate HPET allocation (Myron Stowe) [2118428 2122515 2127028]
- iommu/irq_remapping: Consolidate irq domain lookup (Myron Stowe) [2118428 2122515 2127028]
- iommu/amd: Consolidate irq domain getter (Myron Stowe) [2118428 2122515 2127028]
- iommu/vt-d: Consolidate irq domain getter (Myron Stowe) [2118428 2122515 2127028]
- x86/irq: Add allocation type for parent domain retrieval (Myron Stowe) [2118428 2122515 2127028]
- irqdomain: Export irq_domain_update_bus_token (Myron Stowe) [2118428 2122515 2127028]
- perf/x86/intel: Update the FRONTEND MSR mask on Sapphire Rapids (Michael Petlan) [2125349]
- perf/x86/intel/uncore: Fix invalid unit check (Michael Petlan) [2125349]

* Tue Sep 27 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-428.el8]
- KVM: s390: pv: don't present the ecall interrupt twice (Tobias Huschle) [2125236]
- s390/mm: do not trigger write fault when vma does not allow VM_WRITE (Tobias Huschle) [2125218]
- PCI: Print a debug message on PCI device release (Tobias Huschle) [2125216]
- s390/pci: fix leak of PCI device structure (Tobias Huschle) [2125216]
- s390/pci: refactor zpci_create_device() (Tobias Huschle) [2125216]
- s390/pci: remove superfluous zdev->zbus check (Tobias Huschle) [2125216]
- x86/boot/64: Add missing fixup_pointer() for next_early_pgt access (Rafael Aquini) [2082806]
- x86/boot/64: Fix crash if kernel image crosses page table boundary (Rafael Aquini) [2082806]
- mm/slab_common: fix possible double free of kmem_cache (Waiman Long) [2093781]
- mm/slab_common: Deleting kobject in kmem_cache_destroy() without holding slab_mutex/cpu_hotplug_lock (Waiman Long) [2093781]
- mm/slab_common: use WARN() if cache still has objects on destroy (Waiman Long) [2093781]
- slab: use __func__ to trace function name (Waiman Long) [2093781]
- s390/hugetlb: fix prepare_hugepage_range() check for 2 GB hugepages (Tobias Huschle) [2125215]
- platform/x86: intel/pmc: Add Alder Lake N support to PMC core driver (Prarit Bhargava) [2072654]
- crash_core: Increase crashkernel=auto size for x86_64, s390 and arm64 (Lichen Liu) [2122874]
- virtio-net: fix use-after-free in skb_gro_receive (Cindy Lu) [2069047]
- virtio-net: fix use-after-free in page_to_skb() (Cindy Lu) [2069047]
- virtio-net: restrict build_skb() use to some arches (Cindy Lu) [2069047]
- virtio-net: page_to_skb() use build_skb when there's sufficient tailroom (Cindy Lu) [2069047]
- sched/fair: Consider CPU affinity when allowing NUMA imbalance in find_idlest_group() (Phil Auld) [2110020]
- sched/numa: Adjust imb_numa_nr to a better approximation of memory channels (Phil Auld) [2110020]
- sched/numa: Apply imbalance limitations consistently (Phil Auld) [2110020]
- sched/numa: Do not swap tasks between nodes when spare capacity is available (Phil Auld) [2110020]
- sched/numa: Initialise numa_migrate_retry (Phil Auld) [2110020]
- cpufreq: intel_pstate: Handle no_turbo in frequency invariance (Phil Auld) [2100594]
- sched/fair: Introduce SIS_UTIL to search idle CPU based on sum of util_avg (Phil Auld) [2100594]
- i2c: piix4: Fix a memory leak in the EFCH MMIO support (Sudheesh Mavila) [2105160]
- assoc_array: Fix BUG_ON during garbage collect (Dave Wysochanski) [1920523]
- wait: Fix __wait_event_hrtimeout for RT/DL tasks (Derek Barbosa) [2125233]

* Wed Sep 21 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-427.el8]
- raid1: ensure write behind bio has less than BIO_MAX_VECS sectors (Nigel Croxon) [2116209]
- ceph: fix statfs for subdir mounts (Xiubo Li) [2120943]
- ceph: try to queue a writeback if revoking fails (Xiubo Li) [2120940]
- ceph: update the auth cap when the async create req is forwarded (Xiubo Li) [2120932]
- ceph: make change_auth_cap_ses a global symbol (Xiubo Li) [2120932]
- fs/dcache: export d_same_name() helper (Xiubo Li) [2120932]
- ceph: wait for the first reply of inflight async unlink (Xiubo Li) [2120932]
- redhat: Enable KASAN_VMALLOC (Nico Pache) [2108620]
- arm64: select KASAN_VMALLOC for SW/HW_TAGS modes (Nico Pache) [2108620]
- x86/crash: Fix crash_setup_memmap_entries() out-of-bounds access (Nico Pache) [2108620]
- mm: defer kmemleak object creation of module_alloc() (Nico Pache) [2108620]
- arm64: kaslr: keep modules inside module region when KASAN is enabled (Nico Pache) [2108620]
- kasan: arm64: fix pcpu_page_first_chunk crash with KASAN_VMALLOC (Nico Pache) [2108620]
- arm64: Kconfig: select KASAN_VMALLOC if KANSAN_GENERIC is enabled (Nico Pache) [2108620]
- arm64: kaslr: support randomized module area with KASAN_VMALLOC (Nico Pache) [2108620]
- arm64: Kconfig: support CONFIG_KASAN_VMALLOC (Nico Pache) [2108620]
- arm64: kasan: abstract _text and _end to KERNEL_START/END (Nico Pache) [2108620]
- arm64: kasan: don't populate vmalloc area for CONFIG_KASAN_VMALLOC (Nico Pache) [2108620]
- x86/kasan: support KASAN_VMALLOC (Nico Pache) [2108620]
- ath9k: htc: clean up statistics macros (Jose Ignacio Tornos Martinez) [2084598] {CVE-2022-1679}
- ath9k: hif_usb: simplify if-if to if-else (Jose Ignacio Tornos Martinez) [2084598] {CVE-2022-1679}
- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb (Jose Ignacio Tornos Martinez) [2084598] {CVE-2022-1679}
- igmp: Add ip_mc_list lock in ip_check_mc_rcu (Hangbin Liu) [2114946] {CVE-2022-20141}
- scsi: zfcp: Fix missing auto port scan and thus missing target ports (Tobias Huschle) [2121089]
- vfio/type1: Unpin zero pages (Alex Williamson) [2123015]

* Wed Sep 14 2022 Lucas Zampieri <lzampier@redhat.com> [4.18.0-426.el8]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED default 1024 (Jerry Snitselaar) [2120412]
- Revert "iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting" (Jerry Snitselaar) [2120412]
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on PTRACE_SEIZE (Oleg Nesterov) [2121269] {CVE-2022-30594}
- redhat: remove unused STAMP variable from genspec.sh (Herton R. Krzesinski)
- internal: Update RHEL_MINOR for the start of RHEL-8.8 development (Lucas Zampieri)

* Fri Sep 09 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-425.el8]
- EDAC/amd64: Add new register offset support and related changes (Aristeu Rozanski) [2048792]
- EDAC/amd64: Set memory type per DIMM (Aristeu Rozanski) [2048792]
- Revert "ixgbevf: Mailbox improvements" (Ken Cox) [2120545]
- Revert "ixgbevf: Add support for new mailbox communication between PF and VF" (Ken Cox) [2120545]
- drm/amdgpu: Only disable prefer_shadow on hawaii (Lyude Paul) [2118755]

* Fri Sep 02 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-424.el8]
- redhat: configs: add CONFIG_SERIAL_MULTI_INSTANTIATE=m for x86_64 (Jaroslav Kysela) [2005073]
- ACPI: scan: Add CLSA0101 Laptop Support (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Add CLSA0101 Laptop (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Sort ACPI IDs by HID (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Get rid of redundant 'else' (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Use while (i--) pattern to clean up (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Improve dev_err_probe() messaging (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Drop duplicate check (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Improve autodetection (Jaroslav Kysela) [2005073]
- ACPI / scan: Create platform device for CS35L41 (Jaroslav Kysela) [2005073]
- ACPI: scan: Create platform device for BCM4752 and LNV4752 ACPI nodes (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Add SPI support (Jaroslav Kysela) [2005073]
- platform/x86: serial-multi-instantiate: Reorganize I2C functions (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Rename it for a generic serial driver name (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Use the new i2c_acpi_client_count() helper (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Use device_get_match_data() to get driver data (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Simplify with dev_err_probe() (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Drop redundant ACPI_PTR() (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Fail the probe if no IRQ provided (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Derive the device name from parent (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Use struct_size() helper (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Allow to have same slaves (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Introduce IOAPIC IRQ support (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Distinguish IRQ resource type (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Count I2cSerialBus() resources (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Get rid of obsolete conditional (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Defer probe when no adapter found (Jaroslav Kysela) [2005073]
- platform/x86: i2c-multi-instantiate: Accept errors of i2c_acpi_new_device() (Jaroslav Kysela) [2005073]
- serdev: Fix detection of UART devices on Apple machines. (Jaroslav Kysela) [2005073]
- serdev: Add ACPI devices by ResourceSource field (Jaroslav Kysela) [2005073]
- spi: Return deferred probe error when controller isn't yet available (Jaroslav Kysela) [2005073]
- spi/acpi: avoid spurious matches during slave enumeration (Jaroslav Kysela) [2005073]
- spi: Add API to count spi acpi resources (Jaroslav Kysela) [2005073]
- spi: Support selection of the index of the ACPI Spi Resource before alloc (Jaroslav Kysela) [2005073]
- ACPI: Test for ACPI_SUCCESS rather than !ACPI_FAILURE (Jaroslav Kysela) [2005073]
- spi/acpi: fix incorrect ACPI parent check (Jaroslav Kysela) [2005073]
- spi: Create helper API to lookup ACPI info for spi device (Jaroslav Kysela) [2005073]
- spi/acpi: enumerate all SPI slaves in the namespace (Jaroslav Kysela) [2005073]
- spi: kill useless initializer in spi_register_controller() (Jaroslav Kysela) [2005073]
- spi: fix ctrl->num_chipselect constraint (Jaroslav Kysela) [2005073]
- spi: Don't call spi_get_gpio_descs() before device name is set (Jaroslav Kysela) [2005073]
- spi: Avoid undefined behaviour when counting unused native CSs (Jaroslav Kysela) [2005073]
- spi: Allow to have all native CSs in use along with GPIOs (Jaroslav Kysela) [2005073]
- spi: Add missing error handling for CS GPIOs (Jaroslav Kysela) [2005073]
- spi: export tracepoint symbols to modules (Jaroslav Kysela) [2005073]
- spi: Fix zero length xfer bug (Jaroslav Kysela) [2005073]
- spi: Add generic support for unused native cs with cs-gpios (Jaroslav Kysela) [2005073]
- spi: Reduce kthread priority (Jaroslav Kysela) [2005073]
- spi: core: Use DEVICE_ATTR_RW() for SPI slave control sysfs attribute (Jaroslav Kysela) [2005073]
- i2c: acpi: Add an i2c_acpi_client_count() helper function (Jaroslav Kysela) [2005073]
- s390/qeth: cache link_info for ethtool (Michal Schmidt) [2117098]
- nfp: amend removal of MODULE_VERSION (Stefan Assmann) [1955769]
- x86/speculation: Add LFENCE to RSB fill sequence (Waiman Long) [2115080] {CVE-2022-26373}
- x86/speculation: Add RSB VM Exit protections (Waiman Long) [2115080] {CVE-2022-26373}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2115080]
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2115080]
- x86/speculation: Fix RSB filling with CONFIG_RETPOLINE=n (Waiman Long) [2115080]
- x86/bugs: Do not enable IBPB at firmware entry when IBPB is not available (Waiman Long) [2115080]
- x86/amd: Use IBPB for firmware calls (Waiman Long) [2115080]
- x86/bugs: Warn when "ibrs" mitigation is selected on Enhanced IBRS parts (Waiman Long) [2115080]
- iavf: Fix reset error handling (Petr Oros) [2119759]
- iavf: Fix NULL pointer dereference in iavf_get_link_ksettings (Petr Oros) [2119759]
- iavf: Fix adminq error handling (Petr Oros) [2119759]
- iavf: Fix missing state logs (Petr Oros) [2119759]
- ixgbe: Add locking to prevent panic when setting sriov_numvfs to zero (Ken Cox) [1978613]

* Fri Aug 26 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-423.el8]
- netfilter: ipset: fix suspicious RCU usage in find_set_and_id (Florian Westphal) [2118526]
- net/mlx5e: Update netdev features after changing XDP state (Amir Tzin) [2049440]
- net/mlx5e: CT: Use own workqueue instead of mlx5e priv (Amir Tzin) [2049440]
- net/mlx5e: CT: Add ct driver counters (Amir Tzin) [2049440]
- net/mlx5e: CT: Fix cleanup of CT before cleanup of TC ct rules (Amir Tzin) [2049440]
- net/mlx5e: Align mlx5e_cleanup_uplink_rep_tx() with upstream code. (Amir Tzin) [2049440]
- net/mlx5e: Correct the calculation of max channels for rep (Amir Tzin) [2049440]
- Documentation: devlink: mlx5.rst: Fix htmldoc build warning (Amir Tzin) [2049440]
- net/mlx5: fs, fail conflicting actions (Amir Tzin) [2049440]
- net/mlx5: Rearm the FW tracer after each tracer event (Amir Tzin) [2049440]
- net/mlx5: correct ECE offset in query qp output (Amir Tzin) [2049440]
- net/mlx5e: Disable softirq in mlx5e_activate_rq to avoid race condition (Amir Tzin) [2049440]
- net/mlx5e: TC NIC mode, fix tc chains miss table (Amir Tzin) [2049440]
- net/mlx5: Don't use already freed action pointer (Amir Tzin) [2049440]
- net/mlx5: fix typo in comment (Amir Tzin) [2049440]
- IB/mlx5: Fix undefined behavior due to shift overflowing the constant (Amir Tzin) [2049440]
- net/mlx5e: Force ethertype usage in mlx5_ct_fs_smfs_fill_mask() (Amir Tzin) [2049440]
- net/mlx5: Drain fw_reset when removing device (Amir Tzin) [2049440]
- net/mlx5e: CT: Fix setting flow_source for smfs ct tuples (Amir Tzin) [2049440]
- net/mlx5e: CT: Fix support for GRE tuples (Amir Tzin) [2049440]
- net/mlx5e: Remove HW-GRO from reported features (Amir Tzin) [2049440]
- net/mlx5e: Properly block HW GRO when XDP is enabled (Amir Tzin) [2049440]
- net/mlx5e: Properly block LRO when XDP is enabled (Amir Tzin) [2049440]
- net/mlx5e: Block rx-gro-hw feature in switchdev mode (Amir Tzin) [2049440]
- net/mlx5e: Wrap mlx5e_trap_napi_poll into rcu_read_lock (Amir Tzin) [2049440]
- net/mlx5: Initialize flow steering during driver probe (Amir Tzin) [2049440]
- net/mlx5: Fix matching on inner TTC (Amir Tzin) [2049440]
- net/mlx5: Avoid double clear or set of sync reset requested (Amir Tzin) [2049440]
- net/mlx5: Fix deadlock in sync reset flow (Amir Tzin) [2049440]
- net/mlx5e: Fix trust state reset in reload (Amir Tzin) [2049440]
- net/mlx5e: Avoid checking offload capability in post_parse action (Amir Tzin) [2049440]
- net/mlx5e: CT: Fix queued up restore put() executing after relevant ft release (Amir Tzin) [2049440]
- net/mlx5e: TC, Fix ct_clear overwriting ct action metadata (Amir Tzin) [2049440]
- net/mlx5e: Lag, Don't skip fib events on current dst (Amir Tzin) [2049440]
- net/mlx5e: Lag, Fix fib_info pointer assignment (Amir Tzin) [2049440]
- net/mlx5e: Lag, Fix use-after-free in fib event handler (Amir Tzin) [2049440]
- net/mlx5e: Fix the calling of update_buffer_lossy() API (Amir Tzin) [2049440]
- net/mlx5e: Don't match double-vlan packets if cvlan is not set (Amir Tzin) [2049440]
- net/mlx5: Fix slab-out-of-bounds while reading resource dump menu (Amir Tzin) [2049440]
- RDMA/mlx5: Add a missing update of cache->last_add (Amir Tzin) [2049440]
- RDMA/mlx5: Don't remove cache MRs when a delay is needed (Amir Tzin) [2049440]
- net/mlx5e: HTB, remove unused function declaration (Amir Tzin) [2049440]
- net/mlx5e: Statify function mlx5_cmd_trigger_completions (Amir Tzin) [2049440]
- net/mlx5: Remove unused fill page array API function (Amir Tzin) [2049440]
- net/mlx5: Remove unused exported contiguous coherent buffer allocation API (Amir Tzin) [2049440]
- net/mlx5: CT: Remove extra rhashtable remove on tuple entries (Amir Tzin) [2049440]
- net/mlx5: DR, Remove hw_ste from mlx5dr_ste to reduce memory (Amir Tzin) [2049440]
- net/mlx5: DR, Remove 4 members from mlx5dr_ste_htbl to reduce memory (Amir Tzin) [2049440]
- net/mlx5: DR, Remove num_of_entries byte_size from struct mlx5_dr_icm_chunk (Amir Tzin) [2049440]
- net/mlx5: DR, Remove icm_addr from mlx5dr_icm_chunk to reduce memory (Amir Tzin) [2049440]
- net/mlx5: DR, Remove mr_addr rkey from struct mlx5dr_icm_chunk (Amir Tzin) [2049440]
- net/mlx5: DR, Adjust structure member to reduce memory hole (Amir Tzin) [2049440]
- net/mlx5e: Drop cqe_bcnt32 from mlx5e_skb_from_cqe_mpwrq_linear (Amir Tzin) [2049440]
- net/mlx5e: Drop the len output parameter from mlx5e_xdp_handle (Amir Tzin) [2049440]
- net/mlx5e: RX, Test the XDP program existence out of the handler (Amir Tzin) [2049440]
- net/mlx5e: Build SKB in place over the first fragment in non-linear legacy RQ (Amir Tzin) [2049440]
- net/mlx5e: Add headroom only to the first fragment in legacy RQ (Amir Tzin) [2049440]
- net/mlx5e: Validate MTU when building non-linear legacy RQ fragments info (Amir Tzin) [2049440]
- net/mlx5e: MPLSoUDP encap, support action vlan pop_eth explicitly (Amir Tzin) [2049440]
- net/mlx5e: MPLSoUDP decap, use vlan push_eth instead of pedit (Amir Tzin) [2049440]
- RDMA/mlx5: Fix memory leak in error flow for subscribe event routine (Amir Tzin) [2049440]
- net/mlx5e: Fix use-after-free in mlx5e_stats_grp_sw_update_stats (Amir Tzin) [2049440]
- net/mlx5e: Remove overzealous validations in netlink EEPROM query (Amir Tzin) [2049440]
- net/mlx5: Parse module mapping using mlx5_ifc (Amir Tzin) [2049440]
- net/mlx5: Query the maximum MCIA register read size from firmware (Amir Tzin) [2049440]
- net/mlx5: CT: Create smfs dr matchers dynamically (Amir Tzin) [2049440]
- net/mlx5: CT: Add software steering ct flow steering provider (Amir Tzin) [2049440]
- net/mlx5: Add smfs lib to export direct steering API to CT (Amir Tzin) [2049440]
- net/mlx5: DR, Add helper to get backing dr table from a mlx5 flow table (Amir Tzin) [2049440]
- net/mlx5: CT: Introduce a platform for multiple flow steering providers (Amir Tzin) [2049440]
- net/mlx5: Node-aware allocation for the doorbell pgdir (Amir Tzin) [2049440]
- net/mlx5: Node-aware allocation for UAR (Amir Tzin) [2049440]
- net/mlx5: Node-aware allocation for the EQs (Amir Tzin) [2049440]
- net/mlx5: Node-aware allocation for the EQ table (Amir Tzin) [2049440]
- net/mlx5: Node-aware allocation for the IRQ table (Amir Tzin) [2049440]
- net/mlx5: Delete useless module.h include (Amir Tzin) [2049440]
- net/mlx5: DR, Add support for ConnectX-7 steering (Amir Tzin) [2049440]
- net/mlx5: DR, Refactor ste_ctx handling for STE v0/1 (Amir Tzin) [2049440]
- net/mlx5: DR, Rename action modify fields to reflect naming in HW spec (Amir Tzin) [2049440]
- net/mlx5: DR, Fix handling of different actions on the same STE in STEv1 (Amir Tzin) [2049440]
- net/mlx5: DR, Remove unneeded comments (Amir Tzin) [2049440]
- net/mlx5: DR, Add support for matching on Internet Header Length (IHL) (Amir Tzin) [2049440]
- net/mlx5: DR, Align mlx5dv_dr API vport action with FW behavior (Amir Tzin) [2049440]
- net/mlx5: Add debugfs counters for page commands failures (Amir Tzin) [2049440]
- net/mlx5: Add pages debugfs (Amir Tzin) [2049440]
- net/mlx5: Move debugfs entries to separate struct (Amir Tzin) [2049440]
- net/mlx5: Change release_all_pages cap bit location (Amir Tzin) [2049440]
- net/mlx5: Remove redundant error on reclaim pages (Amir Tzin) [2049440]
- net/mlx5: Remove redundant error on give pages (Amir Tzin) [2049440]
- net/mlx5: Remove redundant notify fail on give pages (Amir Tzin) [2049440]
- net/mlx5: Add command failures data to debugfs (Amir Tzin) [2049440]
- net/mlx5e: TC, Fix use after free in mlx5e_clone_flow_attr_for_post_act() (Amir Tzin) [2049440]
- net/mlx5: Support GRE conntrack offload (Amir Tzin) [2049440]
- mlx5: add support for page_pool_get_stats (Amir Tzin) [2049440]
- net/mlx5: Add migration commands definitions (Amir Tzin) [2049440]
- net/mlx5: Introduce migration bits and structures (Amir Tzin) [2049440]
- net/mlx5: Expose APIs to get/put the mlx5 core device (Amir Tzin) [2049440]
- net/mlx5: Disable SRIOV before PF removal (Amir Tzin) [2049440]
- net/mlx5: Reuse exported virtfn index function call (Amir Tzin) [2049440]
- net/mlx5: Add clarification on sync reset failure (Amir Tzin) [2049440]
- net/mlx5: Add reset_state field to MFRL register (Amir Tzin) [2049440]
- RDMA/mlx5: Use new command interface API (Amir Tzin) [2049440]
- net/mlx5: cmdif, Refactor error handling and reporting of async commands (Amir Tzin) [2049440]
- net/mlx5: Use mlx5_cmd_do() in core create_{cq,dct} (Amir Tzin) [2049440]
- net/mlx5: cmdif, Add new api for command execution (Amir Tzin) [2049440]
- net/mlx5: cmdif, cmd_check refactoring (Amir Tzin) [2049440]
- net/mlx5: cmdif, Return value improvements (Amir Tzin) [2049440]
- net/mlx5: Lag, offload active-backup drops to hardware (Amir Tzin) [2049440]
- net/mlx5: Lag, record inactive state of bond device (Amir Tzin) [2049440]
- net/mlx5: Lag, don't use magic numbers for ports (Amir Tzin) [2049440]
- net/mlx5: Lag, use local variable already defined to access E-Switch (Amir Tzin) [2049440]
- net/mlx5: E-switch, add drop rule support to ingress ACL (Amir Tzin) [2049440]
- net/mlx5: E-switch, remove special uplink ingress ACL handling (Amir Tzin) [2049440 2049580]
- net/mlx5: E-Switch, reserve and use same uplink metadata across ports (Amir Tzin) [2049440 2049580]
- net/mlx5: Add ability to insert to specific flow group (Amir Tzin) [2049440]
- mlx5: remove unused static inlines (Amir Tzin) [2049440]
- RDMA/mlx5: Reorder calls to pcie_relaxed_ordering_enabled() (Amir Tzin) [2049440]
- RDMA/mlx5: Store ndescs instead of the translation table size (Amir Tzin) [2049440]
- RDMA/mlx5: Merge similar flows of allocating MR from the cache (Amir Tzin) [2049440]
- RDMA/mlx5: Fix the flow of a miss in the allocation of a cache ODP MR (Amir Tzin) [2049440]
- RDMA/mlx5: Remove redundant work in struct mlx5_cache_ent (Amir Tzin) [2049440]
- net/mlx5e: TC, Allow sample action with CT (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Make post_act parse CT and sample actions (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Clean redundant counter flag from tc action parsers (Amir Tzin) [2049440 2049659]
- net/mlx5e: Use multi table support for CT and sample actions (Amir Tzin) [2049440 2049659]
- net/mlx5e: Create new flow attr for multi table actions (Amir Tzin) [2049440 2049659]
- net/mlx5e: Add post act offload/unoffload API (Amir Tzin) [2049440 2049659]
- net/mlx5e: Pass actions param to actions_match_supported() (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Move flow hashtable to be per rep (Amir Tzin) [2049440]
- net/mlx5e: E-Switch, Add support for tx_port_ts in switchdev mode (Amir Tzin) [2049440]
- net/mlx5e: E-Switch, Add PTP counters for uplink representor (Amir Tzin) [2049440]
- net/mlx5e: RX, Restrict bulk size for small Striding RQs (Amir Tzin) [2049440]
- net/mlx5e: Default to Striding RQ when not conflicting with CQE compression (Amir Tzin) [2049440]
- net/mlx5e: Generalize packet merge error message (Amir Tzin) [2049440]
- net/mlx5e: Add support for using xdp->data_meta (Amir Tzin) [2049440]
- net/mlx5e: Fix spelling mistake "supoported" -> "supported" (Amir Tzin) [2049440]
- net/mlx5e: Optimize the common case condition in mlx5e_select_queue (Amir Tzin) [2049440]
- net/mlx5e: Optimize modulo in mlx5e_select_queue (Amir Tzin) [2049440]
- net/mlx5e: Optimize mlx5e_select_queue (Amir Tzin) [2049440]
- net/mlx5e: Use READ_ONCE/WRITE_ONCE for DCBX trust state (Amir Tzin) [2049440]
- net/mlx5e: Move repeating code that gets TC prio into a function (Amir Tzin) [2049440]
- net/mlx5e: Use select queue parameters to sync with control flow (Amir Tzin) [2049440]
- net/mlx5e: Move mlx5e_select_queue to en/selq.c (Amir Tzin) [2049440]
- net/mlx5e: Introduce select queue parameters (Amir Tzin) [2049440]
- net/mlx5e: Sync txq2sq updates with mlx5e_xmit for HTB queues (Amir Tzin) [2049440]
- net/mlx5e: Use a barrier after updating txq2sq (Amir Tzin) [2049440]
- net/mlx5e: Disable TX queues before registering the netdev (Amir Tzin) [2049440]
- net/mlx5e: Cleanup of start/stop all queues (Amir Tzin) [2049440]
- net/mlx5e: Use FW limitation for max MPW WQEBBs (Amir Tzin) [2049440]
- net/mlx5e: Read max WQEBBs on the SQ from firmware (Amir Tzin) [2049440]
- net/mlx5e: Remove unused tstamp SQ field (Amir Tzin) [2049440]
- RDMA/mlx5: Delete useless module.h include (Amir Tzin) [2049440]
- RDMA/mlx5: Delete get_num_static_uars function (Amir Tzin) [2049440]
- net/mlx5: VLAN push on RX, pop on TX (Amir Tzin) [2049440 2049616]
- net/mlx5: Introduce software defined steering capabilities (Amir Tzin) [2049440 2049616]
- net/mlx5: Remove unused TIR modify bitmask enums (Amir Tzin) [2049440]
- net/mlx5e: CT, Remove redundant flow args from tc ct calls (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Store mapped tunnel id on flow attr (Amir Tzin) [2049440 2049659]
- net/mlx5e: Test CT and SAMPLE on flow attr (Amir Tzin) [2049440 2049580 2049659]
- net/mlx5e: Refactor eswitch attr flags to just attr flags (Amir Tzin) [2049440 2049580 2049659]
- net/mlx5e: CT, Don't set flow flag CT for ct clear flow (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Hold sample_attr on stack instead of pointer (Amir Tzin) [2049440 2049580 2049659]
- net/mlx5e: TC, Reject rules with multiple CT actions (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Refactor mlx5e_tc_add_flow_mod_hdr() to get flow attr (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Pass attr to tc_act can_offload() (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Split pedit offloads verify from alloc_tc_pedit_action() (Amir Tzin) [2049440 2049659]
- net/mlx5e: TC, Move pedit_headers_action to parse_attr (Amir Tzin) [2049440 2049659]
- net/mlx5e: Move counter creation call to alloc_flow_attr_counter() (Amir Tzin) [2049440 2049659]
- net/mlx5e: Pass attr arg for attaching/detaching encaps (Amir Tzin) [2049440 2049659]
- net/mlx5e: Move code chunk setting encap dests into its own function (Amir Tzin) [2049440 2049659]
- net_sched: cls_route: remove from list when handle is 0 (Felix Maurer) [2116328] {CVE-2022-2588}
- netfilter: nf_tables: do not allow RULE_ID to refer to another chain (Florian Westphal) [2116356] {CVE-2022-2586}
- netfilter: nf_tables: do not allow SET_ID to refer to another table (Florian Westphal) [2116356] {CVE-2022-2586}
- netfilter: nf_queue: do not allow packet truncation below transport header offset (Florian Westphal) [2116159] {CVE-2022-36946}
- net: let flow have same hash in two directions (Ivan Vecera) [2111094]
- ipv4: Fix data-races around sysctl_fib_multipath_hash_fields. (Ivan Vecera) [2111094]
- net: Add notifications when multipath hash field change (Ivan Vecera) [2111094]
- selftests: forwarding: Add test for custom multipath hash with IPv6 GRE (Ivan Vecera) [2111094]
- selftests: forwarding: Add test for custom multipath hash with IPv4 GRE (Ivan Vecera) [2111094]
- selftests: forwarding: Add test for custom multipath hash (Ivan Vecera) [2111094]
- ipv6: Add custom multipath hash policy (Ivan Vecera) [2111094]
- ipv6: Add a sysctl to control multipath hash fields (Ivan Vecera) [2111094]
- ipv6: Calculate multipath hash inside switch statement (Ivan Vecera) [2111094]
- ipv6: Use a more suitable label name (Ivan Vecera) [2111094]
- ipv4: Add custom multipath hash policy (Ivan Vecera) [2111094]
- ipv4: Add a sysctl to control multipath hash fields (Ivan Vecera) [2111094]
- ipv4: Calculate multipath hash inside switch statement (Ivan Vecera) [2111094]
- ipv6: Use math to point per net sysctls into the appropriate struct net (Ivan Vecera) [2111094]
- selftest/net/forwarding: declare NETIFS p9 p10 (Ivan Vecera) [2111094]
- ipv6: Fix sysctl max for fib_multipath_hash_policy (Ivan Vecera) [2111094]
- selftests: forwarding: Test multipath hashing on inner IP pkts for GRE tunnel (Ivan Vecera) [2111094]
- ipv6: Support multipath hashing on inner IP pkts (Ivan Vecera) [2111094]
- ipv4: Multipath hashing on inner L3 needs to consider inner IPv6 pkts (Ivan Vecera) [2111094]
- ipv4: Support multipath hashing on inner IP pkts for GRE tunnel (Ivan Vecera) [2111094]
- ipv4: Initialize flowi4_multipath_hash in data path (Ivan Vecera) [2111094]
- net: ipv4: Fix NULL pointer dereference in route lookup (Ivan Vecera) [2111094]
- route: Add multipath_hash in flowi_common to make user-define hash (Ivan Vecera) [2111094]

* Thu Aug 25 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-422.el8]
- drm/nouveau/kms/nv140-: Disable interlacing (Lyude Paul) [2097647]
- rpm: convert gcc and libelf to Recommends (Jarod Wilson) [2114900]
- redhat: add ca7 to redhat/git/files (Jarod Wilson)

* Wed Aug 24 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-421.el8]
- net/mlx5e: TC, Remove redundant error logging (Amir Tzin) [2049436]
- net/mlx5e: SHAMPO, reduce TIR indication (Amir Tzin) [2049436]
- net/mlx5e: Lag, Only handle events from highest priority multipath entry (Amir Tzin) [2049436]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Amir Tzin) [2049436]
- net/mlx5: Fix a race on command flush flow (Amir Tzin) [2049436]
- net/mlx5: Fix size field in bufferx_reg struct (Amir Tzin) [2049436]
- net/mlx5e: Fix VF min/max rate parameters interchange mistake (Amir Tzin) [2049436]
- net/mlx5e: Add missing increment of count (Amir Tzin) [2049436]
- net/mlx5e: MPLSoUDP decap, fix check for unsupported matches (Amir Tzin) [2049436]
- net/mlx5e: Fix MPLSoUDP encap to use MPLS action information (Amir Tzin) [2049436]
- net/mlx5e: Add feature check for set fec counters (Amir Tzin) [2049436 2049711]
- net/mlx5e: TC, Skip redundant ct clear actions (Amir Tzin) [2049436]
- net/mlx5e: TC, Reject rules with forward and drop actions (Amir Tzin) [2049436]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Amir Tzin) [2049436]
- net/mlx5e: kTLS, Use CHECKSUM_UNNECESSARY for device-offloaded packets (Amir Tzin) [2049436]
- net/mlx5e: Use dma device access helper (add dropped hunk) (Amir Tzin) [2049436]
- net/mlx5e: Fix wrong return value on ioctl EEPROM query failure (Amir Tzin) [2049436]
- net/mlx5: Fix possible deadlock on rule deletion (Amir Tzin) [2049436]
- net/mlx5: Fix tc max supported prio for nic mode (Amir Tzin) [2049436]
- net/mlx5: Update log_max_qp value to be 17 at most (Amir Tzin) [2049436]
- net/mlx5: DR, Don't allow match on IP w/o matching on full ethertype/ip_version (Amir Tzin) [2049436]
- net/mlx5e: Avoid field-overflowing memcpy() (Amir Tzin) [2049436]
- net/mlx5e: Use struct_group() for memcpy() region (Amir Tzin) [2049436]
- net/mlx5e: IPsec: Fix tunnel mode crypto offload for non TCP/UDP traffic (Amir Tzin) [2049436 2052871]
- net/mlx5e: IPsec: Fix crypto offload for non TCP/UDP encapsulated traffic (Amir Tzin) [2049436 2052871]
- net/mlx5e: Don't treat small ceil values as unlimited in HTB offload (Amir Tzin) [2049436]
- net/mlx5: E-Switch, Fix uninitialized variable modact (Amir Tzin) [2049436]
- net/mlx5e: Fix handling of wrong devices during bond netevent (Amir Tzin) [2049436]
- net/mlx5e: Fix broken SKB allocation in HW-GRO (Amir Tzin) [2049436]
- net/mlx5e: Fix wrong calculation of header index in HW_GRO (Amir Tzin) [2049436]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Amir Tzin) [2049436]
- net/mlx5e: TC, Reject rules with forward and drop actions (Amir Tzin) [2049436]
- net/mlx5: Use del_timer_sync in fw reset flow of halting poll (Amir Tzin) [2049436]
- net/mlx5e: Fix module EEPROM query (Amir Tzin) [2049436]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Amir Tzin) [2049436]
- net/mlx5: Bridge, ensure dev_name is null-terminated (Amir Tzin) [2049436]
- net/mlx5: Bridge, take rtnl lock in init error handler (Amir Tzin) [2049436]
- mlx5: Don't accidentally set RTO_ONLINK before mlx5e_route_lookup_ipv4_get() (Amir Tzin) [2049436]
- net/mlx5e: Fix build error in fec_set_block_stats() (Amir Tzin) [2049436]
- Revert "net/mlx5: Add retry mechanism to the command entry index allocation" (Amir Tzin) [2049436]
- net/mlx5: Set command entry semaphore up once got index free (Amir Tzin) [2049436]
- net/mlx5e: Sync VXLAN udp ports during uplink representor profile change (Amir Tzin) [2049436]
- net/mlx5: Fix access to sf_dev_table on allocation failure (Amir Tzin) [2049436]
- net/mlx5e: Fix matching on modified inner ip_ecn bits (Amir Tzin) [2049436]
- Revert "net/mlx5e: Block offload of outer header csum for GRE tunnel" (Amir Tzin) [2049436]
- Revert "net/mlx5e: Block offload of outer header csum for UDP tunnels" (Amir Tzin) [2049436]
- net/mlx5e: Fix nullptr on deleting mirroring rule (Amir Tzin) [2049436]
- net/mlx5e: Fix page DMA map/unmap attributes (Amir Tzin) [2049436]
- net/mlx5: Use dma device access helper (add dropped hunk) (Amir Tzin) [2049436]
- net/mlx5e: Add recovery flow in case of error CQE (Amir Tzin) [2049436]
- net/mlx5e: Refactor set_pflag_cqe_based_moder (Amir Tzin) [2049436]
- net/mlx5e: Move HW-GRO and CQE compression check to fix features flow (Amir Tzin) [2049436]
- net/mlx5e: Fix feature check per profile (Amir Tzin) [2049436]
- net/mlx5e: Unblock setting vid 0 for VF in case PF isn't eswitch manager (Amir Tzin) [2049436]
- net/mlx5e: Expose FEC counters via ethtool (Amir Tzin) [2049436 2049711]
- net/mlx5: Update log_max_qp value to FW max capability (Amir Tzin) [2049436]
- net/mlx5: Use irq_set_affinity_and_hint() (Amir Tzin) [2049436]
- net/mlx5: SF, Use all available cpu for setting cpu affinity (Amir Tzin) [2049436]
- net/mlx5: Introduce API for bulk request and release of IRQs (Amir Tzin) [2049436]
- net/mlx5: Split irq_pool_affinity logic to new file (Amir Tzin) [2049436]
- net/mlx5: Move affinity assignment into irq_request (Amir Tzin) [2049436]
- net/mlx5: Introduce control IRQ request API (Amir Tzin) [2049436]
- net/mlx5: mlx5e_hv_vhca_stats_create return type to void (Amir Tzin) [2049436]
- RDMA/mlx5: Print wc status on CQE error and dump needed (Amir Tzin) [2049436]
- net: fixup build after bpf header changes (Amir Tzin) [2049436]
- net/mlx5: CT: Set flow source hint from provided tuple device (Amir Tzin) [2049436]
- net/mlx5: Set SMFS as a default steering mode if device supports it (Amir Tzin) [2049436]
- net/mlx5: DR, Improve steering for empty or RX/TX-only matchers (Amir Tzin) [2049436]
- net/mlx5: DR, Add support for matching on geneve_tlv_option_0_exist field (Amir Tzin) [2049436]
- net/mlx5: DR, Support matching on tunnel headers 0 and 1 (Amir Tzin) [2049436]
- net/mlx5: DR, Add misc5 to match_param structs (Amir Tzin) [2049436]
- net/mlx5: Add misc5 flow table match parameters (Amir Tzin) [2049436]
- net/mlx5: DR, Add support for UPLINK destination type (Amir Tzin) [2049436]
- net/mlx5e: Use auxiliary_device driver data helpers (Amir Tzin) [2049436]
- net/mlx5e: Take packet_merge params directly from the RX res struct (Amir Tzin) [2049436]
- net/mlx5e: Allocate per-channel stats dynamically at first usage (Amir Tzin) [2049436]
- net/mlx5e: Use dynamic per-channel allocations in stats (Amir Tzin) [2049436]
- net/mlx5e: Allow profile-specific limitation on max num of channels (Amir Tzin) [2049436]
- net/mlx5e: Save memory by using dynamic allocation in netdev priv (Amir Tzin) [2049436]
- net/mlx5e: Add profile indications for PTP and QOS HTB features (Amir Tzin) [2049436]
- net/mlx5e: Use bitmap field for profile features (Amir Tzin) [2049436]
- net/mlx5: Remove the repeated declaration (Amir Tzin) [2049436]
- net/mlx5: Let user configure max_macs generic param (Amir Tzin) [2049436]
- net/mlx5: Let user configure event_eq_size param (Amir Tzin) [2049436]
- net/mlx5: Let user configure io_eq_size param (Amir Tzin) [2049436]
- net/mlx5: Introduce log_max_current_uc_list_wr_supported bit (Amir Tzin) [2049436]
- net/mlx5e: Move goto action checks into tc_action goto post parse op (Amir Tzin) [2049436]
- net/mlx5e: Move vlan action chunk into tc action vlan post parse op (Amir Tzin) [2049436]
- net/mlx5e: Add post_parse() op to tc action infrastructure (Amir Tzin) [2049436]
- net/mlx5e: Move sample attr allocation to tc_action sample parse op (Amir Tzin) [2049436]
- net/mlx5e: TC action parsing loop (Amir Tzin) [2049436]
- net/mlx5e: Add redirect ingress to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add sample and ptype to tc_action infra (Amir Tzin) [2049436]
- net/mlx5e: Add ct to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add mirred/redirect to tc action infra (Amir Tzin) [2049436]
- Revert "net/mlx5e: TC, Remove redundant error logging" (Amir Tzin) [2049436]
- net/mlx5e: Add mpls push/pop to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add vlan push/pop/mangle to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add pedit to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add csum to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add tunnel encap/decap to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add goto to tc action infra (Amir Tzin) [2049436]
- net/mlx5e: Add tc action infrastructure (Amir Tzin) [2049436]
- RDMA/mlx5: Use memset_after() to zero struct mlx5_ib_mr (Amir Tzin) [2049436]
- RDMA/mlx5: Add support to multiple priorities for FDB rules (Amir Tzin) [2049436]
- net/mlx5: Create more priorities for FDB bypass namespace (Amir Tzin) [2049436]
- net/mlx5: Refactor mlx5_get_flow_namespace (Amir Tzin) [2049436]
- net/mlx5: Separate FDB namespace (Amir Tzin) [2049436]
- net/mlx5: Dynamically resize flow counters query buffer (Amir Tzin) [2049436]
- net/mlx5e: TC, Set flow attr ip_version earlier (Amir Tzin) [2049436]
- net/mlx5e: TC, Move common flow_action checks into function (Amir Tzin) [2049436]
- net/mlx5e: Remove redundant actions arg from vlan push/pop funcs (Amir Tzin) [2049436]
- net/mlx5e: Remove redundant actions arg from validate_goto_chain() (Amir Tzin) [2049436]
- net/mlx5e: TC, Remove redundant action stack var (Amir Tzin) [2049436]
- net/mlx5e: Hide function mlx5e_num_channels_changed (Amir Tzin) [2049436]
- net/mlx5e: SHAMPO, clean MLX5E_MAX_KLM_PER_WQE macro (Amir Tzin) [2049436]
- net/mlx5: Print more info on pci error handlers (Amir Tzin) [2049436]
- net/mlx5: SF, silence an uninitialized variable warning (Amir Tzin) [2049436]
- net/mlx5: Fix error return code in esw_qos_create() (Amir Tzin) [2049436]
- net/mlx5: E-switch, Create QoS on demand (Amir Tzin) [2049436]
- net/mlx5: E-switch, Enable vport QoS on demand (Amir Tzin) [2049436]
- net/mlx5: E-switch, move offloads mode callbacks to offloads file (Amir Tzin) [2049436]
- net/mlx5: E-switch, Reuse mlx5_eswitch_set_vport_mac (Amir Tzin) [2049436]
- net/mlx5: E-switch, Remove vport enabled check (Amir Tzin) [2049436]
- net/mlx5e: Specify out ifindex when looking up decap route (Amir Tzin) [2049436]
- net/mlx5e: TC, Move comment about mod header flag to correct place (Amir Tzin) [2049436]
- net/mlx5e: TC, Move kfree() calls after destroying all resources (Amir Tzin) [2049436]
- net/mlx5e: TC, Destroy nic flow counter if exists (Amir Tzin) [2049436]
- net/mlx5: TC, using swap() instead of tmp variable (Amir Tzin) [2049436]
- net/mlx5: CT: Allow static allocation of mod headers (Amir Tzin) [2049436]
- net/mlx5e: Refactor mod header management API (Amir Tzin) [2049436]
- net/mlx5: Avoid printing health buffer when firmware is unavailable (Amir Tzin) [2049436 2049717]
- net/mlx5e: Support ethtool cq mode (Amir Tzin) [2049436 2049840]
- Revert "RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow" (Amir Tzin) [2049435]
- net/mlx5: Use first online CPU instead of hard coded CPU (Amir Tzin) [2049435]
- net/mlx5e: SHAMPO, Fix constant expression result (Amir Tzin) [2049435]
- net/mlx5: Fix access to a non-supported register (Amir Tzin) [2049435 2049717]
- net/mlx5: Fix too early queueing of log timestamp work (Amir Tzin) [2049435 2049717]
- net/mlx5: Fix use after free in mlx5_health_wait_pci_up (Amir Tzin) [2049435]
- net/mlx5: Lag, Fix recreation of VF LAG (Amir Tzin) [2049435]
- net/mlx5e: Sync TIR params updates against concurrent create/modify (Amir Tzin) [2049435]
- RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow (Amir Tzin) [2049435]
- net/mlx5: Fix flow counters SF bulk query len (Amir Tzin) [2049435]
- net/mlx5: Lag, fix a potential Oops with mlx5_lag_create_definer() (Amir Tzin) [2049435]
- net/mlx5e: Prevent HW-GRO and CQE-COMPRESS features operate together (Amir Tzin) [2049435]
- net/mlx5e: Add HW-GRO offload (Amir Tzin) [2049435]
- net/mlx5e: Add HW_GRO statistics (Amir Tzin) [2049435]
- net/mlx5e: HW_GRO cqe handler implementation (Amir Tzin) [2049435]
- net/mlx5e: Add data path for SHAMPO feature (Amir Tzin) [2049435]
- net/mlx5e: Add handle SHAMPO cqe support (Amir Tzin) [2049435]
- net/mlx5e: Add control path for SHAMPO feature (Amir Tzin) [2049435]
- net/mlx5e: Add support to klm_umr_wqe (Amir Tzin) [2049435]
- net/mlx5e: Rename TIR lro functions to TIR packet merge functions (Amir Tzin) [2049435]
- net/mlx5e: Align mlx5e_resources with upstream code. (Amir Tzin) [2049435]
- net/mlx5: Add SHAMPO caps, HW bits and enumerations (Amir Tzin) [2049435]
- net/mlx5e: Rename lro_timeout to packet_merge_timeout (Amir Tzin) [2049435]
- net/mlx5: SF_DEV Add SF device trace points (Amir Tzin) [2049435]
- net/mlx5: SF, Add SF trace points (Amir Tzin) [2049435]
- net/mlx5: Bridge, support replacing existing FDB entry (Amir Tzin) [2049435]
- net/mlx5: Bridge, extract code to lookup and del/notify entry (Amir Tzin) [2049435]
- net/mlx5: Add periodic update of host time to firmware (Amir Tzin) [2049435 2049717]
- net/mlx5: Print health buffer by log level (Amir Tzin) [2049435 2049717]
- net/mlx5: Extend health buffer dump (Amir Tzin) [2049435 2049717]
- net/mlx5: Reduce flow counters bulk query buffer size for SFs (Amir Tzin) [2049435]
- net/mlx5: Fix unused function warning of mlx5i_flow_type_mask (Amir Tzin) [2049435]
- net/mlx5: Remove unnecessary checks for slow path flag (Amir Tzin) [2049435]
- net/mlx5e: don't write directly to netdev->dev_addr (Amir Tzin) [2049435]
- RDMA/mlx5: Use dev_addr_mod() (Amir Tzin) [2049435]
- RDMA/mlx5: fix build error with INFINIBAND_USER_ACCESS=n (Amir Tzin) [2049435]
- RDMA/mlx5: Attach ndescs to mlx5_ib_mkey (Amir Tzin) [2049435]
- RDMA/mlx5: Move struct mlx5_core_mkey to mlx5_ib (Amir Tzin) [2049435]
- RDMA/mlx5: Replace struct mlx5_core_mkey by u32 key (Amir Tzin) [2049435]
- RDMA/mlx5: Align mlx5e_resources with upstream code. (Amir Tzin) [2049435]
- RDMA/mlx5: Remove pd from struct mlx5_core_mkey (Amir Tzin) [2049435]
- RDMA/mlx5: Remove size from struct mlx5_core_mkey (Amir Tzin) [2049435]
- RDMA/mlx5: Remove iova from struct mlx5_core_mkey (Amir Tzin) [2049435]
- net/mlx5: E-Switch, Increase supported number of forward destinations to 32 (Amir Tzin) [2049435]
- net/mlx5: E-Switch, Use dynamic alloc for dest array (Amir Tzin) [2049435]
- net/mlx5: Lag, use steering to select the affinity port in LAG (Amir Tzin) [2049435]
- net/mlx5: Lag, add support to create/destroy/modify port selection (Amir Tzin) [2049435]
- net/mlx5: Lag, add support to create TTC tables for LAG port selection (Amir Tzin) [2049435]
- net/mlx5: Lag, add support to create definers for LAG (Amir Tzin) [2049435]
- net/mlx5: Lag, set match mask according to the traffic type bitmap (Amir Tzin) [2049435]
- net/mlx5: Lag, set LAG traffic type mapping (Amir Tzin) [2049435]
- net/mlx5: Lag, move lag files into directory (Amir Tzin) [2049435]
- net/mlx5: Introduce new uplink destination type (Amir Tzin) [2049435]
- net/mlx5: Add support to create match definer (Amir Tzin) [2049435]
- net/mlx5: Introduce port selection namespace (Amir Tzin) [2049435]
- net/mlx5: Support partial TTC rules (Amir Tzin) [2049435]
- mlx5: prevent 64bit divide (Amir Tzin) [2049435]
- net/mlx5: Use system_image_guid to determine bonding (Amir Tzin) [2049435]
- net/mlx5: Use native_port_num as 1st option of device index (Amir Tzin) [2049435]
- net/mlx5: Introduce new device index wrapper (Amir Tzin) [2049435]
- net/mlx5: Check return status first when querying system_image_guid (Amir Tzin) [2049435]
- net/mlx5: DR, Prefer kcalloc over open coded arithmetic (Amir Tzin) [2049435]
- net/mlx5e: Add extack msgs related to TC for better debug (Amir Tzin) [2049435]
- net/mlx5: CT: Fix missing cleanup of ct nat table on init failure (Amir Tzin) [2049435]
- Revert "net/mlx5e: TC, Skip redundant ct clear actions" (Amir Tzin) [2049435]
- net/mlx5: Disable roce at HCA level (Amir Tzin) [2049435]
- net/mlx5i: Enable Rx steering for IPoIB via ethtool (Amir Tzin) [2049435]
- net/mlx5: Bridge, provide flow source hints (Amir Tzin) [2049435]
- net/mlx5: Read timeout values from DTOR (Amir Tzin) [2049435]
- net/mlx5: Read timeout values from init segment (Amir Tzin) [2049435]
- net/mlx5: Add layout to support default timeouts register (Amir Tzin) [2049435]
- net/mlx5: Set devlink reload feature bit for supported devices only (Amir Tzin) [2049435]
- RDMA/mlx5: Add optional counter support in get_hw_stats callback (Amir Tzin) [2049435]
- RDMA/mlx5: Add modify_op_stat() support (Amir Tzin) [2049435]
- RDMA/mlx5: Add steering support in optional flow counters (Amir Tzin) [2049435]
- RDMA/mlx5: Support optional counters in hw_stats initialization (Amir Tzin) [2049435]
- net/mlx5: Add priorities for counters in RDMA namespaces (Amir Tzin) [2049435]
- net/mlx5: Add ifc bits to support optional counters (Amir Tzin) [2049435]
- net/mlx5: Enable single IRQ for PCI Function (Amir Tzin) [2049435]
- net/mlx5: Shift control IRQ to the last index (Amir Tzin) [2049435]
- net/mlx5: Bridge, pop VLAN on egress table miss (Amir Tzin) [2049435]
- net/mlx5: Bridge, mark reg_c1 when pushing VLAN (Amir Tzin) [2049435]
- net/mlx5: Bridge, extract VLAN pop code to dedicated functions (Amir Tzin) [2049435]
- net/mlx5: Bridge, refactor eswitch instance usage (Amir Tzin) [2049435]
- net/mlx5e: Support accept action (Amir Tzin) [2049435]
- net/mlx5e: Specify out ifindex when looking up encap route (Amir Tzin) [2049435]
- net/mlx5e: Reserve a value from TC tunnel options mapping (Amir Tzin) [2049435]
- net/mlx5e: Move parse fdb check into actions_match_supported_fdb() (Amir Tzin) [2049435]
- net/mlx5e: Split actions_match_supported() into a sub function (Amir Tzin) [2049435]
- net/mlx5e: Move mod hdr allocation to a single place (Amir Tzin) [2049435]
- net/mlx5e: TC, Refactor sample offload error flow (Amir Tzin) [2049435]
- RDMA/mlx5: Avoid taking MRs from larger MR cache pools when a pool is empty (Amir Tzin) [2049435]
- IB/mlx5: Flow through a more detailed return code from get_prefetchable_mr() (Amir Tzin) [2049435]
- net/mlx5e: Use array_size() helper (Amir Tzin) [2049435]
- net/mlx5: Use struct_size() helper in kvzalloc() (Amir Tzin) [2049435]
- net/mlx5: Use kvcalloc() instead of kvzalloc() (Amir Tzin) [2049435]
- net/mlx5: Tolerate failures in debug features while driver load (Amir Tzin) [2049435]
- IB/mlx5: Enable UAR to have DevX UID (Amir Tzin) [2049435]
- net/mlx5: Add uid field to UAR allocation structures (Amir Tzin) [2049435]
- net/mlx5e: check return value of rhashtable_init (Amir Tzin) [2049435]
- net/mlx5e: Enable TC offload for ingress MACVLAN (Amir Tzin) [2049435]
- net/mlx5e: Enable TC offload for egress MACVLAN (Amir Tzin) [2049435]
- net/mlx5e: loopback test is not supported in switchdev mode (Amir Tzin) [2049435]
- net/mlx5e: Use NL_SET_ERR_MSG_MOD() for errors parsing tunnel attributes (Amir Tzin) [2049435]
- net/mlx5e: Use tc sample stubs instead of ifdefs in source file (Amir Tzin) [2049435]
- net/mlx5e: Remove redundant priv arg from parse_pedit_to_reformat() (Amir Tzin) [2049435]
- net/mlx5e: Check action fwd/drop flag exists also for nic flows (Amir Tzin) [2049435]
- net/mlx5e: Set action fwd flag when parsing tc action goto (Amir Tzin) [2049435]
- net/mlx5e: Remove incorrect addition of action fwd flag (Amir Tzin) [2049435]
- Revert "net/mlx5e: TC, Fix ct_clear overwriting ct action metadata" (Amir Tzin) [2049435]
- net/mlx5e: Use correct return type (Amir Tzin) [2049435]
- net/mlx5e: Add error flow for ethtool -X command (Amir Tzin) [2049435]
- net/mlx5: Fix rdma aux device on devlink reload (Amir Tzin) [2049434]
- RDMA/mlx5: Relax DCS QP creation checks (Amir Tzin) [2049434]
- net/mellanox: switch from 'pci_' to 'dma_' API (Amir Tzin) [2049434]
- net/mlx5e: Make use of netdev_warn() (Amir Tzin) [2049434]
- net/mlx5: Initialize numa node for all core devices (Amir Tzin) [2049434]
- net/mlx5: Allocate individual capability (Amir Tzin) [2049434]
- net/mlx5: Reorganize current and maximal capabilities to be per-type (Amir Tzin) [2049434]
- net/mlx5: SF, use recent sysfs api (Amir Tzin) [2049434]
- net/mlx5: Refcount mlx5_irq with integer (Amir Tzin) [2049434]
- net/mlx5: Change SF missing dedicated MSI-X err message to dbg (Amir Tzin) [2049434]
- net/mlx5: Align mlx5_irq structure (Amir Tzin) [2049434]
- net/mlx5: Delete impossible dev->state checks (Amir Tzin) [2049434]
- net/mlx5: Support enable_vnet devlink dev param (Amir Tzin) [2049434]
- net/mlx5: Support enable_rdma devlink dev param (Amir Tzin) [2049434]
- net/mlx5: Support enable_eth devlink dev param (Amir Tzin) [2049434]
- RDMA/mlx5: Drop in-driver verbs object creations (Amir Tzin) [2049434]
- RDMA/mlx5: Delete device resource mutex that didn't protect anything (Amir Tzin) [2049434]
- RDMA/mlx5: Cancel pkey work before destroying device resources (Amir Tzin) [2049434]
- net/mlx5e: Return -EOPNOTSUPP if more relevant when parsing tc actions (Amir Tzin) [2049434]
- net/mlx5e: Remove redundant assignment of counter to null (Amir Tzin) [2049434]
- net/mlx5e: Remove redundant parse_attr arg (Amir Tzin) [2049434]
- net/mlx5e: Remove redundant cap check for flow counter (Amir Tzin) [2049434]
- net/mlx5e: Remove redundant filter_dev arg from parse_tc_fdb_actions() (Amir Tzin) [2049434]
- net/mlx5e: Remove redundant tc act includes (Amir Tzin) [2049434]
- IB/mlx5: Rename is_apu_thread_cq function to is_apu_cq (Amir Tzin) [2049434]
- RDMA/mlx5: Add DCS offload support (Amir Tzin) [2049434]
- RDMA/mlx5: Separate DCI QP creation logic (Amir Tzin) [2049434]
- net/mlx5: Add DCS caps & fields support (Amir Tzin) [2049434]
- KVM: nVMX: Inject #UD if VMXON is attempted with incompatible CR0/CR4 (Vitaly Kuznetsov) [2119233]
- mm: Fix PASID use-after-free issue (Jerry Snitselaar) [2113046]
- scsi: csiostor: Uninitialized data in csio_ln_vnp_read_cbfn() (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Fix a typo (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Assign boolean values to a bool variable (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Fix fall-through warnings for Clang (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Fix spelling mistake "couldnt" -> "couldn't" (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Add missing description for csio_rnode_fwevt_handler()'s 'fwevt' param (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Remove 2 unused variables {mc,edc}_bist_status_rdata_reg (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Demote kerneldoc that fails to meet the criteria (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Fix misnamed function parameter (Rahul Lakkireddy) [2105815]
- scsi: csiostor: Adjust indentation in csio_device_reset (Rahul Lakkireddy) [2105815]
- mediatek: mt76: eeprom: fix missing of_node_put() in mt76_find_power_limits_node() (Jose Ignacio Tornos Martinez) [2103625]
- wifi: mac80211: consider EHT element size in assoc request (Jose Ignacio Tornos Martinez) [2103625]
- wifi: mac80211: switch airtime fairness back to deficit round-robin scheduling (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7615: fix throughput regression on DFS channels (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: fix incorrect testmode ipg on band 1 caused by wmm_idx (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921: enlarge maximum VHT MPDU length to 11454 (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921: fix aggregation subframes setting to HE max (Jose Ignacio Tornos Martinez) [2103625]
- wifi: mac80211_hwsim: set virtio device ready in probe() (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921s: fix possible sdio deadlock in command fail (Jose Ignacio Tornos Martinez) [2103625]
- wifi: rtw89: 8852a: rfk: fix div 0 exception (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921: do not update pm states in case of error (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7615: do not update pm stats in case of error (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: Avoid REO CMD failed prints during firmware recovery (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: Fix incorrect debug_mask mappings (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: fix missing skb drop on htc_tx_completion error (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921s: fix firmware download random fail (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: fix IRQ affinity warning on shutdown (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: fix netdev open race (Jose Ignacio Tornos Martinez) [2103625]
- iwlwifi: fw: init SAR GEO table only if data is present (Jose Ignacio Tornos Martinez) [2103625]
- ath10k: htt_tx: do not interpret Eth frames as WiFi (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: Don't check arvif->is_started before sending management frames (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: fix twt table_mask to u16 in mt7915_dev (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: reset 11d state in process of recovery (Jose Ignacio Tornos Martinez) [2103625]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on brcmfmac43602 chips (Jose Ignacio Tornos Martinez) [2103625]
- mt76: fix tx status related use-after-free race on station removal (Jose Ignacio Tornos Martinez) [2103625]
- mt76: do not attempt to reorder received 802.3 packets without agg session (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921: fix kernel crash at mt7921_pci_remove (Jose Ignacio Tornos Martinez) [2103625]
- mt76: fix antenna config missing in 6G cap (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: report rx mode value in mt7915_mac_fill_rx_rate (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: do not pass data pointer to mt7915_mcu_muru_debug_set (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: fix possible NULL pointer dereference in mt7915_mac_fill_rx_vector (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: fix possible uninitialized pointer dereference in mt7986_wmac_gpio_setup (Jose Ignacio Tornos Martinez) [2103625]
- ath10k: enable napi on RX path for usb (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: fix the warning of dev_wake in mhi_pm_disable_transition() (Jose Ignacio Tornos Martinez) [2103625]
- ath11k: acquire ab->base_lock in unassign when finding the peer by addr (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: fix unbounded shift in mt7915_mcu_beacon_mbss (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7915: fix DBDC default band selection on MT7915D (Jose Ignacio Tornos Martinez) [2103625]
- mt76: mt7921: honor pm user configuration in mt7921_sniffer_interface_iter (Jose Ignacio Tornos Martinez) [2103625]
- i40e: Fix tunnel checksum offload with fragmented traffic (Ivan Vecera) [2107977]
- net/mlx5e: Fix matchall police parameters validation (Ivan Vecera) [2106271]
- net/sched: act_police: allow 'continue' action offload (Ivan Vecera) [2106271]
- net: Print hashed skb addresses for all net and qdisc events (Ivan Vecera) [2106271]
- net: sched: fixed barrier to prevent skbuff sticking in qdisc backlog (Ivan Vecera) [2106271]
- net/sched: act_pedit: sanitize shift argument before usage (Ivan Vecera) [2106271]
- net/sched: act_pedit: really ensure the skb is writable (Ivan Vecera) [2106271]
- net/sched: taprio: Check if socket flags are valid (Ivan Vecera) [2106271]
- net/sched: flower: Avoid overwriting error messages (Ivan Vecera) [2106271]
- net/sched: matchall: Avoid overwriting error messages (Ivan Vecera) [2106271]
- net/sched: cls_api: Add extack message for unsupported action offload (Ivan Vecera) [2106271]
- net/sched: act_vlan: Add extack message for offload failure (Ivan Vecera) [2106271]
- net/sched: act_tunnel_key: Add extack message for offload failure (Ivan Vecera) [2106271]
- net/sched: act_skbedit: Add extack messages for offload failure (Ivan Vecera) [2106271]
- net/sched: act_police: Add extack messages for offload failure (Ivan Vecera) [2106271]
- net/sched: act_pedit: Add extack message for offload failure (Ivan Vecera) [2106271]
- net/sched: act_mpls: Add extack messages for offload failure (Ivan Vecera) [2106271]
- net/sched: act_mirred: Add extack message for offload failure (Ivan Vecera) [2106271]
- net/sched: act_gact: Add extack messages for offload failure (Ivan Vecera) [2106271]
- net/sched: act_api: Add extack to offload_act_setup() callback (Ivan Vecera) [2106271]
- net/sched: flower: Take verbose flag into account when logging error messages (Ivan Vecera) [2106271]
- net/sched: matchall: Take verbose flag into account when logging error messages (Ivan Vecera) [2106271]
- net/sched: fix incorrect vlan_push_eth dest field (Ivan Vecera) [2106271]
- net/sched: add vlan push_eth and pop_eth action to the hardware IR (Ivan Vecera) [2106271]
- selftests: tc-testing: Increase timeout in tdc config file (Ivan Vecera) [2106271]
- flow_offload: improve extack msg for user when adding invalid filter (Ivan Vecera) [2106271]
- flow_offload: reject offload for all drivers with invalid police parameters (Ivan Vecera) [2106271]
- net: flow_offload: add tc police action parameters (Ivan Vecera) [2106271]
- net: sched: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ivan Vecera) [2106271]
- net_sched: add __rcu annotation to netdev->qdisc (Ivan Vecera) [2106271]
- net/sched: act_police: more accurate MTU policing (Ivan Vecera) [2106271]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Ivan Vecera) [2106271]
- net: sched: remove qdisc_qlen_cpu() (Ivan Vecera) [2106271]
- net: sched: remove psched_tdiff_bounded() (Ivan Vecera) [2106271]
- net: sched: Clarify error message when qdisc kind is unknown (Ivan Vecera) [2106271]
- sch_cake: revise Diffserv docs (Ivan Vecera) [2106271]
- flow_offload: fix suspicious RCU usage when offloading tc action (Ivan Vecera) [2106271]
- net/sched: use min() macro instead of doing it manually (Ivan Vecera) [2106271]
- selftests: tc-testing: add action offload selftest for action and filter (Ivan Vecera) [2106271]
- flow_offload: validate flags of filter and actions (Ivan Vecera) [2106271]
- flow_offload: add reoffload process to update hw_count (Ivan Vecera) [2106271]
- net: sched: save full flags for tc action (Ivan Vecera) [2106271]
- flow_offload: add process to update action stats from hardware (Ivan Vecera) [2106271]
- flow_offload: rename exts stats update functions with hw (Ivan Vecera) [2106271]
- flow_offload: add skip_hw and skip_sw to control if offload the action (Ivan Vecera) [2106271]
- flow_offload: allow user to offload tc action to net device (Ivan Vecera) [2106271]
- flow_offload: add ops to tc_action_ops for flow action setup (Ivan Vecera) [2106271]
- flow_offload: rename offload functions with offload instead of flow (Ivan Vecera) [2106271]
- flow_offload: add index to flow_action_entry structure (Ivan Vecera) [2106271]
- flow_offload: reject to offload tc actions in offload drivers (Ivan Vecera) [2106271]
- flow_offload: fill flags to action structure (Ivan Vecera) [2106271]
- sch_cake: do not call cake_destroy() from cake_init() (Ivan Vecera) [2106271]
- net/sched: fq_pie: prevent dismantle issue (Ivan Vecera) [2106271]
- selftests/tc-testing: Fix cannot create /sys/bus/netdevsim/new_device: Directory nonexistent (Ivan Vecera) [2106271]
- selftests/tc-testing: add missing config (Ivan Vecera) [2106271]
- selftests/tc-testing: add exit code (Ivan Vecera) [2106271]
- net/sched: act_ct: Offload only ASSURED connections (Ivan Vecera) [2106271]
- selftests/tc-testings: Be compatible with newer tc output (Ivan Vecera) [2106271]
- selftests: forwarding: Fix packet matching in mirroring selftests (Ivan Vecera) [2106271]
- net/sched: sch_taprio: fix undefined behavior in ktime_mono_to_any (Ivan Vecera) [2106271]
- cls_flower: Fix inability to match GRE/IPIP packets (Ivan Vecera) [2106271]
- sch_htb: Add extack messages for EOPNOTSUPP errors (Ivan Vecera) [2106271]
- net: sch: simplify condtion for selecting mini_Qdisc_pair buffer (Ivan Vecera) [2106271]
- net: sch: eliminate unnecessary RCU waits in mini_qdisc_pair_swap() (Ivan Vecera) [2106271]
- net: sched: gred: dynamically allocate tc_gred_qopt_offload (Ivan Vecera) [2106271]
- net: stats: Read the statistics in ___gnet_stats_copy_basic() instead of adding. (Ivan Vecera) [2106271]
- net: sched: Allow statistics reads from softirq. (Ivan Vecera) [2106271]
- net: sched: remove one pair of atomic operations (Ivan Vecera) [2106271]
- net: sched: fix logic error in qdisc_run_begin() (Ivan Vecera) [2106271]
- net: sch_tbf: Add a graft command (Ivan Vecera) [2106271]
- net: sched: Remove Qdisc::running sequence counter (Ivan Vecera) [2106271]
- net: sched: Merge Qdisc::bstats and Qdisc::cpu_bstats data types (Ivan Vecera) [2106271]
- net: sched: Use _bstats_update/set() instead of raw writes (Ivan Vecera) [2106271]
- net: sched: Protect Qdisc::bstats with u64_stats (Ivan Vecera) [2106271]
- u64_stats: Introduce u64_stats_set() (Ivan Vecera) [2106271]
- gen_stats: Move remaining users to gnet_stats_add_queue(). (Ivan Vecera) [2106271]
- mq, mqprio: Use gnet_stats_add_queue(). (Ivan Vecera) [2106271]
- gen_stats: Add gnet_stats_add_queue(). (Ivan Vecera) [2106271]
- gen_stats: Add instead Set the value in __gnet_stats_copy_basic(). (Ivan Vecera) [2106271]
- testing: selftests: tc_common: Add tc_check_at_least_x_packets() (Ivan Vecera) [2106271]
- testing: selftests: forwarding.config.sample: Add tc flag (Ivan Vecera) [2106271]
- net/sched: sch_taprio: properly cancel timer from taprio_destroy() (Ivan Vecera) [2106271]
- net: sched: Use struct_size() helper in kvmalloc() (Ivan Vecera) [2106271]
- net_sched: Use struct_size() and flex_array_size() helpers (Ivan Vecera) [2106271]
- net: prevent user from passing illegal stab size (Ivan Vecera) [2106271]
- net: sched: move and reuse mq_change_real_num_tx() (Ivan Vecera) [2106271]
- selftests: net: test ethtool -L vs mq (Ivan Vecera) [2106271]
- netdevsim: add ability to change channel count (Ivan Vecera) [2106271]
- net: add netif_set_real_num_queues() for device reconfig (Ivan Vecera) [2106271]
- net: sched: update default qdisc visibility after Tx queue cnt changes (Ivan Vecera) [2106271]
- fix array-index-out-of-bounds in taprio_change (Ivan Vecera) [2106271]
- Revert "flow_offload: action should not be NULL when it is referenced" (Ivan Vecera) [2106271]
- sch_cake: fix srchost/dsthost hashing mode (Ivan Vecera) [2106271]
- net/sched: cls_api, reset flags on replay (Ivan Vecera) [2106271]
- net: sched: provide missing kdoc for tcf_pkt_info and tcf_ematch_ops (Ivan Vecera) [2106271]
- net: flow_offload: correct comments mismatch with code (Ivan Vecera) [2106271]
- net/sched: taprio: Fix init procedure (Ivan Vecera) [2106271]
- net_sched: refactor TC action init API (Ivan Vecera) [2106271]
- tc-testing: Add control-plane selftest for skbmod SKBMOD_F_ECN option (Ivan Vecera) [2106271]
- net/sched: act_skbmod: Add SKBMOD_F_ECN option support (Ivan Vecera) [2106271]
- qdisc: add new field for qdisc_enqueue tracepoint (Ivan Vecera) [2106271]
- net/sched: act_skbmod: Skip non-Ethernet packets (Ivan Vecera) [2106271]
- net/sched: Remove unnecessary if statement (Ivan Vecera) [2106271]
- net_sched: introduce tracepoint trace_qdisc_enqueue() (Ivan Vecera) [2106271]
- net_sched: use px to print skb address in trace_qdisc_dequeue() (Ivan Vecera) [2106271]
- net: use px to print skb address in trace_netif_receive_skb (Ivan Vecera) [2106271]
- net/sched: sch_taprio: fix typo in comment (Ivan Vecera) [2106271]
- flow_offload: action should not be NULL when it is referenced (Ivan Vecera) [2106271]
- net: sched: remove qdisc->empty for lockless qdisc (Ivan Vecera) [2106271]
- net: sched: implement TCQ_F_CAN_BYPASS for lockless qdisc (Ivan Vecera) [2106271]
- net: sched: avoid unnecessary seqcount operation for lockless qdisc (Ivan Vecera) [2106271]
- Revert "net/sched: cls_flower: Remove match on n_proto" (Ivan Vecera) [2106271]
- net: sched: add barrier to ensure correct ordering for lockless qdisc (Ivan Vecera) [2106271]
- net: sched: fix error return code in tcf_del_walker() (Ivan Vecera) [2106271]
- net/sched: cls_flower: Remove match on n_proto (Ivan Vecera) [2106271]
- sch_cake: revise docs for RFC 8622 LE PHB support (Ivan Vecera) [2106271]
- sch_cake: Fix out of bounds when parsing TCP options and header (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_lookup_leaf() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_do_events() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_charge_class() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_deactivate() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_activate() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_change_class_mode() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_class_mode() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_deactivate_prios() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_activate_prios() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_remove_class_from_row() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_add_class_to_row() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_next_rb_node() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_add_to_wait_tree() (Ivan Vecera) [2106271]
- sch_htb: fix doc warning in htb_add_to_id_tree() (Ivan Vecera) [2106271]
- net/sched: act_vlan: Test priority 0 modification (Ivan Vecera) [2106271]
- net/sched: act_vlan: No dump for unset priority (Ivan Vecera) [2106271]
- net: sched: Fix spelling mistakes (Ivan Vecera) [2106271]
- net/sched: fq_pie: fix OOB access in the traffic path (Ivan Vecera) [2106271]
- net/sched: fq_pie: re-factor fix for fq_pie endless loop (Ivan Vecera) [2106271]
- net: taprio offload: enforce qdisc to netdev queue mapping (Ivan Vecera) [2106271]
- net/sched: taprio: Drop unnecessary NULL check after container_of (Ivan Vecera) [2106271]
- net: flow_offload: add FLOW_ACTION_PPPOE_PUSH (Ivan Vecera) [2106271]
- gve: Recording rx queue before sending to napi (Jordan Kimbrough) [2018609]
- gve: fix the wrong AdminQ buffer queue index check (Jordan Kimbrough) [2018609]
- gve: Fix GFP flags when allocing pages (Jordan Kimbrough) [2018609]
- gve: Add tx|rx-coalesce-usec for DQO (Jordan Kimbrough) [2018609]
- gve: Add consumed counts to ethtool stats (Jordan Kimbrough) [2018609]
- gve: Implement suspend/resume/shutdown (Jordan Kimbrough) [2018609]
- gve: Add optional metadata descriptor type GVE_TXD_MTD (Jordan Kimbrough) [2018609]
- gve: remove memory barrier around seqno (Jordan Kimbrough) [2018609]
- gve: Update gve_free_queue_page_list signature (Jordan Kimbrough) [2018609]
- gve: Move the irq db indexes out of the ntfy block struct (Jordan Kimbrough) [2018609]
- gve: Correct order of processing device options (Jordan Kimbrough) [2018609]
- gve: fix for null pointer dereference. (Jordan Kimbrough) [2018609]
- gve: fix unmatched u64_stats_update_end() (Jordan Kimbrough) [2018609]
- gve: Fix off by one in gve_tx_timeout() (Jordan Kimbrough) [2018609]
- gve: Add a jumbo-frame device option. (Jordan Kimbrough) [2018609]
- gve: Implement packet continuation for RX. (Jordan Kimbrough) [2018609]
- gve: Add RX context. (Jordan Kimbrough) [2018609]
- gve: Track RX buffer allocation failures (Jordan Kimbrough) [2018609]
- gve: Allow pageflips on larger pages (Jordan Kimbrough) [2018609]
- gve: Add netif_set_xps_queue call (Jordan Kimbrough) [2018609]
- gve: Recover from queue stall due to missed IRQ (Jordan Kimbrough) [2018609]
- gve: Do lazy cleanup in TX path (Jordan Kimbrough) [2018609]
- gve: Add rx buffer pagecnt bias (Jordan Kimbrough) [2018609]
- gve: Switch to use napi_complete_done (Jordan Kimbrough) [2018609]
- gve: report 64bit tx_bytes counter from gve_handle_report_stats() (Jordan Kimbrough) [2018609]
- gve: fix gve_get_stats() (Jordan Kimbrough) [2018609]
- gve: Properly handle errors in gve_assign_qpl (Jordan Kimbrough) [2018609]
- gve: Avoid freeing NULL pointer (Jordan Kimbrough) [2018609]
- gve: Correct available tx qpl check (Jordan Kimbrough) [2018609]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Jordan Kimbrough) [2018609]
- gve: Use kvcalloc() instead of kvzalloc() (Jordan Kimbrough) [2018609]
- gve: DQO: avoid unused variable warnings (Jordan Kimbrough) [2018609]
- gve: fix the wrong AdminQ buffer overflow check (Jordan Kimbrough) [2018609]
- gve: DQO: Remove incorrect prefetch (Jordan Kimbrough) [2018609]
- gve: Simplify code and axe the use of a deprecated API (Jordan Kimbrough) [2018609]
- gve: Propagate error codes to caller (Jordan Kimbrough) [2018609]
- gve: Fix an error handling path in 'gve_probe()' (Jordan Kimbrough) [2018609]
- gve: DQO: Fix off by one in gve_rx_dqo() (Jordan Kimbrough) [2018609]
- gve: Fix swapped vars when fetching max queues (Jordan Kimbrough) [2018609]
- gve: Fix warnings reported for DQO patchset (Jordan Kimbrough) [2018609]
- gve: DQO: Add RX path (Jordan Kimbrough) [2018609]
- gve: DQO: Add TX path (Jordan Kimbrough) [2018609]
- gve: DQO: Configure interrupts on device up (Jordan Kimbrough) [2018609]
- gve: DQO: Add ring allocation and initialization (Jordan Kimbrough) [2018609]
- gve: DQO: Add core netdev features (Jordan Kimbrough) [2018609]
- gve: Update adminq commands to support DQO queues (Jordan Kimbrough) [2018609]
- gve: Add DQO fields for core data structures (Jordan Kimbrough) [2018609]
- gve: Add dqo descriptors (Jordan Kimbrough) [2018609]
- gve: Add support for DQO RX PTYPE map (Jordan Kimbrough) [2018609]
- gve: adminq: DQO specific device descriptor logic (Jordan Kimbrough) [2018609]
- gve: Introduce per netdev `enum gve_queue_format` (Jordan Kimbrough) [2018609]
- gve: Introduce a new model for device options (Jordan Kimbrough) [2018609]
- gve: Make gve_rx_slot_page_info.page_offset an absolute offset (Jordan Kimbrough) [2018609]
- gve: gve_rx_copy: Move padding to an argument (Jordan Kimbrough) [2018609]
- gve: Move some static functions to a common file (Jordan Kimbrough) [2018609]
- gve: Correct SKB queue index validation. (Jordan Kimbrough) [2018609]
- gve: Upgrade memory barrier in poll routine (Jordan Kimbrough) [2018609]
- gve: Add NULL pointer checks when freeing irqs. (Jordan Kimbrough) [2018609]
- gve: Update mgmt_msix_idx if num_ntfy changes (Jordan Kimbrough) [2018609]
- gve: Check TX QPL was actually assigned (Jordan Kimbrough) [2018609]
- net: gve: remove duplicated allowed (Jordan Kimbrough) [2018609]
- net: gve: convert strlcpy to strscpy (Jordan Kimbrough) [2018609]
- gve: Add support for raw addressing in the tx path (Jordan Kimbrough) [2018609]
- gve: Rx Buffer Recycling (Jordan Kimbrough) [2018609]
- gve: Add support for raw addressing to the rx path (Jordan Kimbrough) [2018609]
- gve: Add support for raw addressing device option (Jordan Kimbrough) [2018609]
- net: don't include ethtool.h from netdevice.h (Jordan Kimbrough) [2018609]
- gve: Replace zero-length array with flexible-array member (Jordan Kimbrough) [2018609]
- gve: Enable Link Speed Reporting in the driver. (Jordan Kimbrough) [2018609]
- gve: Use link status register to report link status (Jordan Kimbrough) [2018609]
- gve: Batch AQ commands for creating and destroying queues. (Jordan Kimbrough) [2018609]
- gve: NIC stats for report-stats and for ethtool (Jordan Kimbrough) [2018609]
- gve: Add Gvnic stats AQ command and ethtool show/set-priv-flags. (Jordan Kimbrough) [2018609]
- gve: Use dev_info/err instead of netif_info/err. (Jordan Kimbrough) [2018609]
- gve: Add stats for gve. (Jordan Kimbrough) [2018609]
- gve: Get and set Rx copybreak via ethtool (Jordan Kimbrough) [2018609]
- redhat: update ppc64le secureboot signing key (Jarod Wilson) [2109215]
- tools: add cpupower daemon reload when installed/upgraded (Jarod Wilson) [2042424]
- sfc: fix use after free when disabling sriov (Íñigo Huguet) [2105999]
- drm/nouveau: recognise GA103 (Karol Herbst) [1923125]
- drm/aperture: Run fbdev removal before internal helpers (Michel Dänzer) [2088410]
- drm/i915/ttm: fix 32b build (Michel Dänzer) [2088410]
- drm/amd/display: Ensure valid event timestamp for cursor-only commits (Michel Dänzer) [2088410]
- drm/amd/pm: Prevent divide by zero (Michel Dänzer) [2088410]
- drm/amd/display: Only use depth 36 bpp linebuffers on DCN display engines. (Michel Dänzer) [2088410]
- drm/amdkfd: correct the MEC atomic support firmware checking for GC 10.3.7 (Michel Dänzer) [2088410]
- drm/i915/selftests: fix subtraction overflow bug (Michel Dänzer) [2088410]
- drm/i915/gt: Serialize TLB invalidates with GT resets (Michel Dänzer) [2088410]
- drm/i915/gt: Serialize GRDOM access between multiple engine resets (Michel Dänzer) [2088410]
- drm/i915/ttm: fix sg_table construction (Michel Dänzer) [2088410]
- drm/i915/selftests: fix a couple IS_ERR() vs NULL tests (Michel Dänzer) [2088410]
- drm/i915/gvt: IS_ERR() vs NULL bug in intel_gvt_update_reg_whitelist() (Michel Dänzer) [2088410]
- drm/i915/guc: ADL-N should use the same GuC FW as ADL-S (Michel Dänzer) [2088410]
- drm/i915: fix a possible refcount leak in intel_dp_add_mst_connector() (Michel Dänzer) [2088410]
- drm/amdgpu/display: disable prefer_shadow for generic fb helpers (Michel Dänzer) [2088410]
- drm/amdgpu: keep fbdev buffers pinned during suspend (Michel Dänzer) [2088410]
- drm/fourcc: fix integer type usage in uapi header (Michel Dänzer) [2088410]
- drm/i915/dgfx: Disable d3cold at gfx root port (Michel Dänzer) [2088410]
- drm/i915/gem: add missing else (Michel Dänzer) [2088410]
- drm/amdgpu: To flush tlb for MMHUB of RAVEN series (Michel Dänzer) [2088410]
- Revert "drm/amdgpu/display: set vblank_disable_immediate for DC" (Michel Dänzer) [2088410]
- drm/amdgpu: fix adev variable used in amdgpu_device_gpu_recover() (Michel Dänzer) [2088410]
- drm/amd: Revert "drm/amd/display: keep eDP Vdd on when eDP stream is already enabled" (Michel Dänzer) [2088410]
- udmabuf: add back sanity check (Michel Dänzer) [2088410]
- drm/amd/display: Fix typo in override_lane_settings (Michel Dänzer) [2088410]
- amd/display/dc: Fix COLOR_ENCODING and COLOR_RANGE doing nothing for DCN20+ (Michel Dänzer) [2088410]
- drm/i915: Implement w/a 22010492432 for adl-s (Michel Dänzer) [2088410]
- drm/i915/uc: remove accidental static from a local variable (Michel Dänzer) [2088410]
- drm/amd/display: Cap OLED brightness per max frame-average luminance (Michel Dänzer) [2088410]
- drm/amdgpu: Fix GTT size reporting in amdgpu_ioctl (Michel Dänzer) [2088410]
- drm/i915/reset: Fix error_state_read ptr + offset use (Michel Dänzer) [2088410]
- drm/amdkfd: add pinned BOs to kfd_bo_list (Michel Dänzer) [2088410]
- drm/amdkfd: Use mmget_not_zero in MMU notifier (Michel Dänzer) [2088410]
- drm/amdgpu: Resolve RAS GFX error count issue after cold boot on Arcturus (Michel Dänzer) [2088410]
- drm/amd/display: Read Golden Settings Table from VBIOS (Michel Dänzer) [2088410]
- Revert "drm/amd/display: Fix DCN3 B0 DP Alt Mapping" (Michel Dänzer) [2088410]
- drm/amdgpu: update VCN codec support for Yellow Carp (Michel Dänzer) [2088410]
- drm/amd/display: remove stale config guards (Michel Dänzer) [2088410]
- drm/amdgpu/jpeg2: Add jpeg vmid update under IB submit (Michel Dänzer) [2088410]
- drm/atomic: Force bridge self-refresh-exit on CRTC switch (Michel Dänzer) [2088410]
- drm/bridge: analogix_dp: Support PSR-exit to disable transition (Michel Dänzer) [2088410]
- drm/amdkfd:Fix fw version for 10.3.6 (Michel Dänzer) [2088410]
- drm/amd/pm: use bitmap_{from,to}_arr32 where appropriate (Michel Dänzer) [2088410]
- drm/amd/pm: correct the metrics version for SMU 11.0.11/12/13 (Michel Dänzer) [2088410]
- drm/amd/pm: Fix missing thermal throttler status (Michel Dänzer) [2088410]
- drm/amd/pm: fix a potential gpu_metrics_table memory leak (Michel Dänzer) [2088410]
- drm/radeon: fix a possible null pointer dereference (Michel Dänzer) [2088410]
- drm/amd/display: Check zero planes for OTG disable W/A on clock change (Michel Dänzer) [2088410]
- drm/amd/display: Check if modulo is 0 before dividing. (Michel Dänzer) [2088410]
- drm/amdgpu: fix limiting AV1 to the first instance on VCN3 (Michel Dänzer) [2088410]
- drm/bridge: ti-sn65dsi83: Handle dsi_lanes == 0 as invalid (Michel Dänzer) [2088410]
- drm/amdgpu: Off by one in dm_dmub_outbox1_low_irq() (Michel Dänzer) [2088410]
- gma500: fix an incorrect NULL check on list iterator (Michel Dänzer) [2088410]
- drm/i915/dsi: fix VBT send packet port selection for ICL+ (Michel Dänzer) [2088410]
- drm/bridge: analogix_dp: Grab runtime PM reference for DP-AUX (Michel Dänzer) [2088410]
- drm/nouveau/kms/nv50-: atom: fix an incorrect NULL check on list iterator (Michel Dänzer) [2088410]
- drm/nouveau/clk: Fix an incorrect NULL check on list iterator (Michel Dänzer) [2088410]
- drm/nouveau/subdev/bus: Ratelimit logging for fault errors (Michel Dänzer) [2088410]
- drm/amdgpu/cs: make commands with 0 chunks illegal behaviour. (Michel Dänzer) [2088410]
- drm/amdgpu: add beige goby PCI ID (Michel Dänzer) [2088410]
- drm/i915: Fix CFI violation with show_dynamic_id() (Michel Dänzer) [2088410]
- drm/bridge: it6505: Send DPCD SET_POWER to downstream (Michel Dänzer) [2088410]
- drm/panel: panel-simple: Fix proper bpc for AM-1280800N3TZQW-T00H (Michel Dänzer) [2088410]
- drm/panel: simple: Add missing bus flags for Innolux G070Y2-L01 (Michel Dänzer) [2088410]
- drm/bridge: Fix it6505 Kconfig DRM_DP_AUX_BUS dependency (Michel Dänzer) [2088410]
- drm/bridge: Fix error handling in analogix_dp_probe (Michel Dänzer) [2088410]
- drm/bridge: anx7625: Use uint8 for lane-swing arrays (Michel Dänzer) [2088410]
- drm/amd/amdgpu: Remove static from variable in RLCG Reg RW (Michel Dänzer) [2088410]
- drm/amd/amdgpu: Fix asm/hypervisor.h build error. (Michel Dänzer) [2088410]
- drm/amd/amdgpu: Only reserve vram for firmware with vega9 MS_HYPERV host. (Michel Dänzer) [2088410]
- drm: bridge: icn6211: Fix HFP_HSW_HBP_HI and HFP_MIN handling (Michel Dänzer) [2088410]
- drm: bridge: icn6211: Fix register layout (Michel Dänzer) [2088410]
- drm/bridge: adv7511: clean up CEC adapter when probe fails (Michel Dänzer) [2088410]
- drm/bridge: anx7625: add missing destroy_workqueue() in anx7625_i2c_probe() (Michel Dänzer) [2088410]
- drm/edid: fix invalid EDID extension block filtering (Michel Dänzer) [2088410]
- drm/bridge: it6505: Fix build error (Michel Dänzer) [2088410]
- drm: bridge: it66121: Fix the register page length (Michel Dänzer) [2088410]
- drm/vmwgfx: Fix an invalid read (Michel Dänzer) [2088410]
- drm/ssd130x: Reduce temporary buffer sizes (Michel Dänzer) [2088410]
- drm/ssd130x: Fix rectangle updates (Michel Dänzer) [2088410]
- drm/format-helper: Fix XRGB888 to monochrome conversion (Michel Dänzer) [2088410]
- drm/format-helper: Rename drm_fb_xrgb8888_to_mono_reversed() (Michel Dänzer) [2088410]
- drm/solomon: Make DRM_SSD130X depends on MMU (Michel Dänzer) [2088410]
- drm: ssd130x: Always apply segment remap setting (Michel Dänzer) [2088410]
- drm: ssd130x: Fix COM scan direction register mask (Michel Dänzer) [2088410]
- drm/bridge: anx7625: check the return on anx7625_aux_trans (Michel Dänzer) [2088410]
- drm/selftests: missing error code in igt_buddy_alloc_smoke() (Michel Dänzer) [2088410]
- drm/bridge_connector: enable HPD by default if supported (Michel Dänzer) [2088410]
- drm: fix EDID struct for old ARM OABI format (Michel Dänzer) [2088410]
- drm/amdgpu: Move mutex_init(&smu->message_lock) to smu_early_init() (Michel Dänzer) [2088410]
- drm/amd/pm: update smartshift powerboost calc for smu13 (Michel Dänzer) [2088410]
- drm/amd/pm: update smartshift powerboost calc for smu12 (Michel Dänzer) [2088410]
- drm/amdgpu/ucode: Remove firmware load type check in amdgpu_ucode_free_bo (Michel Dänzer) [2088410]
- drm/amdgpu/psp: move PSP memory alloc from hw_init to sw_init (Michel Dänzer) [2088410]
- drm/amd/pm: fix the compile warning (Michel Dänzer) [2088410]
- drm/amdkfd: Fix circular lock dependency warning (Michel Dänzer) [2088410]
- drm/plane: Move range check for format_count earlier (Michel Dänzer) [2088410]
- drm/amdgpu/sdma: Fix incorrect calculations of the wptr of the doorbells (Michel Dänzer) [2088410]
- drm/amd/pm: fix double free in si_parse_power_table() (Michel Dänzer) [2088410]
- drm/amdgpu/pm: fix the null pointer while the smu is disabled (Michel Dänzer) [2088410]
- drm/amd/display: Disabling Z10 on DCN31 (Michel Dänzer) [2088410]
- drm/virtio: fix NULL pointer dereference in virtio_gpu_conn_get_modes (Michel Dänzer) [2088410]
- drm/vmwgfx: validate the screen formats (Michel Dänzer) [2088410]
- drm/selftests: fix a shift-out-of-bounds bug (Michel Dänzer) [2088410]
- drm/i915: Fix -Wstringop-overflow warning in call to intel_read_wm_latency() (Michel Dänzer) [2088410]
- selftests/xsk: Disable hanging BPF RES tests (Felix Maurer) [2116940]
- NLM: Defend against file_lock changes after vfs_test_lock() (Benjamin Coddington) [2094884]
- ice: Fix VF not able to send tagged traffic with no VLAN filters (Petr Oros) [2055446]
- ice: Ignore error message when setting same promiscuous mode (Petr Oros) [2100683]
- ice: Fix clearing of promisc mode with bridge over bond (Petr Oros) [2100683]
- ice: Ignore EEXIST when setting promisc mode (Petr Oros) [2100683]
- ice: Fix double VLAN error when entering promisc mode (Petr Oros) [2100683]

* Fri Aug 19 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-420.el8]
- fs: dlm: fix build with CONFIG_IPV6 disabled (Alexander Aring) [2036988]
- fs: dlm: don't call kernel_getpeername() in error_report() (Alexander Aring) [2036988]
- fs: dlm: use sk->sk_socket instead of con->sock (Alexander Aring) [2036988]
- x86: intel_epb: Allow model specific normal EPB value (Prarit Bhargava) [2101488]
- x86: intel_epb: Do not build when CONFIG_PM is unset (Prarit Bhargava) [2101488]
- x86: intel_epb: Take CONFIG_PM into account (Prarit Bhargava) [2101488]
- PM / arch: x86: MSR_IA32_ENERGY_PERF_BIAS sysfs interface (Prarit Bhargava) [2101488]
- PM / arch: x86: Rework the MSR_IA32_ENERGY_PERF_BIAS handling (Prarit Bhargava) [2101488]
- thermal: int340x: Add Raptor Lake PCI device id (Prarit Bhargava) [2064828]
- thermal: int340x: Support Raptor Lake (Prarit Bhargava) [2064828]
- nvme-fc: restart admin queue if the caller needs to restart queue (Ewan D. Milne) [2095693]
- netfilter: nf_tables: replace BUG_ON by element length check (Florian Westphal) [2104497]
- netfilter: nf_log: incorrect offset to network header (Florian Westphal) [2104497]
- netfilter: nft_set_pipapo: release elements in clone from abort path (Florian Westphal) [2104497]
- netfilter: nf_tables: stricter validation of element data (Florian Westphal) [2104497]
- netfilter: nft_dynset: restore set element counter when failing to update (Florian Westphal) [2104497]
- netfilter: use get_random_u32 instead of prandom (Florian Westphal) [2104497]
- netfilter: nf_tables: memleak flow rule from commit path (Florian Westphal) [2104497]
- netfilter: nf_tables: hold mutex on netns pre_exit path (Florian Westphal) [2104497]
- netfilter: conntrack: re-fetch conntrack after insertion (Florian Westphal) [2104497]
- netfilter: flowtable: fix excessive hw offload attempts after failure (Florian Westphal) [2104497]
- netfilter: flowtable: avoid possible false sharing (Florian Westphal) [2104497]
- netfilter: nf_nat_h323: eliminate anonymous module_init & module_exit (Florian Westphal) [2104497]
- netfilter: ip6t_rt: fix rt0_hdr parsing in rt_mt6 (Florian Westphal) [2104497]
- netfilter: socket: icmp6: fix use-after-scope (Florian Westphal) [2104497]
- netfilter: nft_fib_ipv6: skip ipv6 packets from any to link-local (Florian Westphal) [2104497]
- net/mlx5: Remove ConnectX-7 device from the unsupported devices (Kamal Heib) [1899567]
- fs: dlm: change posix lock sigint handling (Alexander Aring) [2088499]
- fs: dlm: use dlm_plock_info for do_unlock_close (Alexander Aring) [2088499]
- fs: dlm: change plock interrupted message to debug again (Alexander Aring) [2088499]
- fs: dlm: add pid to debug log (Alexander Aring) [2088499]
- fs: dlm: plock use list_first_entry (Alexander Aring) [2088499]
- dlm: replace usage of found with dedicated list iterator variable (Alexander Aring) [2088499]
- dlm: move global to static inits (Alexander Aring) [2088499]
- dlm: remove unnecessary INIT_LIST_HEAD() (Alexander Aring) [2088499]
- dlm: improve plock logging if interrupted (Alexander Aring) [2088499]
- dlm: rearrange async condition return (Alexander Aring) [2088499]
- dlm: cleanup plock_op vs plock_xop (Alexander Aring) [2088499]
- dlm: replace sanity checks with WARN_ON (Alexander Aring) [2088499]

* Fri Aug 19 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-419.el8]
- selftests: mptcp: make sendfile selftest work (Florian Westphal) [2109046]
- selftests: mptcp: more stable simult_flows tests (Florian Westphal) [2109046]
- be2net: Remove useless DMA-32 fallback configuration (Petr Oros) [2051324]
- ethernet: constify references to netdev->dev_addr in drivers (Petr Oros) [2051324]
- ethernet: Remove redundant 'flush_workqueue()' calls (Petr Oros) [2051324]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Petr Oros) [2051324]
- ethernet: use eth_hw_addr_set() (Petr Oros) [2051324]
- be2net: Use irq_update_affinity_hint() (Petr Oros) [2051324]
- RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default (Jaroslav Kysela) [2114931]
- ASoC: SOF: make ctx_store and ctx_restore as optional (Jaroslav Kysela) [2114931]
- ASoC: SOF: ipc3-topology: Prevent double freeing of ipc_control_data via load_bytes (Jaroslav Kysela) [2114931]
- ASoC: amd: yc: Update DMI table entries for AMD platforms (Jaroslav Kysela) [2114931]
- ASoC: amd: yc: Update DMI table entries (Jaroslav Kysela) [2114931]
- thunderbolt: Add DP OUT resource when DP tunnel is discovered (Torez Smith) [2107601]
- iavf: Fix VLAN_V2 addition/rejection (Petr Oros) [2115618]
- iavf: Fix deadlock in initialization (Petr Oros) [2054656]
- qede: Reduce verbosity of ptp tx timestamp (Manish Chopra) [2080655]
- dmaengine: idxd: Fixup merge conflict resolution from upstream (Jerry Snitselaar) [2100927]
- dmaengine: idxd: skip clearing device context when device is read-only (Jerry Snitselaar) [2100927]
- dmaengine: idxd: add RO check for wq max_transfer_size write (Jerry Snitselaar) [2100927]
- dmaengine: idxd: add RO check for wq max_batch_size write (Jerry Snitselaar) [2100927]
- dmaengine: idxd: fix device cleanup on disable (Jerry Snitselaar) [2100927]
- Revert "dmaengine: idxd: Separate user and kernel pasid enabling" (Jerry Snitselaar) [2100927]
- net: atlantic: always deep reset on pm op, fixing up my null deref regression (Foggy Liu) [2039680]
- net: atlantic: invert deep par in pm functions, preventing null derefs (Foggy Liu) [2039680]
- s390/ap: extend AP change bindings-complete uevent with counter (Mete Durlu) [2114907]
- powerpc/memhotplug: Make lmb size 64bit (Diego Domingos) [2116517]
- powerpc/drmem: Make lmb_size 64 bit (Diego Domingos) [2116517]
- RHEL-only: tools: arm64: Use alternative.h header in sysreg.h (Eric Auger) [2118527]

* Mon Aug 15 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-418.el8]
- vmxnet3: do not reschedule napi for rx processing (Kamal Heib) [2117263]
- lockdown: also lock down previous kgdb use (Lenny Szubowicz) [2104748] {CVE-2022-21499}
- sfc: fix kernel panic when creating VF (Íñigo Huguet) [2114738]
- net/mlx4_en: use kzalloc (Amir Tzin) [2049433]
- net/mlx4: Delete useless moduleparam include (Amir Tzin) [2049433]
- RDMA/mlx4: remove redundant assignment to variable nreq (Amir Tzin) [2049433]
- RDMA/mlx4: Delete useless module.h include (Amir Tzin) [2049433]
- RDMA/mlx4: Don't continue event handler after memory allocation failure (Amir Tzin) [2049433]
- net/mlx4: Use irq_update_affinity_hint() (Amir Tzin) [2049433]
- RDMA/mlx4: Use bitmap_alloc() when applicable (Amir Tzin) [2049433]
- net/mlx4_en: Update reported link modes for 1/10G (Amir Tzin) [2049433]
- ethernet: Remove redundant 'flush_workqueue()' calls (Amir Tzin) [2049433]
- mlx4: constify args for const dev_addr (Amir Tzin) [2049433]
- mlx4: remove custom dev_addr clearing (Amir Tzin) [2049433]
- mlx4: replace mlx4_u64_to_mac() with u64_to_ether_addr() (Amir Tzin) [2049433]
- mlx4: replace mlx4_mac_to_u64() with ether_addr_to_u64() (Amir Tzin) [2049433]
- net/mlx4_en: avoid one cache line miss to ring doorbell (Amir Tzin) [2049433]
- net/mlx4_en: Add XDP_REDIRECT statistics (Amir Tzin) [2049433]
- net/mlx4: Use array_size() helper in copy_to_user() (Amir Tzin) [2049433]
- net: mlx4: Add support for XDP_REDIRECT (Amir Tzin) [2049433]
- net/mellanox: switch from 'pci_' to 'dma_' API (Amir Tzin) [2049433]
- net/mlx4: Use ARRAY_SIZE to get an array's size (Amir Tzin) [2049433]
- net/mlx4: make the array states static const, makes object smaller (Amir Tzin) [2049433]
- dma-direct: use the correct size for dma_set_encrypted() (Jerry Snitselaar) [2105608]
- dma-debug: make things less spammy under memory pressure (Jerry Snitselaar) [2105608]
- dma-iommu: Check that swiotlb is active before trying to use it (Jerry Snitselaar) [2105608]
- cpufreq: powernow-k8: Re-order the init checks (Mark Langsdorf) [2072974]
- cpufreq: unify show() and store() naming and use __ATTR_XX (Mark Langsdorf) [2072974]
- cpufreq: amd-pstate: Add more tracepoint for AMD P-State module (Mark Langsdorf) [2072974]
- cpufreq: CPPC: Fix performance/frequency conversion (Mark Langsdorf) [2072974]
- cpufreq: Move to_gov_attr_set() to cpufreq.h (Mark Langsdorf) [2072974]
- cpufreq: use default_groups in kobj_type (Mark Langsdorf) [2072974]
- cpufreq: Fix initialization of min and max frequency QoS requests (Mark Langsdorf) [2072974]
- cpufreq: Fix a comment in cpufreq_policy_free (Mark Langsdorf) [2072974]
- cpufreq: Fix get_cpu_device() failure in add_cpu_dev_symlink() (Mark Langsdorf) [2072974]
- cpufreq: schedutil: Destroy mutex before kobject_put() frees the memory (Mark Langsdorf) [2072974]
- cpufreq: sh: Remove sh_cpufreq_cpu_ready() (Mark Langsdorf) [2072974]
- cpufreq: acpi: Remove acpi_cpufreq_cpu_ready() (Mark Langsdorf) [2072974]
- cpufreq: Fix fall-through warning for Clang (Mark Langsdorf) [2072974]
- cpufreq: Remove ->resolve_freq() (Mark Langsdorf) [2072974]
- cpufreq: Reuse cpufreq_driver_resolve_freq() in __cpufreq_driver_target() (Mark Langsdorf) [2072974]
- cpufreq: Remove the ->stop_cpu() driver callback (Mark Langsdorf) [2072974]
- cpufreq: powernv: Migrate to ->exit() callback instead of ->stop_cpu() (Mark Langsdorf) [2072974]
- cpufreq: Make cpufreq_online() call driver->offline() on errors (Mark Langsdorf) [2072974]
- cpufreq: sh: Remove unused linux/sched.h headers (Mark Langsdorf) [2072974]
- cpufreq: stats: Clean up local variable in cpufreq_stats_create_table() (Mark Langsdorf) [2072974]
- cpufreq: Remove unused for_each_policy macro (Mark Langsdorf) [2072974]
- cpufreq: Rudimentary typos fix in the file s5pv210-cpufreq.c (Mark Langsdorf) [2072974]
- ACPI: CPPC: Fix enabling CPPC on AMD systems with shared memory (Mark Langsdorf) [2067296]
- ACPI: CPPC: Don't require flexible address space if X86_FEATURE_CPPC is supported (Mark Langsdorf) [2067296]
- ACPI: CPPC: Don't require _OSC if X86_FEATURE_CPPC is supported (Mark Langsdorf) [2067296]
- x86/ACPI: CPPC: Rename cppc_msr.c to cppc.c (Mark Langsdorf) [2067296]
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked (Mark Langsdorf) [2067296]
- ACPI: CPPC: Assume no transition latency if no PCCT (Mark Langsdorf) [2067296]
- ACPI: bus: Set CPPC _OSC bits for all and when CPPC_LIB is supported (Mark Langsdorf) [2067296]
- ACPI: CPPC: Check _OSC for flexible address space (Mark Langsdorf) [2067296]
- ACPI: processor: idle: Avoid falling back to C3 type C-states (Mark Langsdorf) [2067296]
- Revert "ACPI: processor: idle: Only flush cache on entering C3" (Mark Langsdorf) [2067296]
- ACPI: CPPC: Change default error code and clean up debug messages in probe (Mark Langsdorf) [2067296]
- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data (Mark Langsdorf) [2067296]
- ACPI: tables: Make LAPIC_ADDR_OVR address readable in message (Mark Langsdorf) [2067296]
- ACPI: IPMI: replace usage of found with dedicated list iterator variable (Mark Langsdorf) [2067296]
- ACPI, APEI: Use the correct variable for sizeof() (Mark Langsdorf) [2067296]
- clocksource: acpi_pm: fix return value of __setup handler (Mark Langsdorf) [2067296]
- ACPI / x86: Add support for LPS0 callback handler (Mark Langsdorf) [2067296]
- ACPI: bus: Avoid using CPPC if not supported by firmware (Mark Langsdorf) [2067296]
- Revert "ACPI: Pass the same capabilities to the _OSC regardless of the query flag" (Mark Langsdorf) [2067296]
- ACPI: video: Force backlight native for Clevo NL5xRU and NL5xNU (Mark Langsdorf) [2067296]
- PM: hibernate: Honour ACPI hardware signature by default for virtual guests (Mark Langsdorf) [2067296]
- ACPI: NFIT: Remove block aperture support (Mark Langsdorf) [2067296]
- x86, ACPI: rename init_freq_invariance_cppc() to arch_init_invariance_cppc() (Mark Langsdorf) [2067296]
- ACPI/APEI: Limit printable size of BERT table data (Mark Langsdorf) [2067296]
- ACPI: APEI: fix return value of __setup handlers (Mark Langsdorf) [2067296]
- ACPI / x86: Add skip i2c clients quirk for Lenovo Yoga Tablet 1050F/L (Mark Langsdorf) [2067296]
- ACPI / x86: Add skip i2c clients quirk for Nextbook Ares 8 (Mark Langsdorf) [2067296]
- ACPICA: Avoid walking the ACPI Namespace if it is not there (Mark Langsdorf) [2067296]
- ACPI: processor idle: Check for architectural support for LPI (Mark Langsdorf) [2067296]
- ACPI: battery: Add device HID and quirk for Microsoft Surface Go 3 (Mark Langsdorf) [2067296]
- ACPI: fan: Add additional attributes for fine grain control (Mark Langsdorf) [2067296]
- ACPI: fan: Properly handle fine grain control (Mark Langsdorf) [2067296]
- ACPI: fan: Optimize struct acpi_fan_fif (Mark Langsdorf) [2067296]
- ACPI: fan: Separate file for attributes creation (Mark Langsdorf) [2067296]
- ACPI: fan: Fix error reporting to user space (Mark Langsdorf) [2067296]
- ACPI: clean up double words in two comments (Mark Langsdorf) [2067296]
- ACPI: property: Get rid of redundant 'else' (Mark Langsdorf) [2067296]
- ACPI: EC: Rearrange code in acpi_ec_submit_event() (Mark Langsdorf) [2067296]
- ACPI: EC: Reduce indentation level in acpi_ec_submit_event() (Mark Langsdorf) [2067296]
- ACPI: EC: Do not return result from advance_transaction() (Mark Langsdorf) [2067296]
- ACPI: EC / PM: Print additional debug message in acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067296]
- ACPI: PM: Print additional debug message in acpi_s2idle_wake() (Mark Langsdorf) [2067296]
- ACPI: tables: Add CEDT signature to the list of known tables (Mark Langsdorf) [2067296]
- ACPI: properties: Consistently return -ENOENT if there are no more references (Mark Langsdorf) [2067296]
- ACPI: OSL: Fix and clean up acpi_os_read/write_port() (Mark Langsdorf) [2067296]
- ACPICA: Use uintptr_t and offsetof() in Linux kernel builds (Mark Langsdorf) [2067296]
- ACPI: processor: idle: Only flush cache on entering C3 (Mark Langsdorf) [2067296]
- intel_idle: Add AlderLake support (Lenny Szubowicz) [2075709]
- intel_idle: Fix SPR C6 optimization (Lenny Szubowicz) [2075709]
- intel_idle: Fix the 'preferred_cstates' module parameter (Lenny Szubowicz) [2075709]
- cpuidle: intel_idle: Update intel_idle() kerneldoc comment (Lenny Szubowicz) [2075709]
- ice: Fix promiscuous mode not turning off (Petr Oros) [2088787]
- ice: Introduce enabling promiscuous mode on multiple VF's (Petr Oros) [2088787]
- PCI/IOV: Add pci_iov_get_pf_drvdata() to allow VF reaching the drvdata of a PF (Myron Stowe) [2106259]
- PCI/IOV: Add pci_iov_vf_id() to get VF index (Myron Stowe) [2106259]
- redhat: enable CONFIG_MAXLINEAR_GPHY as module (Petr Oros) [2071856]
- net: phy: enhance GPY115 loopback disable function (Petr Oros) [2071856]
- net: phy: add Maxlinear GPY115/21x/24x driver (Petr Oros) [2071856]
- cgroup: Use css_tryget() instead of css_tryget_online() in task_get_css() (Vratislav Bendel) [2111491]
- ASoC: mediatek: Fix error handling in mt8173_max98090_dev_probe (Jaroslav Kysela) [2065580]
- ASoC: amd: Add support for enabling DMIC on acp6x via _DSD (Jaroslav Kysela) [2065580]
- soundwire: intel: prevent pm_runtime resume prior to system suspend (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (fw v1.0.0) (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Add quirks for MacroSilicon MS2100/MS2106 devices (Jaroslav Kysela) [2065580]
- ASoC: cs35l41: Add ASP TX3/4 source to register patch (Jaroslav Kysela) [2065580]
- ASoC: dapm: Initialise kcontrol data for mux/demux controls (Jaroslav Kysela) [2065580]
- ASoC: rt711-sdca: fix kernel NULL pointer dereference when IO error (Jaroslav Kysela) [2065580]
- ASoC: cs35l41: Correct some control names (Jaroslav Kysela) [2065580]
- ASoC: wm5110: Fix DRE control (Jaroslav Kysela) [2065580]
- ASoC: wm_adsp: Fix event for preloader (Jaroslav Kysela) [2065580]
- ASoC: Intel: bytcr_wm5102: Fix GPIO related probe-ordering problem (Jaroslav Kysela) [2065580]
- ASoC: SOF: Intel: hda-loader: Clarify the cl_dsp_init() flow (Jaroslav Kysela) [2065580]
- ASoC: SOF: Intel: hda-loader: Make sure that the fw load sequence is followed (Jaroslav Kysela) [2065580]
- ASoC: SOF: Intel: hda-dsp: Expose hda_dsp_core_power_up() (Jaroslav Kysela) [2065580]
- ASoC: codecs: rt700/rt711/rt711-sdca: initialize workqueues in probe (Jaroslav Kysela) [2065580]
- ASoC: rt7*-sdw: harden jack_detect_handler (Jaroslav Kysela) [2065580]
- ASoC: rt711: fix calibrate mutex initialization (Jaroslav Kysela) [2065580]
- ASoC: Intel: sof_sdw: handle errors on card registration (Jaroslav Kysela) [2065580]
- ASoC: rt711-sdca-sdw: fix calibrate mutex initialization (Jaroslav Kysela) [2065580]
- ASoC: Realtek/Maxim SoundWire codecs: disable pm_runtime on remove (Jaroslav Kysela) [2065580]
- ASoC: ops: Fix off by one in range control validation (Jaroslav Kysela) [2065580]
- ASoC: Intel: Skylake: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2065580]
- ASoC: Intel: Skylake: Correct the ssp rate discovery in skl_get_ssp_clks() (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc221 (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Fix headset mic for Acer SF313-51 (Jaroslav Kysela) [2065580]
- ALSA: hda/conexant: Apply quirk for another HP ProDesk 600 G3 model (Jaroslav Kysela) [2065580]
- ALSA: hda - Add fixup for Dell Latitidue E5430 (Jaroslav Kysela) [2065580]
- ASoC: SOF: Intel: hda: Fix compressed stream position tracking (Jaroslav Kysela) [2065580]
- ASoC: SOF: ipc3-topology: Move and correct size checks in sof_ipc3_control_load_bytes() (Jaroslav Kysela) [2065580]
- ASoC: codecs: rt700/rt711/rt711-sdca: resume bus/codec in .set_jack_detect (Jaroslav Kysela) [2065580]
- ASoC: rt711-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065580]
- ASoC: rt711: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065580]
- ALSA: cs46xx: Fix missing snd_card_free() call at probe error (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Add quirk for Clevo L140PU (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Workarounds for Behringer UMC 204/404 HD (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Add quirk for Clevo PD70PNT (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Apply fixup for Lenovo Yoga Duet 7 properly (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - ALC897 headset MIC no sound (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Add mute LED quirk for HP Omen laptop (Jaroslav Kysela) [2065580]
- ALSA: hda/conexant: Fix missing beep setup (Jaroslav Kysela) [2065580]
- ALSA: hda: Fix discovery of i915 graphics PCI device (Jaroslav Kysela) [2065580]
- ALSA: hda/via: Fix missing beep setup (Jaroslav Kysela) [2065580]
- ALSA: memalloc: Drop x86-specific hack for WC allocations (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - Add HW8326 support (Jaroslav Kysela) [2065580]
- ALSA: hda: MTL: add HD Audio PCI ID and HDMI codec vendor ID (Jaroslav Kysela) [2065580]
- ASoC: es8328: Fix event generation for deemphasis control (Jaroslav Kysela) [2065580]
- ASoC: cs42l51: Correct minimum value for SX volume control (Jaroslav Kysela) [2065580]
- ASoC: cs42l56: Correct typo in minimum level for SX volume controls (Jaroslav Kysela) [2065580]
- ASoC: cs42l52: Correct TLV for Bypass Volume (Jaroslav Kysela) [2065580]
- ASoC: cs53l30: Correct number of volume levels on SX controls (Jaroslav Kysela) [2065580]
- ASoC: cs35l36: Update digital volume TLV (Jaroslav Kysela) [2065580]
- ASoC: cs42l52: Fix TLV scales for mixer controls (Jaroslav Kysela) [2065580]
- ASoC: Intel: cirrus-common: fix incorrect channel mapping (Jaroslav Kysela) [2065580]
- ASoC: nau8822: Add operation for internal PLL off and on (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Add quirk for HP Dev One (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo Yoga DuetITL 2021 (Jaroslav Kysela) [2065580]
- ALSA: hda/conexant - Fix loopback issue with CX20632 (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Set up (implicit) sync for Saffire 6 (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Skip generic sync EP parse for secondary EP (Jaroslav Kysela) [2065580]
- ASoC: rt5640: Do not manipulate pin "Platform Clock" if the "Platform Clock" is not in the DAPM (Jaroslav Kysela) [2065580]
- ASoC: SOF: amd: Fixed Build error (Jaroslav Kysela) [2065580]
- ASoC: rt5514: Fix event generation for "DSP Voice Wake Up" control (Jaroslav Kysela) [2065580]
- ASoC: max98090: Move check for invalid values before casting in max98090_put_enab_tlv() (Jaroslav Kysela) [2065580]
- ALSA: pcm: Check for null pointer of pointer substream before dereferencing it (Jaroslav Kysela) [2065580]
- ASoC: SOF: ipc3-topology: Set scontrol->priv to NULL after freeing it (Jaroslav Kysela) [2065580]
- ASoC: cs35l41: Fix an out-of-bounds access in otp_packed_element_t (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Move generic implicit fb quirk entries into quirks.c (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Add quirk bits for enabling/disabling generic implicit fb (Jaroslav Kysela) [2065580]
- ASoC: amd: Add driver data to acp6x machine driver (Jaroslav Kysela) [2065580]
- ASoC: rt1015p: remove dependency on GPIOLIB (Jaroslav Kysela) [2065580]
- ASoC: max98357a: remove dependency on GPIOLIB (Jaroslav Kysela) [2065580]
- ASoC: rt5645: Fix errorenous cleanup order (Jaroslav Kysela) [2065580]
- ASoC: SOF: amd: add missing platform_device_unregister in acp_pci_rn_probe (Jaroslav Kysela) [2065580]
- ASoC: Intel: sof_ssp_amp: fix no DMIC BE Link on Chromebooks (Jaroslav Kysela) [2065580]
- ASoC: tscs454: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065580]
- ASoC: SOF: ipc3-topology: Correct get_control_data for non bytes payload (Jaroslav Kysela) [2065580]
- ASoC: dapm: Don't fold register value changes into notifications (Jaroslav Kysela) [2065580]
- ASoC: Intel: bytcr_rt5640: Add quirk for the HP Pro Tablet 408 (Jaroslav Kysela) [2065580]
- ALSA: jack: Access input_dev under mutex (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - Fix microphone noise on ASUS TUF B550M-PLUS (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15 9520 laptop (Jaroslav Kysela) [2065580]
- ALSA: hda/realtek - Add new type for ALC245 (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Optimize TEAC clock quirk (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Configure sync endpoints before data (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Add missing ep_idx in fixed EP quirks (Jaroslav Kysela) [2065580]
- ALSA: usb-audio: Workaround for clock setup on TEAC devices (Jaroslav Kysela) [2065580]
- ALSA: ctxfi: Add SB046x PCI ID (Jaroslav Kysela) [2065580]
- NFS: Fix initialisation of nfs_client cl_flags field (Scott Mayhew) [2114577]
- Documentation: Add an explanation of NFSv4 client identifiers (Dave Wysochanski) [1801326]

* Wed Aug 10 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-417.el8]
- crypto: chelsio/chcr - Remove useless MODULE_VERSION (Rahul Lakkireddy) [2105817]
- crypto: chelsio - remove unused function (Rahul Lakkireddy) [2105817]
- crypto: chelsio - Read rxchannel-id from firmware (Rahul Lakkireddy) [2105817]
- crypto: chelsio - Fix some kernel-doc issues (Rahul Lakkireddy) [2105817]
- crypto: chelsio - remove set but not used variable 'adap' (Rahul Lakkireddy) [2105817]
- dm raid: fix address sanitizer warning in raid_resume (Benjamin Marzinski) [2115118]
- dm raid: fix address sanitizer warning in raid_status (Benjamin Marzinski) [2115118]
- dm: return early from dm_pr_call() if DM device is suspended (Benjamin Marzinski) [2115118]
- dm thin: fix use-after-free crash in dm_sm_register_threshold_callback (Benjamin Marzinski) [2115118]
- dm writecache: count number of blocks discarded, not number of discard bios (Benjamin Marzinski) [2115118]
- dm writecache: count number of blocks written, not number of write bios (Benjamin Marzinski) [2115118]
- dm writecache: count number of blocks read, not number of read bios (Benjamin Marzinski) [2115118]
- dm writecache: return void from functions (Benjamin Marzinski) [2115118]
- dm kcopyd: use __GFP_HIGHMEM when allocating pages (Benjamin Marzinski) [2115118]
- dm writecache: set a default MAX_WRITEBACK_JOBS (Benjamin Marzinski) [2115118]
- dm raid: fix KASAN warning in raid5_add_disks (Benjamin Marzinski) [2115118]
- dm raid: fix KASAN warning in raid5_remove_disk (Benjamin Marzinski) [2115118]
- KVM: x86: do not report preemption if the steal time cache is stale (Vitaly Kuznetsov) [2115240]
- KVM: x86: revalidate steal time cache if MSR value changes (Vitaly Kuznetsov) [2115240]
- KVM: nVMX: Always enable TSC scaling for L2 when it was enabled for L1 (Vitaly Kuznetsov) [2115240]
- KVM: x86: Fully initialize 'struct kvm_lapic_irq' in kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2115240]
- KVM: SEV: Init target VMCBs in sev_migrate_from (Vitaly Kuznetsov) [2115240]
- KVM: SVM: fix tsc scaling cache logic (Vitaly Kuznetsov) [2115240]
- KVM: x86/mmu: Check every prev_roots in __kvm_mmu_free_obsolete_roots() (Vitaly Kuznetsov) [2115240]
- KVM: LAPIC: Drop pending LAPIC timer injection when canceling the timer (Vitaly Kuznetsov) [2115240]
- KVM: x86: avoid calling x86 emulator without a decoded instruction (Vitaly Kuznetsov) [2115240]
- KVM: SVM: Use kzalloc for sev ioctl interfaces to prevent kernel data leak (Vitaly Kuznetsov) [2115240]
- KVM: x86: avoid loading a vCPU after .vm_destroy was called (Vitaly Kuznetsov) [2115240]
- KVM: nVMX: Clear IDT vectoring on nested VM-Exit for double/triple fault (Vitaly Kuznetsov) [2115240]
- KVM: nVMX: Leave most VM-Exit info fields unmodified on failed VM-Entry (Vitaly Kuznetsov) [2115240]
- KVM: x86: Drop WARNs that assert a triple fault never "escapes" from L2 (Vitaly Kuznetsov) [2115240]
- sched/deadline: Fix BUG_ON condition for deboosted tasks (Phil Auld) [2111860]
- scsi: qla2xxx: Fix excessive I/O error messages by default (Nilesh Javali) [2100728]
- scsi: qla2xxx: Fix erroneous mailbox timeout after PCI error injection (Nilesh Javali) [2044160]
- drm/radeon: fix build rules of *_reg_safe.h (Michel Dänzer) [2006451]
- RDMA/irdma: Fix sleep from invalid context BUG (Kamal Heib) [2097318]
- RDMA/irdma: Do not advertise 1GB page size for x722 (Kamal Heib) [2097318]
- RDMA/cm: Fix memory leak in ib_cm_insert_listen (Kamal Heib) [2097318]
- RDMA/hfi1: Fix potential integer multiplication overflow errors (Kamal Heib) [2097318]
- RDMA/hfi1: Prevent use of lock before it is initialized (Kamal Heib) [2097318]
- RDMA/rxe: Fix an error handling path in rxe_get_mcg() (Kamal Heib) [2097318]
- RDMA/rxe: Generate a completion for unsupported/invalid opcode (Kamal Heib) [2097318]
- scsi: target: cxgbit: Enable Delayed ACK (Rahul Lakkireddy) [2105813]
- scsi: target: cxgbit: Increase max DataSegmentLength (Rahul Lakkireddy) [2105813]
- cxgb4: Use the bitmap API to allocate bitmaps (Rahul Lakkireddy) [2105806]
- cxgb4: Fix typo in string (Rahul Lakkireddy) [2105806]
- cxgb4/cxgb4vf: Fix typo in comments (Rahul Lakkireddy) [2105806]
- cxgb4vf: remove unexpected word "the" (Rahul Lakkireddy) [2105806]
- net: chelsio: cxgb4: Avoid potential negative array offset (Rahul Lakkireddy) [2105806]
- libcxgb: Don't accidentally set RTO_ONLINK in cxgb_find_route() (Rahul Lakkireddy) [2105806]
- cxgb4vf: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2105806]
- cxgb4: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2105806]
- cxgb4: allow reading unrecognized port module eeprom (Rahul Lakkireddy) [2105806]
- net: chelsio: cxgb4vf: Fix an error code in cxgb4vf_pci_probe() (Rahul Lakkireddy) [2105806]
- cxgb4: Use struct_group() for memcpy() region (Rahul Lakkireddy) [2105806]
- cxgb4: fix eeprom len when diagnostics not implemented (Rahul Lakkireddy) [2105806]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Rahul Lakkireddy) [2105806]
- ethernet: chelsio: use eth_hw_addr_set() (Rahul Lakkireddy) [2105806]
- net: chelsio: cxgb4vf: Make use of the helper function dev_err_probe() (Rahul Lakkireddy) [2105806]
- cxgb4: improve printing NIC information (Rahul Lakkireddy) [2105806]
- net: chelsio: switch from 'pci_' to 'dma_' API (Rahul Lakkireddy) [2105806]
- cxgb4: make the array match_all_mac static, makes object smaller (Rahul Lakkireddy) [2105806]
- cxgb4: fix IRQ free race during driver unload (Rahul Lakkireddy) [2105806]
- net: chelsio: cxgb4: use eth_zero_addr() to assign zero address (Rahul Lakkireddy) [2105806]
- cxgb4: Fix -Wunused-const-variable warning (Rahul Lakkireddy) [2105806]
- cxgb4: clip_tbl: use list_del_init instead of list_del/INIT_LIST_HEAD (Rahul Lakkireddy) [2105806]
- net: chelsio: cxgb4vf: Fix wrong function name in comments (Rahul Lakkireddy) [2105806]
- net: chelsio: cxgb4: Fix wrong function name in comments (Rahul Lakkireddy) [2105806]
- cxgb4: Remove redundant NULL check (Rahul Lakkireddy) [2105806]
- net: ethernet: chelsiofix: spelling typo of 'rewriteing' (Rahul Lakkireddy) [2105806]
- net: don't include ethtool.h from netdevice.h (Rahul Lakkireddy) [2105806]
- cxgb4vf: convert to use DEFINE_SEQ_ATTRIBUTE macro (Rahul Lakkireddy) [2105806]
- cxgb4vf: fix t4vf_eth_xmit()'s return type (Rahul Lakkireddy) [2105806]
- cxgb4vf: update kernel-doc line comments (Rahul Lakkireddy) [2105806]
- cxgb4: remove duplicate headers (Rahul Lakkireddy) [2105806]
- cxgb4/cxgb4vf: Remove superfluous void * cast in debugfs_create_file() call (Rahul Lakkireddy) [2105806]
- cxgb4: Add missing annotation for service_ofldq() (Rahul Lakkireddy) [2105806]
- net: cxgb4vf: reject unsupported coalescing params (Rahul Lakkireddy) [2105806]
- scsi: mpt3sas: Stop fw fault watchdog work item during system shutdown (Tomas Henzl) [2106413]
- drm/amd/display: Fix new dmub notification enabling in DM (Mika Penttilä) [2107632]
- Revert "crypto: chelsio - Inline single pdu only" (Rahul Lakkireddy) [2105818]
- crypto/chcr: Moving chelsio's inline ipsec functionality to /drivers/net (Rahul Lakkireddy) [2105818]
- net/xfrm: IPsec tunnel mode fix inner_ipproto setting in sec_path (Sabrina Dubroca) [2107200]
- scsi: ch: Make it possible to open a ch device multiple times again (Ewan D. Milne) [2108649]
- lpfc updates for rh8.7 14.0.0.15 (Paul Ely) [2107726]
- scsi: lpfc: Copyright updates for 14.2.0.5 patches (Paul Ely) [2107726]
- scsi: lpfc: Fix lost NVMe paths during LIF bounce stress test (Paul Ely) [2107726]
- scsi: lpfc: Fix attempted FA-PWWN usage after feature disable (Paul Ely) [2107726]
- scsi: lpfc: Fix possible memory leak when failing to issue CMF WQE (Paul Ely) [2107726]
- scsi: lpfc: Remove extra atomic_inc on cmd_pending in queuecommand after VMID (Paul Ely) [2107726]
- scsi: lpfc: Prevent buffer overflow crashes in debugfs with malformed user input (Paul Ely) [2107726]
- scsi: lpfc: Fix uninitialized cqe field in lpfc_nvme_cancel_iocb() (Paul Ely) [2107726]
- scsi: lpfc: Allow reduced polling rate for nvme_admin_async_event cmd completion (Paul Ely) [2107726]
- scsi: lpfc: Fix port stuck in bypassed state after LIP in PT2PT topology (Paul Ely) [2107726]
- scsi: lpfc: Resolve NULL ptr dereference after an ELS LOGO is aborted (Paul Ely) [2107726]
- scsi: lpfc: Correct BDE type for XMIT_SEQ64_WQE in lpfc_ct_reject_event() (Paul Ely) [2107726]
- scsi: qla2xxx: Fix imbalance vha->vref_count (Nilesh Javali) [2108964]
- scsi: smartpqi: Update version to 2.1.18-045 (Don Brace) [2101548]
- scsi: smartpqi: Update copyright to current year (Don Brace) [2101548]
- scsi: smartpqi: Add ctrl ready timeout module parameter (Don Brace) [2101548]
- scsi: smartpqi: Update deleting a LUN via sysfs (Don Brace) [2101548]
- scsi: smartpqi: Add module param to disable managed ints (Don Brace) [2101548]
- scsi: smartpqi: Fix RAID map race condition (Don Brace) [2101548]
- scsi: smartpqi: Fix DMA direction for RAID requests (Don Brace) [2101548]
- scsi: smartpqi: Stop logging spurious PQI reset failures (Don Brace) [2101548]
- scsi: smartpqi: Add PCI IDs for Lenovo controllers (Don Brace) [2101548]
- scsi: smartpqi: Add PCI ID for Adaptec SmartHBA 2100-8i (Don Brace) [2101548]
- scsi: smartpqi: Fix PCI control linkdown system hang (Don Brace) [2101548]
- scsi: smartpqi: Add driver support for multi-LUN devices (Don Brace) [2101548]
- scsi: smartpqi: Close write read holes (Don Brace) [2101548]
- scsi: smartpqi: Add PCI IDs for ramaxel controllers (Don Brace) [2101548]
- scsi: smartpqi: Add controller fw version to console log (Don Brace) [2101548]
- scsi: smartpqi: Shorten drive visibility after removal (Don Brace) [2101548]
- scsi: smartpqi: Fix typo in comment (Don Brace) [2101548]
- docs: kdump: Update the crashkernel description for arm64 (Pingfan Liu) [2093920]
- of: Support more than one crash kernel regions for kexec -s (Pingfan Liu) [2093920]
- of: kexec: Remove FDT_PROP_* definitions (Pingfan Liu) [2093920]
- arm64: kexec: Fix missing error code 'ret' warning in load_other_segments() (Pingfan Liu) [2093920]
- arm64: Use common of_kexec_alloc_and_setup_fdt() (Pingfan Liu) [2093920]
- of: Add a common kexec FDT setup function (Pingfan Liu) [2093920]
- arm64: Use ELF fields defined in 'struct kimage' (Pingfan Liu) [2093920]
- kexec: Move ELF fields to struct kimage (Pingfan Liu) [2093920]
- of: fdt: Add memory for devices by DT property "linux,usable-memory-range" (Pingfan Liu) [2093920]
- efi: apply memblock cap after memblock_add() (Pingfan Liu) [2093920]
- of: fdt: Aggregate the processing of "linux,usable-memory-range" (Pingfan Liu) [2093920]
- of/fdt: Rework early_init_dt_scan_memory() to call directly (Pingfan Liu) [2093920]
- of/fdt: Rework early_init_dt_scan_root() to call directly (Pingfan Liu) [2093920]
- of/fdt: Rework early_init_dt_scan_chosen() to call directly (Pingfan Liu) [2093920]
- of: fdt: Rename reserve_elfcorehdr() to fdt_reserve_elfcorehdr() (Pingfan Liu) [2093920]
- of: fdt: Add generic support for handling elf core headers property (Pingfan Liu) [2093920]
- arm64: kdump: Reimplement crashkernel=X (Pingfan Liu) [2093920]
- arm64: Use insert_resource() to simplify code (Pingfan Liu) [2093920]
- kdump: return -ENOENT if required cmdline option does not exist (Pingfan Liu) [2093920]

* Mon Aug 08 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-416.el8]
- sched: Add WARN_ONCE_SAFE for use during critical scheduler code. (Phil Auld) [2095898]
- printk: remove NMI tracking [partial] (Phil Auld) [2095898]
- ext4: make sure ext4_append() always allocates new block (Lukas Czerner) [2070216]
- ext4: check if directory block is within i_size (Lukas Czerner) [2070216]
- redhat: nvme/tcp mistakenly uses blk_mq_tag_to_rq(nvme_tcp_tagset(queue)) (John Meneghini) [2112036]
- RDMA/cxgb4: Set queue pair state when being queried (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Use non-atomic bitmap functions when possible (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Use bitmap_set() when applicable (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Use bitmap_zalloc() when applicable (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Use helper function to set GUIDs (Rahul Lakkireddy) [2105809]
- RDMA/iw_cxgb4: Fix refcount underflow while destroying cqs. (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Use refcount_t instead of atomic_t for reference counting (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Fix missing error code in create_qp() (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Remove useless assignments (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: add missing qpid increment (Rahul Lakkireddy) [2105809]
- RDMA/iw_cxgb4: Use DEFINE_SPINLOCK() for spinlock (Rahul Lakkireddy) [2105809]
- RDMA/cxgb4: Use sizeof() notation (Rahul Lakkireddy) [2105809]
- drm/amd/display: Ignore First MST Sideband Message Return Error (Michel Dänzer) [2089853]
- sched, cpuset: Fix dl_cpu_busy() panic due to empty cs->cpus_allowed (Waiman Long) [2115165]
- sched/deadline: Merge dl_task_can_attach() and dl_cpu_busy() (Waiman Long) [2115165]
- ibmvnic: Properly dispose of all skbs during a failover. (Steve Best) [2107560]
- redhat/configs: Enable CONFIG_AMD_HSMP for x86_64 (John Allen) [2072233]
- platform/x86: Add AMD system management interface (John Allen) [2072233]
- ice: do not setup vlan for loopback VSI (Petr Oros) [2103845]
- ice: check (DD | EOF) bits on Rx descriptor rather than (EOP | RS) (Petr Oros) [2103845]
- ice: Fix VSIs unable to share unicast MAC (Petr Oros) [2080033]
- ice: Fix max VLANs available for VF (Petr Oros) [2112298]
- ice: change devlink code to read NVM in blocks (Petr Oros) [2093904]
- ALSA: Enable more Intel and AMD x86 chipset drivers (Jaroslav Kysela) [2065575]
- ALSA: Remove module symbols namespace (Jaroslav Kysela) [2065575]
- ASoC: SOF: tokens: add token for Mediatek AFE (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Expand firmware loading search options (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Add trace caps to speaker protection FW (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Make compressed buffers optional (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Correct control read size when parsing compressed buffer (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Add support for "toggle" preloaders (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Fix overrun of unterminated control name string (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Clear core reset for cache (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Move lockdep asserts to avoid potential null pointer (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Allow creation of event controls (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Add offset to cs_dsp read/write (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Clarify some kernel doc comments (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Perform NULL check in cs_dsp_coeff_write/read_ctrl (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Add support for rev 2 coefficient files (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Print messages from bin files (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Add pre_run callback (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Add version checks on coefficient loading (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: Add lockdep asserts to interface functions (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: tidy includes in cs_dsp.c and cs_dsp.h (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Remove the wmfw_add_ctl helper function (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: wm_adsp_control_add() error: uninitialized symbol 'ret' (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: remove a repeated including (Jaroslav Kysela) [2065575]
- firmware: cs_dsp: add driver to support firmware loading on Cirrus Logic DSPs (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Separate wm_adsp specifics in cs_dsp_client_ops (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Split out struct cs_dsp from struct wm_adsp (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: move firmware loading to client (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Pass firmware names as parameters when starting DSP core (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Move check of dsp->running to better place (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Separate generic cs_dsp_coeff_ctl handling (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Move sys_config_size to wm_adsp (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Split DSP power operations into helper functions (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Separate some ASoC and generic functions (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Introduce cs_dsp logging macros (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Rename generic DSP support (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Cancel ongoing work when removing controls (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Switch to using wm_coeff_read_ctrl for compressed buffers (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Move check for control existence (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Remove use of snd_ctl_elem_type_t (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Put debugfs_remove_recursive back in (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Let soc_cleanup_component_debugfs remove debugfs (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Remove pointless string comparison (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Add CCM_CORE_RESET to Halo start core (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Correct wm_coeff_tlv_get handling (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Fix control name parsing for multi-fw (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Fix uninitialized variable warnings (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Use snd_ctl_elem_type_t for control types (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Only use __be32 for big-endian data (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: Improve handling of raw byte streams (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: remove "ctl" from list on error in wm_adsp_create_control() (Jaroslav Kysela) [2065575]
- ASoC: wm_adsp: fix error return code in wm_adsp_load() (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Add the binding include file for the HDA header support (Jaroslav Kysela) [2065575]
- ALSA: uapi: use C90 comment style instead of C99 style (Jaroslav Kysela) [2065575]
- ALSA: hda: intel-dsp-config: Add RaptorLake PCI IDs (Jaroslav Kysela) [2065575]
- ALSA: hda/i915: Fix one too many pci_dev_put() (Jaroslav Kysela) [2065575]
- ALSA: hda: intel-dsp-config: update AlderLake PCI IDs (Jaroslav Kysela) [2065575]
- ALSA: hda/i915 - skip acomp init if no matching display (Jaroslav Kysela) [2065575]
- ALSA: hda/i915 - avoid hung task timeout in i915 wait (Jaroslav Kysela) [2065575]
- ALSA: intel-dspconfig: add ES8336 support for CNL (Jaroslav Kysela) [2065575]
- ALSA: intel-dsp-config: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065575]
- ALSA: hda: intel-dsp-config: reorder the config table (Jaroslav Kysela) [2065575]
- ALSA: hda: intel-dsp-config: add JasperLake support (Jaroslav Kysela) [2065575]
- ALSA: hda: Simplify DMIC-in-NHLT check (Jaroslav Kysela) [2065575]
- ALSA: intel_hdmi: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: x86: Use standard mmap helper for Intel HDMI LPE audio (Jaroslav Kysela) [2065575]
- ALSA: intel_hdmi: Fix reference to PCM buffer address (Jaroslav Kysela) [2065575]
- ALSA: intel_hdmi: Check for error num after setting mask (Jaroslav Kysela) [2065575]
- tools include uapi: Update asound.h copy (Jaroslav Kysela) [2065575]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065575]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065575]
- ALSA: hda: Add helper macros for DSP capable devices (Jaroslav Kysela) [2065575]
- ALSA: intel-nhlt: add helper to detect SSP link mask (Jaroslav Kysela) [2065575]
- ASoC: soc-acpi: add information on I2S/TDM link mask (Jaroslav Kysela) [2065575]
- ASoC: soc-acpi: fix kernel-doc descriptor (Jaroslav Kysela) [2065575]
- ASoC: SOF: fix 32 signed bit overflow (Jaroslav Kysela) [2065575]
- ALSA: hda: Add snd_hdac_ext_bus_link_at() helper (Jaroslav Kysela) [2065575]
- ALSA: cleanup double word in comment (Jaroslav Kysela) [2065575]
- ASoC: SOF: add _D3_PERSISTENT flag to fw_ready message (Jaroslav Kysela) [2065575]
- ALSA: HDA: hdac_ext_stream: use consistent prefixes for variables (Jaroslav Kysela) [2065575]
- ipc: debug: Add shared memory heap to memory scan (Jaroslav Kysela) [2065575]
- ALSA: pcm: comment about relation between msbits hw parameter and [S|U]32 formats (Jaroslav Kysela) [2065575]
- ALSA: hda: Fill gaps in NHLT endpoint-interface (Jaroslav Kysela) [2065575]
- ASoC: SOF: IPC: Add new IPC command to free trace DMA (Jaroslav Kysela) [2065575]
- soundwire: stream: make enable/disable/deprepare idempotent (Jaroslav Kysela) [2065575]
- soundwire: stream: sdw_stream_add_ functions can be called multiple times (Jaroslav Kysela) [2065575]
- soundwire: stream: introduce sdw_slave_rt_find() helper (Jaroslav Kysela) [2065575]
- soundwire: stream: separate alloc and config within sdw_stream_add_xxx() (Jaroslav Kysela) [2065575]
- soundwire: stream: move list addition to sdw_slave_alloc_rt() (Jaroslav Kysela) [2065575]
- soundwire: stream: rename and move master/slave_rt_free routines (Jaroslav Kysela) [2065575]
- soundwire: stream: group sdw_stream_ functions (Jaroslav Kysela) [2065575]
- soundwire: stream: split sdw_alloc_slave_rt() in alloc and config (Jaroslav Kysela) [2065575]
- soundwire: stream: move sdw_alloc_slave_rt() before 'master' helpers (Jaroslav Kysela) [2065575]
- soundwire: stream: split sdw_alloc_master_rt() in alloc and config (Jaroslav Kysela) [2065575]
- soundwire: stream: simplify sdw_alloc_master_rt() (Jaroslav Kysela) [2065575]
- soundwire: stream: group sdw_port and sdw_master/slave_port functions (Jaroslav Kysela) [2065575]
- soundwire: stream: add 'slave' prefix for port range checks (Jaroslav Kysela) [2065575]
- soundwire: stream: split alloc and config in two functions (Jaroslav Kysela) [2065575]
- soundwire: stream: split port allocation and configuration loops (Jaroslav Kysela) [2065575]
- soundwire: stream: add alloc/config/free helpers for ports (Jaroslav Kysela) [2065575]
- soundwire: stream: simplify check on port range (Jaroslav Kysela) [2065575]
- soundwire: stream: add slave runtime to list earlier (Jaroslav Kysela) [2065575]
- soundwire: stream: remove unused parameter in sdw_stream_add_slave (Jaroslav Kysela) [2065575]
- soundwire: intel: fix wrong register name in intel_shim_wake (Jaroslav Kysela) [2065575]
- soundwire: bus: add dev_warn() messages to track UNATTACHED devices (Jaroslav Kysela) [2065575]
- soundwire: intel: remove PDM support (Jaroslav Kysela) [2065575]
- soundwire: intel: remove unnecessary init (Jaroslav Kysela) [2065575]
- ASoC/SoundWire: dai: expand 'stream' concept beyond SoundWire (Jaroslav Kysela) [2065575]
- soundwire: intel: improve suspend flows (Jaroslav Kysela) [2065575]
- soundwire: intel: Use auxiliary_device driver data helpers (Jaroslav Kysela) [2065575]
- soundwire: qcom: remove redundant version number read (Jaroslav Kysela) [2065575]
- ASoC: SOF: Fix NULL pointer exception in sof_pci_probe callback (Jaroslav Kysela) [2065575]
- ASoC: ops: Validate input values in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065575]
- ASoC: dmaengine: Restore NULL prepare_slave_config() callback (Jaroslav Kysela) [2065575]
- ASoC: max98090: Generate notifications on changes for custom control (Jaroslav Kysela) [2065575]
- ASoC: max98090: Reject invalid values in custom control put() (Jaroslav Kysela) [2065575]
- ASoC: rt9120: Correct the reg 0x09 size to one byte (Jaroslav Kysela) [2065575]
- ASoC: soc-ops: fix error handling (Jaroslav Kysela) [2065575]
- ASoC: da7219: Fix change notifications for tone generator frequency (Jaroslav Kysela) [2065575]
- ASoC: simple-card-utils: fix sysclk shutdown (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: Add a quirk for Huawei Matebook D15 (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: add a quirk for headset at mic1 port (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: support a separate gpio to control headphone (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: simplify speaker gpio naming (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi: correct device endpoints for max98373 (Jaroslav Kysela) [2065575]
- ASoC: codecs: wcd934x: do not switch off SIDO Buck when codec is in use (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Fix memory leak in sof_control_load() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: cleanup dailinks on widget unload (Jaroslav Kysela) [2065575]
- ASoC: rt711/5682: check if bus is active before deferred jack detection (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp on SSP2 (Jaroslav Kysela) [2065575]
- ASoC: simple-card-utils: Avoid NULL deref in asoc_simple_set_tdm() (Jaroslav Kysela) [2065575]
- ASoC: soc-core: add debugfs_prefix member to snd_soc_component_driver (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Fix a shift-out-of-bounds warning found by UBSAN (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Add one more variable in the debug log (Jaroslav Kysela) [2065575]
- ASoC: rt5682: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065575]
- ASoC: soc-dapm: fix two incorrect uses of list iterator (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: use GFP_KERNEL when the code is sleepable (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Fix memory leak of scontrol->name (Jaroslav Kysela) [2065575]
- codecs: rt5682s: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065575]
- ASoC: topology: Correct error handling in soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: Fix build error without SND_SOC_SOF_PCI_DEV (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add a new dai_get_clk topology IPC op (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Add ops for setting up and tearing down pipelines (Jaroslav Kysela) [2065575]
- ASoC: SOF: expose sof_route_setup() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add dai_link_fixup PCM op for IPC3 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add trigger PCM op for IPC3 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Define hw_params PCM op for IPC3 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce IPC3 PCM hw_free op (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: expose the sof_pcm_setup_connected_widgets() function (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce IPC-specific PCM ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add bytes_ext control IPC ops for IPC3 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add bytes_get/put control IPC ops for IPC3 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add enum_get/put control ops for IPC3 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add switch get/put IPC3 ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add volume_get/put IPC3 ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add IPC3 topology control ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce IPC ops for kcontrol IO (Jaroslav Kysela) [2065575]
- ASoC: SOF: Make sof_suspend/resume IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: Make sof_widget_setup/free IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: set up scheduler widget before all other widgets in the pipeline (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Use kmemdup() to replace kzalloc + memcpy (Jaroslav Kysela) [2065575]
- ASoC: ak4642: Use of_device_get_match_data() (Jaroslav Kysela) [2065575]
- ASoC: sti: Fix deadlock via snd_pcm_stop_xrun() call (Jaroslav Kysela) [2065575]
- ASoC: amd: Fix reference to PCM buffer address (Jaroslav Kysela) [2065575]
- ASoC: codecs: wcd934x: Add missing of_node_put() in wcd934x_codec_parse_data (Jaroslav Kysela) [2065575]
- ASoC: rt1308-sdw: get calibration params after power on (Jaroslav Kysela) [2065575]
- ASoC: msm8916-wcd-analog: Fix error handling in pm8916_wcd_analog_spmi_probe (Jaroslav Kysela) [2065575]
- ASoC: ti: Fix spelling mistake "cant" -> "can't" (Jaroslav Kysela) [2065575]
- ASoC: samsung: i2s: check the return value of kstrdup() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: remove snd_sof_complete_pipeline() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make widget binding IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make control parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make DAI widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make route setup IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make effect widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make siggen widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make asrc widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make src widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make mux/demux widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make mixer widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make pga widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make buffer widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Make scheduler widget parsing IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce IPC3 ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Add helper function for processing tuple arrays (Jaroslav Kysela) [2065575]
- ASoC: SOF: IPC: Introduce IPC ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce struct snd_sof_dai_link (Jaroslav Kysela) [2065575]
- ASoC: soc-compress: Change the check for codec_dai (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Code loading over HDA (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Code loading over CLDMA (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Implement CLDMA transfer (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: General code loading flow (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Dynamic firmware resources management (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Declare module configuration types (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Firmware resources management utilities (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Add basefw runtime-parameter requests (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Add ROM requests (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Add power management requests (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Add module management requests (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Add pipeline management requests (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Add code loading requests (Jaroslav Kysela) [2065575]
- ASoC: Intel: avs: Inter process communication (Jaroslav Kysela) [2065575]
- ASoC: Intel: Introduce AVS driver (Jaroslav Kysela) [2065575]
- ASoC: Export DAI register and widget ctor and dctor functions (Jaroslav Kysela) [2065575]
- ASoC: simple-card-utils: Don't reset clock of active DAI (Jaroslav Kysela) [2065575]
- ASoC: SOF: Remove ipc_pcm_params() ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-ipc: Add hda_set_stream_data_offset() (Jaroslav Kysela) [2065575]
- ASoC: SOF: stream-ipc: Add sof_set_stream_data_offset() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Mark snd_sof_dsp_ops.ipc_pcm_params() callback optional (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce optional callback to configure stream data offset (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: Remove sof_pcm_dsp_params() wrapper (Jaroslav Kysela) [2065575]
- ASoC: SOF: Make pcm_hw_params snd_sof_dsp_ops callback IPC neutral (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-priv: Remove stale snd_sof_ipc_stream_pcm_params() declaration (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw in ADL match table (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: add topology overwrite for Taniks (Jaroslav Kysela) [2065575]
- ASoC: SOF: trace: Use proper DMA direction for the trace data buffer (Jaroslav Kysela) [2065575]
- ASoC: SOF: compress: fix null check after dereference (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: enable DMI L1 for playback streams (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc-msg-injector: Use devm_kzalloc() for the rx_buffer (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: fix randconfig issue (Jaroslav Kysela) [2065575]
- ASoC: Intel: bytcht_es8316: move comment to the right place (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: add cfg-dmics component for UCM support (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: extend machine driver to support ES8326 codec (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: add support for JD inverted quirk (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: move comment to the right place (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: log all quirks (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: use NHLT information to set dmic and SSP (Jaroslav Kysela) [2065575]
- ASoC: Intel: Revert "ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021" (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: make gpio optional (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi: add ESSX8336 support on Cannon Lake machines (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi: quirk topology filename dynamically (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: report SSP link mask to machine driver (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: retrieve DMIC number for I2S boards (Jaroslav Kysela) [2065575]
- ASoC: SOF: move definition of snd_sof_ipc to header file (Jaroslav Kysela) [2065575]
- ASoC: SOF: make struct snd_sof_dai IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Rename arguments in sof_parse_tokens() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Rename arguments in sof_parse_token_sets() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Modify signature for token parsing functions (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add a tuples array to struct snd_sof_widget (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: make sof_route_load() IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: SOF: make struct snd_sof_widget IPC agnostic (Jaroslav Kysela) [2065575]
- ASoC: mxs: Fix error handling in mxs_sgtl5000_probe (Jaroslav Kysela) [2065575]
- ASoC: dmaengine: do not use a NULL prepare_slave_config() callback (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add missing of_node_put() in imx8m_probe (Jaroslav Kysela) [2065575]
- ASoC: rockchip: i2s: Fix missing clk_disable_unprepare() in rockchip_i2s_probe (Jaroslav Kysela) [2065575]
- ASoC: amd: acp3x: Fix signedness bug in acp3x (Jaroslav Kysela) [2065575]
- ASoC: amd: acp5x-pcm-dma: Fix signedness bug (Jaroslav Kysela) [2065575]
- ASoC: Intel: catpt: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065575]
- ASoC: SOF: change comp_dai to a pointer in struct snd_sof_dai (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: expose some get_token ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Modify the get_token op for string tokens (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Drop the size parameter from struct sof_topology_token (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: remove redundant code in sof_link_afe_load() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: remove redundant code (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-audio: removed unused function (Jaroslav Kysela) [2065575]
- ASoC: SOF: set swidget's core for scheduler widget (Jaroslav Kysela) [2065575]
- ASoC: SOF: simplify snd_sof_device_remove() (Jaroslav Kysela) [2065575]
- ASoC: SOF: remove snd_sof_pipeline_find() (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: fix signedness bug in acp5x_audio_probe() (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Remove unnecessary param (Jaroslav Kysela) [2065575]
- ASoC: rt5682s: Stabilize the combo jack detection (Jaroslav Kysela) [2065575]
- ASoC: wm8350: Handle error for wm8350_register_irq (Jaroslav Kysela) [2065575]
- ASoC: amd: pcm-dma: Fix signedness bug in acp3x_audio_probe() (Jaroslav Kysela) [2065575]
- ASoC: amd: pcm-dma: Fix signedness bug in acp_pdm_audio_probe() (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Fix signedness bug in renoir_audio_probe() (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_sdw: fix quirks for 2022 HP Spectre x360 13" (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: add GPIOLIB dependency where missed (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: remove explicit dependency on GPIOLIB when DMIC is used" (Jaroslav Kysela) [2065575]
- ASoC: fsl_sai: store full version instead of major/minor (Jaroslav Kysela) [2065575]
- ASoC: fsl_sai: simplify register poking in fsl_sai_set_bclk (Jaroslav Kysela) [2065575]
- ASoC: fsl_sai: simplify irq return value (Jaroslav Kysela) [2065575]
- ASoC: fsl_sai: Drop unnecessary defines (Jaroslav Kysela) [2065575]
- ASoC: codecs: Add Awinic AW8738 audio amplifier driver (Jaroslav Kysela) [2065575]
- ASoC: audio_graph_card2: Add support for variable slot widths (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: clarify operator precedence (Jaroslav Kysela) [2065575]
- ASoC: SOF: debug: clarify operator precedence (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Increase ACP_HW_SEM_RETRY_COUNT value (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Move group register configuration to acp-loader (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Use semaphore register to synchronize ipc's irq (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Flush cache after ATU_BASE_ADDR_GRP register update (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Do not set ipc_pcm_params ops as it is optional (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: acp-pcm: Take buffer information directly from runtime (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: pci-tgl: add RPL-S support (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Fix DSP mbox start command and global enable order (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Fix max number of TX channels (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Fix GPIO2 configuration (Jaroslav Kysela) [2065575]
- ASoC: bt-sco: fix bt-sco-pcm-wb dai widget don't connect to the endpoint (Jaroslav Kysela) [2065575]
- ASoC: hdac_hda: Avoid unexpected match when pcm_name is "Analog" (Jaroslav Kysela) [2065575]
- ASoC: soc-compress: prevent the potentially use of null pointer (Jaroslav Kysela) [2065575]
- ASoC: soc-generic-dmaengine-pcm: set period_bytes_min based on maxburst (Jaroslav Kysela) [2065575]
- ASoC: dwc-i2s: Handle errors for clk_enable (Jaroslav Kysela) [2065575]
- ASoC: amd: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065575]
- ASoC: atmel_ssc_dai: Handle errors for clk_enable (Jaroslav Kysela) [2065575]
- ASoC: mxs-saif: Handle errors for clk_enable (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi: add entries in ADL match table (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_ssp_amp: rename driver and support cs35l41 amplifier (Jaroslav Kysela) [2065575]
- ASoC: Intel: cirrus-common: support cs35l41 amplifier (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_rt1308: move rt1308 code to common module (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: create sof-realtek-common module (Jaroslav Kysela) [2065575]
- ASoC: Intel: add RT1308 I2S machine driver and HDMI-in capture via I2S support. (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: fix spelling in comments (Jaroslav Kysela) [2065575]
- ASoC: soc-acpi: remove sof_fw_filename (Jaroslav Kysela) [2065575]
- ASoC: es7241: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98927: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98926: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98925: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max9867: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max9850: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98390: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98371: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98095: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: max98088: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: uda134x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: ml26124: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: pcm512x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: pcm3168a: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: pcm186x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: pcm1681: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: pcm3060: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: ti: davinci-i2s: Add check for clk_enable() (Jaroslav Kysela) [2065575]
- ASoC: mc13783: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: isabelle: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: amd: vangogh: fix uninitialized symbol warning in machine driver (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: remove warnings and errors pointed out by checkpatch pl (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: update DAI link name (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: fix for pm resume callback sequence (Jaroslav Kysela) [2065575]
- ASoC: es8328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: inno_rk3036: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: es8316: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: wl1273: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: es7134: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: twl4030: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: uda1380: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: si476x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: amd: pcm-dma: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065575]
- ASoC: tscs454: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: tscs42xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: lm49453: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065575]
- ASoC: qcom: lpass-platform: Update warning print to control excess logging (Jaroslav Kysela) [2065575]
- ASoC: acp: check the return value of devm_kzalloc() in acp_legacy_dai_links_create() (Jaroslav Kysela) [2065575]
- ASoC: rt5663: check the return value of devm_kzalloc() in rt5663_parse_dp() (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-priv: Drop duplicate sof_compressed_ops declaration (Jaroslav Kysela) [2065575]
- ASoC: amd: Use platform_get_irq_byname() to get the interrupt (Jaroslav Kysela) [2065575]
- ASoC: SOF: Declare sof_compress_ops in sof-priv.h (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: Fix NULL ptr dereference when ENOMEM (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Add DMIC machine driver ops (Jaroslav Kysela) [2065575]
- ASoC: amd: acp-legacy: Add legacy card support for new machines (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Change card name for Guybrush Machine (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: Add compress_ops for SOF platform component driver (Jaroslav Kysela) [2065575]
- ASoC: rt5682s: Fix the wrong jack type detected (Jaroslav Kysela) [2065575]
- ASoC: Intel: soc-acpi-byt: Add new WM5102 ACPI HID (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: update acp init and deinit sequence (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: apply sample bits pcm constraint (Jaroslav Kysela) [2065575]
- ASoC: amd: vg: update platform clock control sequence (Jaroslav Kysela) [2065575]
- ASoC: nau8821: enable no_capture_mute flag (Jaroslav Kysela) [2065575]
- ASoC: amd: vangogh: refactor i2s master mode clock sequence code (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: Add topology overwrite for Felwinter (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021 (Jaroslav Kysela) [2065575]
- ASoC: intel: skylake: Set max DMA segment size (Jaroslav Kysela) [2065575]
- ASoC: SOF: hda: Set max DMA segment size (Jaroslav Kysela) [2065575]
- ASoC: SOF: core: unregister clients and machine drivers in .shutdown (Jaroslav Kysela) [2065575]
- ASoC: cs4265: Fix the duplicated control name (Jaroslav Kysela) [2065575]
- ASoC: ops: Shift tested values in snd_soc_put_volsw() by +min (Jaroslav Kysela) [2065575]
- ASoC: soc-core: skip zero num_dai component in searching dai name (Jaroslav Kysela) [2065575]
- ASoC: SOF: Makefile: Fix randconfig sof-client build when SND_SOC_SOF=y (Jaroslav Kysela) [2065575]
- ASoC: codec: wm8960: complete discharge on BIAS OFF->STANDBY (Jaroslav Kysela) [2065575]
- ASoC: wm8731: Delete empty remove() function (Jaroslav Kysela) [2065575]
- ASoC: pcm3168a: remove numeric PCM3168A_NUM_SUPPLIES (Jaroslav Kysela) [2065575]
- ASoC: pcm3168a: refactor format handling (Jaroslav Kysela) [2065575]
- ASoC: pcm3168a: refactor hw_params routine (Jaroslav Kysela) [2065575]
- ASoC: pcm3168a: cleanup unintuitive mask usage (Jaroslav Kysela) [2065575]
- ASoC: SOF: compr: Mark snd_compress_ops static (Jaroslav Kysela) [2065575]
- ASoC: Intel: bytcr_wm5102: use GFP_KERNEL (Jaroslav Kysela) [2065575]
- ASoC: SOF: Convert the generic probe support to SOF client (Jaroslav Kysela) [2065575]
- ASoC: SOF: Convert the generic IPC message injector into SOF client (Jaroslav Kysela) [2065575]
- ASoC: SOF: Convert the generic IPC flood test into SOF client (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-client: Add support for clients not managed by pm framework (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce IPC SOF client support (Jaroslav Kysela) [2065575]
- ASoC: SOF: Split up utils.c into sof-utils and iomem-utils (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc: Read and pass the whole message to handlers for IPC events (Jaroslav Kysela) [2065575]
- ASoC: SOF: Move the definition of enum sof_dsp_power_states to global header (Jaroslav Kysela) [2065575]
- ASoC: SOF: Drop unused DSP power states: D3_HOT and D3_COLD (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Remove the sysclk and sysclk_src checking (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hdac_ext_stream: consistent prefixes for variables/members (Jaroslav Kysela) [2065575]
- ASoC: fsl_sai: Enable combine mode soft (Jaroslav Kysela) [2065575]
- ASoC: SOF: compr: Add compress ops implementation (Jaroslav Kysela) [2065575]
- ASoC: SOF: dma-trace: Pass pointer to params_ext struct in trace_init() (Jaroslav Kysela) [2065575]
- ASoC: SOF: intel: hda-trace: Pass the dma buffer pointer to hda_dsp_trace_prepare (Jaroslav Kysela) [2065575]
- ASoC: zl38060: Remove spurious gpiolib select (Jaroslav Kysela) [2065575]
- ASoC: max9759: Remove spurious gpiolib select (Jaroslav Kysela) [2065575]
- ASoC: simple-amplifier: Remove spurious gpiolib select (Jaroslav Kysela) [2065575]
- ASoC: rt9120: Remove spurious gpiolib select (Jaroslav Kysela) [2065575]
- ASoC: dmic: Remove spurious gpiolib select (Jaroslav Kysela) [2065575]
- ASoC: rt5682: do not block workqueue if card is unbound (Jaroslav Kysela) [2065575]
- ASoC: rt5668: do not block workqueue if card is unbound (Jaroslav Kysela) [2065575]
- ASoC: rt5682s: do not block workqueue if card is unbound (Jaroslav Kysela) [2065575]
- ASoC: tas2770: Insert post reset delay (Jaroslav Kysela) [2065575]
- ASoC: samsung: Explicitly include gpiolib header (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Set gpio_spkr_en to None for max speaker amplifer in machine driver (Jaroslav Kysela) [2065575]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065575]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065575]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065575]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw() (Jaroslav Kysela) [2065575]
- ASoC: max98927: add missing header file (Jaroslav Kysela) [2065575]
- ASoC: ops: Check for negative values before reading them (Jaroslav Kysela) [2065575]
- ASoC: cs42l51: Improve error handling in cs42l51_remove() (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc: Do not allocate buffer for msg_data (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc: Drop header parameter from sof_ipc_tx_message_unlocked() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: cnl: Use pm_gate->hdr.cmd in cnl_compact_ipc_compress() (Jaroslav Kysela) [2065575]
- ASoC: amd: renoir: Add check for acp configuration flags (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: acp-legacy: Add DMIC dai link support for Renoir (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Add ACP init()/deinit() callback for Renoir. (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Add generic PCI driver module for ACP device (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Add PDM controller based dmic dai for Renoir (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Add generic support for PDM controller on ACP (Jaroslav Kysela) [2065575]
- ASoC: rk3399_gru_sound: Wire up DP jack detection (Jaroslav Kysela) [2065575]
- ASoC: rt5682: Fix deadlock on resume (Jaroslav Kysela) [2065575]
- ASoC: hdmi-codec: Fix OOB memory accesses (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: Move debugfs removal out of spinlock (Jaroslav Kysela) [2065575]
- ASoC: SOF: trace: Simplify count adjustment in trace_read (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: Remove link assignment limitation (Jaroslav Kysela) [2065575]
- ASoC: ops: Reject out of bounds values in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065575]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065575]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw() (Jaroslav Kysela) [2065575]
- ASoC: simple-card-utils: Add new system-clock-fixed flag (Jaroslav Kysela) [2065575]
- ASoC: simple-card-utils: Set sysclk on all components (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_rt5682: add 512FS MCLK clock configuration (Jaroslav Kysela) [2065575]
- ASoC: amd: sof-mach: Add support for RT5682S and RT1019 card (Jaroslav Kysela) [2065575]
- ASoC: soc-generic-dmaengine-pcm: separate max_buffer_size assignment (Jaroslav Kysela) [2065575]
- ASoC: samsung: remove unneeded ret variable (Jaroslav Kysela) [2065575]
- ASoC: codecs: remove redundant ret variable (Jaroslav Kysela) [2065575]
- ASoC: fsl-asoc-card: Add optional dt property for setting mclk-id (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_rt5682: Add support for platform without amplifier (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_rt5682: add support for systems without i915 audio (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: Compare sdw adr directly (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: match sdw version on link_slaves_found (Jaroslav Kysela) [2065575]
- ASoC: add support for TAS5805M digital amplifier (Jaroslav Kysela) [2065575]
- ASoC: topology: Optimize soc_tplg_dapm_graph_elems_load behavior (Jaroslav Kysela) [2065575]
- ASoC: topology: Allow TLV control to be either read or write (Jaroslav Kysela) [2065575]
- ASoC: topology: Remove superfluous error prints (Jaroslav Kysela) [2065575]
- ASoC: SOF: add flag to disable IMR restore to sof_debug (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-loader: add IMR restore support (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-loader: add SSP helper (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: use inclusive language for SSP clocks (Jaroslav Kysela) [2065575]
- ASoC: amd: acp-mach: Fix Left and Right rt1019 amp devices (Jaroslav Kysela) [2065575]
- ASoC: max9759: fix underflow in speaker_gain_control_put() (Jaroslav Kysela) [2065575]
- ASoC: cpcap: Check for NULL pointer after calling of_get_child_by_name (Jaroslav Kysela) [2065575]
- ASoC: simple-card: fix probe failure on platform component (Jaroslav Kysela) [2065575]
- ASoC: xilinx: xlnx_formatter_pcm: Make buffer bytes multiple of period bytes (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Add support for hibernate memory retention mode (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Update handling of test key registers (Jaroslav Kysela) [2065575]
- ASoC: wcd9335: Keep a RX port value for each SLIM RX mux (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: acp-mach: Change default RT1019 amp dev id (Jaroslav Kysela) [2065575]
- ASoC: topology: Fix typo (Jaroslav Kysela) [2065575]
- ASoC: fsl_asrc: refine the check of available clock divider (Jaroslav Kysela) [2065575]
- ASoC: Intel: bytcr_rt5640: Add support for external GPIO jack-detect (Jaroslav Kysela) [2065575]
- ASoC: Intel: bytcr_rt5640: Support retrieving the codec IRQ from the AMCR0F28 ACPI dev (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Add support for boards with an external jack-detect GPIO (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Allow snd_soc_component_set_jack() to override the codec IRQ (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Change jack_work to a delayed_work (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Fix possible NULL pointer deref on resume (Jaroslav Kysela) [2065575]
- ASoC: ak4375: Fix unused function error (Jaroslav Kysela) [2065575]
- ASoC: cs4265: Add a remove() function (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Correct handling of some registers in the cache (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Correct DSP power down (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Remove incorrect comment (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Add cs35l51/53 IDs (Jaroslav Kysela) [2065575]
- ASoC: fsl_mqs: fix MODULE_ALIAS (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Create shared function for boost configuration (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Create shared function for setting channels (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Create shared function for errata patches (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Move power initializations to reg_sequence (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Move cs35l41_otp_unpack to shared code (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Convert tables to shared source code (Jaroslav Kysela) [2065575]
- ASoC: samsung: idma: Check of ioremap return value (Jaroslav Kysela) [2065575]
- ASoC: cs4265: Fix part number ID error message (Jaroslav Kysela) [2065575]
- ALSA/ASoC: hda: move/rename snd_hdac_ext_stop_streams to hdac_stream.c (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Power on/off the speaker enable gpio pin based on DAPM callback. (Jaroslav Kysela) [2065575]
- ASoC: mediatek: mt8173: reduce log verbosity in probe() (Jaroslav Kysela) [2065575]
- ASoC: mediatek: mt8183: fix device_node leak (Jaroslav Kysela) [2065575]
- ASoC: mediatek: mt8173: fix device_node leak (Jaroslav Kysela) [2065575]
- ASoC: Intel/SOF: use set_stream() instead of set_tdm_slots() for HDAudio (Jaroslav Kysela) [2065575]
- ASoC/soundwire: intel: simplify callbacks for params/hw_free (Jaroslav Kysela) [2065575]
- ASOC: SOF: Intel: use snd_soc_dai_get_widget() (Jaroslav Kysela) [2065575]
- ASoC: msm8916-wcd-analog: Use separate outputs for HPH_L/HPH_R (Jaroslav Kysela) [2065575]
- ASoC: qcom: common: Parse "pin-switches" and "widgets" from DT (Jaroslav Kysela) [2065575]
- ASoC: core: Add snd_soc_of_parse_pin_switches() from simple-card-utils (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065575]
- ASoC: SOF: debug: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add clarifying comments for sof_core_debug and DSP dump flags (Jaroslav Kysela) [2065575]
- ASoC: SOF: Rename snd_sof_get_status() and add kernel log level parameter (Jaroslav Kysela) [2065575]
- ASoC: SOF: dsp_arch_ops: add kernel log level parameter for oops and stack (Jaroslav Kysela) [2065575]
- ASoC: SOF: ops: Always print DSP Panic message but use different message (Jaroslav Kysela) [2065575]
- ASoc: SOF: core: Update the FW boot state transition diagram (Jaroslav Kysela) [2065575]
- ASoC: SOF: pm: Force DSP off on suspend in BOOT_FAILED state also (Jaroslav Kysela) [2065575]
- ASoC: SOF: Set SOF_FW_BOOT_FAILED in case we have failure during boot (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc: Only allow sending of an IPC in SOF_FW_BOOT_COMPLETE state (Jaroslav Kysela) [2065575]
- ASoC: SOF: Rename 'enum snd_sof_fw_state' to 'enum sof_fw_state' (Jaroslav Kysela) [2065575]
- ASoC: SOF: Move the definition of enum snd_sof_fw_state to global header (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce new firmware state: SOF_FW_BOOT_READY_OK (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce new firmware state: SOF_FW_CRASHED (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add a 'message' parameter to snd_sof_dsp_dbg_dump() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add 'non_recoverable' parameter to snd_sof_dsp_panic() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Use sof_debug_check_flag() instead of sof_core_debug directly (Jaroslav Kysela) [2065575]
- ASoC: SOF: core: Add simple wrapper to check flags in sof_core_debug (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-loader: Avoid re-defining the HDA_FW_BOOT_ATTEMPTS (Jaroslav Kysela) [2065575]
- ASoC: SOF: ops: Use dev_warn() if the panic offsets differ (Jaroslav Kysela) [2065575]
- ASoC: codecs: ak4375: Change invert controls to a stereo switch (Jaroslav Kysela) [2065575]
- ASoC: Add AK4375 support (Jaroslav Kysela) [2065575]
- ASoC: bcm: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065575]
- ASoC: xlnx: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065575]
- ASoC: amd: acp: Remove duplicate dependency in Kconfig (Jaroslav Kysela) [2065575]
- ASoC: SOF: AMD: simplify return status handling (Jaroslav Kysela) [2065575]
- ASoC: amd: acp-config: Update sof_tplg_filename for SOF machines (Jaroslav Kysela) [2065575]
- ASoC: amd: acp-config: Enable SOF audio for Google chrome boards. (Jaroslav Kysela) [2065575]
- ASoC: sunxi: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: samsung: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: rockchip: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: qcom: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: mxs: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: img: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: generic: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: ti: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: ateml: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: tlv320aic31xx: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: ssm2305: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: simple-amplifier: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: sgtl5000: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: pcm3168a: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: max9860: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: max9759: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: es7241: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: codecs: ak4118: Use dev_err_probe() helper (Jaroslav Kysela) [2065575]
- ASoC: Intel: catpt: Streamline locals declaration for PCM-functions (Jaroslav Kysela) [2065575]
- ASoC: Intel: catpt: Reduce size of catpt_component_open() (Jaroslav Kysela) [2065575]
- ASoC: tegra20: spdif: Improve driver's code (Jaroslav Kysela) [2065575]
- ASoC: tegra20: spdif: Support device-tree (Jaroslav Kysela) [2065575]
- ASoC: tegra20: spdif: Set FIFO trigger level (Jaroslav Kysela) [2065575]
- ASoC: SOF: Kconfig: Make the SOF_DEVELOPER_SUPPORT depend on SND_SOC_SOF (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc: Add null pointer check for substream->runtime (Jaroslav Kysela) [2065575]
- ASoC: SOF: avoid casting "const" attribute away (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: remove support for RESUME in platform trigger (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: remove support for RESUME trigger (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: remove support for RESUME trigger (Jaroslav Kysela) [2065575]
- ASoC: tegra20-spdif: stop setting slave_id (Jaroslav Kysela) [2065575]
- ASoC: AMD: fix depend/select mistake on SND_AMD_ACP_CONFIG (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: read back control data from DSP (Jaroslav Kysela) [2065575]
- ASoC: SOF: Drop ctrl_type parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065575]
- ASoC: SOF: control: Do not handle control notification with component type (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-audio: Drop the `cmd` member from struct snd_sof_control (Jaroslav Kysela) [2065575]
- ASoC: SOF: Drop ctrl_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Set control_data->cmd alongside scontrol->cmd (Jaroslav Kysela) [2065575]
- ASoC: SOF: Drop ipc_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065575]
- ASoC: SOF: ipc: Rename send parameter in snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065575]
- ASoC: rt5663: Handle device_property_read_u32_array error codes (Jaroslav Kysela) [2065575]
- ASoC: SOF: OF: Avoid reverse module dependency (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-probes: Constify sof_probe_compr_ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Remove pm_runtime_put_autosuspend() for SOF OF device (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: add comment on JasperLake support (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-dai: remove unused fields (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: add quirks for HDAudio DMA position information (Jaroslav Kysela) [2065575]
- ASoC: SOF: hda-stream: only enable DPIB if needed (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-ctrl: apply symmetry for DPIB (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda-stream: limit PROCEN workaround (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: ICL: move ICL-specific ops to icl.c (Jaroslav Kysela) [2065575]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065575]
- ASoC: amd: Convert to new style DAI format definitions (Jaroslav Kysela) [2065575]
- ASoC: AMD: acp-config: fix missing dependency on SND_SOC_ACPI (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_rt5682: Move rt1015 speaker amp to common file (Jaroslav Kysela) [2065575]
- ASoC: rt5682s: add delay time to fix pop sound issue (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: add 'static' qualifiers for max98390 routes (Jaroslav Kysela) [2065575]
- ASoC: amd: acp6x-pdm-dma: Constify static snd_soc_dai_ops (Jaroslav Kysela) [2065575]
- ASoC: ti: davinci-mcasp: Get rid of duplicate of_node assignment (Jaroslav Kysela) [2065575]
- ASoC: zl38060: Setup parent device and get rid of unnecessary of_node assignment (Jaroslav Kysela) [2065575]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065575]
- sound/soc: remove useless bool conversion to bool variable (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Fix undefined reference to core functions (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Fix the wrong state of the JD in the HDA header (Jaroslav Kysela) [2065575]
- ASoC: codecs: wcd934x: remove redundant ret variable (Jaroslav Kysela) [2065575]
- ASoC: tegra: Add master volume/mute control support (Jaroslav Kysela) [2065575]
- ASoC: Intel: Skylake: Use NHLT API to search for blob (Jaroslav Kysela) [2065575]
- ASoC: Intel: boards: add max98390 2/4 speakers support (Jaroslav Kysela) [2065575]
- ASoC: intel: boards: bytcht*: Constify static snd_soc_ops (Jaroslav Kysela) [2065575]
- ASoC: Intel: hda_dsp_common: don't multiline PCM topology warning (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: tidyup soc_pcm_pointer()'s delay update method (Jaroslav Kysela) [2065575]
- ASoC: intel: sst-mfld-platform-pcm: add .delay support (Jaroslav Kysela) [2065575]
- ASoC: amd: acp-pcm-dma: add .delay support (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Use pR/pa to print resources/physical addresses (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: Fix link problem (Jaroslav Kysela) [2065575]
- ASoC: codecs/jz4770: Add missing gain control after DAC/ADC mixer (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: send DAI_CONFIG IPC during pause (Jaroslav Kysela) [2065575]
- ASoC: SOF: IPC: dai: Expand DAI_CONFIG IPC flags (Jaroslav Kysela) [2065575]
- ASoC: SOF: align the hw_free sequence with stop (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: move the check for prepared flag (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add a helper for freeing PCM stream (Jaroslav Kysela) [2065575]
- ASoC: SOF: call platform hw_free for paused streams during suspend (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: invoke platform hw_free for STOP/SUSPEND triggers (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: reset stream before coupling host and link DMA's (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: Add a helper function for stream reset (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: clear stream before freeing the DAI widget (Jaroslav Kysela) [2065575]
- ASoC: rt5640: Add the HDA header support (Jaroslav Kysela) [2065575]
- ASoC: uniphier: drop selecting non-existing SND_SOC_UNIPHIER_AIO_DMA (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Add missing of_node_put() in platform_parse_resource() (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: don't use list_for_each_entry_reverse() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: add .ack support for HDaudio platforms (Jaroslav Kysela) [2065575]
- ASoC: SOF: pcm: add .ack callback support (Jaroslav Kysela) [2065575]
- ASoC: SOF: sof-pci-dev: use community key on all Up boards (Jaroslav Kysela) [2065575]
- ASoC: stm32: spdifrx: add pm_runtime support (Jaroslav Kysela) [2065575]
- ASoC: stm32: dfsdm: add pm_runtime support for audio (Jaroslav Kysela) [2065575]
- ASoC: stm32: i2s: add pm_runtime support (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: free DAI widget during stop and suspend (Jaroslav Kysela) [2065575]
- ASoC: SOF: add support for dynamic pipelines with multi-core (Jaroslav Kysela) [2065575]
- ASoC: SOF: hda: don't use the core op for power up/power down (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: remove sof_load_pipeline_ipc() (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: CNL/ICL/APL: set core_get/core_put ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: TGL: set core_get/put ops (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add ops for core_get and core_put (Jaroslav Kysela) [2065575]
- ASoC: SOF: Introduce num_cores and ref count per core (Jaroslav Kysela) [2065575]
- ASoC: SOF: Intel: hda: expose get_chip_info() (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx8m: Implement reset callback (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx8m: Implement DSP start (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx8m: Add runtime PM / System PM support (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx8: Add runtime PM / System PM support (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx: Add code to manage DSP related clocks (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8195 (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Add mt8195 dsp clock support (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Add dai driver dsp ops callback for mt8195 (Jaroslav Kysela) [2065575]
- ASoC: SOF: Add mt8195 device descriptor (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Add fw loader and mt8195 dsp ops to load firmware (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Add support for Mediatek AFE DAI (Jaroslav Kysela) [2065575]
- ASoC: SOF: mediatek: Add mt8195 hardware support (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add support for SOF firmware authentication (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add trace logger support (Jaroslav Kysela) [2065575]
- ASoC: SOF: topology: Add support for AMD ACP DAIs (Jaroslav Kysela) [2065575]
- ASoC: amd: acp-config: Remove legacy acpi based machine struct (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add Renoir PCI driver interface (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add machine driver dsp ops for Renoir platform (Jaroslav Kysela) [2065575]
- ASoC: amd: Add module to determine ACP configuration (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add PCM stream callback for Renoir dai's (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add dai driver dsp ops callback for Renoir (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add IPC support for ACP IP block (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add fw loader and renoir dsp ops to load firmware (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add helper callbacks for ACP's DMA configuration (Jaroslav Kysela) [2065575]
- ASoC: SOF: amd: Add Renoir ACP HW support (Jaroslav Kysela) [2065575]
- ASoC: stm32: sai: increase channels_max limit (Jaroslav Kysela) [2065575]
- ASoC: SOF: debug: Add support for IPC message injection (Jaroslav Kysela) [2065575]
- ASoC: SOF: intel: Use the generic helper to get the reply (Jaroslav Kysela) [2065575]
- ASoC: SOF: imx: Use the generic helper to get the reply (Jaroslav Kysela) [2065575]
- ASoC: SOF: utils: Add generic function to get the reply for a tx message (Jaroslav Kysela) [2065575]
- ASoC: SOF: i.MX: simplify Kconfig (Jaroslav Kysela) [2065575]
- ASoC: SOF: core: Unregister machine driver before IPC and debugfs (Jaroslav Kysela) [2065575]
- ASoC: adau1701: Replace legacy gpio interface for gpiod (Jaroslav Kysela) [2065575]
- ASoC: Intel: add sof-nau8825 machine driver (Jaroslav Kysela) [2065575]
- ASoC: cs35l41: DSP Support (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: add link adr order check (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: remove get_next_be_id (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: remove sof_sdw_mic_codec_mockup_init (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: remove SOF_RT715_DAI_ID_FIX quirk (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: move DMIC link id overwrite to create_sdw_dailink (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: Use a fixed DAI link id for AMP (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: rename be_index/link_id to link_index (Jaroslav Kysela) [2065575]
- ASoC: Intel: sof_sdw: add SKU for Dell Latitude 9520 (Jaroslav Kysela) [2065575]
- ASoC: intel: sof_sdw: return the original error number (Jaroslav Kysela) [2065575]
- ASoC: SOF: trace: send DMA_TRACE_FREE IPC during release (Jaroslav Kysela) [2065575]
- ASoC: SOF: IPC: update ipc_log_header() (Jaroslav Kysela) [2065575]
- ALSA: mtpav: Don't call card private_free at probe error path (Jaroslav Kysela) [2065575]
- ALSA: virmidi: Remove duplicated code (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machine (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for TongFang devices with pop noise (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for the Framework Laptop (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Dell Latitude 7520 (Jaroslav Kysela) [2065575]
- ALSA: hda - fix unused Realtek function when PM is not enabled (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Yoga Duet 7 13ITL6 speakers (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Enable mute/micmute LEDs support for HP Laptops (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Fix mute led issue on thinkpad with cs35l41 s-codec (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNP (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook 845/865 G9 (Jaroslav Kysela) [2065575]
- ALSA: hda/hdmi: add HDMI codec VID for Raptorlake-P (Jaroslav Kysela) [2065575]
- ALSA: hda/hdmi: fix warning about PCM count when used with SOF (Jaroslav Kysela) [2065575]
- ALSA: nm256: Don't call card private_free at probe error path (Jaroslav Kysela) [2065575]
- ALSA: rme9652: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: hdspm: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: hdsp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: oxygen: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: lx6464es: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: cmipci: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: aw2: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: als300: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: lola: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: bt87x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: sis7019: Fix the missing error handling (Jaroslav Kysela) [2065575]
- ALSA: via82xx: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: sonicvibes: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: rme96: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: rme32: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: riptide: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: maestro3: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: korg1212: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: intel8x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: ice1724: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: fm801: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: es1968: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: es1938: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: ens137x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: emu10k1x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: cs5535audio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: cs4281: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: ca0106: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: azt3328: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: au88x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: atiixp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: als4000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: ali5451: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: ad1889: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: echoaudio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: add quirk for Lenovo Thinkpad X12 speakers (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Clevo PD50PNT (Jaroslav Kysela) [2065575]
- ALSA: hda: Avoid unsol event during RPM suspending (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Fix audio regression on Mi Notebook Pro 2020 (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Add new Dolphin HW variants (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Disable HSBIAS_SENSE_EN for Cyborg (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Support new Warlock MLK Variants (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Fix Full Scale Volume setting for all variants (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Re-order quirk table into ascending order (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Fix Warlock to use mono mic configuration (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Enable headset mic on Lenovo P360 (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add mute and micmut LED support for Zbook Fury 17 G9 (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add alc256-samsung-headphone fixup (Jaroslav Kysela) [2065575]
- ALSA: pci: fix reading of swapped values from pcmreg in AC97 codec (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Fix LED on Zbook Studio G9 (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065575]
- ALSA: cmipci: Restore aux vol on suspend/resume (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for ASUS GA402 (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065575]
- ALSA: hda: Add AlderLake-PS variant PCI ID (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Clevo NP50PNJ (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNJ (Jaroslav Kysela) [2065575]
- ALSA: lola: add a check for the return of vmalloc() (Jaroslav Kysela) [2065575]
- ALSA: echoaudio: remove redundant assignment to variable bytes (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Make use of the helper component_compare_dev_name (Jaroslav Kysela) [2065575]
- ALSA: hda/tegra: Update scratch reg. communication (Jaroslav Kysela) [2065575]
- ALSA: hda/tegra: Hardcode GCAP ISS value on T234 (Jaroslav Kysela) [2065575]
- ALSA: hda/tegra: Add Tegra234 hda driver support (Jaroslav Kysela) [2065575]
- ALSA: hda: Expose codec cleanup and power-save functions (Jaroslav Kysela) [2065575]
- ALSA: hda: Update and expose codec register procedures (Jaroslav Kysela) [2065575]
- ALSA: hda: Update and expose snd_hda_codec_device_init() (Jaroslav Kysela) [2065575]
- ALSA: hda/hdmi: add keep-alive support for ADL-P and DG2 (Jaroslav Kysela) [2065575]
- ALSA: hda: Set max DMA segment size (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Fix deadlock by COEF mutex (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix missing codec probe on Shenker Dock 15 (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix regression on forced probe mask option (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2019 (Jaroslav Kysela) [2065575]
- ALSA: hda: Add PCI and HDMI IDs for Intel Raptor Lake (Jaroslav Kysela) [2065575]
- ALSA: ca0106: Rename register macro names (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix driver index handling at re-binding (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add support for HP Laptops (Jaroslav Kysela) [2065575]
- ALSA: hda: Skip codec shutdown in case the codec is not registered (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add quirk for ASUS GU603 (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570 Aorus Xtreme after reboot from Windows (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570S Aorus Master (newer chipset) (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add missing fixup-model entry for Gigabyte X570 ALC1220 quirks (Jaroslav Kysela) [2065575]
- ALSA: hda: realtek: Fix race at concurrent COEF updates (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix signedness of sscanf() arguments (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix UAF of leds class devs at unbinding (Jaroslav Kysela) [2065575]
- ALSA: hda/cs8409: Add new Warlock SKUs to patch_cs8409 (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Make cs35l41_hda_remove() return void (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Tidyup code (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Make use of the helper function dev_err_probe() (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Add missing default cases (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Move cs35l41* calls to its own symbol namespace (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Add calls to newly added test key function (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Avoid overwriting register patch (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: fix speakers and micmute on HP 855 G8 (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: fix double free on error in probe() (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix dependencies of CS35L41 on SPI/I2C buses (Jaroslav Kysela) [2065575]
- ALSA: hda: Fix dependency on ASoC cs35l41 codec (Jaroslav Kysela) [2065575]
- ALSA: hda: ALC287: Add Lenovo IdeaPad Slim 9i 14ITL5 speaker quirk (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add CS35L41 support for Thinkpad laptops (Jaroslav Kysela) [2065575]
- ALSA: hda/realtek: Add support for Legion 7 16ACHg6 laptop (Jaroslav Kysela) [2065575]
- ALSA: hda: cs35l41: Add support for CS35L41 in HDA systems (Jaroslav Kysela) [2065575]
- MAINTAINERS: Update Cirrus Logic codec driver maintainers (Jaroslav Kysela) [2065575]
- ASoC: dt-bindings: cs42l42: Convert binding to yaml (Jaroslav Kysela) [2065575]
- dt-bindings: remove 'interrupt-parent' from bindings (Jaroslav Kysela) [2065575]
- ASoC: dt-bindings: cs42l42: Correct description of ts-inv (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Add warnings about DETECT_MODE and PLL_START (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Handle system suspend (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Change jack_detect_mutex to a lock of all IRQ handling (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Report full jack status when plug is detected (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Remove redundant pll_divout member (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Simplify reporting of jack unplug (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Remove redundant writes to RS_PLUG/RS_UNPLUG masks (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Remove redundant writes to DETECT_MODE (Jaroslav Kysela) [2065575]
- ASoC: cs42l42: Add control for audio slow-start switch (Jaroslav Kysela) [2065575]
- ALSA: mixart: Add sanity check for timer notify streams (Jaroslav Kysela) [2065575]
- ALSA: mixart: Reduce size of mixart_timer_notify (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Restore Rane SL-1 quirk (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Don't get sample rate for MCT Trigger 5 USB-to-HDMI (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Clear MIDI port active flag after draining (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: add mapping for MSI MAG X570S Torpedo MAX. (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Limit max buffer and period sizes per time (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Increase max buffer size (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Cap upper limits of buffer/period bytes for implicit fb (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Fix undefined behavior due to shift overflowing the constant (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Add mute TLV for playback volumes on RODE NT-USB (Jaroslav Kysela) [2065575]
- ALSA: scarlett2: Add support for the internal "standalone" switch (Jaroslav Kysela) [2065575]
- ALSA: scarlett2: Split scarlett2_config_items[] into 3 sections (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: add mapping for new Corsair Virtuoso SE (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Don't abort resume upon errors (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: revert to IMPLICIT_FB_FIXED_DEV for M-Audio FastTrack Ultra (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: remove redundant assignment to variable c (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: Correct quirk for VF0770 (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: initialize variables that could ignore errors (Jaroslav Kysela) [2065575]
- ALSA: usb-audio: scarlett2: Use struct_size() helper in scarlett2_usb() (Jaroslav Kysela) [2065575]
- ALSA: fireworks: fix wrong return count shorter than expected by 4 bytes (Jaroslav Kysela) [2065575]
- ALSA: firewire-lib: fix uninitialized flag for AV/C deferred transaction (Jaroslav Kysela) [2065575]
- ALSA: memalloc: Add fallback SG-buffer allocations for x86 (Jaroslav Kysela) [2065575]
- ALSA: core: Add snd_card_free_on_error() helper (Jaroslav Kysela) [2065575]
- ALSA: pcm: Test for "silence" field in struct "pcm_format_data" (Jaroslav Kysela) [2065575]
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and mmap_lock (Jaroslav Kysela) [2065575]
- ALSA: pcm: Add stream lock during PCM reset ioctl operations (Jaroslav Kysela) [2065575]
- ALSA: pcm: Fix races among concurrent prealloc proc writes (Jaroslav Kysela) [2065575]
- ALSA: pcm: Fix races among concurrent prepare and hw_params/hw_free calls (Jaroslav Kysela) [2065575]
- ALSA: pcm: Fix races among concurrent read/write and buffer changes (Jaroslav Kysela) [2065575]
- ALSA: pcm: Fix races among concurrent hw_params and hw_free calls (Jaroslav Kysela) [2065575]
- ALSA: oss: Release temporary buffers upon errors (Jaroslav Kysela) [2065575]
- ALSA: oss: Fix PCM OSS buffer allocation overflow (Jaroslav Kysela) [2065575]
- ALSA: core: Fix typo in 'PCM Timer Interface' help (Jaroslav Kysela) [2065575]
- ALSA: seq: oss: fix typo (Jaroslav Kysela) [2065575]
- ALSA: seq: oss: use kzalloc (Jaroslav Kysela) [2065575]
- ALSA: memalloc: invalidate SG pages before sync (Jaroslav Kysela) [2065575]
- ALSA: memalloc: Fix dma_need_sync() checks (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: Fix DPCM lockdep warning due to nested stream locks (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: fix BE handling of PAUSE_RELEASE (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: serialize BE triggers (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: Fix and cleanup DPCM locking (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: align BE 'atomicity' with that of the FE (Jaroslav Kysela) [2065575]
- ASoC: soc-pcm: use GFP_ATOMIC for dpcm structure (Jaroslav Kysela) [2065575]
- ASoC: soc-component: add snd_soc_pcm_component_delay() (Jaroslav Kysela) [2065575]
- ASoC: soc-dai: update snd_soc_dai_delay() to snd_soc_pcm_dai_delay() (Jaroslav Kysela) [2065575]
- ALSA: core: Simplify snd_power_ref_and_wait() with the standard macro (Jaroslav Kysela) [2065575]
- ALSA: seq: virmidi: Add a drain operation (Jaroslav Kysela) [2065575]
- ASoC: dai_dma: remove slave_id field (Jaroslav Kysela) [2065575]
- ALSA: seq: Set upper limit of processed events (Jaroslav Kysela) [2065575]
- ALSA: oss: remove useless NULL check before kfree (Jaroslav Kysela) [2065575]
- ALSA: pcm: introduce INFO_NO_REWINDS flag (Jaroslav Kysela) [2065575]
- ALSA: pcm: unconditionally check if appl_ptr is in 0..boundary range (Jaroslav Kysela) [2065575]
- Revert "ASoC: Intel: soc-acpi: add entries in ADL match table" (Jaroslav Kysela) [2065575]
- devlink: hold the instance lock during eswitch_mode callbacks (Petr Oros) [2101715]
- netdevsim: replace vfs_lock with devlink instance lock (Petr Oros) [2101715]
- netdevsim: replace port_list_lock with devlink instance lock (Petr Oros) [2101715]
- devlink: add explicitly locked flavor of the rate node APIs (Petr Oros) [2101715]
- bnxt: use the devlink instance lock to protect sriov (Petr Oros) [2101715]
- devlink: pass devlink_port to port_split / port_unsplit callbacks (Petr Oros) [2101715]
- devlink: hold the instance lock in port_split / port_unsplit callbacks (Petr Oros) [2101715]
- eth: mlxsw: switch to explicit locking for port registration (Petr Oros) [2101715]
- eth: nfp: replace driver's "pf" lock with devlink instance lock (Petr Oros) [2101715]
- eth: nfp: wrap locking assertions in helpers (Petr Oros) [2101715]
- devlink: expose instance locking and add locked port registering (Petr Oros) [2101715]
- ethtool: don't drop the rtnl_lock half way thru the ioctl (Petr Oros) [2101715]
- ethtool: handle info/flash data copying outside rtnl_lock (Petr Oros) [2101715]
- ethtool: push the rtnl_lock into dev_ethtool() (Petr Oros) [2101715]
- mlxsw: reg: Remove PMTM register (Ivan Vecera) [2101715]
- mlxsw: spectrum: Use PMTDB register to obtain split info (Ivan Vecera) [2101715]
- mlxsw: reg: Add Port Module To local DataBase Register (Ivan Vecera) [2101715]
- mlxsw: spectrum: Use PLLP to get front panel number and split number (Ivan Vecera) [2101715]
- mlxsw: reg: Add Port Local port to Label Port mapping Register (Ivan Vecera) [2101715]
- mlxsw: spectrum: Move port SWID set before core port init (Ivan Vecera) [2101715]
- mlxsw: spectrum: Move port module mapping before core port init (Ivan Vecera) [2101715]
- mlxsw: spectrum: Bump minimum FW version to xx.2008.3326 (Ivan Vecera) [2101715]
- bpf: fix build error due to missing bpf_perf_event.h header (Desnes A. Nunes do Rosario) [1908140]
- powerpc/bpf: Fix use of user_pt_regs in uapi (Desnes A. Nunes do Rosario) [1908140]
- net: ena: Do not waste napi skb cache (Michal Schmidt) [2097644]
- net: ena: Extract recurring driver reset code into a function (Michal Schmidt) [2097644]
- net: ena: Change the name of bad_csum variable (Michal Schmidt) [2097644]
- net: ena: Add debug prints for invalid req_id resets (Michal Schmidt) [2097644]
- net: ena: Remove ena_calc_queue_size_ctx struct (Michal Schmidt) [2097644]
- net: ena: Move reset completion print to the reset function (Michal Schmidt) [2097644]
- net: ena: Remove redundant return code check (Michal Schmidt) [2097644]
- net: ena: Change ENI stats support check to use capabilities field (Michal Schmidt) [2097644]
- net: ena: Add capabilities field with support for ENI stats capability (Michal Schmidt) [2097644]
- net: ena: Change return value of ena_calc_io_queue_size() to void (Michal Schmidt) [2097644]
- powerpc/ptrace: replace ptrace_report_syscall() with a tracehook call (Desnes A. Nunes do Rosario) [1992947]
- powerpc/ptrace: Add support for PTRACE_SYSEMU (Desnes A. Nunes do Rosario) [1992947]
- selftests/powerpc: New PTRACE_SYSEMU test (Desnes A. Nunes do Rosario) [1992947]
- powerpc: Redefine TIF_32BITS thread flag (Desnes A. Nunes do Rosario) [1992947]
- redhat: fix libnl3-devel BuildRequires for intel-speed-select (Jarod Wilson)

* Thu Aug 04 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-415.el8]
- redhat: enable mtty module for internal testing (Jarod Wilson) [2071992]
- tools/power/x86/intel-speed-select: v1.12 release (Martin McConnell) [2072658]
- tools/power/x86/intel-speed-select: HFI support (Martin McConnell) [2072658]
- tools/power/x86/intel-speed-select: OOB daemon mode (Martin McConnell) [2072658]
- tools/power/x86/intel-speed-select: v1.11 release (Martin McConnell) [2072658]
- tools/power/x86/intel-speed-select: Update max frequency (Martin McConnell) [2072658]
- Spec fixes for intel-speed-select (Martin McConnell) [2072658]
- Add BuildRequires libnl3-devel for intel-speed-select (Martin McConnell) [2072658]
- xfs: fix soft lockup via spinning in filestream ag selection loop (Brian Foster) [2033293]
- net: ping6: Fix memleak in ipv6_renew_options(). (Ivan Vecera) [2112339]
- Input: i8042 - Add quirk for Fujitsu Lifebook T725 (Benjamin Tissoires) [2019942]
- HID: amd_sfh: Modify the hid name (Benjamin Tissoires) [2090040]
- HID: amd_sfh: Modify the bus name (Benjamin Tissoires) [2090040]
- HID: amd_sfh: Add support for sensor discovery (Benjamin Tissoires) [2090040]
- igc: Reinstate IGC_REMOVED logic and implement it properly (Corinna Vinschen) [2037969]
- intel/igc:fix repeated words in comments (Corinna Vinschen) [2037969]
- intel: remove unused macros (Corinna Vinschen) [2037969]
- igc: Change type of the 'igc_check_downshift' method (Corinna Vinschen) [2037969]
- igc: Remove unused phy_type enum (Corinna Vinschen) [2037969]
- igc: Remove igc_set_spd_dplx method (Corinna Vinschen) [2037969]
- igc: Fix suspending when PTM is active (Corinna Vinschen) [2037969]
- igc: Fix BUG: scheduling while atomic (Corinna Vinschen) [2037969 2014971]
- igc: Fix infinite loop in release_swfw_sync (Corinna Vinschen) [2037969]
- igc: igc_write_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037969]
- igc: igc_read_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037969]
- igc: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Corinna Vinschen) [2037969]
- igc: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037969]
- igc: Fix TX timestamp support for non-MSI-X platforms (Corinna Vinschen) [2037969]
- igc: Do not enable crosstimestamping for i225-V models (Corinna Vinschen) [2037969]
- igc: switch to napi_build_skb() (Corinna Vinschen) [2037969]
- igc: Remove obsolete define (Corinna Vinschen) [2037969]
- igc: Remove obsolete mask (Corinna Vinschen) [2037969]
- igc: Remove obsolete nvm type (Corinna Vinschen) [2037969]
- igc: Remove unused phy type (Corinna Vinschen) [2037969]
- igc: Remove unused _I_PHY_ID define (Corinna Vinschen) [2037969]
- igc: enable XDP metadata in driver (Corinna Vinschen) [2037969]
- intel_idle: Fix false positive RCU splats due to incorrect hardirqs state (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/spec_ctrl: Enable RHEL only ibrs_always & retpoline,ibrs_user spectre_v2 options (Waiman Long) [2090229]
- KVM: emulate: do not adjust size of fastop and setcc subroutines (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: fix FASTOP_SIZE when return thunks are enabled (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- efi/x86: use naked RET on mixed mode call wrapper (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Remove apostrophe typo (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use DECLARE_PER_CPU for x86_spec_ctrl_current (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Remove UNTRAIN_RET from native_irq_return_ldt (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Mark retbleed_strings static (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/asm/32: Fix ANNOTATE_UNRET_SAFE use on 32-bit (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Disable RRSBA behavior (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kexec: Disable RET on kexec (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do not enable IBPB-on-entry when IBPB is not supported (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add Cannon lake to RETBleed affected CPU list (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- redhat/configs: Add new mitigation configs for RetBleed CVEs (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retbleed: Add fine grained Kconfig knobs (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Enumerate BTC_NO (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/common: Stamp out the stepping madness (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent RSB underflow before vmenter (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fill RSB on vmexit for IBRS (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Fix IBRS handling after vmexit (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent guest RSB poisoning attacks with eIBRS (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Convert launched argument to flags (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Flatten __vmx_vcpu_run() (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Remove x86_spec_ctrl_mask (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use cached host SPEC_CTRL value for guest entry/exit (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix SPEC_CTRL write on SMT state change (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix firmware entry SPEC_CTRL handling (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Add Spectral Chicken (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do IBPB fallback check only once (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add retbleed=ibpb (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Update Retpoline validation (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- intel_idle: Disable IBRS during long idle (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report Intel retbleed vulnerability (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Split spectre_v2_select_mitigation() and spectre_v2_user_select_mitigation() (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Add spectre_v2=ibrs option to support Kernel IBRS (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Optimize SPEC_CTRL MSR writes (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Add kernel IBRS implementation (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Keep a per-CPU IA32_SPEC_CTRL value (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Enable STIBP for JMP2RET (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add AMD retbleed= boot parameter (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report AMD retbleed vulnerability (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Add magic AMD return-thunk (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Use return-thunk in asm code (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/sev: Avoid using __x86_return_thunk (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/vsyscall_emu/64: Don't use RET in vsyscall emulation (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: Fix SETcc emulation for return thunks (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bpf: Use alternative RET encoding (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/ftrace: Use alternative RET encoding (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,objtool: Create .return_sites (Josh Poimboeuf) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Undo return-thunk damage (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Use -mfunction-return (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Swizzle retpoline thunk (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Cleanup some #ifdefery (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpufeatures: Move RETPOLINE flags to word 11 (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm/vmx: Make noinstr clean (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- arch/x86/boot/compressed: Add -D__DISABLE_EXPORTS to kbuild flags (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: (Ab)use __DISABLE_EXPORTS to disable RETHUNK in real mode (Waiman Long) [2090229] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Remove skip_r11rcx (Waiman Long) [2090229]
- cpuidle,intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE (Waiman Long) [2090229]
- x86/speculation/srbds: Do not try to turn mitigation off when not supported (Waiman Long) [2090229]
- x86/ibt,paravirt: Use text_gen_insn() for paravirt_patch() (Waiman Long) [2090229]
- x86/text-patching: Make text_gen_insn() play nice with ANNOTATE_NOENDBR (Waiman Long) [2090229]
- x86/module: Fix the paravirt vs alternative order (Waiman Long) [2090229]
- x86: Add straight-line-speculation mitigation (Waiman Long) [2090229]
- x86: Prepare inline-asm for straight-line-speculation (Waiman Long) [2090229]
- x86: Prepare asm files for straight-line-speculation (Waiman Long) [2090229]
- x86: Use -mindirect-branch-cs-prefix for RETPOLINE builds (Waiman Long) [2090229]
- x86: Move RETPOLINE*_CFLAGS to arch Makefile (Waiman Long) [2090229]
- x86/entry: Add a fence for kernel entry SWAPGS in paranoid_entry() (Waiman Long) [2090229]
- Makefile: remove stale cc-option checks (Waiman Long) [2090229]
- tools headers: Remove broken definition of __LITTLE_ENDIAN (Waiman Long) [2090229]
- tools arch: Update arch/x86/lib/mem{cpy,set}_64.S copies used in 'perf bench mem memcpy' (Waiman Long) [2090229]
- x86: Add insn_decode_kernel() (Waiman Long) [2090229]
- tools/insn: Restore the relative include paths for cross building (Waiman Long) [2090229]
- x86/alternative: Use insn_decode() (Waiman Long) [2090229]
- x86/insn: Add an insn_decode() API (Waiman Long) [2090229]
- x86/insn: Rename insn_decode() to insn_decode_from_regs() (Waiman Long) [2090229]
- x86/paravirt: Add new features for paravirt patching (Waiman Long) [2090229]
- x86/alternative: Support not-feature (Waiman Long) [2090229]
- x86/alternative: Merge include files (Waiman Long) [2090229]
- objtool: Fix error handling for STD/CLD warnings (Waiman Long) [2090229]
- x86/alternatives: Teach text_poke_bp() to emulate RET (Waiman Long) [2090229]
- x86/ftrace: Have ftrace trampolines turn read-only at the end of system boot up (Waiman Long) [2090229]
- x86/speculation: Change FILL_RETURN_BUFFER to work with objtool (Waiman Long) [2090229]
- objtool: Add support for intra-function calls (Waiman Long) [2090229]
- objtool: Rework allocating stack_ops on decode (Waiman Long) [2090229]
- objtool: Better handle IRET (Waiman Long) [2090229]
- objtool: Support multiple stack_op per instruction (Waiman Long) [2090229]
- objtool: Make BP scratch register warning more robust (Waiman Long) [2090229]
- x86/kexec: Make relocate_kernel_64.S objtool clean (Waiman Long) [2090229]
- objtool: Introduce validate_return() (Waiman Long) [2090229]
- Makefile: disallow data races on gcc-10 as well (Waiman Long) [2090229]
- objtool: Improve call destination function detection (Waiman Long) [2090229]
- x86/alternatives: Implement a better poke_int3_handler() completion scheme (Waiman Long) [2090229]
- lib/: fix Kconfig indentation (Waiman Long) [2090229]
- x86/alternatives: Use INT3_INSN_SIZE (Waiman Long) [2090229]
- x86/kprobes: Fix ordering while text-patching (Waiman Long) [2090229]
- x86/kprobes: Convert to text-patching.h (Waiman Long) [2090229]
- x86/alternative: Shrink text_poke_loc (Waiman Long) [2090229]
- x86/alternative: Remove text_poke_loc::len (Waiman Long) [2090229]
- x86/ftrace: Use text_gen_insn() (Waiman Long) [2090229]
- x86/alternative: Add text_opcode_size() (Waiman Long) [2090229]
- x86/ftrace: Use text_poke() (Waiman Long) [2090229]
- x86/ftrace: Use vmalloc special flag (Waiman Long) [2090229]
- x86/ftrace: Explicitly include vmalloc.h for set_vm_flush_reset_perms() (Waiman Long) [2090229]
- x86/alternatives: Add and use text_gen_insn() helper (Waiman Long) [2090229]
- x86/alternatives, jump_label: Provide better text_poke() batching interface (Waiman Long) [2090229]
- x86/asm: Annotate relocate_kernel_{32,64}.c (Waiman Long) [2090229]
- x86: kprobes: Prohibit probing on instruction which has emulate prefix (Waiman Long) [2090229]
- x86: Correct misc typos (Waiman Long) [2090229]
- x86/speculation/mds: Apply more accurate check on hypervisor platform (Waiman Long) [2090229]
- objtool: Convert insn type to enum (Waiman Long) [2090229]
- objtool: Track original function across branches (Waiman Long) [2090229]
- objtool: Rename elf_open() to prevent conflict with libelf from elftoolchain (Waiman Long) [2090229]
- x86/ftrace: Make enable parameter bool where applicable (Waiman Long) [2090229]
- x86/CPU/AMD: Don't force the CPB cap when running under a hypervisor (Waiman Long) [2090229]
- objtool: Fix function fallthrough detection (Waiman Long) [2090229]
- x86/paravirt: Detect over-sized patching bugs in paravirt_patch_call() (Waiman Long) [2090229]
- x86/cpu/amd: Exclude 32bit only assembler from 64bit build (Waiman Long) [2090229]
- x86/asm: Mark all top level asm statements as .text (Waiman Long) [2090229]
- x86/cpu/bugs: Use __initconst for 'const' init data (Waiman Long) [2090229]
- objtool: Add Direction Flag validation (Waiman Long) [2090229]
- objtool: Rewrite add_ignores() (Waiman Long) [2090229]
- x86/nospec, objtool: Introduce ANNOTATE_IGNORE_ALTERNATIVE (Waiman Long) [2090229]
- x86/ftrace: Fix warning and considate ftrace_jmp_replace() and ftrace_call_replace() (Waiman Long) [2090229]
- kbuild: Disable extra debugging info in .s output (Waiman Long) [2090229]
- x86/CPU/AMD: Set the CPB bit unconditionally on F17h (Waiman Long) [2090229]
- x86/alternatives: Print containing function (Waiman Long) [2090229]
- x86/ftrace: Do not call function graph from dynamic trampolines (Waiman Long) [2090229]
- ftrace: Create new ftrace_internal.h header (Waiman Long) [2090229]
- kprobes/x86: Fix instruction patching corruption when copying more than one RIP-relative instruction (Waiman Long) [2090229]
- tracing/Makefile: Fix handling redefinition of CC_FLAGS_FTRACE (Waiman Long) [2090229]
- x86/paravirt: Remove unused paravirt bits (Waiman Long) [2090229]
- x86/paravirt: Remove clobbers parameter from paravirt patch functions (Waiman Long) [2090229]
- x86/paravirt: Make paravirt_patch_call() and paravirt_patch_jmp() static (Waiman Long) [2090229]
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled (Waiman Long) [2090229]
- ftrace: Remove unused pointer ftrace_swapper_pid (Waiman Long) [2090229]
- x86/spec_ctrl: Temporarily remove RHEL specific IBRS code (Waiman Long) [2090229]
- net: bonding: fix use-after-free after 802.3ad slave unbind (Jonathan Toppins) [2109327]
- net: bonding: fix possible NULL deref in rlb code (Jonathan Toppins) [2109327]
- bonding: ARP monitor spams NETDEV_NOTIFY_PEERS notifiers (Jonathan Toppins) [2109327]
- bonding: do not discard lowest hash bit for non layer3+4 hashing (Jonathan Toppins) [2109327]
- bonding: helper macro __ATTR_RO to make code more clear (Jonathan Toppins) [2109327]
- bonding: force carrier update when releasing slave (Jonathan Toppins) [2109327]
- bonding: fix data-races around agg_select_timer (Jonathan Toppins) [2109327]
- bonding: switch bond_net_exit() to batch mode (Jonathan Toppins) [2109327]
- bonding: pair enable_port with slave_arr_updates (Jonathan Toppins) [2109327]
- net: bonding: fix bond_xmit_broadcast return value error bug (Jonathan Toppins) [2109327]
- tracing: Show size of requested perf buffer (Michael Petlan) [2103836]
- tracing: Increase PERF_MAX_TRACE_SIZE to handle Sentinel1 and docker together (Michael Petlan) [2103836]
- drivers/base/memory: determine and store zone for single-zone memory blocks (David Hildenbrand) [1997803]
- drivers/base/node: rename link_mem_sections() to register_memory_block_under_node() (David Hildenbrand) [1997803]
- drivers/base/node: consolidate node device subsystem initialization in node_dev_init() (David Hildenbrand) [1997803]
- drivers/base/memory: introduce memory_block_{online,offline} (David Hildenbrand) [1997803]
- mm/memory_hotplug: remove stale function declarations (David Hildenbrand) [1997803]
- mm/memory_hotplug: remove HIGHMEM leftovers (David Hildenbrand) [1997803]
- redhat/configs: remove CONFIG_MEMORY_HOTPLUG_SPARSE (David Hildenbrand) [1997803]
- mm/memory_hotplug: restrict CONFIG_MEMORY_HOTPLUG to 64 bit (David Hildenbrand) [1997803]
- mm/memory_hotplug: remove CONFIG_MEMORY_HOTPLUG_SPARSE (David Hildenbrand) [1997803]
- mm/memory_hotplug: remove CONFIG_X86_64_ACPI_NUMA dependency from CONFIG_MEMORY_HOTPLUG (David Hildenbrand) [1997803]
- memory: remove unused CONFIG_MEM_BLOCK_SIZE (David Hildenbrand) [1997803]
- mm/memory_hotplug: disable the functionality for 32b (David Hildenbrand) [1997803]
- include/linux/memory.h: drop fields 'hw' and 'phys_callback' from struct memory_block (David Hildenbrand) [1997803]
- iommu/vt-d: Fix PCI bus rescan device hot add (Jerry Snitselaar) [2101591]
- iommu/vt-d: Fix RID2PASID setup/teardown failure (Jerry Snitselaar) [2101591]

* Mon Aug 01 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-414.el8]
- cifs: support share failover when remounting (Ronnie Sahlberg) [2095258]
- cifs: avoid starvation when refreshing dfs cache (Ronnie Sahlberg) [2095258]
- cifs: fix path comparison and hash calc (Ronnie Sahlberg) [2095258]
- cifs: handle different charsets in dfs cache (Ronnie Sahlberg) [2095258]
- spi: amd: Limit max transfer and message size (Sudheesh Mavila) [2047996]
- redhat/configs: enable CONFIG_SPI_AMD for x86_64 (Sudheesh Mavila) [2047996]
- spi: amd: Fix building without ACPI enabled (Sudheesh Mavila) [2047996]
- spi: amd: Add support for version AMDI0062 (Sudheesh Mavila) [2047996]
- spi: amd: Remove needless rom_addr variable (Sudheesh Mavila) [2047996]
- spi: amd: Use iopoll for busy waiting (Sudheesh Mavila) [2047996]
- spi: amd: Don't wait for a write-only transfer to finish (Sudheesh Mavila) [2047996]
- spi: amd: Remove unneeded variable (Sudheesh Mavila) [2047996]
- spi: amd: Refactor amd_spi_busy_wait (Sudheesh Mavila) [2047996]
- spi: amd: Refactor code to use less spi_master_get_devdata (Sudheesh Mavila) [2047996]
- spi: amd: Use devm_platform_ioremap_resource() in amd_spi_probe (Sudheesh Mavila) [2047996]
- spi: spi-amd: Do not define 'struct acpi_device_id' when !CONFIG_ACPI (Sudheesh Mavila) [2047996]
- spi: amd: Drop superfluous member from struct amd_spi (Sudheesh Mavila) [2047996]
- spi: amd: Fix refcount underflow on remove (Sudheesh Mavila) [2047996]
- spi: amd: Drop duplicate driver data assignments (Sudheesh Mavila) [2047996]
- spi: amd: Pass probe errors back to driver core (Sudheesh Mavila) [2047996]
- spi: amd: Fix duplicate iounmap in error path (Sudheesh Mavila) [2047996]
- spi: spi-amd: Fix a NULL vs IS_ERR() check in amd_spi_probe() (Sudheesh Mavila) [2047996]
- spi: spi-amd: fix warning (Sudheesh Mavila) [2047996]
- spi: spi-amd: Add AMD SPI controller driver support (Sudheesh Mavila) [2047996]
- selftests/tc-testings: Be compatible with newer tc output (Hangbin Liu) [2100322]
- selftests/net: enable lo.accept_local in psock_snd test (Hangbin Liu) [2100322]
- selftests/net: Use kselftest skip code for skipped tests (Hangbin Liu) [2100322]
- Bluetooth: SCO: Fix sco_send_frame returning skb->len (Gopal Tiwari) [1984641]
- Bluetooth: Add bt_skb_sendmsg helper (Gopal Tiwari) [1984641]
- Bluetooth: SCO: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [1984641]
- Bluetooth: sco: Fix lock_sock() blockage by memcpy_from_msg() (Gopal Tiwari) [1984641]
- platform/mellanox: mlxbf-pmc: Fix an IS_ERR() vs NULL bug in mlxbf_pmc_map_counters (Mark Langsdorf) [2068297]
- platform/mellanox: mlxreg-lc: fix error code in mlxreg_lc_create_static_devices() (Mark Langsdorf) [2068297]
- platform/mellanox: mlxreg-lc: Add initial support for Nvidia line card devices (Mark Langsdorf) [2068297]
- platform/mellanox: mlxreg-io: Extend number of hwmon attributes (Mark Langsdorf) [2068297]
- platform/mellanox: mlxreg-hotplug: Extend logic for hotplug devices operations (Mark Langsdorf) [2068297]
- platform_data/mlxreg: Add new type to support modular systems (Mark Langsdorf) [2068297]
- platform/mellanox: mlxreg-io: Fix read access of n-bytes size attributes (Mark Langsdorf) [2068297]
- platform/mellanox: mlxbf-pmc: fix kernel-doc notation (Mark Langsdorf) [2068297]
- platform/mellanox: Typo fix in the file mlxbf-bootctl.c (Mark Langsdorf) [2068297]
- redhat/configs: Support QAT devices for x86 only (Vladis Dronov) [2040724]
- crypto: qat - expose device config through sysfs for 4xxx (Vladis Dronov) [2040724]
- crypto: qat - relocate and rename adf_sriov_prepare_restart() (Vladis Dronov) [2040724]
- crypto: qat - change behaviour of adf_cfg_add_key_value_param() (Vladis Dronov) [2040724]
- crypto: qat - expose device state through sysfs for 4xxx (Vladis Dronov) [2040724]
- crypto: qat - Removes the x86 dependency on the QAT drivers (Vladis Dronov) [2040724]
- crypto: qat - replace get_current_node() with numa_node_id() (Vladis Dronov) [2040724]
- crypto: qat - add support for 401xx devices (Vladis Dronov) [2040724]
- crypto: qat - re-enable registration of algorithms (Vladis Dronov) [2040724]
- crypto: qat - honor CRYPTO_TFM_REQ_MAY_SLEEP flag (Vladis Dronov) [2040724]
- crypto: qat - add param check for DH (Vladis Dronov) [2040724]
- crypto: qat - add param check for RSA (Vladis Dronov) [2040724]
- crypto: qat - remove dma_free_coherent() for DH (Vladis Dronov) [2040724]
- crypto: qat - remove dma_free_coherent() for RSA (Vladis Dronov) [2040724]
- crypto: qat - fix memory leak in RSA (Vladis Dronov) [2040724]
- crypto: qat - add backlog mechanism (Vladis Dronov) [2040724]
- crypto: qat - refactor submission logic (Vladis Dronov) [2040724]
- crypto: qat - use pre-allocated buffers in datapath (Vladis Dronov) [2040724]
- crypto: qat - set to zero DH parameters before free (Vladis Dronov) [2040724]
- crypto: qat - Fix unsigned function returning negative constant (Vladis Dronov) [2040724]
- crypto: qat - remove line wrapping for pfvf_ops functions (Vladis Dronov) [2040724]
- crypto: qat - use u32 variables in all GEN4 pfvf_ops (Vladis Dronov) [2040724]
- crypto: qat - replace disable_vf2pf_interrupts() (Vladis Dronov) [2040724]
- crypto: qat - leverage the GEN2 VF mask definiton (Vladis Dronov) [2040724]
- crypto: qat - rework the VF2PF interrupt handling logic (Vladis Dronov) [2040724]
- crypto: qat - fix off-by-one error in PFVF debug print (Vladis Dronov) [2040724]
- crypto: qat - fix wording and formatting in code comment (Vladis Dronov) [2040724]
- crypto: qat - test PFVF registers for spurious interrupts on GEN4 (Vladis Dronov) [2040724]
- crypto: qat - add check for invalid PFVF protocol version 0 (Vladis Dronov) [2040724]
- crypto: qat - add missing restarting event notification in VFs (Vladis Dronov) [2040724]
- crypto: qat - remove unnecessary tests to detect PFVF support (Vladis Dronov) [2040724]
- crypto: qat - remove unused PFVF stubs (Vladis Dronov) [2040724]
- crypto: qat - remove unneeded braces (Vladis Dronov) [2040724]
- crypto: qat - fix ETR sources enabled by default on GEN2 devices (Vladis Dronov) [2040724]
- crypto: qat - set COMPRESSION capability for DH895XCC (Vladis Dronov) [2040724]
- crypto: qat - set CIPHER capability for DH895XCC (Vladis Dronov) [2040724]
- crypto: qat - stop using iommu_present() (Vladis Dronov) [2040724]
- crypto: qat - fix initialization of pfvf rts_map_msg structures (Vladis Dronov) [2040724]
- crypto: qat - fix initialization of pfvf cap_msg structures (Vladis Dronov) [2040724]
- crypto: qat - remove unneeded assignment (Vladis Dronov) [2040724]
- crypto: qat - disable registration of algorithms (Vladis Dronov) [2040724]
- crypto: qat - enable power management for QAT GEN4 (Vladis Dronov) [2040724]
- crypto: qat - move and rename GEN4 error register definitions (Vladis Dronov) [2040724]
- crypto: qat - add misc workqueue (Vladis Dronov) [2040724]
- crypto: qat - don't cast parameter in bit operations (Vladis Dronov) [2040724]
- crypto: qat - fix access to PFVF interrupt registers for GEN4 (Vladis Dronov) [2040724]
- crypto: qat - fix a signedness bug in get_service_enabled() (Vladis Dronov) [2040724]
- dlm: fix missing lkb refcount handling (Alexander Aring) [2084606]
- scsi: storvsc: Fix unsigned comparison to zero (Mohammed Gamal) [2020774]
- scsi: storvsc: Fix validation for unsolicited incoming packets (Mohammed Gamal) [2020774]
- scsi: storvsc: Fix storvsc_queuecommand() memory leak (Mohammed Gamal) [2020774]
- x86/kvm: Add kexec support for SEV Live Migration. (Mohammed Gamal) [2018614]
- x86/kvm: Add guest support for detecting and enabling SEV Live Migration feature. (Mohammed Gamal) [2018614]
- mm: x86: Invoke hypercall when page encryption status is changed (Mohammed Gamal) [2018614]
- hv_netvsc: Fix potential dereference of NULL pointer (Mohammed Gamal) [2086611]
- hv_netvsc: Add support for XDP_REDIRECT (Mohammed Gamal) [2086611]
- hv_netvsc: Print value of invalid ID in netvsc_send_{completion,tx_complete}() (Mohammed Gamal) [2086611]
- net: hyperv: remove use of bpf_op_t (Mohammed Gamal) [2086611]
- hv_netvsc: Add check for kvmalloc_array (Mohammed Gamal) [2086611]
- net: netvsc: remove break after return (Mohammed Gamal) [2086611]
- hv_netvsc: Use bitmap_zalloc() when applicable (Mohammed Gamal) [2086611]
- SMB3: EBADF/EIO errors in rename/open caused by race condition in smb2_compound_op (Ronnie Sahlberg) [2108871]
- vsock/virtio: enable VQs early on probe (Stefano Garzarella) [2107594]
- vsock/virtio: initialize vdev->priv before using VQs (Stefano Garzarella) [2107594]
- vsock: each transport cycles only on its own sockets (Stefano Garzarella) [2107594]
- vhost/vsock: don't check owner in vhost_vsock_stop() while releasing (Stefano Garzarella) [2107594]
- vsock: remove vsock from connected table when connect is interrupted by a signal (Stefano Garzarella) [2107594]
- ipv6: take care of disable_policy when restoring routes (Andrea Claudi) [2103894]
- tools/testing/nvdimm: Fix security_init() symbol collision (Jeff Moyer) [2096791]
- redhat: make kernel-devel pkgs Requires elfutils and gcc (Jarod Wilson) [1701282]
- xhci: Fix null pointer dereference in resume if xhci has only one roothub (Dean Nelson) [2061791]
- usb: dwc3: gadget: Move null pinter check to proper place (Dean Nelson) [2061791]
- xhci: Don't defer primary roothub registration if there is only one roothub (Dean Nelson) [2061791]
- USB: serial: pl2303: fix type detection for odd device (Dean Nelson) [2061791]
- media: pvrusb2: fix array-index-out-of-bounds in pvr2_i2c_core_init (Dean Nelson) [2061791]
- usb: xhci-mtk: remove bandwidth budget table (Dean Nelson) [2061791]
- usb: xhci-mtk: fix fs isoc's transfer error (Dean Nelson) [2061791]
- xhci: Allow host runtime PM as default for Intel Alder Lake N xHCI (Dean Nelson) [2061791]
- xhci: prevent U2 link power state if Intel tier policy prevented U1 (Dean Nelson) [2061791]
- xhci: use generic command timer for stop endpoint commands. (Dean Nelson) [2061791]
- usb: host: xhci-plat: omit shared hcd if either root hub has no ports (Dean Nelson) [2061791]
- usb: host: xhci-plat: prepare operation w/o shared hcd (Dean Nelson) [2061791]
- usb: host: xhci-plat: create shared hcd after having added main hcd (Dean Nelson) [2061791]
- xhci: prepare for operation w/o shared hcd (Dean Nelson) [2061791]
- xhci: factor out parts of xhci_gen_setup() (Dean Nelson) [2061791]
- xhci: Set HCD flag to defer primary roothub registration (Dean Nelson) [2061791]
- usb: core: hcd: Add support for deferring roothub registration (Dean Nelson) [2061791]
- thunderbolt: Fix buffer allocation of devices with no DisplayPort adapters (Dean Nelson) [2061791]
- media: uvcvideo: Fix bit overflow in uvc_probe_video (Dean Nelson) [2061791]
- media: uvcvideo: Fix missing check to determine if element is found in list (Dean Nelson) [2061791]
- usb: typec: tcpci: Don't skip cleanup in .remove() on error (Dean Nelson) [2061791]
- usb: cdc-wdm: fix reading stuck on device close (Dean Nelson) [2061791]
- thunderbolt: Ignore port locked error in tb_port_wait_for_link_width() (Dean Nelson) [2061791]
- thunderbolt: Add debug logging when lane is enabled/disabled (Dean Nelson) [2061791]
- usb: dwc3: gadget: Return proper request status (Dean Nelson) [2061791]
- usb: typec: mux: Check dev_set_name() return value (Dean Nelson) [2061791]
- usb: dwc3: pci: Fix pm_runtime_get_sync() error checking (Dean Nelson) [2061791]
- usb: dwc3: gadget: Replace list_for_each_entry_safe() if using giveback (Dean Nelson) [2061791]
- usb: dwc3: core: Only handle soft-reset in DCTL (Dean Nelson) [2061791]
- usb: dwc3: Try usb-role-switch first in dwc3_drd_init (Dean Nelson) [2061791]
- usb: dwc3: core: Fix tx/rx threshold settings (Dean Nelson) [2061791]
- USB: storage: karma: fix rio_karma_init return (Dean Nelson) [2061791]
- xhci: Enable runtime PM on second Alderlake controller (Dean Nelson) [2061791]
- usb: misc: fix improper handling of refcount in uss720_probe() (Dean Nelson) [2061791]
- usb: typec: ucsi: Fix role swapping (Dean Nelson) [2061791]
- usb: typec: ucsi: Fix reuse of completion structure (Dean Nelson) [2061791]
- thunderbolt: Use different lane for second DisplayPort tunnel (Dean Nelson) [2061791]
- thunderbolt: Dump path config space entries during discovery (Dean Nelson) [2061791]
- thunderbolt: Use decimal number with port numbers (Dean Nelson) [2061791]
- xhci: increase usb U3 -> U0 link resume timeout from 100ms to 500ms (Dean Nelson) [2061791]
- xhci: stop polling roothubs after shutdown (Dean Nelson) [2061791]
- USB: Fix xhci event ring dequeue pointer ERDP update issue (Dean Nelson) [2061791]
- USB: storage: ums-realtek: fix error code in rts51x_read_mem() (Dean Nelson) [2061791]
- usb: early: xhci-dbc: Fix xdbc number parsing (Dean Nelson) [2061791]
- usb: early: xhci-dbc: Remove duplicate keep parsing (Dean Nelson) [2061791]
- USB: serial: pl2303: fix GS type detection (Dean Nelson) [2061791]
- usb: host: xhci: Remove some unnecessary return value initializations (Dean Nelson) [2061791]
- usb: host: xhci: add blank line in xhci_halt() (Dean Nelson) [2061791]
- usb: host: xhci: update hci_version operation in xhci_gen_setup() (Dean Nelson) [2061791]
- usb: host: xhci: fix a comment typo in xhci_mem_init() (Dean Nelson) [2061791]
- usb: host: xhci: use ffs() in xhci_mem_init() (Dean Nelson) [2061791]
- xhci: fix runtime PM imbalance in USB2 resume (Dean Nelson) [2061791]
- xhci: fix uninitialized string returned by xhci_decode_ctrl_ctx() (Dean Nelson) [2061791]
- xhci: fix garbage USBSTS being logged in some cases (Dean Nelson) [2061791]
- xhci: make xhci_handshake timeout for xhci_reset() adjustable (Dean Nelson) [2061791]
- xhci: omit mem read just after allocation of trb (Dean Nelson) [2061791]
- Revert "USB: serial: ch341: add new Product ID for CH341A" (Dean Nelson) [2061791]
- usb: xhci: fix minmax.cocci warnings (Dean Nelson) [2061791]
- usb: host: xhci: drop redundant checks (Dean Nelson) [2061791]
- xhci: Allocate separate command structures for each LPM command (Dean Nelson) [2061791]
- xhci: dbgtty: use IDR to support several dbc instances. (Dean Nelson) [2061791]
- xhci: dbc: Don't call dbc_tty_init() on every dbc tty probe (Dean Nelson) [2061791]
- xhci: dbc: Rename xhci_dbc_init and xhci_dbc_exit (Dean Nelson) [2061791]
- xhci: dbc: create and remove dbc structure in dbgtty driver. (Dean Nelson) [2061791]
- xhci: dbc: refactor xhci_dbc_init() (Dean Nelson) [2061791]
- usb: dwc3: pci: Fix Bay Trail phy GPIO mappings (Dean Nelson) [2061791]
- xhci: Prevent futile URB re-submissions due to incorrect return value. (Dean Nelson) [2061791]
- xhci: re-initialize the HC during resume if HCE was set (Dean Nelson) [2061791]
- usb: dwc3: pci: Add "snps,dis_u2_susphy_quirk" for Intel Bay Trail (Dean Nelson) [2061791]
- usb: dwc3: pci: add support for the Intel Raptor Lake-S (Dean Nelson) [2061791]
- usb: xhci-mtk: add support ip-sleep wakeup for mt8195 (Dean Nelson) [2061791]
- usb: dwc3: gadget: Prevent core from processing stale TRBs (Dean Nelson) [2061791]
- thunderbolt: Replace acpi_bus_get_device() (Dean Nelson) [2061791]
- thunderbolt: Add internal xHCI connect flows for Thunderbolt 3 devices (Dean Nelson) [2061791]
- thunderbolt: Add missing device ID to tb_switch_is_alpine_ridge() (Dean Nelson) [2061791]
- thunderbolt: Disable LTTPR on Intel Titan Ridge (Dean Nelson) [2061791]
- usb: ulpi: Call of_node_put correctly (Dean Nelson) [2061791]
- usb: ulpi: Move of_node_put to ulpi_dev_release (Dean Nelson) [2061791]
- usb: xhci-mtk: Use struct_size() helper in create_sch_ep() (Dean Nelson) [2061791]
- usb: common: ulpi: Fix crash in ulpi_match() (Dean Nelson) [2061791]
- usb: typec: tcpm: Do not disconnect when receiving VSAFE0V (Dean Nelson) [2061791]
- usb: typec: tcpm: Do not disconnect while receiving VBUS off (Dean Nelson) [2061791]
- xhci: Fresco FL1100 controller should not have BROKEN_MSI quirk set. (Dean Nelson) [2061791]
- usb: typec: tcpci: don't touch CC line if it's Vconn source (Dean Nelson) [2061791]
- thunderbolt: Remove useless DMA-32 fallback configuration (Dean Nelson) [2061791]
- media: uvcvideo: Support devices that report an OT as an entity source (Dean Nelson) [2061791]
- Revert "media: uvcvideo: Support devices that report an OT as an entity source" (Dean Nelson) [2061791]
- thunderbolt: Add module parameter for CLx disabling (Dean Nelson) [2061791]
- thunderbolt: Enable CL0s for Intel Titan Ridge (Dean Nelson) [2061791]
- thunderbolt: Rename Intel TB_VSE_CAP_IECS capability (Dean Nelson) [2061791]
- thunderbolt: Implement TMU time disruption for Intel Titan Ridge (Dean Nelson) [2061791]
- thunderbolt: Move usb4_switch_wait_for_bit() to switch.c (Dean Nelson) [2061791]
- thunderbolt: Add CL0s support for USB4 routers (Dean Nelson) [2061791]
- thunderbolt: Add TMU uni-directional mode (Dean Nelson) [2061791]
- xhci: use max() to make code cleaner (Dean Nelson) [2061791]
- usb: ftdi-elan: fix memory leak on device disconnect (Dean Nelson) [2061791]
- Revert "usb: early: convert to readl_poll_timeout_atomic()" (Dean Nelson) [2061791]
- usb: typec: tcpm: fix tcpm unregister port but leave a pending timer (Dean Nelson) [2061791]
- thunderbolt: Check return value of kmemdup() in icm_handle_event() (Dean Nelson) [2061791]
- media: dw2102: Fix use after free (Dean Nelson) [2061791]
- USB: serial: cp210x: fix CP2105 GPIO registration (Dean Nelson) [2061791]
- usb: xhci-mtk: fix list_del warning when enable list debug (Dean Nelson) [2061791]
- usb: core: config: fix validation of wMaxPacketValue entries (Dean Nelson) [2061791]
- xhci: avoid race between disable slot command and host runtime suspend (Dean Nelson) [2061791]
- xhci: Remove CONFIG_USB_DEFAULT_PERSIST to prevent xHCI from runtime suspending (Dean Nelson) [2061791]
- thunderbolt: Do not dereference fwnode in struct device (Dean Nelson) [2061791]
- thunderbolt: Add debug logging of DisplayPort resource allocation (Dean Nelson) [2061791]
- thunderbolt: Do not program path HopIDs for USB4 routers (Dean Nelson) [2061791]
- thunderbolt: Do not allow subtracting more NFC credits than configured (Dean Nelson) [2061791]
- thunderbolt: Runtime resume USB4 port when retimers are scanned (Dean Nelson) [2061791]
- thunderbolt: Tear down existing tunnels when resuming from hibernate (Dean Nelson) [2061791]
- thunderbolt: Runtime PM activate both ends of the device link (Dean Nelson) [2061791]
- thunderbolt: xdomain: Avoid potential stack OOB read (Dean Nelson) [2061791]
- media: uvcvideo: fix division by zero at stream start (Dean Nelson) [2061791]
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect (Dean Nelson) [2061791]
- xhci: Fix commad ring abort, write all 64 bits to CRCR register. (Dean Nelson) [2061791]
- usb: dwc3: gadget: Skip reading GEVNTSIZn (Dean Nelson) [2061791]
- usb: dwc3: gadget: Ignore Update Transfer cmd params (Dean Nelson) [2061791]
- usb: dwc3: gadget: Skip checking Update Transfer status (Dean Nelson) [2061791]
- usb: hub: Fix locking issues with address0_mutex (Dean Nelson) [2061791]
- media: dib0700: Only touch one bit when start/stop an adapter (Dean Nelson) [2061791]
- media: dib0700: cleanup start/stop streaming logic (Dean Nelson) [2061791]
- media: dib0700: fix undefined behavior in tuner shutdown (Dean Nelson) [2061791]
- media: s2255: fix control-message timeouts (Dean Nelson) [2061791]
- media: pvrusb2: fix control-message timeouts (Dean Nelson) [2061791]
- media: flexcop-usb: fix control-message timeouts (Dean Nelson) [2061791]
- usb: hub: Fix usb enumeration issue due to address0 race (Dean Nelson) [2061791]
- usb: typec: fusb302: Fix masking of comparator and bc_lvl interrupts (Dean Nelson) [2061791]
- usb: dwc3: gadget: Fix null pointer exception (Dean Nelson) [2061791]
- usb: dwc3: gadget: Check for L1/L2/U3 for Start Transfer (Dean Nelson) [2061791]
- usb: dwc3: gadget: Ignore NoStream after End Transfer (Dean Nelson) [2061791]
- usb: xhci-mtk: fix random remote wakeup (Dean Nelson) [2061791]
- usb: xhci-mtk: remove unnecessary error check (Dean Nelson) [2061791]
- USB: serial: keyspan: fix memleak on probe errors (Dean Nelson) [2061791]
- USB: iowarrior: fix control-message timeouts (Dean Nelson) [2061791]
- usb: dwc3: gadget: Skip resizing EP's TX FIFO if already resized (Dean Nelson) [2061791]
- usb: dwc3: gadget: Change to dev_dbg() when queuing to inactive gadget/ep (Dean Nelson) [2061791]
- xhci: Enable trust tx length quirk for Fresco FL11 USB controller (Dean Nelson) [2061791]
- xhci: Fix command ring pointer corruption while aborting a command (Dean Nelson) [2061791]
- USB: xhci: dbc: fix tty registration race (Dean Nelson) [2061791]
- xhci: add quirk for host controllers that don't update endpoint DCS (Dean Nelson) [2061791]
- xhci: guard accesses to ep_state in xhci_endpoint_reset() (Dean Nelson) [2061791]
- media: usb: dvd-usb: fix uninit-value bug in dibusb_read_eeprom_byte() (Dean Nelson) [2061791]
- USB: cdc-acm: fix break reporting (Dean Nelson) [2061791]
- USB: cdc-acm: fix racy tty buffer accesses (Dean Nelson) [2061791]
- usb: typec: tcpm: handle SRC_STARTUP state if cc changes (Dean Nelson) [2061791]
- usb: typec: tcpci: don't handle vSafe0V event if it's not enabled (Dean Nelson) [2061791]
- usb: xhci-mtk: use xhci_dbg() to print log (Dean Nelson) [2061791]
- media: mxl111sf: change mutex_init() location (Dean Nelson) [2061791]
- media: tm6000: Avoid card name truncation (Dean Nelson) [2061791]
- media: gspca: Limit frame size to sizeimage. (Dean Nelson) [2061791]
- media: uvcvideo: Don't spam the log in uvc_ctrl_restore_values() (Dean Nelson) [2061791]
- media: uvcvideo: Increase the size of UVC_METADATA_BUF_SIZE (Dean Nelson) [2061791]
- media: uvcvideo: Return -EIO for control errors (Dean Nelson) [2061791]
- media: uvcvideo: Remove unused including <linux/version.h> (Dean Nelson) [2061791]
- media: m5602_ov7660: remove the repeated declaration (Dean Nelson) [2061791]
- media: dvb-usb: fix ununit-value in az6027_rc_query (Dean Nelson) [2061791]
- thunderbolt: Fix -Wrestrict warning (Dean Nelson) [2061791]
- USB: serial: cp210x: fix dropped characters with CP2102 (Dean Nelson) [2061791]
- usb: dwc3: gadget: Avoid starting DWC3 gadget during UDC unbind (Dean Nelson) [2061791]
- USB: serial: option: remove duplicate USB device ID (Dean Nelson) [2061791]
- USB: serial: mos7840: remove duplicated 0xac24 device ID (Dean Nelson) [2061791]
- USB: cdc-acm: fix minor-number release (Dean Nelson) [2061791]
- usb: dwc3: reference clock period configuration (Dean Nelson) [2061791]
- usb: xhci-mtk: allow bandwidth table rollover (Dean Nelson) [2061791]
- usb: xhci-mtk: modify the SOF/ITP interval for mt8195 (Dean Nelson) [2061791]
- usb: xhci-mtk: add a member of num_esit (Dean Nelson) [2061791]
- usb: xhci-mtk: check boundary before check tt (Dean Nelson) [2061791]
- usb: xhci-mtk: update fs bus bandwidth by bw_budget_table (Dean Nelson) [2061791]
- usb: xhci-mtk: support option to disable usb2 ports (Dean Nelson) [2061791]
- usb: xhci-mtk: fix use-after-free of mtk->hcd (Dean Nelson) [2061791]
- usb: dwc3: pci: add support for AMD's newer generation platform. (Dean Nelson) [2061791]
- xhci: Add bus number to some debug messages (Dean Nelson) [2061791]
- xhci: Add additional dynamic debug to follow URBs in cancel and error cases. (Dean Nelson) [2061791]
- Revert "USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST quirk set" (Dean Nelson) [2061791]
- xhci: Fix failure to give back some cached cancelled URBs. (Dean Nelson) [2061791]
- xhci: fix even more unsafe memory usage in xhci tracing (Dean Nelson) [2061791]
- xhci: fix unsafe memory usage in xhci tracing (Dean Nelson) [2061791]
- usb: typec: tcpm: Support non-PD mode (Dean Nelson) [2061791]
- USB: serial: cp210x: determine fw version for CP2105 and CP2108 (Dean Nelson) [2061791]
- USB: serial: cp210x: clean up type detection (Dean Nelson) [2061791]
- USB: serial: cp210x: clean up set-chars request (Dean Nelson) [2061791]
- USB: serial: cp210x: clean up control-request timeout (Dean Nelson) [2061791]
- USB: serial: cp210x: fix flow-control error handling (Dean Nelson) [2061791]
- USB: serial: cp210x: fix control-characters error handling (Dean Nelson) [2061791]
- tty: drop put_tty_driver (Dean Nelson) [2061791]
- media: dvb-usb: fix uninit-value in vp702x_read_mac_addr (Dean Nelson) [2061791]
- media: dvb-usb: fix uninit-value in dvb_usb_adapter_dvb_init (Dean Nelson) [2061791]
- usb: renesas-xhci: Remove renesas_xhci_pci_exit() (Dean Nelson) [2061791]
- usb: dwc3: Resize TX FIFOs to meet EP bursting requirements (Dean Nelson) [2061791]
- memstick: rtsx_usb_ms: fix UAF (Dean Nelson) [2061791]
- usb: dwc3: gadget: Clear DEP flags after stop transfers in ep disable (Dean Nelson) [2061791]
- usb: dwc3: gadget: Set gadget_max_speed when set ssp_rate (Dean Nelson) [2061791]
- usb: dwc3: gadget: Prevent EP queuing while stopping transfers (Dean Nelson) [2061791]
- media: lmedm04: Fix misuse of comma (Dean Nelson) [2061791]
- media: tm6000: Fix memleak in tm6000_start_stream (Dean Nelson) [2061791]
- usb: dwc3: gadget: Restart DWC3 gadget when enabling pullup (Dean Nelson) [2061791]
- memstick: Skip allocating card when removing host (Dean Nelson) [2061791]
- USB: Replace zero-length array with flexible-array member (Dean Nelson) [2061791]
- USB: xhci: fix 'broken_suspend' placement in struct xchi_hcd (Dean Nelson) [2061791]
- Revert "[usb] USB: xhci: fix 'broken_suspend' placement in struct xchi_hcd" (Dean Nelson) [2061791]
- memstick: rtsx_usb_ms: Support runtime power management (Dean Nelson) [2061791]
- memstick: rtsx_usb_ms: Use ms_dev() helper (Dean Nelson) [2061791]
- memstick: Prevent memstick host from getting runtime suspended during card detection (Dean Nelson) [2061791]
- misc: rtsx_usb: Use USB remote wakeup signaling for card insertion detection (Dean Nelson) [2061791]
- memstick: rtsx_usb_ms: Add missing pm_runtime_disable() in probe function (Dean Nelson) [2061791]

* Thu Jul 28 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-413.el8]
- RDMA/qedr: Fix reporting QP timeout attribute (Kamal Heib) [2083620]
- NFSD: Handle COPYer - Not suppored in RHEL8 (Benjamin Coddington) [2108628]
- NFSD add ca_source_server<> to COPY (Benjamin Coddington) [2108628]
- NFS NFSD: defining nl4_servers structure needed by both (Benjamin Coddington) [2108628]
- fix backport powerpc/uaccess: get rid of small constant size cases in raw_copy_{to,from}_user() (Diego Domingos) [2106984]
- bpf: Enable bpf_ktime_get_coarse_ns helper (Viktor Malik) [2105133]
- kernel/resource: Introduce request_mem_region_muxed() (Sudheesh Mavila) [2047999]
- i2c: piix4: Enable EFCH MMIO for Family 17h+ (Sudheesh Mavila) [2047999]
- i2c: piix4: Add EFCH MMIO support for SMBus port select (Sudheesh Mavila) [2047999]
- i2c: piix4: Add EFCH MMIO support to SMBus base address detect (Sudheesh Mavila) [2047999]
- i2c: piix4: Add EFCH MMIO support to region request and release (Sudheesh Mavila) [2047999]
- i2c: piix4: Move SMBus port selection into function (Sudheesh Mavila) [2047999]
- i2c: piix4: Move SMBus controller base address detect into function (Sudheesh Mavila) [2047999]
- i2c: piix4: Move port I/O region request/release code into functions (Sudheesh Mavila) [2047999]
- i2c: piix4: Replace hardcoded memory map size with a #define (Sudheesh Mavila) [2047999]
- i2c: piix4: Detect secondary SMBus controller on AMD AM4 chipsets (Sudheesh Mavila) [2047999]
- i2c: piix4: Add ACPI support (Sudheesh Mavila) [2047999]
- i2c: piix4: Fix probing of reserved ports on AMD Family 16h Model 30h (Sudheesh Mavila) [2047999]
- i2c: piix4: Fix port selection for AMD Family 16h Model 30h (Sudheesh Mavila) [2047999]
- i2c-piix4: Add Hygon Dhyana SMBus support (Sudheesh Mavila) [2047999]
- tracing: Remove WARN_ON in start_thread() (Jerome Marchand) [2090967]
- net: usb: Fix spelling mistakes (José Ignacio Tornos Martínez) [1984353]
- net: usb: cdc_ether: record speed in status method (José Ignacio Tornos Martínez) [1984353]
- net: usb: usbnet: add method for reporting speed without MII (José Ignacio Tornos Martínez) [1984353]
- e1000e: Fix possible overflow in LTR decoding (Ken Cox) [2037965]
- e1000e: Print PHY register address when MDI read/write fails (Ken Cox) [2037965]
- e1000e: Correct NVM checksum verification flow (Ken Cox) [2037965]
- e1000e: Fix possible HW unit hang after an s0ix exit (Ken Cox) [2037965 2049952]
- e1000e: Handshake with CSME starts from ADL platforms (Ken Cox) [2037965 2049952]
- e1000e: Separate ADP board type from TGP (Ken Cox) [2037965 2049952]
- e1000e: Remove useless DMA-32 fallback configuration (Ken Cox) [2037965]
- e1000e: Remove redundant statement (Ken Cox) [2037965]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037965]
- net: e1000e: solve insmod 'Unknown symbol mutex_lock' error (Ken Cox) [2037965]
- RDMA/irdma: Add SW mechanism to generate completions on error (Kamal Heib) [2100316]
- RDMA/irdma: Remove the redundant variable (Kamal Heib) [2100316]
- RDMA/irdma: Add support for DSCP (Kamal Heib) [2100316]
- RDMA/irdma: Use irq_update_affinity_hint() (Kamal Heib) [2100316]
- RDMA/irdma: Set protocol based on PF rdma_mode flag (Kamal Heib) [2100316 2096481]
- virtio-ring: fix DMA metadata flags (Cindy Lu) [1969742]
- virtio_ring: fix typos in vring_desc_extra (Jason Wang) [1969742]
- virtio-ring: store DMA metadata in desc_extra for split virtqueue (Jason Wang) [1969742]
- virtio: use err label in __vring_new_virtqueue() (Jason Wang) [1969742]
- virtio_ring: introduce virtqueue_desc_add_split() (Jason Wang) [1969742]
- virtio_ring: secure handling of mapping errors (Jason Wang) [1969742]
- virtio-ring: factor out desc_extra allocation (Jason Wang) [1969742]
- virtio_ring: rename vring_desc_extra_packed (Jason Wang) [1969742]
- virtio-ring: maintain next in extra state for packed virtqueue (Jason Wang) [1969742]
- drivers/base: fix userspace break from using bin_attributes for cpumap and cpulist (Phil Auld) [2089715]
- rpminspect: disable abidiff scanning (Jarod Wilson)

* Mon Jul 25 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-412.el8]
- Netvsc: Call hv_unmap_memory() in the netvsc_device_remove() (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Release cpu lock in error case (Mohammed Gamal) [2086613]
- Drivers: hv: Fix syntax errors in comments (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Don't assign VMbus channel interrupts to isolated CPUs (Mohammed Gamal) [2086613]
- hv_balloon: Fix balloon_probe() and balloon_remove() error handling (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: fix typo in comment (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Remove support for Hyper-V 2008 and Hyper-V 2008R2/Win7 (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Refactor the ring-buffer iterator functions (Mohammed Gamal) [2086613]
- hv_sock: Copy packets sent by Hyper-V out of the ring buffer (Mohammed Gamal) [2086613]
- hv_sock: Check hv_pkt_iter_first_raw()'s return value (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Accept hv_sock offers in isolated guests (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Introduce {lock,unlock}_requestor() (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Introduce vmbus_request_addr_match() (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Introduce vmbus_sendpacket_getid() (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Fix handling of messages with transaction ID of zero (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Add VMbus IMC device to unsupported list (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Replace smp_store_mb() with virt_store_mb() (Mohammed Gamal) [2086613]
- Drivers: hv: balloon: Disable balloon and hot-add accordingly (Mohammed Gamal) [2086613]
- Drivers: hv: balloon: Support status report for larger page sizes (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Prevent load re-ordering when reading ring buffer (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Fix potential crash on module unload (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Fix initialization of device object in vmbus_device_register() (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Deactivate sysctl_record_panic_msg by default in isolated guests (Mohammed Gamal) [2086613]
- drivers: hv: log when enabling crash_kexec_post_notifiers (Mohammed Gamal) [2086613]
- Drivers: hv: utils: Make use of the helper macro LIST_HEAD() (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Rework use of DMA_BIT_MASK(64) (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Fix memory leak in vmbus_add_channel_kobj (Mohammed Gamal) [2086613]
- Drivers: hv: Compare cpumasks and not their weights in init_vp_index() (Mohammed Gamal) [2086613]
- Drivers: hv: Rename 'alloced' to 'allocated' (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Use struct_size() helper in kmalloc() (Mohammed Gamal) [2086613]
- Drivers: hv: balloon: account for vmbus packet header in max_pkt_size (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Initialize request offers message for Isolation VM (Mohammed Gamal) [2086613]
- Drivers: hv: Fix definition of hypercall input & output arg variables (Mohammed Gamal) [2086613]
- net: netvsc: Add Isolation VM support for netvsc driver (Mohammed Gamal) [2086613]
- scsi: storvsc: Add Isolation VM support for storvsc driver (Mohammed Gamal) [2086613]
- Drivers: hv : vmbus: Adding NULL pointer check (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Remove unused code to check for subchannels (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Initialize VMbus ring buffer for Isolation VM (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Add SNP support for VMbus channel initiate message (Mohammed Gamal) [2086613]
- Drivers: hv: vmbus: Mark vmbus ring buffer visible to host in Isolation VM (Mohammed Gamal) [2086613]
- SUNRPC: Don't leak sockets in xs_local_connect() (Jeffrey Layton) [2089429]
- SUNRPC: clean up some inconsistent indenting (Jeffrey Layton) [2089429]
- SUNRPC: Ensure we flush any closed sockets before xs_xprt_free() (Jeffrey Layton) [2089429]
- SUNRPC: Don't call connect() more than once on a TCP socket (Jeffrey Layton) [2089429]
- net: openvswitch: fix misuse of the cached connection on tuple changes (Timothy Redaelli) [2099213]
- sfc: fix considering that all channels have TX queues (Íñigo Huguet) [1851823]
- sfc: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [1851823]
- intel/igb:fix repeated words in comments (Corinna Vinschen) [2037959]
- igb: remove unexpected word "the" (Corinna Vinschen) [2037959]
- igb: Make DMA faster when CPU is active on the PCIe link (Corinna Vinschen) [2037959]
- igb: fix a use-after-free issue in igb_clean_tx_ring (Corinna Vinschen) [2037959]
- igb: Remove duplicate defines (Corinna Vinschen) [2037959]
- igb: skip phy status check where unavailable (Corinna Vinschen) [2037959]
- igb: Convert kmap() to kmap_local_page() (Corinna Vinschen) [2037959]
- igb: zero hwtstamp by default (Corinna Vinschen) [2037959]
- igb: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037959]
- PCI: Work around Intel I210 ROM BAR overlap defect (Corinna Vinschen) [2037959]
- igb: support EXTTS on 82580/i354/i350 (Corinna Vinschen) [2037959]
- igb: support PEROUT on 82580/i354/i350 (Corinna Vinschen) [2037959]
- igb: move PEROUT and EXTTS isr logic to separate functions (Corinna Vinschen) [2037959]
- igb: move SDP config initialization to separate function (Corinna Vinschen) [2037959]
- igb: switch to napi_build_skb() (Corinna Vinschen) [2037959]
- igb: remove never changed variable `ret_val' (Corinna Vinschen) [2037959]
- NFSv4: Add an fattr allocation to _nfs4_discover_trunking() (Scott Mayhew) [2096393]
- sunrpc: set cl_max_connect when cloning an rpc_clnt (Scott Mayhew) [2096393]
- NFSv4.1 mark qualified async operations as MOVEABLE tasks (Scott Mayhew) [2096393]
- powerpc/rtas: Allow ibm,platform-dump RTAS call with null buffer address (Desnes A. Nunes do Rosario) [2095041]
- audit: free module name (Richard Guy Briggs) [2100259]
- bfq: fix blkio cgroup leakage v4 (Ming Lei) [2093206]
- scsi: scsi_dh_alua: Properly handle the ALUA transitioning state (Ewan D. Milne) [1992870]
- mm: sparse: remove __section_nr() function (Mark Langsdorf) [2067280]
- mm: sparse: pass section_nr to find_memory_block (Mark Langsdorf) [2067280]
- mm: sparse: pass section_nr to section_mark_present (Mark Langsdorf) [2067280]
- headers/uninline: Uninline single-use function: kobject_has_children() (Mark Langsdorf) [2067280]
- arch_topology: Do not set llc_sibling if llc_id is invalid (Mark Langsdorf) [2067280]
- topology: make core_mask include at least cluster_siblings (Mark Langsdorf) [2067280]
- regmap: allow a defined reg_base to be added to every address (Mark Langsdorf) [2067280]
- regmap: add configurable downshift for addresses (Mark Langsdorf) [2067280]
- drivers/base/dd.c : Remove the initial value of the global variable (Mark Langsdorf) [2067280]
- devres: fix typos in comments (Mark Langsdorf) [2067280]
- base: soc: Make soc_device_match() simpler and easier to read (Mark Langsdorf) [2067280]
- driver core: Refactor sysfs and drv/bus remove hooks (Mark Langsdorf) [2067280]
- driver core: Refactor multiple copies of device cleanup (Mark Langsdorf) [2067280]
- arch_topology: obtain cpu capacity using information from CPPC (Mark Langsdorf) [2067280]
- PM: core: keep irq flags in device_pm_check_callbacks() (Mark Langsdorf) [2067280]
- PM: sleep: Add device name to suspend_report_result() (Mark Langsdorf) [2067280]
- PM: runtime: Have devm_pm_runtime_enable() handle pm_runtime_dont_use_autosuspend() (Mark Langsdorf) [2067280]
- PM: sleep: wakeup: Fix typos in comments (Mark Langsdorf) [2067280]
- PM: domains: Fix sleep-in-atomic bug caused by genpd_debug_remove() (Mark Langsdorf) [2067280]
- PM: domains: use dev_err_probe() to simplify error handling (Mark Langsdorf) [2067280]
- PM: domains: Prevent power off for parent unless child is in deepest state (Mark Langsdorf) [2067280]
- driver core: cleanup double words comments (Mark Langsdorf) [2067280]
- device property: Don't split fwnode_get_irq*() APIs in the code (Mark Langsdorf) [2067280]
- regmap: irq: cleanup comments (Mark Langsdorf) [2067280]
- platform: use dev_err_probe() in platform_get_irq_byname() (Mark Langsdorf) [2067280]
- devtmpfs: drop redundant fs parameters from internal fs (Mark Langsdorf) [2067280]
- component: Replace most references to 'master' with 'aggregate device' (Mark Langsdorf) [2067280]
- device property: Add fwnode_irq_get_byname (Mark Langsdorf) [2067280]
- regmap-irq: Fix typo in comment (Mark Langsdorf) [2067280]
- driver core: Free DMA range map when device is released (Mark Langsdorf) [2067280]
- regmap-irq: Update interrupt clear register for proper reset (Mark Langsdorf) [2067280]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067280]
- devtmpfs regression fix: reconfigure on each mount (Mark Langsdorf) [2067280]
- regmap: debugfs: Fix indentation (Mark Langsdorf) [2067280]
- regmap: Call regmap_debugfs_exit() prior to _init() (Mark Langsdorf) [2067280]
- driver core: Make bus notifiers in right order in really_probe() (Mark Langsdorf) [2067280]
- driver core: Move driver_sysfs_remove() after driver_sysfs_add() (Mark Langsdorf) [2067280]
- driver core: Simplify async probe test code by using ktime_ms_delta() (Mark Langsdorf) [2067280]
- PM: runtime: Simplify locking in pm_runtime_put_suppliers() (Mark Langsdorf) [2067280]
- software node: fix wrong node passed to find nargs_prop (Mark Langsdorf) [2067280]
- driver core: platform: document registration-failure requirement (Mark Langsdorf) [2067280]
- device property: Add fwnode_iomap() (Mark Langsdorf) [2067280]
- device property: Use fwnode_graph_for_each_endpoint() macro (Mark Langsdorf) [2067280]
- device property: Implement fwnode_graph_get_endpoint_count() (Mark Langsdorf) [2067280]
- device property: Fix documentation for FWNODE_GRAPH_DEVICE_DISABLED (Mark Langsdorf) [2067280]
- rtc: Check return value from mc146818_get_time() (Mark Langsdorf) [2067280]
- device property: Check fwnode->secondary when finding properties (Mark Langsdorf) [2067280]
- topology/sysfs: rework book and drawer topology ifdefery (Mark Langsdorf) [2067280]
- topology/sysfs: export cluster attributes only if an architectures has support (Mark Langsdorf) [2067280]
- topology/sysfs: export die attributes only if an architectures has support (Mark Langsdorf) [2067280]
- driver core: Don't call device_remove_properties() from device_del() (Mark Langsdorf) [2067280]
- regmap: allow to define reg_update_bits for no bus configuration (Mark Langsdorf) [2067280]
- platform/x86: amd-pmc: Set QOS during suspend on CZN w/ timer wakeup (Mark Langsdorf) [2067250]
- PM: sleep: Fix error handling in dpm_prepare() (Mark Langsdorf) [2067250]
- PM: sleep: Avoid calling put_device() under dpm_list_mtx (Mark Langsdorf) [2067250]
- PM: sleep: Fix runtime PM based cpuidle support (Mark Langsdorf) [2067250]
- PM / wakeirq: support enabling wake-up irq after runtime_suspend called (Mark Langsdorf) [2067250]
- device property: Drop redundant NULL checks (Mark Langsdorf) [2067250]
- PM: sleep: Pause cpuidle later and resume it earlier during system transitions (Mark Langsdorf) [2067250]
- PM: suspend: Do not pause cpuidle in the suspend-to-idle path (Mark Langsdorf) [2067250]
- regmap: spi: Set regmap max raw r/w from max_transfer_size (Mark Langsdorf) [2067250]
- PM: sleep: Do not let "syscore" devices runtime-suspend during system transitions (Mark Langsdorf) [2067250]
- component: do not leave master devres group open after bind (Mark Langsdorf) [2067250]
- driver core: Provide device_match_acpi_handle() helper (Mark Langsdorf) [2067250]
- regmap: Fix possible double-free in regcache_rbtree_exit() (Mark Langsdorf) [2067250]
- device property: build kunit tests without structleak plugin (Mark Langsdorf) [2067250]
- driver core: Reject pointless SYNC_STATE_ONLY device links (Mark Langsdorf) [2067250]
- firmware_loader: add a sanity check for firmware_request_builtin() (Mark Langsdorf) [2067250]
- firmware_loader: split built-in firmware call (Mark Langsdorf) [2067250]
- firmware_loader: fix pre-allocated buf built-in firmware use (Mark Langsdorf) [2067250]
- drivers/base/component.c: remove superfluous header files from component.c (Mark Langsdorf) [2067250]
- drivers/base/arch_topology.c: remove superfluous header (Mark Langsdorf) [2067250]
- driver core: use NUMA_NO_NODE during device_initialize (Mark Langsdorf) [2067250]
- driver core: Fix possible memory leak in device_link_add() (Mark Langsdorf) [2067250]
- driver core: Add debug logs when fwnode links are added/deleted (Mark Langsdorf) [2067250]
- driver core: Create __fwnode_link_del() helper function (Mark Langsdorf) [2067250]
- driver core: Set deferred probe reason when deferred by driver core (Mark Langsdorf) [2067250]
- driver core: fw_devlink: Add support for FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD (Mark Langsdorf) [2067250]
- driver core: Clarify that dev_err_probe() is OK even w/out -EPROBE_DEFER (Mark Langsdorf) [2067250]
- driver core: fw_devlink: Improve handling of cyclic dependencies (Mark Langsdorf) [2067250]
- software node: balance refcount for managed software nodes (Mark Langsdorf) [2067250]
- driver core: platform: Make use of the helper macro SET_RUNTIME_PM_OPS() (Mark Langsdorf) [2067250]
- PM: base: power: don't try to use non-existing RTC for storing data (Mark Langsdorf) [2067250]
- PM: sleep: core: Avoid setting power.must_resume to false (Mark Langsdorf) [2067250]
- PM: sleep: wakeirq: drop useless parameter from dev_pm_attach_wake_irq() (Mark Langsdorf) [2067250]
- PM: domains: Fix domain attach for CONFIG_PM_OPP=n (Mark Langsdorf) [2067250]
- PM: runtime: add devm_pm_clk_create helper (Mark Langsdorf) [2067250]
- PM: runtime: add devm_pm_runtime_enable helper (Mark Langsdorf) [2067250]
- regmap: teach regmap to use raw spinlocks if requested in the config (Mark Langsdorf) [2067250]
- PM: domains: Add support for 'required-opps' to set default perf state (Mark Langsdorf) [2067250]
- Revert "media: device property: Call fwnode_graph_get_endpoint_by_id() for fwnode->secondary" (Mark Langsdorf) [2067250]
- driver: base: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067250]
- cacheinfo: clear cache_leaves(cpu) in free_cache_attributes() (Mark Langsdorf) [2067250]
- driver core: Fix error return code in really_probe() (Mark Langsdorf) [2067250]
- driver: base: Replace symbolic permissions with octal permissions (Mark Langsdorf) [2067250]
- regmap: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067250]
- regmap: fix the offset of register error log (Mark Langsdorf) [2067250]
- bpf: Fix request_sock leak in sk lookup helpers (Antoine Tenart) [2085313]
- crypto: fips - make proc files report fips module name and version (Vladis Dronov) [2103966]
- net: tipc: fix possible refcount leak in tipc_sk_create() (Xin Long) [2106048]
- tipc: move bc link creation back to tipc_node_create (Xin Long) [2106048]
- tipc: fix use-after-free Read in tipc_named_reinit (Xin Long) [2106048]
- tipc: check attribute length for bearer name (Xin Long) [2106048]
- ice: Fix memory corruption in VF driver (Petr Oros) [2037937]
- ice: Fix queue config fail handling (Petr Oros) [2037937]
- ice: Sync VLAN filtering features for DVM (Petr Oros) [2037937]
- ice: Fix PTP TX timestamp offset calculation (Petr Oros) [2037937]
- ice: Fix interrupt moderation settings getting cleared (Petr Oros) [2037937]
- ice: fix possible under reporting of ethtool Tx and Rx statistics (Petr Oros) [2037937]
- ice: allow creating VFs for !CONFIG_NET_SWITCHDEV (Petr Oros) [2037937]
- ice: add trace events for tx timestamps (Petr Oros) [2037937]
- ice: fix return value check in ice_gnss.c (Petr Oros) [2037937]
- ice: remove PF pointer from ice_check_vf_init (Petr Oros) [2037937]
- ice: introduce ice_virtchnl.c and ice_virtchnl.h (Petr Oros) [2037937]
- ice: cleanup long lines in ice_sriov.c (Petr Oros) [2037937]
- ice: introduce ICE_VF_RESET_LOCK flag (Petr Oros) [2037937]
- ice: introduce ICE_VF_RESET_NOTIFY flag (Petr Oros) [2037937]
- ice: convert ice_reset_vf to take flags (Petr Oros) [2037937]
- ice: convert ice_reset_vf to standard error codes (Petr Oros) [2037937]
- ice: make ice_reset_all_vfs void (Petr Oros) [2037937]
- ice: drop is_vflr parameter from ice_reset_all_vfs (Petr Oros) [2037937]
- ice: move reset functionality into ice_vf_lib.c (Petr Oros) [2037937]
- ice: fix a long line warning in ice_reset_vf (Petr Oros) [2037937]
- ice: introduce VF operations structure for reset flows (Petr Oros) [2037937]
- ice: fix incorrect dev_dbg print mistaking 'i' for vf->vf_id (Petr Oros) [2037937]
- ice: introduce ice_vf_lib.c, ice_vf_lib.h, and ice_vf_lib_private.h (Petr Oros) [2037937]
- ice: use ice_is_vf_trusted helper function (Petr Oros) [2037937]
- ice: log an error message when eswitch fails to configure (Petr Oros) [2037937]
- ice: cleanup error logging for ice_ena_vfs (Petr Oros) [2037937]
- ice: move ice_set_vf_port_vlan near other .ndo ops (Petr Oros) [2037937]
- ice: refactor spoofchk control code in ice_sriov.c (Petr Oros) [2037937]
- ice: rename ICE_MAX_VF_COUNT to avoid confusion (Petr Oros) [2037937]
- ice: remove unused definitions from ice_sriov.h (Petr Oros) [2037937]
- ice: convert vf->vc_ops to a const pointer (Petr Oros) [2037937]
- ice: remove circular header dependencies on ice.h (Petr Oros) [2037937]
- ice: rename ice_virtchnl_pf.c to ice_sriov.c (Petr Oros) [2037937]
- ice: rename ice_sriov.c to ice_vf_mbx.c (Petr Oros) [2037937]
- ice: Fix FV offset searching (Petr Oros) [2037937]
- ice: Add support for outer dest MAC for ADQ tunnels (Petr Oros) [2037937]
- ice: avoid XDP checks in ice_clean_tx_irq() (Petr Oros) [2037937]
- ice: change "can't set link" message to dbg level (Petr Oros) [2037937]
- ice: Add slow path offload stats on port representor in switchdev (Petr Oros) [2037937]
- ice: Add support for inner etype in switchdev (Petr Oros) [2037937]
- ice: convert VF storage to hash table with krefs and RCU (Petr Oros) [2037937]
- ice: introduce VF accessor functions (Petr Oros) [2037937]
- ice: factor VF variables to separate structure (Petr Oros) [2037937]
- ice: convert ice_for_each_vf to include VF entry iterator (Petr Oros) [2037937]
- ice: use ice_for_each_vf for iteration during removal (Petr Oros) [2037937]
- ice: remove checks in ice_vc_send_msg_to_vf (Petr Oros) [2037937]
- ice: move VFLR acknowledge during ice_free_vfs (Petr Oros) [2037937]
- ice: move clear_malvf call in ice_free_vfs (Petr Oros) [2037937]
- ice: pass num_vfs to ice_set_per_vf_res() (Petr Oros) [2037937]
- ice: store VF pointer instead of VF ID (Petr Oros) [2037937]
- ice: refactor unwind cleanup in eswitch mode (Petr Oros) [2037937]
- ice: add TTY for GNSS module for E810T device (Petr Oros) [2037937]
- ice: Simplify tracking status of RDMA support (Petr Oros) [2037937]
- ice: Add ability for PF admin to enable VF VLAN pruning (Petr Oros) [2037937]
- ice: Add support for 802.1ad port VLANs VF (Petr Oros) [2037937]
- ice: Advertise 802.1ad VLAN filtering and offloads for PF netdev (Petr Oros) [2037937]
- ice: Support configuring the device to Double VLAN Mode (Petr Oros) [2037937]
- ice: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037937]
- ice: Add hot path support for 802.1Q and 802.1ad VLAN offloads (Petr Oros) [2037937]
- ice: Add outer_vlan_ops and VSI specific VLAN ops implementations (Petr Oros) [2037937]
- ice: Adjust naming for inner VLAN operations (Petr Oros) [2037937]
- ice: Use the proto argument for VLAN ops (Petr Oros) [2037937]
- ice: Refactor vf->port_vlan_info to use ice_vlan (Petr Oros) [2037937]
- ice: Introduce ice_vlan struct (Petr Oros) [2037937]
- ice: Add new VSI VLAN ops (Petr Oros) [2037937]
- ice: Add helper function for adding VLAN 0 (Petr Oros) [2037937]
- ice: Refactor spoofcheck configuration functions (Petr Oros) [2037937]
- Revert "ice: Allow to pass VLAN tagged packets to VF when port VLAN is configured" (Petr Oros) [2037937]
- Revert "ice: Do not enable VLAN pruning when spoofchk is enabled" (Petr Oros) [2037937]
- ice: Remove likely for napi_complete_done (Petr Oros) [2037937]
- ice: add support for DSCP QoS for IDC (Petr Oros) [2037937]
- ice: respect metadata on XSK Rx to skb (Petr Oros) [2037937]
- ice: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Petr Oros) [2037937]
- ice: respect metadata in legacy-rx/ice_construct_skb() (Petr Oros) [2037937]
- ice: Fix broken IFF_ALLMULTI handling (Petr Oros) [2037937]

* Wed Jul 20 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-411.el8]
- i40e: Fix call trace in setup_tx_descriptors (Ivan Vecera) [2037943]
- i40e: Fix calculating the number of queue pairs (Ivan Vecera) [2037943]
- i40e: Fix adding ADQ filter to TC0 (Ivan Vecera) [2037943]
- i40e: i40e_main: fix a missing check on list iterator (Ivan Vecera) [2037943]
- i40e, xsk: Get rid of redundant 'fallthrough' (Ivan Vecera) [2037943]
- i40e, xsk: Diversify return values from xsk_wakeup call paths (Ivan Vecera) [2037943]
- i40e, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ivan Vecera) [2037943]
- i40e: Add Ethernet Connection X722 for 10GbE SFP+ support (Ivan Vecera) [2037943]
- i40e: Add vsi.tx_restart to i40e ethtool stats (Ivan Vecera) [2037943]
- i40e: Add tx_stopped stat (Ivan Vecera) [2037943]
- i40e: Add support for MPLS + TSO (Ivan Vecera) [2037943]
- i40e: little endian only valid checksums (Ivan Vecera) [2037943]
- i40e: stop disabling VFs due to PF error responses (Ivan Vecera) [2037943]
- i40e: remove dead stores on XSK hotpath (Ivan Vecera) [2037943]
- i40e: Add a stat for tracking busy rx pages (Ivan Vecera) [2037943]
- i40e: Add a stat for tracking pages waived (Ivan Vecera) [2037943]
- i40e: Add a stat tracking new RX page allocations (Ivan Vecera) [2037943]
- i40e: Aggregate and export RX page reuse stat (Ivan Vecera) [2037943]
- i40e: Remove rx page reuse double count (Ivan Vecera) [2037943]
- i40e: Fix race condition while adding/deleting MAC/VLAN filters (Ivan Vecera) [2037943]
- i40e: Add new version of i40e_aq_add_macvlan function (Ivan Vecera) [2037943]
- i40e: Add new versions of send ASQ command functions (Ivan Vecera) [2037943]
- i40e: Add sending commands in atomic context (Ivan Vecera) [2037943]
- i40e: Remove unused RX realloc stat (Ivan Vecera) [2037943]
- i40e: Disable hw-tc-offload feature on driver load (Ivan Vecera) [2037943]
- i40e: Fix reset path while removing the driver (Ivan Vecera) [2037943]
- i40e: respect metadata on XSK Rx to skb (Ivan Vecera) [2037943]
- i40e: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ivan Vecera) [2037943]
- i40e: Remove useless DMA-32 fallback configuration (Ivan Vecera) [2037943]
- i40e: fix unsigned stat widths (Ivan Vecera) [2037943]
- i40e: Fix for failed to init adminq while VF reset (Ivan Vecera) [2037943]
- i40e: Fix queues reservation for XDP (Ivan Vecera) [2037943]
- i40e: Fix issue when maximum queues is exceeded (Ivan Vecera) [2037943]
- i40e: Increase delay to 1 s after global EMP reset (Ivan Vecera) [2037943]
- i40e: remove variables set but not used (Ivan Vecera) [2037943]
- i40e: Remove non-inclusive language (Ivan Vecera) [2037943]
- i40e: Update FW API version (Ivan Vecera) [2037943]
- i40e: Minimize amount of busy-waiting during AQ send (Ivan Vecera) [2037943]
- i40e: Add ensurance of MacVlan resources for every trusted VF (Ivan Vecera) [2037943]
- i40e: Fix incorrect netdev's real number of RX/TX queues (Ivan Vecera) [2037943]
- i40e: Fix for displaying message regarding NVM version (Ivan Vecera) [2037943]
- i40e: fix use-after-free in i40e_sync_filters_subtask() (Ivan Vecera) [2037943]
- i40e: Fix to not show opcode msg on unsuccessful VF MAC change (Ivan Vecera) [2037943]
- i40e: switch to napi_build_skb() (Ivan Vecera) [2037943]
- i40e: Use irq_update_affinity_hint() (Ivan Vecera) [2037943]
- mptcp: fix race on unaccepted mptcp sockets (Davide Caratti) [2076971]
- mptcp: fix local endpoint accounting (Davide Caratti) [2076971]
- mptcp: fix race in overlapping signal events (Davide Caratti) [2076971]
- mptcp: fix subflow accounting on close (Davide Caratti) [2076971]
- mptcp: introduce implicit endpoints (Davide Caratti) [2076971]
- mptcp: constify a bunch of of helpers (Davide Caratti) [2076971]
- mptcp: drop port parameter of mptcp_pm_add_addr_signal (Davide Caratti) [2076971]
- mptcp: fix removing ids bitmap setting (Davide Caratti) [2076971]
- selftests: mptcp: be more conservative with cookie MPJ limits (Davide Caratti) [2076971]
- selftests: mptcp: more robust signal race test (Davide Caratti) [2076971]
- mptcp: cleanup MPJ subflow list handling (Davide Caratti) [2076971]
- mptcp: do not block subflows creation on errors (Davide Caratti) [2076971]
- mptcp: keep track of local endpoint still available for each msk (Davide Caratti) [2076971]
- mptcp: clean up harmless false expressions (Davide Caratti) [2076971]
- mptcp: fix per socket endpoint accounting (Davide Caratti) [2076971]
- selftests: mptcp: add fullmesh testcases (Davide Caratti) [2076971]
- selftests: mptcp: set and print the fullmesh flag (Davide Caratti) [2076971]
- mptcp: local addresses fullmesh (Davide Caratti) [2076971]
- mptcp: remote addresses fullmesh (Davide Caratti) [2076971]
- mptcp: remove MPTCP_ADD_ADDR_IPV6 and MPTCP_ADD_ADDR_PORT (Davide Caratti) [2076971]
- mptcp: build ADD_ADDR/echo-ADD_ADDR option according pm.add_signal (Davide Caratti) [2076971]
- mptcp: fix ADD_ADDR and RM_ADDR maybe flush addr_signal each other (Davide Caratti) [2076971]
- mptcp: make MPTCP_ADD_ADDR_SIGNAL and MPTCP_ADD_ADDR_ECHO separate (Davide Caratti) [2076971]
- mptcp: move drop_other_suboptions check under pm lock (Davide Caratti) [2076971]
- mptcp: drop flags and ifindex arguments (Davide Caratti) [2076971]
- mptcp: allow to use port and non-signal in set_flags (Davide Caratti) [2076971]
- NFSv4.1 support for NFS4_RESULT_PRESERVER_UNLINKED (Scott Mayhew) [2066369]
- KVM: selftests: get-reg-list: Add KVM_REG_ARM_FW_REG(3) (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: proton-pack: Include unprivileged eBPF status in Spectre v2 miti (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: Use the clearbhb instruction in mitigations (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: add ID_AA64ISAR2_EL1 sys register (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered and migrated (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: Mitigate spectre style branch history side channels (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- KVM: arm64: Add templates for BHB mitigation sequences (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part of Spect (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: Add percpu vectors for EL1 (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Add macro for reading symbol addresses from the trampolin (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Add vectors that have the bhb mitigation sequences (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Add non-kpti __bp_harden_el1_vectors for mitigations (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Allow the trampoline text to occupy multiple pages (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Make the kpti trampoline's kpti sequence optional (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Move trampoline macros out of ifdef'd section (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Don't assume tramp_vectors is the start of the vectors (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Allow tramp_alias to access symbols after the 4K boundary (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Move the trampoline data page before the text page (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Free up another register on kpti's tramp_exit path (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry: Make the trampoline cleanup optional (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: entry.S: Add ventry overflow sanity checks (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: Add Cortex-X2 CPU part definition (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: Add Neoverse-N2, Cortex-A710 CPU part definition (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: syscall: exit userspace before unmasking exceptions (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- arm64: ptrace: Consistently use pseudo-singlestep exceptions (Chris von Recklinghausen) [2062287] {CVE-2022-23960}
- ethtool: Fix get module eeprom fallback (Ivan Vecera) [2091772]
- xfs: use setattr_copy to set vfs inode attributes (Andrey Albershteyn) [2085622]
- xfs: ensure log flush at the end of a synchronous fallocate call (Andrey Albershteyn) [2085622]
- xfs: set prealloc flag in xfs_alloc_file_space() (Andrey Albershteyn) [2085622]
- xfs: fallocate() should call file_modified() (Andrey Albershteyn) [2085622]
- xfs: remove XFS_PREALLOC_SYNC (Andrey Albershteyn) [2085622]
- drm/ast: Fix black screen when getting out of suspend (Jocelyn Falempe) [2097492]
- drm/ast: Create the driver for ASPEED proprietory Display-Port (Jocelyn Falempe) [2097492]
- x86: change default to spec_store_bypass_disable=prctl spectre_v2_user=prctl (Waiman Long) [2101938]
- x86/speculation/mmio: Print SMT warning (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- KVM: x86/speculation: Disable Fill buffer clear within guests (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/srbds: Update SRBDS mitigation selection (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add sysfs reporting for Processor MMIO Stale Data (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add mitigation for Processor MMIO Stale Data (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation: Add a common function for MD_CLEAR mitigation update (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- Documentation: Add documentation for Processor MMIO Stale Data (Waiman Long) [2090252] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/tsx: Disable TSX development mode at boot (Waiman Long) [2090252]
- x86/tsx: Use MSR_TSX_CTRL to clear CPUID bits (Waiman Long) [2090252]
- x86/tsx: Clear CPUID bits when TSX always force aborts (Waiman Long) [2090252]
- cpu/speculation: Add prototype for cpu_show_srbds() (Waiman Long) [2090252]
- x86/cpu: Move arch_smt_update() to a neutral place (Waiman Long) [2090252]
- serial: 8250_pci: rewrite pericom_do_set_divisor() (Myron Stowe) [2096364]
- serial: 8250_pci: Fix ACCES entries in pci_serial_quirks array (Myron Stowe) [2096364]
- serial: 8250_pci: Merge 8250_moxa to 8250_pci (Myron Stowe) [2096364]
- serial: 8250: Use dev_get_drvdata where possible (Myron Stowe) [2096364]
- serial: 8250: pericom_do_set_divisor can be static (Myron Stowe) [2096364]
- serial: 8250: Add support for higher baud rates to Pericom chips (Myron Stowe) [2096364]
- serial: 8250_pci: Have ACCES cards that use the four port Pericom PI7C9X7954 chip use the pci_pericom_setup() (Myron Stowe) [2096364]
- serial: 8250_pci: Fix number of ports for ACCES serial cards (Myron Stowe) [2096364]
- serial: 8250_pci: Replace custom code with pci_match_id() (Myron Stowe) [2096364]
- net/sched: act_police: more accurate MTU policing (Davide Caratti) [2100893]
- selinux: initialize proto variable in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2005892]
- selinux: fix a sock regression in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2005892]
- LSM: Avoid warnings about potentially unused hook variables (Ondrej Mosnacek) [2005892]
- selinux: fix all of the W=1 build warnings (Ondrej Mosnacek) [2005892]
- selinux: make better use of the nf_hook_state passed to the NF hooks (Ondrej Mosnacek) [2005892]
- selinux: fix race condition when computing ocontext SIDs (Ondrej Mosnacek) [2005892 1969344]
- selinux: remove unneeded ipv6 hook wrappers (Ondrej Mosnacek) [2005892]
- lsm_audit: avoid overloading the "key" audit field (Ondrej Mosnacek) [2005892]
- security: remove unneeded subdir-$(CONFIG_...) (Ondrej Mosnacek) [2005892]
- selinux: return early for possible NULL audit buffers (Ondrej Mosnacek) [2005892]
- selinux: correct the return value when loads initial sids (Ondrej Mosnacek) [2005892]
- audit: remove unnecessary 'ret' initialization (Ondrej Mosnacek) [2005892]
- selinux: kill 'flags' argument in avc_has_perm_flags() and avc_audit() (Ondrej Mosnacek) [2005892]
- selinux: slow_avc_audit has become non-blocking (Ondrej Mosnacek) [2005892]
- selinux: Fix kernel-doc (Ondrej Mosnacek) [2005892]
- selinux: use __GFP_NOWARN with GFP_NOWAIT in the AVC (Ondrej Mosnacek) [2005892]
- lsm_audit,selinux: pass IB device name by reference (Ondrej Mosnacek) [2005892]
- selinux: Remove redundant assignment to rc (Ondrej Mosnacek) [2005892]
- selinux: Corrected comment to match kernel-doc comment (Ondrej Mosnacek) [2005892]
- selinux: delete selinux_xfrm_policy_lookup() useless argument (Ondrej Mosnacek) [2005892]
- selinux: constify some avtab function arguments (Ondrej Mosnacek) [2005892]
- selinux: simplify duplicate_policydb_cond_list() by using kmemdup() (Ondrej Mosnacek) [2005892]
- selinux: add proper NULL termination to the secclass_map permissions (Ondrej Mosnacek) [2005892]
- security: commoncap: clean up kernel-doc comments (Ondrej Mosnacek) [2005892]
- security: commoncap: fix -Wstringop-overread warning (Ondrej Mosnacek) [2005892]
- selinux: fix misspellings using codespell tool (Ondrej Mosnacek) [2005892]
- selinux: fix misspellings using codespell tool (Ondrej Mosnacek) [2005892]
- ext4: mballoc: Use this_cpu_read instead of this_cpu_ptr (Lukas Czerner) [2102619]
- ext4: add reserved GDT blocks check (Lukas Czerner) [2099702]
- ext4: make variable "count" signed (Lukas Czerner) [2099702]
- ext4: fix bug_on ext4_mb_use_inode_pa (Lukas Czerner) [2099702]
- ext4: fix super block checksum incorrect after mount (Lukas Czerner) [2099702]
- ext4: fix bug_on in __es_tree_search (Lukas Czerner) [2099702]
- ext4: avoid cycles in directory h-tree (Lukas Czerner) [2099702]
- ext4: verify dir block before splitting it (Lukas Czerner) [2099702]
- ext4: fix bug_on in ext4_writepages (Lukas Czerner) [2099702]
- ext4: reject the 'commit' option on ext2 filesystems (Lukas Czerner) [2099702]
- ext4: fix use-after-free in ext4_rename_dir_prepare (Lukas Czerner) [2099702]
- ext4: fix warning in ext4_handle_inode_extension (Lukas Czerner) [2099702]

* Fri Jul 15 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-410.el8]
- i915: Explicitly #include <linux/string_helpers.h> (Michel Dänzer) [2041811]
- i915: Use mdev_type_kobj_to_group_id instead of mtype_get_type_group_id (Michel Dänzer) [2041811]
- drm/i915: #include <linux/highmem.h> for k(un)map APIs (Michel Dänzer) [2041811]
- Revert "mm: remove the extra ZONE_DEVICE struct page refcount" (Michel Dänzer) [2041811]
- Merge DRM changes from upstream v5.17..v5.18 (Michel Dänzer) [2041811]
- iosys-map: Add a few more helpers (Michel Dänzer) [2041811]
- iosys-map: Add offset to iosys_map_memcpy_to() (Michel Dänzer) [2041811]
- dma-buf-map: Rename to iosys-map (Michel Dänzer) [2041811]
- Revert "drm/amdgpu/display: set vblank_disable_immediate for DC" (Michel Dänzer) [2041811]
- Revert "drm: import DMA_BUF module namespace" (Michel Dänzer) [2041811]
- drm/virtio: Do not use virtio_reset_device (Michel Dänzer) [2041811]
- Merge DRM changes from upstream v5.16..v5.17 (Michel Dänzer) [2041811]
- agp/intel-gtt: reduce intel-gtt dependencies more (Michel Dänzer) [2041811]
- agp/intel-gtt: Replace kernel.h with the necessary inclusions (Michel Dänzer) [2041811]
- x86/gpu: Reserve stolen memory for first integrated Intel GPU (Michel Dänzer) [2041811]
- drm/i915/rpl-s: Add PCI IDS for Raptor Lake S (Michel Dänzer) [2041811]
- drm/amdgpu: Use MCE_PRIO_FIRST instead of MCE_PRIO_UC (Michel Dänzer) [2041811]
- Revert "drm/amdgpu: disable runpm if we are the primary adapter" (Michel Dänzer) [2041811]
- Revert "treewide: Replace the use of mem_encrypt_active() with cc_platform_has()" (Michel Dänzer) [2041811]
- Revert "dma-buf: move dma-buf symbols into the DMA_BUF module namespace" (Michel Dänzer) [2041811]
- Revert "fix for "dma-buf: move dma-buf symbols into the DMA_BUF module namespace"" (Michel Dänzer) [2041811]
- x86/MCE/AMD, EDAC/mce_amd: Support non-uniform MCA bank type enumeration (Michel Dänzer) [2041811]
- Merge DRM changes from upstream v5.15..v5.16 (Michel Dänzer) [2041811]
- drm/bochs: Explicitly #include <linux/module.h> (Michel Dänzer) [2041811]
- Revert "gpu: Bulk conversion to generic_handle_domain_irq()" (Michel Dänzer) [2041811]
- Revert "vfio/gvt: Fix open/close when multiple device FDs are open" (Michel Dänzer) [2041811]
- drm: Drop linux/ prefix from stdarg.h include (Michel Dänzer) [2041811]
- drm/i915: Convert to older tasklet API (Michel Dänzer) [2041811]
- Merge DRM changes from upstream v5.14.21..v5.15 (Michel Dänzer) [2041811]
- dma-buf: Fix kerneldoc comment for struct dma_fence_array (Michel Dänzer) [2041811]
- Makefile: Add RHEL_DRM_EXTRAVERSION (Michel Dänzer) [2041811]
- mei: me: add Alder Lake N device id. (Prarit Bhargava) [2072660]
- pinctrl: alderlake: Fix register offsets for ADL-N variant (Prarit Bhargava) [2049965]
- pinctrl: alderlake: Add Intel Alder Lake-N pin controller support (Prarit Bhargava) [2049965]
- pinctrl: tigerlake: Revert "Add Alder Lake-M ACPI ID" (Prarit Bhargava) [2049965]
- spi: pxa2xx: Add support for Intel Alder Lake PCH-M (Prarit Bhargava) [2089507]
- RHEL-only: KVM: selftests: Compile rseq_test out on aarch64 (Eric Auger) [2078919]
- KVM: arm64: Don't read a HW interrupt pending state in user context (Eric Auger) [2078919]
- KVM: arm64: selftests: Add init ITS device test (Eric Auger) [2078919]
- KVM: arm64: selftests: Add test for legacy GICv3 REDIST base partially above IPA range (Eric Auger) [2078919]
- KVM: arm64: selftests: Add tests for GIC redist/cpuif partially above IPA range (Eric Auger) [2078919]
- KVM: arm64: selftests: Add some tests for GICv2 in vgic_init (Eric Auger) [2078919]
- KVM: arm64: selftests: Make vgic_init/vm_gic_create version agnostic (Eric Auger) [2078919]
- KVM: arm64: selftests: Make vgic_init gic version agnostic (Eric Auger) [2078919]
- KVM: arm64: vgic: Drop vgic_check_ioaddr() (Eric Auger) [2078919]
- KVM: arm64: vgic-v3: Check ITS region is not above the VM IPA size (Eric Auger) [2078919]
- KVM: arm64: vgic-v2: Check cpu interface region is not above the VM IPA size (Eric Auger) [2078919]
- KVM: arm64: vgic-v3: Check redist region is not above the VM IPA size (Eric Auger) [2078919]
- kvm: arm64: vgic: Introduce vgic_check_iorange (Eric Auger) [2078919]
- Revert "RHEL-only: KVM: selftests: Fix AArch64 compilation" (Eric Auger) [2078919]
- selftests: KVM: Free the GIC FD when cleaning up in arch_timer (Eric Auger) [2078919]
- selftests: KVM: Don't leak GIC FD across dirty log test iterations (Eric Auger) [2078919]
- KVM: arm64: selftests: Introduce vcpu_width_config (Eric Auger) [2078919]
- KVM: arm64: mixed-width check should be skipped for uninitialized vCPUs (Eric Auger) [2078919]
- KVM: arm64: Generalise VM features into a set of flags (Eric Auger) [2078919]
- KVM: selftests: aarch64: Skip tests if we can't create a vgic-v3 (Eric Auger) [2078919]
- kvm: selftests: aarch64: use a tighter assert in vgic_poke_irq() (Eric Auger) [2078919]
- kvm: selftests: aarch64: fix some vgic related comments (Eric Auger) [2078919]
- kvm: selftests: aarch64: fix the failure check in kvm_set_gsi_routing_irqchip_check (Eric Auger) [2078919]
- kvm: selftests: aarch64: pass vgic_irq guest args as a pointer (Eric Auger) [2078919]
- kvm: selftests: aarch64: fix assert in gicv3_access_reg (Eric Auger) [2078919]
- KVM: selftests: Add vgic initialization for dirty log perf test for ARM (Eric Auger) [2078919]
- KVM: arm64: vgic: Read HW interrupt pending state from the HW (Eric Auger) [2078919]
- KVM: arm64: Emulate the OS Lock (Eric Auger) [2078919]
- KVM: arm64: Allow guest to set the OSLK bit (Eric Auger) [2078919]
- KVM: arm64: Stash OSLSR_EL1 in the cpu context (Eric Auger) [2078919]
- KVM: arm64: Correctly treat writes to OSLSR_EL1 as undefined (Eric Auger) [2078919]
- KVM: arm64: vgic: Replace kernel.h with the necessary inclusions (Eric Auger) [2078919]
- KVM: arm64: Fix comment typo in kvm_vcpu_finalize_sve() (Eric Auger) [2078919]
- KVM: arm64: selftests: get-reg-list: Add pauth configuration (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add test for restoring active IRQs (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add ISPENDR write tests in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add tests for IRQFD in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: Add IRQ GSI routing library functions (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add test_inject_fail to vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add tests for LEVEL_INFO in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Level-sensitive interrupts tests in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add preemption tests in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Cmdline arg to set EOI mode in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Cmdline arg to set number of IRQs in vgic_irq test (Eric Auger) [2078919]
- KVM: selftests: aarch64: Abstract the injection functions in vgic_irq (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add vgic_irq to test userspace IRQ injection (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add vGIC library functions to deal with vIRQ state (Eric Auger) [2078919]
- KVM: selftests: Add kvm_irq_line library function (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add GICv3 register accessor library functions (Eric Auger) [2078919]
- KVM: selftests: aarch64: Add function for accessing GICv3 dist and redist registers (Eric Auger) [2078919]
- KVM: selftests: aarch64: Move gic_v3.h to shared headers (Eric Auger) [2078919]
- KVM: selftests: arm64: Add support for various modes with 16kB page size (Eric Auger) [2078919]
- KVM: selftests: arm64: Add support for VM_MODE_P36V48_{4K,64K} (Eric Auger) [2078919]
- KVM: arm64: Fix comment on barrier in kvm_psci_vcpu_on() (Eric Auger) [2078919]
- KVM: arm64: Fix comment for kvm_reset_vcpu() (Eric Auger) [2078919]
- KVM: arm64: Use defined value for SCTLR_ELx_EE (Eric Auger) [2078919]
- KVM: arm64: vgic: Demote userspace-triggered console prints to kvm_debug() (Eric Auger) [2078919]
- KVM: arm64: Consolidate dist->ready setting into kvm_vgic_map_resources() (Eric Auger) [2078919]
- arm64/kvm: Fix bitrotted comment for SVE handling in handle_exit.c (Eric Auger) [2078919]
- KVM: arm64: Drop vcpu->arch.has_run_once for vcpu->pid (Eric Auger) [2078919]
- KVM: arm64: Merge kvm_arch_vcpu_run_pid_change() and kvm_vcpu_first_run_init() (Eric Auger) [2078919]
- KVM: arm64: Restructure the point where has_run_once is advertised (Eric Auger) [2078919]
- KVM: arm64: Move kvm_arch_vcpu_run_pid_change() out of line (Eric Auger) [2078919]
- KVM: arm64: Move SVE state mapping at HYP to finalize-time (Eric Auger) [2078919]
- KVM: arm64: Move double-checked lock to kvm_vgic_map_resources() (Eric Auger) [2078919]
- KVM: arm64: Constify kvm_io_gic_ops (Eric Auger) [2078919]
- KVM: arm64: Avoid setting the upper 32 bits of TCR_EL2 and CPTR_EL2 to 1 (Eric Auger) [2078919]
- selftests: KVM: Fix kvm device helper ioctl assertions (Eric Auger) [2078919]
- ACPI: tables: Quiet ACPI table not found warning (Mark Langsdorf) [2067290]
- ACPI/IORT: Check node revision for PMCG resources (Mark Langsdorf) [2067290]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067290]
- ACPI: PM: s2idle: Cancel wakeup before dispatching EC GPE (Mark Langsdorf) [2067290]
- ACPI: PM: Revert "Only mark EC GPE for wakeup on Intel systems" (Mark Langsdorf) [2067290]
- ACPI: require CRC32 to build (Mark Langsdorf) [2067290]
- ACPI: DPTF: Support Raptor Lake (Mark Langsdorf) [2067290]
- ACPI: scan: Rename label in acpi_scan_init() (Mark Langsdorf) [2067290]
- ACPI: scan: Simplify initialization of power and sleep buttons (Mark Langsdorf) [2067290]
- ACPI: scan: Change acpi_scan_init() return value type to void (Mark Langsdorf) [2067290]
- ACPI: SPCR: check if table->serial_port.access_width is too wide (Mark Langsdorf) [2067290]
- ACPI: APD: Check for NULL pointer after calling devm_ioremap() (Mark Langsdorf) [2067290]
- ACPI: pfr_telemetry: Fix info leak in pfrt_log_ioctl() (Mark Langsdorf) [2067290]
- ACPI: APD: Add a fmw property clk-name (Mark Langsdorf) [2067290]
- ACPI: pfr_update: Fix return value check in pfru_write() (Mark Langsdorf) [2067290]
- ACPI: processor: thermal: avoid cpufreq_get_policy() (Mark Langsdorf) [2067290]
- ACPI / x86: Add acpi_quirk_skip_[i2c_client|serdev]_enumeration() helpers (Mark Langsdorf) [2067290]
- ACPI: battery: Add the ThinkPad "Not Charging" quirk (Mark Langsdorf) [2067290]
- acpi: Store CRC-32 hash of the _PLD in struct acpi_device (Mark Langsdorf) [2067290]
- acpi: Export acpi_bus_type (Mark Langsdorf) [2067290]
- ACPI: sysfs: use default_groups in kobj_type (Mark Langsdorf) [2067290]
- ACPI: Introduce Platform Firmware Runtime Telemetry driver (Mark Langsdorf) [2067290]
- ACPI: Introduce Platform Firmware Runtime Update device driver (Mark Langsdorf) [2067290]
- efi: Introduce EFI_FIRMWARE_MANAGEMENT_CAPSULE_HEADER and corresponding structures (Mark Langsdorf) [2067290]
- ACPICA: Update version to 20211217 (Mark Langsdorf) [2067290]
- ACPICA: iASL/NHLT table: "Specific Data" field support (Mark Langsdorf) [2067290]
- ACPICA: iASL: Add suppport for AGDI table (Mark Langsdorf) [2067290]
- ACPICA: iASL: Add TDEL table to both compiler/disassembler (Mark Langsdorf) [2067290]
- ACPICA: Fixed a couple of warnings under MSVC (Mark Langsdorf) [2067290]
- ACPICA: Change a return_ACPI_STATUS (AE_BAD_PARAMETER) (Mark Langsdorf) [2067290]
- ACPICA: Hardware: Do not flush CPU cache when entering S4 and S5 (Mark Langsdorf) [2067290]
- ACPICA: Add support for PCC Opregion special context data (Mark Langsdorf) [2067290]
- ACPICA: Fix wrong interpretation of PCC address (Mark Langsdorf) [2067290]
- ACPICA: Executer: Fix the REFCLASS_REFOF case in acpi_ex_opcode_1A_0T_1R() (Mark Langsdorf) [2067290]
- ACPICA: Utilities: Avoid deleting the same object twice in a row (Mark Langsdorf) [2067290]
- ACPICA: Fix AEST Processor generic resource substructure data field byte length (Mark Langsdorf) [2067290]
- ACPICA: iASL/Disassembler: Additional support for NHLT table (Mark Langsdorf) [2067290]
- ACPICA: Avoid subobject buffer overflow when validating RSDP signature (Mark Langsdorf) [2067290]
- ACPICA: Macros: Remove ACPI_PHYSADDR_TO_PTR (Mark Langsdorf) [2067290]
- ACPICA: Use original pointer for virtual origin tables (Mark Langsdorf) [2067290]
- ACPICA: Use original data_table_region pointer for accesses (Mark Langsdorf) [2067290]
- ACPICA: actypes.h: Expand the ACPI_ACCESS_ definitions (Mark Langsdorf) [2067290]
- ACPI: CPPC: Amend documentation in the comments (Mark Langsdorf) [2067290]
- ACPI: NFIT: Import GUID before use (Mark Langsdorf) [2067290]
- ACPI: PM: Remove redundant cache flushing (Mark Langsdorf) [2067290]
- ACPI: Use acpi_fetch_acpi_dev() instead of acpi_bus_get_device() (Mark Langsdorf) [2067290]
- ACPI: tables: Add AEST to the list of known table signatures (Mark Langsdorf) [2067290]
- ACPI: PM: Avoid CPU cache flush when entering S4 (Mark Langsdorf) [2067290]
- PM: hibernate: Allow ACPI hardware signature to be honoured (Mark Langsdorf) [2067290]
- ACPI: PMIC: xpower: Fix _TMP ACPI errors (Mark Langsdorf) [2067290]
- ACPI: PMIC: allow drivers to provide a custom lpat_raw_to_temp() function (Mark Langsdorf) [2067290]
- ACPI: PMIC: constify all struct intel_pmic_opregion_data declarations (Mark Langsdorf) [2067290]
- ACPI: EC: Mark the ec_sys write_support param as module_param_hw() (Mark Langsdorf) [2067290]
- ACPI: EC: Relocate acpi_ec_create_query() and drop acpi_ec_delete_query() (Mark Langsdorf) [2067290]
- ACPI: EC: Make the event work state machine visible (Mark Langsdorf) [2067290]
- ACPI: EC: Avoid queuing unnecessary work in acpi_ec_submit_event() (Mark Langsdorf) [2067290]
- ACPI: EC: Rename three functions (Mark Langsdorf) [2067290]
- ACPI: EC: Simplify locking in acpi_ec_event_handler() (Mark Langsdorf) [2067290]
- ACPI: EC: Rearrange the loop in acpi_ec_event_handler() (Mark Langsdorf) [2067290]
- ACPI: EC: Fold acpi_ec_check_event() into acpi_ec_event_handler() (Mark Langsdorf) [2067290]
- ACPI: EC: Pass one argument to acpi_ec_query() (Mark Langsdorf) [2067290]
- ACPI: EC: Call advance_transaction() from acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067290]
- ACPI: EC: Rework flushing of EC work while suspended to idle (Mark Langsdorf) [2067290]
- ACPI / x86: Add PWM2 on the Xiaomi Mi Pad 2 to the always_present list (Mark Langsdorf) [2067290]
- ACPI / x86: Add not-present quirk for the PCI0.SDHB.BRC1 device on the GPD win (Mark Langsdorf) [2067290]
- ACPI / x86: Allow specifying acpi_device_override_status() quirks by path (Mark Langsdorf) [2067290]
- ACPI: Change acpi_device_always_present() into acpi_device_override_status() (Mark Langsdorf) [2067290]
- ACPI / x86: Drop PWM2 device on Lenovo Yoga Book from always present table (Mark Langsdorf) [2067290]
- ACPI: processor idle: Use swap() instead of open coding it (Mark Langsdorf) [2067290]
- ACPI: processor: Replace kernel.h with the necessary inclusions (Mark Langsdorf) [2067290]
- ACPI: DPTF: Update device ID in a comment (Mark Langsdorf) [2067290]
- ACPI: PM: Emit debug messages when enabling/disabling wakeup power (Mark Langsdorf) [2067290]
- ACPI: thermal: drop an always true check (Mark Langsdorf) [2067290]
- ACPI: Add a context argument for table parsing handlers (Mark Langsdorf) [2067290]
- ACPI: Teach ACPI table parsing about the CEDT header format (Mark Langsdorf) [2067290]
- ACPI: Keep sub-table parsing infrastructure available for modules (Mark Langsdorf) [2067290]
- cxgb4: fix wrong shift. (Raju Rangoju) [1977437]
- cxgb4: fix wrong ethtool n-tuple rule lookup (Raju Rangoju) [1977437]
- cxgb4: halt chip before flashing PHY firmware image (Raju Rangoju) [1977437]
- cxgb4: fix sleep in atomic when flashing PHY firmware (Raju Rangoju) [1977437]
- cxgb4: fix endianness when flashing boot image (Raju Rangoju) [1977437]
- cxgb4: avoid link re-train during TC-MQPRIO configuration (Raju Rangoju) [1977437]
- cxgb4: fix regression with HASH tc prio value update (Raju Rangoju) [1977437]
- cxgb4: avoid accessing registers when clearing filters (Raju Rangoju) [1977437]
- net:CXGB4: fix leak if sk_buff is not used (Raju Rangoju) [1977437]
- cxgb4: Fix unintentional sign extension issues (Raju Rangoju) [1977437]
- cxgb4: remove unneeded if-null-free check (Raju Rangoju) [1977437]
- PCI: vmd: Assign VMD IRQ domain before enumeration (Myron Stowe) [2050850]
- PCI: vmd: Prevent recursive locking on interrupt allocation (Myron Stowe) [2050850]
- PCI: vmd: Add DID 8086:A77F for all Intel Raptor Lake SKU's (Myron Stowe) [2050850]
- PCI: vmd: Honor ACPI _OSC on PCIe features (Myron Stowe) [2050850]
- PCI: vmd: Clean up domain before enumeration (Myron Stowe) [2050850]
- PCI: vmd: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2050850]
- PCI: Add PCI_ERROR_RESPONSE and related definitions (Myron Stowe) [2050850]
- PCI: vmd: Drop redundant includes of <asm/device.h>, <asm/msi.h> (Myron Stowe) [2050850]
- PCI: vmd: Assign a number to each VMD controller (Myron Stowe) [2050850]
- PCI: vmd: Disable MSI-X remapping when possible (Myron Stowe) [2050850]
- PCI: vmd: Offset Client VMD MSI-X vectors (Myron Stowe) [2050850]
- PCI: vmd: Use msi_msg shadow structs (Myron Stowe) [2050850]
- Merge tag 'pci-v5.10-changes' of git://git.kernel.org/pub/scm/linux/kernel/g (Myron Stowe) [2050850]
- PCI: vmd: Update VMD PM to correctly use generic PCI PM (Myron Stowe) [2050850]
- PCI: vmd: Create IRQ allocation helper (Myron Stowe) [2050850]
- PCI: vmd: Create IRQ Domain configuration helper (Myron Stowe) [2050850]
- PCI: vmd: Create bus offset configuration helper (Myron Stowe) [2050850]
- PCI: vmd: Create physical offset helper (Myron Stowe) [2050850]
- PCI_vmd_Mark_VMD_irqdomain_with_DOMAIN_BUS_VMD_MSI (Myron Stowe) [2050850]
- irqdomain/msi: Provide DOMAIN_BUS_VMD_MSI (Myron Stowe) [2050850]
- PCI: vmd: Dont abuse vector irqomain as parent (Myron Stowe) [2050850]
- PCI: designware-ep: Fix the Header Type check (Myron Stowe) [2050850]
- PCI: vmd: Use Shadow MEMBAR registers for QEMU/KVM guests (Myron Stowe) [2050850]
- PCI: vmd: Filter resource type bits from shadow register (Myron Stowe) [2050850]
- PCI: Fix indentation (Myron Stowe) [2050850]
- scsi: iscsi: Fix session removal on shutdown (Chris Leech) [2101760]
- scsi: qedi: Use QEDI_MODE_NORMAL for error handling (Chris Leech) [2101760]
- scsi: iscsi: Add helper to remove a session from the kernel (Chris Leech) [2101760]
- scsi: iscsi: Clean up bound endpoints during shutdown (Chris Leech) [2101760]
- scsi: iscsi: Allow iscsi_if_stop_conn() to be called from kernel (Chris Leech) [2101760]
- scsi: iscsi: Fix HW conn removal use after free (Chris Leech) [2101760]
- scsi: iscsi: Make iscsi_unregister_transport() return void (Chris Leech) [2101760]
- scsi: core: iscsi: Directly use ida_alloc()/ida_free() (Chris Leech) [2101760]
- scsi: iscsi: Exclude zero from the endpoint ID range (Chris Leech) [2101760]
- scsi: iscsi: Fix harmless double shift bug (Chris Leech) [2101760]
- scsi: libiscsi: Remove unnecessary memset() in iscsi_conn_setup() (Chris Leech) [2101760]
- scsi: libiscsi: Teardown iscsi_cls_conn gracefully (Chris Leech) [2101760]
- scsi: libiscsi: Add iscsi_cls_conn to sysfs after initialization (Chris Leech) [2101760]
- scsi: iscsi: Add helper functions to manage iscsi_cls_conn (Chris Leech) [2101760]
- scsi: iscsi: Drop temp workq_name (Chris Leech) [2101760]
- scsi: iscsi: Use the session workqueue for recovery (Chris Leech) [2101760]
- scsi: iscsi: ql4xxx: Use per-session workqueue for unbinding (Chris Leech) [2101760]
- scsi: iscsi: Remove iscsi_scan_finished() (Chris Leech) [2101760]
- scsi: libiscsi: Fix UAF in iscsi_conn_get_param()/iscsi_conn_teardown() (Chris Leech) [2101760]
- scsi: libiscsi: Move ehwait initialization to iscsi_session_setup() (Chris Leech) [2101760]
- x86/sme: Explicitly map new EFI memmap table as encrypted (Chris von Recklinghausen) [2091831]
- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in mem_encrypt_identity.c (Chris von Recklinghausen) [2091831]
- efi/x86: Fix boot regression on systems with invalid memmap entries (Chris von Recklinghausen) [2091831]
- efi: Add tracking for dynamically allocated memmaps (Chris von Recklinghausen) [2091831]
- efi: Add a flags parameter to efi_memory_map (Chris von Recklinghausen) [2091831]
- x86/kexec: fix memory leak of elf header buffer (Tao Liu) [2014945]
- net: sched: add barrier to fix packet stuck problem for lockless qdisc (Davide Caratti) [2103025]
- powercap: intel_rapl: add support for ALDERLAKE_N (David Arcari) [2096964]
- clk: fix invalid usage of list cursor in unregister (David Arcari) [2105258]
- clk: fix invalid usage of list cursor in register (David Arcari) [2105258]
- powercap: intel_rapl: add support for RaptorLake (David Arcari) [2076724]
- lib/math: move int_pow() from pwm_bl.c for wider use (Ivan Vecera) [2101700]
- x86/fpu: KVM: Set the base guest FPU uABI size to sizeof(struct kvm_xsave) (Paul Lai) [2092066]

* Mon Jul 11 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-409.el8]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Davide Caratti) [2081283]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Davide Caratti) [2081283]
- net/sched: flower: fix parsing of ethertype following VLAN header (Davide Caratti) [2081283]
- net: sched: limit TC_ACT_REPEAT loops (Davide Caratti) [2081283]
- net_sched: add __rcu annotation to netdev->qdisc (Davide Caratti) [2081283]
- sch_htb: Fail on unsupported parameters when offload is requested (Davide Caratti) [2081283]
- net_sched: restore "mpu xxx" handling (Davide Caratti) [2081283]
- net: sched: sch_netem: Refactor code in 4-state loss generator (Davide Caratti) [2081283]
- net/mlx5e: TC, Fix ct_clear overwriting ct action metadata (Amir Tzin) [2100474]
- bpftool: man: Add missing top level docs (Yauheni Kaliuta) [2097615]
- net/mlx5: CT: Fix header-rewrite re-use for tupels (Amir Tzin) [2101162]
- cpuidle: haltpoll: Call cpuidle_poll_state_init() later (Mark Langsdorf) [2067313]
- cpuidle: use default_groups in kobj_type (Mark Langsdorf) [2067313]
- cpuidle: Fix cpuidle_remove_state_sysfs() kerneldoc comment (Mark Langsdorf) [2067313]
- cpuidle: menu: Fix typo in a comment (Mark Langsdorf) [2067313]
- cpuidle: Fix kobject memory leaks in error paths (Mark Langsdorf) [2067313]
- cpuidle: menu: Take negative "sleep length" values into account (Mark Langsdorf) [2067313]
- HID: elo: Revert USB reference counting (Benjamin Tissoires) [2073833]
- HID: elo: fix memory leak in elo_probe (Benjamin Tissoires) [2073833]
- fs: dlm: filter user dlm messages for kernel locks (Alexander Aring) [2026116]
- psample: Add a fwd declaration for skbuff (Ivan Vecera) [2101706]
- platform/x86/intel/sdsi: Fix bug in multi packet reads (Prarit Bhargava) [2100948]
- platform/x86/intel/sdsi: Poll on ready bit for writes (Prarit Bhargava) [2100948]
- platform/x86/intel/sdsi: Handle leaky bucket (Prarit Bhargava) [2100948]
- indirect_call_wrapper: extend indirect wrapper to support up to 4 calls (Petr Oros) [2101705]
- block: Fix handling of offline queues in blk_mq_alloc_request_hctx() (Ming Lei) [2081913]
- netfilter: br_netfilter: do not skip all hooks with 0 priority (Florian Westphal) [2099732]
- net: openvswitch: fix parsing of nw_proto for IPv6 fragments (Eelco Chaudron) [2101537]
- s390/smp,vdso: fix ASCE handling (Tobias Huschle) [2103887]
- [s390] s390/pci: fix zpci_zdev_put() on reserve (Claudio Imbrenda) [2102305]
- intel/igbvf:fix repeated words in comments (Corinna Vinschen) [2037962]
- igbvf: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037962]
- SUNRPC: avoid race between mod_timer() and del_timer_sync() (Benjamin Coddington) [2104507]
- iavf: Fix issue with MAC address of VF shown as zero (Petr Oros) [2037938]
- iavf: switch to napi_build_skb() (Petr Oros) [2037938]
- iavf: Remove non-inclusive language (Petr Oros) [2037938]
- iavf: Fix incorrect use of assigning iavf_status to int (Petr Oros) [2037938]
- iavf: stop leaking iavf_status as "errno" values (Petr Oros) [2037938]
- iavf: Add usage of new virtchnl format to set default MAC (Petr Oros) [2037938]
- iavf: refactor processing of VLAN V2 capability message (Petr Oros) [2037938]
- iavf: Add support for 50G/100G in AIM algorithm (Petr Oros) [2037938]
- iavf: remove redundant ret variable (Petr Oros) [2037938]
- iavf: Remove useless DMA-32 fallback configuration (Petr Oros) [2037938]
- cifs: fix potential double free during failed mount (Ronnie Sahlberg) [2088799]
- cifs: escape spaces in share names (Dave Wysochanski) [2100367]
- Documentation: add documentation for force_cgroup_v2_swappiness control (Nico Pache) [2084242]
- Introduce force_cgroup_v2_swappiness tuneable to deprecate cgv1 per-cgroup swappiness (Nico Pache) [2084242]
- redhat: trim rpminspect config file (Jarod Wilson)

* Wed Jul 06 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-408.el8]
- powerpc/smp: Set numa node before updating mask (Diego Domingos) [2103833]
- iommu/vt-d: Fix potential memory leak in intel_setup_irq_remapping() (Mohammed Gamal) [2088366]
- irqdomain/treewide: Free firmware node after domain removal (Mohammed Gamal) [2088366]
- x86/kvmclock: Fix Hyper-V Isolated VM's boot issue when vCPUs > 64 (Mohammed Gamal) [2088366]
- x86/kvm: Don't waste memory if kvmclock is disabled (Mohammed Gamal) [2088366]
- x86/pci: Create PCI/MSI irqdomain after x86_init.pci.arch_init() (Mohammed Gamal) [2088366]
- x86/pci: Reducde #ifdeffery in PCI init code (Mohammed Gamal) [2088366]
- hv_utils: Add comment about max VMbus packet size in VSS driver (Mohammed Gamal) [2088366]
- x86/coco: Explicitly declare type of confidential computing platform (Mohammed Gamal) [2088366]
- x86/hyper-v: Add hyperv Isolation VM check in the cc_platform_has() (Mohammed Gamal) [2088366]
- x86/sev: Use CC_ATTR attribute to generalize string I/O unroll (Mohammed Gamal) [2088366]
- random: remove unused irq_flags argument from add_interrupt_randomness() (Mohammed Gamal) [2088366]
- x86/hyperv: Fix definition of hv_ghcb_pg variable (Mohammed Gamal) [2088366]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Mohammed Gamal) [2088366]
- hyper-v: Enable swiotlb bounce buffer for Isolation VM (Mohammed Gamal) [2088366]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Mohammed Gamal) [2088366]
- x86/hyperv: Refactor hv_msi_domain_free_irqs() (Mohammed Gamal) [2088366]
- x86/hyperv: Move required MSRs check to initial platform probing (Mohammed Gamal) [2088366]
- x86/hyperv: Fix NULL deref in set_hv_tscchange_cb() if Hyper-V setup fails (Mohammed Gamal) [2088366]
- x86/hyperv: Protect set_hv_tscchange_cb() against getting preempted (Mohammed Gamal) [2088366]
- x86/hyperv: Remove duplicate include (Mohammed Gamal) [2088366]
- x86/hyperv: Remove duplicated include in hv_init (Mohammed Gamal) [2088366]
- x86/hyperv: Add ghcb hvcall support for SNP VM (Mohammed Gamal) [2088366]
- x86/hyperv: Add Write/Read MSR registers via ghcb page (Mohammed Gamal) [2088366]
- x86/hyperv: Add new hvcall guest address host visibility support (Mohammed Gamal) [2088366]
- x86/hyperv: Initialize shared memory boundary in the Isolation VM. (Mohammed Gamal) [2088366]
- x86/hyperv: Initialize GHCB page in Isolation VM (Mohammed Gamal) [2088366]
- x86/sev: Replace occurrences of sev_es_active() with cc_platform_has() (Mohammed Gamal) [2088366]
- x86/sev: Replace occurrences of sev_active() with cc_platform_has() (Mohammed Gamal) [2088366]
- x86/sev-es: Do not unroll string I/O for SEV-ES guests (Mohammed Gamal) [2088366]
- efi/x86: Avoid RWX mappings for all of DRAM (Mohammed Gamal) [2088366]
- x86/sme: Replace occurrences of sme_active() with cc_platform_has() (Mohammed Gamal) [2088366]
- x86/sev: Add an x86 version of cc_platform_has() (Mohammed Gamal) [2088366]
- vmalloc: fix the owner argument for the new __vmalloc_node_range callers (Mohammed Gamal) [2088366]
- mm: remove vmalloc_exec (Mohammed Gamal) [2088366]
- arm64: use PAGE_KERNEL_ROX directly in alloc_insn_page (Mohammed Gamal) [2088366]
- arm64/kprobes: set VM_FLUSH_RESET_PERMS on kprobe instruction pages (Mohammed Gamal) [2088366]
- x86/hyperv: allocate the hypercall page with only read and execute bits (Mohammed Gamal) [2088366]
- x86/hyperv: use vmalloc_exec for the hypercall page (Mohammed Gamal) [2088366]
- drivers: hv: Create a consistent pattern for checking Hyper-V hypercall status (Mohammed Gamal) [2088366]
- x86/irq: Initialize PCI/MSI domain at PCI init time (Mohammed Gamal) [2088366]
- x86/hyperv: implement an MSI domain for root partition (Mohammed Gamal) [2088366]
- irqdomain/treewide: Keep firmware node unconditionally allocated (Mohammed Gamal) [2088366]
- irqdomain/msi: Allow to override msi_domain_alloc/free_irqs() (Mohammed Gamal) [2088366]
- x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV (Mohammed Gamal) [2088366]
- x86/sev: Carve out HV call's return value verification (Mohammed Gamal) [2088366]
- x86/sev: Fix noinstr for vc_ghcb_invalidate() (Mohammed Gamal) [2088366]
- arch/cc: Introduce a function to check for confidential computing features (Mohammed Gamal) [2088366]
- Revert "drivers: hv: Create a consistent pattern for checking Hyper-V hypercall status" (Mohammed Gamal) [2088366]
- Revert "drivers: hv: Create a consistent pattern for checking Hyper-V hypercall status" (Mohammed Gamal) [2088366]
- libperf tests: Fix typo in perf_evlist__open() failure error messages (Michael Petlan) [1878555]
- libperf: Fix 32-bit build for tests uint64_t printf (Michael Petlan) [1878555]
- libperf: Add arm64 support to perf_mmap__read_self() (Michael Petlan) [1878555]
- libperf tests: Add test_stat_multiplexing test (Michael Petlan) [1878555]
- libperf: Remove scaling process from perf_mmap__read_self() (Michael Petlan) [1878555]
- libperf: Adopt perf_counts_values__scale() from tools/perf/util (Michael Petlan) [1878555]
- arm64: perf: Don't register user access sysctl handler multiple times (Michael Petlan) [1878555]
- Documentation: arm64: Document PMU counters access from userspace (Michael Petlan) [1878555]
- arm64: perf: Enable PMU counter userspace access for perf event (Michael Petlan) [1878555]
- arm64: perf: Add support for ARMv8.5-PMU 64-bit counters (Michael Petlan) [1878555]
- arm64: perf: Clean up enable/disable calls (Michael Petlan) [1878555]
- arm64: perf: Only advertise cap_user_time for arch_timer (Michael Petlan) [1878555]
- arm64: perf: Implement correct cap_user_time (Michael Petlan) [1878555]
- arm64: perf: Add userspace counter access disable switch (Michael Petlan) [1878555]
- perf: Add a counter for number of user access events in context (Michael Petlan) [1878555]
- x86: perf: Move RDPMC event flag to a common definition (Michael Petlan) [1878555]
- Fix null ptr dereference crash due to premature release of ndlp. Upstream Status: RHEL-Only Bugzilla: https://bugzilla.redhat.com/show_bug.cgi?id=2034425 (Dick Kennedy)
- lpfc updates for rh8.7 14.0.0.13 (Dick Kennedy) [2034425]
- scsi: lpfc: Use sg_dma_address() and sg_dma_len() macros for NVMe I/O (Dick Kennedy) [2034425]
- scsi: lpfc: Alter FPIN stat accounting logic (Dick Kennedy) [2034425]
- scsi: lpfc: Decrement outstanding gidft_inp counter if lpfc_err_lost_link() (Dick Kennedy) [2034425]
- scsi: lpfc: Use list_for_each_entry_safe() in rscn_recovery_check() (Dick Kennedy) [2034425]
- scsi: lpfc: Fix ndlp put following a LOGO completion (Dick Kennedy) [2034425]
- scsi: lpfc: Fix additional reference counting in lpfc_bsg_rport_els() (Dick Kennedy) [2034425]
- scsi: lpfc: Fix resource leak in lpfc_sli4_send_seq_to_ulp() (Dick Kennedy) [2034425]
- scsi: lpfc: Remove unneeded variable (Dick Kennedy) [2034425]
- scsi: lpfc: Copyright updates for 14.2.0.2 patches (Dick Kennedy) [2034425]
- scsi: lpfc: Expand setting ELS_ID field in ELS_REQUEST64_WQE (Dick Kennedy) [2034425]
- scsi: lpfc: Update stat accounting for READ_STATUS mbox command (Dick Kennedy) [2034425]
- scsi: lpfc: Change FA-PWWN detection methodology (Dick Kennedy) [2034425]
- scsi: lpfc: Register for Application Services FC-4 type in Fabric topology (Dick Kennedy) [2034425]
- scsi: lpfc: Remove false FDMI NVMe FC-4 support for NPIV ports (Dick Kennedy) [2034425]
- scsi: lpfc: Revise FDMI reporting of supported port speed for trunk groups (Dick Kennedy) [2034425]
- scsi: lpfc: Fix call trace observed during I/O with CMF enabled (Dick Kennedy) [2034425]
- scsi: lpfc: Correct CRC32 calculation for congestion stats (Dick Kennedy) [2034425]
- scsi: lpfc: Move MI module parameter check to handle dynamic disable (Dick Kennedy) [2034425]
- scsi: lpfc: Remove unnecessary NULL pointer assignment for ELS_RDF path (Dick Kennedy) [2034425]
- scsi: lpfc: Transition to NPR state upon LOGO cmpl if link down or aborted (Dick Kennedy) [2034425]
- scsi: lpfc: Update fc_prli_sent outstanding only after guaranteed IOCB submit (Dick Kennedy) [2034425]
- scsi: lpfc: Protect memory leak for NPIV ports sending PLOGI_RJT (Dick Kennedy) [2034425]
- scsi: lpfc: Fix null pointer dereference after failing to issue FLOGI and PLOGI (Dick Kennedy) [2034425]
- scsi: lpfc: Clear fabric topology flag before initiating a new FLOGI (Dick Kennedy) [2034425]
- scsi: lpfc: Fix SCSI I/O completion and abort handler deadlock (Dick Kennedy) [2034425]
- scsi: lpfc: Requeue SCSI I/O to upper layer when fw reports link down (Dick Kennedy) [2034425]
- scsi: lpfc: Zero SLI4 fcp_cmnd buffer's fcpCntl0 field (Dick Kennedy) [2034425]
- scsi: lpfc: Fix diagnostic fw logging after a function reset (Dick Kennedy) [2034425]
- scsi: lpfc: Move cfg_log_verbose check before calling lpfc_dmp_dbg() (Dick Kennedy) [2034425]
- scsi: lpfc: Tweak message log categories for ELS/FDMI/NVMe rescan (Dick Kennedy) [2034425]
- scsi: lpfc: Fix queue failures when recovering from PCI parity error (Dick Kennedy) [2034425]
- scsi: lpfc: Fix unload hang after back to back PCI EEH faults (Dick Kennedy) [2034425]
- scsi: lpfc: Improve PCI EEH Error and Recovery Handling (Dick Kennedy) [2034425]
- scsi: lpfc: Use kcalloc() (Dick Kennedy) [2034425]
- scsi: lpfc: Fix typos in comments (Dick Kennedy) [2034425]
- scsi: lpfc: Remove failing soft_wwn support (Dick Kennedy) [2034425]
- scsi: lpfc: Reduce log messages seen after firmware download (Dick Kennedy) [2034425]
- scsi: lpfc: Remove NVMe support if kernel has NVME_FC disabled (Dick Kennedy) [2034425]
- scsi: lpfc: Remove redundant flush_workqueue() call (Dick Kennedy) [2034425]
- scsi: lpfc: Terminate string in lpfc_debugfs_nvmeio_trc_write() (Dick Kennedy) [2034425]
- scsi: lpfc: Use irq_set_affinity() (Dick Kennedy) [2034425]
- time: Handle negative seconds correctly in timespec64_to_ns() (Íñigo Huguet) [2098634]
- time: Prevent undefined behaviour in timespec64_to_ns() (Íñigo Huguet) [2098634]
- mm,hwpoison: return -EBUSY when migration fails (Rafael Aquini) [2092671 2099510]
- mm,hwpoison: remove drain_all_pages from shake_page (Rafael Aquini) [2092671]
- mm,hwpoison: disable pcplists before grabbing a refcount (Rafael Aquini) [2092671]
- mm,hwpoison: fix printing of page flags (Rafael Aquini) [2092671]
- mm,hwpoison: refactor get_any_page (Rafael Aquini) [2092671]
- mm,hwpoison: drop unneeded pcplist draining (Rafael Aquini) [2092671]
- mm,hwpoison: drain pcplists before bailing out for non-buddy zero-refcount page (Rafael Aquini) [2092671]
- redhat: Exclude cpufreq.h from kernel-headers (Patrick Talbert)

* Fri Jul 01 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-407.el8]
- dm raid: fix accesses beyond end of raid member array (Benjamin Marzinski) [2012340]
- dm mirror log: clear log bits up to BITS_PER_LONG boundary (Benjamin Marzinski) [2012340]
- dm: fix BLK_STS_DM_REQUEUE handling when dm_io represents split bio (Benjamin Marzinski) [2012340]
- dm mirror log: round up region bitmap size to BITS_PER_LONG (Benjamin Marzinski) [2012340]
- dm: improve abnormal bio processing (Benjamin Marzinski) [2012340]
- dm: simplify bio-based IO accounting further (Benjamin Marzinski) [2012340]
- dm: don't grab target io reference in dm_zone_map_bio (Benjamin Marzinski) [2012340]
- dm: improve bio splitting and associated IO accounting (Benjamin Marzinski) [2012340]
- dm era: commit metadata in postsuspend after worker stops (Benjamin Marzinski) [2012340]
- dm: fix race in dm_start_io_acct (Benjamin Marzinski) [2012340]
- block: remove bioset_init_from_src (Benjamin Marzinski) [2012340]
- dm: fix bio_set allocation (Benjamin Marzinski) [2012340]
- dm verity: set DM_TARGET_IMMUTABLE feature flag (Benjamin Marzinski) [2012340]
- dm cache metadata: remove unnecessary variable in __dump_mapping (Benjamin Marzinski) [2012340]
- dm mpath: provide high-resolution timer to HST for bio-based (Benjamin Marzinski) [2012340]
- dm crypt: make printing of the key constant-time (Benjamin Marzinski) [2012340]
- dm integrity: fix error code in dm_integrity_ctr() (Benjamin Marzinski) [2012340]
- dm stats: add cond_resched when looping over entries (Benjamin Marzinski) [2012340]
- dm: improve dm_io reference counting (Benjamin Marzinski) [2012340]
- dm: switch to bdev based IO accounting interfaces (Benjamin Marzinski) [2012340]
- block: add sectors parameter to bio_start_io_acct_time() (Benjamin Marzinski) [2012340]
- dm: pass dm_io instance to dm_io_acct directly (Benjamin Marzinski) [2012340]
- dm: don't pass bio to __dm_start_io_acct and dm_end_io_acct (Benjamin Marzinski) [2012340]
- dm: use bio_sectors in dm_aceept_partial_bio (Benjamin Marzinski) [2012340]
- dm: simplify basic targets (Benjamin Marzinski) [2012340]
- dm: conditionally enable branching for less used features (Benjamin Marzinski) [2012340]
- dm: move hot dm_io members to same cacheline as dm_target_io (Benjamin Marzinski) [2012340]
- dm: add local variables to clone_endio and __map_bio (Benjamin Marzinski) [2012340]
- dm: mark various branches unlikely (Benjamin Marzinski) [2012340]
- dm: simplify dm_start_io_acct (Benjamin Marzinski) [2012340]
- dm: simplify dm_io access in dm_split_and_process_bio (Benjamin Marzinski) [2012340]
- dm: factor out dm_io_set_error and __dm_io_dec_pending (Benjamin Marzinski) [2012340]
- block: fix offset/size check in bio_trim() (Benjamin Marzinski) [2012340]
- block: fix argument type of bio_trim() (Benjamin Marzinski) [2012340]
- dm: allow dm_accept_partial_bio() for dm_io without duplicate bios (Benjamin Marzinski) [2012340]
- dm mpath: only use ktime_get_ns() in historical selector (Benjamin Marzinski) [2012340]
- dm: fix dm_io and dm_target_io flags race condition on Alpha (Benjamin Marzinski) [2012340]
- dm integrity: set journal entry unused when shrinking device (Benjamin Marzinski) [2012340]
- dm ioctl: log an error if the ioctl structure is corrupted (Benjamin Marzinski) [2012340]
- dm: consolidate spinlocks in dm_io struct (Benjamin Marzinski) [2012340]
- dm: reduce size of dm_io and dm_target_io structs (Benjamin Marzinski) [2012340]
- dm: switch dm_target_io booleans over to proper flags (Benjamin Marzinski) [2012340]
- dm: switch dm_io booleans over to proper flags (Benjamin Marzinski) [2012340]
- dm: return void from __send_empty_flush (Benjamin Marzinski) [2012340]
- dm: factor out dm_io_complete (Benjamin Marzinski) [2012340]
- dm cache: use dm_submit_bio_remap (Benjamin Marzinski) [2012340]
- dm: simplify dm_sumbit_bio_remap interface (Benjamin Marzinski) [2012340]
- dm thin: use dm_submit_bio_remap (Benjamin Marzinski) [2012340]
- dm: add WARN_ON_ONCE to dm_submit_bio_remap (Benjamin Marzinski) [2012340]
- dm: requeue IO if mapping table not yet available (Benjamin Marzinski) [2012340]
- dm thin metadata: remove unused dm_thin_remove_block and __remove (Benjamin Marzinski) [2012340]
- dm thin: use time_is_before_jiffies instead of open coding it (Benjamin Marzinski) [2012340]
- dm crypt: fix get_key_size compiler warning if !CONFIG_KEYS (Benjamin Marzinski) [2012340]
- dm ioctl: prevent potential spectre v1 gadget (Benjamin Marzinski) [2012340]
- dm cache policy smq: make static read-only array table const (Benjamin Marzinski) [2012340]
- dm delay: use dm_submit_bio_remap (Benjamin Marzinski) [2012340]
- dm crypt: use dm_submit_bio_remap (Benjamin Marzinski) [2012340]
- dm: add dm_submit_bio_remap interface (Benjamin Marzinski) [2012340]
- dm: flag clones created by __send_duplicate_bios (Benjamin Marzinski) [2012340]
- dm: reduce dm_io and dm_target_io struct sizes (Benjamin Marzinski) [2012340]
- dm: move duplicate code from callers of alloc_tio into alloc_tio (Benjamin Marzinski) [2012340]
- dm: record old_sector in dm_target_io before calling map function (Benjamin Marzinski) [2012340]
- dm: remove legacy code only needed before submit_bio recursion (Benjamin Marzinski) [2012340]
- dm: remove unused mapped_device argument from free_tio (Benjamin Marzinski) [2012340]
- dm: remove impossible BUG_ON in __send_empty_flush (Benjamin Marzinski) [2012340]
- dm: reduce code duplication in __map_bio (Benjamin Marzinski) [2012340]
- dm: refactor dm_split_and_process_bio a bit (Benjamin Marzinski) [2012340]
- dm: fold __clone_and_map_data_bio into __split_and_process_bio (Benjamin Marzinski) [2012340]
- dm: rename split functions (Benjamin Marzinski) [2012340]
- dm: eliminate copying of dm_io fields in dm_io_dec_pending (Benjamin Marzinski) [2012340]
- dm ioctl: return UUID in DM_LIST_DEVICES_CMD result (Benjamin Marzinski) [2012340]
- dm crypt: support using trusted keys (Benjamin Marzinski) [2012340]
- dm crypt: replaced #if defined with IS_ENABLED (Benjamin Marzinski) [2012340]
- ext4: add check to prevent attempting to resize an fs with sparse_super2 (Lukas Czerner) [2077760]
- fscache: Avoid ASSERTCMP if two threads race into fscache_disable_cookie (Dave Wysochanski) [2073260]
- lib: bitmap: Introduce node-aware alloc API (Ivan Vecera) [2101701]
- exec: Force single empty string when argv is empty (Rafael Aquini) [2100955]
- powerpc: Enable execve syscall exit tracepoint (Steve Best) [2095521]
- cgroup: disable controllers at parse time (Waiman Long) [2098264]
- init: initialize jump labels before command line option parsing (Waiman Long) [2098264]
- smp: Make softirq handling RT safe in flush_smp_call_function_queue() (Phil Auld) [2097364]
- smp: Rename flush_smp_call_function_from_idle() (Phil Auld) [2097364]
- cpupower: Add "perf" option to print AMD P-State information (Steve Best) [2059365]
- cpupower: Add function to print AMD P-State performance capabilities (Steve Best) [2059365]
- cpupower: Move print_speed function into misc helper (Steve Best) [2059365]
- cpupower: Enable boost state support for AMD P-State module (Steve Best) [2059365]
- cpupower: Add AMD P-State sysfs definition and access helper (Steve Best) [2059365]
- cpupower: Introduce ACPI CPPC library (Steve Best) [2059365]
- cpupower: Add the function to get the sysfs value from specific table (Steve Best) [2059365]
- cpupower: Initial AMD P-State capability (Steve Best) [2059365]
- cpupower: Add the function to check AMD P-State enabled (Steve Best) [2059365]
- cpupower: Add AMD P-State capability flag (Steve Best) [2059365]
- tools/power/cpupower/{ToDo => TODO}: Rename the todo file (Steve Best) [2059365]
- tools: cpupower: fix typo in cpupower-idle-set(1) manpage (Steve Best) [2059365]
- ntb: intel: fix port config status offset for SPR (John W. Linville) [2048750]
- NTB/msi: Use struct_size() helper in devm_kzalloc() (John W. Linville) [2048750]
- ntb_hw_switchtec: Fix a minor issue in config_req_id_table() (John W. Linville) [2048750]
- ntb_hw_switchtec: Remove code for disabling ID protection (John W. Linville) [2048750]
- ntb_hw_switchtec: Update the way of getting VEP instance ID (John W. Linville) [2048750]
- ntb_hw_switchtec: AND with the part_map for a valid tpart_vec (John W. Linville) [2048750]
- ntb_hw_switchtec: Fix bug with more than 32 partitions (John W. Linville) [2048750]
- ntb_hw_switchtec: Fix pff ioread to read into mmio_part_cfg_all (John W. Linville) [2048750]
- ntb_hw_switchtec: fix the spelling of "its" (John W. Linville) [2048750]
- NTB/msi: Fix ntbm_msi_request_threaded_irq() kernel-doc comment (John W. Linville) [2048750]
- NTB: switch from 'pci_' to 'dma_' API (John W. Linville) [2048750]
- ntb: ntb_pingpong: remove redundant initialization of variables msg_data and spad_data (John W. Linville) [2048750]
- NTB: perf: Fix an error code in perf_setup_inbuf() (John W. Linville) [2048750]
- NTB: Fix an error code in ntb_msit_probe() (John W. Linville) [2048750]
- ntb: intel: remove invalid email address in header comment (John W. Linville) [2048750]
- NTB: Add support for EPF PCI Non-Transparent Bridge (John W. Linville) [2048750]
- ntb: intel: add Intel NTB LTR vendor support for gen4 NTB (John W. Linville) [2048750]
- ntb: idt: fix error check in ntb_hw_idt.c (John W. Linville) [2048750]

* Wed Jun 29 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-406.el8]
- KVM: x86: Fix the intel_pt PMI handling wrongly considered from guest (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Don't rebuild page when the page is synced and no tlb flushing is required (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Verify the pmu event filter matches the correct event (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Add the helper function create_pmu_event_filter (Vitaly Kuznetsov) [2074835]
- kvm: x86/pmu: Fix the compare function used by the pmu event filter (Vitaly Kuznetsov) [2074835]
- KVM: Free new dirty bitmap if creating a new memslot fails (Vitaly Kuznetsov) [2074835]
- KVM: Initialize debugfs_dentry when a VM is created to avoid NULL deref (Vitaly Kuznetsov) [2074835]
- tools arch x86: Sync asm/cpufeatures.h with the with the kernel (Vitaly Kuznetsov) [2074835]
- KVM: PPC: Book3S HV: Fix kvm_unmap_gfn_range_hv() for Hash MMU (Vitaly Kuznetsov) [2074835]
- KVM: PPC: Book3S HV: Fix conversion to gfn-based MMU notifier callbacks (Vitaly Kuznetsov) [2074835]
- KVM: arm64: Fix boolreturn.cocci warnings (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Exit to userspace if vCPU has injected exception and invalid state (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Mark nested locking of vcpu->lock (Vitaly Kuznetsov) [2074835]
- kvm: x86/cpuid: Only provide CPUID leaf 0xA if host has architectural PMU (Vitaly Kuznetsov) [2074835]
- KVM: x86/svm: Account for family 17h event renumberings in amd_pmc_perf_hw_id (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Use atomic XCHG to write TDP MMU SPTEs with volatile bits (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Move shadow-present check out of spte_has_volatile_bits() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Don't treat fully writable SPTEs as volatile (modulo A/D) (Vitaly Kuznetsov) [2074835]
- selftests: kvm: add amx_test to .gitignore (Vitaly Kuznetsov) [2074835]
- Revert "x86/mm: Introduce lookup_address_in_mm()" (Vitaly Kuznetsov) [2074835]
- KVM: x86: work around QEMU issue with synthetic CPUID leaves (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: fix potential races when walking host page table (Vitaly Kuznetsov) [2074835]
- Documentation: KVM: Update documentation to indicate KVM is arm64-only (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Do not create SPTEs for GFNs that exceed host.MAXPHYADDR (Vitaly Kuznetsov) [2074835]
- kvm: selftests: introduce and use more page size-related constants (Vitaly Kuznetsov) [2074835]
- kvm: selftests: do not use bitfields larger than 32-bits for PTEs (Vitaly Kuznetsov) [2074835]
- KVM: SEV: add cache flush to solve SEV cache incoherency issues (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Flush when freeing encrypted pages even on SME_COHERENT CPUs (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Simplify and harden helper to flush SEV guest page(s) (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Silence compiler warning in the kvm_page_table_test (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Update AMD PMC sample period to fix guest NMI-watchdog (Vitaly Kuznetsov) [2074835]
- x86/kvm: Preserve BSP MSR_KVM_POLL_CONTROL across suspend/resume (Vitaly Kuznetsov) [2074835]
- KVM: x86: Skip KVM_GUESTDBG_BLOCKIRQ APICv update if APICv is disabled (Vitaly Kuznetsov) [2074835]
- KVM: x86: Pend KVM_REQ_APICV_UPDATE during vCPU creation to fix a race (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Defer APICv updates while L2 is active until L1 is active (Vitaly Kuznetsov) [2074835]
- KVM: x86: Tag APICv DISABLE inhibit, not ABSENT, if APICv is disabled (Vitaly Kuznetsov) [2074835]
- KVM: Add helpers to wrap vcpu->srcu_idx and yell if it's abused (Vitaly Kuznetsov) [2074835]
- KVM: x86: Don't re-acquire SRCU lock in complete_emulated_io() (Vitaly Kuznetsov) [2074835]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074835]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Vitaly Kuznetsov) [2074835]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074835]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074835]
- KVM: selftests: arm64: Check for supported page sizes (Vitaly Kuznetsov) [2074835]
- KVM: selftests: arm64: Initialise default guest mode at test startup time (Vitaly Kuznetsov) [2074835]
- KVM: selftests: arm64: Introduce a variable default IPA size (Vitaly Kuznetsov) [2074835]
- KVM: selftests: arm64: Rework TCR_EL1 configuration (Vitaly Kuznetsov) [2074835]
- KVM: x86: hyper-v: Avoid writing to TSC page without an active vCPU (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Do not activate AVIC for SEV-enabled guest (Vitaly Kuznetsov) [2074835]
- selftests: kvm: add tsc_scaling_sync to .gitignore (Vitaly Kuznetsov) [2074835]
- KVM: Don't create VM debugfs files outside of the VM directory (Vitaly Kuznetsov) [2074835]
- KVM: avoid NULL pointer dereference in kvm_dirty_ring_push (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: remove unnecessary flush_workqueue() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Resolve nx_huge_pages when kvm.ko is loaded (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Add cond_resched() to loop in sev_clflush_pages() (Vitaly Kuznetsov) [2074835]
- KVM: x86: fix sending PV IPI (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: do compare-and-exchange of gPTE via the user address (Vitaly Kuznetsov) [2074835]
- KVM: x86: Remove redundant vm_entry_controls_clearbit() call (Vitaly Kuznetsov) [2074835]
- KVM: x86: cleanup enter_rmode() (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: fix tsc scaling when the host doesn't support it (Vitaly Kuznetsov) [2074835]
- kvm: x86: SVM: remove unused defines (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: move tsc ratio definitions to svm.h (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: fix avic spec based definitions again (Vitaly Kuznetsov) [2074835]
- KVM: x86: Only do MSR filtering when access MSR by rdmsr/wrmsr (Vitaly Kuznetsov) [2074835]
- KVM: x86/emulator: Emulate RDPID only if it is enabled in guest (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Fix and isolate TSX-specific performance event logic (Vitaly Kuznetsov) [2074835]
- KVM: x86: mmu: trace kvm_mmu_set_spte after the new SPTE was set (Vitaly Kuznetsov) [2074835]
- KVM: x86/svm: Clear reserved bits written to PerfEvtSeln MSRs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Trace all APICv inhibit changes and capture overall status (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add wrappers for setting/clearing APICv inhibits (Vitaly Kuznetsov) [2074835]
- KVM: x86: Make APICv inhibit reasons an enum and cleanup naming (Vitaly Kuznetsov) [2074835]
- KVM: X86: Handle implicit supervisor access with SMAP (Vitaly Kuznetsov) [2074835]
- KVM: X86: Rename variable smap to not_smap in permission_fault() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Fix comments in update_permission_bitmask (Vitaly Kuznetsov) [2074835]
- KVM: X86: Change the type of access u32 to u64 (Vitaly Kuznetsov) [2074835]
- KVM: Remove dirty handling from gfn_to_pfn_cache completely (Vitaly Kuznetsov) [2074835]
- KVM: Use enum to track if cached PFN will be used in guest and/or host (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Fix kvm_cache_regs.h inclusions for is_guest_mode() (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Use different raw event masks for AMD and Intel (Vitaly Kuznetsov) [2074835]
- KVM: Don't actually set a request when evicting vCPUs for GFN cache invd (Vitaly Kuznetsov) [2074835]
- KVM: avoid double put_page with gfn-to-pfn cache (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap only TDP MMU leafs in zap range and mmu_notifier unmap (Vitaly Kuznetsov) [2074835]
- KVM: SVM: fix panic on out-of-bounds guest IRQ (Vitaly Kuznetsov) [2074835]
- KVM: MMU: propagate alloc_workqueue failure (Vitaly Kuznetsov) [2074835]
- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't activated (Vitaly Kuznetsov) [2074835]
- KVM: x86: Avoid theoretical NULL pointer dereference in kvm_irq_delivery_to_apic_fast() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Check lapic_in_kernel() before attempting to set a SynIC irq (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fix clang -Wimplicit-fallthrough in do_host_cpuid() (Vitaly Kuznetsov) [2074835]
- Revert "KVM: set owner of cpu and vm file operations" (Vitaly Kuznetsov) [2074835]
- KVM: Prevent module exit until all VMs are freed (Vitaly Kuznetsov) [2074835]
- KVM: use kvcalloc for array allocations (Vitaly Kuznetsov) [2074835]
- KVM: x86: Introduce KVM_CAP_DISABLE_QUIRKS2 (Vitaly Kuznetsov) [2074835]
- kvm: x86: Require const tsc for RT (Vitaly Kuznetsov) [2074835]
- KVM: x86: synthesize CPUID leaf 0x80000021h if useful (Vitaly Kuznetsov) [2074835]
- KVM: x86: add support for CPUID leaf 0x80000021 (Vitaly Kuznetsov) [2074835]
- Revert "KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range()" (Vitaly Kuznetsov) [2074835]
- kvm: x86/mmu: Flush TLB before zap_gfn_range releases RCU (Vitaly Kuznetsov) [2074835]
- kvm/emulate: Fix SETcc emulation function offsets with SLS (Vitaly Kuznetsov) [2074835]
- KVM: compat: riscv: Prevent KVM_COMPAT from being selected (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add test to populate a VM with the max possible guest mem (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Define cpu_relax() helpers for s390 and x86 (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Split out helper to allocate guest mem via memfd (Vitaly Kuznetsov) [2074835]
- KVM: selftests: add shared hugetlbfs backing source type (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Move raw KVM_SET_USER_MEMORY_REGION helper to utils (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: WARN on any attempt to atomically update REMOVED SPTE (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Check for a REMOVED leaf SPTE before making the SPTE (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap defunct roots via asynchronous worker (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap roots in two passes to avoid inducing RCU stalls (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Allow yielding when zapping GFNs for defunct TDP MMU root (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap invalidated roots via asynchronous worker (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Defer TLB flush to caller when freeing TDP MMU shadow pages (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Do remote TLB flush before dropping RCU in TDP MMU resched (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Require mmu_lock be held for write to zap TDP MMU range (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Add dedicated helper to zap TDP MMU root shadow page (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Skip remote TLB flush when zapping all of TDP MMU (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap only the target TDP MMU shadow page in NX recovery (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Refactor low-level TDP MMU set SPTE helper to take raw values (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: WARN if old _or_ new SPTE is REMOVED in non-atomic path (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Add helpers to read/write TDP MMU SPTEs and document RCU (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Drop RCU after processing each root in MMU notifier hooks (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Batch TLB flushes from TDP MMU for MMU notifier change_spte (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Check for !leaf=>leaf, not PFN change, in TDP MMU SP removal (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: do not allow readers to acquire references to invalid roots (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: only perform eager page splitting on valid roots (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Require mmu_lock be held for write in unyielding root iter (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Document that zapping invalidated roots doesn't need to flush (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Formalize TDP MMU's (unintended?) deferred TLB flush logic (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Fix wrong/misleading comments in TDP MMU fast zap (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Check for present SPTE when clearing dirty bit in TDP MMU (Vitaly Kuznetsov) [2074835]
- selftests: kvm: add generated file to the .gitignore (Vitaly Kuznetsov) [2074835]
- KVM: x86: pull kvm->srcu read-side to kvm_arch_vcpu_ioctl_run (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Passing up the error state of mmu_alloc_shadow_roots() (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Disable preemption across AVIC load/put during APICv refresh (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Exit to userspace on ENOMEM/EFAULT GHCB errors (Vitaly Kuznetsov) [2074835]
- KVM: WARN if is_unsync_root() is called on a root without a shadow page (Vitaly Kuznetsov) [2074835]
- KVM: Drop KVM_REQ_MMU_RELOAD and update vcpu-requests.rst documentation (Vitaly Kuznetsov) [2074835]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap only obsolete roots if a root shadow page is zapped (Vitaly Kuznetsov) [2074835]
- KVM: Drop kvm_reload_remote_mmus(), open code request in x86 users (Vitaly Kuznetsov) [2074835]
- KVM: x86: Invoke kvm_mmu_unload() directly on CR4.PCIDE change (Vitaly Kuznetsov) [2074835]
- KVM: x86/emulator: Move the unhandled outer privilege level logic of far return into __load_segment_descriptor() (Vitaly Kuznetsov) [2074835]
- KVM: x86/emulator: Fix wrong privilege check for code segment in __load_segment_descriptor() (Vitaly Kuznetsov) [2074835]
- KVM: x86/emulator: Defer not-present segment check in __load_segment_descriptor() (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add test to verify KVM handling of ICR (Vitaly Kuznetsov) [2074835]
- KVM: x86: Make kvm_lapic_set_reg() a "private" xAPIC helper (Vitaly Kuznetsov) [2074835]
- KVM: x86: Treat x2APIC's ICR as a 64-bit register, not two 32-bit regs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add helpers to handle 64-bit APIC MSR read/writes (Vitaly Kuznetsov) [2074835]
- KVM: x86: Make kvm_lapic_reg_{read,write}() static (Vitaly Kuznetsov) [2074835]
- KVM: x86: WARN if KVM emulates an IPI without clearing the BUSY flag (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Don't rewrite guest ICR on AVIC IPI virtualization failure (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Use common kvm_apic_write_nodecode() for AVIC write traps (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use "raw" APIC register read for handling APIC-write VM-Exit (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Handle APIC-write offset wrangling in VMX code (Vitaly Kuznetsov) [2074835]
- KVM: x86: Do not change ICR on write to APIC_SELF_IPI (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fix emulation in writing cr8 (Vitaly Kuznetsov) [2074835]
- KVM: x86: flush TLB separately from MMU reset (Vitaly Kuznetsov) [2074835]
- KVM: x86: Yield to IPI target vCPU only if it is busy (Vitaly Kuznetsov) [2074835]
- x86/kvmclock: Fix Hyper-V Isolated VM's boot issue when vCPUs > 64 (Vitaly Kuznetsov) [2074835]
- x86/kvm: Don't waste memory if kvmclock is disabled (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: clear MMIO cache when unloading the MMU (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Always use current mmu's role when loading new PGD (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: load new PGD after the shadow MMU is initialized (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: look for a cached PGD when going from 32-bit to 64-bit (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: do not pass vcpu to root freeing functions (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: do not consult levels when freeing roots (Vitaly Kuznetsov) [2074835]
- KVM: x86: use struct kvm_mmu_root_info for mmu->root (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: avoid NULL-pointer dereference on page freeing bugs (Vitaly Kuznetsov) [2074835]
- KVM: x86: do not deliver asynchronous page faults if CR0.PG=0 (Vitaly Kuznetsov) [2074835]
- KVM: x86: Reinitialize context if host userspace toggles EFER.LME (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Verify disabling PMU virtualization via KVM_CAP_CONFIG_PMU (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Carve out helper to create "default" VM without vCPUs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Provide per VM capability for disabling PMU virtualization (Vitaly Kuznetsov) [2074835]
- KVM: Move VM's worker kthreads back to the original cgroup before exiting. (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Remove scratch 'cpu' variable that shadows an identical scratch var (Vitaly Kuznetsov) [2074835]
- kvm: vmx: Fix typos comment in __loaded_vmcs_clear() (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Make setup/unsetup under the same conditions (Vitaly Kuznetsov) [2074835]
- KVM: x86: hyper-v: HVCALL_SEND_IPI_EX is an XMM fast hypercall (Vitaly Kuznetsov) [2074835]
- KVM: x86: hyper-v: Fix the maximum number of sparse banks for XMM fast TLB flush hypercalls (Vitaly Kuznetsov) [2074835]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_flush_tlb() (Vitaly Kuznetsov) [2074835]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_send_ipi() (Vitaly Kuznetsov) [2074835]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest()" (Vitaly Kuznetsov) [2074835]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs()" (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: disallow userspace setting of MSR_AMD64_TSC_RATIO to non default value when tsc scaling disabled (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: make apf token non-zero to fix bug (Vitaly Kuznetsov) [2074835]
- selftests: kvm: Add the uapi headers include variable (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add EXTRA_CFLAGS in top-level Makefile (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove MMU auditing (Vitaly Kuznetsov) [2074835]
- KVM: x86: make several APIC virtualization callbacks optional (Vitaly Kuznetsov) [2074835]
- KVM: x86: warn on incorrectly NULL members of kvm_x86_ops (Vitaly Kuznetsov) [2074835]
- KVM: x86: remove KVM_X86_OP_NULL and mark optional kvm_x86_ops (Vitaly Kuznetsov) [2074835]
- KVM: x86: use static_call_cond for optional callbacks (Vitaly Kuznetsov) [2074835]
- KVM: x86: return 1 unconditionally for availability of KVM_CAP_VAPIC (Vitaly Kuznetsov) [2074835]
- selftests: KVM: allow sev_migrate_tests on machines without SEV-ES (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Allow SEV intra-host migration of VM with mirrors (Vitaly Kuznetsov) [2074835]
- x86/kvm: Fix compilation warning in non-x86_64 builds (Vitaly Kuznetsov) [2074835]
- kvm: x86: Disable KVM_HC_CLOCK_PAIRING if tsc is in always catchup mode (Vitaly Kuznetsov) [2074835]
- KVM: Fix lockdep false negative during host resume (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add KVM_CAP_ENABLE_CAP to x86 (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Rename AVIC helpers to use "avic" prefix instead of "svm" (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Use AMD64_RAW_EVENT_MASK for PERF_TYPE_RAW (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Don't truncate the PerfEvtSeln MSR when creating a perf event (Vitaly Kuznetsov) [2074835]
- KVM: x86: Replace memset() "optimization" with normal per-field writes (Vitaly Kuznetsov) [2074835]
- KVM: SVM: fix race between interrupt delivery and AVIC inhibition (Vitaly Kuznetsov) [2074835]
- KVM: SVM: set IRR in svm_deliver_interrupt (Vitaly Kuznetsov) [2074835]
- KVM: SVM: extract avic_ring_doorbell (Vitaly Kuznetsov) [2074835]
- selftests: kvm: Remove absent target file (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Use local pointer to vcpu_vmx in vmx_vcpu_after_set_cpuid() (Vitaly Kuznetsov) [2074835]
- KVM: selftests: nSVM: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074835]
- KVM: selftests: nSVM: Update 'struct vmcb_control_area' definition (Vitaly Kuznetsov) [2074835]
- KVM: selftests: nSVM: Set up MSR-Bitmap for SVM guests (Vitaly Kuznetsov) [2074835]
- KVM: selftests: nVMX: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074835]
- KVM: selftests: nVMX: Properly deal with 'hv_clean_fields' (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Adapt hyperv_cpuid test to the newly introduced Enlightened MSR-Bitmap (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: Implement Enlightened MSR-Bitmap feature (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: Split off common definitions for Hyper-V on KVM and KVM on Hyper-V (Vitaly Kuznetsov) [2074835]
- KVM: x86: Make kvm_hv_hypercall_enabled() static inline (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add an option to disable MANUAL_PROTECT_ENABLE and INITIALLY_SET (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Add tracepoint for splitting huge pages (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU during KVM_CLEAR_DIRTY_LOG (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU when dirty logging is enabled (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Separate TDP MMU shadow page allocation and initialization (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Derive page role for TDP MMU shadow pages from parent (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove redundant role overrides for TDP MMU shadow pages (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Refactor TDP MMU iterators to take kvm_mmu_page root (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Move restore_acc_track_spte() to spte.h (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Drop new_spte local variable from restore_acc_track_spte() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove unnecessary warnings from restore_acc_track_spte() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Consolidate logic to atomically install a new TDP MMU page table (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename handle_removed_tdp_mmu_page() to handle_removed_pt() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename TDP MMU functions that handle shadow pages (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Change tdp_mmu_{set,zap}_spte_atomic() to return 0/-EBUSY (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Automatically update iter->old_spte if cmpxchg fails (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename __rmap_write_protect() to rmap_write_protect() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename rmap_write_protect() to kvm_vcpu_write_protect_gfn() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add checks for reserved-to-zero Hyper-V hypercall fields (Vitaly Kuznetsov) [2074835]
- KVM: x86: Reject fixeds-size Hyper-V hypercalls with non-zero "var_cnt" (Vitaly Kuznetsov) [2074835]
- KVM: x86: Shove vp_bitmap handling down into sparse_set_to_vcpu_mask() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Don't bother reading sparse banks that end up being ignored (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add a helper to get the sparse VP_SET for IPIs and TLB flushes (Vitaly Kuznetsov) [2074835]
- KVM: x86: Refactor kvm_hv_flush_tlb() to reduce indentation (Vitaly Kuznetsov) [2074835]
- KVM: x86: Get the number of Hyper-V sparse banks from the VARHEAD field (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Consolidate comments about {Host,MMU}-writable (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename DEFAULT_SPTE_MMU_WRITEABLE to DEFAULT_SPTE_MMU_WRITABLE (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Move is_writable_pte() to spte.h (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Check SPTE writable invariants when setting leaf SPTEs (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Move SPTE writable invariant checks to a helper function (Vitaly Kuznetsov) [2074835]
- KVM: LAPIC: Enable timer posted-interrupt only when mwait/hlt is advertised (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Dont' send posted IRQ if vCPU == this vCPU and vCPU is IN_GUEST_MODE (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Rename hook implementations to conform to kvm_x86_ops' names (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Rename SEV implemenations to conform to kvm_x86_ops hooks (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use more verbose names for mem encrypt kvm_x86_ops hooks (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Remove unused MAX_INST_SIZE #define (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Rename svm_flush_tlb() to svm_flush_tlb_current() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Move get_cs_db_l_bits() helper to SVM (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Rename VMX functions to conform to kvm_x86_ops names (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use static_call() for copy/move encryption context ioctls() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Unexport kvm_x86_ops (Vitaly Kuznetsov) [2074835]
- KVM: x86: Uninline and export hv_track_root_tdp() (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Refactor PMU refresh to avoid referencing kvm_x86_ops.pmu_ops (Vitaly Kuznetsov) [2074835]
- KVM: xen: Use static_call() for invoking kvm_x86_ops hooks (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use static_call() for .vcpu_deliver_sipi_vector() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Call vmx_get_cpl() directly in handle_dr() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Rename kvm_x86_ops pointers to align w/ preferred vendor names (Vitaly Kuznetsov) [2074835]
- KVM: x86: Drop export for .tlb_flush_current() static_call key (Vitaly Kuznetsov) [2074835]
- KVM: x86: skip host CPUID call for hypervisor leaves (Vitaly Kuznetsov) [2074835]
- KVM: x86: Remove unused "flags" of kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2074835]
- KVM: Remove unused "kvm" of kvm_make_vcpu_request() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Remove unused "vcpu" of kvm_scale_tsc() (Vitaly Kuznetsov) [2074835]
- KVM: x86/emulate: Remove unused "tss_selector" of task_switch_{16, 32}() (Vitaly Kuznetsov) [2074835]
- KVM: x86/emulate: Remove unused "ctxt" of setup_syscalls_segments() (Vitaly Kuznetsov) [2074835]
- KVM: x86/ioapic: Remove unused "addr" and "length" of ioapic_read_indirect() (Vitaly Kuznetsov) [2074835]
- KVM: x86/i8259: Remove unused "addr" of elcr_ioport_{read,write}() (Vitaly Kuznetsov) [2074835]
- KVM: SVM: improve split between svm_prepare_guest_switch and sev_es_prepare_guest_switch (Vitaly Kuznetsov) [2074835]
- KVM: x86/svm: Remove unused "vcpu" of svm_check_exit_valid() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu_audit: Remove unused "level" of audit_spte_after_sync() (Vitaly Kuznetsov) [2074835]
- KVM: x86/tdp_mmu: Remove unused "kvm" of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove unused "vcpu" of reset_{tdp,ept}_shadow_zero_bits_mask() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove unused "kvm" of __rmap_write_protect() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove unused "kvm" of kvm_mmu_unlink_parents() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Skip APICv update if APICv is disable at the module level (Vitaly Kuznetsov) [2074835]
- KVM: x86: Drop NULL check on kvm_x86_ops.check_apicv_inhibit_reasons (Vitaly Kuznetsov) [2074835]
- KVM: x86: Unexport __kvm_request_apicv_update() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Zap _all_ roots when unmapping gfn range in TDP MMU (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Move "invalid" check out of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Use common TDP MMU zap helper for MMU notifier unmap hook (Vitaly Kuznetsov) [2074835]
- KVM: x86/xen: Fix runstate updates to be atomic when preempting vCPU (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: move avic definitions from AMD's spec to svm.h (Vitaly Kuznetsov) [2074835]
- KVM: x86: lapic: don't touch irr_pending in kvm_apic_update_apicv when inhibiting it (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: deal with L1 hypervisor that intercepts interrupts but lets L2 control them (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: expose clean bit support to the guest (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM/nVMX: set nested_run_pending on VM entry which is a result of RSM (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: mark vmcb01 as dirty when restoring SMM saved state (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: fix potential NULL derefernce on nested migration (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: don't passthrough SMAP/SMEP/PKE bits in !NPT && !gCR0.PG case (Vitaly Kuznetsov) [2074835]
- Revert "svm: Add warning message for AVIC IPI invalid target" (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Test OS lock behavior (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Add OSLSR_EL1 to the list of blessed regs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Report deprecated x87 features in supported CPUID (Vitaly Kuznetsov) [2074835]
- x86/cpufeatures: Add FDP_EXCPTN_ONLY and ZERO_FCS_FDS (Vitaly Kuznetsov) [2074835]
- KVM: x86: use the KVM side max supported fixed counter (Vitaly Kuznetsov) [2074835]
- x86: Share definition of __is_canonical_address() (Vitaly Kuznetsov) [2074835]
- perf/x86/intel/pt: Relax address filter validation (Vitaly Kuznetsov) [2074835]
- KVM: x86: Move delivery of non-APICv interrupt into vendor code (Vitaly Kuznetsov) [2074835]
- KVM: eventfd: Fix false positive RCU usage warning (Vitaly Kuznetsov) [2074835]
- selftests: kvm: check dynamic bits against KVM_X86_XCOMP_GUEST_SUPP (Vitaly Kuznetsov) [2074835]
- KVM: x86: Sync the states size with the XCR0/IA32_XSS at, any time (Vitaly Kuznetsov) [2074835]
- KVM: x86: Update vCPU's runtime CPUID on write to MSR_IA32_XSS (Vitaly Kuznetsov) [2074835]
- KVM: x86: Keep MSR_IA32_XSS unchanged for INIT (Vitaly Kuznetsov) [2074835]
- KVM: x86: Free kvm_cpuid_entry2 array on post-KVM_RUN KVM_SET_CPUID{,2} (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: WARN on any attempt to allocate shadow VMCS for vmcs02 (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Don't skip L2's VMCALL in SMM test for SVM guest (Vitaly Kuznetsov) [2074835]
- KVM: x86: Check .flags in kvm_cpuid_check_equal() too (Vitaly Kuznetsov) [2074835]
- KVM: x86: Forcibly leave nested virt when SMM state is toggled (Vitaly Kuznetsov) [2074835]
- KVM: SVM: drop unnecessary code in svm_hv_vmcb_dirty_nested_enlightenments() (Vitaly Kuznetsov) [2074835]
- KVM: SVM: hyper-v: Enable Enlightened MSR-Bitmap support for real (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Don't kill SEV guest if SMAP erratum triggers in usermode (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Don't apply SEV+SMAP workaround on code fetch or PT access (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Inject #UD on attempted emulation for SEV guest w/o insn buffer (Vitaly Kuznetsov) [2074835]
- KVM: SVM: WARN if KVM attempts emulation on #UD or #GP for SEV guests (Vitaly Kuznetsov) [2074835]
- KVM: x86: Pass emulation type to can_emulate_instruction() (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Explicitly require DECODEASSISTS to enable SEV support (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Don't intercept #GP for SEV guests (Vitaly Kuznetsov) [2074835]
- Revert "KVM: SVM: avoid infinite loop on NPF from bad address" (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Never reject emulation due to SMAP errata for !SEV guests (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: skip eax alignment check for non-SVM instructions (Vitaly Kuznetsov) [2074835]
- KVM: LAPIC: Also cancel preemption timer during SET_LAPIC (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Remove vmcs_config.order (Vitaly Kuznetsov) [2074835]
- KVM/X86: Make kvm_vcpu_reload_apic_access_page() static (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Re-enable access_tracking_perf_test (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Set vmcs.PENDING_DBG.BS on #DB in STI/MOVSS blocking shadow (Vitaly Kuznetsov) [2074835]
- KVM: remove async parameter of hva_to_pfn_remapped() (Vitaly Kuznetsov) [2074835]
- x86,kvm/xen: Remove superfluous .fixup usage (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Zero host's SYSENTER_ESP iff SYSENTER is NOT used (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Fix the warning in lib/x86_64/processor.c (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Fix the warning in pmu_event_filter_test.c (Vitaly Kuznetsov) [2074835]
- kvm: selftests: Do not indent with spaces (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Nullify vcpu_(un)blocking() hooks if AVIC is disabled (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Move svm_hardware_setup() and its helpers below svm_x86_ops (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Drop AVIC's intermediate avic_set_running() helper (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Don't do full kick when handling posted interrupt wakeup (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Fold fallback path into triggering posted IRQ helper (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Pass desired vector instead of bool for triggering posted IRQ (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Don't do full kick when triggering posted interrupt "fails" (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Skip AVIC and IRTE updates when loading blocking vCPU (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Use kvm_vcpu_is_blocking() in AVIC load to handle preemption (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Remove unnecessary APICv/AVIC update in vCPU unblocking path (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Don't bother checking for "running" AVIC when kicking for IPIs (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Signal AVIC doorbell iff vCPU is in guest mode (Vitaly Kuznetsov) [2074835]
- KVM: x86: Remove defunct pre_block/post_block kvm_x86_ops hooks (Vitaly Kuznetsov) [2074835]
- KVM: x86: Unexport LAPIC's switch_to_{hv,sw}_timer() helpers (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Move preemption timer <=> hrtimer dance to common x86 (Vitaly Kuznetsov) [2074835]
- KVM: Move x86 VMX's posted interrupt list_head to vcpu_vmx (Vitaly Kuznetsov) [2074835]
- KVM: Drop unused kvm_vcpu.pre_pcpu field (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Handle PI descriptor updates during vcpu_put/load (Vitaly Kuznetsov) [2074835]
- KVM: avoid warning on s390 in mark_page_dirty (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add a test to force emulation with a pending exception (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Reject KVM_RUN if emulation is required with pending exception (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Add test for KVM_SET_PMU_EVENT_FILTER (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Introduce x86_model() (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Export x86_family() for use outside of processor.c (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Introduce is_amd_cpu() (Vitaly Kuznetsov) [2074835]
- selftests: kvm/x86: Parameterize the CPUID vendor string check (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Use binary search to check filtered events (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Improve TLB flush comment in kvm_mmu_slot_remove_write_access() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Document and enforce MMU-writable and Host-writable invariants (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Clear MMU-writable during changed_pte notifier (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Fix write-protection of PTs mapped by the TDP MMU (Vitaly Kuznetsov) [2074835]
- KVM: x86: Making the module parameter of vPMU more common (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Test KVM_SET_CPUID2 after KVM_RUN (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Rename 'get_cpuid_test' to 'cpuid_test' (Vitaly Kuznetsov) [2074835]
- KVM: x86: Partially allow KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Fix available_event_types check for REF_CPU_CYCLES event (Vitaly Kuznetsov) [2074835]
- KVM: x86: Check for rmaps allocation (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Mark nested locking of kvm->lock (Vitaly Kuznetsov) [2074835]
- KVM: SVM: include CR3 in initial VMSA state for SEV-ES guests (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Provide vmread version using asm-goto-with-outputs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fix wall clock writes in Xen shared_info not to mark page dirty (Vitaly Kuznetsov) [2074835]
- KVM: x86/xen: Add KVM_IRQ_ROUTING_XEN_EVTCHN and event channel delivery (Vitaly Kuznetsov) [2074835]
- KVM: x86/xen: Maintain valid mapping of Xen shared_info page (Vitaly Kuznetsov) [2074835]
- KVM: Reinstate gfn_to_pfn_cache with invalidation support (Vitaly Kuznetsov) [2074835]
- KVM: Warn if mark_page_dirty() is called without an active vCPU (Vitaly Kuznetsov) [2074835]
- x86/kvm: Silence per-cpu pr_info noise about KVM clocks and steal time (Vitaly Kuznetsov) [2074835]
- KVM: x86: Update vPMCs when retiring branch instructions (Vitaly Kuznetsov) [2074835]
- KVM: x86: Update vPMCs when retiring instructions (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Add pmc->intr to refactor kvm_perf_overflow{_intr}() (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Reuse pmc_perf_hw_id() and drop find_fixed_event() (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Refactoring find_arch_event() to pmc_perf_hw_id() (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Setup pmc->eventsel for fixed PMCs (Vitaly Kuznetsov) [2074835]
- KVM: x86: avoid out of bounds indices for fixed performance counters (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Mark VCPU_EXREG_CR3 dirty when !CR0_PG -> CR0_PG if EPT + !URG (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Reconstruct shadow page root if the guest PDPTEs is changed (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs() (Vitaly Kuznetsov) [2074835]
- Revert "KVM: X86: Update mmu->pdptrs only when it is changed" (Vitaly Kuznetsov) [2074835]
- selftests: KVM: sev_migrate_tests: Add mirror command tests (Vitaly Kuznetsov) [2074835]
- selftests: KVM: sev_migrate_tests: Fix sev_ioctl() (Vitaly Kuznetsov) [2074835]
- selftests: KVM: sev_migrate_tests: Fix test_sev_mirror() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Wake vCPU when delivering posted IRQ even if vCPU == this vCPU (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add test to verify TRIPLE_FAULT on invalid L2 guest state (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Synthesize TRIPLE_FAULT for L2 if emulation is required (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Always clear vmx->fail on emulation_required (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Fix non-x86 compiling (Vitaly Kuznetsov) [2074835]
- KVM: x86: Always set kvm_run->if_flag (Vitaly Kuznetsov) [2074835]
- KVM: x86: remove PMU FIXED_CTR3 from msrs_to_save_all (Vitaly Kuznetsov) [2074835]
- KVM: x86: Retry page fault if MMU reload is pending and root has no sp (Vitaly Kuznetsov) [2074835]
- KVM: selftests: vmx_pmu_msrs_test: Drop tests mangling guest visible CPUIDs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Drop guest CPUID check for host initiated writes to MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Add test to verify KVM doesn't explode on "bad" I/O (Vitaly Kuznetsov) [2074835]
- KVM: x86: Don't WARN if userspace mucks with RCX during string I/O exit (Vitaly Kuznetsov) [2074835]
- KVM: X86: Raise #GP when clearing CR0_PG in 64 bit mode (Vitaly Kuznetsov) [2074835]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2074835]
- KVM: x86: Ignore sparse banks size for an "all CPUs", non-sparse IPI req (Vitaly Kuznetsov) [2074835]
- KVM: Add Makefile.kvm for common files, use it for x86 (Vitaly Kuznetsov) [2074835]
- KVM: Introduce CONFIG_HAVE_KVM_DIRTY_RING (Vitaly Kuznetsov) [2074835]
- KVM: x86: selftests: svm_int_ctl_test: fix intercept calculation (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Clean up PI pre/post-block WARNs (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Ensure vCPU honors event request if posting nested IRQ fails (Vitaly Kuznetsov) [2074835]
- KVM: x86: add a tracepoint for APICv/AVIC interrupt delivery (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Implement Enlightened MSR Bitmap feature (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Introduce vmx_msr_bitmap_l01_changed() helper (Vitaly Kuznetsov) [2074835]
- KVM: x86: Exit to userspace if emulation prepared a completion callback (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Don't use Enlightened MSR Bitmap for L3 (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use different callback if msr access comes from the emulator (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add an emulation type to handle completion of user exits (Vitaly Kuznetsov) [2074835]
- KVM: x86: Handle 32-bit wrap of EIP for EMULTYPE_SKIP with flat code seg (Vitaly Kuznetsov) [2074835]
- KVM: Clear pv eoi pending bit only when it is set (Vitaly Kuznetsov) [2074835]
- KVM: x86: don't print when fail to read/write pv eoi memory (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove mmu parameter from load_pdptrs() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Rename gpte_is_8_bytes to has_4_byte_gpte and invert the direction (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Use ept_caps_to_lpage_level() in hardware_setup() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Add parameter huge_page_level to kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Add huge_page_level to __reset_rsvds_bits_mask_ept() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove mmu->translate_gpa (Vitaly Kuznetsov) [2074835]
- KVM: X86: Add parameter struct kvm_mmu *mmu into mmu->gva_to_gpa() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Calculate quadrant when !role.gpte_is_8_bytes (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove useless code to set role.gpte_is_8_bytes when role.direct (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove unused declaration of __kvm_mmu_free_some_pages() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Fix comment in __kvm_mmu_create() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Skip allocating pae_root for vcpu->arch.guest_mmu when !tdp_enabled (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Allocate sd->save_area with __GFP_ZERO (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Rename get_max_npt_level() to get_npt_level() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Change comments about vmx_get_msr() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Use kvm_set_msr_common() for MSR_IA32_TSC_ADJUST in the default way (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Update msr value after kvm_set_user_return_msr() succeeds (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Avoid to rdmsrl(MSR_IA32_SYSENTER_ESP) (Vitaly Kuznetsov) [2074835]
- KVM: X86: Update mmu->pdptrs only when it is changed (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove kvm_register_clear_available() (Vitaly Kuznetsov) [2074835]
- KVM: vmx, svm: clean up mass updates to regs_avail/regs_dirty bits (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Update vmcs.GUEST_CR3 only when the guest CR3 is dirty (Vitaly Kuznetsov) [2074835]
- KVM: X86: Mark CR3 dirty when vcpu->arch.cr3 is changed (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Remove references to VCPU_EXREG_CR3 (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Remove outdated comment in svm_load_mmu_pgd() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Move CR0 pdptr_bits into header file as X86_CR0_PDPTR_BITS (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Add and use X86_CR4_PDPTR_BITS when !enable_ept (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Add and use X86_CR4_TLBFLUSH_BITS when !enable_ept (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Track dirtiness of PDPTRs even if NPT is disabled (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Mark VCPU_EXREG_PDPTR available in ept_save_pdptrs() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Ensure that dirty PDPTRs are loaded (Vitaly Kuznetsov) [2074835]
- KVM: x86/svm: Add module param to control PMU virtualization (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Remove vCPU from PI wakeup list before updating PID.NV (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Move Posted Interrupt ndst computation out of write loop (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Read Posted Interrupt "control" exactly once per loop iteration (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Save/restore IRQs (instead of CLI/STI) during PI pre/post block (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Drop pointless PI.NDST update when blocking (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Use boolean returns for Posted Interrupt "test" helpers (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Drop unnecessary PI logic to handle impossible conditions (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Skip Posted Interrupt updates if APICv is hard disabled (Vitaly Kuznetsov) [2074835]
- KVM: Add helpers to wake/query blocking vCPU (Vitaly Kuznetsov) [2074835]
- KVM: x86: Invoke kvm_vcpu_block() directly for non-HALTED wait states (Vitaly Kuznetsov) [2074835]
- KVM: x86: Directly block (instead of "halting") UNINITIALIZED vCPUs (Vitaly Kuznetsov) [2074835]
- KVM: Don't redo ktime_get() when calculating halt-polling stop/deadline (Vitaly Kuznetsov) [2074835]
- KVM: stats: Add stat to detect if vcpu is currently blocking (Vitaly Kuznetsov) [2074835]
- KVM: Split out a kvm_vcpu_block() helper from kvm_vcpu_halt() (Vitaly Kuznetsov) [2074835]
- KVM: Rename kvm_vcpu_block() => kvm_vcpu_halt() (Vitaly Kuznetsov) [2074835]
- KVM: Drop obsolete kvm_arch_vcpu_block_finish() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Tweak halt emulation helper names to free up kvm_vcpu_halt() (Vitaly Kuznetsov) [2074835]
- KVM: Don't block+unblock when halt-polling is successful (Vitaly Kuznetsov) [2074835]
- KVM: Reconcile discrepancies in halt-polling stats (Vitaly Kuznetsov) [2074835]
- KVM: Refactor and document halt-polling stats update helper (Vitaly Kuznetsov) [2074835]
- KVM: Update halt-polling stats if and only if halt-polling was attempted (Vitaly Kuznetsov) [2074835]
- KVM: Force PPC to define its own rcuwait object (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Ensure target pCPU is read once when signalling AVIC doorbell (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Don't unblock vCPU w/ Posted IRQ if IRQs are disabled in guest (Vitaly Kuznetsov) [2074835]
- KVM: x86: change TLB flush indicator to bool (Vitaly Kuznetsov) [2074835]
- KVM: Avoid atomic operations when kicking the running vCPU (Vitaly Kuznetsov) [2074835]
- KVM: x86/MMU: Simplify flow of vmx_get_mt_mask (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Propagate memslot const qualifier (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove need for a vcpu from mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove need for a vcpu from kvm_slot_page_track_is_active (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Use shadow page role to detect PML-unfriendly pages for L2 (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: introduce struct vmcb_ctrl_area_cached (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: split out __nested_vmcb_check_controls (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: use svm->nested.save to load vmcb12 registers and avoid TOC/TOU races (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: use vmcb_save_area_cached in nested_vmcb_valid_sregs() (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: rename nested_load_control_from_vmcb12 in nested_copy_vmcb_control_to_cache (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: introduce svm->nested.save to cache save area before checks (Vitaly Kuznetsov) [2074835]
- KVM: nSVM: move nested_vmcb_check_cr3_cr4 logic in nested_vmcb_valid_sregs (Vitaly Kuznetsov) [2074835]
- KVM: Dynamically allocate "new" memslots from the get-go (Vitaly Kuznetsov) [2074835]
- KVM: Wait 'til the bitter end to initialize the "new" memslot (Vitaly Kuznetsov) [2074835]
- KVM: Optimize overlapping memslots check (Vitaly Kuznetsov) [2074835]
- KVM: Optimize gfn lookup in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074835]
- KVM: Call kvm_arch_flush_shadow_memslot() on the old slot in kvm_invalidate_memslot() (Vitaly Kuznetsov) [2074835]
- KVM: Keep memslots in tree-based structures instead of array-based ones (Vitaly Kuznetsov) [2074835]
- KVM: Use interval tree to do fast hva lookup in memslots (Vitaly Kuznetsov) [2074835]
- KVM: Resolve memslot ID via a hash table instead of via a static array (Vitaly Kuznetsov) [2074835]
- KVM: Move WARN on invalid memslot index to update_memslots() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use nr_memslot_pages to avoid traversing the memslots array (Vitaly Kuznetsov) [2074835]
- KVM: x86: Don't call kvm_mmu_change_mmu_pages() if the count hasn't changed (Vitaly Kuznetsov) [2074835]
- KVM: Don't make a full copy of the old memslot in __kvm_set_memory_region() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Don't assume old/new memslots are non-NULL at memslot commit (Vitaly Kuznetsov) [2074835]
- KVM: Use prepare/commit hooks to handle generic memslot metadata updates (Vitaly Kuznetsov) [2074835]
- KVM: Stop passing kvm_userspace_memory_region to arch memslot hooks (Vitaly Kuznetsov) [2074835]
- KVM: PPC: Avoid referencing userspace memory region in memslot updates (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074835]
- KVM: s390: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074835]
- KVM: arm64: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074835]
- KVM: Let/force architectures to deal with arch specific memslot data (Vitaly Kuznetsov) [2074835]
- KVM: Use "new" memslot's address space ID instead of dedicated param (Vitaly Kuznetsov) [2074835]
- KVM: Resync only arch fields when slots_arch_lock gets reacquired (Vitaly Kuznetsov) [2074835]
- KVM: Open code kvm_delete_memslot() into its only caller (Vitaly Kuznetsov) [2074835]
- KVM: Require total number of memslot pages to fit in an unsigned long (Vitaly Kuznetsov) [2074835]
- KVM: Convert kvm_for_each_vcpu() to using xa_for_each_range() (Vitaly Kuznetsov) [2074835]
- KVM: arm64: vgic-v3: Fix vcpu index comparison (Vitaly Kuznetsov) [2074835]
- KVM: Use 'unsigned long' as kvm_for_each_vcpu()'s index (Vitaly Kuznetsov) [2074835]
- KVM: Convert the kvm->vcpus array to a xarray (Vitaly Kuznetsov) [2074835]
- KVM: Move wiping of the kvm->vcpus array to common code (Vitaly Kuznetsov) [2074835]
- KVM: MMU: update comment on the number of page role combinations (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Retry page fault if root is invalidated by memslot update (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Set failure code in prepare_vmcs02() (Vitaly Kuznetsov) [2074835]
- KVM: ensure APICv is considered inactive if there is no APIC (Vitaly Kuznetsov) [2074835]
- KVM: x86/pmu: Fix reserved bits for AMD PerfEvtSeln register (Vitaly Kuznetsov) [2074835]
- x86: Snapshot thread flags (Vitaly Kuznetsov) [2074835]
- thread_info: Add helpers to snapshot thread flags (Vitaly Kuznetsov) [2074835]
- KVM: fix avic_set_running for preemptable kernels (Vitaly Kuznetsov) [2074835]
- KVM: VMX: clear vmx_x86_ops.sync_pir_to_irr if APICv is disabled (Vitaly Kuznetsov) [2074835]
- KVM: SEV: accept signals in sev_lock_two_vms (Vitaly Kuznetsov) [2074835]
- KVM: SEV: do not take kvm->lock when destroying (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Prohibit migration of a VM that has mirrors (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Do COPY_ENC_CONTEXT_FROM with both VMs locked (Vitaly Kuznetsov) [2074835]
- selftests: sev_migrate_tests: add tests for KVM_CAP_VM_COPY_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074835]
- KVM: SEV: move mirror status to destination of KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074835]
- KVM: SEV: initialize regions_list of a mirror VM (Vitaly Kuznetsov) [2074835]
- KVM: SEV: cleanup locking for KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074835]
- KVM: SEV: do not use list_replace_init on an empty list (Vitaly Kuznetsov) [2074835]
- KVM: x86: Use a stable condition around all VT-d PI paths (Vitaly Kuznetsov) [2074835]
- KVM: x86: check PIR even for vCPUs with disabled APICv (Vitaly Kuznetsov) [2074835]
- KVM: VMX: prepare sync_pir_to_irr for running with APICv disabled (Vitaly Kuznetsov) [2074835]
- KVM: selftests: page_table_test: fix calculation of guest_test_phys_mem (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Handle "default" period when selectively waking kthread (Vitaly Kuznetsov) [2074835]
- KVM: MMU: shadow nested paging does not have PKU (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Remove spurious TLB flushes in TDP MMU zap collapsible path (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Use yield-safe TDP MMU root iter in MMU notifier unmapping (Vitaly Kuznetsov) [2074835]
- KVM: X86: Use vcpu->arch.walk_mmu for kvm_mmu_invlpg() (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Make sure kvm_create_max_vcpus test won't hit RLIMIT_NOFILE (Vitaly Kuznetsov) [2074835]
- KVM: x86: Forbid KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Avoid KVM_SET_CPUID2 after KVM_RUN in hyperv_features test (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Emulate guest TLB flush on nested VM-Enter with new vpid12 (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Abide to KVM_REQ_TLB_FLUSH_GUEST request on nested vmentry/vmexit (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Flush current VPID (L1 vs. L2) for KVM_REQ_TLB_FLUSH_GUEST (Vitaly Kuznetsov) [2074835]
- KVM: SEV: expose KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM capability (Vitaly Kuznetsov) [2074835]
- selftests: sev_migrate_tests: free all VMs (Vitaly Kuznetsov) [2074835]
- selftests: fix check for circular KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074835]
- KVM: x86: ignore APICv if LAPIC is not enabled (Vitaly Kuznetsov) [2074835]
- KVM: downgrade two BUG_ONs to WARN_ON_ONCE (Vitaly Kuznetsov) [2074835]
- KVM: VMX: do not use uninitialized gfn_to_hva_cache (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Pass parameter flush as false in kvm_tdp_mmu_zap_collapsible_sptes() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Skip tlb flush if it has been done in zap_gfn_range() (Vitaly Kuznetsov) [2074835]
- x86/kvm: remove unused ack_notifier callbacks (Vitaly Kuznetsov) [2074835]
- KVM: Disallow user memslot with size that exceeds "unsigned long" (Vitaly Kuznetsov) [2074835]
- KVM: Ensure local memslot copies operate on up-to-date arch-specific data (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Fix TLB flush range when handling disconnected pt (Vitaly Kuznetsov) [2074835]
- KVM: x86: Assume a 64-bit hypercall for guests with protected state (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Add /x86_64/sev_migrate_tests to .gitignore (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Fix typo in and tweak name of cmd_allowed_from_miror() (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Drop a redundant setting of sev->asid during initialization (Vitaly Kuznetsov) [2074835]
- KVM: SEV: WARN if SEV-ES is marked active but SEV is not (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Set sev_info.active after initial checks in sev_guest_init() (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Disallow COPY_ENC_CONTEXT_FROM if target has created vCPUs (Vitaly Kuznetsov) [2074835]
- KVM: Kill kvm_map_gfn() / kvm_unmap_gfn() and gfn_to_pfn_cache (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Use a gfn_to_hva_cache for vmptrld (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Use kvm_read_guest_offset_cached() for nested VMCS check (Vitaly Kuznetsov) [2074835]
- KVM: x86/xen: Use sizeof_field() instead of open-coding it (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Use kvm_{read,write}_guest_cached() for shadow_vmcs12 (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: include EFER.LMA in extended mmu role (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: don't use vcpu->arch.efer when checking host state on nested state load (Vitaly Kuznetsov) [2074835]
- KVM: Fix steal time asm constraints (Vitaly Kuznetsov) [2074835]
- KVM: x86: Move Intel Processor Trace interrupt handler to vmx.c (Vitaly Kuznetsov) [2074835]
- KVM: Move x86's perf guest info callbacks to generic KVM (Vitaly Kuznetsov) [2074835]
- KVM: x86: More precisely identify NMI from guest when handling PMI (Vitaly Kuznetsov) [2074835]
- KVM: x86: Drop current_vcpu for kvm_running_vcpu + kvm_arch_vcpu variable (Vitaly Kuznetsov) [2074835]
- perf/core: Rework guest callbacks to prepare for static_call support (Vitaly Kuznetsov) [2074835]
- perf: Protect perf_guest_cbs with RCU (Vitaly Kuznetsov) [2074835]
- KVM: x86: Register Processor Trace interrupt hook iff PT enabled in guest (Vitaly Kuznetsov) [2074835]
- KVM: x86: Register perf callbacks after calling vendor's hardware_setup() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fix uninitialized eoi_exit_bitmap usage in vcpu_load_eoi_exitmap() (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Use perf_test_destroy_vm in memslot_modification_stress_test (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Wait for all vCPU to be created before entering guest mode (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Move vCPU thread creation and joining to common helpers (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Sync perf_test_args to guest during VM creation (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Fill per-vCPU struct during "perf_test" VM creation (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Start at iteration 0 instead of -1 (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Create VM with adjusted number of guest pages for perf tests (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Remove perf_test_args.host_page_size (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Move per-VM GPA into perf_test_args (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Use perf util's per-vCPU GPA/pages in demand paging test (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Capture per-vCPU GPA in perf_test_vcpu_args (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Use shorthand local var to access struct perf_tests_args (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Require GPA to be aligned when backed by hugepages (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Assert mmap HVA is aligned when using HugeTLB (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Expose align() helpers to tests (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Explicitly state indicies for vm_guest_mode_params array (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Add event channel upcall support to xen_shinfo_test (Vitaly Kuznetsov) [2074835]
- KVM: SEV: unify cgroup cleanup code for svm_vm_migrate_from (Vitaly Kuznetsov) [2074835]
- KVM: x86: move guest_pv_has out of user_access section (Vitaly Kuznetsov) [2074835]
- KVM: Move INVPCID type check from vmx and svm to the common kvm_handle_invpcid() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Add a helper function to retrieve the GPR index for INVPCID, INVVPID, and INVEPT (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Clean up x2APIC MSR handling for L2 (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Macrofy the MSR bitmap getters and setters (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Handle dynamic MSR intercept toggling (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Query current VMCS when determining if MSR bitmaps are in use (Vitaly Kuznetsov) [2074835]
- KVM: x86: Don't update vcpu->arch.pv_eoi.msr_val when a bogus value was written to MSR_KVM_PV_EOI_EN (Vitaly Kuznetsov) [2074835]
- KVM: x86: Rename kvm_lapic_enable_pv_eoi() (Vitaly Kuznetsov) [2074835]
- kvm: mmu: Use fast PF path for access tracking of huge pages when possible (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Properly dereference rcu-protected TDP MMU sptep iterator (Vitaly Kuznetsov) [2074835]
- kvm: x86: Convert return type of *is_valid_rdpmc_ecx() to bool (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fix recording of guest steal time / preempted status (Vitaly Kuznetsov) [2074835]
- selftest: KVM: Add intra host migration tests (Vitaly Kuznetsov) [2074835]
- selftest: KVM: Add open sev dev helper (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Add support for SEV-ES intra host migration (Vitaly Kuznetsov) [2074835]
- KVM: SEV: Add support for SEV intra host migration (Vitaly Kuznetsov) [2074835]
- KVM: SEV: provide helpers to charge/uncharge misc_cg (Vitaly Kuznetsov) [2074835]
- KVM: generalize "bugged" VM to "dead" VM (Vitaly Kuznetsov) [2074835]
- EFI: Introduce the new AMD Memory Encryption GUID. (Vitaly Kuznetsov) [2074835]
- x86/kvm: Add AMD SEV specific Hypercall3 (Vitaly Kuznetsov) [2074835]
- KVM: x86: SGX must obey the KVM_INTERNAL_ERROR_EMULATION protocol (Vitaly Kuznetsov) [2074835]
- KVM: x86: On emulation failure, convey the exit reason, etc. to userspace (Vitaly Kuznetsov) [2074835]
- KVM: x86: Get exit_reason as part of kvm_x86_ops.get_exit_info (Vitaly Kuznetsov) [2074835]
- KVM: x86: Clarify the kvm_run.emulation_failure structure layout (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Fix nested SVM tests when built with clang (Vitaly Kuznetsov) [2074835]
- kvm: x86: Remove stale declaration of kvm_no_apic_vcpu (Vitaly Kuznetsov) [2074835]
- KVM: x86: Move SVM's APICv sanity check to common x86 (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Extract zapping of rmaps for gfn range to separate helper (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Drop a redundant remote TLB flush in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Drop a redundant, broken remote TLB flush (Vitaly Kuznetsov) [2074835]
- KVM: X86: Don't unload MMU in kvm_vcpu_flush_tlb_guest() (Vitaly Kuznetsov) [2074835]
- KVM: X86: pair smp_wmb() of mmu_try_to_unsync_pages() with smp_rmb() (Vitaly Kuznetsov) [2074835]
- KVM: emulate: Comment on difference between RDPMC implementation and manual (Vitaly Kuznetsov) [2074835]
- KVM: x86: Add vendor name to kvm_x86_ops, use it for error messages (Vitaly Kuznetsov) [2074835]
- kvm: x86: mmu: Make NX huge page recovery period configurable (Vitaly Kuznetsov) [2074835]
- KVM: vPMU: Fill get_msr MSR_CORE_PERF_GLOBAL_OVF_CTRL w/ 0 (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename slot_handle_leaf to slot_handle_level_4k (Vitaly Kuznetsov) [2074835]
- KVM: VMX: RTIT_CTL_BRANCH_EN has no dependency on other CPUID bit (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Rename pt_desc.addr_range to pt_desc.num_address_ranges (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Use precomputed vmx->pt_desc.addr_range (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Restore host's MSR_IA32_RTIT_CTL when it's not zero (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: clean up prefetch/prefault/speculative naming (Vitaly Kuznetsov) [2074835]
- KVM: cleanup allocation of rmaps and page tracking data (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Introduce system counter offset test (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Add helpers for vCPU device attributes (Vitaly Kuznetsov) [2074835]
- selftests: KVM: Add test for KVM_{GET,SET}_CLOCK (Vitaly Kuznetsov) [2074835]
- kvm: x86: protect masterclock with a seqcount (Vitaly Kuznetsov) [2074835]
- KVM: x86: Report host tsc and realtime values in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074835]
- KVM: x86: avoid warning with -Wbitwise-instead-of-logical (Vitaly Kuznetsov) [2074835]
- KVM: x86: only allocate gfn_track when necessary (Vitaly Kuznetsov) [2074835]
- KVM: x86: add config for non-kvm users of page tracking (Vitaly Kuznetsov) [2074835]
- nSVM: Check for reserved encodings of TLB_CONTROL in nested VMCB (Vitaly Kuznetsov) [2074835]
- kvm: use kvfree() in kvm_arch_free_vm() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Expose Predictive Store Forwarding Disable (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Avoid memslot lookup in make_spte and mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Avoid memslot lookup in rmap_add (Vitaly Kuznetsov) [2074835]
- KVM: MMU: pass struct kvm_page_fault to mmu_set_spte (Vitaly Kuznetsov) [2074835]
- KVM: MMU: pass kvm_mmu_page struct to make_spte (Vitaly Kuznetsov) [2074835]
- KVM: MMU: set ad_disabled in TDP MMU role (Vitaly Kuznetsov) [2074835]
- KVM: MMU: remove unnecessary argument to mmu_set_spte (Vitaly Kuznetsov) [2074835]
- KVM: MMU: clean up make_spte return value (Vitaly Kuznetsov) [2074835]
- KVM: MMU: inline set_spte in FNAME(sync_page) (Vitaly Kuznetsov) [2074835]
- KVM: MMU: inline set_spte in mmu_set_spte (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Avoid memslot lookup in page_fault_handle_page_track (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Pass the memslot around via struct kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: unify tdp_mmu_map_set_spte_atomic and tdp_mmu_set_spte_atomic_no_dirty_log (Vitaly Kuznetsov) [2074835]
- KVM: MMU: mark page dirty in make_spte (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Fold rmap_recycle into rmap_add (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Verify shadow walk doesn't terminate early in page faults (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change tracepoints arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change disallowed_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change kvm_mmu_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change fast_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change tdp_mmu_map_handle_target_level() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change kvm_tdp_mmu_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change FNAME(fetch)() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change __direct_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change handle_abnormal_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change kvm_faultin_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change page_fault_handle_page_track() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change direct_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: change mmu->page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: Introduce struct kvm_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: MMU: pass unadulterated gpa to direct_page_fault (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fix potential race in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074835]
- KVM: x86: extract KVM_GET_CLOCK/KVM_SET_CLOCK to separate functions (Vitaly Kuznetsov) [2074835]
- kvm: x86: abstract locking around pvclock_update_vm_gtod_copy (Vitaly Kuznetsov) [2074835]
- KVM: X86: Move PTE present check from loop body to __shadow_walk_next() (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: implement nested TSC scaling (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: add module param to control TSC scaling (Vitaly Kuznetsov) [2074835]
- KVM: x86: SVM: add module param to control LBR virtualization (Vitaly Kuznetsov) [2074835]
- KVM: x86: nSVM: don't copy pause related settings (Vitaly Kuznetsov) [2074835]
- kvm: irqfd: avoid update unmodified entries of the routing (Vitaly Kuznetsov) [2074835]
- KVM: X86: Don't check unsync if the original spte is writible (Vitaly Kuznetsov) [2074835]
- KVM: X86: Don't unsync pagetables when speculative (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove FNAME(update_pte) (Vitaly Kuznetsov) [2074835]
- KVM: X86: Zap the invalid list after remote tlb flushing (Vitaly Kuznetsov) [2074835]
- KVM: X86: Change kvm_sync_page() to return true when remote flush is needed (Vitaly Kuznetsov) [2074835]
- KVM: X86: Remove kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [2074835]
- KVM: X86: Don't flush current tlb on shadow page modification (Vitaly Kuznetsov) [2074835]
- KVM: selftests: Fix kvm_vm_free() in cr4_cpuid_sync and vmx_tsc_adjust tests (Vitaly Kuznetsov) [2074835]
- kvm: selftests: Fix spelling mistake "missmatch" -> "mismatch" (Vitaly Kuznetsov) [2074835]
- KVM: x86: Manually retrieve CPUID.0x1 when getting FMS for RESET/INIT (Vitaly Kuznetsov) [2074835]
- KVM: x86: WARN on non-zero CRs at RESET to detect improper initalization (Vitaly Kuznetsov) [2074835]
- KVM: SVM: Move RESET emulation to svm_vcpu_reset() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Move RESET emulation to vmx_vcpu_reset() (Vitaly Kuznetsov) [2074835]
- KVM: VMX: Drop explicit zeroing of MSR guest values at vCPU creation (Vitaly Kuznetsov) [2074835]
- KVM: x86: Fold fx_init() into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [2074835]
- KVM: x86: Remove defunct setting of XCR0 for guest during vCPU create (Vitaly Kuznetsov) [2074835]
- KVM: x86: Remove defunct setting of CR0.ET for guests during vCPU create (Vitaly Kuznetsov) [2074835]
- KVM: x86: Simplify retrieving the page offset when loading PDTPRs (Vitaly Kuznetsov) [2074835]
- KVM: x86: Subsume nested GPA read helper into load_pdptrs() (Vitaly Kuznetsov) [2074835]
- kvm: rename KVM_MAX_VCPU_ID to KVM_MAX_VCPU_IDS (Vitaly Kuznetsov) [2074835]
- KVM: Make kvm_make_vcpus_request_mask() use pre-allocated cpu_kick_mask (Vitaly Kuznetsov) [2074835]
- KVM: Pre-allocate cpumasks for kvm_make_all_cpus_request_except() (Vitaly Kuznetsov) [2074835]
- KVM: Drop 'except' parameter from kvm_make_vcpus_request_mask() (Vitaly Kuznetsov) [2074835]
- KVM: Optimize kvm_make_vcpus_request_mask() a bit (Vitaly Kuznetsov) [2074835]
- KVM: x86: hyper-v: Avoid calling kvm_make_vcpus_request_mask() with vcpu_mask==NULL (Vitaly Kuznetsov) [2074835]
- KVM: use vma_pages() helper (Vitaly Kuznetsov) [2074835]
- KVM: nVMX: Reset vmxon_ptr upon VMXOFF emulation. (Vitaly Kuznetsov) [2074835]
- x86/kvm: Always inline to_svm() (Vitaly Kuznetsov) [2074835]
- x86/kvm: Always inline vmload() / vmsave() (Vitaly Kuznetsov) [2074835]
- x86/kvm: Always inline sev_*guest() (Vitaly Kuznetsov) [2074835]
- KVM: Remove tlbs_dirty (Vitaly Kuznetsov) [2074835]
- KVM: X86: fix lazy allocation of rmaps (Vitaly Kuznetsov) [2074835]
- KVM: Remove unnecessary export of kvm_{inc,dec}_notifier_count() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Drop 'shared' param from tdp_mmu_link_page() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Add detailed page size stats (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: bump mmu notifier count in kvm_zap_gfn_range (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: fix parameters to kvm_flush_remote_tlbs_with_address (Vitaly Kuznetsov) [2074835]
- Revert "KVM: x86/mmu: Allow zap gfn range to operate under the mmu read lock" (Vitaly Kuznetsov) [2074835]
- KVM: X86: Introduce mmu_rmaps_stat per-vm debugfs file (Vitaly Kuznetsov) [2074835]
- KVM: X86: Introduce kvm_mmu_slot_lpages() helpers (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Protect marking SPs unsync when using TDP MMU with spinlock (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Don't step down in the TDP iterator when zapping all SPTEs (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Don't leak non-leaf SPTEs when zapping all SPTEs (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Rename __gfn_to_rmap to gfn_to_rmap (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Leverage vcpu->last_used_slot in tdp_mmu_map_handle_target_level (Vitaly Kuznetsov) [2074835]
- KVM: const-ify all relevant uses of struct kvm_memory_slot (Vitaly Kuznetsov) [2074835]
- KVM: Don't take mmu_lock for range invalidation unless necessary (Vitaly Kuznetsov) [2074835]
- KVM: Block memslot updates across range_start() and range_end() (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Lazily allocate memslot rmaps (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Skip rmap operations if rmaps not allocated (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Tear down roots before kvm_mmu_zap_all_fast returns (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Fast invalidation for TDP MMU (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Allow enabling/disabling dirty logging under MMU read lock (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Allow zapping collapsible SPTEs to use MMU read lock (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Allow zap gfn range to operate under the mmu read lock (Vitaly Kuznetsov) [2074835]
- KVM: x86/mmu: Allow yielding during MMU notifier unmap/zap, if possible (Vitaly Kuznetsov) [2074835]
- KVM: Take mmu_lock when handling MMU notifier iff the hva hits a memslot (Vitaly Kuznetsov) [2074835]
- KVM: Move MMU notifier's mmu_lock acquisition into common helper (Vitaly Kuznetsov) [2074835]
- KVM: Kill off the old hva-based MMU notifier callbacks (Vitaly Kuznetsov) [2074835]
- KVM: PPC: Convert to the gfn-based MMU notifier callbacks (Vitaly Kuznetsov) [2074835]
- KVM: arm64: Convert to the gfn-based MMU notifier callbacks (Vitaly Kuznetsov) [2074835]
- KVM: Move x86's MMU notifier memslot walkers to generic code (Vitaly Kuznetsov) [2074835]
- KVM: Assert that notifier count is elevated in .change_pte() (Vitaly Kuznetsov) [2074835]
- KVM: Move arm64's MMU notifier trace events to generic code (Vitaly Kuznetsov) [2074835]
- KVM: Switch to new MMU notifiers API (Vitaly Kuznetsov) [2074835]
- scsi: qedi: Remove redundant flush_workqueue() calls (Nilesh Javali) [2044837]
- scsi: qedi: Fix SYSFS_FLAG_FW_SEL_BOOT formatting (Nilesh Javali) [2044837]
- xfs: reserve quota for dir expansion when linking/unlinking files (Carlos Maiolino) [2082833]
- iwlwifi: fix use-after-free (Jose Ignacio Tornos Martinez) [2091539]
- nfs: fix broken handling of the softreval mount option (Benjamin Coddington) [2083224]
- ethtool: extend ringparam setting/getting API with rx_buf_len (Ivan Vecera) [2091857]
- ethtool: add support to set/get rx buf len via ethtool (Ivan Vecera) [2091857]
- ethtool: add support to set/get tx copybreak buf size via ethtool (Ivan Vecera) [2091857]

* Mon Jun 27 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-405.el8]
- x86/apic: Make TSC deadline timer detection message visible (David Arcari) [2098086]
- x86/apic: Move TSC deadline timer debug printk (David Arcari) [2098086]
- [s390] KVM: s390: selftests: Add error memop tests (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: selftests: Add more copy memop tests (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: selftests: Add named stages for memop test (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: selftests: Add macro as abstraction for MEM_OP (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: selftests: Split memop tests (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Fix lockdep issue in vm memop (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Add missing vm MEM_OP size check (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Clarify key argument for MEM_OP in api docs (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Update api documentation for memop ioctl (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Add capability for storage key extension of MEM_OP IOCTL (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Rename existing vcpu memop functions (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Add vm IOCTL for key checked guest absolute memory access (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Add optional storage key checking to MEMOP IOCTL (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: selftests: Test TEST PROTECTION emulation (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: handle_tprot: Honor storage keys (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: Honor storage keys when accessing guest memory (Claudio Imbrenda) [1984917]
- [s390] s390/uaccess: Add copy_from/to_user_key functions (Claudio Imbrenda) [1984917]
- [s390] s390/uaccess: fix compile error (Claudio Imbrenda) [1984917]
- [s390] s390/uaccess: introduce bit field for OAC specifier (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: gaccess: Cleanup access to guest pages (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: gaccess: Refactor access address range check (Claudio Imbrenda) [1984917]
- [s390] KVM: s390: gaccess: Refactor gpa and length calculation (Claudio Imbrenda) [1984917]
- xfs: reorder iunlink remove operation in xfs_ifree (Brian Foster) [2081146]
- tcp: fix TCP socket rehash stats mis-accounting (Antoine Tenart) [2073082]
- tcp: export count for rehash attempts (Antoine Tenart) [2073082]
- tcp: add SRTT to SCM_TIMESTAMPING_OPT_STATS (Antoine Tenart) [2073082]
- tcp: add new SNMP counter for drops when try to queue in rcv queue (Antoine Tenart) [2073082]
- tcp: add SNMP counter for zero-window drops (Antoine Tenart) [2073082]
- net: udp: introduce UDP_MIB_MEMERRORS for udp_mem (Antoine Tenart) [2073082]
- context_tracking: Sync up lockdep and cpu irqs state to prevent false warnings (Waiman Long) [2098074]
- platform/x86: ISST: Fix possible circular locking dependency detected (Prarit Bhargava) [2072659]
- platform/x86: ISST: use semi-colons instead of commas (Prarit Bhargava) [2072659]
- platform/x86: intel_speed_select_if: Move to intel sub-directory (Prarit Bhargava) [2072659]
- x86/sgx: Free backing memory after faulting the enclave page (Vladis Dronov) [2081351]
- x86/sgx: Fix missing poison handling in reclaimer (Vladis Dronov) [2081351]
- x86/sgx: Silence softlockup detection when releasing large enclaves (Vladis Dronov) [2081351]
- selftests/sgx: Treat CC as one argument (Vladis Dronov) [2081351]
- selftests/x86: Add validity check and allow field splitting (Vladis Dronov) [2081351]
- selftests/sgx: Remove extra newlines in test output (Vladis Dronov) [2081351]
- selftests/sgx: Ensure enclave data available during debug print (Vladis Dronov) [2081351]
- selftests/sgx: Do not attempt enclave build without valid enclave (Vladis Dronov) [2081351]
- selftests/sgx: Fix NULL-pointer-dereference upon early test failure (Vladis Dronov) [2081351]
- x86/sgx: Remove .fixup usage (Vladis Dronov) [2081351]
- x86/sgx: Fix NULL pointer dereference on non-SGX systems (Vladis Dronov) [2081351]
- x86/sgx: Add an attribute for the amount of SGX memory in a NUMA node (Vladis Dronov) [2081351]
- vmxnet3: disable overlay offloads if UPT device does not support (Kamal Heib) [2100226]
- vmxnet3: update to version 7 (Kamal Heib) [2100226]
- vmxnet3: use ext1 field to indicate encapsulated packet (Kamal Heib) [2100226]
- vmxnet3: limit number of TXDs used for TSO packet (Kamal Heib) [2100226]
- vmxnet3: add command to set ring buffer sizes (Kamal Heib) [2100226]
- vmxnet3: add support for out of order rx completion (Kamal Heib) [2100226]
- vmxnet3: add support for large passthrough BAR register (Kamal Heib) [2100226]
- vmxnet3: add support for capability registers (Kamal Heib) [2100226]
- vmxnet3: prepare for version 7 changes (Kamal Heib) [2100226]
- net: vmxnet3: fix possible NULL pointer dereference in vmxnet3_rq_cleanup() (Kamal Heib) [2100226]
- net: vmxnet3: fix possible use-after-free bugs in vmxnet3_rq_alloc_rx_buf() (Kamal Heib) [2100226]

* Fri Jun 24 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-404.el8]
- iommu/amd: Enable swiotlb in all cases (Jerry Snitselaar) [2072179]
- iommu/arm-smmu-v3-sva: Fix mm use-after-free (Jerry Snitselaar) [2072179]
- dma-direct: don't over-decrypt memory (Jerry Snitselaar) [2072179]
- dma-direct: always leak memory that can't be re-encrypted (Jerry Snitselaar) [2072179]
- dma-direct: clean up the remapping checks in dma_direct_alloc (Jerry Snitselaar) [2072179]
- dma-direct: don't call dma_set_decrypted for remapped allocations (Jerry Snitselaar) [2072179]
- dma-direct: factor out dma_set_{de,en}crypted helpers (Jerry Snitselaar) [2072179]
- swiotlb: max mapping size takes min align mask into account (Jerry Snitselaar) [2072179]
- dma-debug: change allocation mode from GFP_NOWAIT to GFP_ATIOMIC (Jerry Snitselaar) [2072179]
- dma-direct: don't fail on highmem CMA pages in dma_direct_alloc_pages (Jerry Snitselaar) [2072179]
- dma-direct: factor out a helper for DMA_ATTR_NO_KERNEL_MAPPING allocations (Jerry Snitselaar) [2072179]
- swiotlb: make swiotlb_exit a no-op if SWIOTLB_FORCE is set (Jerry Snitselaar) [2072179]
- dma-direct: use is_swiotlb_active in dma_direct_map_page (Jerry Snitselaar) [2072179]
- iommu/vt-d: Calculate mask for non-aligned flushes (Jerry Snitselaar) [2072179]
- iommu/amd: Call memunmap in error path (Jerry Snitselaar) [2072179]
- iommu/vt-d: Drop duplicate check in dma_pte_free_pagetable() (Jerry Snitselaar) [2072179]
- iommu/vt-d: Use correctly sized arguments for bit field (Jerry Snitselaar) [2072179]
- Revert "iommu/arm-smmu-v3: Decrease the queue size of evtq and priq" (Jerry Snitselaar) [2072179]
- iommu: Fix potential use-after-free during probe (Jerry Snitselaar) [2072179]
- dma-direct: avoid redundant memory sync for swiotlb (Jerry Snitselaar) [2072179]
- iommu/iova: Fix race between FQ timeout and teardown (Jerry Snitselaar) [2072179]
- iommu/io-pgtable-arm: Fix table descriptor paddr formatting (Jerry Snitselaar) [2072179]
- iommu: Extend mutex lock scope in iommu_probe_device() (Jerry Snitselaar) [2072179]
- iommu/amd: X2apic mode: mask/unmask interrupts on suspend/resume (Jerry Snitselaar) [2072179]
- iommu/amd: X2apic mode: setup the INTX registers on mask/unmask (Jerry Snitselaar) [2072179]
- iommu/amd: X2apic mode: re-enable after resume (Jerry Snitselaar) [2072179]
- iommu/amd: Restore GA log/tail pointer on host resume (Jerry Snitselaar) [2072179]
- iommu/amd: Clarify AMD IOMMUv2 initialization messages (Jerry Snitselaar) [2072179]
- iommu/vt-d: Avoid duplicate removing in __domain_mapping() (Jerry Snitselaar) [2072179]
- iommu/vt-d: Fix an unbalanced rcu_read_lock/rcu_read_unlock() (Jerry Snitselaar) [2072179]
- iommu/vt-d: Check FL and SL capability sanity in scalable mode (Jerry Snitselaar) [2072179]
- iommu/vt-d: Add present bit check in pasid entry setup helpers (Jerry Snitselaar) [2072179]
- iommu/vt-d: Preset A/D bits for user space DMA usage (Jerry Snitselaar) [2072179]
- iommu/vt-d: Remove unnecessary oom message (Jerry Snitselaar) [2072179]
- iommu/vt-d: Enable ATS for the devices in SATC table (Jerry Snitselaar) [1893460]
- iommu/vt-d: Parse SATC reporting structure (Jerry Snitselaar) [1893460]
- iommu/vt-d: Dump DMAR translation structure when DMA fault occurs (Jerry Snitselaar) [1868826]
- nvme: fix typos in nvme status code values (Gopal Tiwari) [2091824]
- Adding CONFIG_NVME_VERBOSE_ERRORS to RHEL-8. (Gopal Tiwari) [2091824]
- nvme: add missing status values to verbose logging (Gopal Tiwari) [2091824]
- nvme: don't print verbose errors for internal passthrough requests (Gopal Tiwari) [2091824]
- nvme: add verbose error logging (Gopal Tiwari) [2091824]
- perf/x86/msr: Add Raptor Lake CPU support (Michael Petlan) [2094572]
- perf/x86: Add Intel Raptor Lake support (Michael Petlan) [2094572]
- perf/x86/cstate: Add SAPPHIRERAPIDS_X CPU support (Michael Petlan) [2094572]
- perf/x86/cstate: Add Raptor Lake support (Michael Petlan) [2094572]
- [s390] s390/lcs: fix variable dereferenced before check (Mete Durlu) [2043835]
- [s390] s390/ctcm: fix potential memory leak (Mete Durlu) [2043835]
- [s390] s390/ctcm: fix variable dereferenced before check (Mete Durlu) [2043835]
- [s390] s390/net: sort out physical vs virtual pointers usage (Mete Durlu) [2043835]
- [s390] s390/qeth: remove check for packing mode in qeth_check_outbound_queue() (Mete Durlu) [2043835]
- [s390] s390/qeth: fine-tune .ndo_select_queue() (Mete Durlu) [2043835]
- [s390] s390/qeth: don't offer .ndo_bridge_* ops for OSA devices (Mete Durlu) [2043835]
- [s390] s390/qeth: split up L2 netdev_ops (Mete Durlu) [2043835]
- [s390] s390/qeth: simplify qeth_receive_skb() (Mete Durlu) [2043835]
- [s390] s390/lcs: add braces around empty function body (Mete Durlu) [2043835]
- [s390] s390/ctcm: add __printf format attribute to ctcm_dbf_longtext (Mete Durlu) [2043835]
- [s390] s390/ctcm: fix format string (Mete Durlu) [2043835]
- [s390] s390/qeth: allocate RX queue at probe time (Mete Durlu) [2043835]
- [s390] s390/qeth: update kerneldoc for qeth_add_hw_header() (Mete Durlu) [2043835]
- [s390] s390/qeth: fix kernel doc comments (Mete Durlu) [2043835]
- [s390] s390/qeth: add __printf format attribute to qeth_dbf_longtext (Mete Durlu) [2043835]
- [s390] s390/qeth: fix various format strings (Mete Durlu) [2043835]
- [s390] s390/qeth: don't keep track of Input Queue count (Mete Durlu) [2043835]
- [s390] s390/qeth: clarify remaining dev_kfree_skb_any() users (Mete Durlu) [2043835]
- [s390] s390/qeth: move qdio's QAOB cache into qeth (Mete Durlu) [2043835]
- [s390] s390/qeth: improve trace entries for MAC address (un)registration (Mete Durlu) [2043835]
- [s390] s390/netiucv: remove incorrect kernel doc indicators (Mete Durlu) [2043835]
- [s390] s390/lcs: remove incorrect kernel doc indicators (Mete Durlu) [2043835]
- [s390] s390/ctcm: remove incorrect kernel doc indicators (Mete Durlu) [2043835]
- [s390] s390/qeth: clean up device_type management (Mete Durlu) [2043835]
- [s390] s390/qeth: clean up QETH_PROT_* naming (Mete Durlu) [2043835]
- mm/memcg: Free percpu stats memory of dying memcg's (Waiman Long) [2004037]
- netfilter: flowtable: fix TCP flow teardown (Florian Westphal) [2088234]
- netfilter: conntrack: annotate data-races around ct->timeout (Florian Westphal) [2088234]
- netfilter: conntrack: initialize ct->timeout (Florian Westphal) [2088234]
- NFSv4: Fix free of uninitialized nfs4_label on referral lookup. (Scott Mayhew) [2090994]
- md: fix double free of io_acct_set bioset (Nigel Croxon) [2094076]
- md: Don't set mddev private to NULL in raid0 pers->free (Nigel Croxon) [2094076]
- md: protect md_unregister_thread from reentrancy (Nigel Croxon) [2094076]
- md: don't unregister sync_thread with reconfig_mutex held (Nigel Croxon) [2094076]
- raid5: don't set the discard_alignment queue limit (Nigel Croxon) [2094076]
- md: Replace role magic numbers with defined constants (Nigel Croxon) [2094076]
- md/raid0: Ignore RAID0 layout if the second zone has only one device (Nigel Croxon) [2094076]
- md/raid5: Annotate functions that hold device_lock with __must_hold (Nigel Croxon) [2094076]
- md/raid5-ppl: Annotate with rcu_dereference_protected() (Nigel Croxon) [2094076]
- md/raid5: Annotate rdev/replacement access when mddev_lock is held (Nigel Croxon) [2094076]
- md/raid5: Annotate rdev/replacement accesses when nr_pending is elevated (Nigel Croxon) [2094076]
- md/raid5: Add __rcu annotation to struct disk_info (Nigel Croxon) [2094076]
- md/raid5: Un-nest struct raid5_percpu definition (Nigel Croxon) [2094076]
- md/raid5: Cleanup setup_conf() error returns (Nigel Croxon) [2094076]
- md: replace deprecated strlcpy & remove duplicated line (Nigel Croxon) [2094076]
- md/bitmap: don't set sb values if can't pass sanity check (Nigel Croxon) [2094076]
- md: fix an incorrect NULL check in md_reload_sb (Nigel Croxon) [2094076]
- md: fix an incorrect NULL check in does_sb_need_changing (Nigel Croxon) [2094076]
- md: use msleep() in md_notify_reboot() (Nigel Croxon) [2094076]
- ext4: force overhead calculation if the s_overhead_cluster makes no sense (Lukas Czerner) [2079886]
- ext4: fix overhead calculation to account for the reserved gdt blocks (Lukas Czerner) [2079886]
- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole (Lukas Czerner) [2079886]
- ext4: fix use-after-free in ext4_search_dir (Lukas Czerner) [2079886]
- ext4: fix symlink file size not match to file content (Lukas Czerner) [2079886]
- ext4: fix fallocate to use file_modified to update permissions consistently (Lukas Czerner) [2085623]
- ext4: remove unused macro MPAGE_DA_EXTENT_TAIL (Lukas Czerner) [2079886]
- ext4: add missing braces in ext4_ext_drop_refs() (Lukas Czerner) [2079886]
- ext4: remove obsolete comment from ext4_can_extents_be_merged() (Lukas Czerner) [2079886]
- ext4: make some functions static in extents.c (Lukas Czerner) [2079886]
- ext4: remove redundant S_ISREG() checks from ext4_fallocate() (Lukas Czerner) [2079886]
- ext4: clean up len and offset checks in ext4_fallocate() (Lukas Czerner) [2079886]
- ext4: remove ext4_{ind,ext}_calc_metadata_amount() (Lukas Czerner) [2079886]
- ext4: fix fs corruption when tring to remove a non-empty directory with IO error (Lukas Czerner) [2079886]
- ext4: fix error handling in ext4_restore_inline_data() (Lukas Czerner) [2079886]
- jbd2: export jbd2_journal_[grab|put]_journal_head (Lukas Czerner) [2079886]
- ext4: don't use the orphan list when migrating an inode (Lukas Czerner) [2079886]
- ext4: set csum seed in tmp inode while migrating to extents (Lukas Czerner) [2079886]
- ext4: fix an use-after-free issue about data=journal writeback mode (Lukas Czerner) [2079886]
- ext4: fix bh ref count on error paths (Lukas Czerner) [2079886]
- ext4: fix a possible ABBA deadlock due to busy PA (Lukas Czerner) [2079886]
- ext4: discard preallocations before releasing group lock (Lukas Czerner) [2079886]
- ext4: make ext_debug() implementation to use pr_debug() (Lukas Czerner) [2079886]
- ext4: mballoc: make mb_debug() implementation to use pr_debug() (Lukas Czerner) [2079886]
- ext4: improve ext_debug() msg in case of block allocation failure (Lukas Czerner) [2079886]
- ext4: use BIT() macro for BH_** state bits (Lukas Czerner) [2079886]
- ext4: balloc: use task_pid_nr() helper (Lukas Czerner) [2079886]
- ext4: mballoc: fix possible NULL ptr & remove BUG_ONs from DOUBLE_CHECK (Lukas Czerner) [2079886]
- ext4: mballoc: refactor code inside DOUBLE_CHECK into separate function (Lukas Czerner) [2079886]
- ext4: mballoc: make ext4_mb_use_preallocated() return type as bool (Lukas Czerner) [2079886]
- ext4: mballoc: simplify error handling in ext4_init_mballoc() (Lukas Czerner) [2079886]
- ext4: mballoc: fix few other format specifier in mb_debug() (Lukas Czerner) [2079886]
- ext4: mballoc: correct the mb_debug() format specifier for pa_len var (Lukas Czerner) [2079886]
- ext4: mballoc: add more mb_debug() msgs (Lukas Czerner) [2079886]
- ext4: mballoc: refactor ext4_mb_show_ac() (Lukas Czerner) [2079886]
- ext4: mballoc: print bb_free info even when it is 0 (Lukas Czerner) [2079886]
- ext4: fix dead loop in ext4_mb_new_blocks (Lukas Czerner) [2079886]
- ext4: mballoc: use lock for checking free blocks while retrying (Lukas Czerner) [2079886]
- ext4: mballoc: refactor ext4_mb_good_group() (Lukas Czerner) [2079886]
- ext4: mballoc: introduce pcpu seqcnt for freeing PA to improve ENOSPC handling (Lukas Czerner) [2079886]
- ext4: mballoc: refactor ext4_mb_discard_preallocations() (Lukas Czerner) [2079886]
- ext4: mballoc: add blocks to PA list under same spinlock after allocating blocks (Lukas Czerner) [2079886]
- ext4: fix lazy initialization next schedule time computation in more granular unit (Lukas Czerner) [2079886]
- ext4: fix avefreec in find_group_orlov (Lukas Czerner) [2079886]
- ext4: allow the dax flag to be set and cleared on inline directories (Lukas Czerner) [2079886]
- ext4: annotate data race in jbd2_journal_dirty_metadata() (Lukas Czerner) [2079886]
- ext4: annotate data race in start_this_handle() (Lukas Czerner) [2079886]
- ext4: fix superblock checksum failure when setting password salt (Lukas Czerner) [2079886]
- ext4: correctly report "not supported" for {usr,grp}jquota when !CONFIG_QUOTA (Lukas Czerner) [2079886]
- jbd2: fix ocfs2 corrupt when clearing block group bits (Lukas Czerner) [2079886]
- ext4: fix ext4_empty_dir() for directories with holes (Lukas Czerner) [2079886]
- ext4: allow directory holes (Lukas Czerner) [2079886]
- net/af_packet: make sure to pull mac header (Hangbin Liu) [2066976]
- rcu/nocb: Make rcu_core() callbacks acceleration preempt-safe (Waiman Long) [2097549]
- redhat: drop expired testing secureboot signing key (Jarod Wilson) [2095199]

* Thu Jun 23 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-403.el8]
- atlantic: Fix issue in the pm resume flow. (Igor Russkikh) [2002395]
- atlantic: Fix driver resume flow. (Igor Russkikh) [2002395]
- Build intel_sdsi with {tools_make} (Prarit Bhargava) [1971951]
- redhat/kernel.spec.template: Add intel_sdsi tool (Prarit Bhargava) [1971951]
- redhat/configs: Add CONFIG_INTEL_SDSI (Prarit Bhargava) [1971951]
- selftests: sdsi: test sysfs setup (Prarit Bhargava) [1971951]
- tools arch x86: Add Intel SDSi provisiong tool (Prarit Bhargava) [1971951]
- platform/x86: Add Intel Software Defined Silicon driver (Prarit Bhargava) [1971951]
- platform/x86/intel: Fix 'rmmod pmt_telemetry' panic (Prarit Bhargava) [2080426]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (Prarit Bhargava) [2040019 2040059]
- netfilter: nf_tables: sanitize nft_set_desc_concat_parse() (Florian Westphal) [2096403] {CVE-2022-2078}
- mt76: mt7921: Fix the error handling path of mt7921_pci_probe() (Íñigo Huguet) [2096758]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (Sudheesh Mavila) [2031643]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (Sudheesh Mavila) [2031643]
- kernel/resource: Introduce request_mem_region_muxed() (Sudheesh Mavila) [2031643]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (Sudheesh Mavila) [2031643]
- Watchdog: sp5100_tco: Move timer initialization into function (Sudheesh Mavila) [2031643]
- watchdog: sp5100_tco: Add support for get_timeleft (Sudheesh Mavila) [2031643]
- watchdog: sp5100_tco: Enable watchdog on Family 17h devices if disabled (Sudheesh Mavila) [2031643]
- watchdog: sp5100_tco: drop warning after registering device (Sudheesh Mavila) [2031643]
- watchdog: sp5100_tco: drop warning after calling watchdog_init_timeout (Sudheesh Mavila) [2031643]
- Reinstate some of "swiotlb: rework "fix info leak with DMA_FROM_DEVICE"" (Chris von Recklinghausen) [2059701] {CVE-2022-0854}
- swiotlb: fix info leak with DMA_FROM_DEVICE (Chris von Recklinghausen) [2059701] {CVE-2022-0854}
- redhat/configs: Add CONFIG_S390_UV_UAPI (Claudio Imbrenda) [1984905]
- [s390] s390/uv_uapi: depend on CONFIG_S390 (Claudio Imbrenda) [1984905]
- [s390] drivers/s390/char: Add Ultravisor io device (Claudio Imbrenda) [1984905]
- cpufreq: Specify default governor on command line (Prarit Bhargava) [2083766]
- cpufreq: Fix locking issues with governors (Prarit Bhargava) [2083766]
- cpufreq: Register governors at core_initcall (Prarit Bhargava) [2083766]
- nvme: fix RCU hole that allowed for endless looping in multipath round robin (Gopal Tiwari) [2078806]
- nvme-multipath: fix hang when disk goes live over reconnect (Gopal Tiwari) [2078806]
- nvme-tcp: send H2CData PDUs based on MAXH2CDATA (Gopal Tiwari) [2078806]
- nvme: also mark passthrough-only namespaces ready in nvme_update_ns_info (Gopal Tiwari) [2078806]
- nvme: don't return an error from nvme_configure_metadata (Gopal Tiwari) [2078806]
- nvme-tcp: fix bogus request completion when failing to send AER (Gopal Tiwari) [2078806]
- nvme-fabrics: remove the unneeded ret variable in nvmf_dev_show (Gopal Tiwari) [2078806]
- nvme-pci: add the IGNORE_DEV_SUBNQN quirk for Intel P4500/P4600 SSDs (Gopal Tiwari) [2078806]
- nvme-fabrics: print out valid arguments when reading from /dev/nvme-fabrics (Gopal Tiwari) [2078806]
- nvmet-tcp: fix possible list corruption for unexpected command failure (Gopal Tiwari) [2078806]
- nvme: fix use after free when disconnecting a reconnecting ctrl (Gopal Tiwari) [2078806]
- nvme-multipath: set ana_log_size to 0 after free ana_log_buf (Gopal Tiwari) [2078806]
- nvme: disable namespace access for unsupported metadata (Gopal Tiwari) [2078806]
- nvme: report write pointer for a full zone as zone start + zone len (Gopal Tiwari) [2078806]
- nvme: show subsys nqn for duplicate cntlids (Gopal Tiwari) [2078806]
- nvme-pci: add NO APST quirk for Kioxia device (Gopal Tiwari) [2078806]
- nvme: fix write zeroes pi (Gopal Tiwari) [2078806]
- nvmet: use flex_array_size and struct_size (Gopal Tiwari) [2078806]
- nvme: drop scan_lock and always kick requeue list when removing namespaces (Gopal Tiwari) [2078806]
- nvmet: use struct_size over open coded arithmetic (Gopal Tiwari) [2078806]
- nvme-pci: clear shadow doorbell memory on resets (Gopal Tiwari) [2078806]
- nvmet: use macro definitions for setting cmic value (Gopal Tiwari) [2078806]
- nvme-rdma: fix error code in nvme_rdma_setup_ctrl (Gopal Tiwari) [2078806]
- nvmet: use macro definition for setting nmic value (Gopal Tiwari) [2078806]
- nvmet-rdma: implement get_max_queue_size controller op (Gopal Tiwari) [2078806]
- nvmet: add get_max_queue_size op for controllers (Gopal Tiwari) [2078806]
- nvme-rdma: limit the maximal queue size for RDMA controllers (Gopal Tiwari) [2078806]
- nvme: paring quiesce/unquiesce (Gopal Tiwari) [2078806]
- nvme: add APIs for stopping/starting admin queue (Gopal Tiwari) [2078806]
- nvme: prepare for pairing quiescing and unquiescing (Gopal Tiwari) [2078806]
- nvme: apply nvme API to quiesce/unquiesce admin queue (Gopal Tiwari) [2078806]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Gopal Tiwari) [2078806]
- nvme: remove the call to nvme_update_disk_info in nvme_ns_remove (Gopal Tiwari) [2078806]
- nvme: remove the GENHD_FL_UP check in nvme_ns_remove (Gopal Tiwari) [2078806]
- nvme-rdma: destroy cm id before destroy qp to avoid use after free (Gopal Tiwari) [2078806]
- nvme: only call synchronize_srcu when clearing current path (Gopal Tiwari) [2078806]
- nvme-multipath: revalidate paths during rescan (Gopal Tiwari) [2078806]
- nvme: remove the unused NVME_NS_* enum (Gopal Tiwari) [2078806]
- nvme: Have NVME_FABRICS select NVME_CORE instead of transport drivers (Gopal Tiwari) [2078806]
- nvme-pci: disable hmb on idle suspend (Gopal Tiwari) [2078806]
- nvme: allow user toggling hmb usage (Gopal Tiwari) [2078806]
- nvme-fabrics: remove superfluous nvmf_host_put in nvmf_parse_options (Gopal Tiwari) [2078806]
- nvme: add set feature tracing support (Gopal Tiwari) [2078806]
- nvmet: add set feature tracing support (Gopal Tiwari) [2078806]
- nvme-pci: cmb sysfs: one file, one value (Gopal Tiwari) [2078806]
- nvme-pci: use attribute group for cmb sysfs (Gopal Tiwari) [2078806]
- compiler.h: Introduce absolute_pointer macro (Gopal Tiwari) [2078806]
- vdpa: Fix vdpa-vhost driver (Laurent Vivier) [2093851]
- nl80211: fix locking in nl80211_set_tx_bitrate_mask() (Íñigo Huguet) [2059994]
- mac80211_hwsim: call ieee80211_tx_prepare_skb under RCU protection (Íñigo Huguet) [2059994]
- mac80211_hwsim: fix RCU protected chanctx access (Íñigo Huguet) [2059994]
- mac80211: Reset MBSSID parameters upon connection (Íñigo Huguet) [2059994]
- cfg80211: retrieve S1G operating channel number (Íñigo Huguet) [2059994]
- nl80211: validate S1G channel width (Íñigo Huguet) [2059994]
- mac80211: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2059994]
- ath11k: reduce the wait time of 11d scan and hw scan while add interface (Íñigo Huguet) [2059994]
- iwlwifi: iwl-dbg: Use del_timer_sync() before freeing (Íñigo Huguet) [2059994]
- bus: mhi: host: pci_generic: Flush recovery worker during freeze (Íñigo Huguet) [2059994]
- bus: mhi: host: pci_generic: Add missing poweroff() PM callback (Íñigo Huguet) [2059994]
- mac80211: fix ht_capa printout in debugfs (Íñigo Huguet) [2059994]
- cfg80211: hold bss_lock while updating nontrans_list (Íñigo Huguet) [2059994]
- nl80211: correctly check NL80211_ATTR_REG_ALPHA2 size (Íñigo Huguet) [2059994]
- ath9k: Fix usage of driver-private space in tx_info (Íñigo Huguet) [2059994]
- brcmfmac: sdio: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059994]
- mt76: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059994]
- Revert "ath11k: mesh: add support for 256 bitmap in blockack frames in 11ax" (Íñigo Huguet) [2059994]
- ath9k: Properly clear TX status area before reporting to mac80211 (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Don't fail if PPAG isn't supported (Íñigo Huguet) [2059994]
- bus: mhi: Make mhi_state_str[] array static inline and move to common.h (Íñigo Huguet) [2059994]
- bus: mhi: Move common MHI definitions out of host directory (Íñigo Huguet) [2059994]
- bus: mhi: host: Rename "struct mhi_tre" to "struct mhi_ring_element" (Íñigo Huguet) [2059994]
- bus: mhi: Cleanup the register definitions used in headers (Íñigo Huguet) [2059994]
- bus: mhi: Use bitfield operations for handling DWORDs of ring elements (Íñigo Huguet) [2059994]
- bus: mhi: Use bitfield operations for register read and write (Íñigo Huguet) [2059994]
- bus: mhi: Move host MHI code to "host" directory (Íñigo Huguet) [2059994]
- bus: mhi: Fix MHI DMA structure endianness (Íñigo Huguet) [2059994]
- bus: mhi: Fix pm_state conversion to string (Íñigo Huguet) [2059994]
- bus: mhi: pci_generic: Add mru_default for Quectel EM1xx series (Íñigo Huguet) [2059994]
- rfkill: make new event layout opt-in (Íñigo Huguet) [2059994]
- rtw89: implement stop and resume channels transmission v1 (Íñigo Huguet) [2059994]
- rtw89: extend mac tx_en bits from 16 to 32 (Íñigo Huguet) [2059994]
- rtw89: change value assignment style of rtw89_mac_cfg_gnt() (Íñigo Huguet) [2059994]
- rtw89: 8852c: add mac_ctrl_path and mac_cfg_gnt APIs (Íñigo Huguet) [2059994]
- rtw89: disable FW and H2C function if CPU disabled (Íñigo Huguet) [2059994]
- rtw89: initialize preload window of D-MAC (Íñigo Huguet) [2059994]
- rtw89: modify MAC enable functions (Íñigo Huguet) [2059994]
- rtw89: add config_rf_reg_v1 to configure RF parameter tables (Íñigo Huguet) [2059994]
- rtw89: 8852c: add read/write rf register function (Íñigo Huguet) [2059994]
- rtw89: 8852c: add setting of TB UL TX power offset (Íñigo Huguet) [2059994]
- rtw89: 8852c: add write/read crystal function in CFO tracking (Íñigo Huguet) [2059994]
- rtw89: modify dcfo_comp to share with chips (Íñigo Huguet) [2059994]
- rtw89: Fix spelling mistake "Mis-Match" -> "Mismatch" (Íñigo Huguet) [2059994]
- brcmfmac: p2p: Fix spelling mistake "Comback" -> "Comeback" (Íñigo Huguet) [2059994]
- iwlwifi: mei: fix building iwlmei (Íñigo Huguet) [2059994]
- mt76: fix monitor rx FCS error in DFS channel (Íñigo Huguet) [2059994]
- mt76: mt7921: don't enable beacon filter when IEEE80211_CONF_CHANGE_MONITOR is set (Íñigo Huguet) [2059994]
- mt76: fix wrong HE data rate in sniffer tool (Íñigo Huguet) [2059994]
- mt76: mt7915: introduce 802.11ax multi-bss support (Íñigo Huguet) [2059994]
- mt76: mt7921: move mt7921_init_hw in a dedicated work (Íñigo Huguet) [2059994]
- mt76: mt7921: add mt7921u driver (Íñigo Huguet) [2059994]
- mt76: mt7921: move mt7921_usb_sdio_tx_status_data in mac common code. (Íñigo Huguet) [2059994]
- mt76: mt7921: move mt7921_usb_sdio_tx_complete_skb in common mac code. (Íñigo Huguet) [2059994]
- mt76: mt7921: move mt7921_usb_sdio_tx_prepare_skb in common mac code (Íñigo Huguet) [2059994]
- mt76: mt7921: update mt7921_skb_add_usb_sdio_hdr to support usb (Íñigo Huguet) [2059994]
- mt76: mt7921: disable runtime pm for usb (Íñigo Huguet) [2059994]
- mt76: usb: introduce __mt76u_init utility routine (Íñigo Huguet) [2059994]
- mt76: usb: add req_type to ___mt76u_wr signature (Íñigo Huguet) [2059994]
- mt76: usb: add req_type to ___mt76u_rr signature (Íñigo Huguet) [2059994]
- mt76: mt7915: fix typos in comments (Íñigo Huguet) [2059994]
- mt76: mt7915: fix phy cap in mt7915_set_stream_he_txbf_caps() (Íñigo Huguet) [2059994]
- mt76: mt7915: fix beamforming mib stats (Íñigo Huguet) [2059994]
- mt76: mt7915: set band1 TGID field in tx descriptor (Íñigo Huguet) [2059994]
- mt76: fix invalid rssi report (Íñigo Huguet) [2059994]
- mt76: use le32/16_get_bits() whenever possible (Íñigo Huguet) [2059994]
- mt76: connac: make read-only array ba_range static const (Íñigo Huguet) [2059994]
- mt76: mt7915: check for devm_pinctrl_get() failure (Íñigo Huguet) [2059994]
- mt76: mt7921: get rid of mt7921_wait_for_mcu_init declaration (Íñigo Huguet) [2059994]
- mt76: mt7915: add txpower init for 6GHz (Íñigo Huguet) [2059994]
- mt76: mt7915: fix eeprom fields of txpower init values (Íñigo Huguet) [2059994]
- mt76: mt7915: add 6 GHz support (Íñigo Huguet) [2059994]
- mt76: connac: add 6 GHz support for wtbl and starec configuration (Íñigo Huguet) [2059994]
- mt76: mt7915: allow beaconing on all chains (Íñigo Huguet) [2059994]
- mt76: fix monitor mode crash with sdio driver (Íñigo Huguet) [2059994]
- mt76: mt7921: fix mt7921_queues_acq implementation (Íñigo Huguet) [2059994]
- mt76: mt7921: fix xmit-queue dump for usb and sdio (Íñigo Huguet) [2059994]
- mt76: mt7921: make mt7921_init_tx_queues static (Íñigo Huguet) [2059994]
- mt76: split single ldpc cap bit into bits (Íñigo Huguet) [2059994]
- mt76: mt7915: fix DFS no radar detection event (Íñigo Huguet) [2059994]
- mt76: mt7921: use mt76_hw instead of open coding it (Íñigo Huguet) [2059994]
- mt76: mt7921: fix up the monitor mode (Íñigo Huguet) [2059994]
- mt76: mt7663u: introduce mt7663u_mcu_power_on routine (Íñigo Huguet) [2059994]
- mt76: mt7615: honor ret from mt7615_mcu_restart in mt7663u_mcu_init (Íñigo Huguet) [2059994]
- rtw89: fix uninitialized variable of rtw89_append_probe_req_ie() (Íñigo Huguet) [2059994]
- rtlwifi: rtl8821ae: fix typos in comments (Íñigo Huguet) [2059994]
- rtlwifi: rtl8192cu: Add On Networks N150 (Íñigo Huguet) [2059994]
- mwifiex: make read-only array wmm_oui static const (Íñigo Huguet) [2059994]
- mac80211: update bssid_indicator in ieee80211_assign_beacon (Íñigo Huguet) [2059994]
- mac80211: MBSSID channel switch (Íñigo Huguet) [2059994]
- mac80211: MBSSID beacon handling in AP mode (Íñigo Huguet) [2059994]
- mac80211: always have ieee80211_sta_restart() (Íñigo Huguet) [2059994]
- mac80211: Add support to trigger sta disconnect on hardware restart (Íñigo Huguet) [2059994]
- mac80211: fix potential double free on mesh join (Íñigo Huguet) [2059994]
- mac80211: correct legacy rates check in ieee80211_calc_rx_airtime (Íñigo Huguet) [2059994]
- nl80211: fix typo of NL80211_IF_TYPE_OCB in documentation (Íñigo Huguet) [2059994]
- mac80211: Use GFP_KERNEL instead of GFP_ATOMIC when possible (Íñigo Huguet) [2059994]
- mac80211: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Íñigo Huguet) [2059994]
- rtw89: 8852c: process logic efuse map (Íñigo Huguet) [2059994]
- rtw89: 8852c: process efuse of phycap (Íñigo Huguet) [2059994]
- rtw89: support DAV efuse reading operation (Íñigo Huguet) [2059994]
- rtw89: 8852c: add chip::dle_mem (Íñigo Huguet) [2059994]
- rtw89: add page_regs to handle v1 chips (Íñigo Huguet) [2059994]
- rtw89: add chip_info::{h2c,c2h}_reg to support more chips (Íñigo Huguet) [2059994]
- rtw89: add hci_func_en_addr to support variant generation (Íñigo Huguet) [2059994]
- rtw89: add power_{on/off}_func (Íñigo Huguet) [2059994]
- rtw89: read chip version depends on chip ID (Íñigo Huguet) [2059994]
- rtw89: pci: use a struct to describe all registers address related to DMA channel (Íñigo Huguet) [2059994]
- rtw89: pci: add V1 of PCI channel address (Íñigo Huguet) [2059994]
- rtw89: pci: add struct rtw89_pci_info (Íñigo Huguet) [2059994]
- rtw89: 8852c: add 8852c empty files (Íñigo Huguet) [2059994]
- brcmfmac: make the read-only array pktflags static const (Íñigo Huguet) [2059994]
- rtlwifi: rtl8192ce: remove duplicated function '_rtl92ce_phy_set_rf_sleep' (Íñigo Huguet) [2059994]
- ath10k: Fix error handling in ath10k_setup_msa_resources (Íñigo Huguet) [2059994]
- ath11k: remove unneeded flush_workqueue (Íñigo Huguet) [2059994]
- iwlwifi: bump FW API to 72 for AX devices (Íñigo Huguet) [2059994]
- iwlwifi: acpi: move ppag code from mvm to fw/acpi (Íñigo Huguet) [2059994]
- iwlwifi: dbg: check trigger data before access (Íñigo Huguet) [2059994]
- iwlwifi: dbg: in sync mode don't call schedule (Íñigo Huguet) [2059994]
- iwlwifi: use 4k queue size for Bz A-step (Íñigo Huguet) [2059994]
- iwlwifi: pcie: fix SW error MSI-X mapping (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: dump IMR DRAM only for HW and FW error (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add support for IMR based on platform (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: disable IMR DRAM region if IMR is disabled (Íñigo Huguet) [2059994]
- iwlwifi: mvm: remove cipher scheme support (Íñigo Huguet) [2059994]
- iwlwifi: Configure FW debug preset via module param. (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add a flag to reduce power command. (Íñigo Huguet) [2059994]
- iwlwifi: bump FW API to 71 for AX devices (Íñigo Huguet) [2059994]
- ath9k: make array voice_priority static const (Íñigo Huguet) [2059994]
- rtw89: declare HE capabilities in 6G band (Íñigo Huguet) [2059994]
- rtw89: fix HE PHY bandwidth capability (Íñigo Huguet) [2059994]
- rtw89: add tx_wake notify for low ps mode (Íñigo Huguet) [2059994]
- rtw89: 8852a: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059994]
- Revert "ath: add support for special 0x0 regulatory domain" (Íñigo Huguet) [2059994]
- rtw89: get channel parameters of 160MHz bandwidth (Íñigo Huguet) [2059994]
- mt76: fix dfs state issue with 160 MHz channels (Íñigo Huguet) [2059994]
- mt76: mt7915: simplify conditional (Íñigo Huguet) [2059994]
- mt76: mt7921: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059994]
- mt76: mt7915e: Enable thermal management by default (Íñigo Huguet) [2059994]
- mt76: mt7915e: Add a hwmon attribute to get the actual throttle state. (Íñigo Huguet) [2059994]
- mt76: mt7915e: Fix degraded performance after temporary overheat (Íñigo Huguet) [2059994]
- mt76: improve signal strength reporting (Íñigo Huguet) [2059994]
- mt76: mt7915: use min_t() to make code cleaner (Íñigo Huguet) [2059994]
- mt76: mt7915: fix the muru tlv issue (Íñigo Huguet) [2059994]
- mt76: mt7915: check band idx for bcc event (Íñigo Huguet) [2059994]
- mt76: mt7615: Fix assigning negative values to unsigned variable (Íñigo Huguet) [2059994]
- mt76: connac: adjust wlan_idx size from u8 to u16 (Íñigo Huguet) [2059994]
- mt76: mt7915: fix endianness warnings in mt7915_mac_tx_free() (Íñigo Huguet) [2059994]
- mt76: mt7915: fix endianness warnings in mt7915_debugfs_rx_fw_monitor (Íñigo Huguet) [2059994]
- mt76: mt7615: fix compiler warning on frame size (Íñigo Huguet) [2059994]
- mt76: mt7915: initialize smps mode in mt7915_mcu_sta_rate_ctrl_tlv() (Íñigo Huguet) [2059994]
- mt76: mt7915: introduce band_idx in mt7915_phy (Íñigo Huguet) [2059994]
- mt76: mt7915: add support for MT7986 (Íñigo Huguet) [2059994]
- ath10k: fix pointer arithmetic error in trace call (Íñigo Huguet) [2059994]
- ath11k: add dbring debug support (Íñigo Huguet) [2059994]
- ath11k: translate HE status to radiotap format (Íñigo Huguet) [2059994]
- ath11k: decode HE status tlv (Íñigo Huguet) [2059994]
- ath11k: switch to using ieee80211_tx_status_ext() (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix missing fc type/sub-type for 802.11 pkts (Íñigo Huguet) [2059994]
- mt76: mt7915: fix potential memory leak of fw monitor packets (Íñigo Huguet) [2059994]
- mt76: mt7915: Fix channel state update error issue (Íñigo Huguet) [2059994]
- mt76: fix endianness errors in reverse_frag0_hdr_trans (Íñigo Huguet) [2059994]
- mt76: mt7615: introduce SAR support (Íñigo Huguet) [2059994]
- mt76: mt7915: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059994]
- rtw88: change rtw_info() to proper message level (Íñigo Huguet) [2059994]
- rtw89: Limit the CFO boundaries of x'tal value (Íñigo Huguet) [2059994]
- rtw89: phy: handle txpwr lmt/lmt_ru of 160M bandwidth (Íñigo Huguet) [2059994]
- rtw89: phy: handle txpwr lmt/lmt_ru of 6G band (Íñigo Huguet) [2059994]
- ath11k: Fix frames flush failure caused by deadlock (Íñigo Huguet) [2059994]
- ath11k: Handle failure in qmi firmware ready (Íñigo Huguet) [2059994]
- ath11k: Invalidate cached reo ring entry before accessing it (Íñigo Huguet) [2059994]
- ath: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059994]
- ath11k: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059994]
- ath10k: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059994]
- ath9k: use hw_random API instead of directly dumping into random.c (Íñigo Huguet) [2059994]
- ath11k: configure RDDM size to mhi for recovery by firmware (Íñigo Huguet) [2059994]
- ath11k: fix invalid m3 buffer address (Íñigo Huguet) [2059994]
- ath11k: add ath11k_qmi_free_resource() for recovery (Íñigo Huguet) [2059994]
- rtw89: core.h: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059994]
- brcmfmac: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059994]
- rtw89: fix RCU usage in rtw89_core_txq_push() (Íñigo Huguet) [2059994]
- rtw88: coex: Update rtl8822c COEX version to 22020720 (Íñigo Huguet) [2059994]
- rtw88: coex: Add C2H/H2C handshake with BT mailbox for asking HID Info (Íñigo Huguet) [2059994]
- rtw88: coex: Add WLAN MIMO power saving for Bluetooth gaming controller (Íñigo Huguet) [2059994]
- rtw88: coex: update BT PTA counter regularly (Íñigo Huguet) [2059994]
- rtw88: coex: Improve WLAN throughput when HFP COEX (Íñigo Huguet) [2059994]
- rtw88: 8822ce: add support for TX/RX 1ss mode (Íñigo Huguet) [2059994]
- iwlwifi: dbg_ini: Split memcpy() to avoid multi-field write (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Fix an error code in iwl_mvm_up() (Íñigo Huguet) [2059994]
- iwlwifi: Fix -EIO error code that is never returned (Íñigo Huguet) [2059994]
- iwlwifi: mvm: rfi: use kmemdup() to replace kzalloc + memcpy (Íñigo Huguet) [2059994]
- iwlwifi: Fix syntax errors in comments (Íñigo Huguet) [2059994]
- iwlwifi: dvm: use struct_size over open coded arithmetic (Íñigo Huguet) [2059994]
- iwlwifi/fw: use struct_size over open coded arithmetic (Íñigo Huguet) [2059994]
- iwlwifi: Make use of the helper macro LIST_HEAD() (Íñigo Huguet) [2059994]
- iwlwifi: mvm: fix off by one in iwl_mvm_stat_iterator_all_macs() (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: send hcmd to fw after dump collection completes. (Íñigo Huguet) [2059994]
- iwlwifi: mvm: move only to an enabled channel (Íñigo Huguet) [2059994]
- iwlwifi: mvm: update BAID allocation command again (Íñigo Huguet) [2059994]
- iwlwifi: api: remove ttl field from TX command (Íñigo Huguet) [2059994]
- iwlwifi: support new queue allocation command (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: support dump policy for the dump size (Íñigo Huguet) [2059994]
- iwlwifi: pcie: iwlwifi: fix device id 7F70 struct (Íñigo Huguet) [2059994]
- iwlwifi: tlc: Add logs in rs_fw_rate_init func to print TLC configuration (Íñigo Huguet) [2059994]
- iwlwifi: mvm: remove iwl_mvm_disable_txq() flags argument (Íñigo Huguet) [2059994]
- iwlwifi: remove command ID argument from queue allocation (Íñigo Huguet) [2059994]
- iwlwifi: make iwl_txq_dyn_alloc_dma() return the txq (Íñigo Huguet) [2059994]
- iwlwifi: fix small doc mistake for iwl_fw_ini_addr_val (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059994]
- iwlwifi: mvm: always remove the session protection after association (Íñigo Huguet) [2059994]
- iwlwifi: mvm: make iwl_mvm_reconfig_scd() static (Íñigo Huguet) [2059994]
- iwlwifi: mvm: refactor setting PPE thresholds in STA_HE_CTXT_CMD (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Disable WiFi bands selectively with BIOS (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059994]
- iwlwifi: mvm: don't send BAID removal to the FW during hw_restart (Íñigo Huguet) [2059994]
- iwlwifi: don't dump_stack() when we get an unexpected interrupt (Íñigo Huguet) [2059994]
- iwlwifi: mvm: rfi: handle deactivation notification (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Consider P2P GO operation during scan (Íñigo Huguet) [2059994]
- iwlwifi: bump FW API to 70 for AX devices (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Unify the scan iteration functions (Íñigo Huguet) [2059994]
- iwlwifi: mei: use C99 initializer for device IDs (Íñigo Huguet) [2059994]
- iwlwifi: debugfs: remove useless double condition (Íñigo Huguet) [2059994]
- iwlwifi: remove unused macros (Íñigo Huguet) [2059994]
- iwlwifi: eeprom: clean up macros (Íñigo Huguet) [2059994]
- iwlwifi: drv: load tlv debug data earlier (Íñigo Huguet) [2059994]
- iwlwifi: pcie: Adapt rx queue write pointer for Bz family (Íñigo Huguet) [2059994]
- iwlwifi: pcie: adjust to Bz completion descriptor (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Passively scan non PSC channels only when requested so (Íñigo Huguet) [2059994]
- iwlwifi: scan: Modify return value of a function (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: Avoid using dram data if allocation failed (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Correctly set fragmented EBS (Íñigo Huguet) [2059994]
- iwlwifi: nvm: Correct HE capability (Íñigo Huguet) [2059994]
- iwlwifi: mei: avoid -Wpointer-arith and -Wcast-qual warnings (Íñigo Huguet) [2059994]
- iwlwifi: make some functions friendly to sparse (Íñigo Huguet) [2059994]
- iwlwifi: avoid variable shadowing (Íñigo Huguet) [2059994]
- iwlwifi: remove unused DC2DC_CONFIG_CMD definitions (Íñigo Huguet) [2059994]
- iwlwifi: dbg-tlv: clean up iwl_dbg_tlv_update_drams() (Íñigo Huguet) [2059994]
- iwlwifi: fw: make dump_start callback void (Íñigo Huguet) [2059994]
- iwlwifi: pcie: make sure iwl_rx_packet_payload_len() will not underflow (Íñigo Huguet) [2059994]
- iwlwifi: mvm: use debug print instead of WARN_ON() (Íñigo Huguet) [2059994]
- iwlwifi: read and print OTP minor version (Íñigo Huguet) [2059994]
- iwlwifi: add support for BZ-U and BZ-L HW (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add support for CT-KILL notification version 2 (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: remove DBGI_SRAM address reset writing (Íñigo Huguet) [2059994]
- iwlwifi: mvm: support v3 of station HE context command (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: add IMR DRAM dump support (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: fix DBGC allocation flow (Íñigo Huguet) [2059994]
- iwlwifi: pcie: add support for MS devices (Íñigo Huguet) [2059994]
- iwlwifi: mvm: align locking in D3 test debugfs (Íñigo Huguet) [2059994]
- iwlwifi: mvm: don't iterate unadded vifs when handling FW SMPS req (Íñigo Huguet) [2059994]
- iwlwifi: advertise support for HE - DCM BPSK RX/TX (Íñigo Huguet) [2059994]
- iwlwifi: mvm: only enable HE DCM if we also support TX (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: fix DBGI_SRAM ini dump header. (Íñigo Huguet) [2059994]
- iwlwifi: dbg: add infra for tracking free buffer size (Íñigo Huguet) [2059994]
- iwlwifi: mvm: starting from 22000 we have 32 Rx AMPDU sessions (Íñigo Huguet) [2059994]
- iwlwifi: mvm: support new BAID allocation command (Íñigo Huguet) [2059994]
- iwlwifi: mvm: refactor iwl_mvm_sta_rx_agg() (Íñigo Huguet) [2059994]
- iwlwifi: cfg: add support for 1K BA queue (Íñigo Huguet) [2059994]
- iwlwifi: avoid void pointer arithmetic (Íñigo Huguet) [2059994]
- iwlwifi: fix various more -Wcast-qual warnings (Íñigo Huguet) [2059994]
- iwlwifi: propagate (const) type qualifier (Íñigo Huguet) [2059994]
- iwlwifi: de-const properly where needed (Íñigo Huguet) [2059994]
- iwlwifi: make iwl_fw_lookup_cmd_ver() take a cmd_id (Íñigo Huguet) [2059994]
- iwlwifi: mvm: fw: clean up hcmd struct creation (Íñigo Huguet) [2059994]
- iwlwifi: prefer WIDE_ID() over iwl_cmd_id() (Íñigo Huguet) [2059994]
- iwlwifi: mvm: allow enabling UHB TAS in the USA via ACPI setting (Íñigo Huguet) [2059994]
- iwlwifi: mvm: offload channel switch timing to FW (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Don't call iwl_mvm_sta_from_mac80211() with NULL sta (Íñigo Huguet) [2059994]
- mac80211_hwsim: Advertise support for EHT capabilities (Íñigo Huguet) [2059994]
- mac80211: parse AddBA request with extended AddBA element (Íñigo Huguet) [2059994]
- mac80211: calculate max RX NSS for EHT mode (Íñigo Huguet) [2059994]
- mac80211: Add support for storing station EHT capabilities (Íñigo Huguet) [2059994]
- mac80211: Handle station association response with EHT (Íñigo Huguet) [2059994]
- mac80211: Add EHT capabilities to association/probe request (Íñigo Huguet) [2059994]
- mac80211: Add initial support for EHT and 320 MHz channels (Íñigo Huguet) [2059994]
- mac80211: Support parsing EHT elements (Íñigo Huguet) [2059994]
- cfg80211: Support configuration of station EHT capabilities (Íñigo Huguet) [2059994]
- nl80211: fix NL80211_HE_MAX_CAPABILITY_LEN (Íñigo Huguet) [2059994]
- cfg80211: add NO-EHT flag to regulatory (Íñigo Huguet) [2059994]
- nl80211: add support for 320MHz channel limitation (Íñigo Huguet) [2059994]
- nl80211: add EHT MCS support (Íñigo Huguet) [2059994]
- cfg80211: Add support for EHT 320 MHz channel width (Íñigo Huguet) [2059994]
- cfg80211: Add data structures to capture EHT capabilities (Íñigo Huguet) [2059994]
- ieee80211: add EHT 1K aggregation definitions (Íñigo Huguet) [2059994]
- ieee80211: Add EHT (802.11be) definitions (Íñigo Huguet) [2059994]
- mac80211_hwsim: Add custom regulatory for 6GHz (Íñigo Huguet) [2059994]
- mac80211_hwsim: don't shadow a global variable (Íñigo Huguet) [2059994]
- mac80211_hwsim: check TX and STA bandwidth (Íñigo Huguet) [2059994]
- nl80211: accept only HE capability elements with valid size (Íñigo Huguet) [2059994]
- mac80211: parse only HE capability elements with valid size (Íñigo Huguet) [2059994]
- ieee80211: add helper to check HE capability element size (Íñigo Huguet) [2059994]
- nl80211: use RCU to read regdom in reg get/dump (Íñigo Huguet) [2059994]
- mac80211_hwsim: Add debugfs to control rx status RSSI (Íñigo Huguet) [2059994]
- ieee80211: use tab to indent struct ieee80211_neighbor_ap_info (Íñigo Huguet) [2059994]
- rtw89: handle TX/RX 160M bandwidth (Íñigo Huguet) [2059994]
- rtw89: declare if chip support 160M bandwidth (Íñigo Huguet) [2059994]
- rtw89: add 6G support to rate adaptive mechanism (Íñigo Huguet) [2059994]
- rtw89: extend subband for 6G band (Íñigo Huguet) [2059994]
- rtw89: refine naming of rfk helpers with prefix (Íñigo Huguet) [2059994]
- rtw89: make rfk helpers common across chips (Íñigo Huguet) [2059994]
- brcmfmac: Add BCM43454/6 support (Íñigo Huguet) [2059994]
- ath11k: fix destination monitor ring out of sync (Íñigo Huguet) [2059994]
- ath11k: fix radar detection in 160 Mhz (Íñigo Huguet) [2059994]
- ath11k: fix WARN_ON during ath11k_mac_update_vif_chan (Íñigo Huguet) [2059994]
- ath11k: fix uninitialized rate_idx in ath11k_dp_tx_update_txcompl() (Íñigo Huguet) [2059994]
- brcmfmac: of: remove redundant variable len (Íñigo Huguet) [2059994]
- brcmfmac: p2p: Replace one-element arrays with flexible-array members (Íñigo Huguet) [2059994]
- rtw89: coex: set EN bit to PLT register (Íñigo Huguet) [2059994]
- rtw89: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059994]
- rtw88: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059994]
- rtw89: declare AP mode support (Íñigo Huguet) [2059994]
- rtw89: debug: add stations entry to show ID assignment (Íñigo Huguet) [2059994]
- rtw89: implement ieee80211_ops::start_ap and stop_ap (Íñigo Huguet) [2059994]
- rtw89: maintain assoc/disassoc STA states of firmware and hardware (Íñigo Huguet) [2059994]
- rtw89: only STA mode change vif_type mapping dynamically (Íñigo Huguet) [2059994]
- rtw89: add addr_cam field to sta to support AP mode (Íñigo Huguet) [2059994]
- rtw89: extend role_maintain to support AP mode (Íñigo Huguet) [2059994]
- rtw88: fix use after free in rtw_hw_scan_update_probe_req() (Íñigo Huguet) [2059994]
- mac80211: Remove redundent assignment channel_type (Íñigo Huguet) [2059994]
- mac80211: remove useless ieee80211_vif_is_mesh() check (Íñigo Huguet) [2059994]
- mac80211: fix struct ieee80211_tx_info size (Íñigo Huguet) [2059994]
- mac80211: mlme: validate peer HE supported rates (Íñigo Huguet) [2059994]
- mac80211: remove unused macros (Íñigo Huguet) [2059994]
- cfg80211: pmsr: remove useless ifdef guards (Íñigo Huguet) [2059994]
- mac80211: airtime: avoid variable shadowing (Íñigo Huguet) [2059994]
- mac80211: mlme: add documentation from spec to code (Íñigo Huguet) [2059994]
- mac80211: vht: use HE macros for parsing HE capabilities (Íñigo Huguet) [2059994]
- ieee80211: radiotap: fix -Wcast-qual warnings (Íñigo Huguet) [2059994]
- cfg80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059994]
- ieee80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059994]
- cfg80211: don't add non transmitted BSS to 6GHz scanned channels (Íñigo Huguet) [2059994]
- ieee80211: fix HE SPR size calculation (Íñigo Huguet) [2059994]
- cfg80211/mac80211: assume CHECKSUM_COMPLETE includes SNAP (Íñigo Huguet) [2059994]
- mac80211: consider RX NSS in UHB connection (Íñigo Huguet) [2059994]
- mac80211: limit bandwidth in HE capabilities (Íñigo Huguet) [2059994]
- mt76: redefine mt76_for_each_q_rx to adapt mt7986 changes (Íñigo Huguet) [2059994]
- mt76: dma: initialize skip_unmap in mt76_dma_rx_fill (Íñigo Huguet) [2059994]
- mt76: do not always copy ethhdr in reverse_frag0_hdr_trans (Íñigo Huguet) [2059994]
- mt76: mt76x02: use mt76_phy_dfs_state to determine radar detector state (Íñigo Huguet) [2059994]
- mt76: mt7615: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059994]
- mt76: mt7915: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059994]
- mt76: mt76x02: improve tx hang detection (Íñigo Huguet) [2059994]
- mt76x02: improve mac error check/reset reliability (Íñigo Huguet) [2059994]
- mt76: mt7921s: run sleep mode by default (Íñigo Huguet) [2059994]
- mt76: sdio: honor the largest Tx buffer the hardware can support (Íñigo Huguet) [2059994]
- mt76: mt7915: fix the nss setting in bitrates (Íñigo Huguet) [2059994]
- mt76: mt7915: update max_mpdu_size in mt7915_mcu_sta_amsdu_tlv() (Íñigo Huguet) [2059994]
- mt76: mt7915: fix mcs_map in mt7915_mcu_set_sta_he_mcs() (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix a possible memory leak in mt7921_load_patch (Íñigo Huguet) [2059994]
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_sta (Íñigo Huguet) [2059994]
- mt76: stop the radar detector after leaving dfs channel (Íñigo Huguet) [2059994]
- mt76: mt7615: check sta_rates pointer in mt7615_sta_rate_tbl_update (Íñigo Huguet) [2059994]
- mt76: mt7603: check sta_rates pointer in mt7603_sta_rate_tbl_update (Íñigo Huguet) [2059994]
- mt76: mt7663s: flush runtime-pm queue after waking up the device (Íñigo Huguet) [2059994]
- mt76: mt7615: add support for LG LGSBWAC02 (MT7663BUN) (Íñigo Huguet) [2059994]
- mt76: mt7921: remove duplicated code in mt7921_mac_decode_he_radiotap (Íñigo Huguet) [2059994]
- mt76: mt7915: add missing DATA4_TB_SPTL_REUSE1 to mt7915_mac_decode_he_radiotap (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_lmac_mapping in mt76-connac module (Íñigo Huguet) [2059994]
- mt76: mt7915: enable radar background detection (Íñigo Huguet) [2059994]
- mt76: mt7915: report radar pattern if detected by rdd2 (Íñigo Huguet) [2059994]
- mt76: mt7915: introduce rdd_monitor debugfs node (Íñigo Huguet) [2059994]
- mt76: mt7915: enable radar trigger on rdd2 (Íñigo Huguet) [2059994]
- mt76: mt7915: introduce mt7915_set_radar_background routine (Íñigo Huguet) [2059994]
- mt76: mt7915: set bssinfo/starec command when adding interface (Íñigo Huguet) [2059994]
- mt76: mt7921: toggle runtime-pm adding a monitor vif (Íñigo Huguet) [2059994]
- mt76: mt7921: fix endianness issues in mt7921_mcu_set_tx() (Íñigo Huguet) [2059994]
- mt76: sdio: disable interrupt in mt76s_sdio_irq (Íñigo Huguet) [2059994]
- mt76: mt7921: fix crash when startup fails. (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix mt7921s_mcu_[fw|drv]_pmctrl (Íñigo Huguet) [2059994]
- mt76: mt7921: fix ht mcs in mt7921_mac_add_txs_skb() (Íñigo Huguet) [2059994]
- mt76: mt7915: fix ht mcs in mt7915_mac_add_txs_skb() (Íñigo Huguet) [2059994]
- mt76: mt7615: fix a leftover race in runtime-pm (Íñigo Huguet) [2059994]
- mt76: mt7921: fix a leftover race in runtime-pm (Íñigo Huguet) [2059994]
- mt76: mt7921: do not always disable fw runtime-pm (Íñigo Huguet) [2059994]
- mt76: mt7915: add support for passing chip/firmware debug data to user space (Íñigo Huguet) [2059994]
- mt76: mt7615e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059994]
- mt76: mt7915: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059994]
- mt76: mt7615: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059994]
- mt76: connac: add support for passing the cipher field in bss_info (Íñigo Huguet) [2059994]
- mt76: mt7921e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059994]
- mt76: mt7615: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2059994]
- mt76: mt7921: set EDCA parameters with the MCU CE command (Íñigo Huguet) [2059994]
- mt76: mt76_connac: fix MCU_CE_CMD_SET_ROC definition error (Íñigo Huguet) [2059994]
- mt76: mt7921: forbid the doze mode when coredump is in progress (Íñigo Huguet) [2059994]
- mt76: mt7921e: make dev->fw_assert usage consistent (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_rdd_cmd in mt76-connac module (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_set_rts_thresh (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_gen_dl_mode in mt76-connac module (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_init_download (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_patch_sem_ctrl/mt76_connac_mcu_start_patch (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_restart in common module (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_start_firmware (Íñigo Huguet) [2059994]
- mt76: mt7921: get rid of mt7921_mcu_get_eeprom (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_set_pm in connac module (Íñigo Huguet) [2059994]
- mt76: connac: introduce is_connac_v1 utility routine (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_wtbl_update_hdr_trans in connac module (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_hdr_trans_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ht_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_smps_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_sta_uapsd (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_sta_basic_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_generic_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ba_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba_tlv (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_bss_basic_tlv in connac module (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_bss_ext_tlv in connac module (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_bss_omac_tlv in connac module (Íñigo Huguet) [2059994]
- mt76: mt7915: remove duplicated defs in mcu.h (Íñigo Huguet) [2059994]
- mt76: mt7915: move pci specific code back to pci.c (Íñigo Huguet) [2059994]
- mt76: mt7921s: update mt7921s_wfsys_reset sequence (Íñigo Huguet) [2059994]
- mt76: mt7921s: clear MT76_STATE_MCU_RUNNING immediately after reset (Íñigo Huguet) [2059994]
- mt76: sdio: lock sdio when it is needed (Íñigo Huguet) [2059994]
- mt76: mt7915: use proper aid value in mt7915_mcu_sta_basic_tlv (Íñigo Huguet) [2059994]
- mt76: mt7915: use proper aid value in mt7915_mcu_wtbl_generic_tlv in sta mode (Íñigo Huguet) [2059994]
- mt76: make mt76_sar_capa static (Íñigo Huguet) [2059994]
- mt76: mt7915: add device id for mt7916 (Íñigo Huguet) [2059994]
- mt76: set wlan_idx_hi on mt7916 (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_add_key in connac module (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_get_phy utilities (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_chan_bw in common code (Íñigo Huguet) [2059994]
- mt76: connac: move mt76_connac_mcu_get_cipher in common code (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_add_tlv routine (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_wtbl_req (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_sta_req (Íñigo Huguet) [2059994]
- mt76: connac: fix sta_rec_wtbl tag len (Íñigo Huguet) [2059994]
- mt76: mt7915: add mt7916 calibrated data support (Íñigo Huguet) [2059994]
- mt76: mt7915: update mt7915_chan_mib_offs for mt7916 (Íñigo Huguet) [2059994]
- mt76: mt7915: update rx rate reporting for mt7916 (Íñigo Huguet) [2059994]
- mt76: mt7915: add txfree event v3 (Íñigo Huguet) [2059994]
- mt76: mt7915: enlarge wcid size to 544 (Íñigo Huguet) [2059994]
- mt76: mt7915: rework eeprom.c to adapt mt7916 changes (Íñigo Huguet) [2059994]
- mt76: mt7915: add firmware support for mt7916 (Íñigo Huguet) [2059994]
- mt76: mt7915: rework dma.c to adapt mt7916 changes (Íñigo Huguet) [2059994]
- mt76: add MT_RXQ_MAIN_WA for mt7916 (Íñigo Huguet) [2059994]
- mt76: mt7915: refine register definition (Íñigo Huguet) [2059994]
- mt76: mt7915: add mt7915_mmio_probe() as a common probing function (Íñigo Huguet) [2059994]
- mt76: mt7915: fix polling firmware-own status (Íñigo Huguet) [2059994]
- brcmfmac: pcie: Read the console on init and shutdown (Íñigo Huguet) [2059994]
- brcmfmac: fwil: Constify iovar name arguments (Íñigo Huguet) [2059994]
- brcmfmac: of: Use devm_kstrdup for board_type & check for errors (Íñigo Huguet) [2059994]
- brcmfmac: pcie: Fix crashes due to early IRQs (Íñigo Huguet) [2059994]
- brcmfmac: pcie: Replace brcmf_pcie_copy_mem_todev with memcpy_toio (Íñigo Huguet) [2059994]
- brcmfmac: pcie: Declare missing firmware files in pcie.c (Íñigo Huguet) [2059994]
- brcmfmac: firmware: Allocate space for default boardrev in nvram (Íñigo Huguet) [2059994]
- brcmfmac: pcie: Release firmwares in the brcmf_pcie_setup error path (Íñigo Huguet) [2059994]
- rtlwifi: remove redundant initialization of variable ul_encalgo (Íñigo Huguet) [2059994]
- ray_cs: Check ioremap return value (Íñigo Huguet) [2059994]
- ath11k: add debugfs for TWT debug calls (Íñigo Huguet) [2059994]
- ath11k: add WMI calls to manually add/del/pause/resume TWT dialogs (Íñigo Huguet) [2059994]
- ath11k: Add debugfs interface to configure firmware debug log level (Íñigo Huguet) [2059994]
- rtw88: rtw8821c: enable rfe 6 devices (Íñigo Huguet) [2059994]
- rtw88: fix memory overrun and memory leak during hw_scan (Íñigo Huguet) [2059994]
- rtw88: fix idle mode flow for hw scan (Íñigo Huguet) [2059994]
- rtw88: check for validity before using a pointer (Íñigo Huguet) [2059994]
- ath11k: mhi: use mhi_sync_power_up() (Íñigo Huguet) [2059994]
- ath11k: pci: fix crash on suspend if board file is not found (Íñigo Huguet) [2059994]
- ath11k: Fix missing rx_desc_get_ldpc_support in wcn6855_ops (Íñigo Huguet) [2059994]
- ath11k: Fix uninitialized symbol 'rx_buf_sz' (Íñigo Huguet) [2059994]
- ath11k: fix kernel panic during unload/load ath11k modules (Íñigo Huguet) [2059994]
- ath11k: Rename ath11k_ahb_ext_irq_config (Íñigo Huguet) [2059994]
- brcmfmac: add CYW43570 PCIE device (Íñigo Huguet) [2059994]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on some devices (Íñigo Huguet) [2059994]
- rtw89: use pci_read/write_config instead of dbi read/write (Íñigo Huguet) [2059994]
- rtw89: refine DIG feature to support 160M and CCK PD (Íñigo Huguet) [2059994]
- rtw89: include subband type in channel params (Íñigo Huguet) [2059994]
- rtw89: handle 6G band if supported by a chipset (Íñigo Huguet) [2059994]
- rtw89: separate {init,deinit}_addr_cam functions (Íñigo Huguet) [2059994]
- rtw89: set mac_id and port ID to TXWD (Íñigo Huguet) [2059994]
- rtw89: send broadcast/multicast packets via HIQ if STAs are in sleep mode (Íñigo Huguet) [2059994]
- rtw89: configure mac port HIQ registers (Íñigo Huguet) [2059994]
- rtw89: rename vif_maintain to role_maintain (Íñigo Huguet) [2059994]
- rtw89: extend firmware commands on states of sta_assoc and sta_disconnect (Íñigo Huguet) [2059994]
- rtw89: allocate mac_id for each station in AP mode (Íñigo Huguet) [2059994]
- rtw89: implement mac80211_ops::set_tim to indicate STA to receive packets (Íñigo Huguet) [2059994]
- rtw89: add C2H handle of BCN_CNT (Íñigo Huguet) [2059994]
- rtw89: download beacon content to firmware (Íñigo Huguet) [2059994]
- rtw89: use hardware SSN to TX management frame (Íñigo Huguet) [2059994]
- rtw89: configure rx_filter according to FIF_PROBE_REQ (Íñigo Huguet) [2059994]
- rtw89: correct use of BA CAM (Íñigo Huguet) [2059994]
- rtw89: encapsulate RX handlers to single function (Íñigo Huguet) [2059994]
- rtw89: Add RX counters of VHT MCS-10/11 to debugfs (Íñigo Huguet) [2059994]
- rtw89: remove duplicate definition of hardware port number (Íñigo Huguet) [2059994]
- rtw89: extract modules by chipset (Íñigo Huguet) [2059994]
- ath11k: avoid firmware crash when reg set for QCA6390/WCN6855 (Íñigo Huguet) [2059994]
- ath11k: set WMI_PEER_40MHZ while peer assoc for 6 GHz (Íñigo Huguet) [2059994]
- ath9k_htc: fix uninit value bugs (Íñigo Huguet) [2059994]
- ath10k: abstract htt_rx_desc structure (Íñigo Huguet) [2059994]
- ath9k: remove redundant status variable (Íñigo Huguet) [2059994]
- ath11k: Reconfigure hardware rate for WCN6855 after vdev is started (Íñigo Huguet) [2059994]
- ath: dfs_pattern_detector: Avoid open coded arithmetic in memory allocation (Íñigo Huguet) [2059994]
- ath10k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2059994]
- ath11k: fix error code in ath11k_qmi_assign_target_mem_chunk() (Íñigo Huguet) [2059994]
- ath11k: move function ath11k_dp_rx_process_mon_status (Íñigo Huguet) [2059994]
- ath11k: enable RX PPDU stats in monitor co-exist mode (Íñigo Huguet) [2059994]
- ath11k: free peer for station when disconnect from AP for QCA6390/WCN6855 (Íñigo Huguet) [2059994]
- ath11k: add LDPC FEC type in 802.11 radiotap header (Íñigo Huguet) [2059994]
- ath11k: Refactor the fallback routine when peer create fails (Íñigo Huguet) [2059994]
- ath11k: fix workqueue not getting destroyed after rmmod (Íñigo Huguet) [2059994]
- ath10k: fix memory overwrite of the WoWLAN wakeup packet pattern (Íñigo Huguet) [2059994]
- ath11k: add missing of_node_put() to avoid leak (Íñigo Huguet) [2059994]
- rfkill: define rfill_soft_blocked() if !RFKILL (Íñigo Huguet) [2059994]
- Revert "ath10k: drop beacon and probe response which leak from other channel" (Íñigo Huguet) [2059994]
- iwlwifi: mvm: return value for request_ownership (Íñigo Huguet) [2059994]
- nl80211: Update bss channel on channel switch for P2P_CLIENT (Íñigo Huguet) [2059994]
- iwlwifi: fix build error for IWLMEI (Íñigo Huguet) [2059994]
- mac80211: treat some SAE auth steps as final (Íñigo Huguet) [2059994]
- nl80211: Handle nla_memdup failures in handle_nan_filter (Íñigo Huguet) [2059994]
- iwlwifi: mvm: check debugfs_dir ptr before use (Íñigo Huguet) [2059994]
- iwlwifi: don't advertise TWT support (Íñigo Huguet) [2059994]
- mac80211: fix forwarded mesh frames AC & queue selection (Íñigo Huguet) [2059994]
- mac80211: refuse aggregations sessions before authorized (Íñigo Huguet) [2059994]
- mac80211: fix EAPoL rekey fail in 802.3 rx path (Íñigo Huguet) [2059994]
- iwlwifi: fix use-after-free (Íñigo Huguet) [2059994]
- bus: mhi: pci_generic: Add mru_default for Cinterion MV31-W (Íñigo Huguet) [2059994]
- bus: mhi: pci_generic: Add mru_default for Foxconn SDX55 (Íñigo Huguet) [2059994]
- cfg80211: fix race in netlink owner interface destruction (Íñigo Huguet) [2059994]
- iwlwifi: mvm: don't send SAR GEO command for 3160 devices (Íñigo Huguet) [2059994]
- iwlwifi: remove deprecated broadcast filtering feature (Íñigo Huguet) [2059994]
- iwlwifi: mei: report RFKILL upon register when needed (Íñigo Huguet) [2059994]
- iwlwifi: mvm: don't feed the hardware RFKILL into iwlmei (Íñigo Huguet) [2059994]
- iwlwifi: mei: retry mapping the shared area (Íñigo Huguet) [2059994]
- iwlwifi: mei: fix the pskb_may_pull check in ipv4 (Íñigo Huguet) [2059994]
- iwlwifi: pcie: gen2: fix locking when "HW not ready" (Íñigo Huguet) [2059994]
- iwlwifi: pcie: fix locking when "HW not ready" (Íñigo Huguet) [2059994]
- iwlwifi: fix iwl_legacy_rate_to_fw_idx (Íñigo Huguet) [2059994]
- iwlwifi: mvm: fix condition which checks the version of rate_n_flags (Íñigo Huguet) [2059994]
- mac80211_hwsim: initialize ieee80211_tx_info at hw_scan_work (Íñigo Huguet) [2059994]
- mac80211_hwsim: report NOACK frames in tx_status (Íñigo Huguet) [2059994]
- mac80211: mlme: check for null after calling kmemdup (Íñigo Huguet) [2059994]
- brcmfmac: firmware: Fix crash in brcm_alt_fw_path (Íñigo Huguet) [2059994]
- mac80211: use ieee80211_bss_get_elem() (Íñigo Huguet) [2059994]
- nl80211: clarify comment for mesh PLINK_BLOCKED state (Íñigo Huguet) [2059994]
- mac80211: Add stations iterator where the iterator function may sleep (Íñigo Huguet) [2059994]
- mac80211: allow non-standard VHT MCS-10/11 (Íñigo Huguet) [2059994]
- codel: remove unnecessary pkt_sched.h include (Íñigo Huguet) [2059994]
- codel: remove unnecessary sock.h include (Íñigo Huguet) [2059994]
- rtw88: don't consider deep PS mode when transmitting packet (Íñigo Huguet) [2059994]
- ath11k: add support of firmware logging for WCN6855 (Íñigo Huguet) [2059994]
- ath10k: replace strlcpy with strscpy (Íñigo Huguet) [2059994]
- rtw88: support SAR via kernel common API (Íñigo Huguet) [2059994]
- rtw88: 8822c: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059994]
- iwlwifi: mei: wait before mapping the shared area (Íñigo Huguet) [2059994]
- iwlwifi: mei: clear the ownership when the driver goes down (Íñigo Huguet) [2059994]
- iwlwifi: fw: fix some scan kernel-doc (Íñigo Huguet) [2059994]
- iwlwifi: mvm: remove card state notification code (Íñigo Huguet) [2059994]
- iwlwifi: mvm: drop too short packets silently (Íñigo Huguet) [2059994]
- iwlwifi: return op_mode only in case the failure is from MEI (Íñigo Huguet) [2059994]
- iwlwifi: mvm: support Bz TX checksum offload (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add US/CA to TAS block list if OEM isn't allowed (Íñigo Huguet) [2059994]
- iwlwifi: mvm: correctly set schedule scan profiles (Íñigo Huguet) [2059994]
- iwlwifi: mvm: correctly set channel flags (Íñigo Huguet) [2059994]
- iwlwifi: mvm: always store the PPAG table as the latest version. (Íñigo Huguet) [2059994]
- iwlwifi: bump FW API to 69 for AX devices (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: support TLV-based firmware reset (Íñigo Huguet) [2059994]
- iwlwifi: mvm: change old-SN drop threshold (Íñigo Huguet) [2059994]
- iwlwifi: mvm: don't trust hardware queue number (Íñigo Huguet) [2059994]
- iwlwifi: mvm: handle RX checksum on Bz devices (Íñigo Huguet) [2059994]
- iwlwifi: mvm: use a define for checksum flags mask (Íñigo Huguet) [2059994]
- iwlwifi: remove module loading failure message (Íñigo Huguet) [2059994]
- iwlwifi: mvm: isolate offload assist (checksum) calculation (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add support for OCE scan (Íñigo Huguet) [2059994]
- iwlwifi: dump RCM error tables (Íñigo Huguet) [2059994]
- iwlwifi: dump both TCM error tables if present (Íñigo Huguet) [2059994]
- iwlwifi: dump CSR scratch from outer function (Íñigo Huguet) [2059994]
- iwlwifi: parse error tables from debug TLVs (Íñigo Huguet) [2059994]
- iwlwifi: recognize missing PNVM data and then log filename (Íñigo Huguet) [2059994]
- iwlwifi: rs: add support for TLC config command ver 4 (Íñigo Huguet) [2059994]
- iwlwifi: mvm: rfi: update rfi table (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Add list of OEMs allowed to use TAS (Íñigo Huguet) [2059994]
- iwlwifi: mvm: support revision 1 of WTAS table (Íñigo Huguet) [2059994]
- iwlwifi: fw: remove dead error log code (Íñigo Huguet) [2059994]
- iwlwifi: do not use __unused as variable name (Íñigo Huguet) [2059994]
- iwlwifi: iwl-eeprom-parse: mostly dvm only (Íñigo Huguet) [2059994]
- iwlwifi: mvm: clean up indenting in iwl_mvm_tlc_update_notif() (Íñigo Huguet) [2059994]
- iwlwifi: mvm: fix a stray tab (Íñigo Huguet) [2059994]
- ath11k: add regdb.bin download for regdb offload (Íñigo Huguet) [2059994]
- rtl8xxxu: Improve the A-MPDU retransmission rate with RTS/CTS protection (Íñigo Huguet) [2059994]
- rtw88: don't check CRC of VHT-SIG-B in 802.11ac signal (Íñigo Huguet) [2059994]
- iwlwifi: mvm: fix imbalanced locking in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add dbg_time_point to debugfs (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add missing min_size to kernel-doc (Íñigo Huguet) [2059994]
- iwlwifi: mei: fix W=1 warnings (Íñigo Huguet) [2059994]
- ath11k: add support for hardware rfkill for QCA6390 (Íñigo Huguet) [2059994]
- ath11k: report tx bitrate for iw wlan station dump (Íñigo Huguet) [2059994]
- ath11k: fix warning of RCU usage for ath11k_mac_get_arvif_by_vdev_id() (Íñigo Huguet) [2059994]
- ath11k: add signal report to mac80211 for QCA6390 and WCN6855 (Íñigo Huguet) [2059994]
- ath11k: report rssi of each chain to mac80211 for QCA6390/WCN6855 (Íñigo Huguet) [2059994]
- cfg80211: Enable regulatory enforcement checks for drivers supporting mesh iface (Íñigo Huguet) [2059994]
- rfkill: allow to get the software rfkill state (Íñigo Huguet) [2059994]
- cfg80211: refactor cfg80211_get_ies_channel_number() (Íñigo Huguet) [2059994]
- nl82011: clarify interface combinations wrt. channels (Íñigo Huguet) [2059994]
- nl80211: Add support to offload SA Query procedures for AP SME device (Íñigo Huguet) [2059994]
- nl80211: Add support to set AP settings flags with single attribute (Íñigo Huguet) [2059994]
- mac80211: add more HT/VHT/HE state logging (Íñigo Huguet) [2059994]
- cfg80211: Use the HE operation IE to determine a 6GHz BSS channel (Íñigo Huguet) [2059994]
- cfg80211: rename offchannel_chain structs to background_chain to avoid confusion with ETSI standard (Íñigo Huguet) [2059994]
- mac80211: Notify cfg80211 about association comeback (Íñigo Huguet) [2059994]
- cfg80211: Add support for notifying association comeback (Íñigo Huguet) [2059994]
- mac80211: introduce channel switch disconnect function (Íñigo Huguet) [2059994]
- cfg80211: Fix order of enum nl80211_band_iftype_attr documentation (Íñigo Huguet) [2059994]
- cfg80211: simplify cfg80211_chandef_valid() (Íñigo Huguet) [2059994]
- mac80211: Remove a couple of obsolete TODO (Íñigo Huguet) [2059994]
- mac80211: use coarse boottime for airtime fairness code (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix cmd timeout in throughput test (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix suspend error with enlarging mcu timeout value (Íñigo Huguet) [2059994]
- mt76: mt7921s: make pm->suspended usage consistent (Íñigo Huguet) [2059994]
- mt76: mt7921: clear pm->suspended in mt7921_mac_reset_work (Íñigo Huguet) [2059994]
- mt76: connac: rely on le16_add_cpu in mt76_connac_mcu_add_nested_tlv (Íñigo Huguet) [2059994]
- mt76: mt7921: remove dead definitions (Íñigo Huguet) [2059994]
- mt76: mt7915: add mu-mimo and ofdma debugfs knobs (Íñigo Huguet) [2059994]
- mt76: mt7915: introduce mt76_vif in mt7915_vif (Íñigo Huguet) [2059994]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2059994]
- mt76: mt7915: rely on mt76_connac definitions (Íñigo Huguet) [2059994]
- mt76: connac: rely on MCU_CMD macro (Íñigo Huguet) [2059994]
- mt76: connac: introduce MCU_CE_CMD macro (Íñigo Huguet) [2059994]
- mt76: connac: introduce MCU_UNI_CMD macro (Íñigo Huguet) [2059994]
- mt76: connac: remove MCU_FW_PREFIX bit (Íñigo Huguet) [2059994]
- mt76: connac: align MCU_EXT definitions with 7915 driver (Íñigo Huguet) [2059994]
- mt76: connac: introduce MCU_EXT macros (Íñigo Huguet) [2059994]
- mt76: mt7615: in debugfs queue stats, skip wmm index 3 on mt7663 (Íñigo Huguet) [2059994]
- mt76: mt7915: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059994]
- mt76: allow drivers to drop rx packets early (Íñigo Huguet) [2059994]
- mt76: mt7663: disable 4addr capability (Íñigo Huguet) [2059994]
- mt76: only access ieee80211_hdr after mt76_insert_ccmp_hdr (Íñigo Huguet) [2059994]
- mt76: move sar_capa configuration in common code (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix possible kernel crash due to invalid Rx count (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix bus hang with wrong privilege (Íñigo Huguet) [2059994]
- mt76: eeprom: tolerate corrected bit-flips (Íñigo Huguet) [2059994]
- mt76: mt7603: improve reliability of tx powersave filtering (Íñigo Huguet) [2059994]
- mt76: clear sta powersave flag after notifying driver (Íñigo Huguet) [2059994]
- mt76: mt7915: introduce SAR support (Íñigo Huguet) [2059994]
- mt76: mt7603: introduce SAR support (Íñigo Huguet) [2059994]
- mt76: mt7915: improve wmm index allocation (Íñigo Huguet) [2059994]
- mt76: mt7615: improve wmm index allocation (Íñigo Huguet) [2059994]
- mt76: mt7921s: fix the device cannot sleep deeply in suspend (Íñigo Huguet) [2059994]
- mt76: mt7615: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059994]
- mt76: mt7915: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059994]
- mt76: mt76x02: introduce SAR support (Íñigo Huguet) [2059994]
- mt76: move sar utilities to mt76-core module (Íñigo Huguet) [2059994]
- mt76: mt7921: honor mt76_connac_mcu_set_rate_txpower return value in mt7921_config (Íñigo Huguet) [2059994]
- mt76: do not pass the received frame with decryption error (Íñigo Huguet) [2059994]
- mt76: connac: remove PHY_MODE_AX_6G configuration in mt76_connac_get_phy_mode (Íñigo Huguet) [2059994]
- mt76: mt7615: remove dead code in get_omac_idx (Íñigo Huguet) [2059994]
- mt76: mt7921: introduce 160 MHz channel bandwidth support (Íñigo Huguet) [2059994]
- mt76: mt7921: add support for PCIe ID 0x0608/0x0616 (Íñigo Huguet) [2059994]
- mt76: testmode: add support to set MAC (Íñigo Huguet) [2059994]
- mt76: mt7915: add default calibrated data support (Íñigo Huguet) [2059994]
- mt76: only set rx radiotap flag from within decoder functions (Íñigo Huguet) [2059994]
- mt76: reverse the first fragmented frame to 802.11 (Íñigo Huguet) [2059994]
- bus: mhi: pci_generic: Introduce Sierra EM919X support (Íñigo Huguet) [2059994]
- bus: mhi: core: Add an API for auto queueing buffers for DL channel (Íñigo Huguet) [2059994]
- bus: mhi: pci_generic: Simplify code and axe the use of a deprecated API (Íñigo Huguet) [2059994]
- bus: mhi: core: Use macros for execution environment features (Íñigo Huguet) [2059994]
- bus: mhi: pci_generic: Add new device ID support for T99W175 (Íñigo Huguet) [2059994]
- ath11k: Use reserved host DDR addresses from DT for PCI devices (Íñigo Huguet) [2059994]
- ath11k: Change qcn9074 fw to operate in mode-2 (Íñigo Huguet) [2059994]
- ath11k: add ab to TARGET_NUM_VDEVS & co (Íñigo Huguet) [2059994]
- brcmfmac: Fix incorrect type assignments for keep-alive (Íñigo Huguet) [2059994]
- ath11k: Avoid false DEADLOCK warning reported by lockdep (Íñigo Huguet) [2059994]
- ath11k: set DTIM policy to stick mode for station interface (Íñigo Huguet) [2059994]
- ath11k: support MAC address randomization in scan (Íñigo Huguet) [2059994]
- ath10k: wmi: remove array of flexible structures (Íñigo Huguet) [2059994]
- ath10k: htt: remove array of flexible structures (Íñigo Huguet) [2059994]
- ath10k: drop beacon and probe response which leak from other channel (Íñigo Huguet) [2059994]
- ath11k: Process full monitor mode rx support (Íñigo Huguet) [2059994]
- ath11k: add software monitor ring descriptor for full monitor (Íñigo Huguet) [2059994]
- ath11k: Add htt cmd to enable full monitor mode (Íñigo Huguet) [2059994]
- ath11k: enable IEEE80211_HW_SINGLE_SCAN_ON_ALL_BANDS for WCN6855 (Íñigo Huguet) [2059994]
- rtw88: refine tx_pwr_tbl debugfs to show channel and bandwidth (Íñigo Huguet) [2059994]
- rtw88: add debugfs to fix tx rate (Íñigo Huguet) [2059994]
- ath: regdom: extend South Korea regulatory domain support (Íñigo Huguet) [2059994]
- ath11k: add wait operation for tx management packets for flush from mac80211 (Íñigo Huguet) [2059994]
- ath11k: add 11d scan offload support (Íñigo Huguet) [2059994]
- ath11k: add configure country code for QCA6390 and WCN6855 (Íñigo Huguet) [2059994]
- ath11k: avoid deadlock by change ieee80211_queue_work for regd_update_work (Íñigo Huguet) [2059994]
- iwlwifi: work around reverse dependency on MEI (Íñigo Huguet) [2059994]
- iwlwifi: mvm: optionally suppress assert log (Íñigo Huguet) [2059994]
- iwlwifi: fw: correctly detect HW-SMEM region subtype (Íñigo Huguet) [2059994]
- iwlwifi: implement reset flow for Bz devices (Íñigo Huguet) [2059994]
- iwlwifi: dbg: disable ini debug in 8000 family and below (Íñigo Huguet) [2059994]
- iwlwifi: support SAR GEO Offset Mapping override via BIOS (Íñigo Huguet) [2059994]
- iwlwifi: pcie: retake ownership after reset (Íñigo Huguet) [2059994]
- iwlwifi: mvm: always use 4K RB size by default (Íñigo Huguet) [2059994]
- iwlwifi: mvm/api: define system control command (Íñigo Huguet) [2059994]
- iwlwifi: bump FW API to 68 for AX devices (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add some missing command strings (Íñigo Huguet) [2059994]
- iwlwifi: fw: add support for splitting region type bits (Íñigo Huguet) [2059994]
- iwlwifi: swap 1650i and 1650s killer struct names (Íñigo Huguet) [2059994]
- iwlwifi: yoyo: support for DBGC4 for dram (Íñigo Huguet) [2059994]
- iwlwifi: mvm: update rate scale in moving back to assoc state (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add support for statistics update version 15 (Íñigo Huguet) [2059994]
- iwlwifi: mvm: Add support for a new version of scan request command (Íñigo Huguet) [2059994]
- iwlwifi: mvm: remove session protection upon station removal (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add support for PHY context command v4 (Íñigo Huguet) [2059994]
- iwlwifi: fw: api: add link to PHY context command struct v1 (Íñigo Huguet) [2059994]
- iwlwifi: mvm: support RLC configuration command (Íñigo Huguet) [2059994]
- iwlwifi: mvm: d3: support v12 wowlan status (Íñigo Huguet) [2059994]
- iwlwifi: mvm: parse firmware alive message version 6 (Íñigo Huguet) [2059994]
- iwlwifi: pcie: support Bz suspend/resume trigger (Íñigo Huguet) [2059994]
- iwlwifi: mvm: d3: move GTK rekeys condition (Íñigo Huguet) [2059994]
- ath11k: change to use dynamic memory for channel list of scan (Íñigo Huguet) [2059994]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2059994]
- ath9k: switch to rate table based lookup (Íñigo Huguet) [2059994]
- iwlwifi: mvm: demote non-compliant kernel-doc header (Íñigo Huguet) [2059994]
- iwlwifi: mvm: fix a possible NULL pointer deference (Íñigo Huguet) [2059994]
- iwlwifi: mei: Fix spelling mistake "req_ownserhip" -> "req_ownership" (Íñigo Huguet) [2059994]
- iwlwifi: mei: don't rely on the size from the shared area (Íñigo Huguet) [2059994]
- iwlwifi: mei: fix linking when tracing is not enabled (Íñigo Huguet) [2059994]
- ath11k: Avoid NULL ptr access during mgmt tx cleanup (Íñigo Huguet) [2059994]
- rtlwifi: rtl8192de: Style clean-ups (Íñigo Huguet) [2059994]
- brcmfmac: Configure keep-alive packet on suspend (Íñigo Huguet) [2059994]
- ieee80211: change HE nominal packet padding value defines (Íñigo Huguet) [2059994]
- cfg80211: use ieee80211_bss_get_elem() instead of _get_ie() (Íñigo Huguet) [2059994]
- iwlwifi: mvm: read the rfkill state and feed it to iwlmei (Íñigo Huguet) [2059994]
- iwlwifi: mvm: add vendor commands needed for iwlmei (Íñigo Huguet) [2059994]
- iwlwifi: integrate with iwlmei (Íñigo Huguet) [2059994]
- iwlwifi: mei: add debugfs hooks (Íñigo Huguet) [2059994]
- iwlwifi: mei: add the driver to allow cooperation with CSME (Íñigo Huguet) [2059994]
- mwifiex: Ensure the version string from the firmware is 0-terminated (Íñigo Huguet) [2059994]
- mwifiex: Add quirk to disable deep sleep with certain hardware revision (Íñigo Huguet) [2059994]
- mwifiex: Use a define for firmware version string length (Íñigo Huguet) [2059994]
- rtw88: add debugfs to force lowest basic rate (Íñigo Huguet) [2059994]
- rtw88: follow the AP basic rates for tx mgmt frame (Íñigo Huguet) [2059994]
- mac80211: Use memset_after() to clear tx status (Íñigo Huguet) [2059994]
- mac80211: notify non-transmitting BSS of color changes (Íñigo Huguet) [2059994]
- mac80211: minstrel_ht: remove unused SAMPLE_SWITCH_THR define (Íñigo Huguet) [2059994]
- cfg80211: allow continuous radar monitoring on offchannel chain (Íñigo Huguet) [2059994]
- cfg80211: schedule offchan_cac_abort_wk in cfg80211_radar_event (Íñigo Huguet) [2059994]
- cfg80211: delete redundant free code (Íñigo Huguet) [2059994]
- mac80211: Remove unused assignment statements (Íñigo Huguet) [2059994]
- cfg80211: fix possible NULL pointer dereference in cfg80211_stop_offchan_radar_detection (Íñigo Huguet) [2059994]
- ath11k: Use memset_startat() for clearing queue descriptors (Íñigo Huguet) [2059994]
- ath11k: Fix spelling mistake "detetction" -> "detection" (Íñigo Huguet) [2059994]
- Revert "ath11k: add read variant from SMBIOS for download board data" (Íñigo Huguet) [2059994]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2059994]
- ath11k: calculate the correct NSS of peer for HE capabilities (Íñigo Huguet) [2059994]
- ath11k: change to treat alpha code na as world wide regdomain (Íñigo Huguet) [2059994]
- cfg80211: move offchan_cac_event to a dedicated work (Íñigo Huguet) [2059994]
- mac80211_hwsim: Fix spelling mistake "Droping" -> "Dropping" (Íñigo Huguet) [2059994]
- mac80211: introduce set_radar_offchan callback (Íñigo Huguet) [2059994]
- cfg80211: implement APIs for dedicated radar detection HW (Íñigo Huguet) [2059994]
- ath11k: add support for BSS color change (Íñigo Huguet) [2059994]
- ath11k: add trace log support (Íñigo Huguet) [2059994]
- ath11k: Add missing qmi_txn_cancel() (Íñigo Huguet) [2059994]
- ath11k: Disabling credit flow for WMI path (Íñigo Huguet) [2059994]
- ath11k: Increment pending_mgmt_tx count before tx send invoke (Íñigo Huguet) [2059994]
- ath11k: send proper txpower and maxregpower values to firmware (Íñigo Huguet) [2059994]
- ath11k: move peer delete after vdev stop of station for QCA6390 and WCN6855 (Íñigo Huguet) [2059994]
- ath11k: remove return for empty tx bitrate in mac_op_sta_statistics (Íñigo Huguet) [2059994]
- ath11k: enable IEEE80211_VHT_EXT_NSS_BW_CAPABLE if NSS ratio enabled (Íñigo Huguet) [2059994]
- ath11k: avoid unnecessary lock contention in tx_completion path (Íñigo Huguet) [2059994]
- ath11k: add branch predictors in dp_tx path (Íñigo Huguet) [2059994]
- ath11k: avoid while loop in ring selection of tx completion interrupt (Íñigo Huguet) [2059994]
- ath11k: remove mod operator in dst ring processing (Íñigo Huguet) [2059994]
- ath11k: allocate HAL_WBM2SW_RELEASE ring from cacheable memory (Íñigo Huguet) [2059994]
- ath11k: add branch predictors in process_rx (Íñigo Huguet) [2059994]
- ath11k: remove usage quota while processing rx packets (Íñigo Huguet) [2059994]
- ath11k: avoid active pdev check for each msdu (Íñigo Huguet) [2059994]
- ath11k: avoid additional access to ath11k_hal_srng_dst_num_free (Íñigo Huguet) [2059994]
- ath11k: modify dp_rx desc access wrapper calls inline (Íñigo Huguet) [2059994]
- ath11k: allocate dst ring descriptors from cacheable memory (Íñigo Huguet) [2059994]
- ath11k: disable unused CE8 interrupts for ipq8074 (Íñigo Huguet) [2059994]
- ath11k: avoid unnecessary BH disable lock in STA kickout event (Íñigo Huguet) [2059994]
- ath11k: enable 802.11 power save mode in station mode (Íñigo Huguet) [2059994]
- ath11k: convert ath11k_wmi_pdev_set_ps_mode() to use enum wmi_sta_ps_mode (Íñigo Huguet) [2059994]
- ath9k: use swap() to make code cleaner (Íñigo Huguet) [2059994]
- ath10k: fetch (pre-)calibration data via nvmem subsystem (Íñigo Huguet) [2059994]
- Revert "ath11k: add support for WCN6855 hw2.1" (Íñigo Huguet) [2059994]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting (Jerry Snitselaar) [2095498]
- scsi: mpi3mr: Fix kernel-doc (Tomas Henzl) [2091878]
- scsi: mpi3mr: Rework mrioc->bsg_device model to fix warnings (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add target device related sysfs attributes (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add shost related sysfs attributes (Tomas Henzl) [2091878]
- scsi: mpi3mr: Return error if dma_alloc_coherent() fails (Tomas Henzl) [2091878]
- scsi: mpi3mr: Fix a NULL vs IS_ERR() bug in mpi3mr_bsg_init() (Tomas Henzl) [2091878]
- scsi: mpi3mr: Return I/Os to an unrecoverable HBA with DID_ERROR (Tomas Henzl) [2091878]
- scsi: mpi3mr: Hidden drives not removed during soft reset (Tomas Henzl) [2091878]
- scsi: mpi3mr: Increase I/O timeout value to 60s (Tomas Henzl) [2091878]
- scsi: mpi3mr: Update driver version to 8.0.0.69.0 (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add support for NVMe passthrough (Tomas Henzl) [2091878]
- scsi: mpi3mr: Expose adapter state to sysfs (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add support for PEL commands (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add support for MPT commands (Tomas Henzl) [2091878]
- scsi: mpi3mr: Move data structures/definitions from MPI headers to uapi header (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add support for driver commands (Tomas Henzl) [2091878]
- scsi: mpi3mr: Add bsg device support (Tomas Henzl) [2091878]
- selftests/powerpc: Add PPC_FEATURE2_ARCH_3_1 and PPC_FEATURE2_EBB bits (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc: Add helper to exit on failure (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add interface test for mmcra register fields (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr3_src fields (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr2_fcs_fch fields (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr2_l2l3 field (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr1_comb field (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmc56 using pmc5 (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr0_fc56 field using pmc1 (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmcjce field (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmccext bit (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr0_cc56run field (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu/: Add interface test for mmcr0 exception bits (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add macro to extract mmcr3 and mmcra fields (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add macro to extract mmcr0/mmcr1 fields (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add macros to extract mmcr fields (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add event_init_sampling function (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add utility functions to post process the mmap buffer (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add macros to parse event codes (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Add support for perf sampling tests (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc: Add a test of counting larx/stcx (Desnes A. Nunes do Rosario) [2071113]
- selftests/powerpc/pmu: Include mmap_buffer field as part of struct event (Desnes A. Nunes do Rosario) [2071113]
- [s390] net/smc: Fix af_ops of child socket pointing to released memory (Tobias Huschle) [2043832]
- [s390] net/smc: Fix NULL pointer dereference in smc_pnet_find_ib() (Tobias Huschle) [2043832]
- [s390] net/smc: use memcpy instead of snprintf to avoid out of bounds read (Tobias Huschle) [2043832]
- [s390] net/smc: Call trace_smc_tx_sendmsg when data corked (Tobias Huschle) [2043832]
- [s390] net/smc: Fix cleanup when register ULP fails (Tobias Huschle) [2043832]
- [s390] net/smc: fix connection leak (Tobias Huschle) [2043832]
- [s390] net/smc: Use a mutex for locking "struct smc_pnettable" (Tobias Huschle) [2043832]
- [s390] net/smc: unlock on error paths in __smc_setsockopt() (Tobias Huschle) [2043832]
- [s390] net/smc: return ETIMEDOUT when smc_connect_clc() timeout (Tobias Huschle) [2043832]
- [s390] net/smc: Add comment for smc_tx_pending (Tobias Huschle) [2043832]
- [s390] net/smc: Add global configure for handshake limitation by netlink (Tobias Huschle) [2043832]
- [s390] net/smc: Dynamic control handshake limitation by socket options (Tobias Huschle) [2043832]
- [s390] net/smc: Limit SMC visits when handshake workqueue congested (Tobias Huschle) [2043832]
- [s390] net/smc: Limit backlog connections (Tobias Huschle) [2043832]
- [s390] net/smc: Make smc_tcp_listen_work() independent (Tobias Huschle) [2043832]
- [s390] net/smc: Avoid overwriting the copies of clcsock callback functions (Tobias Huschle) [2043832]
- [s390] Partially revert "net/smc: Add netlink net namespace support" (Tobias Huschle) [2043832]
- [s390] net/smc: Cork when sendpage with MSG_SENDPAGE_NOTLAST flag (Tobias Huschle) [2043832]
- [s390] net/smc: Remove corked dealyed work (Tobias Huschle) [2043832]
- [s390] net/smc: Send directly when TCP_CORK is cleared (Tobias Huschle) [2043832]
- [s390] net/smc: Forward wakeup to smc socket waitqueue after fallback (Tobias Huschle) [2043832]
- [s390] net/smc: Transitional solution for clcsock race issue (Tobias Huschle) [2043832]
- [s390] net/smc: Fix hung_task when removing SMC-R devices (Tobias Huschle) [2043832]
- [s390] net/smc: Remove unused function declaration (Tobias Huschle) [2043832]
- [s390] net/smc: Resolve the race between SMC-R link access and clear (Tobias Huschle) [2043832]
- [s390] net/smc: Introduce a new conn->lgr validity check helper (Tobias Huschle) [2043832]
- [s390] net/smc: Resolve the race between link group access and termination (Tobias Huschle) [2043832]
- [s390] net/smc: Reset conn->lgr when link group registration fails (Tobias Huschle) [2043832]
- [s390] net/smc: add comments for smc_link_{usable|sendable} (Tobias Huschle) [2043832]
- [s390] net/smc: remove redundant re-assignment of pointer link (Tobias Huschle) [2043832]
- [s390] net/smc: Introduce TCP ULP support (Tobias Huschle) [2043832]
- [s390] net/smc: Add net namespace for tracepoints (Tobias Huschle) [2043832]
- [s390] net/smc: Print net namespace in log (Tobias Huschle) [2043832]
- [s390] net/smc: Add netlink net namespace support (Tobias Huschle) [2043832]
- [s390] net/smc: Introduce net namespace support for linkgroup (Tobias Huschle) [2043832]
- [s390] net/smc: Use the bitmap API when applicable (Tobias Huschle) [2043832]
- [s390] net/smc: fix kernel panic caused by race of smc_sock (Tobias Huschle) [2043832]
- [s390] net/smc: don't send CDC/LLC message if link not ready (Tobias Huschle) [2043832]
- [s390] net/smc: fix using of uninitialized completions (Tobias Huschle) [2043832]
- [s390] net/smc: Prevent smc_release() from long blocking (Tobias Huschle) [2043832]
- [s390] net/smc: Clear memory when release and reuse buffer (Tobias Huschle) [2043832]
- [s390] net/smc: Keep smc_close_final rc during active close (Tobias Huschle) [2043832]
- [s390] net/smc: fix wrong list_del in smc_lgr_cleanup_early (Tobias Huschle) [2043832]
- [s390] net/smc: Don't call clcsock shutdown twice when smc shutdown (Tobias Huschle) [2043832]
- [s390] net/smc: Fix loop in smc_listen (Tobias Huschle) [2043832]
- [s390] net/smc: Fix NULL pointer dereferencing in smc_vlan_by_tcpsk() (Tobias Huschle) [2043832]
- [s390] net/smc: Ensure the active closing peer first closes clcsock (Tobias Huschle) [2043832]
- [s390] net/smc: Clean up local struct sock variables (Tobias Huschle) [2043832]
- [s390] net/smc: Avoid warning of possible recursive locking (Tobias Huschle) [2043832]
- [s390] net/smc: Make sure the link_id is unique (Tobias Huschle) [2043832]
- [s390] net/smc: Transfer remaining wait queue entries during fallback (Tobias Huschle) [2043832]
- [s390] net/smc: fix sk_refcnt underflow on linkdown and fallback (Tobias Huschle) [2043832]
- [s390] net/smc: Print function name in smcr_link_down tracepoint (Tobias Huschle) [2043832]
- [s390] net/smc: Introduce tracepoint for smcr link down (Tobias Huschle) [2043832]
- [s390] net/smc: Introduce tracepoints for tx and rx msg (Tobias Huschle) [2043832]
- [s390] net/smc: Introduce tracepoint for fallback (Tobias Huschle) [2043832]
- [s390] net/smc: Correct spelling mistake to TCPF_SYN_RECV (Tobias Huschle) [2043832]
- [s390] net/smc: Fix smc_link->llc_testlink_time overflow (Tobias Huschle) [2043832]
- [s390] net/smc: stop links when their GID is removed (Tobias Huschle) [2043832]
- [s390] net/smc: add netlink support for SMC-Rv2 (Tobias Huschle) [2043832]
- [s390] net/smc: extend LLC layer for SMC-Rv2 (Tobias Huschle) [2043832]
- [s390] net/smc: add v2 support to the work request layer (Tobias Huschle) [2043832]
- [s390] net/smc: retrieve v2 gid from IB device (Tobias Huschle) [2043832]
- [s390] net/smc: add v2 format of CLC decline message (Tobias Huschle) [2043832]
- [s390] net/smc: add listen processing for SMC-Rv2 (Tobias Huschle) [2043832]
- [s390] net/smc: add SMC-Rv2 connection establishment (Tobias Huschle) [2043832]
- [s390] net/smc: prepare for SMC-Rv2 connection (Tobias Huschle) [2043832]
- [s390] net/smc: save stack space and allocate smc_init_info (Tobias Huschle) [2043832]
- [s390] net/smc: add generic netlink support for system EID (Tobias Huschle) [2043832]
- [s390] net/smc: keep static copy of system EID (Tobias Huschle) [2043832]
- [s390] net/smc: add support for user defined EIDs (Tobias Huschle) [2043832]
- [s390] net/smc: Allow SMC-D 1MB DMB allocations (Tobias Huschle) [2043832]
- [s390] net/smc: no need to flush smcd_dev's event_wq before destroying it (Tobias Huschle) [2043832]
- [s390] net/smc: avoid possible duplicate dmb unregistration (Tobias Huschle) [2043832]
- [s390] net/smc: remove device from smcd_dev_list after failed device_add() (Tobias Huschle) [2043832]

* Fri Jun 17 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-402.el8]
- bnxt_en: parse and report result field when NVRAM package install fails (Ken Cox) [2043782]
- bnxt_en: Fix unnecessary dropping of RX packets (Ken Cox) [2043782]
- bnxt_en: Initiallize bp->ptp_lock first before using it (Ken Cox) [2043782]
- bnxt_en: Fix possible bnxt_open() failure caused by wrong RFS flag (Ken Cox) [2043782]
- bnxt_en: Prevent XDP redirect from running when stopping TX queue (Ken Cox) [2043782 1944997]
- bnxt_en: reserve space inside receive page for skb_shared_info (Ken Cox) [2043782 1944997]
- bnxt_en: Synchronize tx when xdp redirects happen on same ring (Ken Cox) [2043782 1944997]
- net: bnxt_ptp: fix compilation error (Ken Cox) [2043782]
- bnxt: revert hastily merged uAPI aberrations (Ken Cox) [2043782]
- bnxt_en: add an nvm test for hw diagnose (Ken Cox) [2043782]
- bnxt_en: implement hw health reporter (Ken Cox) [2043782]
- bnxt_en: Do not destroy health reporters during reset (Ken Cox) [2043782]
- bnxt_en: Eliminate unintended link toggle during FW reset (Ken Cox) [2043782]
- bnxt_en: Properly report no pause support on some cards (Ken Cox) [2043782]
- bnxt_en: introduce initial link state of unknown (Ken Cox) [2043782]
- bnxt_en: parse result field when NVRAM package install fails (Ken Cox) [2043782]
- bnxt_en: add more error checks to HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2043782]
- bnxt_en: refactor error handling of HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2043782]
- bnxt_en: Increase firmware message response DMA wait time (Ken Cox) [2043782]
- bnxt_en: Fix incorrect multicast rx mask setting when not requested (Ken Cox) [2043782]
- bnxt_en: Fix occasional ethtool -t loopback test failures (Ken Cox) [2043782]
- bnxt_en: Fix offline ethtool selftest with RDMA enabled (Ken Cox) [2043782]
- bnxt_en: Fix active FEC reporting to ethtool (Ken Cox) [2043782]
- bnxt_en: Fix devlink fw_activate (Ken Cox) [2043782]
- bnxt_en: Restore the resets_reliable flag in bnxt_open() (Ken Cox) [2043782]
- bnxt_en: Handle async event when the PHC is updated in RTC mode (Ken Cox) [2043782]
- bnxt_en: Implement .adjtime() for PTP RTC mode (Ken Cox) [2043782]
- bnxt_en: Add driver support to use Real Time Counter for PTP (Ken Cox) [2043782]
- bnxt_en: PTP: Refactor PTP initialization functions (Ken Cox) [2043782]
- bnxt_en: Update firmware interface to 1.10.2.73 (Ken Cox) [2043782]
- bnxt_en: improve firmware timeout messaging (Ken Cox) [2043782]
- bnxt_en: use firmware provided max timeout for messages (Ken Cox) [2043782]
- bnxt_en: improve VF error messages when PF is unavailable (Ken Cox) [2043782]
- bnxt_en: add dynamic debug support for HWRM messages (Ken Cox) [2043782]
- bnxt_en: Use page frag RX buffers for better software GRO performance (Ken Cox) [2043782]
- bnxt_en: convert to xdp_do_flush (Ken Cox) [2043782]
- bnxt_en: Support CQE coalescing mode in ethtool (Ken Cox) [2043782]
- bnxt_en: Support configurable CQE coalescing mode (Ken Cox) [2043782]
- bnxt_en: enable interrupt sampling on 5750X for DIM (Ken Cox) [2043782]
- bnxt_en: Log error report for dropped doorbell (Ken Cox) [2043782]
- bnxt_en: Add event handler for PAUSE Storm event (Ken Cox) [2043782]
- flow_offload: reject to offload tc actions in offload drivers (Ken Cox) [2043782]
- bnxt_en: Fix compile error regression when CONFIG_BNXT_SRIOV is not set (Ken Cox) [2043782]
- bnxt_en: fix format specifier in live patch error message (Ken Cox) [2043782]
- bnxt_en: extend RTNL to VF check in devlink driver_reinit (Ken Cox) [2043782]
- bnxt_en: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ken Cox) [2043782]
- bnxt_en: Remove not used other ULP define (Ken Cox) [2043782]
- bnxt_en: Provide stored devlink "fw" version on older firmware (Ken Cox) [2043782]
- bnxt_en: implement firmware live patching (Ken Cox) [2043782]
- bnxt_en: Update firmware interface to 1.10.2.63 (Ken Cox) [2043782]
- bnxt_en: implement dump callback for fw health reporter (Ken Cox) [2043782]
- bnxt_en: extract coredump command line from current task (Ken Cox) [2043782]
- bnxt_en: Retrieve coredump and crashdump size via FW command (Ken Cox) [2043782]
- bnxt_en: Add compression flags information in coredump segment header (Ken Cox) [2043782]
- bnxt_en: move coredump functions into dedicated file (Ken Cox) [2043782]
- bnxt_en: Refactor coredump functions (Ken Cox) [2043782]
- bnxt_en: improve fw diagnose devlink health messages (Ken Cox) [2043782]
- bnxt_en: consolidate fw devlink health reporters (Ken Cox) [2043782]
- bnxt_en: remove fw_reset devlink health reporter (Ken Cox) [2043782]
- bnxt_en: improve error recovery information messages (Ken Cox) [2043782]
- bnxt_en: add enable_remote_dev_reset devlink parameter (Ken Cox) [2043782]
- bnxt_en: implement devlink dev reload fw_activate (Ken Cox) [2043782]
- bnxt_en: implement devlink dev reload driver_reinit (Ken Cox) [2043782]
- bnxt_en: refactor cancellation of resource reservations (Ken Cox) [2043782]
- bnxt_en: refactor printing of device info (Ken Cox) [2043782]
- bnxt: use netif_is_rxfh_configured instead of open code (Ken Cox) [2043782]
- ethernet: use eth_hw_addr_set() (Ken Cox) [2043782]
- bnxt_en: Fix TX timeout when TX ring size is set to the smallest (Ken Cox) [2043782]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Ken Cox) [2043782]
- bnxt_en: make bnxt_free_skbs() safe to call after bnxt_free_mem() (Ken Cox) [2043782]
- netfilter: nat: really support inet nat without l3 address (Phil Sutter) [2092424]
- netfilter: nf_tables: use kfree_rcu(ptr, rcu) to release hooks in clean_net path (Phil Sutter) [2094236]
- netfilter: nf_tables: double hook unregistration in netns path (Phil Sutter) [2094236]
- video: fbdev: hyperv_fb: Allow resolutions with size > 64 MB for Gen1 (Mohammed Gamal) [1948442]
- cpufreq: intel_pstate: Use firmware default EPP (Steve Best) [2072671]
- cpufreq: intel_pstate: Update cpuinfo.max_freq on HWP_CAP changes (Steve Best) [2072671]
- cpufreq: intel_pstate: Update EPP for AlderLake mobile (Steve Best) [2072671]
- cpufreq: intel_pstate: Drop redundant intel_pstate_get_hwp_cap() call (Steve Best) [2072671]
- cpufreq: intel_pstate: ITMT support for overclocked system (Steve Best) [2072671]
- cpufreq: intel_pstate: Fix active mode offline/online EPP handling (Steve Best) [2072671]
- cpufreq: intel_pstate: Clear HWP Status during HWP Interrupt enable (Steve Best) [2072671]
- cpufreq: intel_pstate: Fix unchecked MSR 0x773 access (Steve Best) [2072671]
- cpufreq: intel_pstate: Clear HWP desired on suspend/shutdown and offline (Steve Best) [2072671]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (Steve Best) [2072671]
- cpufreq: intel_pstate: Override parameters if HWP forced by BIOS (Steve Best) [2072671]
- Revert "cpufreq: intel_pstate: Process HWP Guaranteed change notification" (Steve Best) [2072671]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (Steve Best) [2072671]
- cpuidle: intel_idle: Drop redundant backslash at line end (Steve Best) [2072893]
- intel_idle: add core C6 optimization for SPR (Steve Best) [2072893]
- intel_idle: add 'preferred_cstates' module argument (Steve Best) [2072893]
- intel_idle: add SPR support (Steve Best) [2072893]
- intel_idle: enable interrupts before C1 on Xeons (Steve Best) [2072893]

* Wed Jun 15 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-401.el8]
- [s390] s390/airq: use DMA memory for summary indicators (Tobias Huschle) [2043905]
- [s390] s390/zcrypt: Provide target domain for EP11 cprbs to scheduling function (Tobias Huschle) [2043905]
- [s390] s390/zcrypt: change reply buffer size offering (Tobias Huschle) [2043905]
- [s390] s390/zcrypt: Support CPRB minor version T7 (Tobias Huschle) [2043905]
- [s390] s390/zcrypt: handle checkstopped cards with new state (Tobias Huschle) [2043905]
- [s390] s390/zcrypt: CEX8S exploitation support (Tobias Huschle) [2043905]
- [s390] s390/ap/zcrypt: debug feature improvements (Tobias Huschle) [2043905]
- [s390] s390/zcrypt: rework of debug feature messages (Tobias Huschle) [2043905]
- powerpc/perf: Fix the threshold compare group constraint for power10 (Steve Best) [2090058]
- arch/x86: Disable system wide bus lock rate limiting (Prarit Bhargava) [2028252]
- rtnetlink: return ENODEV when IFLA_ALT_IFNAME is used in dellink (Xin Long) [2062780]
- rtnetlink: enable alt_ifname for setlink/newlink (Xin Long) [2062780]
- rtnetlink: return ENODEV when ifname does not exist and group is given (Xin Long) [2062780]
- rtnetlink: Return correct error on changing device netns (Xin Long) [2062780]
- net: remove the new_ifindex argument from dev_change_net_namespace (Xin Long) [2062780]
- net: Allow to specify ifindex when device is moved to another namespace (Xin Long) [2062780]
- net: rtnetlink: add possibility to use alternative names as message handle (Xin Long) [2062780]
- net: rtnetlink: introduce helper to get net_device instance by ifname (Xin Long) [2062780]
- net: rtnetlink: unify the code in __rtnl_newlink get dev with the rest (Xin Long) [2062780]
- net: rtnetlink: put alternative names to getlink message (Xin Long) [2062780]
- block-map: add __GFP_ZERO flag for alloc_page in function bio_copy_kern (Ewan D. Milne) [2049198] {CVE-2022-0494}
- [s390] s390/dasd: prevent double format of tracks for ESE devices (Mete Durlu) [2094296]
- [s390] s390/dasd: fix data corruption for ESE devices (Mete Durlu) [2094296]
- [s390] s390/dasd: Fix read inconsistency for ESE DASD devices (Mete Durlu) [2094294]
- [s390] s390/dasd: Fix read for ESE with blksize < 4k (Mete Durlu) [2094294]
- xfs: validate inode fork size against fork format (Andrey Albershteyn) [2089447]
- selftests/tc-testing: match any qdisc type (Petr Oros) [2021843]
- tc-testing: Add control-plane selftests for sch_mq (Petr Oros) [2021843]
- netdevsim: Zero-initialize memory for new map's value in function nsim_bpf_map_alloc (Petr Oros) [2021843]
- netdevsim: don't overwrite read only ethtool parms (Petr Oros) [2021843]
- netdevsim: fix uninit value in nsim_drv_configure_vfs() (Petr Oros) [2021843]
- netdevsim: rename 'driver' entry points (Petr Oros) [2021843]
- netdevsim: move max vf config to dev (Petr Oros) [2021843]
- netdevsim: move details of vf config to dev (Petr Oros) [2021843]
- netdevsim: move vfconfig to nsim_dev (Petr Oros) [2021843]
- netdevsim: take rtnl_lock when assigning num_vfs (Petr Oros) [2021843]
- netdevsim: Protect both reload_down and reload_up paths (Petr Oros) [2021843]
- netdevsim: make array res_ids static const, makes object smaller (Petr Oros) [2021843]
- netdevsim: Add multi-queue support (Petr Oros) [2021843]
- net: netdevsim: use xso.real_dev instead of xso.dev in callback functions of struct xfrmdev_ops (Petr Oros) [2021843]
- netdevsim: delete unnecessary debugfs checking (Petr Oros) [2021843]
- netdevsim: switch to memdup_user_nul() (Petr Oros) [2021843]
- netdevsim: init u64 stats for 32bit hardware (Petr Oros) [2021843]
- dm: fix bio length of empty flush (Ming Lei) [2090940]
- block: initialize the target bio in __bio_clone_fast (Ming Lei) [2090940]
- dm: use bio_clone_fast in alloc_io/alloc_tio (Ming Lei) [2090940]
- block: clone crypto and integrity data in __bio_clone_fast (Ming Lei) [2090940]
- dm-cache: remove __remap_to_origin_clear_discard (Ming Lei) [2090940]
- dm: simplify the single bio fast path in __send_duplicate_bios (Ming Lei) [2090940]
- dm: retun the clone bio from alloc_tio (Ming Lei) [2090940]
- dm: pass the bio instead of tio to __map_bio (Ming Lei) [2090940]
- dm: move cloning the bio into alloc_tio (Ming Lei) [2090940]
- dm: fold __send_duplicate_bios into __clone_and_map_simple_bio (Ming Lei) [2090940]
- dm: fold clone_bio into __clone_and_map_data_bio (Ming Lei) [2090940]
- dm: add a clone_to_tio helper (Ming Lei) [2090940]
- block: make bio_crypt_clone() able to fail (Ming Lei) [2090940]
- perf/x86/uncore: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088831]
- perf/x86/uncore: Clean up uncore_pci_ids[] (Michael Petlan) [2088831]
- perf/x86/uncore: Add Raptor Lake uncore support (Michael Petlan) [2088831]
- perf/x86/cstate: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088831]
- perf/x86/cstate: Add Raptor Lake support (Michael Petlan) [2088831]
- perf/x86/msr: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088831]
- perf/x86/msr: Add Raptor Lake CPU support (Michael Petlan) [2088831]
- perf/x86: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088831]
- perf/x86: Add Intel Raptor Lake support (Michael Petlan) [2088831]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (Michael Petlan) [2088831]
- x86/intel: Add common OPTDIFFs (Michael Petlan) [2088831]
- x86/cpu: Explain Intel model naming convention (Michael Petlan) [2088831]
- KVM: s390: vsie/gmap: reduce gmap_rmap overhead (Thomas Huth) [2072387]
- KVM: s390x: fix SCK locking (Thomas Huth) [2072387]
- s390/kvm: use union tod_clock (Thomas Huth) [2072387]
- s390/time: introduce new store_tod_clock_ext() (Thomas Huth) [2072387]
- s390/time: introduce union tod_clock (Thomas Huth) [2072387]
- KVM: s390: Clarify SIGP orders versus STOP/RESTART (Thomas Huth) [2043868]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Thomas Huth) [2072387]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Thomas Huth) [2072387]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Thomas Huth) [2072387]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Thomas Huth) [2072387]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Thomas Huth) [2072387]
- KVM: s390: add debug statement for diag 318 CPNC data (Thomas Huth) [2072387]
- KVM: s390: pv: properly handle page flags for protected guests (Thomas Huth) [2072387]
- KVM: s390: Add a routine for setting userspace CPU state (Thomas Huth) [2072387]
- net: sfc: ef10: fix memory leak in efx_ef10_mtd_probe() (Íñigo Huguet) [2042840]
- net: sfc: fix memory leak due to ptp channel (Íñigo Huguet) [2042840]
- net: sfc: fix using uninitialized xdp tx_queue (Íñigo Huguet) [2042840]
- sfc: Do not free an empty page_ring (Íñigo Huguet) [2042840]
- net: sfc: add missing xdp queue reinitialization (Íñigo Huguet) [2042840]
- sfc: Avoid NULL pointer dereference on systems without numa awareness (Íñigo Huguet) [2042840]
- sfc: extend the locking on mcdi->seqno (Íñigo Huguet) [2042840]
- sfc: set affinity hints in local NUMA node only (Íñigo Huguet) [2042840]
- sfc: default config to 1 channel/core in local NUMA node only (Íñigo Huguet) [2042840]
- sfc: The size of the RX recycle ring should be more flexible (Íñigo Huguet) [2042840]
- sfc: Use swap() instead of open coding it (Íñigo Huguet) [2042840]
- ethernet/sfc: remove redundant rc variable (Íñigo Huguet) [2042840]
- PCI/ACPI: Allow D3 only if Root Port can signal and wake from D3 (Myron Stowe) [2015785]
- thunderbolt: Do not make DROM read success compulsory (Myron Stowe) [2015785]
- thunderbolt: Do not resume routers if UID is not set (Myron Stowe) [2015785]
- thunderbolt: Retry DROM reads for more failure scenarios (Myron Stowe) [2015785]
- PCI/ACPI: Replace acpi_bus_get_device() with acpi_fetch_acpi_dev() (Myron Stowe) [2015785]
- ACPI: scan: Introduce acpi_fetch_acpi_dev() (Myron Stowe) [2015785]
- PCI: PM: Fix ordering of operations in pci_back_from_sleep() (Myron Stowe) [2015785]
- PCI: PM: Do not call platform_pci_power_manageable() unnecessarily (Myron Stowe) [2015785]
- PCI: PM: Make pci_choose_state() call pci_target_state() (Myron Stowe) [2015785]
- PCI: PM: Rearrange pci_target_state() (Myron Stowe) [2015785]
- PCI: PM: Simplify acpi_pci_power_manageable() (Myron Stowe) [2015785]
- PCI: PM: Drop struct pci_platform_pm_ops (Myron Stowe) [2015785]
- PCI: ACPI: PM: Do not use pci_platform_pm_ops for ACPI (Myron Stowe) [2015785]
- PCI: PM: Do not use pci_platform_pm_ops for Intel MID PM (Myron Stowe) [2015785]
- ACPI: glue: Look for ACPI bus type only if ACPI companion is not known (Myron Stowe) [2015785]
- ACPI: glue: Drop cleanup callback from struct acpi_bus_type (Myron Stowe) [2015785]
- PCI: ACPI: Drop acpi_pci_bus (Myron Stowe) [2015785]
- PCI: ACPI: Check parent pointer in acpi_pci_find_companion() (Myron Stowe) [2015785]
- PCI/ACPI: Don't reset a fwnode set by OF (Myron Stowe) [2015785]
- PCI: VMD: ACPI: Make ACPI companion lookup work for VMD bus (Myron Stowe) [2015785]
- PCI: Change the type of probe argument in reset functions (Myron Stowe) [2015785]
- PCI: Add support for ACPI _RST reset method (Myron Stowe) [2015785]
- PCI: Setup ACPI fwnode early and at the same time with OF (Myron Stowe) [2015785]
- PCI: Use acpi_pci_power_manageable() (Myron Stowe) [2015785]
- PCI: Add pci_set_acpi_fwnode() to set ACPI_COMPANION (Myron Stowe) [2015785]
- PCI: Allow userspace to query and set device reset mechanism (Myron Stowe) [2015785]
- PCI: Remove reset_fn field from pci_dev (Myron Stowe) [2015785]
- PCI: Add array to track reset method ordering (Myron Stowe) [2015785]
- PCI: Add pcie_reset_flr() with 'probe' argument (Myron Stowe) [2015785]
- PCI: Cache PCIe Device Capabilities register (Myron Stowe) [2015785]
- driver core: Split device_platform_notify() (Myron Stowe) [2015785]
- software nodes: Split software_node_notify() (Myron Stowe) [2015785]
- PCI: PM: Enable PME if it can be signaled from D3cold (Myron Stowe) [2015785]
- PCI: PM: Avoid forcing PCI_D0 for wakeup reasons inconsistently (Myron Stowe) [2015785]
- PCI: Use pci_update_current_state() in pci_enable_device_flags() (Myron Stowe) [2015785]
- PCI: Add pci_reset_bus_function() Secondary Bus Reset interface (Myron Stowe) [2015785]
- ACPI: scan: Rearrange code related to acpi_get_device_data() (Myron Stowe) [2015785]
- PCI/ACPI: Whitelist hotplug ports for D3 if power managed by ACPI (Myron Stowe) [2015785]
- crypto: cavium/nitrox - use pcie_flr instead of duplicating it (Myron Stowe) [2015785]
- NFSv4 only print the label when its queried (Scott Mayhew) [2030827]
- NFSv4.1 provide mount option to toggle trunking discovery (Scott Mayhew) [2030827]
- NFSv4.1 test and add 4.1 trunking transport (Scott Mayhew) [2030827]
- SUNRPC allow for unspecified transport time in rpc_clnt_add_xprt (Scott Mayhew) [2030827]
- NFSv4 handle port presence in fs_location server string (Scott Mayhew) [2030827]
- NFSv4 expose nfs_parse_server_name function (Scott Mayhew) [2030827]
- NFSv4.1 query for fs_location attr on a new file system (Scott Mayhew) [2030827]
- NFSv4 store server support for fs_location attribute (Scott Mayhew) [2030827]
- NFSv4 remove zero number of fs_locations entries error check (Scott Mayhew) [2030827]
- NFSv4.1 add network transport when session trunking is detected (Scott Mayhew) [2030827]
- SUNRPC enforce creation of no more than max_connect xprts (Scott Mayhew) [2030827]
- NFSv4 introduce max_connect mount options (Scott Mayhew) [2030827]
- SUNRPC add xps_nunique_destaddr_xprts to xprt_switch_info in sysfs (Scott Mayhew) [2030827]
- SUNRPC keep track of number of transports to unique addresses (Scott Mayhew) [2030827]
- powerpc/papr_scm: Make 'perf_stats' invisible if perf-stats unavailable (Diego Domingos) [1986188]
- powerpc/papr_scm: Fix warnings about undeclared variable (Diego Domingos) [1986188]
- VMCI: Add support for ARM64 (Cathy Avery) [2080095]
- VMCI: Release notification_bitmap in error path (Cathy Avery) [2080095]
- VMCI: Check exclusive_vectors when freeing interrupt 1 (Cathy Avery) [2080095]
- VMCI: Fix some error handling paths in vmci_guest_probe_device() (Cathy Avery) [2080095]
- VMCI: No need to clear memory after a dma_alloc_coherent() call (Cathy Avery) [2080095]
- VMCI: Fix the description of vmci_check_host_caps() (Cathy Avery) [2080095]
- VMCI: dma dg: add support for DMA datagrams receive (Cathy Avery) [2080095]
- VMCI: dma dg: add support for DMA datagrams sends (Cathy Avery) [2080095]
- VMCI: dma dg: allocate send and receive buffers for DMA datagrams (Cathy Avery) [2080095]
- VMCI: dma dg: register dummy IRQ handlers for DMA datagrams (Cathy Avery) [2080095]
- VMCI: dma dg: set OS page size (Cathy Avery) [2080095]
- VMCI: dma dg: whitespace formatting change for vmci register defines (Cathy Avery) [2080095]
- VMCI: dma dg: detect DMA datagram capability (Cathy Avery) [2080095]
- VMCI: Use BIT() macro for bit definitions (Cathy Avery) [2080095]
- VMCI: dma dg: add MMIO access to registers (Cathy Avery) [2080095]
- misc: vmw_vmci: Switch to kvfree_rcu() API (Cathy Avery) [2080095]
- VMCI: fix NULL pointer dereference when unmapping queue pair (Cathy Avery) [2080095]
- misc: vmci: remove redundant variable is_local (Cathy Avery) [2080095]
- misc: vmw_vmci: return the correct errno code (Cathy Avery) [2080095]
- misc: vmw_vmci: explicitly initialize vmci_datagram payload (Cathy Avery) [2080095]
- misc: vmw_vmci: explicitly initialize vmci_notify_bm_set_msg struct (Cathy Avery) [2080095]
- vmci_host: print unexpanded names of ioctl requests in debug messages (Cathy Avery) [2080095]
- drivers/misc/vmw_vmci: restrict too big queue size in qp_host_alloc_queue (Cathy Avery) [2080095]
- VMCI: Enforce queuepair max size for IOCTL_VMCI_QUEUEPAIR_ALLOC (Cathy Avery) [2080095]
- VMCI: Use set_page_dirty_lock() when unregistering guest memory (Cathy Avery) [2080095]
- misc/vmw_vmci: fix typo (Cathy Avery) [2080095]
- misc: vmw_vmci: fix kernel info-leak by initializing dbells in vmci_ctx_get_chkpt_doorbells() (Cathy Avery) [2080095]
- VMCI: check return value of get_user_pages_fast() for errors (Cathy Avery) [2080095]
- vmci_host: get rid of pointless access_ok() (Cathy Avery) [2080095]
- treewide: Add SPDX license identifier - Makefile/Kconfig (Cathy Avery) [2080095]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 321 (Cathy Avery) [2080095]
- VMCI: Use memdup_user() rather than duplicating its implementation (Cathy Avery) [2080095]
- VMCI: remove set but not used variable 'cid' (Cathy Avery) [2080095]
- vmci: type promotion bug in qp_host_get_user_memory() (Cathy Avery) [2080095]

* Fri Jun 10 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-400.el8]
- misc: pvpanic: introduce device capability (Emanuele Giuseppe Esposito) [2088457]
- misc: pvpanic: add crash loaded event (Emanuele Giuseppe Esposito) [2088457]
- misc: pvpanic: move bit definition to uapi header file (Emanuele Giuseppe Esposito) [2088457]
- rfkill: make new event layout opt-in (Jose Ignacio Tornos Martinez) [2023175]
- lib/sbitmap: fix sb->map leak (Ming Lei) [2093549]
- openvswitch: fix OOB access in reserve_sfa_size() (Antoine Tenart) [2082023]
- net: openvswitch: don't send internal clone attribute to the userspace. (Antoine Tenart) [2082023 2085509]
- openvswitch: Add recirc_id to recirc warning (Antoine Tenart) [2082023]
- openvswitch: Fixed nd target mask field in the flow dump. (Antoine Tenart) [2082023]
- net: openvswitch: Remove redundant if statements (Antoine Tenart) [2082023]
- netfilter: nf_tables: disallow non-stateful expression in sets earlier (Phil Sutter) [2092987] {CVE-2022-1966}
- cachefiles: Drop superfluous readpages aops NULL check (Dave Wysochanski) [2083136]
- audit: fix AUDIT_DISABLED undeclared error when AUDITSYSCALL unconfigured (Richard Guy Briggs) [2035123]
- audit: log AUDIT_TIME_* records only from rules (Richard Guy Briggs) [2035123]
- audit: improve audit queue handling when "audit=1" on cmdline (Richard Guy Briggs) [2035123]
- audit: replace zero-length array with flexible-array member (Richard Guy Briggs) [2035123]
- audit: use struct_size() helper in audit_[send|make]_reply() (Richard Guy Briggs) [2035123]
- audit: ensure userspace is penalized the same as the kernel when under pressure (Richard Guy Briggs) [2035123]
- audit: use struct_size() helper in kmalloc() (Richard Guy Briggs) [2035123]
- audit: improve robustness of the audit queue handling (Richard Guy Briggs) [2035123]
- audit: return early if the filter rule has a lower priority (Richard Guy Briggs) [2035123]
- lsm_audit: avoid overloading the "key" audit field (Richard Guy Briggs) [2035123]
- audit: Convert to SPDX identifier (Richard Guy Briggs) [2035123]
- audit: rename struct node to struct audit_node to prevent future name collisions (Richard Guy Briggs) [2035123]
- audit: prepare audit_context for use in calling contexts beyond syscalls (Richard Guy Briggs) [2035123]
- audit: fix possible null-pointer dereference in audit_filter_rules (Richard Guy Briggs) [2035123]
- audit: add header protection to kernel/audit.h (Richard Guy Briggs) [2035123]
- audit: remove unnecessary 'ret' initialization (Richard Guy Briggs) [2035123]
- audit: remove trailing spaces and tabs (Richard Guy Briggs) [2035123]
- audit: Use list_move instead of list_del/list_add (Richard Guy Briggs) [2035123]
- audit: Rename enum audit_state constants to avoid AUDIT_DISABLED redefinition (Richard Guy Briggs) [2035123]
- selftests/bpf: Fix btf_dump test under new clang (Yauheni Kaliuta) [2087050]
- perf: Fix sys_perf_event_open() race against self (Michael Petlan) [2087949]
- scsi: fnic: Finish scsi_cmnd before dropping the spinlock (John Meneghini) [2062905]
- [s390] s390/setup: Fix secure ipl message (Mete Durlu) [2058619]
- perf evlist: Fix failed to use cpu list for uncore events (Michael Petlan) [2088835]
- perf tools: Enable on a list of CPUs for hybrid (Michael Petlan) [2088835]
- perf tools: Create hybrid flag in target (Michael Petlan) [2088835]
- libperf: Add perf_cpu_map__default_new() (Michael Petlan) [2088835]
- drm/i915: Stop force enabling pipe bottom color gammma/csc (Foggy Liu) [2054487]
- blk-mq: fix blk_mq_flush_plug_list (Ming Lei) [2088397]
- kernel/resource: move and rename IORESOURCE_MEM_DRIVER_MANAGED (Nico Pache) [2028988]
- powerpc/numa: Handle partially initialized numa nodes (Nico Pache) [2028988]
- mm: make free_area_init_node aware of memory less nodes (Nico Pache) [2028988]
- mm, memory_hotplug: reorganize new pgdat initialization (Nico Pache) [2028988]
- mm, memory_hotplug: drop arch_free_nodedata (Nico Pache) [2028988]
- mm: handle uninitialized numa nodes gracefully (Nico Pache) [2028988]
- mm, memory_hotplug: make arch_alloc_nodedata independent on CONFIG_MEMORY_HOTPLUG (Nico Pache) [2028988]
- kexec_file: don't place kexec images on IORESOURCE_MEM_DRIVER_MANAGED (Nico Pache) [2028988]
- mm/memory_hotplug: handle memblock_add_node() failures in add_memory_resource() (Nico Pache) [2028988]
- mm/memory_hotplug: introduce add_memory_driver_managed() (Nico Pache) [2028988]
- mm/memory_hotplug: handle memblocks only with CONFIG_ARCH_KEEP_MEMBLOCK (Nico Pache) [2028988]
- mm/memory_hotplug: set node_start_pfn of hotadded pgdat to 0 (Nico Pache) [2028988]
- mm/hotplug: reorder memblock_[free|remove]() calls in try_remove_memory() (Nico Pache) [2028988]
- mm: memblock: make keeping memblock memory opt-in rather than opt-out (Nico Pache) [2028988]
- [s390] s390/cpumf: add new extended counter set for IBM z16 (Mete Durlu) [2047728]

* Wed Jun 08 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-399.el8]
- [s390] s390/qdio: clarify logical vs absolute in QIB's kerneldoc (Mete Durlu) [2043836]
- [s390] s390/qdio: remove unneeded sanity check in qdio_do_sqbs() (Mete Durlu) [2043836]
- [s390] s390/qdio: split do_QDIO() (Mete Durlu) [2043836]
- [s390] s390/qdio: split qdio_inspect_queue() (Mete Durlu) [2043836]
- [s390] s390/qdio: clarify handler logic for qdio_handle_activate_check() (Mete Durlu) [2043836]
- [s390] s390/qdio: clean up access to queue in qdio_handle_activate_check() (Mete Durlu) [2043836]
- [s390] s390/qdio: avoid allocating the qdio_irq with GFP_DMA (Mete Durlu) [2043836]
- [s390] s390/qdio: improve handling of CIWs (Mete Durlu) [2043836]
- [s390] s390/qdio: remove QDIO_SBAL_SIZE macro (Mete Durlu) [2043836]
- [s390] scsi: zfcp: fix kernel doc comments (Mete Durlu) [2043836]
- [s390] s390/qdio: remove unused support for SLIB parameters (Mete Durlu) [2043836]
- [s390] s390/qdio: consolidate QIB code (Mete Durlu) [2043836]
- [s390] s390/qdio: use dev_info() in qdio_print_subchannel_info() (Mete Durlu) [2043836]
- [s390] s390/qdio: fine-tune the queue sync (Mete Durlu) [2043836]
- [s390] s390/qdio: clean up SIGA capability tracking (Mete Durlu) [2043836]
- [s390] s390/qdio: remove unused sync-after-IRQ infrastructure (Mete Durlu) [2043836]
- [s390] s390/qdio: use absolute data address in ESTABLISH ccw (Mete Durlu) [2043836]
- [s390] s390/qdio: remove unused macros (Mete Durlu) [2043836]
- [s390] s390/qdio: clarify reporting of errors to the drivers (Mete Durlu) [2043836]
- [s390] s390/qdio: remove unneeded siga-sync for Output Queue (Mete Durlu) [2043836]
- [s390] s390/qdio: remove remaining tasklet & timer code (Mete Durlu) [2043836]
- ice: clear stale Tx queue settings before configuring (Petr Oros) [2079926]
- ice: fix crash when writing timestamp on RX rings (Petr Oros) [2079926]
- ice: Fix race during aux device (un)plugging (Petr Oros) [2079926]
- ice: fix PTP stale Tx timestamps cleanup (Petr Oros) [2079926]
- ice: ice_sched: fix an incorrect NULL check on list iterator (Petr Oros) [2079926]
- ice: fix use-after-free when deinitializing mailbox snapshot (Petr Oros) [2079926]
- ice: wait 5 s for EMP reset after firmware flash (Petr Oros) [2079926]
- ice: Protect vf_state check by cfg_lock in ice_vc_process_vf_msg() (Petr Oros) [2079926]
- ice: Fix incorrect locking in ice_vc_process_vf_msg() (Petr Oros) [2079926]
- ice: Fix memory leak in ice_get_orom_civd_data() (Petr Oros) [2079926]
- ice: fix crash in switchdev mode (Petr Oros) [2079926]
- Revert "iavf: Fix deadlock occurrence during resetting VF interface" (Petr Oros) [2079926]
- ice: arfs: fix use-after-free when freeing @rx_cpu_rmap (Petr Oros) [2079926]
- ice: clear cmd_type_offset_bsz for TX rings (Petr Oros) [2079926]
- ice: xsk: fix VSI state check in ice_xsk_wakeup() (Petr Oros) [2079926]
- ice: synchronize_rcu() when terminating rings (Petr Oros) [2079926]
- ice: Do not skip not enabled queues in ice_vc_dis_qs_msg (Petr Oros) [2079926]
- ice: Set txq_teid to ICE_INVAL_TEID on ring creation (Petr Oros) [2079926]
- ice: Fix broken IFF_ALLMULTI handling (Petr Oros) [2079926]
- ice: Fix MAC address setting (Petr Oros) [2079926]
- redhat/configs: Remove CONFIG_MFD_INTEL_PMT (Prarit Bhargava) [2058805]
- redhat/configs: Add CONFIG_INTEL_VSEC (Prarit Bhargava) [2058805]
- platform/x86/intel: Move intel_pmt from MFD to Auxiliary Bus (Prarit Bhargava) [2058805]
- PCI: Add #defines for accessing PCIe DVSEC fields (Prarit Bhargava) [2058805]
- platform/x86: intel_pmt_telemetry: Ignore zero sized entries (Prarit Bhargava) [2058805]
- platform/x86/intel: pmt: Use y instead of objs in Makefile (Prarit Bhargava) [2058805]
- platform/x86/intel: Move Intel PMT drivers to new subfolder (Prarit Bhargava) [2058805]
- dlm: fix plock invalid read (Alexander Aring) [2053095]
- NFS: LOOKUP_DIRECTORY is also ok with symlinks (Scott Mayhew) [2059727]
- NFSv4: nfs_atomic_open() can race when looking up a non-regular file (Scott Mayhew) [2059727]
- NFSv4: Handle case where the lookup of a directory fails (Scott Mayhew) [2059727]
- redhat: always tag non-maintainer builds with .gXXXX (Jarod Wilson)
- mm, compaction: fast_find_migrateblock() should return pfn in the target zone (Rafael Aquini) [2067130]
- [s390] s390/pci: expose a PCI device's UID as its index (Mete Durlu) [1939916]
- [s390] s390/pci: expose UID uniqueness guarantee (Mete Durlu) [1939916]
- [s390] s390/pci: Documentation for zPCI (Mete Durlu) [1939916]
- powerpc/fadump: print start of preserved area (Diego Domingos) [2075092]
- powerpc/fadump: align destination address to pagesize (Diego Domingos) [2075092]
- powerpc/fadump: fix PT_LOAD segment for boot memory area (Diego Domingos) [2075092]
- dmaengine: idxd: make idxd_wq_enable() return 0 if wq is already enabled (Jerry Snitselaar) [2083414]
- dmaengine: idxd: Remove unnecessary synchronize_irq() before free_irq() (Jerry Snitselaar) [2083414]
- dmaengine: idxd: add missing callback function to support DMA_INTERRUPT (Jerry Snitselaar) [2083414]
- dmaengine: idxd: skip irq free when wq type is not kernel (Jerry Snitselaar) [2083414]
- dmaengine: idxd: make idxd_register/unregister_dma_channel() static (Jerry Snitselaar) [2083414]
- dmaengine: idxd: remove redudant idxd_wq_disable_cleanup() call (Jerry Snitselaar) [2083414]
- dmaengine: idxd: free irq before wq type is reset (Jerry Snitselaar) [2083414]
- dmaengine: idxd: fix lockdep warning on device driver removal (Jerry Snitselaar) [2083414]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2083414]
- dmaengine: idxd: refactor wq driver enable/disable operations (Jerry Snitselaar) [2083414]
- dmaengine: idxd: move wq irq enabling to after device enable (Jerry Snitselaar) [2083414]
- dmaengine: idxd: set max_xfer and max_batch for RO device (Jerry Snitselaar) [2083414]
- dmaengine: idxd: Fix the error handling path in idxd_cdev_register() (Jerry Snitselaar) [2083414]
- dmaengine: idxd: set DMA_INTERRUPT cap bit (Jerry Snitselaar) [2083414]
- dmaengine: add verification of DMA_INTERRUPT capability for dmatest (Jerry Snitselaar) [2083414]
- dmaengine: idxd: remove trailing white space on input str for wq name (Jerry Snitselaar) [2083414]
- dmaengine: idxd: don't load pasid config until needed (Jerry Snitselaar) [2083414]
- dmaengine: idxd: fix retry value to be constant for duration of function call (Jerry Snitselaar) [2075705]
- dmaengine: idxd: match type for retries var in idxd_enqcmds() (Jerry Snitselaar) [2075705]
- net: mana: Reuse XDP dropped page (Mohammed Gamal) [2086556]
- net: mana: Add counter for XDP_TX (Mohammed Gamal) [2086556]
- net: mana: Add counter for packet dropped by XDP (Mohammed Gamal) [2086556]
- net: mana: Use struct_size() helper in mana_gd_create_dma_region() (Mohammed Gamal) [2086556]
- SUNRPC release the transport of a relocated task with an assigned transport (Scott Mayhew) [2023840]
- SUNRPC: Do not dereference non-socket transports in sysfs (Scott Mayhew) [2023840]
- SUNRPC don't resend a task on an offlined transport (Scott Mayhew) [2023840]
- SUNRPC: lock against ->sock changing during sysfs read (Scott Mayhew) [2023840]
- SUNRPC: Check if the xprt is connected before handling sysfs reads (Scott Mayhew) [2023840]
- SUNRPC: Add dst_port to the sysfs xprt info file (Scott Mayhew) [2023840]
- SUNRPC: Add srcaddr as a file in sysfs (Scott Mayhew) [2023840]
- sunrpc: Fix return value of get_srcport() (Scott Mayhew) [2023840]
- sunrpc: remove an offlined xprt using sysfs (Scott Mayhew) [2023840]
- sunrpc: display xprt's queuelen of assigned tasks via sysfs (Scott Mayhew) [2023840]
- SUNRPC: take a xprt offline using sysfs (Scott Mayhew) [2023840]
- SUNRPC for TCP display xprt's source port in sysfs xprt_info (Scott Mayhew) [2023840]
- SUNRPC query transport's source port (Scott Mayhew) [2023840]
- SUNRPC display xprt's main value in sysfs's xprt_info (Scott Mayhew) [2023840]
- SUNRPC mark the first transport (Scott Mayhew) [2023840]
- NFSv4.1 identify and mark RPC tasks that can move between transports (Scott Mayhew) [2023840]
- sunrpc: provide showing transport's state info in the sysfs directory (Scott Mayhew) [2023840]
- sunrpc: provide multipath info in the sysfs directory (Scott Mayhew) [2023840]
- sunrpc: provide transport info in the sysfs directory (Scott Mayhew) [2023840]
- sunrpc: add dst_attr attributes to the sysfs xprt directory (Scott Mayhew) [2023840]
- sunrpc: add add sysfs directory per xprt under each xprt_switch (Scott Mayhew) [2023840]
- sunrpc: add a symlink from rpc-client directory to the xprt_switch (Scott Mayhew) [2023840]
- sunrpc: add xprt_switch direcotry to sunrpc's sysfs (Scott Mayhew) [2023840]
- sunrpc: keep track of the xprt_class in rpc_xprt structure (Scott Mayhew) [2023840]
- sunrpc: add IDs to multipath (Scott Mayhew) [2023840]
- sunrpc: add xprt id (Scott Mayhew) [2023840]
- sunrpc: Create per-rpc_clnt sysfs kobjects (Scott Mayhew) [2023840]
- sunrpc: Create a client/ subdirectory in the sunrpc sysfs (Scott Mayhew) [2023840]
- sunrpc: Create a sunrpc directory under /sys/kernel/ (Scott Mayhew) [2023840]
- vfs: check fd has read access in kernel_read_file_from_fd() (Ian Kent) [2040615]
- SUNRPC: Fix NFSD's request deferral on RDMA transports (Benjamin Coddington) [2090525]
- vdpa/mlx5: Use consistent RQT size (Cindy Lu) [2063108]
- vdpa/mlx5: add validation for VIRTIO_NET_CTRL_MQ_VQ_PAIRS_SET command (Cindy Lu) [2063108]
- vdpa/mlx5: should verify CTRL_VQ feature exists for MQ (Cindy Lu) [2063108]
- gfs2: Stop using glock holder auto-demotion for now (Andreas Gruenbacher) [2054855]
- gfs2: buffered write prefaulting (Andreas Gruenbacher) [2054855]
- gfs2: Align read and write chunks to the page cache (Andreas Gruenbacher) [2054855]
- gfs2: Pull return value test out of should_fault_in_pages (Andreas Gruenbacher) [2054855]
- gfs2: Clean up use of fault_in_iov_iter_{read,write}able (Andreas Gruenbacher) [2054855]
- gfs2: Variable rename (Andreas Gruenbacher) [2054855]
- gfs2: Fix filesystem block deallocation for short writes (Andreas Gruenbacher) [2054855]
- iomap: iomap_write_end cleanup (Andreas Gruenbacher) [2054855]
- iomap: iomap_write_failed fix (Andreas Gruenbacher) [2054855]
- gfs2: Don't re-check for write past EOF unnecessarily (Andreas Gruenbacher) [2054855]
- gfs2: No short reads or writes upon glock contention (Andreas Gruenbacher) [2054855]
- fs/iomap: Fix buffered write page prefaulting (Andreas Gruenbacher) [2054855]
- generic_perform_write()/iomap_write_actor(): saner logics for short copy (Andreas Gruenbacher) [2054855]
- iomap: Convert iomap_write_end types (Andreas Gruenbacher) [2054855]
- gfs2: Make sure not to return short direct writes (Andreas Gruenbacher) [2054855]
- gfs2: Remove dead code in gfs2_file_read_iter (Andreas Gruenbacher) [2054855]
- gfs2: Fix gfs2_file_buffered_write endless loop workaround (Andreas Gruenbacher) [2054855]
- gfs2: Minor retry logic cleanup (Andreas Gruenbacher) [2054855]
- gfs2: Disable page faults during lockless buffered reads (Andreas Gruenbacher) [2054855]
- gfs2: Fix should_fault_in_pages() logic (Andreas Gruenbacher) [2054855]
- mm: gup: make fault_in_safe_writeable() use fixup_user_fault() (Andreas Gruenbacher) [2054855]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2054855]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2054855]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2054855]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2054855]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2054855]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2054855]
- gfs2: Fix gfs2_release for non-writers regression (Bob Peterson) [1955591]
- gfs2: gfs2_create_inode rework (Andreas Gruenbacher) [1955591]
- gfs2: gfs2_inode_lookup rework (Andreas Gruenbacher) [1955591]
- gfs2: gfs2_inode_lookup cleanup (Andreas Gruenbacher) [1955591]
- gfs2: Fix remote demote of weak glock holders (Andreas Gruenbacher) [1955591]
- gfs2: Fix glock_hash_walk bugs (Andreas Gruenbacher) [1955591]
- gfs2: Cancel remote delete work asynchronously (Bob Peterson) [1955591]
- gfs2: set glock object after nq (Bob Peterson) [1955591]
- gfs2: remove RDF_UPTODATE flag (Bob Peterson) [1955591]
- gfs2: Eliminate GIF_INVALID flag (Bob Peterson) [1955591]
- gfs2: Fix atomic bug in gfs2_instantiate (Andreas Gruenbacher) [1955591]
- gfs2: fix GL_SKIP node_scope problems (Bob Peterson) [1955591]
- gfs2: Add some flags missing from glock output (Bob Peterson) [1955591]
- gfs2: split glock instantiation off from do_promote (Bob Peterson) [1955591]
- gfs2: further simplify do_promote (Bob Peterson) [1955591]
- gfs2: re-factor function do_promote (Bob Peterson) [1955591]
- gfs2: Remove 'first' trace_gfs2_promote argument (Andreas Gruenbacher) [1955591]
- gfs2: change go_lock to go_instantiate (Bob Peterson) [1955591]
- gfs2: Switch some BUG_ON to GLOCK_BUG_ON for debug (Bob Peterson) [1955591]
- gfs2: move GL_SKIP check from glops to do_promote (Bob Peterson) [1955591]
- gfs2: Add GL_SKIP holder flag to dump_holder (Bob Peterson) [1955591]
- gfs2: remove redundant check in gfs2_rgrp_go_lock (Bob Peterson) [1955591]
- gfs2: Fix mmap + page fault deadlocks for direct I/O (Andreas Gruenbacher) [1955591]
- iov_iter: Introduce ITER_IOVEC_FLAG_NOFAULT flag to disable page faults (Andreas Gruenbacher) [1955591]
- gup: Introduce FOLL_NOFAULT flag to disable page faults (Andreas Gruenbacher) [1955591]
- iomap: Add done_before argument to iomap_dio_rw (Andreas Gruenbacher) [1955591]
- iomap: Support partial direct I/O on user copy failures (Andreas Gruenbacher) [1955591]
- iomap: Fix iomap_dio_rw return value for user copies (Andreas Gruenbacher) [1955591]
- iomap: support reading inline data from non-zero pos (Andreas Gruenbacher) [1955591]
- gfs2: Only dereference i->iov when iter_is_iovec(i) (Andreas Gruenbacher) [1955591]
- gfs2: Prevent endless loops in gfs2_file_buffered_write (Andreas Gruenbacher) [1955591]
- gfs2: Fix mmap + page fault deadlocks for buffered I/O (Andreas Gruenbacher) [1955591]
- gfs2: Eliminate ip->i_gh (Andreas Gruenbacher) [1955591]
- gfs2: Move the inode glock locking to gfs2_file_buffered_write (Andreas Gruenbacher) [1955591]
- gfs2: Fix "Introduce flag for glock holder auto-demotion" (Andreas Gruenbacher) [1955591]
- gfs2: Introduce flag for glock holder auto-demotion (Bob Peterson) [1955591]
- gfs2: fix scheduling while atomic bug in glocks (Bob Peterson) [1955591]
- gfs2: Clean up function may_grant (Andreas Gruenbacher) [1955591]
- gfs2: Add wrapper for iomap_file_buffered_write (Andreas Gruenbacher) [1955591]
- iov_iter: Introduce fault_in_iov_iter_writeable (Andreas Gruenbacher) [1955591]
- iov_iter: Turn iov_iter_fault_in_readable into fault_in_iov_iter_readable (Andreas Gruenbacher) [1955591]
- gup: Turn fault_in_pages_{readable,writeable} into fault_in_{readable,writeable} (Andreas Gruenbacher) [1955591]
- powerpc/signal64: Don't opencode page prefaulting (Andreas Gruenbacher) [1955591]
- sanitize iov_iter_fault_in_readable() (Andreas Gruenbacher) [1955591]
- [xarray] iov_iter_fault_in_readable() should do nothing in xarray case (Andreas Gruenbacher) [1955591]
- powerpc/kvm: Fix kvm_use_magic_page (Andreas Gruenbacher) [1955591]
- iov_iter: Fix iov_iter_get_pages{,_alloc} page fault return value (Andreas Gruenbacher) [1955591]
- gfs2: Fix length of holes reported at end-of-file (Andreas Gruenbacher) [1955591]
- gfs2: Remove redundant check from gfs2_glock_dq (Bob Peterson) [1955591]
- gfs2: release iopen glock early in evict (Bob Peterson) [1955591]
- mm: change fault_in_pages_* to have an unsigned size parameter (Andreas Gruenbacher) [1955591]
- gfs2: Eliminate vestigial HIF_FIRST (Bob Peterson) [1955591]
- iomap: remove the iomap arguments to ->page_{prepare,done} (Andreas Gruenbacher) [1955591]
- net: sched: fix use-after-free in tc_new_tfilter() (Ivan Vecera) [2071704]

* Fri Jun 03 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-398.el8]
- Bluetooth: virtio_bt: fix memory leak in virtbt_rx_handle() (Gopal Tiwari) [2076180]
- powerpc/papr_scm: Fix buffer overflow issue with CONFIG_FORTIFY_SOURCE (Gustavo Walbon) [2069468]
- powerpc/papr_scm: Fix build failure when (Gustavo Walbon) [2069468]
- drivers/nvdimm: Fix build failure when CONFIG_PERF_EVENTS is not set (Gustavo Walbon) [2069468]
- powerpc/papr_scm: Add perf interface support (Gustavo Walbon) [2069468]
- drivers/nvdimm: Add perf interface to expose nvdimm performance stats (Gustavo Walbon) [2069468]
- drivers/nvdimm: Add nvdimm pmu structure (Gustavo Walbon) [2069468]
- mptcp: Fix crash due to tcp_tsorted_anchor was initialized before release skb (Davide Caratti) [2084048]
- mptcp: Correctly set DATA_FIN timeout when number of retransmits is large (Davide Caratti) [2084048]
- mptcp: add mibs counter for ignored incoming options (Davide Caratti) [2084048]
- mptcp: fix race in incoming ADD_ADDR option processing (Davide Caratti) [2084048]
- mptcp: netlink: process IPv6 addrs in creating listening sockets (Davide Caratti) [2084048]
- mptcp: use delegate action to schedule 3rd ack retrans (Davide Caratti) [2084048]
- mptcp: fix delack timer (Davide Caratti) [2084048]
- powerpc/module_64: use module_init_section instead of patching names (Jan Stancek) [1985851]
- module: check for exit sections in layout_sections() instead of module_init_section() (Jan Stancek) [1985851]
- module: treat exit sections the same as init sections when !CONFIG_MODULE_UNLOAD (Jan Stancek) [1985851]
- module: allow arch overrides for .exit section names (Jan Stancek) [1985851]
- ARM: 8976/1: module: allow arch overrides for .init section names (Jan Stancek) [1985851]
- KVM: s390: pv: make use of ultravisor AIV support (Thomas Huth) [2043870]
- redhat: Enable VM kselftests (Nico Pache) [1978539]
- selftests: vm: Makefile: rename TARGETS to VMTARGETS (Nico Pache) [1978539]
- redhat: enable CONFIG_TEST_VMALLOC for vm selftests (Nico Pache) [1978539]
- redhat: enable GUP TEST for kselftests (Nico Pache) [1978539]
- redhat: Enable HMM test to be used by the kselftest test suite (Nico Pache) [1978539]
- selftests/vm/pkeys: fix alloc_random_pkey() to make it really, really random (Nico Pache) [1978539]
- selftests/vm: fix display of page size in map_hugetlb (Nico Pache) [1978539]
- selftests/vm: fix building protection keys test (Nico Pache) [1978539]
- lib/test_vmalloc.c: do not create cpumask_t variable on stack (Nico Pache) [1978539]
- vmalloc: add test driver to analyse vmalloc allocator (Nico Pache) [1978539]
- vmalloc: export __vmalloc_node_range for CONFIG_TEST_VMALLOC_MODULE (Nico Pache) [1978539]
- selftests/vm: add protection_keys_32 / protection_keys_64 to gitignore (Nico Pache) [1978539]
- selftests/vm: rename file run_vmtests to run_vmtests.sh (Nico Pache) [1978539]
- mm/gup_benchmark: support threading (Nico Pache) [1978539]
- selftests/vm: gup_test: test faulting in kernel, and verify pinnable pages (Nico Pache) [1978539]
- selftests/vm: gup_test: fix test flag (Nico Pache) [1978539]
- selftests/vm: fix out-of-tree build (Nico Pache) [1978539]
- selftests/vm: 2x speedup for run_vmtests.sh (Nico Pache) [1978539]
- selftests/vm: hmm-tests: remove the libhugetlbfs dependency (Nico Pache) [1978539]
- selftests/vm: run_vmtests.sh: update and clean up gup_test invocation (Nico Pache) [1978539]
- selftests/vm: gup_test: introduce the dump_pages() sub-test (Nico Pache) [1978539]
- selftests/vm: only some gup_test items are really benchmarks (Nico Pache) [1978539]
- selftests/vm: minor cleanup: Makefile and gup_test.c (Nico Pache) [1978539]
- selftests/vm: rename run_vmtests --> run_vmtests.sh (Nico Pache) [1978539]
- selftests/vm: use a common gup_test.h (Nico Pache) [1978539]
- mm/gup_benchmark: rename to mm/gup_test (Nico Pache) [1978539]
- tools/testing/selftests/vm: fix build error (Nico Pache) [1978539]
- selftests: vm: add fragment CONFIG_GUP_BENCHMARK (Nico Pache) [1978539]
- selftests/vm: 8x compaction_test speedup (Nico Pache) [1978539]
- selftests/vm: fix incorrect gcc invocation in some cases (Nico Pache) [1978539]
- selftests/vm: fix false build success on the second and later attempts (Nico Pache) [1978539]
- mm/gup: don't permit users to call get_user_pages with FOLL_LONGTERM (Nico Pache) [1978539]
- mm/gup_benchmark: use pin_user_pages for FOLL_LONGTERM flag (Nico Pache) [1978539]
- mm/gup_benchmark: update the documentation in Kconfig (Nico Pache) [1978539]
- khugepaged: selftests: fix timeout condition in wait_for_scan() (Nico Pache) [1978539]
- selftests: vm: pkeys: fix multilib builds for x86 (Nico Pache) [1978539]
- selftests: vm: pkeys: use the correct page size on powerpc (Nico Pache) [1978539]
- selftests/vm/pkeys: override access right definitions on powerpc (Nico Pache) [1978539]
- selftests/vm/pkeys: test correct behaviour of pkey-0 (Nico Pache) [1978539]
- selftests/vm/pkeys: introduce a sub-page allocator (Nico Pache) [1978539]
- selftests/vm/pkeys: detect write violation on a mapped access-denied-key page (Nico Pache) [1978539]
- selftests/vm/pkeys: associate key on a mapped page and detect write violation (Nico Pache) [1978539]
- selftests/vm/pkeys: associate key on a mapped page and detect access violation (Nico Pache) [1978539]
- selftests/vm/pkeys: improve checks to determine pkey support (Nico Pache) [1978539]
- selftests/vm/pkeys: fix assertion in test_pkey_alloc_exhaust() (Nico Pache) [1978539]
- selftests/vm/pkeys: fix number of reserved powerpc pkeys (Nico Pache) [1978539]
- selftests/vm/pkeys: introduce powerpc support (Nico Pache) [1978539]
- selftests/vm/pkeys: introduce generic pkey abstractions (Nico Pache) [1978539]
- selftests: vm: pkeys: use the correct huge page size (Nico Pache) [1978539]
- selftests/vm/pkeys: fix alloc_random_pkey() to make it really random (Nico Pache) [1978539]
- selftests/vm/pkeys: fix assertion in pkey_disable_set/clear() (Nico Pache) [1978539]
- selftests/vm/pkeys: fix pkey_disable_clear() (Nico Pache) [1978539]
- selftests: vm: pkeys: add helpers for pkey bits (Nico Pache) [1978539]
- selftests: vm: pkeys: Use sane types for pkey register (Nico Pache) [1978539]
- selftests/vm/pkeys: make gcc check arguments of sigsafe_printf() (Nico Pache) [1978539]
- selftests/vm/pkeys: move some definitions to arch-specific header (Nico Pache) [1978539]
- selftests/vm/pkeys: move generic definitions to header file (Nico Pache) [1978539]
- selftests/vm/pkeys: rename all references to pkru to a generic name (Nico Pache) [1978539]
- selftests/x86/pkeys: move selftests to arch-neutral directory (Nico Pache) [1978539]
- selftests/vm: 10x speedup for hmm-tests (Nico Pache) [1978539]
- mm/migrate: add migrate-shared test for migrate_vma_*() (Nico Pache) [1978539]
- mm/migrate: optimize migrate_vma_setup() for holes (Nico Pache) [1978539]
- lib/test_hmm: use vma_lookup() in dmirror_migrate() (Nico Pache) [1978539]
- lib/test_hmm.c: fix an error code in dmirror_allocate_chunk() (Nico Pache) [1978539]
- lib/test_hmm.c: remove unused dmirror_zero_page (Nico Pache) [1978539]
- mm/memremap_pages: support multiple ranges per invocation (Nico Pache) [1978539]
- mm/memremap_pages: convert to 'struct range' (Nico Pache) [1978539]
- tools/testing/selftests/vm/hmm-tests.c: use the new SKIP() macro (Nico Pache) [1978539]
- mm/hmm/test: use the new migration invalidation (Nico Pache) [1978539]
- lib/test_hmm.c: add a flag parameter to migrate_vma (Nico Pache) [1978539]
- mm/hmm: add tests for hmm_pfn_to_map_order() (Nico Pache) [1978539]
- lib: fix test_hmm.c reference after free (Nico Pache) [1978539]
- mm/hmm/test: add selftests for HMM (Nico Pache) [1978539]
- mm/hmm/test: add selftest driver for HMM (Nico Pache) [1978539]
- mm: convert insert_pfn() to vm_fault_t (Nico Pache) [1978539]
- selftests/vm/.gitignore: add mremap_dontunmap (Nico Pache) [1978539]
- selftests: vm: Fix 64-bit test builds for powerpc64le (Nico Pache) [1978539]
- selftests: vm: Do not override definition of ARCH (Nico Pache) [1978539]
- selftests/vm: fix map_hugetlb length used for testing read and write (Nico Pache) [1978539]
- selftests/vm: add missed tests in run_vmtests (Nico Pache) [1978539]
- selftests: vm: add fragment CONFIG_TEST_VMALLOC (Nico Pache) [1978539]
- selftests: vm: Build/Run 64bit tests only on 64bit arch (Nico Pache) [1978539]
- selftests: vm: Fix test build failure when built by itself (Nico Pache) [1978539]
- selftests: vm: install test_vmalloc.sh for run_vmtests (Nico Pache) [1978539]
- tools: mark 'test_vmalloc.sh' executable (Nico Pache) [1978539]
- tools/selftest/vm: allow choosing mem size and page size in map_hugetlb (Nico Pache) [1978539]
- selftests/vm: add script helper for CONFIG_TEST_VMALLOC_MODULE (Nico Pache) [1978539]
- tools/testing/selftests/vm/map_fixed_noreplace.c: add test for MAP_FIXED_NOREPLACE (Nico Pache) [1978539]
- tools/testing/selftests/vm/: add MAP_POPULATE test (Nico Pache) [1978539]
- xfs: return errors in xfs_fs_sync_fs (Andrey Albershteyn) [2087991]
- vfs: make sync_filesystem return errors from ->sync_fs (Andrey Albershteyn) [2087991]
- PCI: hv: Remove unused hv_set_msi_entry_from_desc() (Mohammed Gamal) [2086560]
- PCI: hv: Avoid the retarget interrupt hypercall in irq_unmask() on ARM64 (Mohammed Gamal) [2086560]
- PCI: hv: Fix NUMA node assignment when kernel boots with custom NUMA topology (Mohammed Gamal) [2086560]
- PCI: hv: Use PCI_ERROR_RESPONSE to identify config read errors (Mohammed Gamal) [2086560]
- vdpa: clean up get_config_size ret value handling (Cindy Lu) [2059841]
- vdpa: mlx5: synchronize driver status with CVQ (Jason Wang) [2048009]
- vdpa: mlx5: prevent cvq work from hogging CPU (Jason Wang) [2048009]
- vdpa/mlx5: Avoid processing works if workqueue was destroyed (Cindy Lu) [2048009]
- cpufreq: Cancel policy update work scheduled before freeing (Prarit Bhargava) [2083728]
- tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT (Paolo Abeni) [2081411]
- tcp: ensure to use the most recently sent skb when filling the rate sample (Paolo Abeni) [2081411]
- tcp: make sure treq->af_specific is initialized (Paolo Abeni) [2081411]
- tcp: md5: incorrect tcp_header_len for incoming connections (Paolo Abeni) [2081411]
- tcp: ensure PMTU updates are processed during fastopen (Paolo Abeni) [2081411]
- tcp: add missing tcp_skb_can_collapse() test in tcp_shift_skb_data() (Paolo Abeni) [2081411]
- inet: fully convert sk->sk_rx_dst to RCU rules (Paolo Abeni) [2081411]
- tcp_cubic: fix spurious Hystart ACK train detections for not-cwnd-limited flows (Paolo Abeni) [2081411]

* Tue May 31 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-397.el8]
- selftests/bpf/test_xdp_redirect_multi: use temp netns for testing (Felix Maurer) [2017875]
- selftests/bpf/xdp_redirect_multi: Limit the tests in netns (Jiri Benc) [2017875]
- selftests/bpf/xdp_redirect_multi: Give tcpdump a chance to terminate cleanly (Jiri Benc) [2017875]
- selftests/bpf/xdp_redirect_multi: Use arping to accurate the arp number (Jiri Benc) [2017875]
- selftests/bpf/xdp_redirect_multi: Put the logs to tmp folder (Jiri Benc) [2017875]
- bpf, sockmap: Zap ingress queues after stopping strparser (Jiri Benc) [2017875]
- xdp, net: Fix use-after-free in bpf_xdp_link_release (Jiri Benc) [2017875]
- doc, af_xdp: Fix bind flags option typo (Jiri Benc) [2017875]
- bpf, devmap: Convert remaining READ_ONCE() to rcu_dereference_check() (Jiri Benc) [2017875]
- xdp: Move the rxq_info.mem clearing to unreg_mem_model() (Jiri Benc) [2017875]
- bpf, sched: Remove unneeded rcu_read_lock() around BPF program invocation (Jiri Benc) [2017875]
- xdp: Add proper __rcu annotations to redirect map entries (Jiri Benc) [2017875]
- doc: Give XDP as example of non-obvious RCU reader/updater pairing (Jiri Benc) [2017875]
- doc: Clarify and expand RCU updaters and corresponding readers (Jiri Benc) [2017875]
- bpfilter: Specify the log level for the kmsg message (Jiri Benc) [2017875]
- docs, af_xdp: Consistent indentation in examples (Jiri Benc) [2017875]
- xsk: Fix missing validation for skb and unaligned mode (Jiri Benc) [2017875]
- bpf: Support all gso types in bpf_skb_change_proto() (Jiri Benc) [2017875]
- bpf: Do not change gso_size during bpf_skb_change_proto() (Jiri Benc) [2017875]
- Revert "bpf: Check for BPF_F_ADJ_ROOM_FIXED_GSO when bpf_skb_change_proto" (Jiri Benc) [2017875]
- selftests/bpf: Add xdp_redirect_multi into .gitignore (Jiri Benc) [2017875]
- bpf, devmap: Remove drops variable from bq_xmit_all() (Jiri Benc) [2017875]
- locking/atomic: net: use linux/atomic.h for xchg & cmpxchg (Jiri Benc) [2017875]
- xsk: Use kvcalloc to support large umems (Jiri Benc) [2017875]
- selftests/bpf: Add xdp_redirect_multi test (Jiri Benc) [2017875]
- sample/bpf: Add xdp_redirect_map_multi for redirect_map broadcast test (Jiri Benc) [2017875]
- xdp: Extend xdp_redirect_map with broadcast support (Jiri Benc) [2017875]
- bpf: Let bpf_warn_invalid_xdp_action() report more info (Felix Maurer) [2017875]
- bpf: Run devmap xdp_prog on flush instead of bulk enqueue (Jiri Benc) [2017875]
- skmsg: Remove unused parameters of sk_msg_wait_data() (Jiri Benc) [2017875]
- bpf: Use struct_size() in kzalloc() (Jiri Benc) [2017875]
- bpf: Check for BPF_F_ADJ_ROOM_FIXED_GSO when bpf_skb_change_proto (Jiri Benc) [2017875]
- treewide: Replace zero-length arrays with flexible-array members (Tomas Henzl) [2049660]
- scsi: mpi3mr: Bump driver version to 8.0.0.68.0 (Tomas Henzl) [2049660]
- scsi: mpi3mr: Update the copyright year (Tomas Henzl) [2049660]
- scsi: mpi3mr: Update MPI3 headers (Tomas Henzl) [2049660]
- scsi: mpi3mr: Fix formatting problems in some kernel-doc comments (Tomas Henzl) [2049660]
- scsi: mpi3mr: Fix some spelling mistakes (Tomas Henzl) [2049660]
- scsi: mpi3mr: Bump driver version to 8.0.0.61.0 (Tomas Henzl) [2049660]
- scsi: mpi3mr: Add io_uring interface support in I/O-polled mode (Tomas Henzl) [2049660]
- scsi: mpi3mr: Print cable mngnt and temp threshold events (Tomas Henzl) [2049660]
- scsi: mpi3mr: Support Prepare for Reset event (Tomas Henzl) [2049660]
- scsi: mpi3mr: Add Event acknowledgment logic (Tomas Henzl) [2049660]
- scsi: mpi3mr: Gracefully handle online FW update operation (Tomas Henzl) [2049660]
- scsi: mpi3mr: Detect async reset that occurred in firmware (Tomas Henzl) [2049660]
- scsi: mpi3mr: Add IOC reinit function (Tomas Henzl) [2049660]
- scsi: mpi3mr: Handle offline FW activation in graceful manner (Tomas Henzl) [2049660]
- scsi: mpi3mr: Code refactor of IOC init - part2 (Tomas Henzl) [2049660]
- scsi: mpi3mr: Code refactor of IOC init - part1 (Tomas Henzl) [2049660]
- scsi: mpi3mr: Fault IOC when internal command gets timeout (Tomas Henzl) [2049660]
- scsi: mpi3mr: Display IOC firmware package version (Tomas Henzl) [2049660]
- scsi: mpi3mr: Handle unaligned PLL in unmap cmnds (Tomas Henzl) [2049660]
- scsi: mpi3mr: Add support for PCIe Managed Switch SES device (Tomas Henzl) [2049660]
- [s390] s390/cio: verify the driver availability for path_event call (Mete Durlu) [2058620]
- selinux: fix bad cleanup on error in hashtab_duplicate() (Ondrej Mosnacek) [2005890]
- selinux: fix race between old and new sidtab (Ondrej Mosnacek) [2005890]
- selinux: fix cond_list corruption when changing booleans (Ondrej Mosnacek) [2005890]
- selinux: make nslot handling in avtab more robust (Ondrej Mosnacek) [2005890]
- selinuxfs: unify policy load error reporting (Ondrej Mosnacek) [2005890]
- selinux: fix variable scope issue in live sidtab conversion (Ondrej Mosnacek) [2005890]
- selinux: don't log MAC_POLICY_LOAD record on failed policy load (Ondrej Mosnacek) [2005890]
- selinux: simplify away security_policydb_len() (Ondrej Mosnacek) [2005890]
- selinux: move policy mutex to selinux_state, use in lockdep checks (Ondrej Mosnacek) [2005890]
- selinux: fix error handling bugs in security_load_policy() (Ondrej Mosnacek) [2005890]
- selinux: convert policy read-write lock to RCU (Ondrej Mosnacek) [2005890]
- selinux: Create new booleans and class dirs out of tree (Ondrej Mosnacek) [2005890]
- selinux: Standardize string literal usage for selinuxfs directory names (Ondrej Mosnacek) [2005890]
- selinux: Refactor selinuxfs directory populating functions (Ondrej Mosnacek) [2005890]
- selinux: Create function for selinuxfs directory cleanup (Ondrej Mosnacek) [2005890]
- selinux: fix memdup.cocci warnings (Ondrej Mosnacek) [2005890]
- selinux: avoid dereferencing the policy prior to initialization (Ondrej Mosnacek) [2005890]
- selinux: fix allocation failure check on newpolicy->sidtab (Ondrej Mosnacek) [2005890]
- selinux: refactor changing booleans (Ondrej Mosnacek) [2005890]
- selinux: move policy commit after updating selinuxfs (Ondrej Mosnacek) [2005890]
- selinux: encapsulate policy state, refactor policy load (Ondrej Mosnacek) [2005890]
- Revert "selinux: fix deadlock in security_set_bools()" (Ondrej Mosnacek) [2005890]
- thunderx nic: mark device as deprecated (Íñigo Huguet) [2060286]
- cpufreq: intel_pstate: Add Ice Lake server to out-of-band IDs (Vitaly Kuznetsov) [2091523]
- [s390] s390/hypfs: include z/VM guests with access control group set (Mete Durlu) [2058621]
- scsi: mpt3sas: Fix a few kernel-doc issues (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix a typo (Tomas Henzl) [2049623]
- scsi: mpt3sas: Update driver version to 42.100.00.00 (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix junk chars displayed while printing ChipName (Tomas Henzl) [2049623]
- scsi: mpt3sas: Use cached ATA Information VPD page (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix adapter replyPostRegisterIndex declaration (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix event callback log_code value handling (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix ioc->base_readl() use (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix writel() use (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix _ctl_set_task_mid() TaskMID check (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fail reset operation if config request timed out (Tomas Henzl) [2049623]
- scsi: mpt3sas: Fix use after free in _scsih_expander_node_remove() (Tomas Henzl) [2049623]
- scsi: mpt3sas: Page fault in reply q processing (Tomas Henzl) [2049623]
- scsi: mpt3sas: Convert to flexible arrays (Tomas Henzl) [2049623]
- scsi: mpt3sas: Update persistent trigger pages from sysfs interface (Tomas Henzl) [2049623]
- Revert "netfilter: conntrack: tag conntracks picked up in local out hook" (Florian Westphal) [2062870]
- Revert "netfilter: nat: force port remap to prevent shadowing well-known ports" (Florian Westphal) [2062870]
- drm/amdgpu: vi: disable ASPM on Intel Alder Lake based systems (Michel Dänzer) [2066918]
- drm/amd: Use amdgpu_device_should_use_aspm on navi umd pstate switching (Michel Dänzer) [2066918]
- drm/amd: Refactor `amdgpu_aspm` to be evaluated per device (Michel Dänzer) [2066918]
- drm/amd: Check if ASPM is enabled from PCIe subsystem (Michel Dänzer) [2066918]
- [s390] s390/tape: fix timer initialization in tape_std_assign() (Mete Durlu) [2085420]
- powerpc/pseries/vas: Use QoS credits from the userspace (Steve Best) [2075174]
- thermal: don't make THERMAL_NETLINK 'default y' (Prarit Bhargava) [2040062]
- redhat/configs: Add CONFIG_INTEL_HFI_THERMAL (Prarit Bhargava) [2040062]
- thermal/drivers/core: Remove module unload code (Prarit Bhargava) [2040062]
- thermal: core: Fix TZ_GET_TRIP NULL pointer dereference (Prarit Bhargava) [2040062]
- thermal: intel: hfi: INTEL_HFI_THERMAL depends on NET (Prarit Bhargava) [2040062]
- thermal: netlink: Fix parameter type of thermal_genl_cpu_capability_event() stub (Prarit Bhargava) [2040062]
- thermal: intel: hfi: Notify user space for HFI events (Prarit Bhargava) [2040062]
- thermal: netlink: Add a new event to notify CPU capabilities change (Prarit Bhargava) [2040062]
- thermal: intel: hfi: Enable notification interrupt (Prarit Bhargava) [2040062]
- thermal: intel: hfi: Handle CPU hotplug events (Prarit Bhargava) [2040062]
- thermal: intel: hfi: Minimally initialize the Hardware Feedback Interface (Prarit Bhargava) [2040062]
- x86/cpu: Add definitions for the Intel Hardware Feedback Interface (Prarit Bhargava) [2040062]
- x86/Documentation: Describe the Intel Hardware Feedback Interface (Prarit Bhargava) [2040062]
- thermal: intel: Allow processing of HWP interrupt (Prarit Bhargava) [2040062]
- x86/thermal: Fix LVT thermal setup for SMI delivery mode (Prarit Bhargava) [2040062]
- thermal: Move therm_throt there from x86/mce (Prarit Bhargava) [2040062]
- thermal: core: Adding missing nlmsg_free() in thermal_genl_sampling_temp() (Prarit Bhargava) [2040062]
- thermal: move to smaller ops wherever possible (Prarit Bhargava) [2040062]
- thermal: add small version of ops (Prarit Bhargava) [2040062]
- thermal: netlink: Improve the initcall ordering (Prarit Bhargava) [2040062]
- thermal: core: remove redundant initialization of variable ret (Prarit Bhargava) [2040062]
- thermal: netlink: Fix compilation error when CONFIG_NET=n (Prarit Bhargava) [2040062]
- thermal: core: Fix thermal zone lookup by ID (Prarit Bhargava) [2040062]
- thermal: core: Get thermal zone by id (Prarit Bhargava) [2040062]
- thermal: core: Add helpers to browse the cdev, tz and governor list (Prarit Bhargava) [2040062]
- thermal: Remove netlink support (Prarit Bhargava) [2040062]
- thermal: core: genetlink support for events/cmd/sampling (Prarit Bhargava) [2040062]

* Fri May 27 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-396.el8]
- mailbox: pcc: Handle all PCC subtypes correctly in pcc_mbox_irq (Mark Langsdorf) [1997698]
- i2c: xgene-slimpro: Fix wrong pointer passed to PTR_ERR() (Mark Langsdorf) [1997698]
- ACPI: Make acpi_node_get_parent() local (Mark Langsdorf) [1997698]
- ACPI: Get acpi_device's parent from the parent field (Mark Langsdorf) [1997698]
- ACPI: PM: Fix device wakeup power reference counting error (Mark Langsdorf) [1997698]
- ACPI: video: use platform backlight driver on Xiaomi Mi Pad 2 (Mark Langsdorf) [1997698]
- ACPI: video: Drop dmi_system_id.ident settings from video_detect_dmi_table[] (Mark Langsdorf) [1997698]
- ACPI: PMIC: Fix intel_pmic_regs_handler() read accesses (Mark Langsdorf) [1997698]
- ACPI: EC: Use ec_no_wakeup on HP ZHAN 66 Pro (Mark Langsdorf) [1997698]
- ACPI: Add a convenience function to tell a device is in D0 state (Mark Langsdorf) [1997698]
- ACPI: scan: Obtain device's desired enumeration power state (Mark Langsdorf) [1997698]
- perf: qcom_l2_pmu: ACPI: Use ACPI_COMPANION() directly (Mark Langsdorf) [1997698]
- ACPI/PCC: Add maintainer for PCC mailbox driver (Mark Langsdorf) [1997698]
- mailbox: pcc: Add support for PCCT extended PCC subspaces(type 3/4) (Mark Langsdorf) [1997698]
- mailbox: pcc: Drop handling invalid bit-width in {read,write}_register (Mark Langsdorf) [1997698]
- mailbox: pcc: Avoid accessing PCCT table in pcc_send_data and pcc_mbox_irq (Mark Langsdorf) [1997698]
- mailbox: pcc: Add PCC register bundle and associated accessor functions (Mark Langsdorf) [1997698]
- mailbox: pcc: Rename doorbell ack to platform interrupt ack register (Mark Langsdorf) [1997698]
- mailbox: pcc: Use PCC mailbox channel pointer instead of standard (Mark Langsdorf) [1997698]
- mailbox: pcc: Add pcc_mbox_chan structure to hold shared memory region info (Mark Langsdorf) [1997698]
- mailbox: pcc: Consolidate subspace doorbell register parsing (Mark Langsdorf) [1997698]
- mailbox: pcc: Consolidate subspace interrupt information parsing (Mark Langsdorf) [1997698]
- mailbox: pcc: Refactor all PCC channel information into a structure (Mark Langsdorf) [1997698]
- mailbox: pcc: Fix kernel doc warnings (Mark Langsdorf) [1997698]
- ACPI: glue: Use acpi_device_adr() in acpi_find_child_device() (Mark Langsdorf) [1997698]
- ACPI: APEI: mark apei_hest_parse() static (Mark Langsdorf) [1997698]
- ACPI: APEI: EINJ: Relax platform response timeout to 1 second (Mark Langsdorf) [1997698]
- ACPI: resources: Add one more Medion model in IRQ override quirk (Mark Langsdorf) [1997698]
- ACPI: AC: Quirk GK45 to skip reading _PSR (Mark Langsdorf) [1997698]
- ACPI: PM: sleep: Do not set suspend_ops unnecessarily (Mark Langsdorf) [1997698]
- ACPI: PRM: Handle memory allocation and memory remap failure (Mark Langsdorf) [1997698]
- ACPI: PRM: Remove unnecessary blank lines (Mark Langsdorf) [1997698]
- ACPI: PM: Turn off wakeup power resources on _DSW/_PSW errors (Mark Langsdorf) [1997698]
- ACPI: PM: Fix sharing of wakeup power resources (Mark Langsdorf) [1997698]
- ACPI: PM: Turn off unused wakeup power resources (Mark Langsdorf) [1997698]
- ACPI: PM: Check states of power resources during initialization (Mark Langsdorf) [1997698]
- hwmon: (acpi_power_meter) Use acpi_bus_get_acpi_device() (Mark Langsdorf) [1997698]
- ACPI: replace snprintf() in "show" functions with sysfs_emit() (Mark Langsdorf) [1997698]
- ACPI: LPSS: Use ACPI_COMPANION() directly (Mark Langsdorf) [1997698]
- ACPI: battery: Accept charges over the design capacity as full (Mark Langsdorf) [1997698]
- ACPICA: Update version to 20210930 (Mark Langsdorf) [1997698]
- ACPICA: iASL table disassembler: Added disassembly support for the NHLT ACPI table (Mark Langsdorf) [1997698]
- ACPICA: ACPI 6.4 SRAT: add Generic Port Affinity type (Mark Langsdorf) [1997698]
- ACPICA: Add support for Windows 2020 _OSI string (Mark Langsdorf) [1997698]
- ACPICA: Avoid evaluating methods too early during system resume (Mark Langsdorf) [1997698]
- ACPI: processor: idle: fix lockup regression on 32-bit ThinkPad T40 (Mark Langsdorf) [1997698]
- ACPI: processor idle: Allow playing dead in C3 state (Mark Langsdorf) [1997698]
- ACPI: Kconfig: Fix a typo in Kconfig (Mark Langsdorf) [1997698]
- ACPI: PNP: remove duplicated BRI0A49 and BDP3336 entries (Mark Langsdorf) [1997698]
- ACPI: resources: Add DMI-based legacy IRQ override quirk (Mark Langsdorf) [1997698]
- ACPICA: Add support for MADT online enabled bit (Mark Langsdorf) [1997698]
- acpi/arm64: fix next_platform_timer() section mismatch error (Mark Langsdorf) [1997697]
- ACPI: PM: Include alternate AMDI0005 id in special behaviour (Mark Langsdorf) [1997697]
- MAINTAINERS: Change Rafael's e-mail address (Mark Langsdorf) [1997697]
- ACPI: scan: Remove unneeded header linux/nls.h (Mark Langsdorf) [1997697]
- ACPI: PM: s2idle: Run both AMD and Microsoft methods if both are supported (Mark Langsdorf) [1997697]
- ACPI: power: Drop name from struct acpi_power_resource (Mark Langsdorf) [1997697]
- ACPI: power: Use acpi_handle_debug() to print debug messages (Mark Langsdorf) [1997697]
- ACPI: button: Add DMI quirk for Lenovo Yoga 9 (14INTL5) (Mark Langsdorf) [1997697]
- ACPI: SPCR: Add support for the new 16550-compatible Serial Port Subtype (Mark Langsdorf) [1997697]
- ACPI: platform-profile: call sysfs_notify() from platform_profile_store() (Mark Langsdorf) [1997697]
- ACPICA: Update version to 20210730 (Mark Langsdorf) [1997697]
- ACPICA: Add method name "_DIS" For use with aslmethod.c (Mark Langsdorf) [1997697]
- ACPICA: iASL: Fix for WPBT table with no command-line arguments (Mark Langsdorf) [1997697]
- ACPICA: Headers: Add new DBG2 Serial Port Subtypes (Mark Langsdorf) [1997697]
- ACPICA: Macros should not use a trailing semicolon (Mark Langsdorf) [1997697]
- ACPICA: Fix an if statement (add parens) (Mark Langsdorf) [1997697]
- ACPICA: iASL: Add support for the AEST table (data compiler) (Mark Langsdorf) [1997697]
- clk: fractional-divider: Introduce POWER_OF_TWO_PS flag (Mark Langsdorf) [1997697]
- clk: fractional-divider: add explicit big endian support (Mark Langsdorf) [1997697]
- clk: gate: add explicit big endian support (Mark Langsdorf) [1997697]
- clk: fractional-divider: add CLK_FRAC_DIVIDER_ZERO_BASED flag support (Mark Langsdorf) [1997697]
- ACPI: processor: Replace deprecated CPU-hotplug functions (Mark Langsdorf) [1997697]
- ABI: sysfs-platform-dptf: Add tables markup to a table (Mark Langsdorf) [1997697]
- ACPI: DPTF: Add new PCH FIVR methods (Mark Langsdorf) [1997697]
- clk: x86: Rename clk-lpt to more specific clk-lpss-atom (Mark Langsdorf) [1997697]
- ACPI: configfs: Make get_header() to return error pointer (Mark Langsdorf) [1997697]
- ACPI: configfs: Use sysfs_emit() in "show" functions (Mark Langsdorf) [1997697]
- ACPI: glue: Eliminate acpi_platform_notify() (Mark Langsdorf) [1997697]
- ACPI: bus: Rename functions to avoid name collision (Mark Langsdorf) [1997697]
- ACPI: glue: Change return type of two functions to void (Mark Langsdorf) [1997697]
- ACPI: glue: Rearrange acpi_device_notify() (Mark Langsdorf) [1997697]
- ACPI: Add LoongArch support for ACPI_PROCESSOR/ACPI_NUMA (Mark Langsdorf) [1997697]
- ACPI / PMIC: XPower: optimize MIPI PMIQ sequence I2C-bus accesses (Mark Langsdorf) [1997697]
- ACPI / PMIC: XPower: optimize I2C-bus accesses (Mark Langsdorf) [1997697]
- stddef: Introduce DECLARE_FLEX_ARRAY() helper (Josef Oskera) [2062594]
- Revert "iavf: Fix deadlock occurrence during resetting VF interface" (Ivan Vecera) [2066693]
- scsi: core: Fix sbitmap depth in scsi_realloc_sdev_budget_map() (Ewan D. Milne) [2071831]
- lib/sbitmap: allocate sb->map via kvzalloc_node (Ewan D. Milne) [2071831]
- mm: move kvmalloc-related functions to slab.h (Ewan D. Milne) [2071831]
- scsi: core: sd: Add silence_suspend flag to suppress some PM messages (Ewan D. Milne) [2071831]
- scsi: scsi_transport_fc: Fix FPIN Link Integrity statistics counters (Ewan D. Milne) [2071831]
- sd: call sd_zbc_release_disk before releasing the scsi_device reference (Ewan D. Milne) [2071831]
- scsi: core: Reallocate device's budget map on queue depth change (Ewan D. Milne) [2071831]
- scsi: sr: Don't use GFP_DMA (Ewan D. Milne) [2071831]
- scsi: core: Fix scsi_device_max_queue_depth() (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Fix buffer size of REPORT ZONES command (Ewan D. Milne) [2071831]
- scsi: sd_zbc: Clean up sd_zbc_parse_report() setting of wp (Ewan D. Milne) [2071831]
- scsi: sd_zbc: Simplify zone full condition check (Ewan D. Milne) [2071831]
- scsi: core: Show SCMD_LAST in text form (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Zero clear zones at reset write pointer (Ewan D. Milne) [2071831]
- scsi: core: sysfs: Fix setting device state to SDEV_RUNNING (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Sanity check block descriptor length in resp_mode_select() (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Fix type in min_t to avoid stack OOB (Ewan D. Milne) [2071831]
- scsi: core: Simplify control flow in scmd_eh_abort_handler() (Ewan D. Milne) [2071831]
- scsi: core: sysfs: Fix hang when device state is set via sysfs (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Don't call kcalloc() if size arg is zero (Ewan D. Milne) [2071831]
- scsi: sr: Remove duplicate assignment (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Fix out-of-bound read in resp_report_tgtpgs() (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Fix out-of-bound read in resp_readcap16() (Ewan D. Milne) [2071831]
- scsi: sd: Print write through due to no caching mode page as warning (Ewan D. Milne) [2071831]
- scsi: sd: Fix crashes in sd_resume_runtime() (Ewan D. Milne) [2071831]
- scsi: core: Fix shost->cmd_per_lun calculation in scsi_add_host_with_dma() (Ewan D. Milne) [2071831]
- scsi: core: Fix spelling in a source code comment (Ewan D. Milne) [2071831]
- scsi: sd: Fix sd_do_mode_sense() buffer length handling (Ewan D. Milne) [2071831]
- scsi: core: Fix scsi_mode_select() buffer length handling (Ewan D. Milne) [2071831]
- scsi: core: Fix scsi_mode_sense() buffer length handling (Ewan D. Milne) [2071831]
- scsi: core: Remove include <scsi/scsi_host.h> from scsi_cmnd.h (Ewan D. Milne) [2071831]
- scsi: sd_zbc: Support disks with more than 2**32 logical blocks (Ewan D. Milne) [2071831]
- scsi: sd: Make sd_spinup_disk() less noisy (Ewan D. Milne) [2071831]
- scsi: sr: Fix spelling mistake "does'nt" -> "doesn't" (Ewan D. Milne) [2071831]
- scsi: sd_zbc: Ensure buffer size is aligned to SECTOR_SIZE (Ewan D. Milne) [2071831]
- scsi: sd: Do not exit sd_spinup_disk() quietly (Ewan D. Milne) [2071831]
- scsi: core: Add helper to return number of logical blocks in a request (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071831]
- scsi: scsi_transport_spi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071831]
- scsi: scsi_transport_fc: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071831]
- scsi: sr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071831]
- scsi: sd: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071831]
- scsi: core: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071831]
- scsi: core: Introduce the scsi_cmd_to_rq() function (Ewan D. Milne) [2071831]
- scsi: core: Add BLIST_IGN_MEDIA_CHANGE for Ultra HS-SD/MMC USB card readers (Ewan D. Milne) [2071831]
- scsi: sd: REQUEST SENSE for BLIST_IGN_MEDIA_CHANGE devices in runtime_resume() (Ewan D. Milne) [2071831]
- scsi: core: Add new flag BLIST_IGN_MEDIA_CHANGE (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Improve RDPROTECT/WRPROTECT handling (Ewan D. Milne) [2071831]
- scsi: scsi_debug: Remove dump_sector() (Ewan D. Milne) [2071831]
- scsi: core: Add scsi_prot_ref_tag() helper (Ewan D. Milne) [2071831]
- scsi: core: Add scsi_msg_to_host_byte() (Ewan D. Milne) [2071831]
- scsi: core: Add get_{status,host}_byte() accessor functions (Ewan D. Milne) [2071831]
- scsi: core: Cap scsi_host cmd_per_lun at can_queue (Ewan D. Milne) [2071831]
- scsi: Fix spelling mistakes in header files (Ewan D. Milne) [2071831]
- scsi: core: Treat device offline as a failure (Ewan D. Milne) [2071831]
- sched/topology: Skip updating masks for non-online nodes (Diego Domingos) [1946251]
- powerpc/numa: Update cpu_cpu_map on CPU online/offline (Diego Domingos) [1946251]
- powerpc/numa: Print debug statements only when required (Diego Domingos) [1946251]
- powerpc/numa: convert printk to pr_xxx (Diego Domingos) [1946251]
- powerpc/numa: Drop dbg in favour of pr_debug (Diego Domingos) [1946251]
- livepatch: Fix missing unlock on error in klp_enable_patch() (Julia Denham) [2069340]
- livepatch: Fix kobject refcount bug on klp_init_patch_early failure path (Julia Denham) [2069340]
- Documentation: livepatch: Add livepatch API page (Julia Denham) [2069340]
- scsi: megaraid_sas: Remove unnecessary memset (Tomas Henzl) [2049686]
- scsi: megaraid_sas: Target with invalid LUN ID is deleted during scan (Tomas Henzl) [2049686]
- scsi: megasas: Clean up some inconsistent indenting (Tomas Henzl) [2049686]
- scsi: megasas: Stop using the SCSI pointer (Tomas Henzl) [2049686]
- aarch64: enable memory hotplug (Baoquan He) [1818517]
- mm/memory_hotplug: introduce default dummy memory_add_physaddr_to_nid() (Baoquan He) [1818517]
- arm64/mm: Add one hunk back missed in earlier back porting (Baoquan He) [1818517]
- arm64/mm: Hold memory hotplug lock while walking for kernel page table dump (Baoquan He) [1818517]
- ARM64: dump: Convert to use DEFINE_SHOW_ATTRIBUTE macro (Baoquan He) [1818517]
- net/mlx5: DR, Ignore modify TTL on RX if device doesn't support it (Amir Tzin) [2072934]
- net: bridge: switchdev: check br_vlan_group() return value (Ivan Vecera) [2080332]
- net: bridge: mst: Restrict info size queries to bridge ports (Ivan Vecera) [2080332]
- net: bridge: mst: prevent NULL deref in br_mst_info_size() (Ivan Vecera) [2080332]
- selftests: forwarding: Use same VRF for port and VLAN upper (Ivan Vecera) [2080332]
- selftests: forwarding: Disable learning before link up (Ivan Vecera) [2080332]
- net: bridge: mst: Add helper to query a port's MST state (Ivan Vecera) [2080332]
- net: bridge: mst: Add helper to check if MST is enabled (Ivan Vecera) [2080332]
- net: bridge: mst: Add helper to map an MSTI to a VID set (Ivan Vecera) [2080332]
- net: bridge: mst: Notify switchdev drivers of MST state changes (Ivan Vecera) [2080332]
- net: bridge: mst: Notify switchdev drivers of VLAN MSTI migrations (Ivan Vecera) [2080332]
- net: bridge: mst: Notify switchdev drivers of MST mode changes (Ivan Vecera) [2080332]
- net: bridge: mst: Support setting and reporting MST port states (Ivan Vecera) [2080332]
- net: bridge: mst: Allow changing a VLAN's MSTI (Ivan Vecera) [2080332]
- net: bridge: mst: Multiple Spanning Tree (MST) mode (Ivan Vecera) [2080332]
- net: switchdev: remove lag_mod_cb from switchdev_handle_fdb_event_to_device (Ivan Vecera) [2080332]
- selftests: forwarding: tests of locked port feature (Ivan Vecera) [2080332]
- net: bridge: Add support for offloading of locked port flag (Ivan Vecera) [2080332]
- net: bridge: Add support for bridge port in locked mode (Ivan Vecera) [2080332]
- net: switchdev: avoid infinite recursion from LAG to bridge with port object handler (Ivan Vecera) [2080332]
- bridge: switch br_net_exit to batch mode (Ivan Vecera) [2080332]
- net: bridge: multicast: notify switchdev driver whenever MC processing gets disabled (Ivan Vecera) [2080332]
- net: switchdev: introduce switchdev_handle_port_obj_{add,del} for foreign interfaces (Ivan Vecera) [2080332]
- net: switchdev: rename switchdev_lower_dev_find to switchdev_lower_dev_find_rcu (Ivan Vecera) [2080332]
- net: bridge: switchdev: replay all VLAN groups (Ivan Vecera) [2080332]
- net: bridge: make nbp_switchdev_unsync_objs() follow reverse order of sync() (Ivan Vecera) [2080332]
- net: bridge: switchdev: differentiate new VLANs from changed ones (Ivan Vecera) [2080332]
- net: bridge: vlan: notify switchdev only when something changed (Ivan Vecera) [2080332]
- net: bridge: vlan: make __vlan_add_flags react only to PVID and UNTAGGED (Ivan Vecera) [2080332]
- net: bridge: vlan: don't notify to switchdev master VLANs without BRENTRY flag (Ivan Vecera) [2080332]
- net: bridge: vlan: check early for lack of BRENTRY flag in br_vlan_add_existing (Ivan Vecera) [2080332]
- net: bridge: vlan: check for errors from __vlan_del in __vlan_flush (Ivan Vecera) [2080332]
- net/switchdev: use struct_size over open coded arithmetic (Ivan Vecera) [2080332]
- net: bridge: vlan: fix single net device option dumping (Ivan Vecera) [2080332]
- net: bridge: mcast: fix br_multicast_ctx_vlan_global_disabled helper (Ivan Vecera) [2080332]
- net: bridge: mcast: add and enforce startup query interval minimum (Ivan Vecera) [2080332]
- net: bridge: mcast: add and enforce query interval minimum (Ivan Vecera) [2080332]
- netfilter: bridge: add support for pppoe filtering (Ivan Vecera) [2080332]
- bridge: use __set_bit in __br_vlan_set_default_pvid (Ivan Vecera) [2080332]
- net: bridge: Allow base 16 inputs in sysfs (Ivan Vecera) [2080332]
- net/bridge: replace simple_strtoul to kstrtol (Ivan Vecera) [2080332]
- net: bridge: Slightly optimize 'find_portno()' (Ivan Vecera) [2080332]
- net: bridge: switchdev: fix shim definition for br_switchdev_mdb_notify (Ivan Vecera) [2080332]
- net: bridge: switchdev: consistent function naming (Ivan Vecera) [2080332]
- net: bridge: mdb: move all switchdev logic to br_switchdev.c (Ivan Vecera) [2080332]
- net: bridge: split out the switchdev portion of br_mdb_notify (Ivan Vecera) [2080332]
- net: bridge: move br_vlan_replay to br_switchdev.c (Ivan Vecera) [2080332]
- net: bridge: provide shim definition for br_vlan_flags (Ivan Vecera) [2080332]
- net: switchdev: merge switchdev_handle_fdb_{add,del}_to_device (Ivan Vecera) [2080332]
- net: bridge: create a common function for populating switchdev FDB entries (Ivan Vecera) [2080332]
- net: bridge: move br_fdb_replay inside br_switchdev.c (Ivan Vecera) [2080332]
- net: bridge: reduce indentation level in fdb_create (Ivan Vecera) [2080332]
- net: bridge: rename br_fdb_insert to br_fdb_add_local (Ivan Vecera) [2080332]
- net: bridge: rename fdb_insert to fdb_add_local (Ivan Vecera) [2080332]
- net: bridge: remove fdb_insert forward declaration (Ivan Vecera) [2080332]
- net: bridge: remove fdb_notify forward declaration (Ivan Vecera) [2080332]
- net: make use of helper netif_is_bridge_master() (Ivan Vecera) [2080332]
- net: use eth_hw_addr_set() (Ivan Vecera) [2080332]
- net: bridge: Use array_size() helper in copy_to_user() (Ivan Vecera) [2080332]
- net/mlx5: DR, Fix missing flow_source when creating multi-destination FW table (Amir Tzin) [2072920]
- net/mlx5: DR, Fix slab-out-of-bounds in mlx5_cmd_dr_create_fte (Amir Tzin) [2072920]
- ixgbevf: Require large buffers for build_skb on 82599VF (Ken Cox) [2037956]
- ixgbevf: Remove useless DMA-32 fallback configuration (Ken Cox) [2037956]
- ixgbevf: switch to napi_build_skb() (Ken Cox) [2037956]
- ixgbevf: Add support for new mailbox communication between PF and VF (Ken Cox) [2037956]
- ixgbevf: Mailbox improvements (Ken Cox) [2037956]
- ixgbevf: Add legacy suffix to old API mailbox functions (Ken Cox) [2037956]
- ixgbevf: Improve error handling in mailbox (Ken Cox) [2037956]
- ixgbevf: Rename MSGTYPE to SUCCESS and FAILURE (Ken Cox) [2037956]
- net: ixgbevf: Remove redundant initialization of variable ret_val (Ken Cox) [2037956]
- selftests: mptcp: fix diag instability (Hangbin Liu) [2077358]
- selftests: mptcp: fix ipv6 routing setup (Hangbin Liu) [2077358]
- selftests: mptcp: clean tmp files in simult_flows (Hangbin Liu) [2077358]
- selftests: netfilter: fix exit value for nft_concat_range (Hangbin Liu) [2077358]
- selftests: netfilter: remove stray bash debug line (Hangbin Liu) [2077358]
- selftests: Fix IPv6 address bind tests (Hangbin Liu) [2077358]
- selftests: Fix raw socket bind tests with VRF (Hangbin Liu) [2077358]
- selftests: net: Correct case name (Hangbin Liu) [2077358]
- selftests: pmtu.sh: Kill nettest processes launched in subshell. (Hangbin Liu) [2077358]
- selftests: pmtu.sh: Kill tcpdump processes launched by subshell. (Hangbin Liu) [2077358]
- selftests: net: Fix a typo in udpgro_fwd.sh (Hangbin Liu) [2077358]
- selftests/net: udpgso_bench_tx: fix dst ip argument (Hangbin Liu) [2077358]
- selftests/net: udpgso_bench_rx: fix port argument (Hangbin Liu) [2077358]
- selftests: net: tls: remove unused variable and code (Hangbin Liu) [2077358]
- selftest: net: fix typo in altname test (Hangbin Liu) [2077358]

* Tue May 24 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-395.el8]
- net/mlx5: DR, Fix the threshold that defines when pool sync is initiated (Amir Tzin) [2062715]
- net/mlx5: DR, Cache STE shadow memory (Amir Tzin) [2062715]
- perf/x86/intel/lbr: Add static_branch for LBR INFO flags (Michael Petlan) [2039998]
- perf/x86/intel/lbr: Support LBR format V7 (Michael Petlan) [2039998]
- net/mlx5e: TC, fix decap fallback to uplink when int port not supported (Amir Tzin) [2077048]
- net/mlx5e: Fix wrong source vport matching on tunnel rule (Amir Tzin) [2064589]
- hv_balloon: rate-limit "Unhandled message" warning (Vitaly Kuznetsov) [2087270]
- tcp: drop the hash_32() part from the index calculation (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: increase source port perturb table to 2^16 (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: dynamically allocate the perturb table used by source ports (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: add small random increments to the source port (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: resalt the secret every 10 seconds (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: use different parts of the port_offset for index and offset (Guillaume Nault) [2064876] {CVE-2022-1012}
- secure_seq: use the 64 bits of the siphash for port offset calculation (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: add some entropy in __inet_hash_connect() (Guillaume Nault) [2064876] {CVE-2022-1012}
- tcp: change source port randomizarion at connect() time (Guillaume Nault) [2064876] {CVE-2022-1012}
- net/mlx5e: TC, Skip redundant ct clear actions (Amir Tzin) [2055590]
- spi: pxa2xx: Add support for Intel Raptor Lake PCH-S (Prarit Bhargava) [2040031]
- mfd: intel-lpss: Add Intel Raptor Lake PCH-S PCI IDs (Prarit Bhargava) [2040031]
- pinctrl: alderlake: Add Raptor Lake-S ACPI ID (Prarit Bhargava) [2040033]
- i2c: i801: Add support for Intel Raptor Lake PCH-S (Prarit Bhargava) [2040027 2040029]
- redhat/configs: Add CONFIG_INTEL_IDXD_PERFMON (Jerry Snitselaar) [1921296]
- x86/fpu/xstate: Consolidate size calculations (Jerry Snitselaar) [2071461]
- x86/fpu/xstate: Handle supervisor states in XSTATE permissions (Jerry Snitselaar) [2071461]
- x86/fpu/xsave: Handle compacted offsets correctly with supervisor states (Jerry Snitselaar) [2071461]
- x86/fpu: Cache xfeature flags from CPUID (Jerry Snitselaar) [2071461]
- x86/fpu/xsave: Initialize offset/size cache early (Jerry Snitselaar) [2071461]
- x86/fpu: Remove unused supervisor only offsets (Jerry Snitselaar) [2071461]
- dmaengine: idxd: Change license on idxd.h to LGPL (Jerry Snitselaar) [2072156]
- dmaengine: idxd: fix delta_rec and crc size field for completion record (Jerry Snitselaar) [1971892]
- dmaengine: idxd: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2072156]
- dmaengine: idxd: restore traffic class defaults after wq reset (Jerry Snitselaar) [2046469]
- dmaengine: idxd: deprecate token sysfs attributes for read buffers (Jerry Snitselaar) [2040042]
- dmaengine: idxd: change bandwidth token to read buffers (Jerry Snitselaar) [2040042]
- dmaengine: idxd: fix wq settings post wq disable (Jerry Snitselaar) [2040045]
- dmaengine: idxd: change MSIX allocation based on per wq activation (Jerry Snitselaar) [2040495]
- edmaengine: idxd: fix descriptor flushing locking (Jerry Snitselaar) [2040495]
- dmaengine: idxd: embed irq_entry in idxd_wq struct (Jerry Snitselaar) [2040495]
- dmaengine: idxd: fix calling wq quiesce inside spinlock (Jerry Snitselaar) [2040040]
- dmaengine: idxd: add knob for enqcmds retries (Jerry Snitselaar) [2040047]
- dmaengine: idxd: set defaults for wq configs (Jerry Snitselaar) [2040047]
- dmaengine: idxd: handle interrupt handle revoked event (Jerry Snitselaar) [2040051]
- dmaengine: idxd: handle invalid interrupt handle descriptors (Jerry Snitselaar) [2040051]
- dmaengine: idxd: create locked version of idxd_quiesce() call (Jerry Snitselaar) [2040051]
- dmaengine: idxd: add helper for per interrupt handle drain (Jerry Snitselaar) [2040051]
- dmaengine: idxd: move interrupt handle assignment (Jerry Snitselaar) [2040051]
- dmaengine: idxd: int handle management refactoring (Jerry Snitselaar) [2040051]
- dmaengine: idxd: rework descriptor free path on failure (Jerry Snitselaar) [2040051]
- dmaengine: idxd: fix missed completion on abort path (Jerry Snitselaar) [2040040]
- dmaengine: idxd: fix resource leak on dmaengine driver disable (Jerry Snitselaar) [2040040]
- dmaengine: idxd: cleanup completion record allocation (Jerry Snitselaar) [2040040]
- dmaengine: idxd: reconfig device after device reset command (Jerry Snitselaar) [2072156]
- dmaengine: idxd: add halt interrupt support (Jerry Snitselaar) [2040047]
- dmaengine: idxd: Use list_move_tail instead of list_del/list_add_tail (Jerry Snitselaar) [2072156]
- dmanegine: idxd: fix resource free ordering on driver removal (Jerry Snitselaar) [2040040]
- dmaengine: idxd: remove kernel wq type set when load configuration (Jerry Snitselaar) [2040040]
- dmaengine: idxd: remove gen cap field per spec 1.2 update (Jerry Snitselaar) [2040040]
- dmaengine: idxd: check GENCAP config support for gencfg register (Jerry Snitselaar) [2040040]
- dmaengine: idxd: move out percpu_ref_exit() to ensure it's outside submission (Jerry Snitselaar) [2040040]
- dmaengine: idxd: remove interrupt disable for dev_lock (Jerry Snitselaar) [2040040]
- dmaengine: idxd: remove interrupt disable for cmd_lock (Jerry Snitselaar) [2040040]
- dmaengine: idxd: fix setting up priv mode for dwq (Jerry Snitselaar) [2040040]
- dmaengine: idxd: set descriptor allocation size to threshold for swq (Jerry Snitselaar) [2040040]
- dmaengine: idxd: make submit failure path consistent on desc freeing (Jerry Snitselaar) [2040040]
- dmaengine: idxd: remove interrupt flag for completion list spinlock (Jerry Snitselaar) [2040040]
- dmaengine: idxd: make I/O interrupt handler one shot (Jerry Snitselaar) [2040040]
- dmaengine: idxd: clear block on fault flag when clear wq (Jerry Snitselaar) [2040040]
- dmaengine: idxd: add capability check for 'block on fault' attribute (Jerry Snitselaar) [2040040]
- dmaengine: idxd: Remove unused status variable in irq_process_work_list() (Jerry Snitselaar) [2072156]
- dmaengine: idxd: Fix a possible NULL pointer dereference (Jerry Snitselaar) [2072156]
- dmaengine: idxd: fix abort status check (Jerry Snitselaar) [2040040]
- dmanegine: idxd: add software command status (Jerry Snitselaar) [2040047]
- dmaengine: idxd: rotate portal address for better performance (Jerry Snitselaar) [2040047]
- dmaengine: idxd: fix wq slot allocation index check (Jerry Snitselaar) [2040040]
- dmaengine: idxd: fix uninit var for alt_drv (Jerry Snitselaar) [2072156]
- dmaengine: idxd: Set defaults for GRPCFG traffic class (Jerry Snitselaar) [2040047]
- dmaengine: idxd: remove fault processing code (Jerry Snitselaar) [2040040]
- dmaengine: idxd: move dsa_drv support to compatible mode (Jerry Snitselaar) [1971961]
- dmaengine: dsa: move dsa_bus_type out of idxd driver to standalone (Jerry Snitselaar) [1971961]
- dmaengine: idxd: create user driver for wq 'device' (Jerry Snitselaar) [1971961]
- dmaengine: idxd: create dmaengine driver for wq 'device' (Jerry Snitselaar) [1971961]
- dmaengine: idxd: create idxd_device sub-driver (Jerry Snitselaar) [1971961]
- dmaengine: idxd: add type to driver in order to allow device matching (Jerry Snitselaar) [1971961]
- dmanegine: idxd: open code the dsa_drv registration (Jerry Snitselaar) [1971961]
- dmaengine: idxd: idxd: move remove() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971961]
- dmaengine: idxd: move probe() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971961]
- dmaengine: idxd: fix bus_probe() and bus_remove() for dsa_bus (Jerry Snitselaar) [1971961]
- dmaengine: idxd: remove iax_bus_type prototype (Jerry Snitselaar) [1971961]
- dmaengine: idxd: remove bus shutdown (Jerry Snitselaar) [1971961]
- dmaengine: idxd: move wq_disable() to device.c (Jerry Snitselaar) [1971961]
- dmaengine: idxd: move wq_enable() to device.c (Jerry Snitselaar) [1971961]
- dmaengine: idxd: remove IDXD_DEV_CONF_READY (Jerry Snitselaar) [1971961]
- dmaengine: idxd: add 'struct idxd_dev' as wrapper for conf_dev (Jerry Snitselaar) [1971961]
- dmaengine: idxd: add driver name (Jerry Snitselaar) [1971961]
- dmaengine: idxd: add driver register helper (Jerry Snitselaar) [1971961]
- dmaengine: idxd: depends on !UML (Jerry Snitselaar) [2072156]
- dmaengine: idxd: fix PCI_MSI build errors (Jerry Snitselaar) [2072156]
- dmaengine: idxd: fix submission race window (Jerry Snitselaar) [2040040]
- dmaengine: idxd: fix sequence for pci driver remove() and shutdown() (Jerry Snitselaar) [2072156]
- dmaengine: idxd: fix setup sequence for MSIXPERM table (Jerry Snitselaar) [2040040]
- dmaengine: idxd: fix array index when int_handles are being used (Jerry Snitselaar) [2040040]
- dmaengine: idxd: assign MSIX vectors to each WQ rather than roundrobin (Jerry Snitselaar) [2072156]
- dmaengine: idxd: fix desc->vector that isn't being updated (Jerry Snitselaar) [2040040]
- dmaengine: idxd: add missing percpu ref put on failure (Jerry Snitselaar) [2072156]
- dmaengine: idxd: have command status always set (Jerry Snitselaar) [1973882]
- dmanegine: idxd: cleanup all device related bits after disabling device (Jerry Snitselaar) [2072156]
- dmaengine: idxd: Simplify code and axe the use of a deprecated API (Jerry Snitselaar) [2072156]
- dmaengine: idxd: remove devm allocation for idxd->int_handles (Jerry Snitselaar) [2072156]
- dmaengine: idxd: Remove redundant variable cdev_ctx (Jerry Snitselaar) [2072156]
- dmaengine: idxd: Add missing cleanup for early error out in probe call (Jerry Snitselaar) [1971892]
- dmaengine: idxd: Enable IDXD performance monitor support (Jerry Snitselaar) [1921296]
- dmaengine: idxd: Add IDXD performance monitor support (Jerry Snitselaar) [1921296]
- dmaengine: idxd: device cmd should use dedicated lock (Jerry Snitselaar) [1971892]
- dmaengine: idxd: support reporting of halt interrupt (Jerry Snitselaar) [1971890]
- dmaengine: idxd: convert sprintf() to sysfs_emit() for all usages (Jerry Snitselaar) [1971890]
- dmaengine: idxd: add interrupt handle request and release support (Jerry Snitselaar) [1971890]
- dmaengine: idxd: add support for readonly config mode (Jerry Snitselaar) [1971890]
- dmaengine: idxd: add percpu_ref to descriptor submission path (Jerry Snitselaar) [1971949]
- dmaengine: idxd: remove detection of device type (Jerry Snitselaar) [1971963]
- Documentation/x86: Update documentation for SVA (Shared Virtual Addressing) (Jerry Snitselaar) [2071461]
- tools/objtool: Check for use of the ENQCMD instruction in the kernel (Jerry Snitselaar) [2071461]
- x86/cpufeatures: Re-enable ENQCMD (Jerry Snitselaar) [2071461]
- x86/traps: Demand-populate PASID MSR via #GP (Jerry Snitselaar) [2071461]
- sched: Define and initialize a flag to identify valid PASID in the task (Jerry Snitselaar) [2071461]
- x86/fpu: Clear PASID when copying fpstate (Jerry Snitselaar) [2071461]
- iommu/sva: Assign a PASID to mm on PASID allocation and free it on mm exit (Jerry Snitselaar) [2071461]
- iommu/ioasid: Introduce a helper to check for valid PASIDs (Jerry Snitselaar) [2071461]
- kernel/fork: Initialize mm's PASID (Jerry Snitselaar) [2071461]
- mm: Change CONFIG option for mm->pasid field (Jerry Snitselaar) [2071461]
- mm/fork: clear PASID for new mm (Jerry Snitselaar) [2071461]
- iommu/sva: Rename CONFIG_IOMMU_SVA_LIB to CONFIG_IOMMU_SVA (Jerry Snitselaar) [2071461]
- turbostat: fix PC6 displaying on some systems (Steve Best) [2040078]

* Mon May 23 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-394.el8]
- quota: make dquot_quota_sync return errors from ->sync_fs (Lukas Czerner) [2083057]
- redhat: disable more noisy rpminspect tests (Jarod Wilson)
- mm: thp: replace the page lock with the seqlock for the THP mapcount (Andrea Arcangeli) [1958020]
- mm: do_wp_page: deduplicate smart_lock_page (Andrea Arcangeli) [1958020]
- mm: hugetlbfs: gup_must_unshare() cleanup (Andrea Arcangeli) [1958020]
- mm: GUP: cleanup FOLL_UNSHARE (Andrea Arcangeli) [1958020]
- mm: COW: skip the page lock in the COW copy path (Andrea Arcangeli) [1958020]
- mm: gup: gup_must_unshare() use can_read_pin_swap_page() (Andrea Arcangeli) [1958020]
- mm: hugetlbfs: gup: gup_must_unshare(): enable hugetlbfs (Andrea Arcangeli) [1958020]
- mm: hugetlbfs: FOLL_FAULT_UNSHARE (Andrea Arcangeli) [1958020]
- mm: hugetlbfs: COR: copy-on-read fault (Andrea Arcangeli) [1958020]
- mm: gup: FOLL_UNSHARE RHEL (Andrea Arcangeli) [1958020]
- mm: gup: FOLL_NOUNSHARE: optimize follow_page (Andrea Arcangeli) [1958020]
- mm: gup: FOLL_UNSHARE (Andrea Arcangeli) [1958020]
- mm: gup: gup_must_unshare() (Andrea Arcangeli) [1958020]
- mm: gup: COR: copy-on-read fault (Andrea Arcangeli) [1958020]
- mm: thp: introduce page_trans_huge_anon_shared (Andrea Arcangeli) [1958020]
- mm: thp: stabilize the THP mapcount in page_remove_anon_compound_rmap (Andrea Arcangeli) [1958020]
- mm: thp: make the THP mapcount atomic with a seqlock (Andrea Arcangeli) [1958020]
- mm: thp: consolidate mapcount logic on THP split (David Hildenbrand) [1958020]
- vmxnet3: Remove useless DMA-32 fallback configuration (Kamal Heib) [2083561]
- vmxnet3: fix minimum vectors alloc issue (Kamal Heib) [2083561]
- net: vmxnet3: remove multiple false checks in vmxnet3_ethtool.c (Kamal Heib) [2083561]
- vmxnet3: do not stop tx queues after netif_device_detach() (Kamal Heib) [2083561]
- block: limit request dispatch loop duration (Ming Lei) [2005082]
- esp: limit skb_page_frag_refill use to a single page (Sabrina Dubroca) [2062115] {CVE-2022-27666}
- esp: Fix possible buffer overflow in ESP transformation (Sabrina Dubroca) [2062115] {CVE-2022-27666}
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb() in error path (Chris von Recklinghausen) [2080376] {CVE-2022-28390}
- NFSD: Deprecate NFS_OFFSET_MAX (Scott Mayhew) [2064216]
- NFSD: Fix offset type in I/O trace points (Scott Mayhew) [2064216]
- NFSD: COMMIT operations must not return NFS?ERR_INVAL (Scott Mayhew) [2064216]
- NFSD: Clamp WRITE offsets (Scott Mayhew) [2064216]
- NFSD: Fix NFSv3 SETATTR/CREATE's handling of large file sizes (Scott Mayhew) [2064216]
- NFSD: Fix ia_size underflow (Scott Mayhew) [2064216]
- NFSD: Fix the behavior of READ near OFFSET_MAX (Scott Mayhew) [2064216]
- NFSD: Fix READDIR buffer overflow (Scott Mayhew) [2064216]
- nfsd: Fix nsfd startup race (again) (Scott Mayhew) [2064216]
- NFS: Add a tracepoint to show the results of nfs_set_cache_invalid() (Scott Mayhew) [2064216]
- NFSv42: Don't fail clone() unless the OP_CLONE operation failed (Scott Mayhew) [2064216]
- NFSD: Fix exposure in nfsd4_decode_bitmap() (Scott Mayhew) [2064216]
- NFSv4: Sanity check the parameters in nfs41_update_target_slotid() (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label argument from decode_getattr_*() functions (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label argument from nfs_setsecurity (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label argument from nfs_fhget() (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label argument from nfs_add_or_obtain() (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label argument from nfs_instantiate() (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label from the nfs_setattrres (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label from the nfs4_getattr_res (Scott Mayhew) [2064216]
- NFS: Remove the f_label from the nfs4_opendata and nfs_openres (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label from the nfs4_lookupp_res struct (Scott Mayhew) [2064216]
- NFS: Remove the label from the nfs4_lookup_res struct (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label from the nfs4_link_res struct (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label from the nfs4_create_res struct (Scott Mayhew) [2064216]
- NFS: Remove the nfs4_label from the nfs_entry struct (Scott Mayhew) [2064216]
- NFS: Create a new nfs_alloc_fattr_with_label() function (Scott Mayhew) [2064216]
- NFS: Always initialise fattr->label in nfs_fattr_alloc() (Scott Mayhew) [2064216]
- NFSv4: Remove unnecessary 'minor version' check (Scott Mayhew) [2064216]
- NFSv4: Fix potential Oops in decode_op_map() (Scott Mayhew) [2064216]
- NFSv4: Ensure decode_compound_hdr() sanity checks the tag (Scott Mayhew) [2064216]
- NFS: Don't trace an uninitialised value (Scott Mayhew) [2064216]
- NFSv4.2 add tracepoint to OFFLOAD_CANCEL (Scott Mayhew) [2064216]
- NFSv4.2 add tracepoint to CB_OFFLOAD (Scott Mayhew) [2064216]
- NFSv4.2 add tracepoint to CLONE (Scott Mayhew) [2064216]
- NFSv4.2 add tracepoint to COPY (Scott Mayhew) [2064216]
- NFSv4.2 add tracepoints to FALLOCATE and DEALLOCATE (Scott Mayhew) [2064216]
- NFSv4.2 add tracepoint to SEEK (Scott Mayhew) [2064216]
- nfs4: take a reference on the nfs_client when running FREE_STATEID (Scott Mayhew) [2064216]
- NFS: Move NFS protocol display macros to global header (Scott Mayhew) [2064216]
- NFS: Move generic FS show macros to global header (Scott Mayhew) [2064216]
- SUNRPC: Clean up xs_tcp_setup_sock() (Scott Mayhew) [2064216]
- NFSv4: Fix a regression in nfs_set_open_stateid_locked() (Scott Mayhew) [2064216]
- NFS: Remove redundant call to __set_page_dirty_nobuffers (Scott Mayhew) [2064216]
- NFS: Unexport nfs_probe_fsinfo() (Scott Mayhew) [2064216]
- NFS: Call nfs_probe_server() during a fscontext-reconfigure event (Scott Mayhew) [2064216]
- NFS: Replace calls to nfs_probe_fsinfo() with nfs_probe_server() (Scott Mayhew) [2064216]
- NFS: Move nfs_probe_destination() into the generic client (Scott Mayhew) [2064216]
- NFS: Create an nfs4_server_set_init_caps() function (Scott Mayhew) [2064216]
- NFS: Remove --> and <-- dprintk call sites (Scott Mayhew) [2064216]
- SUNRPC: Trace calls to .rpc_call_done (Scott Mayhew) [2064216]
- NFS: Replace dprintk callsites in nfs_readpage(s) (Scott Mayhew) [2064216]
- SUNRPC: Use BIT() macro in rpc_show_xprt_state() (Scott Mayhew) [2064216]
- SUNRPC: Tracepoints should display tk_pid and cl_clid as a fixed-size field (Scott Mayhew) [2064216]
- xprtrdma: Remove rpcrdma_ep::re_implicit_roundup (Scott Mayhew) [2064216]
- xprtrdma: Provide a buffer to pad Write chunks of unaligned length (Scott Mayhew) [2064216]
- Fix user namespace leak (Scott Mayhew) [2064216]
- NFS: Save some space in the inode (Scott Mayhew) [2064216]
- NFS: Fix WARN_ON due to unionization of nfs_inode.nrequests (Scott Mayhew) [2064216]
- NFSv4: Fixes for nfs4_inode_return_delegation() (Scott Mayhew) [2064216]
- NFS: Fix an Oops in pnfs_mark_request_commit() (Scott Mayhew) [2064216]
- NFS: Fix up commit deadlocks (Scott Mayhew) [2064216]
- NFSD:fix boolreturn.cocci warning (Scott Mayhew) [2064216]
- nfsd: update create verifier comment (Scott Mayhew) [2064216]
- SUNRPC: Change return value type of .pc_encode (Scott Mayhew) [2064216]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_encode (Scott Mayhew) [2064216]
- NFSD: Save location of NFSv4 COMPOUND status (Scott Mayhew) [2064216]
- SUNRPC: Change return value type of .pc_decode (Scott Mayhew) [2064216]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_decode (Scott Mayhew) [2064216]
- SUNRPC: De-duplicate .pc_release() call sites (Scott Mayhew) [2064216]
- SUNRPC: Simplify the SVC dispatch code path (Scott Mayhew) [2064216]
- NFS: Fix deadlocks in nfs_scan_commit_list() (Scott Mayhew) [2064216]
- NFS: Instrument i_size_write() (Scott Mayhew) [2064216]
- SUNRPC: Per-rpc_clnt task PIDs (Scott Mayhew) [2064216]
- NFS: Remove unnecessary TRACE_DEFINE_ENUM()s (Scott Mayhew) [2064216]
- SUNRPC: Capture value of xdr_buf::page_base (Scott Mayhew) [2064216]
- svcrdma: Split svcrmda_wc_{read,write} tracepoints (Scott Mayhew) [2064216]
- svcrdma: Split the svcrdma_wc_send() tracepoint (Scott Mayhew) [2064216]
- svcrdma: Split the svcrdma_wc_receive() tracepoint (Scott Mayhew) [2064216]
- pnfs/flexfiles: Fix misplaced barrier in nfs4_ff_layout_prepare_ds (Scott Mayhew) [2064216]
- NFS: Remove unnecessary page cache invalidations (Scott Mayhew) [2064216]
- NFS: Fix dentry verifier races (Scott Mayhew) [2064216]
- NFS: Further optimisations for 'ls -l' (Scott Mayhew) [2064216]
- NFS: Fix up nfs_readdir_inode_mapping_valid() (Scott Mayhew) [2064216]
- NFS: Ignore the directory size when marking for revalidation (Scott Mayhew) [2064216]
- NFS: Don't set NFS_INO_DATA_INVAL_DEFER and NFS_INO_INVALID_DATA (Scott Mayhew) [2064216]
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED (Scott Mayhew) [2064216]
- NFSv4: Retrieve ACCESS on open if we're not using NFS4_CREATE_EXCLUSIVE (Scott Mayhew) [2064216]
- NFS: Fix a few more clear_bit() instances that need release semantics (Scott Mayhew) [2064216]
- SUNRPC: xprt_clear_locked() only needs release memory semantics (Scott Mayhew) [2064216]
- SUNRPC: Remove unnecessary memory barriers (Scott Mayhew) [2064216]
- SUNRPC: Remove WQ_HIGHPRI from xprtiod (Scott Mayhew) [2064216]
- SUNRPC: Add cond_resched() at the appropriate point in __rpc_execute() (Scott Mayhew) [2064216]
- SUNRPC: Partial revert of commit 6f9f17287e78 (Scott Mayhew) [2064216]
- NFS: Fix up nfs_ctx_key_to_expire() (Scott Mayhew) [2064216]
- NFS: Label the dentry with a verifier in nfs_rmdir() and nfs_unlink() (Scott Mayhew) [2064216]
- NFS: Label the dentry with a verifier in nfs_link(), nfs_symlink() (Scott Mayhew) [2064216]
- NFSD: Have legacy NFSD WRITE decoders use xdr_stream_subsegment() (Scott Mayhew) [2064216]
- SUNRPC: xdr_stream_subsegment() must handle non-zero page_bases (Scott Mayhew) [2064216]
- NFSD: simplify struct nfsfh (Scott Mayhew) [2064216]
- NFSD: drop support for ancient filehandles (Scott Mayhew) [2064216]
- NFSD: move filehandle format declarations out of "uapi". (Scott Mayhew) [2064216]
- UNRPC: Return specific error code on kmalloc failure (Scott Mayhew) [2064216]
- NFSD: Optimize DRC bucket pruning (Scott Mayhew) [2064216]
- nfsd: don't alloc under spinlock in rpc_parse_scope_id (Scott Mayhew) [2064216]
- NFSD: Keep existing listeners on portlist error (Scott Mayhew) [2064216]
- nfs: Fix kerneldoc warning shown up by W=1 (Scott Mayhew) [2064216]
- nfsd: back channel stuck in SEQ4_STATUS_CB_PATH_DOWN (Scott Mayhew) [2064216]
- NLM: Fix svcxdr_encode_owner() (Scott Mayhew) [2064216]
- SUNRPC: improve error response to over-size gss credential (Scott Mayhew) [2064216]
- NFS: Always provide aligned buffers to the RPC read layers (Scott Mayhew) [2064216]
- NFSv3: Delete duplicate judgement in nfs3_async_handle_jukebox (Scott Mayhew) [2064216]
- SUNRPC: Tweak TCP socket shutdown in the RPC client (Scott Mayhew) [2064216]
- svcrdma: xpt_bc_xprt is already clear in __svc_rdma_free() (Scott Mayhew) [2064216]
- rpc: fix gss_svc_init cleanup on failure (Scott Mayhew) [2064216]
- SUNRPC: Add RPC_AUTH_TLS protocol numbers (Scott Mayhew) [2064216]
- NFSD: remove vanity comments (Scott Mayhew) [2064216]
- svcrdma: Convert rdma->sc_rw_ctxts to llist (Scott Mayhew) [2064216]
- svcrdma: Relieve contention on sc_send_lock. (Scott Mayhew) [2064216]
- svcrdma: Fewer calls to wake_up() in Send completion handler (Scott Mayhew) [2064216]
- NFSD: Use new __string_len C macros for nfsd_clid_class (Scott Mayhew) [2064216]
- NFSD: Use new __string_len C macros for the nfs_dirent tracepoint (Scott Mayhew) [2064216]
- tracing: Add trace_event helper macros __string_len() and __assign_str_len() (Scott Mayhew) [2064216]
- NFSD: Clean up splice actor (Scott Mayhew) [2064216]
- NFS: Clean up the synopsis of callback process_op() (Scott Mayhew) [2064216]
- NFS: Extract the xdr_init_encode/decode() calls from decode_compound (Scott Mayhew) [2064216]
- NFS: Remove unused callback void decoder (Scott Mayhew) [2064216]
- NFS: Add a private local dispatcher for NFSv4 callback operations (Scott Mayhew) [2064216]
- SUNRPC: Eliminate the RQ_AUTHERR flag (Scott Mayhew) [2064216]
- SUNRPC: Set rq_auth_stat in the pg_authenticate() callout (Scott Mayhew) [2064216]
- SUNRPC: Add svc_rqst::rq_auth_stat (Scott Mayhew) [2064216]
- NFSv4/pNFS: Remove dead code (Scott Mayhew) [2064216]
- SUNRPC: Convert rpc_client refcount to use refcount_t (Scott Mayhew) [2064216]
- xprtrdma: Eliminate rpcrdma_post_sends() (Scott Mayhew) [2064216]
- xprtrdma: Add an xprtrdma_post_send_err tracepoint (Scott Mayhew) [2064216]
- xprtrdma: Add xprtrdma_post_recvs_err() tracepoint (Scott Mayhew) [2064216]
- xprtrdma: Add an rpcrdma_mr_completion_class (Scott Mayhew) [2064216]
- xprtrdma: Don't display r_xprt memory addresses in tracepoints (Scott Mayhew) [2064216]
- xprtrdma: Disconnect after an ib_post_send() immediate error (Scott Mayhew) [2064216]
- SUNRPC: Record timeout value in xprt_retransmit tracepoint (Scott Mayhew) [2064216]
- SUNRPC: xprt_retransmit() displays the the NULL procedure incorrectly (Scott Mayhew) [2064216]
- treewide: Add missing semicolons to __assign_str uses (Scott Mayhew) [2064216]
- SUNRPC: Remove unneeded TRACE_DEFINE_ENUMs (Scott Mayhew) [2064216]
- SUNRPC: Unset RPC_TASK_NO_RETRANS_TIMEOUT for NULL RPCs (Scott Mayhew) [2064216]
- SUNRPC: Refactor rpc_ping() (Scott Mayhew) [2064216]
- nfsd: fix NULL dereference in nfs3svc_encode_getaclres (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 SHARE results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 nlm_res results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 TEST results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 void results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 FREE_ALL arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 SHARE arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 SM_NOTIFY arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 nlm_res arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 UNLOCK arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 CANCEL arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 LOCK arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 TEST arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv4 void arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 SHARE results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 nlm_res results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 TEST results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 void results encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 FREE_ALL arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 SHARE arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 SM_NOTIFY arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 nlm_res arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 UNLOCK arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 CANCEL arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 LOCK arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 TEST arguments decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Update the NLMv1 void argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- lockd: Common NLM XDR helpers (Scott Mayhew) [2064216]
- lockd: Create a simplified .vs_dispatch method for NLM requests (Scott Mayhew) [2064216]
- lockd: Remove stale comments (Scott Mayhew) [2064216]
- nfsd: rpc_peeraddr2str needs rcu lock (Scott Mayhew) [2064216]
- rpc: remove redundant initialization of variable status (Scott Mayhew) [2064216]
- NFSv4: setlease should return EAGAIN if locks are not available (Scott Mayhew) [2064216]
- NFS: Avoid duplicate resets of attribute cache timeouts (Scott Mayhew) [2064216]
- NFSv4: Fix handling of non-atomic change attrbute updates (Scott Mayhew) [2064216]
- NFS: Fix up inode attribute revalidation timeouts (Scott Mayhew) [2064216]
- NFSv4: Add support for application leases underpinned by a delegation (Scott Mayhew) [2064216]
- NFSv4: Add lease breakpoints in case of a delegation recall or return (Scott Mayhew) [2064216]
- NFSv4: Fix delegation return in cases where we have to retry (Scott Mayhew) [2064216]
- nfsd: move some commit_metadata()s outside the inode lock (Scott Mayhew) [2064216]
- NFSD: Update nfsd_cb_args tracepoint (Scott Mayhew) [2064216]
- NFSD: Remove the nfsd_cb_work and nfsd_cb_done tracepoints (Scott Mayhew) [2064216]
- NFSD: Add an nfsd_cb_probe tracepoint (Scott Mayhew) [2064216]
- NFSD: Replace the nfsd_deleg_break tracepoint (Scott Mayhew) [2064216]
- NFSD: Add an nfsd_cb_offload tracepoint (Scott Mayhew) [2064216]
- NFSD: Add an nfsd_cb_lm_notify tracepoint (Scott Mayhew) [2064216]
- NFSD: Enhance the nfsd_cb_setup tracepoint (Scott Mayhew) [2064216]
- NFSD: Remove spurious cb_setup_err tracepoint (Scott Mayhew) [2064216]
- NFSD: Adjust cb_shutdown tracepoint (Scott Mayhew) [2064216]
- NFSD: Add cb_lost tracepoint (Scott Mayhew) [2064216]
- NFSD: Drop TRACE_DEFINE_ENUM for NFSD4_CB_<state> macros (Scott Mayhew) [2064216]
- NFSD: Capture every CB state transition (Scott Mayhew) [2064216]
- NFSD: Constify @fh argument of knfsd_fh_hash() (Scott Mayhew) [2064216]
- NFSD: Add tracepoints for EXCHANGEID edge cases (Scott Mayhew) [2064216]
- NFSD: Add tracepoints for SETCLIENTID edge cases (Scott Mayhew) [2064216]
- NFSD: Add a couple more nfsd_clid_expired call sites (Scott Mayhew) [2064216]
- NFSD: Add nfsd_clid_destroyed tracepoint (Scott Mayhew) [2064216]
- NFSD: Add nfsd_clid_reclaim_complete tracepoint (Scott Mayhew) [2064216]
- NFSD: Add nfsd_clid_confirmed tracepoint (Scott Mayhew) [2064216]
- NFSD: Remove trace_nfsd_clid_inuse_err (Scott Mayhew) [2064216]
- NFSD: Add nfsd_clid_verf_mismatch tracepoint (Scott Mayhew) [2064216]
- NFSD: Add nfsd_clid_cred_mismatch tracepoint (Scott Mayhew) [2064216]
- NFSD: Add an RPC authflavor tracepoint display helper (Scott Mayhew) [2064216]
- NFS: Ensure the NFS_CAP_SECURITY_LABEL capability is set when appropriate (Scott Mayhew) [2064216]
- NFS: Split attribute support out from the server capabilities (Scott Mayhew) [2064216]
- NFS: Don't store NFS_INO_REVAL_FORCED (Scott Mayhew) [2064216]
- NFSv4: link must update the inode nlink. (Scott Mayhew) [2064216]
- NFSv4: nfs4_inc/dec_nlink_locked should also invalidate ctime (Scott Mayhew) [2064216]
- NFS: Another inode revalidation improvement (Scott Mayhew) [2064216]
- NFS: Use information about the change attribute to optimise updates (Scott Mayhew) [2064216]
- NFSv4: Add support for the NFSv4.2 "change_attr_type" attribute (Scott Mayhew) [2064216]
- NFS: Simplify cache consistency in nfs_check_inode_attributes() (Scott Mayhew) [2064216]
- NFS: Remove a line of code that has no effect in nfs_update_inode() (Scott Mayhew) [2064216]
- NFS: Fix up handling of outstanding layoutcommit in nfs_update_inode() (Scott Mayhew) [2064216]
- NFS: Separate tracking of file mode cache validity from the uid/gid (Scott Mayhew) [2064216]
- NFS: Separate tracking of file nlinks cache validity from the mode/uid/gid (Scott Mayhew) [2064216]
- NFSv4: Fix nfs4_bitmap_copy_adjust() (Scott Mayhew) [2064216]
- NFS: Don't set NFS_INO_REVAL_PAGECACHE in the inode cache validity (Scott Mayhew) [2064216]
- NFS: Replace use of NFS_INO_REVAL_PAGECACHE when checking cache validity (Scott Mayhew) [2064216]
- NFS: Add a cache validity flag argument to nfs_revalidate_inode() (Scott Mayhew) [2064216]
- NFS: nfs_setattr_update_inode() should clear the suid/sgid bits (Scott Mayhew) [2064216]
- NFS: Fix up statx() results (Scott Mayhew) [2064216]
- NFS: Don't revalidate attributes that are not being asked for (Scott Mayhew) [2064216]
- NFSD: Clean up after updating NFSv3 ACL encoders (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 SETACL result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 GETACL result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Clean up after updating NFSv2 ACL encoders (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 ACL ACCESS result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 ACL GETATTR result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 SETACL result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 GETACL result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Add an xdr_stream-based encoder for NFSv2/3 ACLs (Scott Mayhew) [2064216]
- NFSD: Remove unused NFSv2 directory entry encoders (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READDIR entry encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READDIR result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Count bytes instead of pages in the NFSv2 READDIR encoder (Scott Mayhew) [2064216]
- NFSD: Add a helper that encodes NFSv3 directory offset cookies (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 STATFS result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READ result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READLINK result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 diropres encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 attrstat encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 stat encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Reduce svc_rqst::rq_pages churn during READDIR operations (Scott Mayhew) [2064216]
- NFSD: Remove unused NFSv3 directory entry encoders (Scott Mayhew) [2064216]
- NFSD: Update NFSv3 READDIR entry encoders to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 READDIR3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Count bytes instead of pages in the NFSv3 READDIR encoder (Scott Mayhew) [2064216]
- NFSD: Add a helper that encodes NFSv3 directory offset cookies (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 COMMIT3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 PATHCONF3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 FSINFO3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 FSSTAT3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 LINK3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 RENAMEv3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 CREATE family of encoders to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 WRITE3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 READ3res encode to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 READLINK3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 wccstat result encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 LOOKUP3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 ACCESS3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the GETATTR3res encoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Extract the svcxdr_init_encode() helper (Scott Mayhew) [2064216]
- NFSD: Clean up after updating NFSv3 ACL decoders (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 SETACL argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 GETACL argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Clean up after updating NFSv2 ACL decoders (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 ACL ACCESS argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 ACL GETATTR argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 SETACL argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Add an xdr_stream-based decoder for NFSv2/3 ACLs (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 GETACL argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Remove argument length checking in nfsd_dispatch() (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 SYMLINK argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 CREATE argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 SETATTR argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 LINK argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 RENAME argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update NFSv2 diropargs decoding to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READDIR argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Add helper to set up the pages where the dirlist is encoded (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READLINK argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 WRITE argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 READ argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv2 GETATTR argument decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the MKNOD3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the SYMLINK3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the MKDIR3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the CREATE3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the SETATTR3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the LINK3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the RENAME3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update the NFSv3 DIROPargs decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update COMMIT3arg decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update READDIR3args decoders to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Add helper to set up the pages where the dirlist is encoded (Scott Mayhew) [2064216]
- NFSD: Fix returned READDIR offset cookie (Scott Mayhew) [2064216]
- NFSD: Update READLINK3arg decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update WRITE3arg decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update READ3arg decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update ACCESS3arg decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- NFSD: Update GETATTR3args decoder to use struct xdr_stream (Scott Mayhew) [2064216]
- SUNRPC: Move definition of XDR_UNIT (Scott Mayhew) [2064216]
- rpcrdma: Capture bytes received in Receive completion tracepoints (Scott Mayhew) [2064216]
- NFSD: Restore NFSv4 decoding's SAVEMEM functionality (Scott Mayhew) [2064216]
- NFSD: Remove macros that are no longer used (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_compound() (Scott Mayhew) [2064216]
- NFSD: Make nfsd4_ops::opnum a u32 (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_listxattrs() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_setxattr() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_xattr_name() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_clone() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_seek() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_offload_status() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_copy() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_fallocate() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_reclaim_complete() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_destroy_clientid() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_test_stateid() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_sequence() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_secinfo_no_name() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_layoutreturn() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_layoutget() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_layoutcommit() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_getdeviceinfo() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_free_stateid() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_destroy_session() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_create_session() (Scott Mayhew) [2064216]
- NFSD: Add a helper to decode channel_attrs4 (Scott Mayhew) [2064216]
- NFSD: Add a helper to decode nfs_impl_id4 (Scott Mayhew) [2064216]
- NFSD: Add a helper to decode state_protect4_a (Scott Mayhew) [2064216]
- NFSD: Add a separate decoder for ssv_sp_parms (Scott Mayhew) [2064216]
- NFSD: Add a separate decoder to handle state_protect_ops (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_bind_conn_to_session() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_backchannel_ctl() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_cb_sec() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_release_lockowner() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_write() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_verify() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_setclientid_confirm() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_setclientid() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_setattr() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_secinfo() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_renew() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_rename() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_remove() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_readdir() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_read() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_putfh() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_open_downgrade() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_open_confirm() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_open() (Scott Mayhew) [2064216]
- NFSD: Add helper to decode OPEN's open_claim4 argument (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_share_deny() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_share_access() (Scott Mayhew) [2064216]
- NFSD: Add helper to decode OPEN's openflag4 argument (Scott Mayhew) [2064216]
- NFSD: Add helper to decode OPEN's createhow4 argument (Scott Mayhew) [2064216]
- NFSD: Add helper to decode NFSv4 verifiers (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_lookup() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_locku() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_lockt() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_lock() (Scott Mayhew) [2064216]
- NFSD: Add helper for decoding locker4 (Scott Mayhew) [2064216]
- NFSD: Add helpers to decode a clientid4 and an NFSv4 state owner (Scott Mayhew) [2064216]
- NFSD: Relocate nfsd4_decode_opaque() (Scott Mayhew) [2064216]
-  NFSD: Replace READ* macros in nfsd4_decode_link() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_getattr() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_delegreturn() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_create() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_fattr() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 umask attribute (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 security label attribute (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 time_set attributes (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 owner_group attribute (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 owner attribute (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 mode attribute (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 acl attribute (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros that decode the fattr4 size attribute (Scott Mayhew) [2064216]
- NFSD: Change the way the expected length of a fattr4 is checked (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_commit() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_close() (Scott Mayhew) [2064216]
- NFSD: Replace READ* macros in nfsd4_decode_access() (Scott Mayhew) [2064216]
- NFSD: Replace the internals of the READ_BUF() macro (Scott Mayhew) [2064216]
- nfsd/nfs3: remove unused macro nfsd3_fhandleres (Scott Mayhew) [2064216]
- vt: vt_ioctl: fix race in VT_RESIZEX (Čestmír Kalina) [2068338]
- net/mlx5: Bridge, Fix devlink deadlock on net namespace deletion (Amir Tzin) [2055580]
- openvswitch: Fix setting ipv6 fields causing hw csum failure (Eelco Chaudron) [1974356]

* Wed May 18 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-393.el8]
- Fix up versioning for maintainer builds (Jarod Wilson)
- powerpc/iommu: Enable remaining IOMMU Pagesizes present in LoPAR (Gustavo Walbon) [1987109]
- sizes.h: add SZ_8G/SZ_16G/SZ_32G macros (Gustavo Walbon) [1987109]
- x86/cpu: Add Xeon Icelake-D to list of CPUs that support PPIN (Puneet Sethi) [2040336]
- dm integrity: fix memory corruption when tag_size is less than digest size (Benjamin Marzinski) [2081775]
- sctp: check asoc strreset_chunk in sctp_generate_reconf_event (Xin Long) [2079980]
- sctp: Initialize daddr on peeled off socket (Xin Long) [2079980]
- sctp: fix kernel-infoleak for SCTP sockets (Xin Long) [2079980]
- sctp: do not update transport pathmtu if SPP_PMTUD_ENABLE is not set (Xin Long) [2079980]
- dm crypt: fix copy and paste bug in crypt_alloc_req_aead (Benjamin Marzinski) [2073431]
- dm crypt: defer decryption to a tasklet if interrupts disabled (Benjamin Marzinski) [2073431]
- dm crypt: do not call bio_endio() from the dm-crypt tasklet (Benjamin Marzinski) [2073431]
- dm crypt: use GFP_ATOMIC when allocating crypto requests from softirq (Benjamin Marzinski) [2073431]
- dm crypt: do not wait for backlogged crypto request completion in softirq (Benjamin Marzinski) [2073431]
- dm crypt: document new no_workqueue flags (Benjamin Marzinski) [2073431]
- dm crypt: add flags to optionally bypass kcryptd workqueues (Benjamin Marzinski) [2073431]
- tracing/osnoise: Force quiescent states while tracing (Jerome Marchand) [2069710]
- tracing/osnoise: Do not unregister events twice (Jerome Marchand) [2069710]
- tracing/osnoise: Make osnoise_main to sleep for microseconds (Jerome Marchand) [2069710]
- tracing/osnoise: Properly unhook events if start_per_cpu_kthreads() fails (Jerome Marchand) [2069710]
- tracing/osnoise: Make osnoise_instances static (Jerome Marchand) [2069710]
- tracing/osnoise: Remove PREEMPT_RT ifdefs from inside functions (Jerome Marchand) [2069710]
- tracing/osnoise: Remove STACKTRACE ifdefs from inside functions (Jerome Marchand) [2069710]
- tracing/osnoise: Allow multiple instances of the same tracer (Jerome Marchand) [2069710]
- tracing/osnoise: Remove TIMERLAT ifdefs from inside functions (Jerome Marchand) [2069710]
- tracing/osnoise: Support a list of trace_array *tr (Jerome Marchand) [2069710]
- tracing/osnoise: Use start/stop_per_cpu_kthreads() on osnoise_cpus_write() (Jerome Marchand) [2069710]
- tracing/osnoise: Split workload start from the tracer start (Jerome Marchand) [2069710]
- tracing/osnoise: Improve comments about barrier need for NMI callbacks (Jerome Marchand) [2069710]
- tracing/osnoise: Do not follow tracing_cpumask (Jerome Marchand) [2069710]
- trace/timerlat: Add migrate-disabled field to the timerlat header (Jerome Marchand) [2069710]
- trace/osnoise: Add migrate-disabled field to the osnoise header (Jerome Marchand) [2069710]
- tracing/doc: Fix typos on the timerlat tracer documentation (Jerome Marchand) [2069710]
- trace/osnoise: Fix an ifdef comment (Jerome Marchand) [2069710]
- redhat: indicate HEAD state in tarball/rpm name (Jarod Wilson)
- selftest: net: Test IPv4 PMTU exceptions with DSCP and ECN (Guillaume Nault) [2081453]
- ipv4: Fix route lookups when handling ICMP redirects and PMTU updates (Guillaume Nault) [2081453]
- ipv4: tcp: send zero IPID in SYNACK messages (Guillaume Nault) [2081453]
- ipv4: raw: lock the socket in raw_bind() (Guillaume Nault) [2081453]
- net/af_packet: add VLAN support for AF_PACKET SOCK_RAW GSO (Hangbin Liu) [2066976]
- net/packet: fix packet_sock xmit return value checking (Hangbin Liu) [2066976]
- doc/ip-sysctl: add bc_forwarding (Xin Long) [2080486]
- net/packet: fix packet_sock xmit return value checking (Xin Long) [2080486]
- net: handle ARPHRD_PIMREG in dev_is_mac_header_xmit() (Xin Long) [2080486]
- net/packet: fix slab-out-of-bounds access in packet_recvmsg() (Xin Long) [2080486]
- veth: fix races around rq->rx_notify_masked (Xin Long) [2080486]
- af_packet: fix data-race in packet_setsockopt / packet_setsockopt (Xin Long) [2080486]
- ipv4: remove sparse error in ip_neigh_gw4() (Xin Long) [2080486]
- af_unix: annote lockless accesses to unix_tot_inflight & gc_in_progress (Xin Long) [2080486]
- veth: Do not record rx queue hint in veth_xmit (Xin Long) [2080486]
- veth: ensure skb entering GRO are not cloned. (Xin Long) [2080486]
- ethtool: Fix link extended state for big endian (Xin Long) [2080486]
- ethtool: do not perform operations on net devices being unregistered (Xin Long) [2080486]
- ethtool: Add transceiver module extended state (Xin Long) [2080486]
- ethtool: runtime-resume netdev parent in ethnl_ops_begin (Xin Long) [2080486]
- ethtool: move netif_device_present check from ethnl_parse_header_dev_get to ethnl_ops_begin (Xin Long) [2080486]
- ethtool: move implementation of ethnl_ops_begin/complete to netlink.c (Xin Long) [2080486]
- net: validate lwtstate->data before returning from skb_tunnel_info() (Xin Long) [2080486]

* Tue May 17 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-392.el8]
- bnx2x: fix napi API usage sequence (Manish Chopra) [2080659]
- netfilter: fix use-after-free in __nf_register_net_hook() (Florian Westphal) [2080272]
- netfilter: nf_tables: unregister flowtable hooks on netns exit (Florian Westphal) [2080272]
- netfilter: nftables: add helper function to release hooks of one single table (Florian Westphal) [2080272]
- netfilter: nft_socket: only do sk lookups when indev is available (Florian Westphal) [2080272]
- netfilter: nf_conntrack_tcp: re-init for syn packets only (Florian Westphal) [2080272]
- netfilter: nft_set_rbtree: overlap detection with element re-addition after deletion (Florian Westphal) [2080272]
- netfilter: nf_tables: fix memory leak during stateful obj update (Florian Westphal) [2080272]
- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp options (Florian Westphal) [2080272]
- netfilter: ctnetlink: disable helper autoassign (Florian Westphal) [2080272]
- netfilter: nft_payload: don't allow th access for fragments (Florian Westphal) [2080272]
- netfilter: nft_payload: simplify vlan header handling (Florian Westphal) [2080272]
- RDMA/rxe: Change mcg_lock to a _bh lock (Kamal Heib) [2056500]
- RDMA/rxe: Do not call dev_mc_add/del() under a spinlock (Kamal Heib) [2056500]
- RDMA/rxe: Recheck the MR in when generating a READ reply (Kamal Heib) [2056500]
- RDMA/rxe: Fix "Replace mr by rkey in responder resources" (Kamal Heib) [2056500]
- RDMA/siw: Fix a condition race issue in MPA request processing (Kamal Heib) [2056500]
- RDMA/irdma: Fix possible crash due to NULL netdev in notifier (Kamal Heib) [2056500]
- RDMA/irdma: Reduce iWARP QP destroy time (Kamal Heib) [2056500]
- RDMA/irdma: Flush iWARP QP if modified to ERR from RTR state (Kamal Heib) [2056500]
- RDMA/irdma: Fix deadlock in irdma_cleanup_cm_core() (Kamal Heib) [2056500]
- RDMA/hfi1: Fix use-after-free bug for mm struct (Kamal Heib) [2056500]
- IB/rdmavt: add lock to call to rvt_error_qp to prevent a race condition (Kamal Heib) [2056500]
- IB/cm: Cancel mad on the DREQ event when the state is MRA_REP_RCVD (Kamal Heib) [2056500]
- RDMA/nldev: Prevent underflow in nldev_stat_set_counter_dynamic_doit() (Kamal Heib) [2056500]
- IB/iser: Fix error flow in case of registration failure (Kamal Heib) [2056500]
- IB/iser: Generalize map/unmap dma tasks (Kamal Heib) [2056500]
- IB/iser: Use iser_fr_desc as registration context (Kamal Heib) [2056500]
- IB/iser: Remove iser_reg_data_sg helper function (Kamal Heib) [2056500]
- RDMA/rxe: Use standard names for ref counting (Kamal Heib) [2056500]
- RDMA/rxe: Replace red-black trees by xarrays (Kamal Heib) [2056500]
- RDMA/rxe: Shorten pool names in rxe_pool.c (Kamal Heib) [2056500]
- RDMA/rxe: Move max_elem into rxe_type_info (Kamal Heib) [2056500]
- RDMA/rxe: Replace obj by elem in declaration (Kamal Heib) [2056500]
- RDMA/rxe: Delete _locked() APIs for pool objects (Kamal Heib) [2056500]
- RDMA/rxe: Reverse the sense of RXE_POOL_NO_ALLOC (Kamal Heib) [2056500]
- RDMA/rxe: Replace mr by rkey in responder resources (Kamal Heib) [2056500]
- RDMA/rxe: Fix ref error in rxe_av.c (Kamal Heib) [2056500]
- RDMA/irdma: Add support for address handle re-use (Kamal Heib) [2056500]
- Revert "RDMA/core: Fix ib_qp_usecnt_dec() called when error" (Kamal Heib) [2056500]
- RDMA/rxe: Remove useless argument for update_state() (Kamal Heib) [2056500]
- RDMA/rxe: Change variable and function argument to proper type (Kamal Heib) [2056500]
- RDMA/irdma: Prevent some integer underflows (Kamal Heib) [2056500]
- RDMA/core: Fix ib_qp_usecnt_dec() called when error (Kamal Heib) [2056500]
- IB/hfi1: Allow larger MTU without AIP (Kamal Heib) [2056500]
- RDMA/core: Remove unnecessary statements (Kamal Heib) [2056500]
- RDMA/irdma: Remove incorrect masking of PD (Kamal Heib) [2056500]
- RDMA/irdma: Fix Passthrough mode in VM (Kamal Heib) [2056500]
- RDMA/irdma: Fix netdev notifications for vlan's (Kamal Heib) [2056500]
- RDMA/irdma: Make irdma_create_mg_ctx return a void (Kamal Heib) [2056500]
- RDMA/irdma: Move union irdma_sockaddr to header file (Kamal Heib) [2056500]
- RDMA/irdma: Remove the unnecessary variable saddr (Kamal Heib) [2056500]
- RDMA/irdma: Use net_type to check network type (Kamal Heib) [2056500]
- RDMA/rxe: Cleanup rxe_mcast.c (Kamal Heib) [2056500]
- RDMA/rxe: Collect cleanup mca code in a subroutine (Kamal Heib) [2056500]
- RDMA/rxe: Collect mca init code in a subroutine (Kamal Heib) [2056500]
- RDMA/rxe: Warn if mcast memory is not freed (Kamal Heib) [2056500]
- RDMA/irdma: Remove excess error variables (Kamal Heib) [2056500]
- RDMA/irdma: Propagate error codes (Kamal Heib) [2056500]
- RDMA/irdma: Remove enum irdma_status_code (Kamal Heib) [2056500]
- RDMA/ib_srp: Add more documentation (Kamal Heib) [2056500]
- IB/cma: Allow XRC INI QPs to set their local ACK timeout (Kamal Heib) [2056500]
- RDMA/rxe: Remove mcg from rxe pools (Kamal Heib) [2056500]
- RDMA/rxe: Remove key'ed object support (Kamal Heib) [2056500]
- RDMA/rxe: Replace pool key by rxe->mcg_tree (Kamal Heib) [2056500]
- RDMA/rxe: Replace int num_qp by atomic_t qp_num (Kamal Heib) [2056500]
- RDMA/rxe: Replace grp by mcg, mce by mca (Kamal Heib) [2056500]
- RDMA/rxe: Use kzmalloc/kfree for mca (Kamal Heib) [2056500]
- RDMA/rxe: Move mcg_lock to rxe (Kamal Heib) [2056500]
- RDMA/hfi: Replace cpumask_weight with cpumask_empty where appropriate (Kamal Heib) [2056500]
- RDMA/irdma: Refactor DCB bits in prep for DSCP support (Kamal Heib) [2056500]
- RDMA/opa: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/iser: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/ipoib: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/rxe: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/usnic: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/hfi1: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/core: Delete useless module.h include (Kamal Heib) [2056500]
- RDMA/core: Set MR type in ib_reg_user_mr (Kamal Heib) [2056500]
- md: Set MD_BROKEN for RAID1 and RAID10 (Nigel Croxon) [2042729]
- raid5: introduce MD_BROKEN (Nigel Croxon) [2042729]
- RHEL only Changes to support block changes not picked up (Nigel Croxon) [2042729]
- md: fix NULL pointer deref with nowait but no mddev->queue (Nigel Croxon) [2042729]
- md: use default_groups in kobj_type (Nigel Croxon) [2042729]
- md: Move alloc/free acct bioset in to personality (Nigel Croxon) [2042729]
- md: fix spelling of "its" (Nigel Croxon) [2042729]
- md: raid456 add nowait support (Nigel Croxon) [2042729]
- md: raid10 add nowait support (Nigel Croxon) [2042729]
- md: raid1 add nowait support (Nigel Croxon) [2042729]
- md: add support for REQ_NOWAIT (Nigel Croxon) [2042729]
- md/raid5: play nice with PREEMPT_RT (Nigel Croxon) [2042729]
- md/raid1: fix missing bitmap update w/o WriteMostly devices (Nigel Croxon) [2042729]
- md: fix double free of mddev->private in autorun_array() (Nigel Croxon) [2042729]
- md: fix update super 1.0 on rdev size change (Nigel Croxon) [2042729]
- raid5-ppl: use swap() to make code cleaner (Nigel Croxon) [2042729]
- md/bitmap: don't set max_write_behind if there is no write mostly device (Nigel Croxon) [2042729]
- md: update superblock after changing rdev flags in state_store (Nigel Croxon) [2042729]
- md: remove unused argument from md_new_event (Nigel Croxon) [2042729]
- md/raid5: call roundup_pow_of_two in raid5_run (Nigel Croxon) [2042729]
- md/raid1: use rdev in raid1_write_request directly (Nigel Croxon) [2042729]
- md/raid1: only allocate write behind bio for WriteMostly device (Nigel Croxon) [2042729]
- md: properly unwind when failing to add the kobject in md_alloc (Nigel Croxon) [2042729]
- md: extend disks_mutex coverage (Nigel Croxon) [2042729]
- md: add the bitmap group to the default groups for the md kobject (Nigel Croxon) [2042729]
- md: add error handling support for add_disk() (Nigel Croxon) [2042729]
- md: fix a lock order reversal in md_alloc (Nigel Croxon) [2042729]
- scsi: qedf: Stop using the SCSI pointer (Nilesh Javali) [2044843]
- scsi: qedf: Change context reset messages to ratelimited (Nilesh Javali) [2044843]
- scsi: qedf: Fix refcount issue when LOGO is received during TMF (Nilesh Javali) [2044843]
- scsi: qedf: Add stag_work to all the vports (Nilesh Javali) [2044843]
- scsi: qedf: Fix potential dereference of NULL pointer (Nilesh Javali) [2044843]
- eth: fwnode: remove the addr len from mac helpers (Íñigo Huguet) [2069565]
- eth: fwnode: change the return type of mac address helpers (Íñigo Huguet) [2069565]
- device property: move mac addr helpers to eth.c (Íñigo Huguet) [2069565]
- net: thunderx: Use fwnode_get_mac_address() (Íñigo Huguet) [2069565]
- qede: confirm skb is allocated before using (Manish Chopra) [2040267]
- qed: fix ethtool register dump (Manish Chopra) [2040267]
- qed: remove unnecessary memset in qed_init_fw_funcs (Manish Chopra) [2040267]
- qed: return status of qed_iov_get_link (Manish Chopra) [2040267]
- net: qlogic: check the return value of dma_alloc_coherent() in qed_vf_hw_prepare() (Manish Chopra) [2040267]
- qed: validate and restrict untrusted VFs vlan promisc mode (Manish Chopra) [2040267]
- qed: display VF trust config (Manish Chopra) [2040267]
- qed: prevent a fw assert during device shutdown (Manish Chopra) [2040267]
- qed: use msleep() in qed_mcp_cmd() and add qed_mcp_cmd_nosleep() for udelay. (Manish Chopra) [2040267]
- qed: Use dma_set_mask_and_coherent() and simplify code (Manish Chopra) [2040267]
- qed*: esl priv flag support through ethtool (Manish Chopra) [2040267]
- qed*: enhance tx timeout debug info (Manish Chopra) [2040267]
- qede: validate non LSO skb length (Manish Chopra) [2040267]
- qed: Enhance rammod debug prints to provide pretty details (Manish Chopra) [2040267]
- net: qed: fix the array may be out of bound (Manish Chopra) [2040267]
- qed: Use the bitmap API to simplify some functions (Manish Chopra) [2040267]
- RDMA/qed: Use helper function to set GUIDs (Manish Chopra) [2040267]
- net: qed_dev: fix check of true !rc expression (Manish Chopra) [2040267]
- net: qed_ptp: fix check of true !rc expression (Manish Chopra) [2040267]
- RDMA/qedr: Remove unsupported qedr_resize_cq callback (Manish Chopra) [2040267]
- qed: Change the TCP common variable - "iscsi_ooo" (Manish Chopra) [2040267]
- qed: Optimize the ll2 ooo flow (Manish Chopra) [2040267]
- net: qed_debug: fix check of false (grc_param < 0) expression (Manish Chopra) [2040267]
- qed: Fix missing error code in qed_slowpath_start() (Manish Chopra) [2040267]
- qed: Fix compilation for CONFIG_QED_SRIOV undefined scenario (Manish Chopra) [2040267]
- qed: Initialize debug string array (Manish Chopra) [2040267]
- qed: Fix spelling mistake "ctx_bsaed" -> "ctx_based" (Manish Chopra) [2040267]
- qed: fix ll2 establishment during load of RDMA driver (Manish Chopra) [2040267]
- qed: Update the TCP active termination 2 MSL timer ("TIME_WAIT") (Manish Chopra) [2040267]
- qed: Update TCP silly-window-syndrome timeout for iwarp, scsi (Manish Chopra) [2040267]
- qed: Update debug related changes (Manish Chopra) [2040267]
- qed: Add '_GTT' suffix to the IRO RAM macros (Manish Chopra) [2040267]
- qed: Update FW init functions to support FW 8.59.1.0 (Manish Chopra) [2040267]
- qed: Use enum as per FW 8.59.1.0 in qed_iro_hsi.h (Manish Chopra) [2040267]
- qed: Update qed_hsi.h for fw 8.59.1.0 (Manish Chopra) [2040267]
- qed: Update qed_mfw_hsi.h for FW ver 8.59.1.0 (Manish Chopra) [2040267]
- qed: Update common_hsi for FW ver 8.59.1.0 (Manish Chopra) [2040267]
- qed: Split huge qed_hsi.h header file (Manish Chopra) [2040267]
- qed: Remove e4_ and _e4 from FW HSI (Manish Chopra) [2040267]
- qed: Fix kernel-doc warnings (Manish Chopra) [2040267]
- qed: Don't ignore devlink allocation failures (Manish Chopra) [2040267]
- qed: Improve the stack space of filter_config() (Manish Chopra) [2040267]
- RDMA/qedr: Move variables reset to qedr_set_common_qp_params() (Manish Chopra) [2040267]
- ip_gre, ip6_gre: Fix race condition on o_seqno in collect_md mode (Guillaume Nault) [2081030]
- ip6_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081030]
- ip_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081030]
- ip6_gre: Fix skb_under_panic in __gre6_xmit() (Guillaume Nault) [2081030]
- ip6_gre: Avoid updating tunnel->tun_hlen in __gre6_xmit() (Guillaume Nault) [2081030]
- ipv6_tunnel: Rate limit warning messages (Guillaume Nault) [2081030]
- net: fix up skbs delta_truesize in UDP GRO frag_list (Hangbin Liu) [2082388]
- drop_monitor: fix data-race in dropmon_net_event / trace_napi_poll_hit (Hangbin Liu) [2082388]
- rtnetlink: make sure to refresh master_dev/m_ops in __rtnl_newlink() (Hangbin Liu) [2082388]
- netns: add schedule point in ops_exit_list() (Hangbin Liu) [2082388]
- lwtunnel: Validate RTA_ENCAP_TYPE attribute length (Hangbin Liu) [2082388]
- net, neigh: clear whole pneigh_entry at alloc time (Hangbin Liu) [2082388]
- net: annotate data-races on txq->xmit_lock_owner (Hangbin Liu) [2082388]
- sock: fix /proc/net/sockstat underflow in sk_clone_lock() (Hangbin Liu) [2082388]
- net: stream: don't purge sk_error_queue in sk_stream_kill_queues() (Hangbin Liu) [2082388]
- rtnetlink: fix if_nlmsg_stats_size() under estimation (Hangbin Liu) [2082388]
- net: watchdog: hold device global xmit lock during tx disable (Hangbin Liu) [2082388]
- torture: Fix incorrectly redirected "exit" in kvm-remote.sh (Waiman Long) [2065993]
- rcu: Allow rcu_irq_enter_check_tick() from NMI (Waiman Long) [2065993]
- srcu: Early test SRCU polling start (Waiman Long) [2065993]
- rcu/nocb: Unify timers (Waiman Long) [2065993]
- rcu/nocb: Prepare for fine-grained deferred wakeup (Waiman Long) [2065993]
- rcu/nocb: Only cancel nocb timer if not polling (Waiman Long) [2065993]
- rcu/nocb: Delete bypass_timer upon nocb_gp wakeup (Waiman Long) [2065993]
- rcu/nocb: Cancel nocb_timer upon nocb_gp wakeup (Waiman Long) [2065993]
- rcu/nocb: Allow de-offloading rdp leader (Waiman Long) [2065993]
- rcu/nocb: Directly call __wake_nocb_gp() from bypass timer (Waiman Long) [2065993]
- refscale: Avoid false-positive warnings in ref_scale_reader() (Waiman Long) [2065993]
- scftorture: Avoid false-positive warnings in scftorture_invoker() (Waiman Long) [2065993]
- rcu-tasks: Don't delete holdouts within trc_wait_for_one_reader() (Waiman Long) [2065993]
- rcu-tasks: Don't delete holdouts within trc_inspect_reader() (Waiman Long) [2065993]
- rcutorture: Move mem_dump_obj() tests into separate function (Waiman Long) [2065993]
- rcu: Remove obsolete rcu_read_unlock() deadlock commentary (Waiman Long) [2065993]
- rcu: Improve comments describing RCU read-side critical sections (Waiman Long) [2065993]
- rcu: Add missing __releases() annotation (Waiman Long) [2065993]
- kvfree_rcu: Fix comments according to current code (Waiman Long) [2065993]
- torture: Don't cap remote runs by build-system number of CPUs (Waiman Long) [2065993]
- torture: Make kvm-remote.sh account for network failure in pathname checks (Waiman Long) [2065993]
- rcu: Create an unrcu_pointer() to remove __rcu from a pointer (Waiman Long) [2065993]
- kvfree_rcu: Refactor kfree_rcu_monitor() (Waiman Long) [2065993]
- srcu: Fix broken node geometry after early ssp init (Waiman Long) [2065993]
- rcu: Point to documentation of ordering guarantees (Waiman Long) [2065993]
- rcu: Don't penalize priority boosting when there is nothing to boost (Waiman Long) [2065993]
- kvfree_rcu: Use kfree_rcu_monitor() instead of open-coded variant (Waiman Long) [2065993]
- kvfree_rcu: Update "monitor_todo" once a batch is started (Waiman Long) [2065993]
- kvfree_rcu: Add a bulk-list check when a scheduler is run (Waiman Long) [2065993]
- kvfree_rcu: Use [READ/WRITE]_ONCE() macros to access to nr_bkv_objs (Waiman Long) [2065993]
- kvfree_rcu: Release a page cache under memory pressure (Waiman Long) [2065993]
- rcu: Shrink each possible cpu krcp (Waiman Long) [2065993]
- rcu/segcblist: Prevent useless GP start if no CBs to accelerate (Waiman Long) [2065993]
- rcutorture: Don't count CPU-stalled time against priority boosting (Waiman Long) [2065993]
- rcu: Make rcu_gp_cleanup() be noinline for tracing (Waiman Long) [2065993]
- rcutorture: Add BUSTED-BOOST to test RCU priority boosting tests (Waiman Long) [2065993]
- srcu: Initialize SRCU after timers (Waiman Long) [2065993]
- srcu: Unconditionally embed struct lockdep_map (Waiman Long) [2065993]
- rcutorture: Forgive RCU boost failures when CPUs don't pass through QS (Waiman Long) [2065993]
- rcutorture: Test start_poll_synchronize_rcu() and poll_state_synchronize_rcu() (Waiman Long) [2065993]
- rcu: Provide polling interfaces for Tree RCU grace periods (Waiman Long) [2065993]
- rcutorture: Make rcu_torture_boost_failed() check for GP end (Waiman Long) [2065993]
- rcutorture: Consolidate rcu_torture_boost() timing and statistics (Waiman Long) [2065993]
- rcutorture: Delay-based false positives for RCU priority boosting tests (Waiman Long) [2065993]
- rcu: Restrict RCU_STRICT_GRACE_PERIOD to at most four CPUs (Waiman Long) [2065993]
- rcu: Make show_rcu_gp_kthreads() dump rcu_node structures blocking GP (Waiman Long) [2065993]
- rcu: Add quiescent states and boost states to show_rcu_gp_kthreads() output (Waiman Long) [2065993]
- rcu: Make RCU priority boosting work on single-CPU rcu_node structures (Waiman Long) [2065993]
- rcu: Reject RCU_LOCKDEP_WARN() false positives (Waiman Long) [2065993]
- lockdep: Explicitly flag likely false-positive report (Waiman Long) [2065993]
- rcu: Add ->gp_max to show_rcu_gp_kthreads() output (Waiman Long) [2065993]
- rcu: Add ->rt_priority and ->gp_start to show_rcu_gp_kthreads() output (Waiman Long) [2065993]
- srcu: Remove superfluous sdp->srcu_lock_count zero filling (Waiman Long) [2065993]
- srcu: Remove superfluous ssp initialization for early callbacks (Waiman Long) [2065993]
- torture:  Set kvm.sh language to English (Waiman Long) [2065993]
- torture: Correctly fetch number of CPUs for non-English languages (Waiman Long) [2065993]
- rcu: Invoke rcu_spawn_core_kthreads() from rcu_spawn_gp_kthread() (Waiman Long) [2065993]
- rcutorture: Judge RCU priority boosting on grace periods, not callbacks (Waiman Long) [2065993]
- sched,rcutorture: Convert to sched_set_fifo_low() (Waiman Long) [2065993]
- rcu: Improve tree.c comments and add code cleanups (Waiman Long) [2065993]
- rcu: Abstract out rcu_irq_enter_check_tick() from rcu_nmi_enter() (Waiman Long) [2065993]
- rcu: Remove the unused rcu_irq_exit_preempt() function (Waiman Long) [2065993]
- torture: Make kvm-find-errors.sh account for kvm-remote.sh (Waiman Long) [2065993]
- torture:  Make the build machine control N in "make -jN" (Waiman Long) [2065993]
- torture: Make kvm.sh use abstracted kvm-end-run-stats.sh (Waiman Long) [2065993]
- torture: Abstract end-of-run summary (Waiman Long) [2065993]
- rcu: Fix typo in comment: kthead -> kthread (Waiman Long) [2065993]
- rcutorture: Abstract read-lock-held checks (Waiman Long) [2065993]
- refscale: Add acqrel, lock, and lock-irq (Waiman Long) [2065993]
- torture: Add kvm-remote.sh script for distributed rcutorture test runs (Waiman Long) [2065993]
- refscale: Allow CPU hotplug to be enabled (Waiman Long) [2065993]
- torture: Make kvm-again.sh use "scenarios" rather than "batches" file (Waiman Long) [2065993]
- torture: Add "scenarios" option to kvm.sh --dryrun parameter (Waiman Long) [2065993]
- rcu-tasks: Add block comment laying out RCU Rude design (Waiman Long) [2065993]
- torture: Fix remaining erroneous torture.sh instance of $* (Waiman Long) [2065993]
- rcu/tree: Add a trace event for RCU CPU stall warnings (Waiman Long) [2065993]
- torture: Fix kvm.sh --datestamp regex check (Waiman Long) [2065993]
- rcu: Add explicit barrier() to __rcu_read_unlock() (Waiman Long) [2065993]
- rcu-tasks: Add block comment laying out RCU Tasks Trace design (Waiman Long) [2065993]
- rcu: Make nocb_nobypass_lim_per_jiffy static (Waiman Long) [2065993]
- torture: Consolidate qemu-cmd duration editing into kvm-transform.sh (Waiman Long) [2065993]
- torture: Print proper vmlinux path for kvm-again.sh runs (Waiman Long) [2065993]
- torture: Make TORTURE_TRUST_MAKE available in kvm-again.sh environment (Waiman Long) [2065993]
- docs: Correctly spell Stephen Hemminger's name (Waiman Long) [2065993]
- rcu/nocb: Use the rcuog CPU's ->nocb_timer (Waiman Long) [2065993]
- rcu/nocb: Move trace_rcu_nocb_wake() calls outside nocb_lock when possible (Waiman Long) [2065993]
- rcu/nocb: Remove stale comment above rcu_segcblist_offload() (Waiman Long) [2065993]
- rcu/nocb: Disable bypass when CPU isn't completely offloaded (Waiman Long) [2065993]
- rcu/nocb: Fix missed nocb_timer requeue (Waiman Long) [2065993]
- rcu/nocb: Trigger self-IPI on late deferred wake up before user resume (Waiman Long) [2065993]
- torture: Make kvm-transform.sh update jitter commands (Waiman Long) [2065993]
- torture: Add --duration argument to kvm-again.sh (Waiman Long) [2065993]
- rcu: deprecate "all" option to rcu_nocbs= (Waiman Long) [2065993]
- torture: Rename SRCU-t and SRCU-u to avoid lowercase characters (Waiman Long) [2065993]
- torture: Add kvm-again.sh to rerun a previous torture-test (Waiman Long) [2065993]
- torture: Create a "batches" file for build reuse (Waiman Long) [2065993]
- torture: De-capitalize TORTURE_SUITE (Waiman Long) [2065993]
- rcuscale: Add kfree_rcu() single-argument scale test (Waiman Long) [2065993]
- torture: Make upper-case-only no-dot no-slash scenario names official (Waiman Long) [2065993]
- torture: Remove no-mpstat error message (Waiman Long) [2065993]
- torture: Record kvm-test-1-run.sh and kvm-test-1-run-qemu.sh PIDs (Waiman Long) [2065993]
- torture: Record jitter start/stop commands (Waiman Long) [2065993]
- softirq: Don't try waking ksoftirqd before it has been spawned (Waiman Long) [2065993]
- torture: Extract kvm-test-1-run-qemu.sh from kvm-test-1-run.sh (Waiman Long) [2065993]
- torture: Record TORTURE_KCONFIG_GDB_ARG in qemu-cmd (Waiman Long) [2065993]
- torture: Abstract jitter.sh start/stop into scripts (Waiman Long) [2065993]
- torture: Reverse jittering and duration parameters for jitter.sh (Waiman Long) [2065993]
- torture: Eliminate jitter_pids file (Waiman Long) [2065993]
- torture: Use "jittering" file to control jitter.sh execution (Waiman Long) [2065993]
- torture: Use file-based protocol to mark batch's runs complete (Waiman Long) [2065993]
- torture: Move build/run synchronization files into scenario directories (Waiman Long) [2065993]
- torture: Make jitter.sh handle large systems (Waiman Long) [2065993]
- torture: Improve readability of the testid.txt file (Waiman Long) [2065993]
- torture: Provide bare-metal modprobe-based advice (Waiman Long) [2065993]
- kvfree_rcu: Use same set of GFP flags as does single-argument (Waiman Long) [2065993]
- kvfree_rcu: Replace __GFP_RETRY_MAYFAIL by __GFP_NORETRY (Waiman Long) [2065993]
- torture: Allow 1G of memory for torture.sh kvfree testing (Waiman Long) [2065993]
- torture: Do Kconfig analysis only once per scenario (Waiman Long) [2065993]
- torture: Compress KASAN vmlinux files (Waiman Long) [2065993]
- torture: Add --kcsan-kmake-arg to torture.sh for KCSAN (Waiman Long) [2065993]
- torture: Add command and results directory to torture.sh log (Waiman Long) [2065993]
- torture: Allow scenarios to be specified to torture.sh (Waiman Long) [2065993]
- torture: Drop log.long generation from torture.sh (Waiman Long) [2065993]
- torture: Make torture.sh refuse to do zero-length runs (Waiman Long) [2065993]
- torture: Make torture.sh throttle VERBOSE_TOROUT_*() for refscale (Waiman Long) [2065993]
- torture: Make torture.sh allmodconfig retain and label output (Waiman Long) [2065993]
- torture: Create doyesno helper function for torture.sh (Waiman Long) [2065993]
- torture: Make torture.sh refscale runs use verbose_batched module parameter (Waiman Long) [2065993]
- torture: Make torture.sh rcuscale and refscale deal with allmodconfig (Waiman Long) [2065993]
- torture: Enable torture.sh argument checking (Waiman Long) [2065993]
- torture: Auto-size SCF and scaling runs based on number of CPUs (Waiman Long) [2065993]
- torture: Add "make allmodconfig" to torture.sh (Waiman Long) [2065993]
- torture: Remove use of "eval" in torture.sh (Waiman Long) [2065993]
- torture: Make torture.sh use common time-duration bash functions (Waiman Long) [2065993]
- torture: Add torture.sh torture-everything script (Waiman Long) [2065993]
- refscale: Disable verbose torture-test output (Waiman Long) [2065993]
- rcuscale: Disable verbose torture-test output (Waiman Long) [2065993]
- rcu/nocb: Rename nocb_gp_update_state to nocb_gp_update_state_deoffloading (Waiman Long) [2065993]
- rcu/nocb: Avoid confusing double write of rdp->nocb_cb_sleep (Waiman Long) [2065993]
- rcu/nocb: Only (re-)initialize segcblist when needed on CPU up (Waiman Long) [2065993]
- rcu/nocb: Forbid NOCB toggling on offline CPUs (Waiman Long) [2065993]
- rcu/nocb: Comment the reason behind BH disablement on batch processing (Waiman Long) [2065993]
- rcu: Make rcu_read_unlock_special() expedite strict grace periods (Waiman Long) [2065993]
- rcu-tasks: Rectify kernel-doc for struct rcu_tasks (Waiman Long) [2065993]
- rcutorture: Replace rcu_torture_stall string with s (Waiman Long) [2065993]
- torture: Replace torture_init_begin string with s (Waiman Long) [2065993]
- rcutorture: Use "all" and "N" in "nohz_full" and "rcu_nocbs" (Waiman Long) [2065993]
- kvfree_rcu: Make krc_this_cpu_unlock() use raw_spin_unlock_irqrestore() (Waiman Long) [2065993]
- kvfree_rcu: Use __GFP_NOMEMALLOC for single-argument kvfree_rcu() (Waiman Long) [2065993]
- kvfree_rcu: Directly allocate page for single-argument case (Waiman Long) [2065993]
- rcutorture: Fix testing of RCU priority boosting (Waiman Long) [2065993]
- rculist: Replace reference to atomic_ops.rst (Waiman Long) [2065993]
- rcutorture: Make TREE03 use real-time tree.use_softirq setting (Waiman Long) [2065993]
- rcu: Expedite deboost in case of deferred quiescent state (Waiman Long) [2065993]
- rcu: Fix CPU-offline trace in rcutree_dying_cpu (Waiman Long) [2065993]
- rcu: Remove superfluous rdp fetch (Waiman Long) [2065993]
- torturescript: Don't rerun failed rcutorture builds (Waiman Long) [2065993]
- rcutorture: Add crude tests for mem_dump_obj() (Waiman Long) [2065993]
- mm: Don't build mm_dump_obj() on CONFIG_PRINTK=n kernels (Waiman Long) [2065993]
- rcu/nocb: Detect unsafe checks for offloaded rdp (Waiman Long) [2065993]
- sched/pelt: Fix attach_entity_load_avg() corner case (Phil Auld) [2056383]
- devlink: Clarifies max_macs generic devlink param (Petr Oros) [2076586]
- devlink: Add new "event_eq_size" generic device param (Petr Oros) [2076586]
- devlink: Add new "io_eq_size" generic device param (Petr Oros) [2076586]
- devlink: fix netns refcount leak in devlink_nl_cmd_reload() (Petr Oros) [2076586]
- devlink: Simplify devlink resources unregister call (Petr Oros) [2076586]
- devlink: Remove misleading internal_flags from health reporter dump (Petr Oros) [2076586]
- devlink: Don't throw an error if flash notification sent before devlink visible (Petr Oros) [2076586]
- devlink: fix flexible_array.cocci warning (Petr Oros) [2076586]
- devlink: expose get/put functions (Petr Oros) [2076586]
- devlink: make all symbols GPL-only (Petr Oros) [2076586]
- devlink: Simplify internal devlink params implementation (Petr Oros) [2076586]
- devlink: Clean not-executed param notifications (Petr Oros) [2076586]
- devlink: Delete obsolete parameters publish API (Petr Oros) [2076586]
- devlink: Remove extra device_lock assert checks (Petr Oros) [2076586]
- devlink: Delete reload enable/disable interface (Petr Oros) [2076586]
- devlink: Allow control devlink ops behavior through feature mask (Petr Oros) [2076586]
- devlink: Annotate devlink API calls (Petr Oros) [2076586]
- devlink: Move netdev_to_devlink helpers to devlink.c (Petr Oros) [2076586]
- devlink: Reduce struct devlink exposure (Petr Oros) [2076586]
- devlink: report maximum number of snapshots with regions (Petr Oros) [2076586]
- devlink: Add missed notifications iterators (Petr Oros) [2076586]
- netdevsim: Move devlink registration to be last devlink command (Petr Oros) [2076586]
- qed: Move devlink registration to be last devlink command (Petr Oros) [2076586]
- ionic: Move devlink registration to be last devlink command (Petr Oros) [2076586]
- nfp: Move delink_register to be last command (Petr Oros) [2076586]
- mlxsw: core: Register devlink instance last (Petr Oros) [2076586]
- net/mlx5: Accept devlink user input after driver initialization complete (Petr Oros) [2076586]
- net/mlx4: Move devlink_register to be the last initialization command (Petr Oros) [2076586]
- ice: Open devlink when device is ready (Petr Oros) [2076586]
- liquidio: Overcome missing device lock protection in init/remove flows (Petr Oros) [2076586]
- bnxt_en: Register devlink instance at the end devlink configuration (Petr Oros) [2076586]
- devlink: Notify users when objects are accessible (Petr Oros) [2076586]
- devlink: Remove single line function obfuscations (Petr Oros) [2076586]
- devlink: Delete not used port parameters APIs (Petr Oros) [2076586]
- bnxt_en: Properly remove port parameter support (Petr Oros) [2076586]
- bnxt_en: Check devlink allocation and registration status (Petr Oros) [2076586]
- devlink: Make devlink_register to be void (Petr Oros) [2076586]
- devlink: Delete not-used devlink APIs (Petr Oros) [2076586]
- devlink: Delete not-used single parameter notification APIs (Petr Oros) [2076586]
- devlink: Use xarray to store devlink instances (Petr Oros) [2076586]
- devlink: Count struct devlink consumers (Petr Oros) [2076586]
- devlink: Remove check of always valid devlink pointer (Petr Oros) [2076586]
- devlink: Simplify devlink_pernet_pre_exit call (Petr Oros) [2076586]
- devlink: Add APIs to publish, unpublish individual parameter (Petr Oros) [2076586]
- devlink: Add API to register and unregister single parameter (Petr Oros) [2076586]
- devlink: Create a helper function for one parameter registration (Petr Oros) [2076586]
- devlink: Fix port_type_set function pointer check (Petr Oros) [2076586]
- devlink: Set device as early as possible (Petr Oros) [2076586]
- devlink: Simplify devlink port API calls (Petr Oros) [2076586]
- devlink: Allocate devlink directly in requested net namespace (Petr Oros) [2076586]
- devlink: Break parameter notification sequence to be before/after unload/load driver (Petr Oros) [2076586]
- devlink: Remove duplicated registration check (Petr Oros) [2076586]
- net/mlx5: Don't rely on always true registered field (Petr Oros) [2076586]
- devlink: Unlock on error in dumpit() (Petr Oros) [2076586]
- devlink: Fix some error codes (Petr Oros) [2076586]
- net: devlink: Add support for port regions (Petr Oros) [2076586]
- netdevsim: Forbid devlink reload when adding or deleting ports (Petr Oros) [2076586]
- netdevsim: dev: Initialize FIB module after debugfs (Petr Oros) [2076586]
- pidfd: fix a poll race when setting exit_state (Oleg Nesterov) [2044587]
- fork: fix pidfd_poll()'s return type (Oleg Nesterov) [2044587]
- pidfd: add polling support (Oleg Nesterov) [2044587]
- kabi: introduce the kabi_aux_*() helpers (Oleg Nesterov) [2044587]
- tg3: Remove redundant assignments (Ken Cox) [2043792]
- ethernet: Remove redundant statement (Ken Cox) [2043792]
- ethernet: tg3: remove direct netdev->dev_addr writes (Ken Cox) [2043792]
- net: tg3: fix redundant check of true expression (Ken Cox) [2043792]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2043792]
- net: ethernet: Use existing define with polynomial (Ken Cox) [2043792]

* Fri May 13 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-391.el8]
- scsi: mpt3sas: Fix mpt3sas_check_same_4gb_region() kdoc comment (Tomas Henzl) [2068045]
- scsi: mpt3sas: Fix incorrect 4GB boundary check (Tomas Henzl) [2068045]
- genirq/affinity: Consider that CPUs on nodes can be unbalanced (Ming Lei) [2074317]
- scsi: target: pscsi: Set SCF_TREAT_READ_AS_NORMAL flag only if there is valid data (Maurizio Lombardi) [2074246]
- audit: don't deref the syscall args when checking the openat2 open_how::flags (Carlos Maiolino) [2026590]
- audit: add OPENAT2 record to list "how" info (Carlos Maiolino) [2026590]
- audit: add support for the openat2 syscall (Carlos Maiolino) [2026590]
- audit: replace magic audit syscall class numbers with macros (Carlos Maiolino) [2026590]
- tools include UAPI: Sync x86's syscalls_64.tbl, generic unistd.h and fcntl.h to pick up openat2 and pidfd_getfd (Carlos Maiolino) [2026590]
- open: don't silently ignore unknown O-flags in openat2() (Carlos Maiolino) [2026590]
- openat2: reject RESOLVE_BENEATH|RESOLVE_IN_ROOT (Carlos Maiolino) [2026590]
- open: introduce openat2(2) syscall (Carlos Maiolino) [2026590]
- namei: LOOKUP_{IN_ROOT,BENEATH}: permit limited ".." resolution (Carlos Maiolino) [2026590]
- namei: LOOKUP_IN_ROOT: chroot-like scoped resolution (Carlos Maiolino) [2026590]
- namei: LOOKUP_BENEATH: O_BENEATH-like scoped resolution (Carlos Maiolino) [2026590]
- namei: LOOKUP_NO_XDEV: block mountpoint crossing (Carlos Maiolino) [2026590]
- namei: LOOKUP_NO_MAGICLINKS: block magic-link resolution (Carlos Maiolino) [2026590]
- namei: LOOKUP_NO_SYMLINKS: block symlink resolution (Carlos Maiolino) [2026590]
- namei: allow set_root() to produce errors (Carlos Maiolino) [2026590]
- namei: allow nd_jump_link() to produce errors (Carlos Maiolino) [2026590]
- nsfs: clean-up ns_get_path() signature to return int (Carlos Maiolino) [2026590]
- namei: only return -ECHILD from follow_dotdot_rcu() (Carlos Maiolino) [2026590]
- make path_init() unconditionally paired with terminate_walk() (Carlos Maiolino) [2026590]
- nsfs: unobfuscate (Carlos Maiolino) [2026590]
- ASoC: Intel: soc-acpi: add entries in ADL match table (Jaroslav Kysela) [2052011]
- nvme-fc: add support for ->map_queues (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix typos in comments (Nilesh Javali) [2044833]
- scsi: qla2xxx: Update version to 10.02.07.400-k (Nilesh Javali) [2044833]
- scsi: qla2xxx: Increase max limit of ql2xnvme_queues (Nilesh Javali) [2044833]
- scsi: qla2xxx: Use correct feature type field during RFF_ID processing (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix stuck session of PRLI reject (Nilesh Javali) [2044833]
- scsi: qla2xxx: Reduce false trigger to login (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix laggy FC remote port session recovery (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix hang due to session stuck (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix N2N inconsistent PLOGI (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix crash during module load unload test (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix missed DMA unmap for NVMe ls requests (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix loss of NVMe namespaces after driver reload test (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix incorrect reporting of task management failure (Nilesh Javali) [2044833]
- scsi: qla2xxx: Use named initializers for q_dev_state (Nilesh Javali) [2044833]
- scsi: qla2xxx: Use named initializers for port_[d]state_str (Nilesh Javali) [2044833]
- scsi: qla2xxx: Stop using the SCSI pointer (Nilesh Javali) [2044833]
- scsi: qla2xxx: Remove unused qla_sess_op_cmd_list from scsi_qla_host_t (Nilesh Javali) [2044833]
- scsi: qla2xxx: Add qla2x00_async_done() for async routines (Nilesh Javali) [2044833]
- scsi: qla2xxx: Update version to 10.02.07.300-k (Nilesh Javali) [2044833]
- scsi: qla2xxx: Check for firmware dump already collected (Nilesh Javali) [2044833]
- scsi: qla2xxx: Add devids and conditionals for 28xx (Nilesh Javali) [2044833]
- scsi: qla2xxx: Suppress a kernel complaint in qla_create_qpair() (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix T10 PI tag escape and IP guard options for 28XX adapters (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Fix clang warning (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix warning for missing error code (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix device reconnect in loop topology (Nilesh Javali) [2044833]
- scsi: qla2xxx: Add ql2xnvme_queues module param to configure number of NVMe queues (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix wrong FDMI data for 64G adapter (Nilesh Javali) [2044833]
- scsi: qla2xxx: Add retry for exec firmware (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix scheduling while atomic (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix premature hw access after PCI error (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix warning message due to adisc being flushed (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix stuck session in gpdb (Nilesh Javali) [2044833]
- scsi: qla2xxx: Implement ref count for SRB (Nilesh Javali) [2044833]
- scsi: qla2xxx: Refactor asynchronous command initialization (Nilesh Javali) [2044833]
- scsi: qla2xxx: Synchronize rport dev_loss_tmo setting (Nilesh Javali) [2044833]
- scsi: qla2xxx: Format log strings only if needed (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Fix off by one bug in qla_edif_app_getfcinfo() (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix mailbox direction flags in qla2xxx_get_adapter_id() (Nilesh Javali) [2044833]
- scsi: qla2xxx: Update version to 10.02.07.200-k (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Fix EDIF bsg (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Fix inconsistent check of db_flags (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Increase ELS payload (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Reduce connection thrash (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Tweak trace message (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Replace list_for_each_safe with list_for_each_entry_safe (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Flush stale events and msgs on session down (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Fix app start delay (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Fix app start fail (Nilesh Javali) [2044833]
- scsi: qla2xxx: Turn off target reset during issue_lip (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix gnl list corruption (Nilesh Javali) [2044833]
- scsi: qla2xxx: Relogin during fabric disturbance (Nilesh Javali) [2044833]
- qla2xxx: add ->map_queues support for nvme (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix unmap of already freed sgl (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix a memory leak in an error path of qla2x00_process_els() (Nilesh Javali) [2044833]
- scsi: qla2xxx: Return -ENOMEM if kzalloc() fails (Nilesh Javali) [2044833]
- scsi: qla2xxx: Remove a declaration (Nilesh Javali) [2044833]
- scsi: target: qla2xxx: Replace enable attr with ops.enable (Nilesh Javali) [2044833]
- scsi: qla2xxx: Restore initiator in dual mode (Nilesh Javali) [2044833]
- scsi: qla2xxx: Remove redundant initialization of pointer req (Nilesh Javali) [2044833]
- scsi: qla2xxx: Update version to 10.02.07.100-k (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix use after free in eh_abort path (Nilesh Javali) [2044833]
- scsi: qla2xxx: Move heartbeat handling from DPC thread to workqueue (Nilesh Javali) [2044833]
- scsi: qla2xxx: Call process_response_queue() in Tx path (Nilesh Javali) [2044833]
- scsi: qla2xxx: edif: Use link event to wake up app (Nilesh Javali) [2044833]
- scsi: qla2xxx: Fix crash in NVMe abort path (Nilesh Javali) [2044833]
- scsi: qla2xxx: Check for firmware capability before creating QPair (Nilesh Javali) [2044833]
- scsi: qla2xxx: Display 16G only as supported speeds for 3830c card (Nilesh Javali) [2044833]
- scsi: qla2xxx: Indicate correct supported speeds for Mezz card (Nilesh Javali) [2044833]
- scsi: qla2xxx: Add support for mailbox passthru (Nilesh Javali) [2044833]
- scsi: qla2xxx: Open-code qla2xxx_eh_device_reset() (Nilesh Javali) [2044833]
- scsi: qla2xxx: Open-code qla2xxx_eh_target_reset() (Nilesh Javali) [2044833]
- scsi: qla2xxx: Do not call fc_block_scsi_eh() during bus reset (Nilesh Javali) [2044833]
- sctp: count singleton chunks in assoc user stats (Jamie Bainbridge) [2073913]
- hrtimer: Unbreak hrtimer_force_reprogram() (Fernando Pacheco) [2071776]
- hrtimer: Use raw_cpu_ptr() in clock_was_set() (Fernando Pacheco) [2071776]
- hrtimer: Avoid more SMP function calls in clock_was_set() (Fernando Pacheco) [2071776]
- hrtimer: Avoid unnecessary SMP function calls in clock_was_set() (Fernando Pacheco) [2071776]
- hrtimer: Add bases argument to clock_was_set() (Fernando Pacheco) [2071776]
- time/timekeeping: Avoid invoking clock_was_set() twice (Fernando Pacheco) [2071776]
- timekeeping: Distangle resume and clock-was-set events (Fernando Pacheco) [2071776]
- timerfd: Provide timerfd_resume() (Fernando Pacheco) [2071776]
- hrtimer: Force clock_was_set() handling for the HIGHRES=n, NOHZ=y case (Fernando Pacheco) [2071776]
- hrtimer: Ensure timerfd notification for HIGHRES=n (Fernando Pacheco) [2071776]
- hrtimer: Consolidate reprogramming code (Fernando Pacheco) [2071776]
- hrtimer: Avoid double reprogramming in __hrtimer_start_range_ns() (Fernando Pacheco) [2071776]
- hrtimer: Update softirq_expires_next correctly after __hrtimer_get_next_event() (Fernando Pacheco) [2071776]
- hrtimer: Annotate lockless access to timer->state (Fernando Pacheco) [2071776]
- drm/i915/display: Remove check for low voltage sku for max dp source rate (Jocelyn Falempe) [2063931]
- s390/kexec: handle R_390_PLT32DBL rela in arch_kexec_apply_relocations_add() (Philipp Rudo) [2039278]
- s390/kexec_file: fix error handling when applying relocations (Philipp Rudo) [2039278]
- s390/kexec_file: print some more error messages (Philipp Rudo) [2039278]
- ixgbe: respect metadata on XSK Rx to skb (Ken Cox) [2037952]
- ixgbe: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ken Cox) [2037952]
- ixgbe: pass bi->xdp to ixgbe_construct_skb_zc() directly (Ken Cox) [2037952]
- ixgbe: Remove useless DMA-32 fallback configuration (Ken Cox) [2037952]
- ixgbe: switch to napi_build_skb() (Ken Cox) [2037952]
- ixgbe: set X550 MDIO speed before talking to PHY (Ken Cox) [2037952]
- ixgbe: Document how to enable NBASE-T support (Ken Cox) [2037952]
- xsk: Wipe out dead zero_copy_allocator declarations (Ken Cox) [2037952]
- ixgbe: let the xdpdrv work with more than 64 cpus (Ken Cox) [2037952]
- scsi: fcoe: Fix I/O path allocation (Ken Cox) [2037952]
- ixgbe: extend PTP gettime function to read system clock (Ken Cox) [2037952]
- ixgbe: Replace GFP_ATOMIC with GFP_KERNEL (Ken Cox) [2037952]
- net: mpls: Fix notifications when deleting a device (Guillaume Nault) [2081757]

* Tue May 10 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-390.el8]
- sched/cputime, proc/stat: Fix incorrect guest nice cpustat value (Waiman Long) [2017382]
- procfs: Use all-in-one vtime aware kcpustat accessor (Waiman Long) [2017382]
- procfs: Use vtime aware kcpustat accessor to fetch CPUTIME_SYSTEM (Waiman Long) [2017382]
- proc: read kernel cpu stat pointer once (Waiman Long) [2017382]
- proc: use "unsigned int" in /proc/stat hook (Waiman Long) [2017382]
- sched/cputime: Support other fields on kcpustat_field() (Waiman Long) [2017382]
- sched/cputime: Add vtime guest task state (Waiman Long) [2017382]
- sched/cputime: Add vtime idle task state (Waiman Long) [2017382]
- sched/cputime: Spare a seqcount lock/unlock cycle on context switch (Waiman Long) [2017382]
- sched/vtime: Move task_struct_rh->vtime_cpu back to vtime structure (Waiman Long) [2017382]
- usb: xhci-plat: fix crash when suspend if remote wake enable (Mark Langsdorf) [2065730]
- PM: domains: Improve runtime PM performance state handling (Mark Langsdorf) [2065730]
- firmware_loader: fix use-after-free in firmware_fallback_sysfs (Mark Langsdorf) [2065730]
- firmware_loader: use -ETIMEDOUT instead of -EAGAIN in fw_load_sysfs_fallback (Mark Langsdorf) [2065730]
- driver core: Prevent warning when removing a device link from unregistered consumer (Mark Langsdorf) [2065730]
- PM: domains: Shrink locking area of the gpd_list_lock (Mark Langsdorf) [2065730]
- PM: sleep: Use ktime_us_delta() in initcall_debug_report() (Mark Langsdorf) [2065730]
- driver core: Export device_driver_attach() (Mark Langsdorf) [2065730]
- driver core: Don't return EPROBE_DEFER to userspace during sysfs bind (Mark Langsdorf) [2065730]
- driver core: Flow the return code from ->probe() through to sysfs bind (Mark Langsdorf) [2065730]
- driver core: Better distinguish probe errors in really_probe (Mark Langsdorf) [2065730]
- driver core: Pull required checks into driver_probe_device() (Mark Langsdorf) [2065730]
- driver core: add a helper to setup both the of_node and fwnode of a device (Mark Langsdorf) [2065730]
- devres: Enable trace events (Mark Langsdorf) [2065730]
- devres: No need to call remove_nodes() when there none present (Mark Langsdorf) [2065730]
- devres: Use list_for_each_safe_from() in remove_nodes() (Mark Langsdorf) [2065730]
- devres: Make locking straight forward in release_nodes() (Mark Langsdorf) [2065730]
- regmap: mdio: Reject invalid addresses (Mark Langsdorf) [2065730]
- regmap: mdio: Fix regmap_bus pointer constness (Mark Langsdorf) [2065730]
- PM: runtime: Allow unassigned ->runtime_suspend|resume callbacks (Mark Langsdorf) [2065730]
- PM: runtime: Improve path in rpm_idle() when no callback (Mark Langsdorf) [2065730]
- PM: domains: Drop/restore performance state votes for devices at runtime PM (Mark Langsdorf) [2065730]
- PM: domains: Return early if perf state is already set for the device (Mark Langsdorf) [2065730]
- PM: domains: Split code in dev_pm_genpd_set_performance_state() (Mark Langsdorf) [2065730]
- PM: domains: fix some kernel-doc issues (Mark Langsdorf) [2065730]
- regmap: mdio: Add clause-45 support (Mark Langsdorf) [2065730]
- regmap: mdio: Clean up invalid clause-22 addresses (Mark Langsdorf) [2065730]
- regmap-irq: Introduce inverted status registers support (Mark Langsdorf) [2065730]
- ACPI: property: Constify stubs for CONFIG_ACPI=n case (Mark Langsdorf) [2065730]
- device property: Unify access to of_node (Mark Langsdorf) [2065730]
- drivers/base: Constify static attribute_group structs (Mark Langsdorf) [2065730]
- devcoredump: remove contact information (Mark Langsdorf) [2065730]
- component: Rename 'dev' to 'parent' (Mark Langsdorf) [2065730]
- component: Drop 'dev' argument to component_match_realloc() (Mark Langsdorf) [2065730]
- device property: Don't check for NULL twice in the loops (Mark Langsdorf) [2065730]
- regmap: add support for 7/17 register formating (Mark Langsdorf) [2065730]
- PM: wakeirq: Set IRQF_NO_AUTOEN when requesting the IRQ (Mark Langsdorf) [2065730]
- drivers/base/node.c: make CACHE_ATTR define static DEVICE_ATTR_RO (Mark Langsdorf) [2065730]
- regmap: mdio: Don't modify output if error happened (Mark Langsdorf) [2065730]
- regmap: Add MDIO bus support (Mark Langsdorf) [2065730]
- regmap-i2c: Set regmap max raw r/w from quirks (Mark Langsdorf) [2065730]
- driver core: attribute_container: fix W=1 warnings (Mark Langsdorf) [2065730]
- driver core: replace open-coded device_lock_assert() (Mark Langsdorf) [2065730]
- device property: Retrieve fwnode from of_node via accessor (Mark Langsdorf) [2065730]
- cpufreq: Kconfig: fix documentation links (Mark Langsdorf) [2065730]
- PM: wakeup: remove redundant assignment to variable retval (Mark Langsdorf) [2065730]
- PM / wakeup: use dev_set_name() directly (Mark Langsdorf) [2065730]
- PM: clk: remove kernel-doc warning (Mark Langsdorf) [2065730]
- PM: wakeup: fix kernel-doc warnings and fix typos (Mark Langsdorf) [2065730]
- PM: runtime: remove kernel-doc warnings (Mark Langsdorf) [2065730]
- software node: Introduce SOFTWARE_NODE_REFERENCE() helper macro (Mark Langsdorf) [2065730]
- software node: Imply kobj_to_swnode() to be no-op (Mark Langsdorf) [2065730]
- software node: Deduplicate code in fwnode_create_software_node() (Mark Langsdorf) [2065730]
- software node: Introduce software_node_alloc()/software_node_free() (Mark Langsdorf) [2065730]
- software node: Free resources explicitly when swnode_register() fails (Mark Langsdorf) [2065730]
- driver core: add helper for deferred probe reason setting (Mark Langsdorf) [2065730]
- driver core: Improve fw_devlink & deferred_probe_timeout interaction (Mark Langsdorf) [2065730]
- driver core: Replace printf() specifier and drop unneeded casting (Mark Langsdorf) [2065730]
- driver core: Cast to (void *) with __force for __percpu pointer (Mark Langsdorf) [2065730]
- devcoredump: fix kernel-doc warning (Mark Langsdorf) [2065730]
- platform-msi: fix kernel-doc warnings (Mark Langsdorf) [2065730]
- driver core: attribute_container: remove kernel-doc warnings (Mark Langsdorf) [2065730]
- driver core: remove kernel-doc warnings (Mark Langsdorf) [2065730]
- base: dd: fix error return code of driver_sysfs_add() (Mark Langsdorf) [2065730]
- driver core: Use unbound workqueue for deferred probes (Mark Langsdorf) [2065730]
- devcoredump: avoid -Wempty-body warnings (Mark Langsdorf) [2065730]
- device property: Add test cases for fwnode_property_count_*() APIs (Mark Langsdorf) [2065730]
- device property: Sync descriptions of swnode array and group APIs (Mark Langsdorf) [2065730]
- driver core: Update device link status properly for device_bind_driver() (Mark Langsdorf) [2065730]
- driver core: Avoid pointless deferred probe attempts (Mark Langsdorf) [2065730]
- drivers/base/cpu: remove redundant assignment of variable retval (Mark Langsdorf) [2065730]
- driver core: dd: remove deferred_devices variable (Mark Langsdorf) [2065730]
- driver core: component: remove dentry pointer in "struct master" (Mark Langsdorf) [2065730]
- driver core: auxiliary bus: Remove unneeded module bits (Mark Langsdorf) [2065730]
- PM: domains: Don't runtime resume devices at genpd_prepare() (Mark Langsdorf) [2065730]
- redhat/configs: Add CONFIG_X86_AMD_PSTATE (Prarit Bhargava)
- ACPI: CPPC: Drop redundant local variable from cpc_read() (Prarit Bhargava) [1961726]
- ACPI: CPPC: Fix up I/O port access in cpc_read() (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Fix Kconfig dependencies for AMD P-State (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Fix struct amd_cpudata kernel-doc comment (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Add AMD P-State performance attributes (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Add AMD P-State frequencies attributes (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Add boost mode support for AMD P-State (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Add trace for AMD P-State module (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Introduce the support for the processors with shared memory solution (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Add fast switch function for AMD P-State (Prarit Bhargava) [1961726]
- cpufreq: amd-pstate: Introduce a new AMD P-State driver to support future processors (Prarit Bhargava) [1961726]
- ACPI: CPPC: Add CPPC enable register function (Prarit Bhargava) [1961726]
- ACPI: CPPC: Check present CPUs for determining _CPC is valid (Prarit Bhargava) [1961726]
- ACPI: CPPC: Implement support for SystemIO registers (Prarit Bhargava) [1961726]
- x86/msr: Add AMD CPPC MSR definitions (Prarit Bhargava) [1961726]
- x86/cpufeatures: Add AMD Collaborative Processor Performance Control feature flag (Prarit Bhargava) [1961726]
- cpufreq: remove useless INIT_LIST_HEAD() (Prarit Bhargava) [1961726]
- cpufreq: CPPC: Pass structure instance by reference (Prarit Bhargava) [1961726]
- cpufreq: CPPC: Fix potential memleak in cppc_cpufreq_cpu_init (Prarit Bhargava) [1961726]
- cpufreq: CPPC: Migrate to ->exit() callback instead of ->stop_cpu() (Prarit Bhargava) [1961726]
- cpufreq: cppc: simplify default delay_us setting (Prarit Bhargava) [1961726]
- cppc_cpufreq: replace per-cpu data array with a list (Prarit Bhargava) [1961726]
- cppc_cpufreq: expose information on frequency domains (Prarit Bhargava) [1961726]
- cppc_cpufreq: clarify support for coordination types (Prarit Bhargava) [1961726]
- cppc_cpufreq: use policy->cpu as driver of frequency setting (Prarit Bhargava) [1961726]
- cppc_cpufreq: simplify use of performance capabilities (Prarit Bhargava) [1961726]
- cppc_cpufreq: clean up cpu, cpu_num and cpunum variable use (Prarit Bhargava) [1961726]
- cppc_cpufreq: fix misspelling, code style and readability issues (Prarit Bhargava) [1961726]
- cpufreq: CPPC: Reuse caps variable in few routines (Prarit Bhargava) [1961726]
- cpufreq: cppc: Reorder code and remove apply_hisi_workaround variable (Prarit Bhargava) [1961726]
- cpufreq: CPPC: add SW BOOST support (Prarit Bhargava) [1961726]
- net/sched: act_ct: fix ref leak when switching zones (Marcelo Ricardo Leitner) [2014027]
- net/sched: act_ct: Fix flow table lookup after ct clear or switching zones (Marcelo Ricardo Leitner) [2014027]
- genirq: Provide new interfaces for affinity hints (Ivan Vecera) [2070044]
- af_key: add __GFP_ZERO flag for compose_sadb_supported in function pfkey_register (Xin Long) [2075181]
- ipv6: make ip6_rt_gc_expire an atomic_t (Hangbin Liu) [2077365]
- ipv6: fix panic when forwarding a pkt with no in6 dev (Hangbin Liu) [2077365]
- net: ipv6: ensure we call ipv6_mc_down() at most once (Hangbin Liu) [2077365]
- ipv6/addrconf: use a boolean to choose between UNREGISTER/DOWN (Hangbin Liu) [2077365]
- ipv6/addrconf: call addrconf_ifdown with consistent values (Hangbin Liu) [2077365]
- ipmr,ip6mr: acquire RTNL before calling ip[6]mr_free_table() on failure path (Hangbin Liu) [2077365]
- ipv6: annotate accesses to fn->fn_sernum (Hangbin Liu) [2077365]
- ipv6: correct comments about fib6_node sernum (Hangbin Liu) [2077365]
- ipv6: fix typos in __ip6_finish_output() (Hangbin Liu) [2077365]
- oom_kill.c: futex: delay the OOM reaper to allow time for proper futex cleanup (Nico Pache) [1778048]
- KVM: PPC: Fix TCE handling for VFIO (Daniel Henrique Barboza) [2062687]
- udf: Restore i_lenAlloc when inode expansion fails (Carlos Maiolino) [2054653] {CVE-2022-0617}
- udf: Fix NULL ptr deref when converting from inline format (Carlos Maiolino) [2054653] {CVE-2022-0617}
- net/tls: fix slab-out-of-bounds bug in decrypt_internal (Sabrina Dubroca) [2080344]
- tls: fix replacing proto_ops (Sabrina Dubroca) [2080344]
- net/tls: use semicolons rather than commas to separate statements (Sabrina Dubroca) [2080344]
- redhat: further rpminspect tuning (Jarod Wilson)

* Fri May 06 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-389.el8]
- tun: annotate access to queue->trans_start (Ivan Vecera) [2069673]
- net: annotate accesses to queue->trans_start (Ivan Vecera) [2069673]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (Sudheesh Mavila) [2037287]
- ipmi: initialize len variable (Tony Camuso) [2069839]
- ipmi: kcs: aspeed: Remove old bindings support (Tony Camuso) [2069839]
- ipmi:ipmb: Add the ability to have a separate slave and master device (Tony Camuso) [2069839]
- ipmi:ipmi_ipmb: Unregister the SMI on remove (Tony Camuso) [2069839]
- ipmi: kcs: aspeed: Add AST2600 compatible string (Tony Camuso) [2069839]
- ipmi: ssif: replace strlcpy with strscpy (Tony Camuso) [2069839]
- ipmi/watchdog: Constify ident (Tony Camuso) [2069839]
- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module (Tony Camuso) [2069839]
- ipmi: fix initialization when workqueue allocation fails (Tony Camuso) [2069839]
- ipmi: bail out if init_srcu_struct fails (Tony Camuso) [2069839]
- ipmi: ssif: initialize ssif_info->client early (Tony Camuso) [2069839]
- ipmi: msghandler: Make symbol 'remove_work_wq' static (Tony Camuso) [2069839]
- ipmi: Move remove_work to dedicated workqueue (Tony Camuso) [2069839]
- ipmi: kcs_bmc: Fix a memory leak in the error handling path of 'kcs_bmc_serio_add_device()' (Tony Camuso) [2069839]
- char: ipmi: replace snprintf in show functions with sysfs_emit (Tony Camuso) [2069839]
- ipmi: ipmb: fix dependencies to eliminate build error (Tony Camuso) [2069839]
- ipmi:ipmb: Add OF support (Tony Camuso) [2069839]
- ipmi: bt: Add ast2600 compatible string (Tony Camuso) [2069839]
- ipmi: bt-bmc: Use registers directly (Tony Camuso) [2069839]
- ipmi: ipmb: Fix off-by-one size check on rcvlen (Tony Camuso) [2069839]
- ipmi:ssif: Use depends on, not select, for I2C (Tony Camuso) [2069839]
- ipmi:ipmb: Add initial support for IPMI over IPMB (Tony Camuso) [2069839]
- ipmi: Export ipmb_checksum() (Tony Camuso) [2069839]
- ipmi: Check error code before processing BMC response (Tony Camuso) [2069839]
- ipmi:devintf: Return a proper error when recv buffer too small (Tony Camuso) [2069839]
- ipmi: Disable some operations during a panic (Tony Camuso) [2069839]
- ipmi:watchdog: Set panic count to proper value on a panic (Tony Camuso) [2069839]
- char: ipmi: use DEVICE_ATTR helper macro (Tony Camuso) [2069839]
- ipmi: rate limit ipmi smi_event failure message (Tony Camuso) [2069839]
- cifs: fix NULL ptr dereference in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074316]
- cifs: prevent bad output lengths in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074316]
- net: tcp better handling of reordering then loss cases (Marcelo Ricardo Leitner) [2074566]
- tcp: tcp_mark_head_lost is only valid for sack-tcp (Marcelo Ricardo Leitner) [2074566]
- udp6: allow SO_MARK ctrl msg to affect routing (Xin Long) [2066598]
- ip: Fix SO_MARK in RST, ACK and ICMP packets (Xin Long) [2066598]
- ip: support SO_MARK cmsg (Xin Long) [2066598]
- ip: unconditionally set cork gso_size (Xin Long) [2066598]
- ip: remove tx_flags from ipcm_cookie and use same logic for v4 and v6 (Xin Long) [2066598]
- ipv6: fold sockcm_cookie into ipcm6_cookie (Xin Long) [2066598]
- sock: sockc cookie initializer (Xin Long) [2066598]
- ipv6: ipcm6_cookie initializer (Xin Long) [2066598]
- ipv4: ipcm_cookie initializers (Xin Long) [2066598]
- s390/kexec: fix memory leak of ipl report buffer (Lichen Liu) [2001758]
- s390/kexec: fix return code handling (Lichen Liu) [2001758]
- block: don't try to throttle split bio if iops limit isn't set (Ming Lei) [2027241]
- block: throttle split bio in case of iops limit (Ming Lei) [2027241]
- block: don't check bio in blk_throtl_dispatch_work_fn (Ming Lei) [2027241]
- x86/apic/vector: Fix ordering in vector assignment (Frank Ramsay) [2076607]
- mt76: mt7921e: fix possible probe failure after reboot (Íñigo Huguet) [2078877]
- veth: Ensure eth header is in skb's linear part (Guillaume Nault) [1966887]
- net: annotate accesses to dev->gso_max_segs (Ivan Vecera) [2080317]
- net: annotate accesses to dev->gso_max_size (Ivan Vecera) [2080317]
- NFS: Don't loop forever in nfs_do_recoalesce() (Scott Mayhew) [2080467]
- tipc: fix the timer expires after interval 100ms (Xin Long) [2080369]
- tipc: Fix end of loop tests for list_for_each_entry() (Xin Long) [2080369]
- tipc: fix a bit overflow in tipc_crypto_key_rcv() (Xin Long) [2080369]
- tipc: rate limit warning for received illegal binding update (Xin Long) [2080369]
- net: tipc: remove unused static inlines (Xin Long) [2080369]
- tipc: fix unique bearer names sanity check (Xin Long) [2080369]
- net/tipc: fix missing destroy_workqueue() on error in tipc_crypto_start() (Xin Long) [2080369]
- tipc: add extack messages for bearer/media failure (Xin Long) [2080369]
- scsi: smartpqi: Fix unused variable pqi_pm_ops for clang (Don Brace) [2012227]
- scsi: smartpqi: Update version to 2.1.14-035 (Don Brace) [2012227]
- scsi: smartpqi: Fix lsscsi -t SAS addresses (Don Brace) [2012227]
- scsi: smartpqi: Fix hibernate and suspend (Don Brace) [2012227]
- scsi: smartpqi: Fix BUILD_BUG_ON() statements (Don Brace) [2012227]
- scsi: smartpqi: Fix NUMA node not updated during init (Don Brace) [2012227]
- scsi: smartpqi: Expose SAS address for SATA drives (Don Brace) [2012227]
- scsi: smartpqi: Speed up RAID 10 sequential reads (Don Brace) [2012227]
- scsi: smartpqi: Fix kdump issue when controller is locked up (Don Brace) [2012227]
- scsi: smartpqi: Update volume size after expansion (Don Brace) [2012227]
- scsi: smartpqi: Avoid drive spin-down during suspend (Don Brace) [2012227]
- scsi: smartpqi: Resolve delay issue with PQI_HZ value (Don Brace) [2012227]
- scsi: smartpqi: Fix a typo in func pqi_aio_submit_io() (Don Brace) [2012227]
- scsi: smartpqi: Fix a name typo and cleanup code (Don Brace) [2012227]
- scsi: smartpqi: Quickly propagate path failures to SCSI midlayer (Don Brace) [2012227]
- scsi: smartpqi: Eliminate drive spin down on warm boot (Don Brace) [2012227]
- scsi: smartpqi: Enable SATA NCQ priority in sysfs (Don Brace) [2012227]
- scsi: smartpqi: Add PCI IDs (Don Brace) [2012227]
- scsi: smartpqi: Fix rmmod stack trace (Don Brace) [2012227]
- ibmvnic: fix race between xmit and reset (Diego Domingos) [2051354]
- ibmvnic: Allow queueing resets during probe (Diego Domingos) [2051354]
- ibmvnic: clear fop when retrying probe (Diego Domingos) [2051354]
- ibmvnic: init init_done_rc earlier (Diego Domingos) [2051354]
- ibmvnic: register netdev after init of adapter (Diego Domingos) [2051354]
- ibmvnic: complete init_done on transport events (Diego Domingos) [2051354]
- ibmvnic: define flush_reset_queue helper (Diego Domingos) [2051354]
- ibmvnic: initialize rc before completing wait (Diego Domingos) [2051354]
- ibmvnic: free reset-work-item when flushing (Diego Domingos) [2051354]
- ibmvnic: schedule failover only if vioctl fails (Diego Domingos) [2051354]
- net/ibmvnic: Cleanup workaround doing an EOI after partition migration (Diego Domingos) [2051354]

* Fri Apr 29 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-388.el8]
- xfs: don't expose misaligned extszinherit hints to userspace (Brian Foster) [2072552]
- xfs: correct the narrative around misaligned rtinherit/extszinherit dirs (Brian Foster) [2072552]
- xfs: fix endianness issue in xfs_ag_shrink_space (Brian Foster) [2072552]
- xfs: bunmapi has unnecessary AG lock ordering issues (Brian Foster) [2072552]
- xfs: btree format inode forks can have zero extents (Brian Foster) [2072552]
- xfs: validate extsz hints against rt extent size when rtinherit is set (Brian Foster) [2072552]
- xfs: standardize extent size hint validation (Brian Foster) [2072552]
- xfs: check free AG space when making per-AG reservations (Brian Foster) [2072552]
- xfs: retry allocations when locality-based search fails (Brian Foster) [2072552]
- xfs: adjust rt allocation minlen when extszhint > rtextsize (Brian Foster) [2072552]
- iomap: remove unused private field from ioend (Brian Foster) [2072552]
- xfs: don't allow log writes if the data device is readonly (Brian Foster) [2072552]
- xfs: count free space btree blocks when scrubbing pre-lazysbcount fses (Brian Foster) [2072552]
- xfs: update superblock counters correctly for !lazysbcount (Brian Foster) [2072552]
- xfs: don't check agf_btreeblks on pre-lazysbcount filesystems (Brian Foster) [2072552]
- xfs: rename struct xfs_legacy_ictimestamp (Brian Foster) [2072552]
- xfs: rename xfs_ictimestamp_t (Brian Foster) [2072552]
- xfs: remove xfs_quiesce_attr declaration (Brian Foster) [2072552]
- xfs: remove XFS_IFEXTENTS (Brian Foster) [2072552]
- xfs: remove XFS_IFINLINE (Brian Foster) [2072552]
- xfs: remove XFS_IFBROOT (Brian Foster) [2072552]
- xfs: only look at the fork format in xfs_idestroy_fork (Brian Foster) [2072552]
- xfs: simplify xfs_attr_remove_args (Brian Foster) [2072552]
- xfs: rename and simplify xfs_bmap_one_block (Brian Foster) [2072552]
- xfs: move the XFS_IFEXTENTS check into xfs_iread_extents (Brian Foster) [2072552]
- xfs: get rid of the ip parameter to xchk_setup_* (Brian Foster) [2072552]
- xfs: move the check for post-EOF mappings into xfs_can_free_eofblocks (Brian Foster) [2072552]
- xfs: move the xfs_can_free_eofblocks call under the IOLOCK (Brian Foster) [2072552]
- xfs: precalculate default inode attribute offset (Brian Foster) [2072552]
- xfs: default attr fork size does not handle device inodes (Brian Foster) [2072552]
- xfs: inode fork allocation depends on XFS_IFEXTENT flag (Brian Foster) [2072552]
- xfs: eager inode attr fork init needs attr feature awareness (Brian Foster) [2072552]
- xfs: scrub: Disable check for unoptimized data fork bmbt node (Brian Foster) [2072552]
- xfs: Use struct xfs_bmdr_block instead of struct xfs_btree_block to calculate root node size (Brian Foster) [2072552]
- xfs: merge _xfs_dic2xflags into xfs_ip2xflags (Brian Foster) [2072552]
- xfs: move the di_crtime field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_flags2 field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_flags field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_forkoff field to struct xfs_inode (Brian Foster) [2072552]
- xfs: use a union for i_cowextsize and i_flushiter (Brian Foster) [2072552]
- xfs: use XFS_B_TO_FSB in xfs_ioctl_setattr (Brian Foster) [2072552]
- xfs: cleanup xfs_fill_fsxattr (Brian Foster) [2072552]
- xfs: move the di_flushiter field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_cowextsize field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_extsize field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_nblocks field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_size field to struct xfs_inode (Brian Foster) [2072552]
- xfs: move the di_projid field to struct xfs_inode (Brian Foster) [2072552]
- xfs: don't clear the "dinode core" in xfs_inode_alloc (Brian Foster) [2072552]
- xfs: remove the di_dmevmask and di_dmstate fields from struct xfs_icdinode (Brian Foster) [2072552]
- xfs: remove the unused xfs_icdinode_has_bigtime helper (Brian Foster) [2072552]
- xfs: handle crtime more carefully in xfs_bulkstat_one_int (Brian Foster) [2072552]
- xfs: consistently initialize di_flags2 (Brian Foster) [2072552]
- xfs: split xfs_imap_to_bp (Brian Foster) [2072552]
- xfs: scrub: Remove incorrect check executed on block format directories (Brian Foster) [2072552]
- xfs: add error injection for per-AG resv failure (Brian Foster) [2072552]
- xfs: support shrinking unused space in the last AG (Brian Foster) [2072552]
- xfs: introduce xfs_ag_shrink_space() (Brian Foster) [2072552]
- xfs: hoist out xfs_resizefs_init_new_ags() (Brian Foster) [2072552]
- xfs: update lazy sb counters immediately for resizefs (Brian Foster) [2072552]
- xfs: __percpu_counter_compare() inode count debug too expensive (Brian Foster) [2072552]
- xfs: reduce debug overhead of dir leaf/node checks (Brian Foster) [2072552]
- xfs: No need for inode number error injection in __xfs_dir3_data_check (Brian Foster) [2072552]
- xfs: type verification is expensive (Brian Foster) [2072552]
- xfs: optimise xfs_buf_item_size/format for contiguous regions (Brian Foster) [2072552]
- xfs: xfs_buf_item_size_segment() needs to pass segment offset (Brian Foster) [2072552]
- xfs: reduce buffer log item shadow allocations (Brian Foster) [2072552]
- xfs: initialise attr fork on inode create (Brian Foster) [2072552]
- xfs: ensure xfs_errortag_random_default matches XFS_ERRTAG_MAX (Brian Foster) [2072552]
- xfs: rename variable mp to parsing_mp (Brian Foster) [2072552]
- xfs: rename the blockgc workqueue (Brian Foster) [2072552]
- xfs: validate ag btree levels using the precomputed values (Brian Foster) [2072552]
- xfs: remove return value from xchk_ag_btcur_init (Brian Foster) [2072552]
- xfs: set the scrub AG number in xchk_ag_read_headers (Brian Foster) [2072552]
- xfs: bail out of scrub immediately if scan incomplete (Brian Foster) [2072552]
- xfs: drop freeze protection when running GETFSMAP (Brian Foster) [2072552]
- selftest/powerpc: Add PAPR sysfs attributes sniff test (Steve Best) [1986183]
- powerpc/pseries: Interface to represent PAPR firmware attributes (Steve Best) [1986183]
- net: mana: Remove unnecessary check of cqe_type in mana_process_rx_cqe() (Mohammed Gamal) [2051719]
- net: mana: Add handling of CQE_RX_TRUNCATED (Mohammed Gamal) [2051719]
- RDMA/rxe: Revert changes from irqsave to bh locks (Kamal Heib) [2056499]
- RDMA/rxe: Check the last packet by RXE_END_MASK (Kamal Heib) [2056499]
- RDMA/rxe: Remove qp->grp_lock and qp->grp_list (Kamal Heib) [2056499]
- RDMA/rxe: Remove rxe_drop_all_macst_groups (Kamal Heib) [2056499]
- RDMA/rxe: Enforce IBA o10-2.2.3 (Kamal Heib) [2056499]
- RDMA/rxe: Rename rxe_mc_grp and rxe_mc_elem (Kamal Heib) [2056499]
- RDMA/rxe: Move rxe_mcast_attach/detach to rxe_mcast.c (Kamal Heib) [2056499]
- RDMA/rxe: Move rxe_mcast_add/delete to rxe_mcast.c (Kamal Heib) [2056499]
- RDMA/cma: Do not change route.addr.src_addr outside state checks (Kamal Heib) [2056499]
- RDMA/ib_srp: Fix a deadlock (Kamal Heib) [2056499]
- RDMA/siw: Fix broken RDMA Read Fence/Resume logic. (Kamal Heib) [2056499]
- IB/cm: Release previously acquired reference counter in the cm_id_priv (Kamal Heib) [2056499]
- RDMA/siw: Fix refcounting leak in siw_create_qp() (Kamal Heib) [2056499]
- RDMA/ucma: Protect mc during concurrent multicast leaves (Kamal Heib) [2056499]
- RDMA/cma: Use correct address when leaving multicast group (Kamal Heib) [2056499]
- IB/hfi1: Fix tstats alloc and dealloc (Kamal Heib) [2056499 2049845]
- IB/hfi1: Fix AIP early init panic (Kamal Heib) [2056499 2049845]
- IB/hfi1: Fix alloc failure with larger txqueuelen (Kamal Heib) [2056499 2049845]
- IB/hfi1: Fix panic with larger ipoib send_queue_size (Kamal Heib) [2056499 2049845]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Kamal Heib) [2056499]
- RDMA/irdma: Remove the redundant return (Kamal Heib) [2056499 2037972]
- RDMA/rxe: Use the standard method to produce udp source port (Kamal Heib) [2056499]
- RDMA/irdma: Make the source udp port vary (Kamal Heib) [2056499 2037972]
- RDMA/core: Calculate UDP source port based on flow label or lqpn/rqpn (Kamal Heib) [2056499]
- IB/iser: Align coding style across driver (Kamal Heib) [2056499]
- IB/iser: Remove un-needed casting to/from void pointer (Kamal Heib) [2056499]
- IB/iser: Don't suppress send completions (Kamal Heib) [2056499]
- IB/iser: Rename ib_ret local variable (Kamal Heib) [2056499]
- IB/iser: Fix RNR errors (Kamal Heib) [2056499]
- IB/iser: Remove deprecated pi_guard module param (Kamal Heib) [2056499]
- IB/mlx5: Expose NDR speed through MAD (Kamal Heib) [2056499]
- RDMA/rxe: Delete deprecated module parameters interface (Kamal Heib) [2056499]
- RDMA/mad: Delete duplicated init_query_mad functions (Kamal Heib) [2056499]
- RDMA/rxe: Fix indentations and operators sytle (Kamal Heib) [2056499]
- RDMA: Use default_groups in kobj_type (Kamal Heib) [2056499]
- RDMA/rxe: Fix a typo in opcode name (Kamal Heib) [2056499]
- RDMA/rxe: Remove the unused xmit_errors member (Kamal Heib) [2056499]
- RDMA/rxe: Remove redundant err variable (Kamal Heib) [2056499]
- RDMA/irdma: Use auxiliary_device driver data helpers (Kamal Heib) [2056499 2037972]
- driver core: auxiliary bus: Add driver data helpers (Kamal Heib) [2056499]
- RDMA/cma: Let cma_resolve_ib_dev() continue search even after empty entry (Kamal Heib) [2056499]
- RDMA/core: Let ib_find_gid() continue search even after empty entry (Kamal Heib) [2056499]
- RDMA/core: Modify rdma_query_gid() to return accurate error codes (Kamal Heib) [2056499]
- RDMA/rxe: Remove the unnecessary variable (Kamal Heib) [2056499]
- RDMA/irdma: Fix the type used to declare a bitmap (Kamal Heib) [2056499 2037972]
- RDMA/uverbs: Remove the unnecessary assignment (Kamal Heib) [2056499]
- RDMA/siw: Use max() instead of doing it manually (Kamal Heib) [2056499]
- RDMA/pvrdma: Use non-atomic bitmap functions when possible (Kamal Heib) [2056499]
- RDMA/pvrdma: Use bitmap_zalloc() when applicable (Kamal Heib) [2056499]
- IB/hfi1: Use bitmap_zalloc() when applicable (Kamal Heib) [2056499 2049845]
- RDMA/siw: Use helper function to set sys_image_guid (Kamal Heib) [2056499]
- RDMA/cma: Remove open coding of overflow checking for private_data_len (Kamal Heib) [2056499]
- RDMA/rxe: Remove some #defines from rxe_pool.h (Kamal Heib) [2056499]
- RDMA/rxe: Remove #include "rxe_loc.h" from rxe_pool.c (Kamal Heib) [2056499]
- RDMA/rxe: Save object pointer in pool element (Kamal Heib) [2056499]
- RDMA/rxe: Copy setup parameters into rxe_pool (Kamal Heib) [2056499]
- RDMA/rxe: Cleanup rxe_pool_entry (Kamal Heib) [2056499]
- RDMA/rxe: Replace irqsave locks with bh locks (Kamal Heib) [2056499]
- RDMA/usnic: Clean up usnic_ib_alloc_pd() (Kamal Heib) [2056499]
- RDMA/irdma: Use helper function to set GUIDs (Kamal Heib) [2056499 2037972]
- RDMA/rxe: Prevent double freeing rxe_map_set() (Kamal Heib) [2056498]
- IB/hfi1: Fix leak of rcvhdrtail_dummy_kvaddr (Kamal Heib) [2056498 2049845]
- IB/hfi1: Fix early init panic (Kamal Heib) [2056498 2049845]
- IB/hfi1: Insure use of smp_processor_id() is preempt disabled (Kamal Heib) [2056498 2049845]
- IB/hfi1: Correct guard on eager buffer deallocation (Kamal Heib) [2056498 2049845]
- RDMA: Fix use-after-free in rxe_queue_cleanup (Kamal Heib) [2056498]
- RDMA/nldev: Check stat attribute before accessing it (Kamal Heib) [2056498]
- IB/hfi1: Properly allocate rdma counter desc memory (Kamal Heib) [2056498 2049845]
- RDMA/core: Set send and receive CQ before forwarding to the driver (Kamal Heib) [2056498]
- RDMA/netlink: Add __maybe_unused to static inline in C file (Kamal Heib) [2056498]
- RDMA/core: Require the driver to set the IOVA correctly during rereg_mr (Kamal Heib) [2056498]
- RDMA/irdma: optimize rx path by removing unnecessary copy (Kamal Heib) [2056498 2037972]
- IB/opa_vnic: Rebranding of OPA VNIC driver to Cornelis Networks (Kamal Heib) [2056498]
- IB/hfi1: Rebranding of hfi1 driver to Cornelis Networks (Kamal Heib) [2056498 2049845]
- RDMA/rxe: Make rxe_type_info static const (Kamal Heib) [2056498]
- RDMA/rxe: Use 'bitmap_zalloc()' when applicable (Kamal Heib) [2056498]
- RDMA/rxe: Save a few bytes from struct rxe_pool (Kamal Heib) [2056498]
- RDMA/irdma: Remove the unused variable local_qp (Kamal Heib) [2056498 2037972]
- RDMA/core: Fix missed initialization of rdma_hw_stats::lock (Kamal Heib) [2056498]
- RDMA/irdma: Remove the unused spin lock in struct irdma_qp_uk (Kamal Heib) [2056498 2037972]
- RDMA: Constify netdev->dev_addr accesses (Kamal Heib) [2056498]
- RDMA/ipoib: Use dev_addr_mod() (Kamal Heib) [2056498]
- RDMA/core: Use kvzalloc when allocating the struct ib_port (Kamal Heib) [2056498]
- RDMA/irdma: Make irdma_uk_cq_init() return a void (Kamal Heib) [2056498 2037972]
- RDMA/rxe: Convert kernel UD post send to use ah_num (Kamal Heib) [2056498]
- RDMA/rxe: Lookup kernel AH from ah index in UD WQEs (Kamal Heib) [2056498]
- RDMA/rxe: Replace ah->pd by ah->ibah.pd (Kamal Heib) [2056498]
- RDMA/rxe: Create AH index and return to user space (Kamal Heib) [2056498]
- RDMA/rxe: Change AH objects to indexed (Kamal Heib) [2056498]
- RDMA/rxe: Move AV from rxe_send_wqe to rxe_send_wr (Kamal Heib) [2056498]
- RDMA/irdma: Remove irdma_cqp_up_map_cmd() (Kamal Heib) [2056498 2037972]
- RDMA/irdma: Remove irdma_get_hw_addr() (Kamal Heib) [2056498 2037972]
- RDMA/irdma: Remove irdma_sc_send_lsmm_nostag() (Kamal Heib) [2056498 2037972]
- RDMA/irdma: Remove irdma_uk_mw_bind() (Kamal Heib) [2056498 2037972]
- RDMA: Remove redundant 'flush_workqueue()' calls (Kamal Heib) [2056498]
- RDMA/iwpm: Remove redundant initialization of pointer err_str (Kamal Heib) [2056498]
- RDMA/nldev: Allow optional-counter status configuration through RDMA netlink (Kamal Heib) [2056498]
- RDMA/nldev: Split nldev_stat_set_mode_doit out of nldev_stat_set_doit (Kamal Heib) [2056498]
- RDMA/nldev: Add support to get status of all counters (Kamal Heib) [2056498]
- RDMA/counter: Add optional counter support (Kamal Heib) [2056498]
- RDMA/counter: Add an is_disabled field in struct rdma_hw_stats (Kamal Heib) [2056498]
- RDMA/core: Add a helper API rdma_free_hw_stats_struct (Kamal Heib) [2056498]
- RDMA/bnxt_re: Fix kernel panic when trying to access bnxt_re_stat_descs (Kamal Heib) [2056499]
- RDMA/counter: Add a descriptor in struct rdma_hw_stats (Kamal Heib) [2056498]
- RDMA/bnxt_re: Update statistics counter name (Kamal Heib) [2056498]
- RDMA/bnxt_re: Add extended statistics counters (Kamal Heib) [2056498]
- RDMA/efa: CQ notifications (Kamal Heib) [2056498]
- RDMA/rxe: Remove duplicate settings (Kamal Heib) [2056498]
- RDMA/rxe: Set partial attributes when completion status != IBV_WC_SUCCESS (Kamal Heib) [2056498]
- RDMA/rxe: Change the is_user member of struct rxe_cq to bool (Kamal Heib) [2056498]
- RDMA/rxe: Remove the is_user members of struct rxe_sq/rxe_rq/rxe_srq (Kamal Heib) [2056498]
- RDMA/irdma: Delete unused struct irdma_bth (Kamal Heib) [2056498 2037972]
- IB/hf1: Use string_upper() instead of an open coded variant (Kamal Heib) [2056498]
- RDMA/cma: Split apart the multiple uses of the same list heads (Kamal Heib) [2056498]
- RDMA/rxe: Remove unused WR_READ_WRITE_OR_SEND_MASK (Kamal Heib) [2056498]
- RDMA/rxe: Add MASK suffix for RXE_READ_OR_ATOMIC and RXE_WRITE_OR_SEND (Kamal Heib) [2056498]
- RDMA/rxe: Add new RXE_READ_OR_WRITE_MASK (Kamal Heib) [2056498]
- RDMA/hfi1: Use struct_size() and flex_array_size() helpers (Kamal Heib) [2056498 2049845]
- IB/hfi1: Add ring consumer and producers traces (Kamal Heib) [2056498 2049845]
- IB/hfi1: Remove atomic completion count (Kamal Heib) [2056498 2049845]
- IB/hfi1: Tune netdev xmit cachelines (Kamal Heib) [2056498 2049845]
- IB/hfi1: Get rid of tx priv backpointer (Kamal Heib) [2056498 2049845]
- IB/hfi1: Get rid of hot path divide (Kamal Heib) [2056498 2049845]
- IB/hfi1: Remove cache and embed txreq in ring (Kamal Heib) [2056498 2049845]
- RDMA/rxe: Only allow invalidate for appropriate MRs (Kamal Heib) [2056498]
- RDMA/rxe: Create duplicate mapping tables for FMRs (Kamal Heib) [2056498]
- RDMA/rxe: Separate HW and SW l/rkeys (Kamal Heib) [2056498]
- RDMA/rxe: Cleanup MR status and type enums (Kamal Heib) [2056498]
- RDMA/rxe: Add memory barriers to kernel queues (Kamal Heib) [2056498]
- RDMA/rxe: remove the unnecessary variable (Kamal Heib) [2056498]
- RDMA/rxe: remove the redundant variable (Kamal Heib) [2056498]
- RDMA/rxe: Fix wrong port_cap_flags (Kamal Heib) [2056498]
- RDMA/rdmavt: Fix error code in rvt_create_qp() (Kamal Heib) [2056497 2049845]
- IB/hfi1: Fix abba locking issue with sc_disable() (Kamal Heib) [2056497 2049845]
- RDMA/hfi1: Fix kernel pointer leak (Kamal Heib) [2056497 2049845]
- RDMA/usnic: Lock VF with mutex instead of spinlock (Kamal Heib) [2056497]
- RDMA/cma: Do not change route.addr.src_addr.ss_family (Kamal Heib) [2056497]
- IB/hfi1: make hist static (Kamal Heib) [2056497 2049845]
- RDMA/hfi1: Convert to SPDX identifier (Kamal Heib) [2056497 2049845]
- IB/rdmavt: Convert to SPDX identifier (Kamal Heib) [2056497 2049845]
- RDMA/core/sa_query: Retry SA queries (Kamal Heib) [2056497]
- IB/core: Remove deprecated current_seq comments (Kamal Heib) [2056497]
- RDMA/efa: Rename vector field in efa_irq struct to irqn (Kamal Heib) [2056497]
- RDMA/efa: Remove unused cpu field from irq struct (Kamal Heib) [2056497]
- RDMA/core/sa_query: Remove unused function (Kamal Heib) [2056497]
- RDMA/hfi1: Stop using seq_get_buf in _driver_stats_seq_show (Kamal Heib) [2056497 2049845]
- RDMA/core: Create clean QP creations interface for uverbs (Kamal Heib) [2056497]
- RDMA/core: Properly increment and decrement QP usecnts (Kamal Heib) [2056497]
- RDMA/core: Configure selinux QP during creation (Kamal Heib) [2056497]
- RDMA/core: Reorganize create QP low-level functions (Kamal Heib) [2056497]
- RDMA/core: Remove protection from wrong in-kernel API usage (Kamal Heib) [2056497]
- RDMA/core: Delete duplicated and unreachable code (Kamal Heib) [2056497]
- rdma/qedr: Fix crash due to redundant release of device's qp memory (Kamal Heib) [2056497]
- RDMA: Globally allocate and release QP memory (Kamal Heib) [2056497]
- RDMA/mlx5: Rework custom driver QP type creation (Kamal Heib) [2056497]
- RDMA/usnic: Fix memleak in find_free_vf_and_create_qp_grp (Kamal Heib) [2056497]
- RDMA/rdmavt: Decouple QP and SGE lists allocations (Kamal Heib) [2056497 2049845]
- RDMA/efa: Remove double QP type assignment (Kamal Heib) [2056497]
- RDMA/hfi1: Fix typo in comments (Kamal Heib) [2056497 2049845]
- RDMA/iwpm: Rely on the rdma_nl_[un]register() to ensure that requests are valid (Kamal Heib) [2056497]
- RDMA/iwpm: Remove not-needed reference counting (Kamal Heib) [2056497]
- RDMA/hfi1: Convert from atomic_t to refcount_t on hfi1_devdata->user_refcount (Kamal Heib) [2056497 2049845]
- IB/hfi1: Adjust pkey entry in index 0 (Kamal Heib) [2056497 2049845]
- IB/hfi1: Indicate DMA wait when txq is queued for wakeup (Kamal Heib) [2056497 2049845]
- RDMA/rxe: Fix types in rxe_icrc.c (Kamal Heib) [2056497]
- RDMA/rxe: Add kernel-doc comments to rxe_icrc.c (Kamal Heib) [2056497]
- RDMA/rxe: Move crc32 init code to rxe_icrc.c (Kamal Heib) [2056497]
- RDMA/rxe: Fixup rxe_icrc_hdr (Kamal Heib) [2056497]
- RDMA/rxe: Move rxe_crc32 to a subroutine (Kamal Heib) [2056497]
- RDMA/rxe: Move ICRC generation to a subroutine (Kamal Heib) [2056497]
- RDMA/rxe: Fixup rxe_send and rxe_loopback (Kamal Heib) [2056497]
- RDMA/rxe: Move rxe_xmit_packet to a subroutine (Kamal Heib) [2056497]
- RDMA/rxe: Move ICRC checking to a subroutine (Kamal Heib) [2056497]
- IB/core: Read subnet_prefix in ib_query_port via cache. (Kamal Heib) [2056497]
- IB/core: Shifting initialization of device->cache_lock (Kamal Heib) [2056497]
- IB/core: Updating cache for subnet_prefix in config_non_roce_gid_cache() (Kamal Heib) [2056497]
- RDMA/efa: Split hardware stats to device and port stats (Kamal Heib) [2056497]
- RDMA/rxe: Remove the repeated 'mr->umem = umem' (Kamal Heib) [2056497]
- RDMA/siw: Convert siw_tx_hdt() to kmap_local_page() (Kamal Heib) [2056497]
- RDMA/siw: Remove kmap() (Kamal Heib) [2056497]
- treewide: Add missing semicolons to __assign_str uses (Kamal Heib) [2056497]
- RDMA/hfi1: Remove use of kmap() (Kamal Heib) [2056497 2049845]
- RDMA: Delete not-used static inline functions (Kamal Heib) [2056497]
- mm/page_owner.c: record tgid (Waiman Long) [2069294]
- mm/page_owner: record task command name (Waiman Long) [2069294]
- mm/page_owner: print memcg information (Waiman Long) [2069294]
- mm/page_owner: use scnprintf() to avoid excessive buffer overrun check (Waiman Long) [2069294]
- lib/vsprintf: avoid redundant work with 0 size (Waiman Long) [2069294]
- lib, stackdepot: add helper to print stack entries into buffer (Waiman Long) [2069294]
- lib, stackdepot: add helper to print stack entries (Waiman Long) [2069294]
- lib, stackdepot: check stackdepot handle before accessing slabs (Waiman Long) [2069294]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Waiman Long) [2069294]
- lib/stackdepot: introduce __stack_depot_save() (Waiman Long) [2069294]
- mm: introduce PAGEFLAGS_MASK to replace ((1UL << NR_PAGEFLAGS) - 1) (Waiman Long) [2069294]
- mm/page_owner: constify dump_page_owner (Waiman Long) [2069294]
- mm: page_owner: detect page_owner recursion via task_struct (Waiman Long) [2069294]
- mm: page_owner: use kstrtobool() to parse bool option (Waiman Long) [2069294]
- mm: page_owner: fetch backtrace only for tracked pages (Waiman Long) [2069294]
- mm, page_owner: remove unused parameter in __set_page_owner_handle (Waiman Long) [2069294]
- mm/page_owner: record the timestamp of all pages during free (Waiman Long) [2069294]
- mm/page_owner: use helper function zone_end_pfn() to get end_pfn (Waiman Long) [2069294]
- mm/page_owner: record timestamp and pid (Waiman Long) [2069294]
- x86/platform/uv: Log gap hole end size (Frank Ramsay) [2074098]
- x86/platform/uv: Update TSC sync state for UV5 (Frank Ramsay) [2074098]
- x86/platform/uv: Update NMI Handler for UV5 (Frank Ramsay) [2074098]
- x86/platform/uv: Remove unused variable in UV5 NMI handler (Frank Ramsay) [2074098]
- timekeeping: Boot should be boottime for coarse ns accessor (Ivan Vecera) [2076879]

* Thu Apr 28 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-387.el8]
- net_tstamp: define new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2070041]
- net_tstamp: add new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2070041]
- net: fix NULL pointer reference in cipso_v4_doi_free (Guillaume Nault) [2074597]
- partitions/efi: Fix partition name parsing in GUID partition entry (Ming Lei) [2075085]
- psi: Fix uaf issue when psi trigger is destroyed while being polled (Waiman Long) [2046396]
- cgroup/cpuset: Make child cpusets restrict parents on v1 hierarchy (Waiman Long) [2046396]
- cgroup/cpuset: Don't let child cpusets restrict parent in default hierarchy (Waiman Long) [2046396]
- mm/page_alloc: detect allocation forbidden by cpuset and bail out early (Waiman Long) [2046396]
- cgroup: Fix rootcg cpu.stat guest double counting (Waiman Long) [2046396]
- cgroup: no need for cgroup_mutex for /proc/cgroups (Waiman Long) [2046396]
- cgroup: remove cgroup_mutex from cgroupstats_build (Waiman Long) [2046396]
- cgroup: Fix memory leak caused by missing cgroup_bpf_offline (Waiman Long) [2046396]
- cgroup: cgroup-v1: do not exclude cgrp_dfl_root (Waiman Long) [2046396]
- bpf, test, cgroup: Use sk_{alloc,free} for test cases (Waiman Long) [2046396]
- bpf, cgroup: Assign cgroup in cgroup_sk_alloc when called from interrupt (Waiman Long) [2046396]
- bpf, cgroups: Fix cgroup v2 fallback on v1/v2 mixed mode (Waiman Long) [2046396]
- cgroup/cpuset: Change references of cpuset_mutex to cpuset_rwsem (Waiman Long) [2046396]
- cgroup: Replace deprecated CPU-hotplug functions. (Waiman Long) [2046396]
- cgroup/cpuset: Fix a partition bug with hotplug (Waiman Long) [2046396]
- cgroup/cpuset: Miscellaneous code cleanup (Waiman Long) [2046396]
- cgroup/cpuset: fix typos in comments (Waiman Long) [2046396]
- enable DAMON configs (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/reclaim: document statistics parameters (Chris von Recklinghausen) [2004233]
- mm/damon: hide kernel pointer from tracepoint event (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: hide kernel pointer from damon_va_three_regions() failure log (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: use pr_debug() for damon_va_three_regions() failure logging (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: remove an unnecessary variable (Chris von Recklinghausen) [2004233]
- mm/damon: move the implementation of damon_insert_region to damon.h (Chris von Recklinghausen) [2004233]
- mm/damon: add access checking for hugetlb pages (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/usage: update for schemes statistics (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support all DAMOS stats (Chris von Recklinghausen) [2004233]
- mm/damon/reclaim: provide reclamation statistics (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: account how many times quota limit has exceeded (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: account scheme actions that successfully applied (Chris von Recklinghausen) [2004233]
- mm/damon: remove a mistakenly added comment for a future feature (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/usage: update for kdamond_pid and (mk|rm)_contexts (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/usage: mention tracepoint at the beginning (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/usage: remove redundant information (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/usage: update for scheme quotas and watermarks (Chris von Recklinghausen) [2004233]
- mm/damon: convert macro functions to static inline functions (Chris von Recklinghausen) [2004233]
- mm/damon: modify damon_rand() macro to static inline function (Chris von Recklinghausen) [2004233]
- mm/damon: move damon_rand() definition into damon.h (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: add the validity judgment of thresholds (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: remove swap_ranges() and replace it with swap() (Chris von Recklinghausen) [2004233]
- mm/damon: remove some unneeded function definitions in damon.h (Chris von Recklinghausen) [2004233]
- mm/damon/core: use abs() instead of diff_of() (Chris von Recklinghausen) [2004233]
- mm/damon: unified access_check function naming rules (Chris von Recklinghausen) [2004233]
- mm/damon: add 'age' of region tracepoint support (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: fix 'struct pid' leaks in 'dbgfs_target_ids_write()' (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: protect targets destructions with kdamond_lock (Chris von Recklinghausen) [2004233]
- selftests/damon: split test cases (Chris von Recklinghausen) [2004233]
- selftests/damon: test debugfs file reads/writes with huge count (Chris von Recklinghausen) [2004233]
- selftests/damon: test wrong DAMOS condition ranges input (Chris von Recklinghausen) [2004233]
- selftests/damon: test DAMON enabling with empty target_ids case (Chris von Recklinghausen) [2004233]
- selftests/damon: skip test if DAMON is running (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr-test: remove unnecessary variables (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr-test: split a test function having >1024 bytes frame size (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: remove an unnecessary warning message (Chris von Recklinghausen) [2004233]
- mm/damon/core: remove unnecessary error messages (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: remove an unnecessary error message (Chris von Recklinghausen) [2004233]
- mm/damon/core: use better timer mechanisms selection threshold (Chris von Recklinghausen) [2004233]
- mm/damon/core: fix fake load reports due to uninterruptible sleeps (Chris von Recklinghausen) [2004233]
- timers: implement usleep_idle_range() (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: fix missed use of damon_dbgfs_lock (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: use '__GFP_NOWARN' for user-specified size buffer allocation (Chris von Recklinghausen) [2004233]
- mm/damon: remove return value from before_terminate callback (Chris von Recklinghausen) [2004233]
- mm/damon: fix a few spelling mistakes in comments and a pr_debug message (Chris von Recklinghausen) [2004233]
- mm/damon: simplify stop mechanism (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/start: simplify the content (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/start: fix a wrong link (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon/start: fix wrong example commands (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: add adaptive_targets list check before enable monitor_on (Chris von Recklinghausen) [2004233]
- mm/damon: remove unnecessary variable initialization (Chris von Recklinghausen) [2004233]
- Documentation/admin-guide/mm/damon: add a document for DAMON_RECLAIM (Chris von Recklinghausen) [2004233]
- mm/damon: introduce DAMON-based Reclamation (DAMON_RECLAIM) (Chris von Recklinghausen) [2004233]
- selftests/damon: support watermarks (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support watermarks (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: activate schemes based on a watermarks mechanism (Chris von Recklinghausen) [2004233]
- tools/selftests/damon: update for regions prioritization of schemes (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support prioritization weights (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr,paddr: support pageout prioritization (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: prioritize regions within the quotas (Chris von Recklinghausen) [2004233]
- mm/damon/selftests: support schemes quotas (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support quotas of schemes (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: implement time quota (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: skip already charged targets and regions (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: implement size quota for schemes application speed control (Chris von Recklinghausen) [2004233]
- mm/damon/paddr: support the pageout scheme (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: remove unnecessary variables (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: constify static mm_walk_ops (Chris von Recklinghausen) [2004233]
- Docs/DAMON: document physical memory monitoring support (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support physical memory monitoring (Chris von Recklinghausen) [2004233]
- mm/damon: implement primitives for physical address space monitoring (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: separate commonly usable functions (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs-test: add a unit test case for 'init_regions' (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon: document 'init_regions' feature (Chris von Recklinghausen) [2004233]
- Docs/admin-guide/mm/damon: document DAMON-based Operation Schemes (Chris von Recklinghausen) [2004233]
- docs/vm/damon: remove broken reference (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: allow users to set initial monitoring target regions (Chris von Recklinghausen) [2004233]
- selftests/damon: add 'schemes' debugfs tests (Chris von Recklinghausen) [2004233]
- mm/damon/schemes: implement statistics feature (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004233]
- mm/damon/vaddr: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004233]
- mm/damon/core: implement DAMON-based Operation Schemes (DAMOS) (Chris von Recklinghausen) [2004233]
- mm/damon/core: account age of target regions (Chris von Recklinghausen) [2004233]
- mm/damon/core: nullify pointer ctx->kdamond with a NULL (Chris von Recklinghausen) [2004233]
- mm/damon: needn't hold kdamond_lock to print pid of kdamond (Chris von Recklinghausen) [2004233]
- mm/damon: remove unnecessary do_exit() from kdamond (Chris von Recklinghausen) [2004233]
- mm/damon/core: print kdamond start log in debug mode only (Chris von Recklinghausen) [2004233]
- mm/damon: grammar s/works/work/ (Chris von Recklinghausen) [2004233]
- mm/damon/core-test: fix wrong expectations for 'damon_split_regions_of()' (Chris von Recklinghausen) [2004233]
- mm/damon: don't use strnlen() with known-bogus source length (Chris von Recklinghausen) [2004233]
- mm/damon: add kunit tests (Chris von Recklinghausen) [2004233]
- Documentation: add documents for DAMON (Chris von Recklinghausen) [2004233]
- mm/damon: add user space selftests (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: support multiple contexts (Chris von Recklinghausen) [2004233]
- mm/damon/dbgfs: export kdamond pid to the user space (Chris von Recklinghausen) [2004233]
- mm/damon: implement a debugfs-based user space interface (Chris von Recklinghausen) [2004233]
- mm/damon: add a tracepoint (Chris von Recklinghausen) [2004233]
- mm/damon: implement primitives for the virtual memory address spaces (Chris von Recklinghausen) [2004233]
- mm/damon: adaptively adjust regions (Chris von Recklinghausen) [2004233]
- mm/damon/core: implement region-based sampling (Chris von Recklinghausen) [2004233]
- mm: introduce Data Access MONitor (DAMON) (Chris von Recklinghausen) [2004233]
- khugepaged: use helper khugepaged_test_exit() in __khugepaged_enter() (Chris von Recklinghausen) [2004233]
- mm/madvise: pass mm to do_madvise (Chris von Recklinghausen) [2004233]
- ceph: fix possible NULL pointer dereference for req->r_session (Xiubo Li) [2076165]
- thermal: int340x: Fix VCoRefLow MMIO bit offset for TGL (Prarit Bhargava) [2039994]
- MAINTAINERS: sort field names for all entries (Joel Savitz) [2064843]
- parse-maintainers: Do not sort section content by default (Joel Savitz) [2064843]
- parse-maintainers: Mark as executable (Joel Savitz) [2064843]
- KVM: x86: Use ERR_PTR_USR() to return -EFAULT as a __user pointer (Paul Lai) [2074679]
- KVM: x86: add system attribute to retrieve full set of supported xsave states (Paul Lai) [2074679]
- KVM: x86: Add a helper to retrieve userspace address from kvm_device_attr (Paul Lai) [2074679]
- tools: arch: x86: pull in pvclock headers (Paul Lai) [2074679]
- KVM: x86: Expose TSC offset controls to userspace (Paul Lai) [2074679]
- KVM: x86: Refactor tsc synchronization code (Paul Lai) [2074679]
- selftests: kvm: move vm_xsave_req_perm call to amx_test (Paul Lai) [2074679]
- powerpc/pseries/vas: Add VAS migration handler (Steve Best) [2028678]
- powerpc/pseries/vas: Modify reconfig open/close functions for migration (Steve Best) [2028678]
- powerpc/pseries/vas: Define global hv_cop_caps struct (Steve Best) [2028678]
- powerpc/pseries/vas: Add 'update_total_credits' entry for QoS capabilities (Steve Best) [2028678]
- powerpc/pseries/vas: sysfs interface to export capabilities (Steve Best) [2028678]
- powerpc/pseries/vas: Reopen windows with DLPAR core add (Steve Best) [2028678]
- powerpc/pseries/vas: Close windows with DLPAR core removal (Steve Best) [2028678]
- powerpc/vas: Map paste address only if window is active (Steve Best) [2028678]
- powerpc/vas: Return paste instruction failure if no active window (Steve Best) [2028678]
- powerpc/vas: Add paste address mmap fault handler (Steve Best) [2028678]
- powerpc/pseries/vas: Save PID in pseries_vas_window struct (Steve Best) [2028678]
- powerpc/pseries/vas: Use common names in VAS capability structure (Steve Best) [2028678]
- perf powerpc: Update global/local variants for p_stage_cyc (Desnes A. Nunes do Rosario) [2051358]
- perf sort: Include global and local variants for p_stage_cyc sort key (Desnes A. Nunes do Rosario) [2051358]
- perf sort: Fix the 'p_stage_cyc' sort key behavior (Desnes A. Nunes do Rosario) [2051358]
- perf sort: Fix the 'ins_lat' sort key behavior (Desnes A. Nunes do Rosario) [2051358]
- perf sort: Fix the 'weight' sort key behavior (Desnes A. Nunes do Rosario) [2051358]
- block: loop:use kstatfs.f_bsize of backing file to set discard granularity (Ming Lei) [2069472]
- blk-cgroup: set blkg iostat after percpu stat aggregation (Ming Lei) [2069472]
- block: update io_ticks when io hang (Ming Lei) [2069472]
- block: don't delete queue kobject before its children (Ming Lei) [2069472]
- block/wbt: fix negative inflight counter when remove scsi device (Ming Lei) [2069472]
- block: bio-integrity: Advance seed correctly for larger interval sizes (Ming Lei) [2069472]
- block: fix async_depth sysfs interface for mq-deadline (Ming Lei) [2069472]
- bfq: Do not let waker requests skip proper accounting (Ming Lei) [2069472]
- block: Fix fsync always failed if once failed (Ming Lei) [2069472]
- blktrace: fix use after free for struct blk_trace (Ming Lei) [2069472]
- block: Check ADMIN before NICE for IOPRIO_CLASS_RT (Ming Lei) [2069472]
- blk-cgroup: fix missing put device in error path from blkg_conf_pref() (Ming Lei) [2069472]
- blkcg: Remove extra blkcg_bio_issue_init (Ming Lei) [2069472]
- nbd: Fix use-after-free in pid_show (Ming Lei) [2069472]
- block/mq-deadline: Improve request accounting further (Ming Lei) [2069472]
- block, bfq: fix UAF problem in bfqg_stats_init() (Ming Lei) [2069472]
- blk-cgroup: synchronize blkg creation against policy deactivation (Ming Lei) [2069472]
- block, bfq: reset last_bfqq_created on group change (Ming Lei) [2069472]
- block: bfq: fix bfq_set_next_ioprio_data() (Ming Lei) [2069472]
- sched/topology: Remove redundant variable and fix incorrect type in build_sched_domains (Phil Auld) [2065200]
- sched/fair: Adjust the allowed NUMA imbalance when SD_NUMA spans multiple LLCs (Phil Auld) [2065200]
- sched/fair: Improve consistency of allowed NUMA balance calculations (Phil Auld) [2065200]
- Revert: sched: Disable allowing small imbalance to preserve RHEL performance (Phil Auld) [2065200]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Steve Dickson) [2023844]
- SUNRPC: use different lock keys for INET6 and LOCAL (Guillaume Nault) [2061651]
- arm64: Restore forced disabling of KPTI on ThunderX (Mark Salter) [1999157]
- arm64: mte: initialize RGSR_EL1.SEED in __cpu_setup (Mark Salter) [1999157]
- arm64: Remove exporting cpu_logical_map symbol (Mark Salter) [1999157]
- arm64: tlb: fix the TTL value of tlb_get_level (Mark Salter) [1999157]
- arm64: Validate tagged addresses in access_ok() called from kernel threads (Mark Salter) [1999157]
- arm64: ptrace: Fix seccomp of traced syscall -1 (NO_SYSCALL) (Mark Salter) [1999157]
- arm64: ptrace: Use NO_SYSCALL instead of -1 in syscall_trace_enter() (Mark Salter) [1999157]
- arm64: mm: Fix TLBI vs ASID rollover (Mark Salter) [1999157]
- arm64: errata: Fix exec handling in erratum 1418040 workaround (Mark Salter) [1999157]
- arm64: Generate cpucaps.h (Mark Salter) [1999157]
- arm64/sve: Skip flushing Z registers with 128 bit vectors (Mark Salter) [1999157]
- arm64/sve: Rework SVE access trap to convert state in registers (Mark Salter) [1999157]
- arm64/sve: Use the sve_flush macros in sve_load_from_fpsimd_state() (Mark Salter) [1999157]
- arm64/sve: Split _sve_flush macro into separate Z and predicate flushes (Mark Salter) [1999157]
- arm64: fix inline asm in load_unaligned_zeropad() (Mark Salter) [1999157]
- arm64: Extend workaround for erratum 1024718 to all versions of Cortex-A55 (Mark Salter) [1999157]
- arm64/fpsimd: add <asm/insn.h> to <asm/kprobes.h> to fix fpsimd build (Mark Salter) [1999157]
- arm64: cpu_errata: Apply Erratum 845719 to KRYO2XX Silver (Mark Salter) [1999157]
- arm64: kpti: Add KRYO2XX gold/silver CPU cores to kpti safelist (Mark Salter) [1999157]
- arm64: Add MIDR value for KRYO2XX gold/silver CPU cores (Mark Salter) [1999157]
- arm64: errata: Fix handling of 1418040 with late CPU onlining (Mark Salter) [1999157]
- arm64: cpufeature: upgrade hyp caps to final (Mark Salter) [1999157]
- arm64: cpufeature: reorder cpus_have_{const, final}_cap() (Mark Salter) [1999157]
- arm64: Add workaround for Arm Cortex-A77 erratum 1508412 (Mark Salter) [1999157]
- arm64: Add part number for Arm Cortex-A77 (Mark Salter) [1999157]
- arm64: reject prctl(PR_PAC_RESET_KEYS) on compat tasks (Mark Salter) [1999157]
- arm64: Treat SSBS as a non-strict system feature (Mark Salter) [1999157]
- arm64: Group start_thread() functions together (Mark Salter) [1999157]
- arm64: Remove Spectre-related CONFIG_* options (Mark Salter) [1999157]
- arm64: Run ARCH_WORKAROUND_2 enabling code on all CPUs (Mark Salter) [1999157]
- arm64: Run ARCH_WORKAROUND_1 enabling code on all CPUs (Mark Salter) [1999157]
- arm64: mte: CPU feature detection and initial sysreg configuration (Mark Salter) [1999157]
- arm64: cpufeature: Export symbol read_sanitised_ftr_reg() (Mark Salter) [1999157]
- arm64/fpsimd: Fix missing-prototypes in fpsimd.c (Mark Salter) [1999157]
- arm64: traps: Add str of description to panic() in die() (Mark Salter) [1999157]
- arm64/sve: Implement a helper to load SVE registers from FPSIMD state (Mark Salter) [1999157]
- arm64/sve: Implement a helper to flush SVE registers (Mark Salter) [1999157]
- arm64/fpsimdmacros: Allow the macro "for" to be used in more cases (Mark Salter) [1999157]
- arm64/fpsimdmacros: Introduce a macro to update ZCR_EL1.LEN (Mark Salter) [1999157]
- arm64/signal: Update the comment in preserve_sve_context (Mark Salter) [1999157]
- arm64/fpsimd: Update documentation of do_sve_acc (Mark Salter) [1999157]
- arm64: cpufeature: Modify address authentication cpufeature to exact (Mark Salter) [1999157]
- arm64: ptrauth: Introduce Armv8.3 pointer authentication enhancements (Mark Salter) [1999157]
- arm64: traps: Allow force_signal_inject to pass esr error code (Mark Salter) [1999157]
- arm64/cpuinfo: Define HWCAP name arrays per their actual bit definitions (Mark Salter) [1999157]
- arm64: Reserve HWCAP2_MTE as (1 << 18) (Mark Salter) [1999157]
- arm64: Allow CPUs unffected by ARM erratum 1418040 to come in late (Mark Salter) [1999157]
- arm64: Allow booting of late CPUs affected by erratum 1418040 (Mark Salter) [1999157]
- arm64: Drop unnecessary include from asm/smp.h (Mark Salter) [1999157]
- arm64: Move handling of erratum 1418040 into C code (Mark Salter) [1999157]
- arm64: Fix __cpu_logical_map undefined issue (Mark Salter) [1999157]
- arm64: tlb: don't set the ttl value in flush_tlb_page_nosync (Mark Salter) [1999157]
- arm64: Shift the __tlbi_level() indentation left (Mark Salter) [1999157]
- arm64: tlb: Set the TTL field in flush_*_tlb_range (Mark Salter) [1999157]
- arm64: tlb: Set the TTL field in flush_tlb_range (Mark Salter) [1999157]
- arm64: Add tlbi_user_level TLB invalidation helper (Mark Salter) [1999157]
- arm64: Add level-hinted TLB invalidation helper (Mark Salter) [1999157]
- arm64: Document SW reserved PTE/PMD bits in Stage-2 descriptors (Mark Salter) [1999157]
- arm64/cpufeature: Validate feature bits spacing in arm64_ftr_regs[] (Mark Salter) [1999157]
- arm64/cpufeature: Replace all open bits shift encodings with macros (Mark Salter) [1999157]
- arm64/cpufeature: Add remaining feature bits in ID_AA64MMFR2 register (Mark Salter) [1999157]
- arm64/cpufeature: Add remaining feature bits in ID_AA64MMFR1 register (Mark Salter) [1999157]
- arm64/cpufeature: Add remaining feature bits in ID_AA64MMFR0 register (Mark Salter) [1999157]
- arm64: csum: Fix handling of bad packets (Mark Salter) [1999157]
- arm64: Add missing sentinel to erratum_1463225 (Mark Salter) [1999157]
- arm64: Documentation: Fix broken table in generated HTML (Mark Salter) [1999157]
- arm64: kgdb: Fix single-step exception handling oops (Mark Salter) [1999157]
- arm64: entry: Tidy up block comments and label numbers (Mark Salter) [1999157]
- arm64: Rework ARM_ERRATUM_1414080 handling (Mark Salter) [1999157]
- arm64: entry: Fix the typo in the comment of el1_dbg() (Mark Salter) [1999157]
- arm64: Add KRYO4XX silver CPU cores to erratum list 1530923 and 1024718 (Mark Salter) [1999157]
- arm64: Add KRYO4XX gold CPU cores to erratum list 1463225 and 1418040 (Mark Salter) [1999157]
- arm64: Add MIDR value for KRYO4XX gold CPU cores (Mark Salter) [1999157]
- arm64: Add KRYO{3,4}XX silver CPU cores to SSB safelist (Mark Salter) [1999157]
- arm64: kpti: Add KRYO{3, 4}XX silver CPU cores to kpti safelist (Mark Salter) [1999157]
- arm64: sve: Fix build failure when ARM64_SVE=y and SYSCTL=n (Mark Salter) [1999157]
- arm64: mm: reset address tag set by kasan sw tagging (Mark Salter) [1999157]
- arm64: traps: Dump registers prior to panic() in bad_mode() (Mark Salter) [1999157]
- arm64/sve: Eliminate data races on sve_default_vl (Mark Salter) [1999157]
- arm64: csum: Disable KASAN for do_csum() (Mark Salter) [1999157]
- arm64/cpufeature: Add get_arm64_ftr_reg_nowarn() (Mark Salter) [1999157]
- arm64/cpuinfo: Add ID_MMFR4_EL1 into the cpuinfo_arm64 context (Mark Salter) [1999157]
- arm64/cpufeature: Add remaining feature bits in ID_AA64PFR0 register (Mark Salter) [1999157]
- arm64/cpufeature: Add remaining feature bits in ID_MMFR4 register (Mark Salter) [1999157]
- arm64/cpufeature: Add remaining feature bits in ID_PFR0 register (Mark Salter) [1999157]
- arm64/cpufeature: Introduce ID_MMFR5 CPU register (Mark Salter) [1999157]
- arm64/cpufeature: Introduce ID_DFR1 CPU register (Mark Salter) [1999157]
- arm64/cpufeature: Introduce ID_PFR2 CPU register (Mark Salter) [1999157]
- arm64/cpufeature: Make doublelock a signed feature in ID_AA64DFR0 (Mark Salter) [1999157]
- arm64/cpufeature: Drop TraceFilt feature exposure from ID_DFR0 register (Mark Salter) [1999157]
- arm64/cpufeature: Add explicit ftr_id_isar0[] for ID_ISAR0 register (Mark Salter) [1999157]
- arm64: cpufeature: Group indexed system register definitions by name (Mark Salter) [1999157]
- arm64: cpufeature: Extend comment to describe absence of field info (Mark Salter) [1999157]
- arm64: drop duplicate definitions of ID_AA64MMFR0_TGRAN constants (Mark Salter) [1999157]
- arm64: cpufeature: Add an overview comment for the cpufeature framework (Mark Salter) [1999157]
- arm64: cpufeature: Relax checks for AArch32 support at EL[0-2] (Mark Salter) [1999157]
- arm64: cpufeature: Relax AArch32 system checks if EL1 is 64-bit only (Mark Salter) [1999157]
- arm64: cpufeature: Factor out checking of AArch32 features (Mark Salter) [1999157]
- arm64: cpufeature: Remove redundant call to id_aa64pfr0_32bit_el0() (Mark Salter) [1999157]
- arm64: cpufeature: Spell out register fields for ID_ISAR4 and ID_PFR1 (Mark Salter) [1999157]
- arm64: cpufeature: Relax check for IESB support (Mark Salter) [1999157]
- arm64: mm: Add asid_gen_match() helper (Mark Salter) [1999157]
- arm64: Call debug_traps_init() from trap_init() to help early kgdb (Mark Salter) [1999157]
- arm64: cacheflush: Fix KGDB trap detection (Mark Salter) [1999157]
- arm64/cpuinfo: Move device_initcall() near cpuinfo_regs_init() (Mark Salter) [1999157]
- arm64: kexec_file: print appropriate variable (Mark Salter) [1999157]
- arm: mm: use __pfn_to_section() to get mem_section (Mark Salter) [1999157]
- arm64: Reorder the macro arguments in the copy routines (Mark Salter) [1999157]
- KVM: arm64: Drop PTE_S2_MEMATTR_MASK (Mark Salter) [1999157]
- arm64/kernel: Fix range on invalidating dcache for boot page tables (Mark Salter) [1999157]
- arm64: set TEXT_OFFSET to 0x0 in preparation for removing it entirely (Mark Salter) [1999157]
- arm64/mm: Use phys_to_page() to access pgtable memory (Mark Salter) [1999157]
- arm64: smp: Make cpus_stuck_in_kernel static (Mark Salter) [1999157]
- arm64: entry: remove unneeded semicolon in el1_sync_handler() (Mark Salter) [1999157]
- arm64: cpufeature: Add "or" to mitigations for multiple errata (Mark Salter) [1999157]
- arm64: Sort vendor-specific errata (Mark Salter) [1999157]
- arm64: simplify ptrauth initialization (Mark Salter) [1999157]
- arm64: remove ptrauth_keys_install_kernel sync arg (Mark Salter) [1999157]
- arm64: insn: Provide a better name for aarch64_insn_is_nop() (Mark Salter) [1999157]
- arm64: kernel: Convert to modern annotations for assembly functions (Mark Salter) [1999157]
- arm64: entry: Refactor and modernise annotation for ret_to_user (Mark Salter) [1999157]
- arm64: BTI: Reset BTYPE when skipping emulated instructions (Mark Salter) [1999157]
- arm64: traps: Shuffle code to eliminate forward declarations (Mark Salter) [1999157]
- arm64: unify native/compat instruction skipping (Mark Salter) [1999157]
- arm64: BTI: Decode BYTPE bits when printing PSTATE (Mark Salter) [1999157]
- arm64: Basic Branch Target Identification support (Mark Salter) [1999157]
- arm64/kernel: Fix return value when cpu_online() fails in __cpu_up() (Mark Salter) [1999157]
- arm64: Add get_user() type annotation on the !access_ok() path (Mark Salter) [1999157]
- arm64: Fix PTRACE_SYSEMU semantics (Mark Salter) [1999157]
- arm64: fix the flush_icache_range arguments in machine_kexec (Mark Salter) [1999157]
- Documentation: arm64: fix amu.rst doc warnings (Mark Salter) [1999157]
- arm64: sync kernel APIAKey when installing (Mark Salter) [1999157]
- arm64: Delete the space separator in __emit_inst (Mark Salter) [1999157]
- arm64: remove CONFIG_DEBUG_ALIGN_RODATA feature (Mark Salter) [1999157]
- arm64: head: Convert install_el2_stub to SYM_INNER_LABEL (Mark Salter) [1999157]
- arm64: Introduce get_cpu_ops() helper function (Mark Salter) [1999157]
- arm64: Rename cpu_read_ops() to init_cpu_ops() (Mark Salter) [1999157]
- arm64: Declare ACPI parking protocol CPU operation if needed (Mark Salter) [1999157]
- arm64: move kimage_vaddr to .rodata (Mark Salter) [1999157]
- arm64: sdei: Annotate SDEI entry points using new style annotations (Mark Salter) [1999157]
- arm64: kernel: Convert to modern annotations for assembly data (Mark Salter) [1999157]
- arm64: head: Annotate stext and preserve_boot_args as code (Mark Salter) [1999157]
- arm64: head.S: Convert to modern annotations for assembly functions (Mark Salter) [1999157]
- arm64: entry: Additional annotation conversions for entry.S (Mark Salter) [1999157]
- arm64: entry: Annotate ret_from_fork as code (Mark Salter) [1999157]
- arm64: entry: Annotate vector table and handlers as code (Mark Salter) [1999157]
- kconfig: Add support for 'as-option' (Mark Salter) [1999157]
- arm64: suspend: restore the kernel ptrauth keys (Mark Salter) [1999157]
- arm64: __show_regs: strip PAC from lr in printk (Mark Salter) [1999157]
- arm64: unwind: strip PAC from kernel addresses (Mark Salter) [1999157]
- arm64/crash_core: Export KERNELPACMASK in vmcoreinfo (Mark Salter) [1999157]
- arm64: mask PAC bits of __builtin_return_address (Mark Salter) [1999157]
- compiler.h: Allow arch-specific asm/compiler.h (Mark Salter) [1999157]
- arm64: initialize ptrauth keys for kernel booting task (Mark Salter) [1999157]
- arm64: initialize and switch ptrauth kernel keys (Mark Salter) [1999157]
- arm64: enable ptrauth earlier (Mark Salter) [1999157]
- arm64: cpufeature: handle conflicts based on capability (Mark Salter) [1999157]
- arm64: cpufeature: Move cpu capability helpers inside C file (Mark Salter) [1999157]
- arm64: ptrauth: Add bootup/runtime flags for __cpu_setup (Mark Salter) [1999157]
- arm64: install user ptrauth keys at kernel exit time (Mark Salter) [1999157]
- arm64: rename ptrauth key structures to be user-specific (Mark Salter) [1999157]
- arm64: cpufeature: add pointer auth meta-capabilities (Mark Salter) [1999157]
- arm64: cpufeature: Fix meta-capability cpufeature check (Mark Salter) [1999157]
- arm64: define __alloc_zeroed_user_highpage (Mark Salter) [1999157]
- arm64/kernel: Simplify __cpu_up() by bailing out early (Mark Salter) [1999157]
- arm64: smp: Mark expected switch fall-through (Mark Salter) [1999157]
- arm64: remove redundant blank for '=' operator (Mark Salter) [1999157]
- arm64: kexec_file: Fixed code style. (Mark Salter) [1999157]
- arm64: add blank after 'if' (Mark Salter) [1999157]
- arm64: fix spelling mistake "ca not" -> "cannot" (Mark Salter) [1999157]
- arm64: entry: unmask IRQ in el0_sp() (Mark Salter) [1999157]
- arm64: efi: add efi-entry.o to targets instead of extra-$(CONFIG_EFI) (Mark Salter) [1999157]
- arm64: csum: Optimise IPv6 header checksum (Mark Salter) [1999157]
- arch/arm64: fix typo in a comment (Mark Salter) [1999157]
- arm64: remove gratuitious/stray .ltorg stanzas (Mark Salter) [1999157]
- arm64: Update comment for ASID() macro (Mark Salter) [1999157]
- arm64: mm: convert cpu_do_switch_mm() to C (Mark Salter) [1999157]
- Documentation: arm64: document support for the AMU extension (Mark Salter) [1999157]
- arm64: trap to EL1 accesses to AMU counters from EL0 (Mark Salter) [1999157]
- arm64: add support for the AMU extension v1 (Mark Salter) [1999157]
- arm64: smp: fix crash_smp_send_stop() behaviour (Mark Salter) [1999157]
- arm64: smp: fix smp_send_stop() behaviour (Mark Salter) [1999157]
- arm64: context: Fix ASID limit in boot messages (Mark Salter) [1999157]
- docs: arm64: fix trivial spelling enought to enough in memory.rst (Mark Salter) [1999157]
- arm64: time: Replace <linux/clk-provider.h> by <linux/of_clk.h> (Mark Salter) [1999157]
- arm64: ssbs: Fix context-switch when SSBS is present on all CPUs (Mark Salter) [1999157]
- arm64: use shared sysctl constants (Mark Salter) [1999157]
- arm64: Drop do_el0_ia_bp_hardening() & do_sp_pc_abort() declarations (Mark Salter) [1999157]
- arm64: entry: Avoid empty alternatives entries (Mark Salter) [1999157]
- arm64: Kconfig: select HAVE_FUTEX_CMPXCHG (Mark Salter) [1999157]
- arm64: Use macros instead of hard-coded constants for MAIR_EL1 (Mark Salter) [1999157]
- arm64: Add KRYO{3,4}XX CPU cores to spectre-v2 safe list (Mark Salter) [1999157]
- arm64: context: Free up kernel ASIDs if KPTI is not in use (Mark Salter) [1999157]
- arm64: Remove __exception_text_start and __exception_text_end from asm/section.h (Mark Salter) [1999157]
- arm64: armv8_deprecated: update the comments of armv8_deprecated_init() (Mark Salter) [1999157]
- arm64: kpti: Add Broadcom Brahma-B53 core to the KPTI whitelist (Mark Salter) [1999157]
- arm64: csum: Fix pathological zero-length calls (Mark Salter) [1999157]
- arm64: Implement optimised checksum routine (Mark Salter) [1999157]
- arm64: entry: cleanup sp_el0 manipulation (Mark Salter) [1999157]
- arm64: entry: cleanup el0 svc handler naming (Mark Salter) [1999157]
- arm64: entry: mark all entry code as notrace (Mark Salter) [1999157]
- arm64: assembler: remove smp_dmb macro (Mark Salter) [1999157]
- arm64: assembler: remove inherit_daif macro (Mark Salter) [1999157]
- arm64: signal: nofpsimd: Handle fp/simd context for signal frames (Mark Salter) [1999157]
- arm64: ptrace: nofpsimd: Fail FP/SIMD regset operations (Mark Salter) [1999157]
- arm64: cpufeature: Set the FP/SIMD compat HWCAP bits properly (Mark Salter) [1999157]
- arm64: cpufeature: Fix the type of no FP/SIMD capability (Mark Salter) [1999157]
- arm64: fpsimd: Make sure SVE setup is complete before SIMD is used (Mark Salter) [1999157]
- arm64: kernel: Correct annotation of end of el0_sync (Mark Salter) [1999157]
- arm64: asm: Remove ENDPIPROC() (Mark Salter) [1999157]
- arm64: mm: Use modern annotations for assembly functions (Mark Salter) [1999157]
- arm64: lib: Use modern annotations for assembly functions (Mark Salter) [1999157]
- arm64: asm: Add new-style position independent function annotations (Mark Salter) [1999157]
- arm64: kernel: avoid x18 in __cpu_soft_restart (Mark Salter) [1999157]
- arm64/lib: copy_page: avoid x18 register in assembler code (Mark Salter) [1999157]
- arm64: mm: avoid x18 in idmap_kpti_install_ng_mappings (Mark Salter) [1999157]
- arm64: cpu_errata: Add Hisilicon TSV110 to spectre-v2 safe list (Mark Salter) [1999157]
- arm64: entry: refine comment of stack overflow check (Mark Salter) [1999157]
- arm64: kpti: Add NVIDIA's Carmel core to the KPTI whitelist (Mark Salter) [1999157]
- arm64: mm: simplify the page end calculation in __create_pgd_mapping() (Mark Salter) [1999157]
- arm64: print additional fault message when executing non-exec memory (Mark Salter) [1999157]
- arm64: pgtable: Correct typo in comment (Mark Salter) [1999157]
- arm64: cpufeature: Fix typos in comment (Mark Salter) [1999157]
- arm64: entry-common: don't touch daif before bp-hardening (Mark Salter) [1999157]
- arm64: Remove asmlinkage from updated functions (Mark Salter) [1999157]
- arm64: entry: convert el0_sync to C (Mark Salter) [1999157]
- arm64: entry: convert el1_sync to C (Mark Salter) [1999157]
- arm64: Add prototypes for functions called by entry.S (Mark Salter) [1999157]
- arm64: remove __exception annotations (Mark Salter) [1999157]
- arm64: kprobes: Move exception_text check in blacklist (Mark Salter) [1999157]
- arm64: kprobes: Remove unneeded RODATA check (Mark Salter) [1999157]
- arm64: kprobes: Move extable address check into arch_prepare_kprobe() (Mark Salter) [1999157]
- arm64: cpufeature: introduce helper cpu_has_hw_af() (Mark Salter) [1999157]
- arm64: Document ICC_CTLR_EL3.PMHE setting requirements (Mark Salter) [1999157]
- firmware: arm_sdei: use common SMCCC_CONDUIT_* (Mark Salter) [1999157]
- arm64: uaccess: Remove uaccess_*_not_uao asm macros (Mark Salter) [1999157]
- arm64: uaccess: Ensure PAN is re-enabled after unhandled uaccess fault (Mark Salter) [1999157]
- arm64: Do not mask out PTE_RDONLY in pte_same() (Mark Salter) [1999157]
- arm64: apply ARM64_ERRATUM_843419 workaround for Brahma-B53 core (Mark Salter) [1999157]
- arm64: Brahma-B53 is SSB and spectre v2 safe (Mark Salter) [1999157]
- arm64: apply ARM64_ERRATUM_845719 workaround for Brahma-B53 core (Mark Salter) [1999157]
- arm64: cpufeature: Enable Qualcomm Falkor errata 1009 for Kryo (Mark Salter) [1999157]
- arm64: cpufeature: Enable Qualcomm Falkor/Kryo errata 1003 (Mark Salter) [1999157]
- arm64: Ensure VM_WRITE|VM_SHARED ptes are clean by default (Mark Salter) [1999157]
- arm64: mm: fix inverted PAR_EL1.F check (Mark Salter) [1999157]
- arm64: hibernate: check pgd table allocation (Mark Salter) [1999157]
- arm64: armv8_deprecated: Checking return value for memory allocation (Mark Salter) [1999157]
- arm64: mm: fix spurious fault detection (Mark Salter) [1999157]
- arm64: ftrace: Ensure synchronisation in PLT setup for Neoverse-N1 #1542419 (Mark Salter) [1999157]
- arm64: mm: avoid virt_to_phys(init_mm.pgd) (Mark Salter) [1999157]
- docs: arm64: Fix indentation and doc formatting (Mark Salter) [1999157]
- arm64: errata: Update stale comment (Mark Salter) [1999157]
- arm64: consider stack randomization for mmap base only when necessary (Mark Salter) [1999157]
- arm64: make use of is_compat_task instead of hardcoding this test (Mark Salter) [1999157]
- arm64: kpti: ensure patched kernel text is fetched from PoU (Mark Salter) [1999157]
- arm64: Clarify when cpu_enable() is called (Mark Salter) [1999157]
- arm64: constify sys64_hook instances (Mark Salter) [1999157]
- arm64: constify aarch64_insn_encoding_class[] (Mark Salter) [1999157]
- arm64: constify icache_policy_str[] (Mark Salter) [1999157]
- arm64: prefer __section from compiler_attributes.h (Mark Salter) [1999157]
- arm64/ptrace: Fix typoes in sve_set() comment (Mark Salter) [1999157]
- arm64: mm: print hexadecimal EC value in mem_abort_decode() (Mark Salter) [1999157]
- ahci: thunderx2: Fix workaround to use new inline function (Mark Salter) [1999157]
- arm64/prefetch: fix a -Wtype-limits warning (Mark Salter) [1999157]
- arm64: Move TIF_* documentation to individual definitions (Mark Salter) [1999157]
- arm64: mm: free the initrd reserved memblock in a aligned manner (Mark Salter) [1999157]
- arm64: io: Relax implicit barriers in default I/O accessors (Mark Salter) [1999157]
- arm64: Remove unused cpucap_multi_entry_cap_cpu_enable() (Mark Salter) [1999157]
- arm64: sysreg: Remove unused and rotting SCTLR_ELx field definitions (Mark Salter) [1999157]
- arm64: esr: Add ESR exception class encoding for trapped ERET (Mark Salter) [1999157]
- arm64/kexec: Use consistent convention of initializing 'kxec_buf.mem' with KEXEC_BUF_MEM_UNKNOWN (Mark Salter) [1999157]
- arm64: remove pointless __KERNEL__ guards (Mark Salter) [1999157]
- arm64: Remove unused assembly macro (Mark Salter) [1999157]
- arm64: memory: Cosmetic cleanups (Mark Salter) [1999157]
- arm64: memory: Add comments to end of non-trivial #ifdef blocks (Mark Salter) [1999157]
- arm64: memory: Simplify virt_to_page() implementation (Mark Salter) [1999157]
- arm64: memory: Rewrite default page_to_virt()/virt_to_page() (Mark Salter) [1999157]
- arm64: mm: Ignore spurious translation faults taken from the kernel (Mark Salter) [1999157]
- arm64: mm: Add ISB instruction to set_pgd() (Mark Salter) [1999157]
- arm64: tlb: Ensure we execute an ISB following walk cache invalidation (Mark Salter) [1999157]
- Revert "arm64: Remove unnecessary ISBs from set_{pte,pmd,pud}" (Mark Salter) [1999157]
- arm64: pgtable: Implement p[mu]d_valid() and check in set_p[mu]d() (Mark Salter) [1999157]
- arm64: Change the tagged_addr sysctl control semantics to only prevent the opt-in (Mark Salter) [1999157]
- redhat/configs: Add CONFIG_ARM64_TAGGED_ADDR_ABI (Mark Salter) [1999157]
- arm64: Introduce prctl() options to control the tagged user addresses ABI (Mark Salter) [1999157]
- arm64: smp: Treat unknown boot failures as being 'stuck in kernel' (Mark Salter) [1999157]
- arm64: smp: Don't enter kernel with NULL stack pointer or task struct (Mark Salter) [1999157]
- arm64: map FDT as RW for early_init_dt_scan() (Mark Salter) [1999157]
- arm64: ftrace: Ensure module ftrace trampoline is coherent with I-side (Mark Salter) [1999157]
- arch: replace _BITUL() in kernel-space headers with BIT() (Mark Salter) [1999157]
- arm64: move jump_label_init() before parse_early_param() (Mark Salter) [1999157]
- arm64: don't use asm-generic/ptrace.h (Mark Salter) [1999157]
- arm64: rename dump_instr as dump_kernel_instr (Mark Salter) [1999157]
- arm64/mm: Drop [PTE|PMD]_TYPE_FAULT (Mark Salter) [1999157]
- arm64: module: create module allocations without exec permissions (Mark Salter) [1999157]
- acpi/arm64: ignore 5.1 FADTs that are reported as 5.0 (Mark Salter) [1999157]
- arm64: remove redundant 'default n' from Kconfig (Mark Salter) [1999157]
- arm64: mm: avoid redundant READ_ONCE(*ptep) (Mark Salter) [1999157]
- arm64/mm: Document write abort detection from ESR (Mark Salter) [1999157]
- arm64: Fix comment after #endif (Mark Salter) [1999157]
- arm64: ptrace: add support for syscall emulation (Mark Salter) [1999157]
- arm64: add PTRACE_SYSEMU{,SINGLESTEP} definations to uapi headers (Mark Salter) [1999157]
- arm64/mm: Identify user instruction aborts (Mark Salter) [1999157]
- arm64/mm: Change BUG_ON() to VM_BUG_ON() in [pmd|pud]_set_huge() (Mark Salter) [1999157]
- arm64: kernel: use aff3 instead of aff2 in comment (Mark Salter) [1999157]
- arm64/mm: Simplify protection flag creation for kernel huge mappings (Mark Salter) [1999157]
- arm64/mm: Move PTE_VALID from SW defined to HW page table entry definitions (Mark Salter) [1999157]
- arm64/sve: <uapi/asm/ptrace.h> should not depend on <uapi/linux/prctl.h> (Mark Salter) [1999157]
- arm64: ssbd: explicitly depend on <linux/prctl.h> (Mark Salter) [1999157]
- ARM64: trivial: s/TIF_SECOMP/TIF_SECCOMP/ comment typo fix (Mark Salter) [1999157]
- arm64: smp: Moved cpu_logical_map[] to smp.h (Mark Salter) [1999157]
- arm64: use the correct function type for __arm64_sys_ni_syscall (Mark Salter) [1999157]
- arm64: use the correct function type in SYSCALL_DEFINE0 (Mark Salter) [1999157]
- arm64: fix syscall_fn_t type (Mark Salter) [1999157]
- signal/arm64: Use force_sig not force_sig_fault for SIGKILL (Mark Salter) [1999157]
- arm64: Fix the arm64_personality() syscall wrapper redirection (Mark Salter) [1999157]
- arm64: Remove useless message during oops (Mark Salter) [1999157]
- arm64: don't trash config with compat symbol if COMPAT is disabled (Mark Salter) [1999157]
- arm64: assembler: Update comment above cond_yield_neon() macro (Mark Salter) [1999157]
- arm64: Fix size of __early_cpu_boot_status (Mark Salter) [1999157]
- arm64: mm: Remove pte_unmap_nested() (Mark Salter) [1999157]
- arm64: Fix compiler warning from pte_unmap() with -Wunused-but-set-variable (Mark Salter) [1999157]
- arm64: compat: Reduce address limit for 64K pages (Mark Salter) [1999157]
- arm64: mmap: Ensure file offset is treated as unsigned (Mark Salter) [1999157]
- arm64: instrument smp_{load_acquire,store_release} (Mark Salter) [1999157]
- arm64: mm: check virtual addr in virt_to_page() if CONFIG_DEBUG_VIRTUAL=y (Mark Salter) [1999157]
- arm64: ptrace: Add function argument access API (Mark Salter) [1999157]
- arm64: compat: Reduce address limit (Mark Salter) [1999157]
- arm64: Save and restore OSDLR_EL1 across suspend/resume (Mark Salter) [1999157]
- arm64: Clear OSDLR_EL1 on CPU boot (Mark Salter) [1999157]
- arm64: debug: Separate debug hooks based on target exception level (Mark Salter) [1999157]
- arm64: debug: Remove meaningless comment (Mark Salter) [1999157]
- arm64: debug: Rename addr parameter for non-watchpoint exception hooks (Mark Salter) [1999157]
- arm64: Use defines instead of magic numbers (Mark Salter) [1999157]
- arm64: cpu_ops: fix a leaked reference by adding missing of_node_put (Mark Salter) [1999157]
- arm64: mm: Make show_pte() a static function (Mark Salter) [1999157]
- arm64: setup min_low_pfn (Mark Salter) [1999157]
- arm64: mm: fix incorrect assignment of 'max_mapnr' (Mark Salter) [1999157]
- arm64: perf_event: Remove wrongfully used inline (Mark Salter) [1999157]
- arm64: backtrace: Don't bother trying to unwind the userspace stack (Mark Salter) [1999157]
- arm64: replace memblock_alloc_low with memblock_alloc (Mark Salter) [1999157]
- arm64: kdump: no need to mark crashkernel pages manually PG_reserved (Mark Salter) [1999157]
- arm64: kexec: no need to ClearPageReserved() (Mark Salter) [1999157]
- arm64: mmu: drop paging_init comments (Mark Salter) [1999157]
- arm64: debug: Ensure debug handlers check triggering exception level (Mark Salter) [1999157]
- arm64: io: Hook up __io_par() for inX() ordering (Mark Salter) [1999157]
- arm64: Rename get_thread_info() (Mark Salter) [1999157]
- arm64: Remove documentation about TIF_USEDFPU (Mark Salter) [1999157]
- arm64: uaccess: Cleanup get/put_user() (Mark Salter) [1999157]
- arm64: Remove asm/memblock.h (Mark Salter) [1999157]
- arm64: default NR_CPUS to 256 (Mark Salter) [1999157]
- arm64: perf: remove misleading comment (Mark Salter) [1999157]
- arm64: Relax GIC version check during early boot (Mark Salter) [1999157]
- arm64, mm, efi: Account for GICv3 LPI tables in static memblock reserve table (Mark Salter) [1999157]
- arm64: hibernate: Clean the __hyp_text to PoC after resume (Mark Salter) [1999157]
- arm64: hyp-stub: Forbid kprobing of the hyp-stub (Mark Salter) [1999157]
- arm64: kprobe: Always blacklist the KVM world-switch code (Mark Salter) [1999157]
- kasan, arm64: remove redundant ARCH_SLAB_MINALIGN define (Mark Salter) [1999157]
- arm64: asm-prototypes: Fix fat-fingered typo in comment (Mark Salter) [1999157]
- arm64: compat: Hook up io_pgetevents() for 32-bit tasks (Mark Salter) [1999157]
- arm64: compat: Don't pull syscall number from regs in arm_compat_syscall (Mark Salter) [1999157]
- arm64: compat: Avoid sending SIGILL for unallocated syscall numbers (Mark Salter) [1999157]
- arm64: kaslr: Reserve size of ARM64_MEMSTART_ALIGN in linear region (Mark Salter) [1999157]
- arm64: smp: Fix compilation error (Mark Salter) [1999157]
- arm64: select ACPI PCI code only when both features are enabled (Mark Salter) [1999157]
- arm64: kaslr: print PHYS_OFFSET in dump_kernel_offset() (Mark Salter) [1999157]
- arm64: sysreg: Use _BITUL() when defining register bits (Mark Salter) [1999157]
- arm64: perf: Treat EXCLUDE_EL* bit definitions as unsigned (Mark Salter) [1999157]
- arm64: percpu: Fix LSE implementation of value-returning pcpu atomics (Mark Salter) [1999157]
- arm64: smp: Handle errors reported by the firmware (Mark Salter) [1999157]
- arm64: smp: Rework early feature mismatched detection (Mark Salter) [1999157]
- arm64: percpu: Rewrite per-cpu ops to allow use of LSE atomics (Mark Salter) [1999157]
- arm64: crypto: add NEON accelerated XOR implementation (Mark Salter) [1999157]
- arm64/neon: add workaround for ambiguous C99 stdint.h types (Mark Salter) [1999157]
- arm64: ftrace: always pass instrumented pc in x0 (Mark Salter) [1999157]
- arm64: ftrace: use GLOBAL() (Mark Salter) [1999157]
- arm64: io: Ensure value passed to __iormb() is held in a 64-bit register (Mark Salter) [1999157]
- arm64: acpi: Prepare for longer MADTs (Mark Salter) [1999157]
- arm64: io: Ensure calls to delay routines are ordered against prior readX() (Mark Salter) [1999157]
- arm64: perf: Fix typos in comment (Mark Salter) [1999157]
- arm64: function_graph: Simplify with function_graph_enter() (Mark Salter) [1999157]
- arm64: sysreg: fix sparse warnings (Mark Salter) [1999157]
- arm64: mm: define NET_IP_ALIGN to 0 (Mark Salter) [1999157]
- arm64: kprobe: make page to RO mode when allocate it (Mark Salter) [1999157]
- arm64: kdump: fix small typo (Mark Salter) [1999157]
- arm64: mm: Use #ifdef for the __PAGETABLE_P?D_FOLDED defines (Mark Salter) [1999157]
- arm64: Trap WFI executed in userspace (Mark Salter) [1999157]
- arm64/mm: Use ESR_ELx_FSC macro while decoding fault exception (Mark Salter) [1999157]
- arm64: compat: Add CNTFRQ trap handler (Mark Salter) [1999157]
- arm64: compat: Add CNTVCT trap handler (Mark Salter) [1999157]
- arm64: compat: Add cp15_32 and cp15_64 handler arrays (Mark Salter) [1999157]
- arm64: compat: Add condition code checks and IT advance (Mark Salter) [1999157]
- arm64: Add decoding macros for CP15_32 and CP15_64 traps (Mark Salter) [1999157]
- arm64: Remove unused VGA console support (Mark Salter) [1999157]
- arm64: Kconfig: Remove ARCH_HAS_HOLES_MEMORYMODEL (Mark Salter) [1999157]
- arm64/cpufeatures: Emulate MRS instructions by parsing ESR_ELx.ISS (Mark Salter) [1999157]
- arm64/cpufeatures: Factorize emulate_mrs() (Mark Salter) [1999157]
- arm64: fix for bad_mode() handler to always result in panic (Mark Salter) [1999157]
- arm64: force_signal_inject: WARN if called from kernel context (Mark Salter) [1999157]
- arm64: tlb: Adjust stride and type of TLBI according to mmu_gather (Mark Salter) [1999157]
- arm64: percpu: Initialize ret in the default case (Mark Salter) [1999157]
- arm64: mm: always enable CONFIG_HOLES_IN_ZONE (Mark Salter) [1999157]
- arm64: Avoid calling stop_machine() when patching jump labels (Mark Salter) [1999157]
- arm64: Drop asmlinkage qualifier from syscall_trace_{enter,exit} (Mark Salter) [1999157]
- arm64: zero GPRs upon entry from EL0 (Mark Salter) [1999157]
- arm64: don't reload GPRs after apply_ssbd (Mark Salter) [1999157]
- arm64: consistently use unsigned long for thread flags (Mark Salter) [1999157]
- arm64: insn: Don't fallback on nosync path for general insn patching (Mark Salter) [1999157]
- arm64: remove unused COMPAT_PSR definitions (Mark Salter) [1999157]
- kvm/arm: use PSR_AA32 definitions (Mark Salter) [1999157]
- arm64: use PSR_AA32 definitions (Mark Salter) [1999157]
- arm64: compat: map SPSR_ELx<->PSR for signals (Mark Salter) [1999157]

* Tue Apr 26 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-386.el8]
- RDMA/qedr: Fix reporting max_{send/recv}_wr attrs (Kamal Heib) [2051524]
- thermal/drivers/int340x: Fix RFIM mailbox write commands (Prarit Bhargava) [2040065]
- thermal: int340x: Limit Kconfig to 64-bit (Prarit Bhargava) [2040065]
- thermal: int340x: fix build on 32-bit targets (Prarit Bhargava) [2040065]
- thermal/drivers/int340x: processor_thermal: Suppot 64 bit RFIM responses (Prarit Bhargava) [2040065]
- PCI/MSI: Clear PCI_MSIX_FLAGS_MASKALL on error (Myron Stowe) [1911591]
- PCI/MSI: Skip masking MSI-X on Xen PV (Myron Stowe) [1911591]
- PCI/MSI: Mask all unused MSI-X entries (Myron Stowe) [1911591]
- PCI/MSI: Enable and mask MSI-X early (Myron Stowe) [1911591]
- genirq: Use rcu in kstat_irqs_usr() (Waiman Long) [2068445]
- scsi: target: Allow changing dbroot if there are no registered devices (Maurizio Lombardi) [2073435]
- powerpc/pseries: Fix use after free in remove_phb_dynamic() (Steve Best) [2073707]
- sctp: use the correct skb for security_sctp_assoc_request (Xin Long) [2070915]
- s390/mm: check 2KB-fragment page on release (Rafael Aquini) [2026578]
- s390/mm: better annotate 2KB pagetable fragments handling (Rafael Aquini) [2026578]
- s390/mm: fix 2KB pgtable release race (Rafael Aquini) [2026578]
- s390/mm: fix phys vs virt confusion in pgtable allocation routines (Rafael Aquini) [2026578]
- net: openvswitch: fix leak of nested actions (Eelco Chaudron) [2073538]
- bpf: Let bpf_warn_invalid_xdp_action() report more info (Petr Oros) [2069671]
- bpf: Do not WARN in bpf_warn_invalid_xdp_action() (Petr Oros) [2069671]

* Mon Apr 25 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-385.el8]
- scsi: qedi: Fix failed disconnect handling (Chris Leech) [2071519]
- scsi: iscsi: Fix unbound endpoint error handling (Chris Leech) [2071519]
- scsi: iscsi: Fix conn cleanup and stop race during iscsid restart (Chris Leech) [2071519]
- scsi: iscsi: Fix endpoint reuse regression (Chris Leech) [2071519]
- scsi: iscsi: Release endpoint ID when its freed (Chris Leech) [2071519]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2071519]
- Revert "scsi: iscsi: Fix offload conn cleanup when iscsid restarts" (Chris Leech) [2071519]
- scsi: iscsi: Speed up session unblocking and removal (Chris Leech) [2071519]
- scsi: iscsi: Fix recovery and unblocking race (Chris Leech) [2071519]
- scsi: iscsi: Unblock session then wake up error handler (Chris Leech) [2071519]
- bnxt_en: make hw-tc-offload default to off (Ken Cox) [2005101]
- bnxt_en: reject indirect blk offload when hw-tc-offload is off (Ken Cox) [2005101]

* Wed Apr 20 2022 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-384.el8]
- bpf, test_offload.py: Skip base maps without names (Yauheni Kaliuta) [2025787]
- bnx2x: truncate value to original sizing (Manish Chopra) [2040271]
- bnx2x: use correct format characters (Manish Chopra) [2040271]
- bnx2x: fix built-in kernel driver load failure (Manish Chopra) [2040271]
- bnx2x: fix driver load from initrd (Manish Chopra) [2040271]
- bnx2x: Replace one-element array with flexible-array member (Manish Chopra) [2040271]
- bnx2x: Remove useless DMA-32 fallback configuration (Manish Chopra) [2040271]
- bnx2x: Invalidate fastpath HSI version for VFs (Manish Chopra) [2040271]
- bnx2x: Utilize firmware 7.13.21.0 (Manish Chopra) [2040271]
- bnx2x: constify static inline stub for dev_addr (Manish Chopra) [2040271]
- net: bnx2x: fix variable dereferenced before check (Manish Chopra) [2040271]
- ethernet: bnx2x: use eth_hw_addr_set() (Manish Chopra) [2040271]
- bnx2x: Fix enabling network interfaces without VFs (Manish Chopra) [2040271]
- bnx2x: fix an error code in bnx2x_nic_load() (Manish Chopra) [2040271]
- bnx2x: remove unused variable 'cur_data_offset' (Manish Chopra) [2040271]
- bnx2x: Remove the repeated declaration (Manish Chopra) [2040271]
- bnx2x: Fix missing error code in bnx2x_iov_init_one() (Manish Chopra) [2040271]
- net: broadcom: bnx2x: Fix wrong function name in comments (Manish Chopra) [2040271]
- bnx2x: Remove redundant assignment to err (Manish Chopra) [2040271]
- bnx2x: Use fallthrough pseudo-keyword (Manish Chopra) [2040271]
- bnx2x: use true,false for bool variables (Manish Chopra) [2040271]
- bnx2x: Fix some kernel-doc warnings (Manish Chopra) [2040271]
- bnx2x: convert to new udp_tunnel_nic infra (Manish Chopra) [2040271]
- bnx2x: Remove hw_reset_t function casts (Manish Chopra) [2040271]
- bnx2x: Remove format_fw_ver_t function casts (Manish Chopra) [2040271]
- bnx2x: Remove config_init_t function casts (Manish Chopra) [2040271]
- bnx2x: Remove read_status_t function casts (Manish Chopra) [2040271]
- bnx2x: Drop redundant callback function casts (Manish Chopra) [2040271]
- bnx2x: Use napi_alloc_frag() (Manish Chopra) [2040271]
- HID: intel-ish-hid: fix module device-id handling (Tony Camuso) [1921300]
- mod_devicetable: fix kdocs for ishtp_device_id (Tony Camuso) [1921300]
- HID: intel-ish-hid: add support for MODULE_DEVICE_TABLE() (Tony Camuso) [1921300]
- platform/x86: isthp_eclite: only load for matching devices (Tony Camuso) [1921300]
- platform/x86: Add Intel ishtp eclite driver (Tony Camuso) [1921300]
- platform/x86: Add config file for Intel ishtp eclite driver (Tony Camuso) [1921300]
- modpost: add guid_t type definition (Tony Camuso) [1921300]
- squashfs: provide backing_dev_info in order to disable read-ahead (Brian Foster) [2025351]
- mm: fix readahead_page_batch for retry entries (Brian Foster) [2025351]
- iomap: convert from readpages to readahead (Brian Foster) [2025351]
- fs: convert mpage_readpages to mpage_readahead (Brian Foster) [2025351]
- mm: use memalloc_nofs_save in readahead path (Brian Foster) [2025351]
- mm: document why we don't set PageReadahead (Brian Foster) [2025351]
- mm: add page_cache_readahead_unbounded (Brian Foster) [2025351]
- mm: move end_index check out of readahead loop (Brian Foster) [2025351]
- mm: add readahead address space operation (Brian Foster) [2025351]
- mm: put readahead pages in cache earlier (Brian Foster) [2025351]
- mm: remove 'page_offset' from readahead loop (Brian Foster) [2025351]
- mm: rename readahead loop variable to 'i' (Brian Foster) [2025351]
- mm: rename various 'offset' parameters to 'index' (Brian Foster) [2025351]
- mm: use readahead_control to pass arguments (Brian Foster) [2025351]
- mm: add new readahead_control API (Brian Foster) [2025351]
- mm: move readahead nr_pages check into read_pages (Brian Foster) [2025351]
- mm: ignore return value of ->readpages (Brian Foster) [2025351]
- mm: return void from various readahead functions (Brian Foster) [2025351]
- mm: move readahead prototypes from mm.h (Brian Foster) [2025351]
- mpage: mpage_readpages() should submit IO as read-ahead (Brian Foster) [2025351]
- mpage: add argument structure for do_mpage_readpage() (Brian Foster) [2025351]
- redhat/configs: enable CONFIG_AMD_PTDMA for x86_64 (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: handle the cases based on DMA is complete (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: fix concurrency issue with multiple dma transfer (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: Fix the error handling path in pt_core_init() (Sudheesh Mavila) [2027231]
- MAINTAINERS: Fix AMD PTDMA DRIVER entry (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: remove PT_OFFSET to avoid redefnition (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: Add debugfs entries for PTDMA (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: register PTDMA controller as a DMA resource (Sudheesh Mavila) [2027231]
- dmaengine: ptdma: Initial driver for the AMD PTDMA (Sudheesh Mavila) [2027231]
- isert: support for unsolicited NOPIN with no response (Maurizio Lombardi) [2035915]
- iscsit: increment max_cmd_sn for isert on command release (Maurizio Lombardi) [2035915]
- sched/debug: Remove mpol_get/put and task_lock/unlock from sched_show_numa (Phil Auld) [2062841]
- sched/numa: initialize numa statistics when forking new task (Phil Auld) [2062841]
- cgroup: Fix suspicious rcu_dereference_check() usage warning (Phil Auld) [2062841]
- sched/cpuacct: Remove redundant RCU read lock (Phil Auld) [2062841]
- sched/cpuacct: Optimize away RCU read lock (Phil Auld) [2062841]
- sched/cpuacct: Fix charge percpu cpuusage (Phil Auld) [2062841]
- sched: replace cpumask_weight with cpumask_empty where appropriate (Phil Auld) [2062841]
- sched/rt: Plug rt_mutex_setprio() vs push_rt_task() race (Phil Auld) [2062841]
- psi: fix possible trigger missing in the window (Phil Auld) [2062841]
- sched: Avoid double preemption in __cond_resched_*lock*() (Phil Auld) [2062841]
- sched/fair: Fix all kernel-doc warnings (Phil Auld) [2062841]
- sched/rt: Try to restart rt period timer when rt runtime exceeded (Phil Auld) [2062841]
- sched/fair: Fix detection of per-CPU kthreads waking a task (Phil Auld) [2062841]
- locking: Remove rt_rwlock_is_contended(). (Phil Auld) [2062841]
- sched: Trigger warning if ->migration_disabled counter underflows. (Phil Auld) [2062841]
- sched/cpuacct: Make user/system times in cpuacct.stat more precise (Phil Auld) [2062841]
- sched/cpuacct: Fix user/system in shown cpuacct.usage* (Phil Auld) [2062841]
- cpuacct: Convert BUG_ON() to WARN_ON_ONCE() (Phil Auld) [2062841]
- cputime, cpuacct: Include guest time in user time in cpuacct.stat (Phil Auld) [2062841]
- sched/fair: Document the slow path and fast path in select_task_rq_fair (Phil Auld) [2062841]
- drm/i915/ehl: Remove require_force_probe protection (Michel Dänzer) [2048674]
- net/sched: fix initialization order when updating chain 0 head (Marcelo Ricardo Leitner) [2044711]
- smp: Process pending softirqs in flush_smp_call_function_from_idle() (Waiman Long) [2066087]
- irq_work: Optimize irq_work_single() (Waiman Long) [2066087]
- irq_work: Cleanup (Waiman Long) [2066087]
- smp, irq_work: Continue smp_call_function*() and irq_work*() integration (Waiman Long) [2066087]
- irq_work: Define irq_work_single() on !CONFIG_IRQ_WORK too (Waiman Long) [2066087]
- sched/headers: Split out open-coded prototypes into kernel/sched/smp.h (Waiman Long) [2066087]
- sched: Replace rq::wake_list (Waiman Long) [2066087]
- sched: Add rq::ttwu_pending (Waiman Long) [2066087]
- irq_work, smp: Allow irq_work on call_single_queue (Waiman Long) [2066087]
- smp: Optimize send_call_function_single_ipi() (Waiman Long) [2066087]
- smp: Move irq_work_run() out of flush_smp_call_function_queue() (Waiman Long) [2066087]
- smp: Optimize flush_smp_call_function_queue() (Waiman Long) [2066087]
- sched: Fix smp_call_function_single_async() usage for ILB (Waiman Long) [2066087]
- sched: Make scheduler_ipi inline (Waiman Long) [2066087]
- sched: Clean up scheduler_ipi() (Waiman Long) [2066087]
- sched/core: Remove rq.hrtick_csd_pending (Waiman Long) [2066087]
- sched/fair: Clean up comment in nohz_idle_balance() (Waiman Long) [2066087]
- context_tracking: Rename context_tracking_is_enabled() => context_tracking_enabled() (Waiman Long) [2066087]
- context_tracking: Remove context_tracking_active() (Waiman Long) [2066087]
- redhat: configs: Disable CONFIG_MPLS for s390x/zfcpdump (Guillaume Nault) [2051659]
- KVM: PPC: Book3S HV: Add infrastructure to support 2nd DAWR (Laurent Vivier) [2059318]
- KVM: PPC: Book3S HV: Rename current DAWR macros and variables (Laurent Vivier) [2059318]
- uapi/linux/stddef.h: Add include guards (Michel Dänzer) [2072125]
- stddef: Introduce struct_group() helper macro (Michel Dänzer) [2072125]
- component: Add common helper for compare/release functions (Michel Dänzer) [2072125]
- PCI/VGA: Move vgaarb to drivers/pci (Michel Dänzer) [2072125]
- vgaarb: don't pass a cookie to vga_client_register (Michel Dänzer) [2072125]
- vgaarb: remove the unused irq_set_state argument to vga_client_register (Michel Dänzer) [2072125]
- vgaarb: provide a vga_client_unregister wrapper (Michel Dänzer) [2072125]
- vgaarb: cleanup vgaarb.h (Michel Dänzer) [2072125]
- vgaarb: move the kerneldoc for vga_set_legacy_decoding to vgaarb.c (Michel Dänzer) [2072125]
- vgaarb: remove vga_conflicts (Michel Dänzer) [2072125]
- vgaarb: remove VGA_DEFAULT_DEVICE (Michel Dänzer) [2072125]
- lib/string_helpers: Consolidate string helpers implementation (Michel Dänzer) [2072125]
- include/linux/string_helpers.h: add linux/string.h for strlen() (Michel Dänzer) [2072125]
- kernel.h: split out container_of() and typeof_member() macros (Michel Dänzer) [2072125]
- mm/vmscan: add sync_shrinkers function v3 (Michel Dänzer) [2072125]
- lib: devres: Add managed arch_io_reserve_memtype_wc() (Michel Dänzer) [2072125]
- lib: devres: Add managed arch_phys_wc_add() (Michel Dänzer) [2072125]
- kernel/locking: Use a pointer in ww_mutex_trylock(). (Michel Dänzer) [2072125]
- locking/ww-mutex: Fix uninitialized use of ret in test_aa() (Michel Dänzer) [2072125]
- kernel/locking: Add context to ww_mutex_trylock() (Michel Dänzer) [2072125]
- locking/lockdep: Provide lockdep_assert{,_once}() helpers (Michel Dänzer) [2072125]
- mm: gup: pack has_pinned in MMF_HAS_PINNED (Chris von Recklinghausen) [2073217]
- mm: gup: allow FOLL_PIN to scale in SMP (Chris von Recklinghausen) [2073217]
- CI: Drop baseline runs (Veronika Kabatova)

* Thu Apr 14 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-383.el8]
- powerpc/xive: Export XIVE IPI information for online-only processors. (Steve Best) [2038448]
- netfilter: conntrack: fix reading nf_conntrack_buckets (Phil Sutter) [2053628]
- netfilter: nf_tables: initialize registers in nft_do_chain() (Florian Westphal) [2067966] {CVE-2022-1016}
- x86/sev-es: Use __put_user()/__get_user() for data accesses (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Handle string port IO to kernel memory properly (Vitaly Kuznetsov) [2063719]
- x86/sev: Return an error on a returned non-zero SW_EXITINFO1[31:0] (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Use __copy_from_user_inatomic() (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Check regs->sp is trusted before adjusting #VC IST stack (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Introduce ip_within_syscall_gap() helper (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Forward page-faults which happen during emulation (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Don't return NULL from sev_es_get_ghcb() (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Invalidate the GHCB after completing VMGEXIT (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Move sev_es_put_ghcb() in prep for follow on patch (Vitaly Kuznetsov) [2063719]
- x86/sev: Fix stack type check in vc_switch_off_ist() (Vitaly Kuznetsov) [2063719]
- x86/sev: Allow #VC exceptions on the VC2 stack (Vitaly Kuznetsov) [2063719]
- x86/sev-es: Enable #VC specific entry point for real (Vitaly Kuznetsov) [2063719]
- x86/cpu: Use pinning mask for CR4 bits needing to be 0 (Vitaly Kuznetsov) [2063719]
- x86/asm: Move native_write_cr0/4() out of line (Vitaly Kuznetsov) [2063719]
- x86/asm: Pin sensitive CR4 bits (Vitaly Kuznetsov) [2063719]
- x86/asm: Pin sensitive CR0 bits (Vitaly Kuznetsov) [2063719]
- powerpc/mce: Modify the real address error logging messages (Desnes A. Nunes do Rosario) [2068761]
- selftests/powerpc: Add test for real address error handling (Desnes A. Nunes do Rosario) [2068761]
- powerpc/pseries: Parse control memory access error (Desnes A. Nunes do Rosario) [2068761]
- powerpc/pseries/mce: Fix a typo in error type assignment (Desnes A. Nunes do Rosario) [2068761]
- netfilter: nf_tables: validate registers coming from userspace. (Florian Westphal) [2065357] {CVE-2022-1015}
- PCI: hv: Propagate coherence from VMbus device to PCI device (Vitaly Kuznetsov) [2068429]
- Drivers: hv: vmbus: Propagate VMbus coherence to each VMbus device (Vitaly Kuznetsov) [2068429]
- Revert "xfs: actually bump warning counts when we send warnings" (Carlos Maiolino) [2059262]
- perf/x86/intel: Add a quirk for the calculation of the number of counters on Alder Lake (Michael Petlan) [2039996]
- perf stat: Support --cputype option for hybrid events (Michael Petlan) [1971941]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2042217]
- tipc: fix kernel panic when enabling bearer (Xin Long) [2061233]
- media: v4l: ioctl: Fix memory leak in video_usercopy (Jarod Wilson) [1954604] {CVE-2021-30002}

* Mon Apr 11 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-382.el8]
- esp6: fix check on ipv6_skip_exthdr's return value (Sabrina Dubroca) [2054075]
- scsi: iscsi: Fix nop handling during conn recovery (Chris Leech) [2069969]
- scsi: iscsi: Merge suspend fields (Chris Leech) [2069969]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2069969]
- scsi: iscsi: Move iscsi_ep_disconnect (Chris Leech) [2069969]
- CI: Remove deprecated option (Veronika Kabatova)

* Fri Apr 08 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-381.el8]
- redhat: add new KUNIT tests to mod-internal.list (Nico Pache) [2065444]
- kasan: test: prevent cache merging in kmem_cache_double_destroy (Nico Pache) [2065444]
- kasan: test: fix compatibility with FORTIFY_SOURCE (Nico Pache) [2065444]
- kasan: test: add test case for double-kmem_cache_destroy() (Nico Pache) [2065444]
- kasan: add ability to detect double-kmem_cache_destroy() (Nico Pache) [2065444]
- kasan: test: add globals left-out-of-bounds test (Nico Pache) [2065444]
- kasan: test: silence intentional read overflow warnings (Nico Pache) [2065444]
- kasan: test: bypass __alloc_size checks (Nico Pache) [2065444]
- kasan: test: add memcpy test that avoids out-of-bounds write (Nico Pache) [2065444]
- kasan: test: clean up ksize_uaf (Nico Pache) [2065444]
- kasan: test: disable kmalloc_memmove_invalid_size for HW_TAGS (Nico Pache) [2065444]
- kasan: test: only do kmalloc_uaf_memset for generic mode (Nico Pache) [2065444]
- kasan: test: avoid corrupting memory via memset (Nico Pache) [2065444]
- kasan: test: avoid writing invalid memory (Nico Pache) [2065444]
- kasan: test: rework kmalloc_oob_right (Nico Pache) [2065444]
- Documentation: kunit: remove claims that kunit is a mocking framework (Nico Pache) [2065444]
- kunit: Reset suite count after running tests (Nico Pache) [2065444]
- kunit: drop assumption in kunit-log-test about current suite (Nico Pache) [2065444]
- string.h: Introduce memset_startat() for wiping trailing members and padding (Nico Pache) [2065444]
- string.h: Introduce memset_after() for wiping trailing members/padding (Nico Pache) [2065444]
- lib: Introduce CONFIG_MEMCPY_KUNIT_TEST (Nico Pache) [2065444]
- kunit: fix kernel-doc warnings due to mismatched arg names (Nico Pache) [2065444]
- kunit: fix reference count leak in kfree_at_end (Nico Pache) [2065444]
- kunit: Print test statistics on failure (Nico Pache) [2065444]
- fat: Add KUnit tests for checksums and timestamps (Nico Pache) [2065444]
- kunit: add unit test for filtering suites by names (Nico Pache) [2065444]
- kunit: test: Add example tests which are always skipped (Nico Pache) [2065444]
- kunit: Support skipped tests (Nico Pache) [2065444]
- redhat: remove TEST_LIST_SORT config definitions (Nico Pache) [2065444]
- lib/test: convert test_sort.c to use KUnit (Nico Pache) [2065444]
- lib/test: convert lib/test_list_sort.c to use KUnit (Nico Pache) [2065444]
- kunit: introduce kunit_kmalloc_array/kunit_kcalloc() helpers (Nico Pache) [2065444]
- kunit: Add gnu_printf specifiers (Nico Pache) [2065444]
- lib/cmdline_kunit: Remove a cast which are no-longer required (Nico Pache) [2065444]
- kernel/sysctl-test: Remove some casts which are no-longer required (Nico Pache) [2065444]
- device property: Remove some casts in property-entry-test (Nico Pache) [2065444]
- Documentation: kunit: Clean up some string casts in examples (Nico Pache) [2065444]
- kunit: Assign strings to 'const char*' in STREQ assertions (Nico Pache) [2065444]
- kunit: Do not typecheck binary assertions (Nico Pache) [2065444]
- Documentation: kunit: document support for QEMU in kunit_tool (Nico Pache) [2065444]
- kunit: Add 'kunit_shutdown' option (Nico Pache) [2065444]
- Documentation: kunit: Update kunit_tool page (Nico Pache) [2065444]
- Documentation: kunit: add tips for running KUnit (Nico Pache) [2065444]
- slub: remove resiliency_test() function (Nico Pache) [2065444]
- mm/slub, kunit: add a KUnit test for SLUB debugging functionality (Nico Pache) [2065444]
- kunit: make test->lock irq safe (Nico Pache) [2065444]
- docs: dev-tools: kunit: avoid using ReST :doc:`foo` markup (Nico Pache) [2065444]
- docs: dev-tools: kunit: don't use a table for docs name (Nico Pache) [2065444]
- kunit: make KUNIT_EXPECT_STREQ() quote values, don't print literals (Nico Pache) [2065444]
- kunit: Match parenthesis alignment to improve code readability (Nico Pache) [2065444]
- openvswitch: always update flow key after nat (Aaron Conole) [2066885]
- md: initialize percpu refcounters using PERCU_REF_ALLOW_REINIT (Nigel Croxon) [2032272]
- net: fix a memleak when uncloning an skb dst and its metadata (Hangbin Liu) [2068355]
- net: do not keep the dst cache when uncloning an skb dst and its metadata (Hangbin Liu) [2068355]
- net: phy: at803x: move page selection fix to config_init (Petr Oros) [2021822]
- net: phylink: rejig SFP interface selection in ksettings_set() (Petr Oros) [2021822]
- ptp: dp83640: don't define PAGE0 (Petr Oros) [2021822]
- net: phylink: Update SFP selected interface on advertising changes (Petr Oros) [2021822]
- net: phy: marvell10g: fix broken PHY interrupts for anyone after us in the driver probe list (Petr Oros) [2021822]
- net: phy: marvell: Add WAKE_PHY support to WOL event (Petr Oros) [2021822]
- net: phy: micrel: Fix link detection on ksz87xx switch" (Petr Oros) [2021822]
- net: phy: micrel: Fix detection of ksz87xx switch (Petr Oros) [2021822]
- net: phy: broadcom: re-add check for PHY_BRCM_DIS_TXCRXC_NOENRGY on the BCM54811 PHY (Petr Oros) [2021822]
- net: phy: at803x: simplify custom phy id matching (Petr Oros) [2021822]
- net: phy: intel-xway: Add RGMII internal delay configuration (Petr Oros) [2021822]
- net: phylink: cleanup ksettings_set (Petr Oros) [2021822]
- net: phylink: add phy change pause mode debug (Petr Oros) [2021822]
- net: phy: add API to read 802.3-c45 IDs (Petr Oros) [2021822]
- net: phy: Fix data type in DP83822 dp8382x_disable_wol() (Petr Oros) [2021822]
- net: phy: marvell10g: enable WoL for 88X3310 and 88E2110 (Petr Oros) [2021822]
- net: phy: marvell10g: fix differentiation of 88X3310 from 88X3340 (Petr Oros) [2021822]
- net: phy: replace if-else statements with switch (Petr Oros) [2021822]
- net: phy: remove unnecessary line continuation (Petr Oros) [2021822]
- net: phy: print the function name by __func__ instead of an fixed string (Petr Oros) [2021822]
- net: phy: fix formatting issues with braces (Petr Oros) [2021822]
- net: phy: fix space alignment issues (Petr Oros) [2021822]
- net: phy: delete repeated words of comments (Petr Oros) [2021822]
- net: phy: correct format of block comments (Petr Oros) [2021822]
- net: phy: change format of some declarations (Petr Oros) [2021822]
- net: phy: micrel: remove redundant assignment to pointer of_node (Petr Oros) [2021822]
- net: phy: dp83867: perform soft reset and retain established link (Petr Oros) [2021822]
- net: phy: do not print dump stack if device was removed (Petr Oros) [2021822]
- net: phy: probe for C45 PHYs that return PHY ID of zero in C22 space (Petr Oros) [2021822]
- net: phy: marvell: use phy_modify_changed() for marvell_set_polarity() (Petr Oros) [2021822]
- net: phy: Fix inconsistent indenting (Petr Oros) [2021822]
- net: mdiobus: get rid of a BUG_ON() (Petr Oros) [2021822]
- net: phy: marvell: enable downshift by default (Petr Oros) [2021822]
- net: phy: marvell: add downshift support for M88E1240 (Petr Oros) [2021822]
- net: phy: marvell: fix m88e1111_set_downshift (Petr Oros) [2021822]
- net: phy: marvell: fix m88e1011_set_downshift (Petr Oros) [2021822]
- net: phy: marvell: don't use empty switch default case (Petr Oros) [2021822]
- net: phy: intel-xway: enable integrated led functions (Petr Oros) [2021822]
- net: phy: at803x: fix probe error if copper page is selected (Petr Oros) [2021822]
- net: phy: marvell: add support for Amethyst internal PHY (Petr Oros) [2021822]
- net: dsa: mv88e6xxx: simulate Amethyst PHY model number (Petr Oros) [2021822]
- net: phy: marvell: use assignment by bitwise AND operator (Petr Oros) [2021822]
- net: phy: marvell: fix HWMON enable register for 6390 (Petr Oros) [2021822]
- net: phy: marvell: refactor HWMON OOP style (Petr Oros) [2021822]
- net: phy: at803x: select correct page on config init (Petr Oros) [2021822]
- net: phy: marvell: fix detection of PHY on Topaz switches (Petr Oros) [2021822]
- net: phy: marvell10g: change module description (Petr Oros) [2021822]
- net: phy: marvell10g: differentiate 88E2110 vs 88E2111 (Petr Oros) [2021822]
- net: phy: add constants for 2.5G and 5G speed in PCS speed register (Petr Oros) [2021822]
- net: phy: marvell10g: fix driver name for mv88e2110 (Petr Oros) [2021822]
- net: phy: marvell10g: add separate structure for 88X3340 (Petr Oros) [2021822]
- net: phy: marvell10g: support other MACTYPEs (Petr Oros) [2021822]
- net: phy: marvell10g: store temperature read method in chip strucutre (Petr Oros) [2021822]
- net: phy: marvell10g: check for correct supported interface mode (Petr Oros) [2021822]
- net: phy: marvell10g: support all rate matching modes (Petr Oros) [2021822]
- net: phy: marvell10g: add MACTYPE definitions for 88E21xx (Petr Oros) [2021822]
- net: phy: marvell10g: add all MACTYPE definitions for 88X33x0 (Petr Oros) [2021822]
- net: phy: marvell10g: indicate 88X33x0 only port control registers (Petr Oros) [2021822]
- net: phy: marvell10g: allow 5gbase-r and usxgmii (Petr Oros) [2021822]
- net: phy: marvell10g: fix typo (Petr Oros) [2021822]
- net: phy: marvell10g: rename register (Petr Oros) [2021822]
- net: fec: use mac-managed PHY PM (Petr Oros) [2021822]
- net: phy: broadcom: Add statistics for all Gigabit PHYs (Petr Oros) [2021822]
- net: phy: broadcom: Only advertise EEE for supported modes (Petr Oros) [2021822]
- net: phy: remove repeated word (Petr Oros) [2021822]
- net: phy: Correct function name mdiobus_register_board_info() in comment (Petr Oros) [2021822]
- net: phy: lan87xx: fix access to wrong register of LAN87xx (Petr Oros) [2021822]
- net: phy: at803x: remove at803x_aneg_done() (Petr Oros) [2021822]
- net: phy: broadcom: Fix RGMII delays for BCM50160 and BCM50610M (Petr Oros) [2021822]
- docs: networking: phy: Improve placement of parenthesis (Petr Oros) [2021822]
- net: phy: broadcom: Add power down exit reset state delay (Petr Oros) [2021822]
- net: phy: make mdio_bus_phy_suspend/resume as __maybe_unused (Petr Oros) [2021822]
- net: mdio: Remove of_phy_attach() (Petr Oros) [2021822]
- net: phy: broadcom: Do not modify LED configuration for SFP module PHYs (Petr Oros) [2021822]
- net: phy: Add is_on_sfp_module flag and phy_on_sfp helper (Petr Oros) [2021822]
- net: phy: broadcom: Set proper 1000BaseX/SGMII interface mode for BCM54616S (Petr Oros) [2021822]
- net: phy: marvell: Ensure SGMII auto-negotiation is enabled for 88E1111 (Petr Oros) [2021822]
- net: phylink: Add 5gbase-r support (Petr Oros) [2021822]
- net: phy: Add 5GBASER interface mode (Petr Oros) [2021822]
- net: phy: rename PHY_IGNORE_INTERRUPT to PHY_MAC_INTERRUPT (Petr Oros) [2021822]
- net: phy: at803x: add MDIX support to AR8031/33 (Petr Oros) [2021822]
- net: phy: broadcom: Allow BCM54210E to configure APD (Petr Oros) [2021822]
- net: phy: broadcom: Remove unused flags (Petr Oros) [2021822]
- net: phy: broadcom: Avoid forward for bcm54xx_config_clock_delay() (Petr Oros) [2021822]
- net: phy: consider that suspend2ram may cut off PHY power (Petr Oros) [2021822]
- net: phy: bcm7xxx: Add an entry for BCM72116 (Petr Oros) [2021822]
- net: mdiobus: Remove WARN_ON_ONCE(in_interrupt()) (Petr Oros) [2021822]
- net: Use kobj_to_dev() API (Petr Oros) [2021822]
- net: phy: Fixup kernel doc (Petr Oros) [2021822]
- net: phy: bcm7xxx: Add an entry for BCM72113 (Petr Oros) [2021822]
- net: phy: mchp: Add support for LAN8814 QUAD PHY (Petr Oros) [2021822]
- net: dp83867: Fix WoL SecureOn password (Petr Oros) [2021822]
- net: phy: at803x: constify static regulator_ops (Petr Oros) [2021822]
- net: phy: marvell10g: support XFI rate matching mode (Petr Oros) [2021822]
- net: switch to using PHY_INTERFACE_MODE_10GBASER rather than 10GKR (Petr Oros) [2021822]
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Phil Sutter) [1896241]
- net: do not reuse skbuff allocated from skbuff_fclone_cache in the skb cache (Ivan Vecera) [2069781]
- skbuff: queue NAPI_MERGED_FREE skbs into NAPI cache instead of freeing (Ivan Vecera) [2069781]
- skbuff: allow to use NAPI cache from __napi_alloc_skb() (Ivan Vecera) [2069781]
- skbuff: allow to optionally use NAPI cache from __alloc_skb() (Ivan Vecera) [2069781]
- skbuff: introduce {,__}napi_build_skb() which reuses NAPI cache heads (Ivan Vecera) [2069781]
- skbuff: move NAPI cache declarations upper in the file (Ivan Vecera) [2069781]
- skbuff: remove __kfree_skb_flush() (Ivan Vecera) [2069781]
- skbuff: use __build_skb_around() in __alloc_skb() (Ivan Vecera) [2069781]
- skbuff: simplify __alloc_skb() a bit (Ivan Vecera) [2069781]
- skbuff: make __build_skb_around() return void (Ivan Vecera) [2069781]
- skbuff: simplify kmalloc_reserve() (Ivan Vecera) [2069781]
- skbuff: move __alloc_skb() next to the other skb allocation functions (Ivan Vecera) [2069781]
- net: Introduce {netdev,napi}_alloc_frag_align() (Ivan Vecera) [2069781]
- mm: page_frag: Introduce page_frag_alloc_align() (Ivan Vecera) [2069781]
- perf tests attr: Add missing topdown metrics events (Michael Petlan) [1986275]
- cifs: Return correct error code from smb2_get_enc_key (Ronnie Sahlberg) [2058369]
- ipv4: avoid using shared IP generator for connected sockets (Paolo Abeni) [2062427] {CVE-2020-36516}
- crypto: cryptd - Fix skcipher instance memory leak (Vladis Dronov) [2004344]
- EVM: fix the evm= __setup handler return value (Bruno Meneguele) [2063900]
- integrity: include keyring name for unknown key request (Bruno Meneguele) [2063900]
- ima: limit secure boot feedback scope for appraise (Bruno Meneguele) [2063900]
- integrity: invalid kernel parameters feedback (Bruno Meneguele) [2063900]
- ima: add check for enforced appraise option (Bruno Meneguele) [2063900]
- ima: Allow template selection with ima_template[_fmt]= after ima_hash= (Bruno Meneguele) [2063900]
- ima: Remove ima_policy file before directory (Bruno Meneguele) [2063900]
- integrity: check the return value of audit_log_start() (Bruno Meneguele) [2063900]
- ima: fix deadlock when traversing "ima_default_rules". (Bruno Meneguele) [2063900]
- evm: Introduce evm_revalidate_status() (Bruno Meneguele) [2063900]
- evm: Refuse EVM_ALLOW_METADATA_WRITES only if an HMAC key is loaded (Bruno Meneguele) [2063900]
- evm: Load EVM key in ima_load_x509() to avoid appraisal (Bruno Meneguele) [2063900]
- evm: Execute evm_inode_init_security() only when an HMAC key is loaded (Bruno Meneguele) [2063900]
- fs/kernel_read_file: Remove FIRMWARE_PREALLOC_BUFFER enum (Bruno Meneguele) [2063900]
- RHEL-only: KVM: selftests: Fix AArch64 compilation (Andrew Jones) [2071997]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Andrew Jones) [2071997]
- RHEL-only: KVM: selftests: Remove unused modes (Andrew Jones) [2071997]

* Wed Apr 06 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-380.el8]
- netfilter: nf_tables_offload: incorrect flow offload action array size (Florian Westphal) [2056728] {CVE-2022-25636}
- netfilter: nftables_offload: KASAN slab-out-of-bounds Read in nft_flow_rule_create (Florian Westphal) [2056728]
- KVM: SVM: Allow AVIC support on system w/ physical APIC ID > 255 (Bandan Das) [2033068]
- PCI/ACPI: Fix acpi_pci_osc_control_set() kernel-doc comment (Mark Langsdorf) [2049209]
- PCI/ACPI: Check for _OSC support in acpi_pci_osc_control_set() (Mark Langsdorf) [2049209]
- PCI/ACPI: Move _OSC query checks to separate function (Mark Langsdorf) [2049209]
- PCI/ACPI: Move supported and control calculations to separate functions (Mark Langsdorf) [2049209]
- PCI/ACPI: Remove OSC_PCI_SUPPORT_MASKS and OSC_PCI_CONTROL_MASKS (Mark Langsdorf) [2049209]
- kabi: Adding symbol blkdev_get_by_dev (fs/block_dev.c) (Čestmír Kalina) [2010296]
- kabi: Adding symbol thaw_bdev (fs/block_dev.c) (Čestmír Kalina) [2010296]
- kabi: Adding symbol freeze_bdev (fs/block_dev.c) (Čestmír Kalina) [2010296]
- s390/cio: make ccw_device_dma_* more robust (Thomas Huth) [2066709]
- perf/x86/intel/uncore: Make uncore_discovery clean for 64 bit addresses (Michael Petlan) [2069237]
- redhat: switch secureboot kernel image signing to release keys (Augusto Caringi)
- ice: xsk: Stop Rx processing when ntc catches ntu (Ivan Vecera) [2069082]
- ice: xsk: Fix indexing in ice_tx_xsk_pool() (Ivan Vecera) [2069082]
- ice: Fix kernel crash in XDP scenario (Ivan Vecera) [2069082]

* Wed Apr 06 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-379.el8]
- do_wait: make PIDTYPE_PID case O(1) instead of O(n) (Nico Pache) [2055973]
- n_tty: wake up poll(POLLRDNORM) on receiving data (Rafael Aquini) [2033338]
- powerpc/papr_scm: Implement initial support for injecting smart errors (Steve Best) [1987103]
- mm: memcg: synchronize objcg lists with a dedicated spinlock (Rafael Aquini) [2064847]
- kasan: fix quarantine conflicting with init_on_free (Rafael Aquini) [2064847]
- mm/hwpoison: clear MF_COUNT_INCREASED before retrying get_any_page() (Rafael Aquini) [2064847]
- mm/memcg: relocate mod_objcg_mlstate(), get_obj_stock() and put_obj_stock() (Rafael Aquini) [2064847]
- mm: move node_reclaim_distance to fix NUMA without SMP (Rafael Aquini) [2064847]
- vmalloc: choose a better start address in vm_area_register_early() (Rafael Aquini) [2064847]
- mm/vmalloc: check various alignments when debugging (Rafael Aquini) [2064847]
- mm/vmalloc: don't allow VM_NO_GUARD on vmap() (Rafael Aquini) [2064847]
- mm, thp: bail out early in collapse_file for writeback page (Rafael Aquini) [2064847]
- mm/sparse: set SECTION_NID_SHIFT to 6 (Rafael Aquini) [2064847]
- mm/memory_hotplug: fix kerneldoc comment for __remove_memory (Rafael Aquini) [2064847]
- mm: fix memory_failure() handling of dax-namespace metadata (Rafael Aquini) [2064847]
- mm: teach pfn_to_online_page() about ZONE_DEVICE section collisions (Rafael Aquini) [2064847]
- mm: teach pfn_to_online_page() to consider subsection validity (Rafael Aquini) [2064847]
- mm: move pfn_to_online_page() out of line (Rafael Aquini) [2064847]
- Revert "mm: use early_pfn_to_nid in page_ext_init" (Rafael Aquini) [2064847]
- x86/mm: Fix kern_addr_valid() to cope with existing but not present entries (Rafael Aquini) [2064847]
- powerpc/book3s64: Fix error handling in mm_iommu_do_alloc() (Rafael Aquini) [2064847]
- powerpc/pkeys: remove unused pkey_allows_readwrite (Rafael Aquini) [2064847]
- x86/hyperv: Output host build info as normal Windows version number (Vitaly Kuznetsov) [2060700]
- powerpc/smp: Update cpu_core_map on all PowerPc systems (Diego Domingos) [2064104]
- crypto: ccp - ccp_dmaengine_unregister release dma channels (Vladis Dronov) [2015374]
- crypto: ccp - remove redundant ret variable (Vladis Dronov) [2015374]
- crypto: ccp - Ensure psp_ret is always init'd in __sev_platform_init_locked() (Vladis Dronov) [2015374]
- crypto: ccp - remove unneeded semicolon (Vladis Dronov) [2015374]
- crypto: ccp - Add SEV_INIT_EX support (Vladis Dronov) [2015374]
- crypto: ccp - Add psp_init_on_probe module parameter (Vladis Dronov) [2015374]
- crypto: ccp - Refactor out sev_fw_alloc() (Vladis Dronov) [2015374]
- crypto: ccp - Move SEV_INIT retry for corrupted data (Vladis Dronov) [2015374]
- crypto: ccp - Add SEV_INIT rc error logging on init (Vladis Dronov) [2015374]
- crypto: ccp - no need to initialise statics to 0 (Vladis Dronov) [2015374]
- ccp: ccp - add support for Green Sardine (Vladis Dronov) [2015374]
- crypto: ccp - fix command queuing to TEE ring buffer (Vladis Dronov) [2015374]
- crypto: ccp - reduce tee command status polling interval from 5ms to 1ms (Vladis Dronov) [2015374]
- crypto: ccp - provide in-kernel API to submit TEE commands (Vladis Dronov) [2015374]
- crypto: ccp - add TEE support for Raven Ridge (Vladis Dronov) [2015374]
- crypto: ccp - check whether PSP supports SEV or TEE before initialization (Vladis Dronov) [2015374]
- ice: Allow to pass VLAN tagged packets to VF when port VLAN is configured (Ivan Vecera) [2071027]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Fix power_pmu_disable to call clear_pmi_irq_pending only if PMI is pending (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Only define power_pmu_wants_prompt_pmi() for CONFIG_PPC64 (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Add data source encodings for power10 platform (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Add encodings to represent data based on newer composite PERF_MEM_LVLNUM* fields (Desnes A. Nunes do Rosario) [1992813]
- perf: Add new macros for mem_hops field (Desnes A. Nunes do Rosario) [1992813]
- tools headers UAPI: Add new macros for mem_hops field to perf_event.h (Desnes A. Nunes do Rosario) [1992813]
- bpf: Remove config check to enable bpf support for branch records (Desnes A. Nunes do Rosario) [1992813]
- perf powerpc: Update global/local variants for p_stage_cyc (Desnes A. Nunes do Rosario) [1992813]
- perf sort: Include global and local variants for p_stage_cyc sort key (Desnes A. Nunes do Rosario) [1992813]
- perf sort: Fix the 'p_stage_cyc' sort key behavior (Desnes A. Nunes do Rosario) [1992813]
- perf sort: Fix the 'ins_lat' sort key behavior (Desnes A. Nunes do Rosario) [1992813]
- perf sort: Fix the 'weight' sort key behavior (Desnes A. Nunes do Rosario) [1992813]
- perf vendor events power10: Add metric events JSON file for power10 platform (Desnes A. Nunes do Rosario) [1992813]
- perf powerpc: Add support to expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [1992813]
- perf powerpc: Refactor the code definition of perf reg extended mask in tools side header file (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Refactor the code definition of perf reg extended mask (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Fix data source encodings for L2.1 and L3.1 accesses (Desnes A. Nunes do Rosario) [1992813]
- tools/perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [1992813]
- perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [1992813]
- perf: Add comment about current state of PERF_MEM_LVL_* namespace and remove an extra line (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Fix the check for SIAR value (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Drop the case of returning 0 as instruction pointer (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Use stack siar instead of mfspr (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf/hv-gpci: Fix counter value parsing (Desnes A. Nunes do Rosario) [1992813]
- powerpc/perf: Fix PMU callbacks to clear pending PMI before resetting an overflown PMC (Desnes A. Nunes do Rosario) [1992813]
- CI: Remove deprecated option (Veronika Kabatova)

* Fri Apr 01 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-378.el8]
- bareudp: use ipv6_mod_enabled to check if IPv6 enabled (Hangbin Liu) [2063813]
- powerpc/mm/numa: skip NUMA_NO_NODE onlining in parse_numa_properties() (Diego Domingos) [2048218]
- redhat: copy rpminspect to dist-git repo (Jarod Wilson)
- configs: enable CONFIG_RMI4_F3A (Benjamin Tissoires) [2067219]
- Input: synaptics-rmi4 - add support for F3A (Benjamin Tissoires) [2067219]
- RDMA/cma: Do not change route.addr.src_addr.ss_family (Kamal Heib) [2032074] {CVE-2021-4028}
- drm/i915/adl_s: Remove require_force_probe protection (Michel Dänzer) [2025896]
- drm/i915/adl_s: Update ADL-S PCI IDs (Michel Dänzer) [2025896]
- drm/i915: Limit Wa_22010178259 to affected platforms (Michel Dänzer) [2025896]
- drm/i915/adl_s: Fix dma_mask_size to 39 bit (Michel Dänzer) [2025896]
- drm/i915/dmc: Update DMC to v2.14 on ADL-P (Michel Dänzer) [2060051]
- drm/i915: Update memory bandwidth formulae (Michel Dänzer) [2060051]
- drm/i915/fb: Fold modifier CCS type/tiling attribute to plane caps (Michel Dänzer) [2060051]
- drm/i915/fb: Don't store bitmasks in the intel_plane_caps enum (Michel Dänzer) [2060051]
- drm/i915/adl_p: Add ddc pin mapping (Michel Dänzer) [2060051]
- iommu/amd: Fix I/O page table memory leak (Jerry Snitselaar) [2053210]
- iommu/amd: Recover from event log overflow (Jerry Snitselaar) [2053210]

* Thu Mar 31 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-377.el8]
- redhat: tune rpminspect w/additions from rhel9 branch (Jarod Wilson)
- powerpc/pseries/ddw: Revert "Extend upper limit for huge DMA window for persistent memory" (Steve Best) [2056080]
- x86/tsc: Disable clocksource watchdog for TSC on qualified platorms (Prarit Bhargava) [1971939]
- x86/tsc: Add a timer to make sure TSC_adjust is always checked (Prarit Bhargava) [1971939]
- x86/hpet: Use another crystalball to evaluate HPET usability (Prarit Bhargava) [1971939]
- x86/tsc: Respect tsc command line paraemeter for clocksource_tsc_early (Prarit Bhargava) [1971939]
- [s390] s390/pci: fix zpci_zdev_put() on reserve (Claudio Imbrenda) [2039185]
- [s390] s390/pci: fix use after free of zpci_dev (Claudio Imbrenda) [2039185]
- [s390] s390/cio: make ccw_device_dma_* more robust (Claudio Imbrenda) [2039186]
- [s390] s390/pci: add s390_iommu_aperture kernel parameter (Claudio Imbrenda) [2039181]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Paul Lai) [1918929]
- kvm: selftests: sync uapi/linux/kvm.h with Linux header (Paul Lai) [1918929]
- kvm: selftests: conditionally build vm_xsave_req_perm() (Paul Lai) [1918929]
- x86/kvm/fpu: Remove kvm_vcpu_arch.guest_supported_xcr0 (Paul Lai) [1918929]
- x86/kvm/fpu: Limit guest user_xfeatures to supported bits of XCR0 (Paul Lai) [1918929]
- KVM: x86/cpuid: Exclude unpermitted xfeatures sizes at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1918929]
- KVM: x86: Move CPUID.(EAX=0x12,ECX=1) mangling to __kvm_update_cpuid_runtime() (Paul Lai) [1918929]
- KVM: x86/cpuid: Clear XFD for component i if the base feature is missing (Paul Lai) [1918929]
- KVM: x86: Do runtime CPUID update before updating vcpu->arch.cpuid_entries (Paul Lai) [1918929]
- x86/fpu: Fix inline prefix warnings (Paul Lai) [1918929]
- selftest: kvm: Add amx selftest (Paul Lai) [1918929]
- selftest: kvm: Move struct kvm_x86_state to header (Paul Lai) [1918929]
- selftest: kvm: Reorder vcpu_load_state steps for AMX (Paul Lai) [1918929]
- kvm: x86: Disable interception for IA32_XFD on demand (Paul Lai) [1918929]
- x86/fpu: Provide fpu_sync_guest_vmexit_xfd_state() (Paul Lai) [1918929]
- kvm: selftests: Add support for KVM_CAP_XSAVE2 (Paul Lai) [1918929]
- kvm: x86: Add support for getting/setting expanded xstate buffer (Paul Lai) [1918929]
- x86/fpu: Add uabi_size to guest_fpu (Paul Lai) [1918929]
- kvm: x86: Add CPUID support for Intel AMX (Paul Lai) [1918929]
- kvm: x86: Add XCR0 support for Intel AMX (Paul Lai) [1918929]
- kvm: x86: Disable RDMSR interception of IA32_XFD_ERR (Paul Lai) [1918929]
- kvm: x86: Emulate IA32_XFD_ERR for guest (Paul Lai) [1918929]
- kvm: x86: Intercept #NM for saving IA32_XFD_ERR (Paul Lai) [1918929]
- x86/fpu: Prepare xfd_err in struct fpu_guest (Paul Lai) [1918929]
- kvm: x86: Add emulation for IA32_XFD (Paul Lai) [1918929]
- x86/fpu: Provide fpu_update_guest_xfd() for IA32_XFD emulation (Paul Lai) [1918929]
- kvm: x86: Enable dynamic xfeatures at KVM_SET_CPUID2 (Paul Lai) [1918929]
- x86/fpu: Provide fpu_enable_guest_xfd_features() for KVM (Paul Lai) [1918929]
- x86/fpu: Add guest support to xfd_enable_feature() (Paul Lai) [1918929]
- x86/fpu: Make XFD initialization in __fpstate_reset() a function argument (Paul Lai) [1918929]
- kvm: x86: Exclude unpermitted xfeatures at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1918929]
- kvm: x86: Fix xstate_required_size() to follow XSTATE alignment rule (Paul Lai) [1918929]
- x86/fpu: Prepare guest FPU for dynamically enabled FPU features (Paul Lai) [1918929]
- x86/fpu: Extend fpu_xstate_prctl() with guest permissions (Paul Lai) [1918929]
- kvm: selftests: move ucall declarations into ucall_common.h (Paul Lai) [1918929]
- kvm: selftests: move base kvm_util.h declarations to kvm_util_base.h (Paul Lai) [1918929]
- cpuid: kvm_find_kvm_cpuid_features() should be declared 'static' (Paul Lai) [1918929]
- KVM: x86: Make sure KVM_CPUID_FEATURES really are KVM_CPUID_FEATURES (Paul Lai) [1918929]
- KVM: x86: Add helper to consolidate core logic of SET_CPUID{2} flows (Paul Lai) [1918929]

* Mon Mar 28 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-376.el8]
- scsi: mpi3mr: Fix flushing !WQ_MEM_RECLAIM events warning (Tomas Henzl) [2052278]
- scsi: mpi3mr: Fix memory leaks (Tomas Henzl) [2054814]
- scsi: mpi3mr: Fix reporting of actual data transfer size (Tomas Henzl) [2054814]
- scsi: mpi3mr: Fix cmnd getting marked as in use forever (Tomas Henzl) [2054814]
- scsi: mpi3mr: Fix hibernation issue (Tomas Henzl) [2054814]
- scsi: mpi3mr: Fix printing of pending I/O count (Tomas Henzl) [2054814]
- scsi: mpi3mr: Fix deadlock while canceling the fw event (Tomas Henzl) [2054814]
- scsi: mpi3mr: Fixes around reply request queues (Tomas Henzl) [2054814]
- scsi: mpi3mr: Enhanced Task Management Support Reply handling (Tomas Henzl) [2054814]
- scsi: mpi3mr: Use TM response codes from MPI3 headers (Tomas Henzl) [2054814]
- scsi: mpi3mr: Increase internal cmnds timeout to 60s (Tomas Henzl) [2054814]
- scsi: mpi3mr: Do access status validation before adding devices (Tomas Henzl) [2054814]
- scsi: mpi3mr: Update MPI3 headers - part2 (Tomas Henzl) [2054814]
- scsi: mpi3mr: Update MPI3 headers - part1 (Tomas Henzl) [2054814]
- scsi: mpi3mr: Don't reset IOC if cmnds flush with reset status (Tomas Henzl) [2054814]
- scsi: mpi3mr: Replace spin_lock() with spin_lock_irqsave() (Tomas Henzl) [2054814]
- scsi: mpi3mr: Add debug APIs based on logging_level bits (Tomas Henzl) [2054814]
- scsi: mpt3sas: Remove scsi_dma_map() error messages (Tomas Henzl) [2057021]
- net/mlx5: Fix wrong limitation of metadata match on ecpf (Amir Tzin) [2049094]
- nfsd: fix use-after-free due to delegation race (Thiago Becker) [2053262]
- dma-buf: cma_heap: Fix mutex locking section (Michel Dänzer) [2044440]
- drm/amdkfd: Check for null pointer after calling kmemdup (Michel Dänzer) [2044440]
- drm/atomic: Check new_crtc_state->active to determine if CRTC needs disable in self refresh mode (Michel Dänzer) [2044440]
- drm/amd: avoid suspend on dGPUs w/ s2idle support when runtime PM enabled (Michel Dänzer) [2044440]
- drm/i915/overlay: Prevent divide by zero bugs in scaling (Michel Dänzer) [2044440]
- dma-buf: heaps: Fix potential spectre v1 gadget (Michel Dänzer) [2044440]
- drm/amd/display: Force link_rate as LINK_RATE_RBR2 for 2018 15" Apple Retina panels (Michel Dänzer) [2044440]
- drm/amd/display: watermark latencies is not enough on DCN31 (Michel Dänzer) [2044440]
- drm/amd/pm: correct the MGpuFanBoost support for Beige Goby (Michel Dänzer) [2044440]
- drm/i915/adlp: Fix TypeC PHY-ready status readout (Michel Dänzer) [2044440]
- drm/nouveau: fix off by one in BIOS boundary checking (Michel Dänzer) [2044440]
- drm/i915: Disable DSB usage for now (Michel Dänzer) [2044440]
- Revert "drm/ast: Support 1600x900 with 108MHz PCLK" (Michel Dänzer) [2044440]
- drm/amd/display: Fix FP start/end for dcn30_internal_validate_bw. (Michel Dänzer) [2044440]
- drm/atomic: Add the crtc to affected crtc only if uapi.enable = true (Michel Dänzer) [2044440]
- drm/amdgpu: Use correct VIEWPORT_DIMENSION for DCN2 (Michel Dänzer) [2044440]
- drm/amd/display: reset dcn31 SMU mailbox on failures (Michel Dänzer) [2044440]
- drm/vmwgfx: Remove explicit transparent hugepages support (Michel Dänzer) [2044440]
- drm/radeon: fix error handling in radeon_driver_open_kms (Michel Dänzer) [2044440]
- drm/i915/display/ehl: Update voltage swing table (Michel Dänzer) [2044440]
- drm/nouveau/kms/nv04: use vzalloc for nv04_display (Michel Dänzer) [2044440]
- drm/amd/display: Fix the uninitialized variable in enable_stream_features() (Michel Dänzer) [2044440]
- amdgpu/pm: Make sysfs pm attributes as read-only for VFs (Michel Dänzer) [2044440]
- drm/amdgpu: fixup bad vram size on gmc v8 (Michel Dänzer) [2044440]
- drm/amd/amdgpu: fix gmc bo pin count leak in SRIOV (Michel Dänzer) [2044440]
- drm/amd/amdgpu: fix psp tmr bo pin count leak in SRIOV (Michel Dänzer) [2044440]
- drm/amdkfd: Fix error handling in svm_range_add (Michel Dänzer) [2044440]
- drm/vmwgfx: Introduce a new placement for MOB page tables (Michel Dänzer) [2044440]
- drm/vmwgfx: Release ttm memory if probe fails (Michel Dänzer) [2044440]
- drm/amd/display: add else to avoid double destroy clk_mgr (Michel Dänzer) [2044440]
- drm/amdgpu/display: set vblank_disable_immediate for DC (Michel Dänzer) [2044440]
- drm/amd/display: check top_pipe_to_program pointer (Michel Dänzer) [2044440]
- drm: panel-orientation-quirks: Add quirk for the Lenovo Yoga Book X91F/L (Michel Dänzer) [2044440]
- drm/amd/display: Fix out of bounds access on DNC31 stream encoder regs (Michel Dänzer) [2044440]
- drm/amd/display: Fix bug in debugfs crc_win_update entry (Michel Dänzer) [2044440]
- drm/radeon/radeon_kms: Fix a NULL pointer dereference in radeon_driver_open_kms() (Michel Dänzer) [2044440]
- drm/amdgpu: Fix a NULL pointer dereference in amdgpu_connector_lcd_native_mode() (Michel Dänzer) [2044440]
- drm/vmwgfx: Fail to initialize on broken configs (Michel Dänzer) [2044440]
- drm/vmwgfx: Remove the deprecated lower mem limit (Michel Dänzer) [2044440]
- drm/vboxvideo: fix a NULL vs IS_ERR() check (Michel Dänzer) [2044440]
- drm: fix null-ptr-deref in drm_dev_init_release() (Michel Dänzer) [2044440]
- drm/ttm: Put BO in its memory manager's lru list (Michel Dänzer) [2044440]
- dma_fence_array: Fix PENDING_ERROR leak in dma_fence_array_signaled() (Michel Dänzer) [2044440]
- drm/amd/display: explicitly set is_dsc_supported to false before use (Michel Dänzer) [2044440]
- drm/i915: Avoid bitwise vs logical OR warning in snb_wm_latency_quirk() (Michel Dänzer) [2044440]
- drm/amd/pm: keep the BACO feature enabled for suspend (Michel Dänzer) [2044440]
- Revert "drm/amdgpu: stop scheduler when calling hw_fini (v2)" (Michel Dänzer) [2044440]
- drm/amd/display: Added power down for DCN10 (Michel Dänzer) [2044440]
- drm/amd/display: fix B0 TMDS deepcolor no dislay issue (Michel Dänzer) [2044440]
- drm/amdgpu: put SMU into proper state on runpm suspending for BOCO capable platform (Michel Dänzer) [2044440]
- drm/amd/pm: skip setting gfx cgpg in the s0ix suspend-resume (Michel Dänzer) [2044440]
- drm/amd/pm: Fix xgmi link control on aldebaran (Michel Dänzer) [2044440]
- drm/amdgpu: fix dropped backing store handling in amdgpu_dma_buf_move_notify (Michel Dänzer) [2044440]
- drm/amd/display: Changed pipe split policy to allow for multi-display pipe split (Michel Dänzer) [2044440]
- drm/amdgpu: add support for IP discovery gc_info table v2 (Michel Dänzer) [2044440]
- drm/amdgpu: When the VCN(1.0) block is suspended, powergating is explicitly enabled (Michel Dänzer) [2044440]
- drm/nouveau: wait for the exclusive fence after the shared ones v2 (Michel Dänzer) [2044440]
- drm/nouveau: always wait for the exclusive fence (Michel Dänzer) [2044440]
- drm/amd/display: Set optimize_pwr_state for DCN31 (Michel Dänzer) [2044440]
- drm/amd/display: Send s0i2_rdy in stream_count == 0 optimization (Michel Dänzer) [2044440]
- drm/amd/pm: fix reading SMU FW version from amdgpu_firmware_info on YC (Michel Dänzer) [2044440]
- drm/amdgpu: don't override default ECO_BITs setting (Michel Dänzer) [2044440]
- drm/amdgpu: correct register access for RLC_JUMP_TABLE_RESTORE (Michel Dänzer) [2044440]
- drm/amd/pm: fix a potential gpu_metrics_table memory leak (Michel Dänzer) [2044440]
- drm/amd/display: Set exit_optimized_pwr_state for DCN31 (Michel Dänzer) [2044440]
- drm/i915/display: Fix an unsigned subtraction which can never be negative. (Michel Dänzer) [2044440]
- drm/ast: potential dereference of null pointer (Michel Dänzer) [2044440]
- drm: simpledrm: fix wrong unit with pixel clock (Michel Dänzer) [2044440]
- Revert "drm/fb-helper: improve DRM fbdev emulation device names" (Michel Dänzer) [2044440]
- drm/i915/hdmi: Turn DP++ TMDS output buffers back on in encoder->shutdown() (Michel Dänzer) [2044440]
- drm/i915/hdmi: convert intel_hdmi_to_dev to intel_hdmi_to_i915 (Michel Dänzer) [2044440]
- drm/amdkfd: process_info lock not needed for svm (Michel Dänzer) [2044440]
- drm/amd/display: add connector type check for CRC source set (Michel Dänzer) [2044440]
- drm/amdkfd: fix double free mem structure (Michel Dänzer) [2044440]
- drm/amd/display: Fix for the no Audio bug with Tiled Displays (Michel Dänzer) [2044440]
- drm/amdgpu: check atomic flag to differeniate with legacy path (Michel Dänzer) [2044440]
- drm/amd/display: Fix DPIA outbox timeout after S3/S4/reset (Michel Dänzer) [2044440]
- drm/syncobj: Deal with signalled fences in drm_syncobj_find_fence. (Michel Dänzer) [2044440]
- drm/i915/dp: Perform 30ms delay after source OUI write (Michel Dänzer) [2044440]
- drm/amd/display: Allow DSC on supported MST branch devices (Michel Dänzer) [2044440]
- dma-buf: system_heap: Use 'for_each_sgtable_sg' in pages free flow (Michel Dänzer) [2044440]
- drm/amd/amdgpu: fix potential memleak (Michel Dänzer) [2044440]
- drm/amd/amdkfd: Fix kernel panic when reset failed and been triggered again (Michel Dänzer) [2044440]
- drm/amd/pm: Remove artificial freq level on Navi1x (Michel Dänzer) [2044440]
- drm/amdgpu/gfx9: switch to golden tsc registers for renoir+ (Michel Dänzer) [2044440]
- drm/amd/display: Set plane update flags for all planes in reset (Michel Dänzer) [2044440]
- drm/amd/display: Fix DPIA outbox timeout after GPU reset (Michel Dänzer) [2044440]
- drm/aspeed: Fix vga_pw sysfs output (Michel Dänzer) [2044440]
- drm/nouveau/acr: fix a couple NULL vs IS_ERR() checks (Michel Dänzer) [2044440]
- drm/amd/display: Fix OLED brightness control on eDP (Michel Dänzer) [2044440]
- drm/amdgpu: IH process reset count when restart (Michel Dänzer) [2044440]
- drm/amd/pm: avoid duplicate powergate/ungate setting (Michel Dänzer) [2044440]
- drm/amdgpu: fix set scaling mode Full/Full aspect/Center not works on vga and dvi connectors (Michel Dänzer) [2044440]
- drm/i915: Fix type1 DVI DP dual mode adapter heuristic for modern platforms (Michel Dänzer) [2044440]
- drm/i915/dp: Ensure max link params are always valid (Michel Dänzer) [2044440]
- drm/i915/dp: Ensure sink rate values are always valid (Michel Dänzer) [2044440]
- drm/prime: Fix use after free in mmap with drm_gem_ttm_mmap (Michel Dänzer) [2044440]
- drm/udl: fix control-message timeout (Michel Dänzer) [2044440]
- drm/amd/display: Limit max DSC target bpp for specific monitors (Michel Dänzer) [2044440]
- drm/amd/display: Update swizzle mode enums (Michel Dänzer) [2044440]
- drm/cma-helper: Release non-coherent memory with dma_free_noncoherent() (Michel Dänzer) [2044440]
- Revert "drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping" (Michel Dänzer) [2044440]
- drm/nouveau: hdmigv100.c: fix corrupted HDMI Vendor InfoFrame (Michel Dänzer) [2044440]
- x86/speculation: Check CPU capability before applying IBRS spectre v2 mitigation (Waiman Long) [2062156 2062166] {CVE-2022-0001 CVE-2022-0002 CVE-2021-26401}
- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF + SMT (Waiman Long) [2062156 2062166] {CVE-2022-0001 CVE-2022-0002 CVE-2021-26401}
- x86/speculation: Warn about Spectre v2 LFENCE mitigation (Waiman Long) [2062156 2062166] {CVE-2022-0001 CVE-2022-0002 CVE-2021-26401}
- x86/speculation: Update link to AMD speculation whitepaper (Waiman Long) [2062166] {CVE-2021-26401}
- x86/speculation: Use generic retpoline by default on AMD (Waiman Long) [2062166] {CVE-2021-26401}
- x86/speculation: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062156] {CVE-2022-0001 CVE-2022-0002}
- Documentation/hw-vuln: Update spectre doc (Waiman Long) [2062156] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Add eIBRS + Retpoline options (Waiman Long) [2062156] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE (Waiman Long) [2062156] {CVE-2022-0001 CVE-2022-0002}
- x86,bugs: Unconditionally allow spectre_v2=retpoline,amd (Waiman Long) [2062156] {CVE-2022-0001 CVE-2022-0002}
- x86: deduplicate the spectre_v2_user documentation (Waiman Long) [2062156] {CVE-2022-0001 CVE-2022-0002}
- fuse: fix pipe buffer lifetime for direct_io (Miklos Szeredi) [2064863] {CVE-2022-1011}
- ice: Do not enable VLAN pruning when spoofchk is enabled (Ivan Vecera) [2062343]
- ice: don't allow to run ice_send_event_to_aux() in atomic ctx (Ivan Vecera) [2062343]
- ice: fix 'scheduling while atomic' on aux critical err interrupt (Ivan Vecera) [2062343]
- ice: Fix MAC address setting (Ivan Vecera) [2062343]
- ice: Clear default forwarding VSI during release (Ivan Vecera) [2062343]
- ice: Fix broken IFF_ALLMULTI handling (Ivan Vecera) [2062343]
- iavf: Fix hang during reboot/shutdown (Ivan Vecera) [2062343]
- iavf: Fix double free in iavf_reset_task (Ivan Vecera) [2062343]
- ice: destroy flow director filter mutex after releasing VSIs (Ivan Vecera) [2062343]
- ice: fix NULL pointer dereference in ice_update_vsi_tx_ring_stats() (Ivan Vecera) [2062343]
- iavf: Fix adopting new combined setting (Ivan Vecera) [2062343]
- iavf: Fix handling of vlan strip virtual channel messages (Ivan Vecera) [2062343]
- iavf: Fix __IAVF_RESETTING state usage (Ivan Vecera) [2062343]
- iavf: Fix missing check for running netdev (Ivan Vecera) [2062343]
- iavf: Fix deadlock in iavf_reset_task (Ivan Vecera) [2062343]
- iavf: Fix race in init state (Ivan Vecera) [2062343]
- iavf: Fix locking for VIRTCHNL_OP_GET_OFFLOAD_VLAN_V2_CAPS (Ivan Vecera) [2062343]
- iavf: Fix init state closure on remove (Ivan Vecera) [2062343]
- iavf: Add waiting so the port is initialized in remove (Ivan Vecera) [2062343]
- iavf: Rework mutexes for better synchronisation (Ivan Vecera) [2062343]
- iavf: remove an unneeded variable (Ivan Vecera) [2062343]
- iavf: Fix limit of total number of queues to active queues of VF (Ivan Vecera) [2062343]
- iavf: Restrict maximum VLAN filters for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Ivan Vecera) [2062343]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 offload enable/disable (Ivan Vecera) [2062343]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 hotpath (Ivan Vecera) [2062343]
- iavf: Add support VIRTCHNL_VF_OFFLOAD_VLAN_V2 during netdev config (Ivan Vecera) [2062343]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 negotiation (Ivan Vecera) [2062343]
- virtchnl: Add support for new VLAN capabilities (Ivan Vecera) [2062343]
- virtchnl: Use the BIT() macro for capability/offload flags (Ivan Vecera) [2062343]
- virtchnl: Remove unused VIRTCHNL_VF_OFFLOAD_RSVD define (Ivan Vecera) [2062343]
- virtchnl: Add missing padding to virtchnl_proto_hdrs (Ivan Vecera) [2062343]
- ice: Fix race condition during interface enslave (Ivan Vecera) [2062343]
- ice: Fix curr_link_speed advertised speed (Ivan Vecera) [2062343]
- ice: Don't use GFP_KERNEL in atomic context (Ivan Vecera) [2062343]
- ice: Fix error with handling of bonding MTU (Ivan Vecera) [2062343]
- ice: stop disabling VFs due to PF error responses (Ivan Vecera) [2062343]
- ice: initialize local variable 'tlv' (Ivan Vecera) [2062343]
- ice: check the return of ice_ptp_gettimex64 (Ivan Vecera) [2062343]
- ice: fix concurrent reset and removal of VFs (Ivan Vecera) [2062343]
- ice: fix setting l4 port flag when adding filter (Ivan Vecera) [2062343]
- ice: Match on all profiles in slow-path (Ivan Vecera) [2062343]
- ice: enable parsing IPSEC SPI headers for RSS (Ivan Vecera) [2062343]
- ice: Avoid RTNL lock when re-creating auxiliary device (Ivan Vecera) [2062343]
- ice: Fix KASAN error in LAG NETDEV_UNREGISTER handler (Ivan Vecera) [2062343]
- ice: fix IPIP and SIT TSO offload (Ivan Vecera) [2062343]
- ice: fix an error code in ice_cfg_phy_fec() (Ivan Vecera) [2062343]
- ice: Use bitmap_free() to free bitmap (Ivan Vecera) [2062343]
- ice: Optimize a few bitmap operations (Ivan Vecera) [2062343]
- ice: Slightly simply ice_find_free_recp_res_idx (Ivan Vecera) [2062343]
- ice: improve switchdev's slow-path (Ivan Vecera) [2062343]
- ice: replay advanced rules after reset (Ivan Vecera) [2062343]
- ice: Add flow director support for channel mode (Ivan Vecera) [2062343]
- ice: trivial: fix odd indenting (Ivan Vecera) [2062343]
- ice: support crosstimestamping on E822 devices if supported (Ivan Vecera) [2062343]
- ice: exit bypass mode once hardware finishes timestamp calibration (Ivan Vecera) [2062343]
- ice: ensure the hardware Clock Generation Unit is configured (Ivan Vecera) [2062343]
- ice: implement basic E822 PTP support (Ivan Vecera) [2062343]
- ice: convert clk_freq capability into time_ref (Ivan Vecera) [2062343]
- ice: introduce ice_ptp_init_phc function (Ivan Vecera) [2062343]
- ice: use 'int err' instead of 'int status' in ice_ptp_hw.c (Ivan Vecera) [2062343]
- ice: PTP: move setting of tstamp_config (Ivan Vecera) [2062343]
- ice: introduce ice_base_incval function (Ivan Vecera) [2062343]
- ice: xsk: fix cleaned_count setting (Ivan Vecera) [2062343]
- ice: xsk: allow empty Rx descriptors on XSK ZC data path (Ivan Vecera) [2062343]
- ice: xsk: allocate separate memory for XDP SW ring (Ivan Vecera) [2062343]
- ice: xsk: return xsk buffers back to pool when cleaning the ring (Ivan Vecera) [2062343]
- ice: use modern kernel API for kick (Ivan Vecera) [2062343]
- ice: tighter control over VSI_DOWN state (Ivan Vecera) [2062343]
- ice: use prefetch methods (Ivan Vecera) [2062343]
- ice: update to newer kernel API (Ivan Vecera) [2062343]
- ice: support immediate firmware activation via devlink reload (Ivan Vecera) [2062343]
- ice: reduce time to read Option ROM CIVD data (Ivan Vecera) [2062343]
- ice: move ice_devlink_flash_update and merge with ice_flash_pldm_image (Ivan Vecera) [2062343]
- ice: move and rename ice_check_for_pending_update (Ivan Vecera) [2062343]
- ice: devlink: add shadow-ram region to snapshot Shadow RAM (Ivan Vecera) [2062343]
- ice: Remove unused ICE_FLOW_SEG_HDRS_L2_MASK (Ivan Vecera) [2062343]
- ice: Remove unnecessary casts (Ivan Vecera) [2062343]
- ice: Propagate error codes (Ivan Vecera) [2062343]
- ice: Remove excess error variables (Ivan Vecera) [2062343]
- ice: Cleanup after ice_status removal (Ivan Vecera) [2062343]
- ice: Remove enum ice_status (Ivan Vecera) [2062343]
- ice: Use int for ice_status (Ivan Vecera) [2062343]
- ice: Remove string printing for ice_status (Ivan Vecera) [2062343]
- ice: Refactor status flow for DDP load (Ivan Vecera) [2062343]
- ice: Refactor promiscuous functions (Ivan Vecera) [2062343]
- ice: refactor PTYPE validating (Ivan Vecera) [2062343]
- ice: Add package PTYPE enable information (Ivan Vecera) [2062343]
- ice: safer stats processing (Ivan Vecera) [2062343]
- ice: fix adding different tunnels (Ivan Vecera) [2062343]
- ice: fix choosing UDP header type (Ivan Vecera) [2062343]
- ice: ignore dropped packets during init (Ivan Vecera) [2062343]
- ice: rearm other interrupt cause register after enabling VFs (Ivan Vecera) [2062343]
- net/ice: Remove unused enum (Ivan Vecera) [2062343]
- net/ice: Fix boolean assignment (Ivan Vecera) [2062343]
- net/ice: Add support for enable_iwarp and enable_roce devlink param (Ivan Vecera) [2062343]
- ice: avoid bpf_prog refcount underflow (Ivan Vecera) [2062343]
- ice: fix vsi->txq_map sizing (Ivan Vecera) [2062343]
- ice: Hide bus-info in ethtool for PRs in switchdev mode (Ivan Vecera) [2062343]
- ice: Clear synchronized addrs when adding VFs in switchdev mode (Ivan Vecera) [2062343]
- ice: fix error return code in ice_get_recp_frm_fw() (Ivan Vecera) [2062343]
- ice: Fix clang -Wimplicit-fallthrough in ice_pull_qvec_from_rc() (Ivan Vecera) [2062343]
- ice: Add support to print error on PHY FW load failure (Ivan Vecera) [2062343]
- ice: Add support for changing MTU on PR in switchdev mode (Ivan Vecera) [2062343]
- ice: send correct vc status in switchdev (Ivan Vecera) [2062343]
- ice: support for GRE in eswitch (Ivan Vecera) [2062343]
- ice: low level support for tunnels (Ivan Vecera) [2062343]
- ice: VXLAN and Geneve TC support (Ivan Vecera) [2062343]
- ice: support for indirect notification (Ivan Vecera) [2062343]
- ice: Add tc-flower filter support for channel (Ivan Vecera) [2062343]
- ice: enable ndo_setup_tc support for mqprio_qdisc (Ivan Vecera) [2062343]
- ice: Add infrastructure for mqprio support via ndo_setup_tc (Ivan Vecera) [2062343]
- ice: fix an error code in ice_ena_vfs() (Ivan Vecera) [2062343]
- ice: use devm_kcalloc() instead of devm_kzalloc() (Ivan Vecera) [2062343]
- ice: Make use of the helper function devm_add_action_or_reset() (Ivan Vecera) [2062343]
- ice: Refactor PR ethtool ops (Ivan Vecera) [2062343]
- ice: Forbid trusted VFs in switchdev mode (Ivan Vecera) [2062343]
- ice: Manage act flags for switchdev offloads (Ivan Vecera) [2062343]
- ice: introduce XDP_TX fallback path (Ivan Vecera) [2062343]
- ice: optimize XDP_TX workloads (Ivan Vecera) [2062343]
- ice: propagate xdp_ring onto rx_ring (Ivan Vecera) [2062343]
- ice: do not create xdp_frame on XDP_TX (Ivan Vecera) [2062343]
- ice: unify xdp_rings accesses (Ivan Vecera) [2062343]
- ice: ndo_setup_tc implementation for PR (Ivan Vecera) [2062343]
- ice: ndo_setup_tc implementation for PF (Ivan Vecera) [2062343]
- ice: Allow changing lan_en and lb_en on all kinds of filters (Ivan Vecera) [2062343]
- ice: cleanup rules info (Ivan Vecera) [2062343]
- ice: allow deleting advanced rules (Ivan Vecera) [2062343]
- ice: allow adding advanced rules (Ivan Vecera) [2062343]
- ice: create advanced switch recipe (Ivan Vecera) [2062343]
- ice: manage profiles and field vectors (Ivan Vecera) [2062343]
- ice: implement low level recipes functions (Ivan Vecera) [2062343]
- ice: add port representor ethtool ops and stats (Ivan Vecera) [2062343]
- ice: switchdev slow path (Ivan Vecera) [2062343]
- ice: rebuild switchdev when resetting all VFs (Ivan Vecera) [2062343]
- ice: enable/disable switchdev when managing VFs (Ivan Vecera) [2062343]
- ice: introduce new type of VSI for switchdev (Ivan Vecera) [2062343]
- ice: set and release switchdev environment (Ivan Vecera) [2062343]
- net: export metadata_dst_free() (Ivan Vecera) [2062343]
- ice: allow changing lan_en and lb_en on dflt rules (Ivan Vecera) [2062343]
- ice: manage VSI antispoof and destination override (Ivan Vecera) [2062343]
- ice: allow process VF opcodes in different ways (Ivan Vecera) [2062343]
- ice: introduce VF port representor (Ivan Vecera) [2062343]
- ice: Move devlink port to PF/VF struct (Ivan Vecera) [2062343]
- ice: support basic E-Switch mode control (Ivan Vecera) [2062343]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ivan Vecera) [2062343]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2062343]
- ice: Use xdp_buf instead of rx_buf for xsk zero-copy (Ivan Vecera) [2062343]
- ice: fix FDIR init missing when reset VF (Ivan Vecera) [2062343]
- intel: Remove rcu_read_lock() around XDP program invocation (Ivan Vecera) [2062343]
- intel: Update drivers to use ethtool_sprintf (Ivan Vecera) [2062343]
- ice: fix conversion to new udp_tunnel infrastructure (Ivan Vecera) [2062343]
- intel-ethernet: clean up W=1 warnings in kdoc (Ivan Vecera) [2062343]
- PCI: Use 'pci_channel_state_t' instead of 'enum pci_channel_state' (Ivan Vecera) [2062343]
- treewide: Use sizeof_field() macro (Ivan Vecera) [2062343]
- devlink: Add 'enable_iwarp' generic device param (Ivan Vecera) [2062343]
- devlink: Add new "enable_vnet" generic device param (Ivan Vecera) [2062343]
- devlink: Add new "enable_rdma" generic device param (Ivan Vecera) [2062343]
- devlink: Add new "enable_eth" generic device param (Ivan Vecera) [2062343]
- gfs2: dequeue iopen holder in gfs2_inode_lookup error (Bob Peterson) [2061665]
- redhat/configs: Increase CONFIG_LOCKDEP_CHAINS_BITS from 16 to 17 (Waiman Long) [2057339]
- redhat: spec: trigger dracut when modules are installed separately (Jan Stancek) [2060237 2016948]

* Wed Mar 23 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-375.el8]
- makefile: Add dist-* targets (Prarit Bhargava)
- Fonts: Replace discarded const qualifier (Nico Pache) [1904374]
- Fonts: Support FONT_EXTRA_WORDS macros for built-in fonts (Nico Pache) [1904374]
- fbdev, newport_con: Move FONT_EXTRA_WORDS macros into linux/font.h (Nico Pache) [1904374]
- x86/cpu: Drop spurious underscore from RAPTOR_LAKE #define (Prarit Bhargava) [2040021]
- x86/cpu: Add Raptor Lake to Intel family (Prarit Bhargava) [2040021]
- powerpc/64: Move paca allocation later in boot (Desnes A. Nunes do Rosario) [2016335]
- powerpc/prom: fix early DEBUG messages (Desnes A. Nunes do Rosario) [2016335]
- powerpc: Set crashkernel offset to mid of RMA region (Desnes A. Nunes do Rosario) [2016335]
- KVM: x86/mmu: Don't advance iterator after restart due to yielding (Nico Pache) [2058907]
- igb: refactor XDP registration (Corinna Vinschen) [2040171]
- igc: avoid kernel warning when changing RX ring parameters (Corinna Vinschen) [2040171]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Nilesh Javali) [2054565]
- EDAC/amd64: Save max number of controllers for F19 M70 (Aristeu Rozanski) [2064285]
- CI: Use 8.6-rt branch for rhel8 realtime_check (Chris White)
- blk-mq: avoid extending delays of active hctx from blk_mq_delay_run_hw_queues (Ming Lei) [2046525]
- tipc: fix incorrect order of state message data sanity check (Xin Long) [2048971]
- tipc: improve size validations for received domain records (Xin Long) [2048971] {CVE-2022-0435}
- efi/x86: Call efi_parse_options() from efi_main() (Lenny Szubowicz) [2049233]

* Mon Mar 21 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-374.el8]
- net/mlx5e: TC, Remove redundant error logging (Amir Tzin) [2023907]
- net/mlx5: DR, Warn on failure to destroy objects due to refcount (Amir Tzin) [2022325]
- net/mlx5: DR, Add support for dumping steering info (Amir Tzin) [2022325]
- net/mlx5: DR, Add missing reserved fields to dr_match_param (Amir Tzin) [2022325]
- net/mlx5: DR, Add check for flex parser ID value (Amir Tzin) [2022325]
- net/mlx5: DR, Rename list field in matcher struct to list_node (Amir Tzin) [2022325]
- net/mlx5: DR, Remove unused struct member in matcher (Amir Tzin) [2022325]
- net/mlx5: DR, Fix error flow in creating matcher (Amir Tzin) [2022325]
- net/mlx5e: Avoid implicit modify hdr for decap drop rule (Amir Tzin) [2015434]
- net/mlx5e: TC, Fix memory leak with rules with internal port (Amir Tzin) [2015434]
- net/mlx5e: Fix skb memory leak when TC classifier action offloads are disabled (Amir Tzin) [2015434]
- net/mlx5: Fix some error handling paths in 'mlx5e_tc_add_fdb_flow()' (Amir Tzin) [2015434]
- net/mlx5: E-Switch, Check group pointer before reading bw_share value (Amir Tzin) [2015434]
- net/mlx5: E-Switch, fix single FDB creation on BlueField (Amir Tzin) [2015434]
- net/mlx5: E-switch, Respect BW share of the new group (Amir Tzin) [2015434]
- net/mlx5: DR, Fix check for unsupported fields in match param (Amir Tzin) [2015434]
- net/mlx5: E-Switch, rebuild lag only when needed (Amir Tzin) [2015434]
- net/mlx5e: Delete forward rule for ct or sample action (Amir Tzin) [2015434]
- net/mlx5: E-Switch, Use indirect table only if all destinations support it (Amir Tzin) [2015434]
- net/mlx5: Support internal port as decap route device (Amir Tzin) [2015434]
- net/mlx5e: Term table handling of internal port rules (Amir Tzin) [2015434]
- net/mlx5e: Add indirect tc offload of ovs internal port (Amir Tzin) [2015434]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Amir Tzin) [2015434]
- net/mlx5e: Offload internal port as encap route device (Amir Tzin) [2015434]
- net/mlx5e: Offload tc rules that redirect to ovs internal port (Amir Tzin) [2015434]
- net/mlx5e: Accept action skbedit in the tc actions list (Amir Tzin) [2015434]
- net/mlx5: E-Switch, Add ovs internal port mapping to metadata support (Amir Tzin) [2015434]
- net/mlx5e: Use generic name for the forwarding dev pointer (Amir Tzin) [2015434]
- net/mlx5e: Refactor rx handler of represetor device (Amir Tzin) [2015434]
- net/mlx5: DR, Add check for unsupported fields in match param (Amir Tzin) [2015434]
- net/mlx5: Allow skipping counter refresh on creation (Amir Tzin) [2015434]
- net/mlx5e: IPsec: Refactor checksum code in tx data path (Amir Tzin) [2015434]
- net/mlx5: CT: Remove warning of ignore_flow_level support for VFs (Amir Tzin) [2015434]
- net/mlx5: Add esw assignment back in mlx5e_tc_sample_unoffload() (Amir Tzin) [2015434]
- net/mlx5: Bridge, fix uninitialized variable usage (Amir Tzin) [2015434]
- net/mlx5: Lag, don't update lag if lag isn't supported (Amir Tzin) [2015434]
- net/mlx5: E-switch, Return correct error code on group creation failure (Amir Tzin) [2015434]
- net/mlx5: Bridge, support LAG (Amir Tzin) [2015434]
- net/mlx5: Bridge, allow merged eswitch connectivity (Amir Tzin) [2015434]
- net/mlx5: Bridge, extract FDB delete notification to function (Amir Tzin) [2015434]
- net/mlx5: Bridge, identify port by vport_num+esw_owner_vhca_id pair (Amir Tzin) [2015434]
- net/mlx5: Bridge, obtain core device from eswitch instead of priv (Amir Tzin) [2015434]
- net/mlx5: Bridge, release bridge in same function where it is taken (Amir Tzin) [2015434]
- net/mlx5: Lag, Create shared FDB when in switchdev mode (Amir Tzin) [2015434]
- net/mlx5: E-Switch, add logic to enable shared FDB (Amir Tzin) [2015434]
- net/mlx5: Lag, properly lock eswitch if needed (Amir Tzin) [2015434]
- net/mlx5: Add send to vport rules on paired device (Amir Tzin) [2015434]
- net/mlx5: E-Switch, Add event callback for representors (Amir Tzin) [2015434]
- net/mlx5e: Use shared mappings for restoring from metadata (Amir Tzin) [2015434]
- net/mlx5e: Add an option to create a shared mapping (Amir Tzin) [2015434]
- net/mlx5: E-Switch, set flow source for send to uplink rule (Amir Tzin) [2015434]
- RDMA/mlx5: Add shared FDB support (Amir Tzin) [2015434]
- {net, RDMA}/mlx5: Extend send to vport rules (Amir Tzin) [2015434]
- RDMA/mlx5: Fill port info based on the relevant eswitch (Amir Tzin) [2015434]
- net/mlx5: Lag, add initial logic for shared FDB (Amir Tzin) [2015434]
- net/mlx5: Return mdev from eswitch (Amir Tzin) [2015434]
- net/mlx5: E-switch, Add QoS tracepoints (Amir Tzin) [2015434]
- net/mlx5: E-switch, Allow to add vports to rate groups (Amir Tzin) [2015434]
- net/mlx5: E-switch, Allow setting share/max tx rate limits of rate groups (Amir Tzin) [2015434]
- net/mlx5: E-switch, Introduce rate limiting groups API (Amir Tzin) [2015434]
- net/mlx5: E-switch, Enable devlink port tx_{share|max} rate control (Amir Tzin) [2015434]
- net/mlx5: E-switch, Move QoS related code to dedicated file (Amir Tzin) [2015434]
- net/mlx5e: TC, Support sample offload action for tunneled traffic (Amir Tzin) [2015434]
- net/mlx5e: TC, Restore tunnel info for sample offload (Amir Tzin) [2015434]
- net/mlx5e: TC, Remove CONFIG_NET_TC_SKB_EXT dependency when restoring tunnel (Amir Tzin) [2015434]
- net/mlx5e: Refactor ct to use post action infrastructure (Amir Tzin) [2015434]
- net/mlx5e: Introduce post action infrastructure (Amir Tzin) [2015434]
- net/mlx5e: CT, Use xarray to manage fte ids (Amir Tzin) [2015434]
- net/mlx5e: Move sample attribute to flow attribute (Amir Tzin) [2015434]
- net/mlx5e: Move esw/sample to en/tc/sample (Amir Tzin) [2015434]
- net/mlx5e: Remove mlx5e dependency from E-Switch sample (Amir Tzin) [2015434]
- net/mlx5: DR, Fix querying eswitch manager vport for ECPF (Amir Tzin) [2018097]
- net/mlx5: DR, Handle eswitch manager and uplink vports separately (Amir Tzin) [2018097]
- net/mlx5: DR, Add missing string for action type SAMPLER (Amir Tzin) [2018097]
- net/mlx5: DR, init_next_match only if needed (Amir Tzin) [2018097]
- net/mlx5: DR, Increase supported num of actions to 32 (Amir Tzin) [2018097]
- net/mlx5: DR, Add support for SF vports (Amir Tzin) [2018097]
- net/mlx5: DR, Support csum recalculation flow table on SFs (Amir Tzin) [2018097]
- net/mlx5: DR, Align error messages for failure to obtain vport caps (Amir Tzin) [2018097]
- net/mlx5: DR, Add missing query for vport 0 (Amir Tzin) [2018097]
- net/mlx5: DR, Replace local WIRE_PORT macro with the existing MLX5_VPORT_UPLINK (Amir Tzin) [2018097]
- scsi: lpfc: Fix pt2pt NVMe PRLI reject LOGO loop (Dick Kennedy) [1943202]
- nvme-tcp: change target from tech-preview to unmaintained (John Meneghini) [2061577]
- drm/amd/display: Don't reinitialize DMCUB on s0ix resume (Karol Herbst) [2059680]
- tcp: Add snd_wnd to TCP_INFO (Davide Caratti) [2056608]
- tcp: Add TCP_INFO counter for packets received out-of-order (Davide Caratti) [2056608]
- net/mlx5: Move MODIFY_RQT command to ignore list in internal error state (Amir Tzin) [1982236]
- net/mlx5e: Add TX max rate support for MQPRIO channel mode (Amir Tzin) [1982236]
- net/mlx5e: Specify SQ stats struct for mlx5e_open_txqsq() (Amir Tzin) [1982236]
- net/mlx5e: Allow only complete TXQs partition in MQPRIO channel mode (Amir Tzin) [1982236]
- net/mlx5e: Mutually exclude setting of TX-port-TS and MQPRIO in channel mode (Amir Tzin) [1982236]
- net/mlx5e: Fix condition when retrieving PTP-rqn (Amir Tzin) [1982236]
- net/mlx5: Fix inner TTC table creation (Amir Tzin) [1982236]
- net/mlx5e: Fix division by 0 in mlx5e_select_queue for representors (Amir Tzin) [1982236]
- net/mlx5e: Improve MQPRIO resiliency (Amir Tzin) [1982236]
- net/mlx5e: Support MQPRIO channel mode (Amir Tzin) [1982236]
- net/mlx5e: Handle errors of netdev_set_num_tc() (Amir Tzin) [1982236]
- net/mlx5e: Maintain MQPRIO mode parameter (Amir Tzin) [1982236]
- net/mlx5e: Abstract MQPRIO params (Amir Tzin) [1982236]
- net/mlx5e: Support flow classification into RSS contexts (Amir Tzin) [1982236]
- net/mlx5e: Support multiple RSS contexts (Amir Tzin) [1982236]
- net/mlx5e: Dynamically allocate TIRs in RSS contexts (Amir Tzin) [1982236]
- net/mlx5e: Convert RSS to a dedicated object (Amir Tzin) [1982236]
- net/mlx5e: Introduce abstraction of RSS context (Amir Tzin) [1982236]
- net/mlx5e: Introduce TIR create/destroy API in rx_res (Amir Tzin) [1982236]
- net/mlx5e: Do not try enable RSS when resetting indir table (Amir Tzin) [1982236]
- net/mlx5: Embed mlx5_ttc_table (Amir Tzin) [1982236]
- net/mlx5: Move TTC logic to fs_ttc (Amir Tzin) [1982236]
- net/mlx5e: Decouple TTC logic from mlx5e (Amir Tzin) [1982236]
- net/mlx5e: Rename some related TTC args and functions (Amir Tzin) [1982236]
- net/mlx5e: Rename traffic type enums (Amir Tzin) [1982236]
- net/mlx5e: Allocate the array of channels according to the real max_nch (Amir Tzin) [1982236]
- net/mlx5e: Hide all implementation details of mlx5e_rx_res (Amir Tzin) [1982236]
- net/mlx5e: Introduce mlx5e_channels API to get RQNs (Amir Tzin) [1982236]
- net/mlx5e: Use a new initializer to build uniform indir table (Amir Tzin) [1982236]
- net/mlx5e: Use the new TIR API for kTLS (Amir Tzin) [1982236]
- net/mlx5e: Move management of indir traffic types to rx_res (Amir Tzin) [1982236]
- net/mlx5e: Convert TIR to a dedicated object (Amir Tzin) [1982236]
- net/mlx5e: Create struct mlx5e_rss_params_hash (Amir Tzin) [1982236]
- net/mlx5e: Remove mdev from mlx5e_build_indir_tir_ctx_common() (Amir Tzin) [1982236]
- net/mlx5e: Remove lro_param from mlx5e_build_indir_tir_ctx_common() (Amir Tzin) [1982236]
- net/mlx5e: Remove mlx5e_priv usage from mlx5e_build_*tir_ctx*() (Amir Tzin) [1982236]
- net/mlx5e: Use mlx5e_rqt_get_rqtn to access RQT hardware id (Amir Tzin) [1982236]
- net/mlx5e: Take RQT out of TIR and group RX resources (Amir Tzin) [1982236]
- net/mlx5e: Move RX resources to a separate struct (Amir Tzin) [1982236]
- net/mlx5e: Move mlx5e_build_rss_params() call to init_rx (Amir Tzin) [1982236]
- net/mlx5e: Convert RQT to a dedicated object (Amir Tzin) [1982236]
- net/mlx5e: Check if inner FT is supported outside of create/destroy functions (Amir Tzin) [1982236]
- net/mlx5: Take TIR destruction out of the TIR list lock (Amir Tzin) [1982236]
- PCI: pciehp: Ignore Link Down/Up caused by error-induced Hot Reset (Myron Stowe) [2060122]
- PCI/portdrv: Rename pm_iter() to pcie_port_device_iter() (Myron Stowe) [2060122]
- iommu/vt-d: Fix double list_add when enabling VMD in scalable mode (Jerry Snitselaar) [2062094]
- redhat/configs: Disable CONFIG_SENSORS_NCT6683 in RHEL for arm/aarch64 (Dean Nelson) [2059695]
- redhat: drop the -sha512 suffix from default rhpkg invocation (Jarod Wilson)
- sysctl: return -EINVAL if val violates minmax (Rafael Aquini) [2062571]
- kernel/sysctl.c: switch to bitmap_zalloc() (Rafael Aquini) [2062571]
- netlabel: remove unused parameter in netlbl_netlink_auditinfo() (William Zhao) [1985319]
- netlabel: Fix memory leak in netlbl_mgmt_add_common (William Zhao) [1985319]
- bpftool: Fix indent in option lists in the documentation (Yauheni Kaliuta) [2014861]
- libbpf: Fix memleak in libbpf_netlink_recv() (Yauheni Kaliuta) [2014861]
- libbpf: Use dynamically allocated buffer when receiving netlink messages (Yauheni Kaliuta) [2014861]
- libbpf: Clean gen_loader's attach kind. (Yauheni Kaliuta) [2014861]
- powerpc/bpf: Use bctrl for making function calls (Jiri Olsa) [2014861]
- powerpc/signal: Use PPC_RAW_xx() macros (Jiri Olsa) [2014861]
- powerpc/ebpf64: Use PPC_RAW_MFLR() (Jiri Olsa) [2014861]
- powerpc/opcodes: Add shorter macros for registers for use with PPC_RAW_xx() (Jiri Olsa) [2014861]
- lib/test: fix spelling mistakes (Jiri Olsa) [2014861]
- tracepoint: Add tracepoint_probe_register_may_exist() for BPF tracing (Jiri Olsa) [2014861]
- bpf: Allow bpf_get_current_ancestor_cgroup_id for tracing (Jiri Olsa) [2014861]
- docs: bpf: bpf_lsm.rst: avoid using ReST :doc:`foo` markup (Jiri Olsa) [2014861]
- bpf, docs: Add llvm_reloc.rst to explain llvm bpf relocations (Jiri Olsa) [2014861]
- bpf, arm64: Remove redundant switch case about BPF_DIV and BPF_MOD (Jiri Olsa) [2014861]
- bpf, arm64: Replace STACK_ALIGN() with round_up() to align stack size (Jiri Olsa) [2014861]
- selftests, bpf: Test that dead ldx_w insns are accepted (Jiri Olsa) [2014861]
- bpf, selftests: Add test cases for pointer alu from multiple paths (Jiri Olsa) [2014861]
- bpf: Selftest to verify mixing bpf2bpf calls and tailcalls with insn patch (Jiri Olsa) [2014861]
- selftests/bpf: Fix ringbuf test fetching map FD (Jiri Olsa) [2014861]
- selftests/bpf: Whitelist test_progs.h from .gitignore (Jiri Olsa) [2014861]
- selftests, bpf: Make docs tests fail more reliably (Jiri Olsa) [2014861]
- selftests/bpf: Turn on libbpf 1.0 mode and fix all IS_ERR checks (Jiri Olsa) [2014861]
- selftests/bpf: Add bpf_lookup_and_delete_elem tests (Jiri Olsa) [2014861]
- selftests/bpf: Convert test trace_printk to lskel. (Jiri Olsa) [2014861]
- selftests/bpf: Convert test printk to use rodata. (Jiri Olsa) [2014861]
- selftests/bpf: Convert atomics test to light skeleton. (Yauheni Kaliuta) [2014861]
- selftests/bpf: Convert few tests to light skeleton. (Jiri Olsa) [2014861]
- selftests/bpf: Test for btf_load command. (Jiri Olsa) [2014861]
- selftests/bpf: Test for syscall program type (Jiri Olsa) [2014861]
- libbpf: Add selftests for TC-BPF management API (Jiri Olsa) [2014861]
- selftests/bpf: Validate skeleton gen handles skipped fields (Jiri Olsa) [2014861]
- selftests/bpf: Stop using static variables for passing data to/from user-space (Jiri Olsa) [2014861]
- tools: bpftool: Document and add bash completion for -L, -B options (Jiri Olsa) [2014861]
- tools: bpftool: Update and synchronise option list in doc and help msg (Jiri Olsa) [2014861]
- bpftool: Remove unused includes to <bpf/bpf_gen_internal.h> (Jiri Olsa) [2014861]
- powerpc/bpf: Fix write protecting JIT code (Jiri Olsa) [2014861]
- libbpf: Fix lookup_and_delete_elem_flags error reporting (Jiri Olsa) [2014861]
- bpftool: Check malloc return value in mount_bpffs_for_pin (Jiri Olsa) [2014861]
- tools: bpf: Fix error in 'make -C tools/ bpf_install' (Jiri Olsa) [2014861]
- bpftool: Properly close va_list 'ap' by va_end() on error (Jiri Olsa) [2014861]
- bpf: Fix libelf endian handling in resolv_btfids (Jiri Olsa) [2014861]
- tools/bpftool: Fix error return code in do_batch() (Jiri Olsa) [2014861]
- tools/bpftool: Fix cross-build (Jiri Olsa) [2014861]
- bpftool: Set errno on skeleton failures and propagate errors (Jiri Olsa) [2014861]
- bpftool: Use syscall/loader program in "prog load" and "gen skeleton" command. (Jiri Olsa) [2014861]
- bpftool: Stop emitting static variables in BPF skeleton (Jiri Olsa) [2014861]
- bpftool: Strip const/volatile/restrict modifiers from .bss and .data vars (Jiri Olsa) [2014861]
- bpf: Add missing bpf_read_[un]lock_trace() for syscall program (Jiri Olsa) [2014861]
- libbpf: Fix skel_internal.h to set errno on loader retval < 0 (Jiri Olsa) [2014861]
- libbpf: Fix segfault in light skeleton for objects without BTF (Jiri Olsa) [2014861]
- libbpf: Return non-null error on failures in libbpf_find_prog_btf_id() (Jiri Olsa) [2014861]
- libbpf, doc: Eliminate warnings in libbpf_naming_convention (Jiri Olsa) [2014861]
- net, core: Allow netdev_lower_get_next_private_rcu in bh context (Jiri Olsa) [2014861]
- samples/bpf: Fix the error return code of xdp_redirect's main() (Jiri Olsa) [2014861]
- samples/bpf: Fix Segmentation fault for xdp_redirect command (Jiri Olsa) [2014861]
- samples/bpf: Add missing option to xdp_sample_pkts usage (Jiri Olsa) [2014861]
- samples/bpf: Add missing option to xdp_fwd usage (Jiri Olsa) [2014861]
- samples, bpf: Suppress compiler warning (Jiri Olsa) [2014861]
- file: Rename __close_fd to close_fd and remove the files parameter (Jiri Olsa) [2014861]
- bpf: Fix ringbuf helper function compatibility (Jiri Olsa) [2014861]
- bpf: Clear zext_dst of dead insns (Jiri Olsa) [2014861]
- bpf: Add rcu_read_lock in bpf_get_current_[ancestor_]cgroup_id() helpers (Jiri Olsa) [2014861]
- bpf, core: Fix kernel-doc notation (Jiri Olsa) [2014861]
- libbpf: Do not close un-owned FD 0 on errors (Jiri Olsa) [2014861]
- libbpf: Fix probe for BPF_PROG_TYPE_CGROUP_SOCKOPT (Jiri Olsa) [2014861]
- s390/bpf: Perform r1 range checking before accessing jit->seen_reg[r1] (Jiri Olsa) [2014861]
- libbpf: Restore errno return for functions that were already returning it (Jiri Olsa) [2014861]
- powerpc/bpf: Write protect JIT code (Jiri Olsa) [2014861]
- powerpc/bpf: Remove bpf_jit_free() (Jiri Olsa) [2014861]
- bpf: Fix integer overflow in argument calculation for bpf_map_area_alloc (Jiri Olsa) [2014861]
- bpf: Fix false positive kmemleak report in bpf_ringbuf_area_alloc() (Jiri Olsa) [2014861]
- bpf: Allow RCU-protected lookups to happen from bh context (Jiri Olsa) [2014861]
- bpf, x86: Remove unused cnt increase from EMIT macro (Jiri Olsa) [2014861]
- libbpf: Switch to void * casting in netlink helpers (Jiri Olsa) [2014861]
- libbpf: Add request buffer type for netlink messages (Jiri Olsa) [2014861]
- libbpf: Add extra BPF_PROG_TYPE check to bpf_object__probe_loading (Jiri Olsa) [2014861]
- bpf: Add documentation for libbpf including API autogen (Jiri Olsa) [2014861]
- bpf: Fix up register-based shifts in interpreter to silence KUBSAN (Jiri Olsa) [2014861]
- libbpf: Fail compilation if target arch is missing (Jiri Olsa) [2014861]
- bpf: Fix typo in kernel/bpf/bpf_lsm.c (Jiri Olsa) [2014861]
- bpf: Support BPF_FUNC_get_socket_cookie() for BPF_PROG_TYPE_SK_REUSEPORT. (Jiri Olsa) [2014861]
- libbpf: Set NLM_F_EXCL when creating qdisc (Jiri Olsa) [2014861]
- libbpf: Remove unneeded check for flags during tc detach (Jiri Olsa) [2014861]
- libbpf: Simplify the return expression of bpf_object__init_maps function (Jiri Olsa) [2014861]
- libbpf: Fix pr_warn type warnings on 32bit (Jiri Olsa) [2014861]
- libbpf: Install skel_internal.h header used from light skeletons (Jiri Olsa) [2014861]
- libbpf: Refactor header installation portions of Makefile (Jiri Olsa) [2014861]
- libbpf: Move few APIs from 0.4 to 0.5 version (Jiri Olsa) [2014861]
- bpf, tnums: Provably sound, faster, and more precise algorithm for tnum_mul (Jiri Olsa) [2014861]
- libbpf: Move BPF_SEQ_PRINTF and BPF_SNPRINTF to bpf_helpers.h (Jiri Olsa) [2014861]
- libbpf: Streamline error reporting for high-level APIs (Jiri Olsa) [2014861]
- libbpf: Streamline error reporting for low-level APIs (Jiri Olsa) [2014861]
- libbpf: Add libbpf_set_strict_mode() API to turn on libbpf 1.0 behaviors (Jiri Olsa) [2014861]
- bpf: Fix spelling mistakes (Jiri Olsa) [2014861]
- bpf: Extend libbpf with bpf_map_lookup_and_delete_elem_flags (Jiri Olsa) [2014861]
- bpf: Add lookup_and_delete_elem support to hashtab (Jiri Olsa) [2014861]
- libbpf: Skip bpf_object__probe_loading for light skeleton (Jiri Olsa) [2014861]
- bpf: Make some symbols static (Jiri Olsa) [2014861]
- bpf: Add cmd alias BPF_PROG_RUN (Jiri Olsa) [2014861]
- libbpf: Introduce bpf_map__initial_value(). (Jiri Olsa) [2014861]
- libbpf: Cleanup temp FDs when intermediate sys_bpf fails. (Jiri Olsa) [2014861]
- libbpf: Generate loader program out of BPF ELF file. (Jiri Olsa) [2014861]
- libbpf: Preliminary support for fd_idx (Jiri Olsa) [2014861]
- libbpf: Add bpf_object pointer to kernel_supports(). (Jiri Olsa) [2014861]
- libbpf: Change the order of data and text relocations. (Jiri Olsa) [2014861]
- bpf: Add bpf_sys_close() helper. (Jiri Olsa) [2014861]
- bpf: Add bpf_btf_find_by_name_kind() helper. (Jiri Olsa) [2014861]
- bpf: Introduce fd_idx (Jiri Olsa) [2014861]
- bpf: Make btf_load command to be bpfptr_t compatible. (Jiri Olsa) [2014861]
- libbpf: Support for syscall program type (Jiri Olsa) [2014861]
- bpf: Prepare bpf syscall to be used from kernel and user space. (Jiri Olsa) [2014861]
- bpf: Introduce bpfptr_t user/kernel pointer. (Jiri Olsa) [2014861]
- bpf: Introduce bpf_sys_bpf() helper and program type. (Jiri Olsa) [2014861]
- libbpf: Add low level TC-BPF management API (Jiri Olsa) [2014861]
- libbpf: Add various netlink helpers (Jiri Olsa) [2014861]
- libbpf: Reject static entry-point BPF programs (Jiri Olsa) [2014861]
- libbpf: Reject static maps (Jiri Olsa) [2014861]
- libbpf: Treat STV_INTERNAL same as STV_HIDDEN for functions (Jiri Olsa) [2014861]
- libbpf: Add per-file linker opts (Jiri Olsa) [2014861]
- bpf: verifier: Use copy_array for jmp_history (Jiri Olsa) [2014861]
- bpf: verifier: Improve function state reallocation (Jiri Olsa) [2014861]

* Thu Mar 17 2022 Jarod Wilson <jarod@redhat.com> [4.18.0-373.el8]
- ice: fix getting UDP tunnel entry (Jonathan Toppins) [2015409]
- ice: convert to new udp_tunnel infrastructure (Jonathan Toppins) [2015409]
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2050807]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2050807] {CVE-2022-0516}
- lib/iov_iter: initialize "flags" in new pipe_buffer (Jan Stancek) [2060875] {CVE-2022-0847}
- fget: clarify and improve __fget_files() implementation (Patrick Talbert) [2032303]
- fget: check that the fd still exists after getting a ref to it (Patrick Talbert) [2032303] {CVE-2021-4083}
- drm/ast: Create threshold values for AST2600 (Jocelyn Falempe) [2053358]
- cgroup-v1: Correct privileges check in release_agent writes (Waiman Long) [2052167]
- cgroup-v1: Require capabilities to set release_agent (Waiman Long) [2052167] {CVE-2022-0492}
- spec: Fix separate tools build (Yauheni Kaliuta) [2056301]
- net/mlx5: DR, Add support for update FTE (Amir Tzin) [2047231]
- net/mlx5: DR, Improve rule tracking memory consumption (Amir Tzin) [2047231]
- net/mlx5: DR, Remove rehash ctrl struct from dr_htbl (Amir Tzin) [2047231]
- net/mlx5: DR, Remove HW specific STE type from nic domain (Amir Tzin) [2047231]
- net/mlx5: DR, Merge DR_STE_SIZE enums (Amir Tzin) [2047231]
- net/mlx5: DR, Skip source port matching on FDB RX domain (Amir Tzin) [2047231]
- net/mlx5: DR, Add ignore_flow_level support for multi-dest flow tables (Amir Tzin) [2047231]
- net/mlx5: DR, replace uintN_t with kernel-style types (Amir Tzin) [2047231]
- net/mlx5: DR, Support IPv6 matching on flow label for STEv0 (Amir Tzin) [2047231]
- net/mlx5: DR, Reduce print level for FT chaining level check (Amir Tzin) [2047231]
- net/mlx5: DR, Warn and ignore SW steering rule insertion on QP err (Amir Tzin) [2047231]
- net/mlx5: DR, Improve error flow in actions_build_ste_arr (Amir Tzin) [2047231]
- net/mlx5: DR, Enable QP retransmission (Amir Tzin) [2047231]
- net/mlx5: DR, Enable VLAN pop on TX and VLAN push on RX (Amir Tzin) [2047231]
- net/mlx5: DR, Split modify VLAN state to separate pop/push states (Amir Tzin) [2047231]
- net/mlx5: DR, Added support for REMOVE_HEADER packet reformat (Amir Tzin) [2047231]
- net/mlx4_en: Resolve bad operstate value (Amir Tzin) [1982190]
- net/mlx4_en: Fix an use-after-free bug in mlx4_en_try_alloc_resources() (Amir Tzin) [1982190]
- RDMA/mlx4: Do not fail the registration on port stats (Amir Tzin) [1982190]
- RDMA/mlx4: Return missed an error if device doesn't support steering (Amir Tzin) [1982190]
- net/mlx4_en: Don't allow aRFS for encapsulated packets (Amir Tzin) [1982190]
- mlx4: Fix missing error code in mlx4_load_one() (Amir Tzin) [1982190]
- net/mlx4: Fix fall-through warning for Clang (Amir Tzin) [1982190]
- mlx4: Remove rcu_read_lock() around XDP program invocation (Amir Tzin) [1982190]
- IB/mlx4: Avoid field-overflowing memcpy() (Amir Tzin) [1982190]
- RDMA/mlx4: Do not map the core_clock page to user space unless enabled (Amir Tzin) [1982190]
- net/mlx4: Treat VFs fair when handling comm_channel_events (Amir Tzin) [1982190]
- RDMA/mlx4: Remove an unused variable (Amir Tzin) [1982190]
- megaraid_sas: Add new messaging - a fix (Tomas Henzl) [2055248]
- HID: amd_sfh: Add interrupt handler to process interrupts (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Add functionality to clear interrupts (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Disable the interrupt for all command (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Correct the structure field name (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Handle amd_sfh work buffer in PM ops (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Add illuminance mask to limit ALS max value (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Increase sensor command timeout (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Update Copyright details (Benjamin Tissoires) [2054929]
- HID: amd_sfh: switch from 'pci_' to 'dev_' API (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Use dma_set_mask_and_coherent() (Benjamin Tissoires) [2054929]
- HID: amd_sfh: switch from 'pci_' to 'dma_' API (Benjamin Tissoires) [2054929]
- dm stats: fix too short end duration_ns when using precise_timestamps (Benjamin Marzinski) [2057166]
- dm: fix double accounting of flush with data (Benjamin Marzinski) [2057166]
- dm: interlock pending dm_io and dm_wait_for_bios_completion (Benjamin Marzinski) [2057166]
- x86/MCE/AMD, EDAC/mce_amd: Support non-uniform MCA bank type enumeration (Aristeu Rozanski) [2050410 2048786 2050412]
- x86/MCE/AMD, EDAC/mce_amd: Add new SMCA bank types (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC/amd64: Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC: Add RDDR5 and LRDDR5 memory types (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC/amd64: Handle three rank interleaving mode (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC/amd64: Set proper family type for Family 19h Models 20h-2Fh (Aristeu Rozanski) [2050410 2048786 2050412]
- netfilter: nf_queue: handle socket prefetch (Florian Westphal) [2009786]
- netfilter: nf_queue: fix possible use-after-free (Florian Westphal) [2009786]
- selftests: netfilter: add nfqueue TCP_NEW_SYN_RECV socket race test (Florian Westphal) [2009786]
- netfilter: nf_queue: don't assume sk is full socket (Florian Westphal) [2009786]
- Enable HSA_AMD_SVM config (Donald Dutile) [2025123]
- mm/memremap_pages: support multiple ranges per invocation (Donald Dutile) [2025123]
- mm/memremap_pages: convert to 'struct range' (Donald Dutile) [2025123]
- device-dax: add an allocation interface for device-dax instances (Donald Dutile) [2025123]
- device-dax: make pgmap optional for instance creation (Donald Dutile) [2025123]
- device-dax: move instance creation parameters to 'struct dev_dax_data' (Donald Dutile) [2025123]
- device-dax: drop the dax_region.pfn_flags attribute (Donald Dutile) [2025123]
- memremap: rename MEMORY_DEVICE_DEVDAX to MEMORY_DEVICE_GENERIC (Donald Dutile) [2025123]
- PCI/P2PDMA: Introduce private pagemap structure (Donald Dutile) [2025123]
- security: implement sctp_assoc_established hook in selinux (Ondrej Mosnacek) [2015525 2048251]
- security: add sctp_assoc_established hook (Ondrej Mosnacek) [2015525 2048251]
- security: call security_sctp_assoc_request in sctp_sf_do_5_1D_ce (Ondrej Mosnacek) [2015525 2048251]
- security: pass asoc to sctp_assoc_request and sctp_sk_clone (Ondrej Mosnacek) [2015525 2048251]
- net: sctp: Fix some typos (Ondrej Mosnacek) [2015525 2048251]
- iwlwifi: mvm: read 6E enablement flags from DSM and pass to FW (Íñigo Huguet) [1923170 1936001]
- net/mlx5: Lag, Make mlx5_lag_is_multipath() be static inline (Amir Tzin) [1982193]
- net/mlx5e: nullify cq->dbg pointer in mlx5_debug_cq_remove() (Amir Tzin) [1982193]
- net/mlx5: DR, Ignore modify TTL if device doesn't support it (Amir Tzin) [1982193 2028504]
- net/mlx5: Warn for devlink reload when there are VFs alive (Amir Tzin) [1982193]
- net/mlx5: DR, Fix lower case macro prefix "mlx5_" to "MLX5_" (Amir Tzin) [1982193]
- net/mlx5e: Fix wrong features assignment in case of error (Amir Tzin) [1982193]
- net/mlx5e: Fix ICOSQ recovery flow for XSK (Amir Tzin) [1982193]
- net/mlx5e: Fix interoperability between XSK and ICOSQ recovery flow (Amir Tzin) [1982193]
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq (Amir Tzin) [1982193]
- net/mlx5: Fix tc max supported prio for nic mode (Amir Tzin) [1982193]
- net/mlx5: Fix SF health recovery flow (Amir Tzin) [1982193]
- net/mlx5: Fix error print in case of IRQ request failed (Amir Tzin) [1982193]
- net/mlx5: DR, Fix NULL vs IS_ERR checking in dr_domain_init_resources (Amir Tzin) [1982193]
- mlx5: fix mlx5i_grp_sw_update_stats() stack usage (Amir Tzin) [1982193]
- mlx5: fix psample_sample_packet link error (Amir Tzin) [1982193]
- net/mlx5: Fix format-security build warnings (Amir Tzin) [1982193]
- net/mlx5e: Fix missing IPsec statistics on uplink representor (Amir Tzin) [1982193]
- net/mlx5e: IPsec: Fix Software parser inner l3 type setting in case of encapsulation (Amir Tzin) [1982193]
- net/mlx5: E-Switch, return error if encap isn't supported (Amir Tzin) [1982193]
- net/mlx5: Lag, update tracker when state change event received (Amir Tzin) [1982193]
- net/mlx5e: CT, Fix multiple allocations and memleak of mod acts (Amir Tzin) [1982193 2017675]
- net/mlx5: Update error handler for UCTX and UMEM (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Fix resetting of encap mode when entering switchdev (Amir Tzin) [1982193]
- net/mlx5e: Wait for concurrent flow deletion during neigh/fib events (Amir Tzin) [1982193]
- net/mlx5e: kTLS, Fix crash in RX resync flow (Amir Tzin) [1982193]
- net/mlx5e: IPsec: Fix work queue entry ethernet segment checksum flags (Amir Tzin) [1982193]
- net/mlx5e: IPsec: Fix a misuse of the software parser's fields (Amir Tzin) [1982193]
- net/mlx5e: Fix vlan data lost during suspend flow (Amir Tzin) [1982193]
- net/mlx5: Lag, change multipath and bonding to be mutually exclusive (Amir Tzin) [1982193]
- net/mlx5: Lag, move lag destruction to a workqueue (Amir Tzin) [1982193]
- RDMA/mlx5: Initialize the ODP xarray when creating an ODP MR (Amir Tzin) [1982193]
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp (Amir Tzin) [1982193]
- net/mlx5e: Switchdev representors are not vlan challenged (Amir Tzin) [1982193]
- net/mlx5e: Fix memory leak in mlx5_core_destroy_cq() error path (Amir Tzin) [1982193]
- net/mlx5: Fix cleanup of bridge delayed work (Amir Tzin) [1982193]
- RDMA/mlx5: Set user priority for DCT (Amir Tzin) [1982193]
- net/mlx5: DR, Fix typo 'offeset' to 'offset' (Amir Tzin) [1982193]
- net/mlx5: DR, Fix vport number data type to u16 (Amir Tzin) [1982193]
- net/mlx5e: Fix the presented RQ index in PTP stats (Amir Tzin) [1982193]
- net/mlx5: Fix setting number of EQs of SFs (Amir Tzin) [1982193]
- net/mlx5: Fix length of irq_index in chars (Amir Tzin) [1982193]
- net/mlx5: Avoid generating event after PPS out in Real time mode (Amir Tzin) [1982193]
- net/mlx5: Force round second at 1PPS out start time (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Fix double allocation of acl flow counter (Amir Tzin) [1982193]
- net/mlx5e: Keep the value for maximum number of channels in-sync (Amir Tzin) [1982193]
- net/mlx5e: IPSEC RX, enable checksum complete (Amir Tzin) [1982193]
- net/mlx5: DR, Fix code indentation in dr_ste_v1 (Amir Tzin) [1982193]
- RDMA/mlx5: Fix xlt_chunk_align calculation (Amir Tzin) [1982193]
- RDMA/mlx5: Fix number of allocated XLT entries (Amir Tzin) [1982193]
- net/mlx5e: Fix mutual exclusion between CQE compression and HW TS (Amir Tzin) [1982193]
- net/mlx5: Fix potential sleeping in atomic context (Amir Tzin) [1982193]
- net/mlx5: FWTrace, cancel work on alloc pd error flow (Amir Tzin) [1982193]
- net/mlx5: DR, fix a potential use-after-free bug (Amir Tzin) [1982193]
- net/mlx5e: Use correct eswitch for stack devices with lag (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Set vhca id valid flag when creating indir fwd group (Amir Tzin) [1982193]
- net/mlx5: Remove all auxiliary devices at the unregister event (Amir Tzin) [1982193]
- net/mlx5: Lag, fix multipath lag activation (Amir Tzin) [1982193]
- net/mlx5: Fix variable type to match 64bit (Amir Tzin) [1982193]
- net/mlx5: Fix typo in comments (Amir Tzin) [1982193]
- net/mlx5e: Remove Duplicated hunk in function __parse_cls_flower() (Amir Tzin) [1982193]
- net/mlx5: Fix unpublish devlink parameters (Amir Tzin) [1982193]
- RDMA/mlx5: Delete not-available udata check (Amir Tzin) [1982193]
- net/mlx5: Fix missing return value in mlx5_devlink_eswitch_inline_mode_set() (Amir Tzin) [1982193]
- net/mlx5e: Block LRO if firmware asks for tunneled LRO (Amir Tzin) [1982193]
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (Amir Tzin) [1982193]
- net: switchdev: zero-initialize struct switchdev_notifier_fdb_info emitted by drivers towards the bridge (Amir Tzin) [1982193]
- net/mlx5: Fix return value from tracer initialization (Amir Tzin) [1982193]
- net/mlx5: Synchronize correct IRQ when destroying CQ (Amir Tzin) [1982193 1982219]
- net/mlx5e: TC, Fix error handling memory leak (Amir Tzin) [1982193]
- net/mlx5: Destroy pool->mutex (Amir Tzin) [1982193]
- net/mlx5: Set all field of mlx5_irq before inserting it to the xarray (Amir Tzin) [1982193]
- net/mlx5: Fix order of functions in mlx5_irq_detach_nb() (Amir Tzin) [1982193]
- net/mlx5: Block switchdev mode while devlink traps are active (Amir Tzin) [1982193]
- net/mlx5e: Destroy page pool after XDP SQ to fix use-after-free (Amir Tzin) [1982193]
- net/mlx5: Bridge, fix ageing time (Amir Tzin) [1982193]
- net/mlx5e: Avoid creating tunnel headers for local route (Amir Tzin) [1982193]
- net/mlx5: DR, Add fail on error check on decap (Amir Tzin) [1982193]
- net/mlx5: Don't skip subfunction cleanup in case of error in module init (Amir Tzin) [1982193]
- RDMA/mlx5: Delay emptying a cache entry when a new MR is added to it recently (Amir Tzin) [1982193]
- net/mlx5: Fix mlx5_vport_tbl_attr chain from u16 to u32 (Amir Tzin) [1982193]
- net/mlx5e: Fix nullptr in mlx5e_hairpin_get_mdev() (Amir Tzin) [1982193]
- net/mlx5: Unload device upon firmware fatal error (Amir Tzin) [1982193]
- net/mlx5e: Fix page allocation failure for ptp-RQ over SF (Amir Tzin) [1982193]
- net/mlx5e: Fix page allocation failure for trap-RQ over SF (Amir Tzin) [1982193]
- net/mlx5e: Consider PTP-RQ when setting RX VLAN stripping (Amir Tzin) [1982193]
- net/mlx5e: Add NETIF_F_HW_TC to hw_features when HTB offload is available (Amir Tzin) [1982193]
- net/mlx5e: RX, Avoid possible data corruption when relaxed ordering and LRO combined (Amir Tzin) [1982193]
- net/mlx5: E-Switch, handle devcom events only for ports on the same device (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Set destination vport vhca id only when merged eswitch is supported (Amir Tzin) [1982193]
- net/mlx5e: Disable Rx ntuple offload for uplink representor (Amir Tzin) [1982193]
- net/mlx5e: kTLS, Add stats for number of deleted kTLS TX offloaded connections (Amir Tzin) [1982193]
- net/mlx5: SF, Improve performance in SF allocation (Amir Tzin) [1982193]
- net/mlx5: Increase hairpin buffer size (Amir Tzin) [1982193]
- net/mlx5: DR, Add support for flow sampler offload (Amir Tzin) [1982193]
- net/mlx5: Compare sampler flow destination ID in fs_core (Amir Tzin) [1982193]
- net/mlx5: remove "default n" from Kconfig (Amir Tzin) [1982193]
- net/mlx5: Fix spelling mistake "enught" -> "enough" (Amir Tzin) [1982193]
- net/mlx5: Use cpumask_available() in mlx5_eq_create_generic() (Amir Tzin) [1982193]
- net/mlx5: Fix missing error code in mlx5_init_fs() (Amir Tzin) [1982193]
- RDMA/mlx5: Support real-time timestamp directly from the device (Amir Tzin) [1982193]
- RDMA/mlx5: Refactor get_ts_format functions to simplify code (Amir Tzin) [1982193]
- RDMA/mlx5: Enable Relaxed Ordering by default for kernel ULPs (Amir Tzin) [1982193]
- net/mlx5: Round-Robin EQs over IRQs (Amir Tzin) [1982193]
- net/mlx5: Separate between public and private API of sf.h (Amir Tzin) [1982193]
- net/mlx5: Enlarge interrupt field in CREATE_EQ (Amir Tzin) [1982193]
- net/mlx5: Allocating a pool of MSI-X vectors for SFs (Amir Tzin) [1982193]
- net/mlx5: Change IRQ storage logic from static to dynamic (Amir Tzin) [1982193]
- net/mlx5: Moving rmap logic to EQs (Amir Tzin) [1982193]
- net/mlx5: Extend mlx5_irq_request to request IRQ from the kernel (Amir Tzin) [1982193]
- net/mlx5: Removing rmap per IRQ (Amir Tzin) [1982193]
- net/mlx5: Clean license text in eq.[c|h] files (Amir Tzin) [1982193]
- net/mlx5: Provide cpumask at EQ creation phase (Amir Tzin) [1982193]
- net/mlx5: Introduce API for request and release IRQs (Amir Tzin) [1982193]
- net/mlx5: Delay IRQ destruction till all users are gone (Amir Tzin) [1982193]
- net/mlx5: Change ownership model for lag (Amir Tzin) [1982193]
- net/mlx5: Lag, Don't rescan if the device is going down (Amir Tzin) [1982193]
- net/mlx5: Lag, refactor disable flow (Amir Tzin) [1982193]
- net/mlx5: Bridge, add tracepoints (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, filter tagged packets that didn't match tagged fg (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, support pvid and untagged vlan configurations (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, match FDB entry vlan tag (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, implement infrastructure for vlans (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, dynamic entry ageing (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, handle FDB events (Amir Tzin) [1982193 1982234]
- docs: networking: Add missing mlx5 documentation (Amir Tzin) [1982193]
- net/mlx5: Bridge, add offload infrastructure (Amir Tzin) [1982193 1982234]
- net/mlx5e: Refactor mlx5e_eswitch_{*}rep() helpers (Amir Tzin) [1982193 1982234]
- net/mlx5: Create TC-miss priority and table (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Support EMD tag in modify header for STEv1 (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Added support for INSERT_HEADER reformat type (Amir Tzin) [1982193 1982234]
- net/mlx5: Added new parameters to reformat context (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Allow encap action for RX for supporting devices (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Split reformat state to Encap and Decap (Amir Tzin) [1982193 1982234]
- net/mlx5: mlx5_ifc support for header insert/remove (Amir Tzin) [1982193 1982234]
- net/mlx5e: Remove unreachable code in mlx5e_xmit() (Amir Tzin) [1982193]
- net/mlx5e: RX, Re-place page pool numa node change logic (Amir Tzin) [1982193]
- net/mlx5e: Zero-init DIM structures (Amir Tzin) [1982193]
- net/mlx5e: IPoIB, Add support for NDR speed (Amir Tzin) [1982193]
- net/mlx5e: Remove the repeated declaration (Amir Tzin) [1982193]
- net/mlx5: check for allocation failure in mlx5_ft_pool_init() (Amir Tzin) [1982193]
- mlx5: count all link events (Amir Tzin) [1982193]
- net/mlx5: Expose FW version over defined keyword (Amir Tzin) [1982193]
- net/mlx5: Use boolean arithmetic to evaluate roce_lag (Amir Tzin) [1982193]
- net/mlx5: Remove unnecessary spin lock protection (Amir Tzin) [1982193]
- net/mlx5: Cap the maximum flow group size to 16M entries (Amir Tzin) [1982193]
- net/mlx5: DR, Set max table size to 2G entries (Amir Tzin) [1982193]
- net/mlx5: Move chains ft pool to be used by all firmware steering (Amir Tzin) [1982193]
- net/mlx5: Move table size calculation to steering cmd layer (Amir Tzin) [1982193]
- net/mlx5: Add case for FS_FT_NIC_TX FT in MLX5_CAP_FLOWTABLE_TYPE (Amir Tzin) [1982193]
- net/mlx5: DR, Remove unused field of send_ring struct (Amir Tzin) [1982193]
- net/mlx5e: RX, Remove unnecessary check in RX CQE compression handling (Amir Tzin) [1982193]
- net/mlx5: CT: Avoid reusing modify header context for natted entries (Amir Tzin) [1982193]
- net/mlx5e: CT, Remove newline from ct_dbg call (Amir Tzin) [1982193]
- RDMA/mlx5: Take qp type from mlx5_ib_qp (Amir Tzin) [1982193]
- RDMA/mlx5: Add SQD2RTS bit to the alloc ucontext response (Amir Tzin) [1982193]
- RDMA/mlx5: Support SQD2RTS for modify QP (Amir Tzin) [1982193]
- RDMA/mlx5: Remove redundant assignment to ret (Amir Tzin) [1982193]
- firewire: fix support status (Tomas Henzl) [2055319]
- dlci: fix support status (Tomas Henzl) [2055319]
- dlink: fix support status (Tomas Henzl) [2055319]
- rxe: fix support status (Tomas Henzl) [2055319]
- qic: fix support status (Tomas Henzl) [2055319]
- Revert "ceph: enable async dirops by default" (Jeffrey Layton) [2052542]
- libceph: optionally use bounce buffer on recv path in crc mode (Jeffrey Layton) [2024725]
- libceph: make recv path in secure mode work the same as send path (Jeffrey Layton) [2024725]
- mm: use kmap_local_page in memzero_page (Jeffrey Layton) [2024725]
- mm: call flush_dcache_page() in memcpy_to_page() and memzero_page() (Jeffrey Layton) [2024725]
- iov_iter: lift memzero_page() to highmem.h (Jeffrey Layton) [2024725]
- mm/highmem: Convert memcpy_[to|from]_page() to kmap_local_page() (Jeffrey Layton) [2024725]
- mm/highmem: Lift memcpy_[to|from]_page to core (Jeffrey Layton) [2024725]
- ceph: set pool_ns in new inode layout for async creates (Jeffrey Layton) [2046021]
- ceph: properly put ceph_string reference after async create attempt (Jeffrey Layton) [2046021]
- ceph: put the requests/sessions when it fails to alloc memory (Jeffrey Layton) [2046021]
- ceph: remove redundant Lsx caps check (Jeffrey Layton) [2046021]
- ceph: don't check for quotas on MDS stray dirs (Jeffrey Layton) [2046021]
- ceph: drop send metrics debug message (Jeffrey Layton) [2046021]
- ceph: Fix incorrect statfs report for small quota (Jeffrey Layton) [2011104]
- scsi: qla2xxx: stop timer in shutdown path (Nilesh Javali) [2056055]
- Revert "PCI: Add support for dev_groups to struct pci_driver" (Michel Dänzer) [2054595]
- drm/amdgpu: Assign amdgpu_sysfs_groups to struct device_driver directly (Michel Dänzer) [2054595]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers (Aristeu Rozanski) [1998359]
- redhat: enable zstream release numbering for rhel 8.6 (Augusto Caringi)
- redhat: generate distgit changelog in genspec.sh as well (Jan Stancek)
- redhat: always upload kabi tarballs (Jan Stancek)
- redhat: make genspec prefer metadata from git notes (Jan Stancek)
- internal: update RHEL_MINOR for the start of RHEL-8.7 development (Jarod Wilson)

* Wed Mar 16 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-372.2.1.el8]
- ice: fix getting UDP tunnel entry (Jonathan Toppins) [2015409]
- ice: convert to new udp_tunnel infrastructure (Jonathan Toppins) [2015409]
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2050807]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2050807] {CVE-2022-0516}
- lib/iov_iter: initialize "flags" in new pipe_buffer (Jan Stancek) [2060875] {CVE-2022-0847}
- fget: clarify and improve __fget_files() implementation (Patrick Talbert) [2032303]
- fget: check that the fd still exists after getting a ref to it (Patrick Talbert) [2032303] {CVE-2021-4083}
- drm/ast: Create threshold values for AST2600 (Jocelyn Falempe) [2053358]
- cgroup-v1: Correct privileges check in release_agent writes (Waiman Long) [2052167]
- cgroup-v1: Require capabilities to set release_agent (Waiman Long) [2052167] {CVE-2022-0492}
- spec: Fix separate tools build (Yauheni Kaliuta) [2056301]
- net/mlx5: DR, Add support for update FTE (Amir Tzin) [2047231]
- net/mlx5: DR, Improve rule tracking memory consumption (Amir Tzin) [2047231]
- net/mlx5: DR, Remove rehash ctrl struct from dr_htbl (Amir Tzin) [2047231]
- net/mlx5: DR, Remove HW specific STE type from nic domain (Amir Tzin) [2047231]
- net/mlx5: DR, Merge DR_STE_SIZE enums (Amir Tzin) [2047231]
- net/mlx5: DR, Skip source port matching on FDB RX domain (Amir Tzin) [2047231]
- net/mlx5: DR, Add ignore_flow_level support for multi-dest flow tables (Amir Tzin) [2047231]
- net/mlx5: DR, replace uintN_t with kernel-style types (Amir Tzin) [2047231]
- net/mlx5: DR, Support IPv6 matching on flow label for STEv0 (Amir Tzin) [2047231]
- net/mlx5: DR, Reduce print level for FT chaining level check (Amir Tzin) [2047231]
- net/mlx5: DR, Warn and ignore SW steering rule insertion on QP err (Amir Tzin) [2047231]
- net/mlx5: DR, Improve error flow in actions_build_ste_arr (Amir Tzin) [2047231]
- net/mlx5: DR, Enable QP retransmission (Amir Tzin) [2047231]
- net/mlx5: DR, Enable VLAN pop on TX and VLAN push on RX (Amir Tzin) [2047231]
- net/mlx5: DR, Split modify VLAN state to separate pop/push states (Amir Tzin) [2047231]
- net/mlx5: DR, Added support for REMOVE_HEADER packet reformat (Amir Tzin) [2047231]
- net/mlx4_en: Resolve bad operstate value (Amir Tzin) [1982190]
- net/mlx4_en: Fix an use-after-free bug in mlx4_en_try_alloc_resources() (Amir Tzin) [1982190]
- RDMA/mlx4: Do not fail the registration on port stats (Amir Tzin) [1982190]
- RDMA/mlx4: Return missed an error if device doesn't support steering (Amir Tzin) [1982190]
- net/mlx4_en: Don't allow aRFS for encapsulated packets (Amir Tzin) [1982190]
- mlx4: Fix missing error code in mlx4_load_one() (Amir Tzin) [1982190]
- net/mlx4: Fix fall-through warning for Clang (Amir Tzin) [1982190]
- mlx4: Remove rcu_read_lock() around XDP program invocation (Amir Tzin) [1982190]
- IB/mlx4: Avoid field-overflowing memcpy() (Amir Tzin) [1982190]
- RDMA/mlx4: Do not map the core_clock page to user space unless enabled (Amir Tzin) [1982190]
- net/mlx4: Treat VFs fair when handling comm_channel_events (Amir Tzin) [1982190]
- RDMA/mlx4: Remove an unused variable (Amir Tzin) [1982190]

* Mon Mar 14 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-372.1.1.el8]
- megaraid_sas: Add new messaging - a fix (Tomas Henzl) [2055248]
- HID: amd_sfh: Add interrupt handler to process interrupts (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Add functionality to clear interrupts (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Disable the interrupt for all command (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Correct the structure field name (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Handle amd_sfh work buffer in PM ops (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Add illuminance mask to limit ALS max value (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Increase sensor command timeout (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Update Copyright details (Benjamin Tissoires) [2054929]
- HID: amd_sfh: switch from 'pci_' to 'dev_' API (Benjamin Tissoires) [2054929]
- HID: amd_sfh: Use dma_set_mask_and_coherent() (Benjamin Tissoires) [2054929]
- HID: amd_sfh: switch from 'pci_' to 'dma_' API (Benjamin Tissoires) [2054929]
- dm stats: fix too short end duration_ns when using precise_timestamps (Benjamin Marzinski) [2057166]
- dm: fix double accounting of flush with data (Benjamin Marzinski) [2057166]
- dm: interlock pending dm_io and dm_wait_for_bios_completion (Benjamin Marzinski) [2057166]
- x86/MCE/AMD, EDAC/mce_amd: Support non-uniform MCA bank type enumeration (Aristeu Rozanski) [2050410 2048786 2050412]
- x86/MCE/AMD, EDAC/mce_amd: Add new SMCA bank types (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC/amd64: Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC: Add RDDR5 and LRDDR5 memory types (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC/amd64: Handle three rank interleaving mode (Aristeu Rozanski) [2050410 2048786 2050412]
- EDAC/amd64: Set proper family type for Family 19h Models 20h-2Fh (Aristeu Rozanski) [2050410 2048786 2050412]
- netfilter: nf_queue: handle socket prefetch (Florian Westphal) [2009786]
- netfilter: nf_queue: fix possible use-after-free (Florian Westphal) [2009786]
- selftests: netfilter: add nfqueue TCP_NEW_SYN_RECV socket race test (Florian Westphal) [2009786]
- netfilter: nf_queue: don't assume sk is full socket (Florian Westphal) [2009786]
- Enable HSA_AMD_SVM config (Donald Dutile) [2025123]
- mm/memremap_pages: support multiple ranges per invocation (Donald Dutile) [2025123]
- mm/memremap_pages: convert to 'struct range' (Donald Dutile) [2025123]
- device-dax: add an allocation interface for device-dax instances (Donald Dutile) [2025123]
- device-dax: make pgmap optional for instance creation (Donald Dutile) [2025123]
- device-dax: move instance creation parameters to 'struct dev_dax_data' (Donald Dutile) [2025123]
- device-dax: drop the dax_region.pfn_flags attribute (Donald Dutile) [2025123]
- memremap: rename MEMORY_DEVICE_DEVDAX to MEMORY_DEVICE_GENERIC (Donald Dutile) [2025123]
- PCI/P2PDMA: Introduce private pagemap structure (Donald Dutile) [2025123]
- security: implement sctp_assoc_established hook in selinux (Ondrej Mosnacek) [2015525 2048251]
- security: add sctp_assoc_established hook (Ondrej Mosnacek) [2015525 2048251]
- security: call security_sctp_assoc_request in sctp_sf_do_5_1D_ce (Ondrej Mosnacek) [2015525 2048251]
- security: pass asoc to sctp_assoc_request and sctp_sk_clone (Ondrej Mosnacek) [2015525 2048251]
- net: sctp: Fix some typos (Ondrej Mosnacek) [2015525 2048251]
- iwlwifi: mvm: read 6E enablement flags from DSM and pass to FW (Íñigo Huguet) [1923170 1936001]
- net/mlx5: Lag, Make mlx5_lag_is_multipath() be static inline (Amir Tzin) [1982193]
- net/mlx5e: nullify cq->dbg pointer in mlx5_debug_cq_remove() (Amir Tzin) [1982193]
- net/mlx5: DR, Ignore modify TTL if device doesn't support it (Amir Tzin) [1982193 2028504]
- net/mlx5: Warn for devlink reload when there are VFs alive (Amir Tzin) [1982193]
- net/mlx5: DR, Fix lower case macro prefix "mlx5_" to "MLX5_" (Amir Tzin) [1982193]
- net/mlx5e: Fix wrong features assignment in case of error (Amir Tzin) [1982193]
- net/mlx5e: Fix ICOSQ recovery flow for XSK (Amir Tzin) [1982193]
- net/mlx5e: Fix interoperability between XSK and ICOSQ recovery flow (Amir Tzin) [1982193]
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq (Amir Tzin) [1982193]
- net/mlx5: Fix tc max supported prio for nic mode (Amir Tzin) [1982193]
- net/mlx5: Fix SF health recovery flow (Amir Tzin) [1982193]
- net/mlx5: Fix error print in case of IRQ request failed (Amir Tzin) [1982193]
- net/mlx5: DR, Fix NULL vs IS_ERR checking in dr_domain_init_resources (Amir Tzin) [1982193]
- mlx5: fix mlx5i_grp_sw_update_stats() stack usage (Amir Tzin) [1982193]
- mlx5: fix psample_sample_packet link error (Amir Tzin) [1982193]
- net/mlx5: Fix format-security build warnings (Amir Tzin) [1982193]
- net/mlx5e: Fix missing IPsec statistics on uplink representor (Amir Tzin) [1982193]
- net/mlx5e: IPsec: Fix Software parser inner l3 type setting in case of encapsulation (Amir Tzin) [1982193]
- net/mlx5: E-Switch, return error if encap isn't supported (Amir Tzin) [1982193]
- net/mlx5: Lag, update tracker when state change event received (Amir Tzin) [1982193]
- net/mlx5e: CT, Fix multiple allocations and memleak of mod acts (Amir Tzin) [1982193 2017675]
- net/mlx5: Update error handler for UCTX and UMEM (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Fix resetting of encap mode when entering switchdev (Amir Tzin) [1982193]
- net/mlx5e: Wait for concurrent flow deletion during neigh/fib events (Amir Tzin) [1982193]
- net/mlx5e: kTLS, Fix crash in RX resync flow (Amir Tzin) [1982193]
- net/mlx5e: IPsec: Fix work queue entry ethernet segment checksum flags (Amir Tzin) [1982193]
- net/mlx5e: IPsec: Fix a misuse of the software parser's fields (Amir Tzin) [1982193]
- net/mlx5e: Fix vlan data lost during suspend flow (Amir Tzin) [1982193]
- net/mlx5: Lag, change multipath and bonding to be mutually exclusive (Amir Tzin) [1982193]
- net/mlx5: Lag, move lag destruction to a workqueue (Amir Tzin) [1982193]
- RDMA/mlx5: Initialize the ODP xarray when creating an ODP MR (Amir Tzin) [1982193]
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp (Amir Tzin) [1982193]
- net/mlx5e: Switchdev representors are not vlan challenged (Amir Tzin) [1982193]
- net/mlx5e: Fix memory leak in mlx5_core_destroy_cq() error path (Amir Tzin) [1982193]
- net/mlx5: Fix cleanup of bridge delayed work (Amir Tzin) [1982193]
- RDMA/mlx5: Set user priority for DCT (Amir Tzin) [1982193]
- net/mlx5: DR, Fix typo 'offeset' to 'offset' (Amir Tzin) [1982193]
- net/mlx5: DR, Fix vport number data type to u16 (Amir Tzin) [1982193]
- net/mlx5e: Fix the presented RQ index in PTP stats (Amir Tzin) [1982193]
- net/mlx5: Fix setting number of EQs of SFs (Amir Tzin) [1982193]
- net/mlx5: Fix length of irq_index in chars (Amir Tzin) [1982193]
- net/mlx5: Avoid generating event after PPS out in Real time mode (Amir Tzin) [1982193]
- net/mlx5: Force round second at 1PPS out start time (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Fix double allocation of acl flow counter (Amir Tzin) [1982193]
- net/mlx5e: Keep the value for maximum number of channels in-sync (Amir Tzin) [1982193]
- net/mlx5e: IPSEC RX, enable checksum complete (Amir Tzin) [1982193]
- net/mlx5: DR, Fix code indentation in dr_ste_v1 (Amir Tzin) [1982193]
- RDMA/mlx5: Fix xlt_chunk_align calculation (Amir Tzin) [1982193]
- RDMA/mlx5: Fix number of allocated XLT entries (Amir Tzin) [1982193]
- net/mlx5e: Fix mutual exclusion between CQE compression and HW TS (Amir Tzin) [1982193]
- net/mlx5: Fix potential sleeping in atomic context (Amir Tzin) [1982193]
- net/mlx5: FWTrace, cancel work on alloc pd error flow (Amir Tzin) [1982193]
- net/mlx5: DR, fix a potential use-after-free bug (Amir Tzin) [1982193]
- net/mlx5e: Use correct eswitch for stack devices with lag (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Set vhca id valid flag when creating indir fwd group (Amir Tzin) [1982193]
- net/mlx5: Remove all auxiliary devices at the unregister event (Amir Tzin) [1982193]
- net/mlx5: Lag, fix multipath lag activation (Amir Tzin) [1982193]
- net/mlx5: Fix variable type to match 64bit (Amir Tzin) [1982193]
- net/mlx5: Fix typo in comments (Amir Tzin) [1982193]
- net/mlx5e: Remove Duplicated hunk in function __parse_cls_flower() (Amir Tzin) [1982193]
- net/mlx5: Fix unpublish devlink parameters (Amir Tzin) [1982193]
- RDMA/mlx5: Delete not-available udata check (Amir Tzin) [1982193]
- net/mlx5: Fix missing return value in mlx5_devlink_eswitch_inline_mode_set() (Amir Tzin) [1982193]
- net/mlx5e: Block LRO if firmware asks for tunneled LRO (Amir Tzin) [1982193]
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (Amir Tzin) [1982193]
- net: switchdev: zero-initialize struct switchdev_notifier_fdb_info emitted by drivers towards the bridge (Amir Tzin) [1982193]
- net/mlx5: Fix return value from tracer initialization (Amir Tzin) [1982193]
- net/mlx5: Synchronize correct IRQ when destroying CQ (Amir Tzin) [1982193 1982219]
- net/mlx5e: TC, Fix error handling memory leak (Amir Tzin) [1982193]
- net/mlx5: Destroy pool->mutex (Amir Tzin) [1982193]
- net/mlx5: Set all field of mlx5_irq before inserting it to the xarray (Amir Tzin) [1982193]
- net/mlx5: Fix order of functions in mlx5_irq_detach_nb() (Amir Tzin) [1982193]
- net/mlx5: Block switchdev mode while devlink traps are active (Amir Tzin) [1982193]
- net/mlx5e: Destroy page pool after XDP SQ to fix use-after-free (Amir Tzin) [1982193]
- net/mlx5: Bridge, fix ageing time (Amir Tzin) [1982193]
- net/mlx5e: Avoid creating tunnel headers for local route (Amir Tzin) [1982193]
- net/mlx5: DR, Add fail on error check on decap (Amir Tzin) [1982193]
- net/mlx5: Don't skip subfunction cleanup in case of error in module init (Amir Tzin) [1982193]
- RDMA/mlx5: Delay emptying a cache entry when a new MR is added to it recently (Amir Tzin) [1982193]
- net/mlx5: Fix mlx5_vport_tbl_attr chain from u16 to u32 (Amir Tzin) [1982193]
- net/mlx5e: Fix nullptr in mlx5e_hairpin_get_mdev() (Amir Tzin) [1982193]
- net/mlx5: Unload device upon firmware fatal error (Amir Tzin) [1982193]
- net/mlx5e: Fix page allocation failure for ptp-RQ over SF (Amir Tzin) [1982193]
- net/mlx5e: Fix page allocation failure for trap-RQ over SF (Amir Tzin) [1982193]
- net/mlx5e: Consider PTP-RQ when setting RX VLAN stripping (Amir Tzin) [1982193]
- net/mlx5e: Add NETIF_F_HW_TC to hw_features when HTB offload is available (Amir Tzin) [1982193]
- net/mlx5e: RX, Avoid possible data corruption when relaxed ordering and LRO combined (Amir Tzin) [1982193]
- net/mlx5: E-Switch, handle devcom events only for ports on the same device (Amir Tzin) [1982193]
- net/mlx5: E-Switch, Set destination vport vhca id only when merged eswitch is supported (Amir Tzin) [1982193]
- net/mlx5e: Disable Rx ntuple offload for uplink representor (Amir Tzin) [1982193]
- net/mlx5e: kTLS, Add stats for number of deleted kTLS TX offloaded connections (Amir Tzin) [1982193]
- net/mlx5: SF, Improve performance in SF allocation (Amir Tzin) [1982193]
- net/mlx5: Increase hairpin buffer size (Amir Tzin) [1982193]
- net/mlx5: DR, Add support for flow sampler offload (Amir Tzin) [1982193]
- net/mlx5: Compare sampler flow destination ID in fs_core (Amir Tzin) [1982193]
- net/mlx5: remove "default n" from Kconfig (Amir Tzin) [1982193]
- net/mlx5: Fix spelling mistake "enught" -> "enough" (Amir Tzin) [1982193]
- net/mlx5: Use cpumask_available() in mlx5_eq_create_generic() (Amir Tzin) [1982193]
- net/mlx5: Fix missing error code in mlx5_init_fs() (Amir Tzin) [1982193]
- RDMA/mlx5: Support real-time timestamp directly from the device (Amir Tzin) [1982193]
- RDMA/mlx5: Refactor get_ts_format functions to simplify code (Amir Tzin) [1982193]
- RDMA/mlx5: Enable Relaxed Ordering by default for kernel ULPs (Amir Tzin) [1982193]
- net/mlx5: Round-Robin EQs over IRQs (Amir Tzin) [1982193]
- net/mlx5: Separate between public and private API of sf.h (Amir Tzin) [1982193]
- net/mlx5: Enlarge interrupt field in CREATE_EQ (Amir Tzin) [1982193]
- net/mlx5: Allocating a pool of MSI-X vectors for SFs (Amir Tzin) [1982193]
- net/mlx5: Change IRQ storage logic from static to dynamic (Amir Tzin) [1982193]
- net/mlx5: Moving rmap logic to EQs (Amir Tzin) [1982193]
- net/mlx5: Extend mlx5_irq_request to request IRQ from the kernel (Amir Tzin) [1982193]
- net/mlx5: Removing rmap per IRQ (Amir Tzin) [1982193]
- net/mlx5: Clean license text in eq.[c|h] files (Amir Tzin) [1982193]
- net/mlx5: Provide cpumask at EQ creation phase (Amir Tzin) [1982193]
- net/mlx5: Introduce API for request and release IRQs (Amir Tzin) [1982193]
- net/mlx5: Delay IRQ destruction till all users are gone (Amir Tzin) [1982193]
- net/mlx5: Change ownership model for lag (Amir Tzin) [1982193]
- net/mlx5: Lag, Don't rescan if the device is going down (Amir Tzin) [1982193]
- net/mlx5: Lag, refactor disable flow (Amir Tzin) [1982193]
- net/mlx5: Bridge, add tracepoints (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, filter tagged packets that didn't match tagged fg (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, support pvid and untagged vlan configurations (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, match FDB entry vlan tag (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, implement infrastructure for vlans (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, dynamic entry ageing (Amir Tzin) [1982193 1982234]
- net/mlx5: Bridge, handle FDB events (Amir Tzin) [1982193 1982234]
- docs: networking: Add missing mlx5 documentation (Amir Tzin) [1982193]
- net/mlx5: Bridge, add offload infrastructure (Amir Tzin) [1982193 1982234]
- net/mlx5e: Refactor mlx5e_eswitch_{*}rep() helpers (Amir Tzin) [1982193 1982234]
- net/mlx5: Create TC-miss priority and table (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Support EMD tag in modify header for STEv1 (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Added support for INSERT_HEADER reformat type (Amir Tzin) [1982193 1982234]
- net/mlx5: Added new parameters to reformat context (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Allow encap action for RX for supporting devices (Amir Tzin) [1982193 1982234]
- net/mlx5: DR, Split reformat state to Encap and Decap (Amir Tzin) [1982193 1982234]
- net/mlx5: mlx5_ifc support for header insert/remove (Amir Tzin) [1982193 1982234]
- net/mlx5e: Remove unreachable code in mlx5e_xmit() (Amir Tzin) [1982193]
- net/mlx5e: RX, Re-place page pool numa node change logic (Amir Tzin) [1982193]
- net/mlx5e: Zero-init DIM structures (Amir Tzin) [1982193]
- net/mlx5e: IPoIB, Add support for NDR speed (Amir Tzin) [1982193]
- net/mlx5e: Remove the repeated declaration (Amir Tzin) [1982193]
- net/mlx5: check for allocation failure in mlx5_ft_pool_init() (Amir Tzin) [1982193]
- mlx5: count all link events (Amir Tzin) [1982193]
- net/mlx5: Expose FW version over defined keyword (Amir Tzin) [1982193]
- net/mlx5: Use boolean arithmetic to evaluate roce_lag (Amir Tzin) [1982193]
- net/mlx5: Remove unnecessary spin lock protection (Amir Tzin) [1982193]
- net/mlx5: Cap the maximum flow group size to 16M entries (Amir Tzin) [1982193]
- net/mlx5: DR, Set max table size to 2G entries (Amir Tzin) [1982193]
- net/mlx5: Move chains ft pool to be used by all firmware steering (Amir Tzin) [1982193]
- net/mlx5: Move table size calculation to steering cmd layer (Amir Tzin) [1982193]
- net/mlx5: Add case for FS_FT_NIC_TX FT in MLX5_CAP_FLOWTABLE_TYPE (Amir Tzin) [1982193]
- net/mlx5: DR, Remove unused field of send_ring struct (Amir Tzin) [1982193]
- net/mlx5e: RX, Remove unnecessary check in RX CQE compression handling (Amir Tzin) [1982193]
- net/mlx5: CT: Avoid reusing modify header context for natted entries (Amir Tzin) [1982193]
- net/mlx5e: CT, Remove newline from ct_dbg call (Amir Tzin) [1982193]
- RDMA/mlx5: Take qp type from mlx5_ib_qp (Amir Tzin) [1982193]
- RDMA/mlx5: Add SQD2RTS bit to the alloc ucontext response (Amir Tzin) [1982193]
- RDMA/mlx5: Support SQD2RTS for modify QP (Amir Tzin) [1982193]
- RDMA/mlx5: Remove redundant assignment to ret (Amir Tzin) [1982193]
- firewire: fix support status (Tomas Henzl) [2055319]
- dlci: fix support status (Tomas Henzl) [2055319]
- dlink: fix support status (Tomas Henzl) [2055319]
- rxe: fix support status (Tomas Henzl) [2055319]
- qic: fix support status (Tomas Henzl) [2055319]
- Revert "ceph: enable async dirops by default" (Jeffrey Layton) [2052542]
- libceph: optionally use bounce buffer on recv path in crc mode (Jeffrey Layton) [2024725]
- libceph: make recv path in secure mode work the same as send path (Jeffrey Layton) [2024725]
- mm: use kmap_local_page in memzero_page (Jeffrey Layton) [2024725]
- mm: call flush_dcache_page() in memcpy_to_page() and memzero_page() (Jeffrey Layton) [2024725]
- iov_iter: lift memzero_page() to highmem.h (Jeffrey Layton) [2024725]
- mm/highmem: Convert memcpy_[to|from]_page() to kmap_local_page() (Jeffrey Layton) [2024725]
- mm/highmem: Lift memcpy_[to|from]_page to core (Jeffrey Layton) [2024725]
- ceph: set pool_ns in new inode layout for async creates (Jeffrey Layton) [2046021]
- ceph: properly put ceph_string reference after async create attempt (Jeffrey Layton) [2046021]
- ceph: put the requests/sessions when it fails to alloc memory (Jeffrey Layton) [2046021]
- ceph: remove redundant Lsx caps check (Jeffrey Layton) [2046021]
- ceph: don't check for quotas on MDS stray dirs (Jeffrey Layton) [2046021]
- ceph: drop send metrics debug message (Jeffrey Layton) [2046021]
- ceph: Fix incorrect statfs report for small quota (Jeffrey Layton) [2011104]
- scsi: qla2xxx: stop timer in shutdown path (Nilesh Javali) [2056055]
- Revert "PCI: Add support for dev_groups to struct pci_driver" (Michel Dänzer) [2054595]
- drm/amdgpu: Assign amdgpu_sysfs_groups to struct device_driver directly (Michel Dänzer) [2054595]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers (Aristeu Rozanski) [1998359]
- redhat: enable zstream release numbering for rhel 8.6 (Augusto Caringi)
- redhat: generate distgit changelog in genspec.sh as well (Jan Stancek)
- redhat: always upload kabi tarballs (Jan Stancek)
- redhat: make genspec prefer metadata from git notes (Jan Stancek)

* Wed Mar 09 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-372.el8]
- xfs: don't generate selinux audit messages for capability testing (Brian Foster) [2059835]

* Sat Feb 26 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-371.el8]
- ice: Implement support for SMA and U.FL on E810-T (Jonathan Toppins) [1975007]
- ice: Add support for SMA control multiplexer (Jonathan Toppins) [1975007]
- ice: Implement functions for reading and setting GPIO pins (Jonathan Toppins) [1975007]
- ice: Refactor ice_aqc_link_topo_addr (Jonathan Toppins) [1975007]
- xfs: restore speculative_cow_prealloc_lifetime sysctl (Bill O'Donnell) [2015621]
- xfs: Fix the free logic of state in xfs_attr_node_hasname (Bill O'Donnell) [2015621 2037498]
- xfs: punch out data fork delalloc blocks on COW writeback failure (Bill O'Donnell) [2015621 2012872]
- xfs: use kmem_cache_free() for kmem_cache objects (Bill O'Donnell) [2015621]
- xfs: logging the on disk inode LSN can make it go backwards (Bill O'Donnell) [2015621]
- xfs: only reset incore inode health state flags when reclaiming an inode (Bill O'Donnell) [2015621]
- xfs: remove obsolete AGF counter debugging (Bill O'Donnell) [2015621]
- xfs: Initialize xfs_alloc_arg->total correctly when allocating minlen extents (Bill O'Donnell) [2015621]
- xfs: Fix dax inode extent calculation when direct write is performed on an unwritten extent (Bill O'Donnell) [2015621]
- xfs: mark a data structure sick if there are cross-referencing errors (Bill O'Donnell) [2015621]
- xfs: fix maxlevels comparisons in the btree staging code (Bill O'Donnell) [2015621]
- xfs: fix incorrect unit conversion in scrub tracepoint (Bill O'Donnell) [2015621]
- xfs: fix log intent recovery ENOSPC shutdowns when inactivating inodes (Bill O'Donnell) [2015621]
- xfs: fix radix tree tag signs (Bill O'Donnell) [2015621]
- xfs: force log and push AIL to clear pinned inodes when aborting mount (Bill O'Donnell) [2015621]
- xfs: use current->journal_info for detecting transaction recursion (Bill O'Donnell) [2015621]
- xfs: don't nest transactions when scanning for eofblocks (Bill O'Donnell) [2015621]
- xfs: fix boolreturn.cocci warnings (Bill O'Donnell) [2015621]
- xfs: get rid of xfs_growfs_{data,log}_t (Bill O'Donnell) [2015621]
- xfs: rename `new' to `delta' in xfs_growfs_data_private() (Bill O'Donnell) [2015621]
- xfs: don't bounce the iolock between free_{eof,cow}blocks (Bill O'Donnell) [2015621]
- xfs: expose the blockgc workqueue knobs publicly (Bill O'Donnell) [2015621]
- xfs: parallelize block preallocation garbage collection (Bill O'Donnell) [2015621]
- xfs: rename block gc start and stop functions (Bill O'Donnell) [2015621]
- xfs: only walk the incore inode tree once per blockgc scan (Bill O'Donnell) [2015621]
- xfs: consolidate the eofblocks and cowblocks workers (Bill O'Donnell) [2015621]
- xfs: consolidate incore inode radix tree posteof/cowblocks tags (Bill O'Donnell) [2015621]
- xfs: remove trivial eof/cowblocks functions (Bill O'Donnell) [2015621]
- xfs: hide xfs_icache_free_cowblocks (Bill O'Donnell) [2015621]
- xfs: hide xfs_icache_free_eofblocks (Bill O'Donnell) [2015621]
- xfs: relocate the eofb/cowb workqueue functions (Bill O'Donnell) [2015621]
- xfs: set WQ_SYSFS on all workqueues in debug mode (Bill O'Donnell) [2015621]
- xfs: increase the default parallelism levels of pwork clients (Bill O'Donnell) [2015621]
- xfs: flush speculative space allocations when we run out of space (Bill O'Donnell) [2015621]
- xfs: refactor xfs_icache_free_{eof,cow}blocks call sites (Bill O'Donnell) [2015621]
- xfs: add a tracepoint for blockgc scans (Bill O'Donnell) [2015621]
- xfs: flush eof/cowblocks if we can't reserve quota for chown (Bill O'Donnell) [2015621]
- xfs: flush eof/cowblocks if we can't reserve quota for inode creation (Bill O'Donnell) [2015621]
- xfs: flush eof/cowblocks if we can't reserve quota for file blocks (Bill O'Donnell) [2015621]
- xfs: try worst case space reservation upfront in xfs_reflink_remap_extent (Bill O'Donnell) [2015621]
- xfs: pass flags and return gc errors from xfs_blockgc_free_quota (Bill O'Donnell) [2015621]
- xfs: move and rename xfs_inode_free_quota_blocks to avoid conflicts (Bill O'Donnell) [2015621]
- xfs: xfs_inode_free_quota_blocks should scan project quota (Bill O'Donnell) [2015621]
- xfs: don't stall cowblocks scan if we can't take locks (Bill O'Donnell) [2015621]
- xfs: trigger all block gc scans when low on quota space (Bill O'Donnell) [2015621]
- xfs: shut down the filesystem if we screw up quota reservation (Bill O'Donnell) [2015621]
- xfs: rename code to error in xfs_ioctl_setattr (Bill O'Donnell) [2015621]
- xfs: remove xfs_qm_vop_chown_reserve (Bill O'Donnell) [2015621]
- xfs: refactor inode ownership change transaction/inode/quota allocation idiom (Bill O'Donnell) [2015621]
- xfs: refactor inode creation transaction/inode/quota allocation idiom (Bill O'Donnell) [2015621]
- xfs: refactor reflink functions to use xfs_trans_alloc_inode (Bill O'Donnell) [2015621]
- xfs: allow reservation of rtblocks with xfs_trans_alloc_inode (Bill O'Donnell) [2015621]
- xfs: refactor common transaction/inode/quota allocation idiom (Bill O'Donnell) [2015621]
- xfs: reserve data and rt quota at the same time (Bill O'Donnell) [2015621]
- xfs: clean up icreate quota reservation calls (Bill O'Donnell) [2015621]
- xfs: remove xfs_trans_unreserve_quota_nblks completely (Bill O'Donnell) [2015621]
- xfs: create convenience wrappers for incore quota block reservations (Bill O'Donnell) [2015621]
- xfs: clean up quota reservation callsites (Bill O'Donnell) [2015621]
- xfs: reduce quota reservation when doing a dax unwritten extent conversion (Bill O'Donnell) [2015621]
- xfs: reduce exclusive locking on unaligned dio (Bill O'Donnell) [2015621]
- xfs: split the unaligned DIO write code out (Bill O'Donnell) [2015621]
- xfs: improve the reflink_bounce_dio_write tracepoint (Bill O'Donnell) [2015621]
- xfs: simplify the read/write tracepoints (Bill O'Donnell) [2015621]
- xfs: remove the buffered I/O fallback assert (Bill O'Donnell) [2015621]
- xfs: cleanup the read/write helper naming (Bill O'Donnell) [2015621]
- xfs: make xfs_file_aio_write_checks IOCB_NOWAIT-aware (Bill O'Donnell) [2015621]
- xfs: factor out a xfs_ilock_iocb helper (Bill O'Donnell) [2015621]
- xfs: Fix 'set but not used' warning in xfs_bmap_compute_alignments() (Bill O'Donnell) [2015621]
- xfs: fix unused log variable in xfs_log_cover() (Bill O'Donnell) [2015621]
- iomap: add a IOMAP_DIO_OVERWRITE_ONLY flag (Bill O'Donnell) [2015621]
- iomap: pass a flags argument to iomap_dio_rw (Bill O'Donnell) [2015621]
- iomap: rename the flags variable in __iomap_dio_rw (Bill O'Donnell) [2015621]
- iomap: Allow filesystem to call iomap_dio_complete without i_rwsem (Bill O'Donnell) [2015621]
- xfs: reduce ilock acquisitions in xfs_file_fsync (Bill O'Donnell) [2015621]
- xfs: refactor xfs_file_fsync (Bill O'Donnell) [2015621]
- xfs: cover the log on freeze instead of cleaning it (Bill O'Donnell) [2015621]
- xfs: remove xfs_quiesce_attr() (Bill O'Donnell) [2015621]
- xfs: remove duplicate wq cancel and log force from attr quiesce (Bill O'Donnell) [2015621]
- xfs: fold sbcount quiesce logging into log covering (Bill O'Donnell) [2015621]
- xfs: don't reset log idle state on covering checkpoints (Bill O'Donnell) [2015621]
- xfs: cover the log during log quiesce (Bill O'Donnell) [2015621]
- xfs: separate log cleaning from log quiesce (Bill O'Donnell) [2015621]
- xfs: lift writable fs check up into log worker task (Bill O'Donnell) [2015621]
- xfs: set inode size after creating symlink (Bill O'Donnell) [2015621]
- xfs: remove a stale comment from xfs_file_aio_write_checks() (Bill O'Donnell) [2015621]
- xfs: Introduce error injection to allocate only minlen size extents for files (Bill O'Donnell) [2015621]
- xfs: Process allocated extent in a separate function (Bill O'Donnell) [2015621]
- xfs: Compute bmap extent alignments in a separate function (Bill O'Donnell) [2015621]
- xfs: Remove duplicate assert statement in xfs_bmap_btalloc() (Bill O'Donnell) [2015621]
- xfs: Introduce error injection to reduce maximum inode fork extent count (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when swapping extents (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when remapping an extent (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when moving extent from cow to data fork (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when writing to unwritten extent (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when adding/removing xattrs (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when renaming dir entries (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when removing dir entries (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when adding dir entries (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when punching a hole (Bill O'Donnell) [2015621]
- xfs: Check for extent overflow when trivally adding a new extent (Bill O'Donnell) [2015621]
- xfs: Add helper for checking per-inode extent count overflow (Bill O'Donnell) [2015621]
- iwlwifi: pcie: add killer devices to the driver (Íñigo Huguet) [2043453]
- iwlwifi: add support for BNJ HW (Íñigo Huguet) [2043453]
- iwlwifi: Fix FW name for gl (Íñigo Huguet) [2043453]
- iwlwifi: Read the correct addresses when getting the crf id (Íñigo Huguet) [2043453]
- iwlwifi: pcie: add jacket bit to device configuration parsing (Íñigo Huguet) [2043453]
- iwlwifi: add new ax1650 killer device (Íñigo Huguet) [2043453]
- iwlwifi: add new Qu-Hr device (Íñigo Huguet) [2043453]
- iwlwifi: add missing entries for Gf4 with So and SoF (Íñigo Huguet) [2043453]
- iwlwifi: remove unused iwlax210_2ax_cfg_so_hr_a0 structure (Íñigo Huguet) [2043453]
- iwlwifi: add support for Bz-Z HW (Íñigo Huguet) [2043453]
- iwlwifi: support 4-bits in MAC step value (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Increase the scan timeout guard to 30 seconds (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Use div_s64 instead of do_div in iwl_mvm_ftm_rtt_smoothing() (Íñigo Huguet) [2043453]
- mt76: mt7921: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2043453]
- ath11k: Fix unexpected return buffer manager error for QCA6390 (Íñigo Huguet) [2043453]
- ath11k: Fix napi related hang (Íñigo Huguet) [2043453]
- iwlwifi: yoyo: fix issue with new DBGI_SRAM region read. (Íñigo Huguet) [2043453]
- iwlwifi: pcie: make sure prph_info is set when treating wakeup IRQ (Íñigo Huguet) [2043453]
- iwlwifi: mvm: fix AUX ROC removal (Íñigo Huguet) [2043453]
- iwlwifi: mvm: set protected flag only for NDP ranging (Íñigo Huguet) [2043453]
- iwlwifi: mvm: perform 6GHz passive scan after suspend (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Fix calculation of frame length (Íñigo Huguet) [2043453]
- iwlwifi: mvm: test roc running status bits before removing the sta (Íñigo Huguet) [2043453]
- iwlwifi: don't pass actual WGDS revision number in table_revision (Íñigo Huguet) [2043453]
- iwlwifi: fix leaks/bad data after failed firmware load (Íñigo Huguet) [2043453]
- iwlwifi: fix debug TLV parsing (Íñigo Huguet) [2043453]
- iwlwifi: mvm: fix 32-bit build in FTM (Íñigo Huguet) [2043453]
- iwlwifi: fix Bz NMI behaviour (Íñigo Huguet) [2043453]
- rtlwifi: rtl8192cu: Fix WARNING when calling local_irq_restore() with interrupts enabled (Íñigo Huguet) [2043453]
- rtw88: 8822c: update rx settings to prevent potential hw deadlock (Íñigo Huguet) [2043453]
- rtw88: Disable PCIe ASPM while doing NAPI poll on 8821CE (Íñigo Huguet) [2043453]
- ath9k: Fix out-of-bound memcpy in ath9k_hif_usb_rx_stream (Íñigo Huguet) [2043453]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_tx_get_packet() (Íñigo Huguet) [2043453]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_rxep() (Íñigo Huguet) [2043453]
- mac80211: fix FEC flag in radio tap header (Íñigo Huguet) [2043453]
- mt76: mt7921: fix possible resume failure (Íñigo Huguet) [2043453]
- mt76: mt7921: move mt76_connac_mcu_set_hif_suspend to bus-related files (Íñigo Huguet) [2043453]
- mt76: mt7921: fix network buffer leak by txs missing (Íñigo Huguet) [2043453]
- mt76: mt7615: clear mcu error interrupt status on mt7663 (Íñigo Huguet) [2043453]
- mt76: connac: fix last_chan configuration in mt76_connac_mcu_rate_txpower_band (Íñigo Huguet) [2043453]
- mt76: mt7921: use correct iftype data on 6GHz cap init (Íñigo Huguet) [2043453]
- mt76: mt7921: fix boolreturn.cocci warning (Íñigo Huguet) [2043453]
- mt76: mt7615: fix unused tx antenna mask in testmode (Íñigo Huguet) [2043453]
- mt76: fix the wiphy's available antennas to the correct value (Íñigo Huguet) [2043453]
- mt76: connac: fix a theoretical NULL pointer dereference in mt76_connac_get_phy_mode (Íñigo Huguet) [2043453]
- mt76: mt7921: fix possible NULL pointer dereference in mt7921_mac_write_txwi (Íñigo Huguet) [2043453]
- mt76: fix possible OOB issue in mt76_calculate_default_rate (Íñigo Huguet) [2043453]
- mt76: debugfs: fix queue reporting for mt76-usb (Íñigo Huguet) [2043453]
- mt76: mt7915: fix SMPS operation fail (Íñigo Huguet) [2043453]
- mt76: mt7915: fix return condition in mt7915_tm_reg_backup_restore() (Íñigo Huguet) [2043453]
- mt76: mt7921: fix MT7921E reset failure (Íñigo Huguet) [2043453]
- mt76: mt7615: fix possible deadlock while mt7615_register_ext_phy() (Íñigo Huguet) [2043453]
- mt76: mt7921: drop offload_flags overwritten (Íñigo Huguet) [2043453]
- mt76: mt7915: get rid of mt7915_mcu_set_fixed_rate routine (Íñigo Huguet) [2043453]
- bus: mhi: core: Use correctly sized arguments for bit field (Íñigo Huguet) [2043453]
- bus: mhi: core: Fix race while handling SYS_ERR at power up (Íñigo Huguet) [2043453]
- bus: mhi: core: Fix reading wake_capable channel configuration (Íñigo Huguet) [2043453]
- bus: mhi: core: Minor style and comment fixes (Íñigo Huguet) [2043453]
- bus: mhi: pci_generic: Graceful shutdown on freeze (Íñigo Huguet) [2043453]
- ath11k: Fix a NULL pointer dereference in ath11k_mac_op_hw_scan() (Íñigo Huguet) [2043453]
- mt76: remove variable set but not used (Íñigo Huguet) [2043453]
- ath11k: Fix deleting uninitialized kernel timer during fragment cache flush (Íñigo Huguet) [2043453]
- ath11k: add spectral/CFR buffer validation support (Íñigo Huguet) [2043453]
- ath11k: Fix buffer overflow when scanning with extraie (Íñigo Huguet) [2043453]
- mwifiex: Fix possible ABBA deadlock (Íñigo Huguet) [2043453]
- ath10k: fix scan abort when duration is set for hw scan (Íñigo Huguet) [2043453]
- ath10k: Fix tx hanging (Íñigo Huguet) [2043453]
- iwlwifi: acpi: fix wgds rev 3 size (Íñigo Huguet) [2043453]
- iwlwifi: mvm: avoid clearing a just saved session protection id (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Fix wrong documentation for scan request command (Íñigo Huguet) [2043453]
- iwlwifi: mvm: synchronize with FW after multicast commands (Íñigo Huguet) [2043453]
- iwlwifi: mvm: fix delBA vs. NSSN queue sync race (Íñigo Huguet) [2043453]
- ath11k: Fix QMI file type enum value (Íñigo Huguet) [2043453]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2043453]
- ath10k: Fix the MTU size on QCA9377 SDIO (Íñigo Huguet) [2043453]
- wireless: iwlwifi: Fix a double free in iwl_txq_dyn_alloc_dma (Íñigo Huguet) [2043453]
- mwifiex: Ignore BTCOEX events from the 88W8897 firmware (Íñigo Huguet) [2043453]
- mwifiex: Fix skb_over_panic in mwifiex_usb_recv() (Íñigo Huguet) [2043453]
- ath11k: Use host CE parameters for CE interrupts configuration (Íñigo Huguet) [2043453]
- ath11k: Fix mon status ring rx tlv processing (Íñigo Huguet) [2043453]
- ath11k: skip sending vdev down for channel switch (Íñigo Huguet) [2043453]
- ath11k: fix read fail for htt_stats and htt_peer_stats for single pdev (Íñigo Huguet) [2043453]
- ath11k: Set IRQ affinity to CPU0 in case of one MSI vector (Íñigo Huguet) [2043453]
- ath11k: do not restore ASPM in case of single MSI vector (Íñigo Huguet) [2043453]
- ath11k: add support one MSI vector (Íñigo Huguet) [2043453]
- ath11k: refactor multiple MSI vector implementation (Íñigo Huguet) [2043453]
- ath11k: use ATH11K_PCI_IRQ_DP_OFFSET for DP IRQ (Íñigo Huguet) [2043453]
- ath11k: add CE and ext IRQ flag to indicate irq_handler (Íñigo Huguet) [2043453]
- ath11k: get msi_data again after request_irq is called (Íñigo Huguet) [2043453]
- ath9k: fix intr_txqs setting (Íñigo Huguet) [2043453]
- ath11k: add hw_param for wakeup_mhi (Íñigo Huguet) [2043453]
- ath11k: reset RSN/WPA present state for open BSS (Íñigo Huguet) [2043453]
- ath11k: clear the keys properly via DISABLE_KEY (Íñigo Huguet) [2043453]
- ath11k: Fix crash caused by uninitialized TX ring (Íñigo Huguet) [2043453]
- ath11k: use cache line aligned buffers for dbring (Íñigo Huguet) [2043453]
- ath11k: Fix ETSI regd with weather radar overlap (Íñigo Huguet) [2043453]
- ath11k: fix FCS_ERR flag in radio tap header (Íñigo Huguet) [2043453]
- ath11k: fix the value of msecs_to_jiffies in ath11k_debugfs_fw_stats_request (Íñigo Huguet) [2043453]
- ath11k: fix firmware crash during channel switch (Íñigo Huguet) [2043453]
- ath11k: Fix 'unused-but-set-parameter' error (Íñigo Huguet) [2043453]
- ath11k: fix DMA memory free in CE pipe cleanup (Íñigo Huguet) [2043453]
- ath11k: fix error routine when fallback of add interface fails (Íñigo Huguet) [2043453]
- ath11k: fix fw crash due to peer get authorized before key install (Íñigo Huguet) [2043453]
- ath11k: Clear auth flag only for actual association in security mode (Íñigo Huguet) [2043453]
- ath11k: Send PPDU_STATS_CFG with proper pdev mask to firmware (Íñigo Huguet) [2043453]
- ath11k: set correct NL80211_FEATURE_DYNAMIC_SMPS for WCN6855 (Íñigo Huguet) [2043453]
- mac80211: mesh: embedd mesh_paths and mpp_paths into ieee80211_if_mesh (Íñigo Huguet) [2043453]
- mac80211: initialize variable have_higher_than_11mbit (Íñigo Huguet) [2043453]
- mac80211: fix locking in ieee80211_start_ap error path (Íñigo Huguet) [2043453]
- mac80211: do drv_reconfig_complete() before restarting all (Íñigo Huguet) [2043453]
- mac80211: mark TX-during-stop for TX in in_reconfig (Íñigo Huguet) [2043453]
- mac80211: update channel context before station state (Íñigo Huguet) [2043453]
- mac80211: Fix the size used for building probe request (Íñigo Huguet) [2043453]
- mac80211: fix lookup when adding AddBA extension element (Íñigo Huguet) [2043453]
- mac80211: validate extended element ID is present (Íñigo Huguet) [2043453]
- cfg80211: Acquire wiphy mutex on regulatory work (Íñigo Huguet) [2043453]
- mac80211: agg-tx: don't schedule_and_wake_txq() under sta->lock (Íñigo Huguet) [2043453]
- nl80211: remove reload flag from regulatory_request (Íñigo Huguet) [2043453]
- mac80211: send ADDBA requests using the tid/queue of the aggregation session (Íñigo Huguet) [2043453]
- bus: mhi: core: Add support for forced PM resume (Íñigo Huguet) [2043453]
- mt76: mt7921: fix build regression (Íñigo Huguet) [2043453]
- brcmsmac: rework LED dependencies (Íñigo Huguet) [2043453]
- iwlwifi: fix LED dependencies (Íñigo Huguet) [2043453]
- iwlwifi: mvm: don't crash on invalid rate w/o STA (Íñigo Huguet) [2043453]
- bus: mhi: pci_generic: Fix device recovery failed issue (Íñigo Huguet) [2043453]
- mt76: fix key pointer overwrite in mt7921s_write_txwi/mt7663_usb_sdio_write_txwi (Íñigo Huguet) [2043453]
- rt2x00: do not mark device gone on EPROTO errors during start (Íñigo Huguet) [2043453]
- nl80211: reset regdom when reloading regdb (Íñigo Huguet) [2043453]
- mac80211: add docs for ssn in struct tid_ampdu_tx (Íñigo Huguet) [2043453]
- mac80211: fix a memory leak where sta_info is not freed (Íñigo Huguet) [2043453]
- mac80211: set up the fwd_skb->dev for mesh forwarding (Íñigo Huguet) [2043453]
- mac80211: fix regression in SSN handling of addba tx (Íñigo Huguet) [2043453]
- mac80211: fix rate control for retransmitted frames (Íñigo Huguet) [2043453]
- mac80211: track only QoS data frames for admission control (Íñigo Huguet) [2043453]
- mac80211: fix TCP performance on mesh interface (Íñigo Huguet) [2043453]
- mt76: fix possible pktid leak (Íñigo Huguet) [2043453]
- mt76: fix timestamp check in tx_status (Íñigo Huguet) [2043453]
- mt76: mt7915: fix NULL pointer dereference in mt7915_get_phy_mode (Íñigo Huguet) [2043453]
- iwlwifi: Fix memory leaks in error handling path (Íñigo Huguet) [2043453]
- iwlwifi: fix warnings produced by kernel debug options (Íñigo Huguet) [2043453]
- iwlwifi: mvm: retry init flow if failed (Íñigo Huguet) [2043453]
- iwlwifi: Fix missing error code in iwl_pci_probe() (Íñigo Huguet) [2043453]
- iwlwifi: pcie: fix constant-conversion warning (Íñigo Huguet) [2043453]
- mac80211: fix throughput LED trigger (Íñigo Huguet) [2043453]
- mac80211: fix monitor_sdata RCU/locking assertions (Íñigo Huguet) [2043453]
- mac80211: drop check for DONT_REORDER in __ieee80211_select_queue (Íñigo Huguet) [2043453]
- mac80211: fix radiotap header generation (Íñigo Huguet) [2043453]
- mac80211: do not access the IV when it was stripped (Íñigo Huguet) [2043453]
- nl80211: fix radio statistics in survey dump (Íñigo Huguet) [2043453]
- cfg80211: call cfg80211_stop_ap when switch from P2P_GO type (Íñigo Huguet) [2043453]
- mwifiex: fix division by zero in fw download path (Íñigo Huguet) [2043453]
- iwlwifi: bump FW API to 67 for AX devices (Íñigo Huguet) [2043453]
- iwlwifi: mvm: extend session protection on association (Íñigo Huguet) [2043453]
- iwlwifi: rename CHANNEL_SWITCH_NOA_NOTIF to CHANNEL_SWITCH_START_NOTIF (Íñigo Huguet) [2043453]
- iwlwifi: mvm: remove session protection on disassoc (Íñigo Huguet) [2043453]
- iwlwifi: mvm: fix WGDS table print in iwl_mvm_chub_update_mcc() (Íñigo Huguet) [2043453]
- iwlwifi: rename GEO_TX_POWER_LIMIT to PER_CHAIN_LIMIT_OFFSET_CMD (Íñigo Huguet) [2043453]
- iwlwifi: mvm: d3: use internal data representation (Íñigo Huguet) [2043453]
- iwlwifi: mvm: update RFI TLV (Íñigo Huguet) [2043453]
- iwlwifi: mvm: don't get address of mvm->fwrt just to dereference as a pointer (Íñigo Huguet) [2043453]
- iwlwifi: yoyo: support for ROM usniffer (Íñigo Huguet) [2043453]
- iwlwifi: fw: uefi: add missing include guards (Íñigo Huguet) [2043453]
- iwlwifi: dump host monitor data when NIC doesn't init (Íñigo Huguet) [2043453]
- iwlwifi: pcie: simplify iwl_pci_find_dev_info() (Íñigo Huguet) [2043453]
- iwlwifi: ACPI: support revision 3 WGDS tables (Íñigo Huguet) [2043453]
- iwlwifi: pcie: update sw error interrupt for BZ family (Íñigo Huguet) [2043453]
- iwlwifi: add new pci SoF with JF (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Use all Rx chains for roaming scan (Íñigo Huguet) [2043453]
- iwlwifi: pcie: remove two duplicate PNJ device entries (Íñigo Huguet) [2043453]
- iwlwifi: pcie: refactor dev_info lookup (Íñigo Huguet) [2043453]
- iwlwifi: pcie: remove duplicate entry (Íñigo Huguet) [2043453]
- iwlwifi: pcie: fix killer name matching for AX200 (Íñigo Huguet) [2043453]
- iwlwifi: mvm: fix some kerneldoc issues (Íñigo Huguet) [2043453]
- ath10k: fix division by zero in send path (Íñigo Huguet) [2043453]
- ath10k: fix control-message timeout (Íñigo Huguet) [2043453]
- ath10k: fix module load regression with iram-recovery feature (Íñigo Huguet) [2043453]
- ath10k: fix invalid dma_addr_t token assignment (Íñigo Huguet) [2043453]
- ath11k: change return buffer manager for QCA6390 (Íñigo Huguet) [2043453]
- mt76: connac: fix unresolved symbols when CONFIG_PM is unset (Íñigo Huguet) [2043453]
- mt76: Make use of the helper macro kthread_run() (Íñigo Huguet) [2043453]
- mt76: Print error message when reading EEPROM from mtd failed (Íñigo Huguet) [2043453]
- mt76: mt7921: disable 4addr capability (Íñigo Huguet) [2043453]
- mt76: mt7915: add debugfs knobs for MCU utilization (Íñigo Huguet) [2043453]
- mt76: mt7915: add WA firmware log support (Íñigo Huguet) [2043453]
- mt76: mt7915: fix endiannes warning mt7915_mcu_beacon_check_caps (Íñigo Huguet) [2043453]
- mt76: mt7915: rework debugfs fixed-rate knob (Íñigo Huguet) [2043453]
- mt76: mt7915: rework .set_bitrate_mask() to support more options (Íñigo Huguet) [2043453]
- mt76: mt7915: remove mt7915_mcu_add_he() (Íñigo Huguet) [2043453]
- mt76: mt7615: apply cached RF data for DBDC (Íñigo Huguet) [2043453]
- mt76: mt7615: mt7622: fix ibss and meshpoint (Íñigo Huguet) [2043453]
- mt76: mt7921: fix Wformat build warning (Íñigo Huguet) [2043453]
- mt76: mt7921: fix mt7921s Kconfig (Íñigo Huguet) [2043453]
- iwlwifi: pnvm: print out the version properly (Íñigo Huguet) [2043453]
- iwlwifi: dbg: treat non active regions as unsupported regions (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Read acpi dsm to get channel activation bitmap (Íñigo Huguet) [2043453]
- iwlwifi: add new device id 7F70 (Íñigo Huguet) [2043453]
- iwlwifi: mvm: improve log when processing CSA (Íñigo Huguet) [2043453]
- iwlwifi: mvm: set BT-coex high priority for 802.1X/4-way-HS (Íñigo Huguet) [2043453]
- iwlwifi: dbg: treat dbgc allocation failure when tlv is missing (Íñigo Huguet) [2043453]
- iwlwifi: add new killer devices to the driver (Íñigo Huguet) [2043453]
- iwlwifi: mvm: set inactivity timeouts also for PS-poll (Íñigo Huguet) [2043453]
- iwlwifi: pcie: try to grab NIC access early (Íñigo Huguet) [2043453]
- iwlwifi: mvm: reduce WARN_ON() in TX status path (Íñigo Huguet) [2043453]
- iwlwifi: allow rate-limited error messages (Íñigo Huguet) [2043453]
- iwlwifi: mvm: remove session protection after auth/assoc (Íñigo Huguet) [2043453]
- iwlwifi: remove redundant iwl_finish_nic_init() argument (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Add RTS and CTS flags to iwl_tx_cmd_flags. (Íñigo Huguet) [2043453]
- iwlwifi: mvm: remove csi from iwl_mvm_pass_packet_to_mac80211() (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Support new rate_n_flags for REPLY_RX_MPDU_CMD and RX_NO_DATA_NOTIF (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Support new TX_RSP and COMPRESSED_BA_RES versions (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Support new version of BEACON_TEMPLATE_CMD. (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Add support for new rate_n_flags in tx_cmd. (Íñigo Huguet) [2043453]
- iwlwifi: BZ Family SW reset support (Íñigo Huguet) [2043453]
- iwlwifi: BZ Family BUS_MASTER_DISABLE_REQ code duplication (Íñigo Huguet) [2043453]
- iwlwifi: yoyo: fw debug config from context info and preset (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Support new version of ranging response notification (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Support version 3 of tlc_update_notif. (Íñigo Huguet) [2043453]
- iwlwifi: mvm: convert old rate & flags to the new format. (Íñigo Huguet) [2043453]
- iwlwifi: mvm: add definitions for new rate & flags (Íñigo Huguet) [2043453]
- iwlwifi: mvm: update definitions due to new rate & flags (Íñigo Huguet) [2043453]
- iwlwifi: mvm: scrub key material in firmware dumps (Íñigo Huguet) [2043453]
- iwlwifi: parse debug exclude data from firmware file (Íñigo Huguet) [2043453]
- iwlwifi: fw dump: add infrastructure for dump scrubbing (Íñigo Huguet) [2043453]
- iwlwifi: mvm: correct sta-state logic for TDLS (Íñigo Huguet) [2043453]
- iwlwifi: api: fix struct iwl_wowlan_status_v7 kernel-doc (Íñigo Huguet) [2043453]
- iwlwifi: fix fw/img.c license statement (Íñigo Huguet) [2043453]
- iwlwifi: remove contact information (Íñigo Huguet) [2043453]
- iwlwifi: remove MODULE_AUTHOR() statements (Íñigo Huguet) [2043453]
- iwlwifi: api: remove unused RX status bits (Íñigo Huguet) [2043453]
- iwlwifi: add some missing kernel-doc in struct iwl_fw (Íñigo Huguet) [2043453]
- iwlwifi: mvm: Remove antenna c references (Íñigo Huguet) [2043453]
- iwlwifi: mvm: add support for 160Mhz in ranging measurements (Íñigo Huguet) [2043453]
- iwlwifi: add vendor specific capabilities for some RFs (Íñigo Huguet) [2043453]
- iwlwifi: mvm: add lmac/umac PC info in case of error (Íñigo Huguet) [2043453]
- iwlwifi: mvm: disable RX-diversity in powersave (Íñigo Huguet) [2043453]
- iwlwifi: mvm: fix ieee80211_get_he_iftype_cap() iftype (Íñigo Huguet) [2043453]
- iwlwifi: Start scratch debug register for Bz family (Íñigo Huguet) [2043453]
- iwlwifi: Add support for more BZ HWs (Íñigo Huguet) [2043453]
- iwlwifi: Add support for getting rf id with blank otp (Íñigo Huguet) [2043453]
- cfg80211: fix kernel-doc for MBSSID EMA (Íñigo Huguet) [2043453]
- mac80211: Prevent AP probing during suspend (Íñigo Huguet) [2043453]
- nl80211: Add LC placeholder band definition to nl80211_band (Íñigo Huguet) [2043453]
- mac80211: split beacon retrieval functions (Íñigo Huguet) [2043453]
- cfg80211: separate get channel number from ies (Íñigo Huguet) [2043453]
- mac80211: use ieee80211_bss_get_elem() in most places (Íñigo Huguet) [2043453]
- cfg80211: scan: use element finding functions in easy cases (Íñigo Huguet) [2043453]
- nl80211: use element finding functions (Íñigo Huguet) [2043453]
- mac80211: fils: use cfg80211_find_ext_elem() (Íñigo Huguet) [2043453]
- mac80211: fix memory leaks with element parsing (Íñigo Huguet) [2043453]
- cfg80211: prepare for const netdev->dev_addr (Íñigo Huguet) [2043453]
- mac80211: use eth_hw_addr_set() (Íñigo Huguet) [2043453]
- wireless: mac80211_hwsim: use eth_hw_addr_set() (Íñigo Huguet) [2043453]
- mac80211: debugfs: calculate free buffer size correctly (Íñigo Huguet) [2043453]
- fq_codel: generalise ce_threshold marking for subset of traffic (Íñigo Huguet) [2043453]
- wl3501_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043453]
- ray_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043453]
- brcmfmac: prepare for const netdev->dev_addr (Íñigo Huguet) [2043453]
- wireless: use eth_hw_addr_set() instead of ether_addr_copy() (Íñigo Huguet) [2043453]
- wireless: use eth_hw_addr_set() (Íñigo Huguet) [2043453]
- iwlwifi: cfg: set low-latency-xtal for some integrated So devices (Íñigo Huguet) [2043453]
- iwlwifi: pnvm: read EFI data only if long enough (Íñigo Huguet) [2043453]
- iwlwifi: pnvm: don't kmemdup() more than we have (Íñigo Huguet) [2043453]
- iwlwifi: change all JnP to NO-160 configuration (Íñigo Huguet) [2043453]
- iwlwifi: mvm: reset PM state on unsuccessful resume (Íñigo Huguet) [2043453]
- mwifiex: Deactive host sleep using HSCFG after it was activated manually (Íñigo Huguet) [2043453]
- mwifiex: Send DELBA requests according to spec (Íñigo Huguet) [2043453]
- mwifiex: Fix an incorrect comment (Íñigo Huguet) [2043453]
- mwifiex: Log an error on command failure during key-material upload (Íñigo Huguet) [2043453]
- mwifiex: Don't log error on suspend if wake-on-wlan is disabled (Íñigo Huguet) [2043453]
- mt76: mt7915: change max rx len limit of hw modules (Íñigo Huguet) [2043453]
- mt76: mt7915: fix missing HE phy cap (Íñigo Huguet) [2043453]
- mt76: mt7915: rework mt7915_mcu_sta_muru_tlv() (Íñigo Huguet) [2043453]
- mt76: mt7915: enable HE UL MU-MIMO (Íñigo Huguet) [2043453]
- mt76: mt7921: add per-vif counters in ethtool (Íñigo Huguet) [2043453]
- mt76: mt7921: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043453]
- mt76: mt7921: add sta stats accounting in mt7921_mac_add_txs_skb (Íñigo Huguet) [2043453]
- mt76: mt7921: introduce stats reporting through ethtool (Íñigo Huguet) [2043453]
- mt76: mt7921: add some more MIB counters (Íñigo Huguet) [2043453]
- mt76: do not reset MIB counters in get_stats callback (Íñigo Huguet) [2043453]
- mt76: mt7915: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043453]
- mt76: mt7915: run mt7915_get_et_stats holding mt76 mutex (Íñigo Huguet) [2043453]
- mt76: move mt76_ethtool_worker_info in mt76 module (Íñigo Huguet) [2043453]
- mt76: move mt76_sta_stats in mt76.h (Íñigo Huguet) [2043453]
- mt76: mt76x0: correct VHT MCS 8/9 tx power eeprom offset (Íñigo Huguet) [2043453]
- mt76: mt7921s: add reset support (Íñigo Huguet) [2043453]
- mt76: mt7921: introduce mt7921s support (Íñigo Huguet) [2043453]
- mt76: mt7921: refactor mt7921_mcu_send_message (Íñigo Huguet) [2043453]
- mt76: mt7921: rely on mcu_get_nic_capability (Íñigo Huguet) [2043453]
- mt76: connac: extend mcu_get_nic_capability (Íñigo Huguet) [2043453]
- mt76: sdio: extend sdio module to support CONNAC2 (Íñigo Huguet) [2043453]
- mt76: sdio: introduce parse_irq callback (Íñigo Huguet) [2043453]
- mt76: sdio: move common code in mt76_sdio module (Íñigo Huguet) [2043453]
- mt76: mt7921: use physical addr to unify register access (Íñigo Huguet) [2043453]
- mt76: mt7921: make all event parser reusable between mt7921s and mt7921e (Íñigo Huguet) [2043453]
- mt76: mt7663s: rely on mcu reg access utility (Íñigo Huguet) [2043453]
- mt76: connac: move mcu reg access utility routines in mt76_connac_lib module (Íñigo Huguet) [2043453]
- mt76: mt7921: add MT7921_COMMON module (Íñigo Huguet) [2043453]
- mt76: mt7921: refactor init.c to be bus independent (Íñigo Huguet) [2043453]
- mt76: mt7921: refactor mcu.c to be bus independent (Íñigo Huguet) [2043453]
- mt76: mt7921: refactor dma.c to be pcie specific (Íñigo Huguet) [2043453]
- mt76: mt7921: refactor mac.c to be bus independent (Íñigo Huguet) [2043453]
- mt76: mt7921: add MU EDCA cmd support (Íñigo Huguet) [2043453]
- mt76: mt7915: remove dead code in debugfs code (Íñigo Huguet) [2043453]
- mt76: sdio: export mt76s_alloc_rx_queue and mt76s_alloc_tx routines (Íñigo Huguet) [2043453]
- mt76: mt7915: improve code readability for xmit-queue handler (Íñigo Huguet) [2043453]
- mt76: mt7915: introduce mt76 debugfs sub-dir for ext-phy (Íñigo Huguet) [2043453]
- mt76: rely on phy pointer in mt76_register_debugfs_fops routine signature (Íñigo Huguet) [2043453]
- mt76: mt7915: set muru platform type (Íñigo Huguet) [2043453]
- mt76: mt7915: set VTA bit in tx descriptor (Íñigo Huguet) [2043453]
- mt76: mt7915: fix muar_idx in mt7915_mcu_alloc_sta_req() (Íñigo Huguet) [2043453]
- mt76: mt7915: rework starec TLV tags (Íñigo Huguet) [2043453]
- mt76: mt7915: fix sta_rec_wtbl tag len (Íñigo Huguet) [2043453]
- mt76: mt7915: improve starec readability of txbf (Íñigo Huguet) [2043453]
- mt76: mt7915: fix txbf starec TLV issues (Íñigo Huguet) [2043453]
- mt76: mt7915: introduce mt7915_mcu_beacon_check_caps() (Íñigo Huguet) [2043453]
- mt76: connac: fix possible NULL pointer dereference in mt76_connac_get_phy_mode_v2 (Íñigo Huguet) [2043453]
- mt76: do not access 802.11 header in ccmp check for 802.3 rx skbs (Íñigo Huguet) [2043453]
- mt76: use a separate CCMP PN receive counter for management frames (Íñigo Huguet) [2043453]
- mt76: mt7921: add delay config for sched scan (Íñigo Huguet) [2043453]
- mt76: mt7615: fix monitor mode tear down crash (Íñigo Huguet) [2043453]
- mt76: debugfs: improve queue node readability (Íñigo Huguet) [2043453]
- mt76: mt7915: add twt_stats knob in debugfs (Íñigo Huguet) [2043453]
- mt76: mt7915: enable twt responder capability (Íñigo Huguet) [2043453]
- mt76: mt7915: introduce mt7915_mac_add_twt_setup routine (Íñigo Huguet) [2043453]
- mt76: mt7915: introduce mt7915_mcu_twt_agrt_update mcu command (Íñigo Huguet) [2043453]
- mt76: mt7915: introduce __mt7915_get_tsf routine (Íñigo Huguet) [2043453]
- mt76: drop MCU header size from buffer size in __mt76_mcu_send_firmware (Íñigo Huguet) [2043453]
- mt76: introduce __mt76_mcu_send_firmware routine (Íñigo Huguet) [2043453]
- mt76: support reading EEPROM data embedded in fdt (Íñigo Huguet) [2043453]
- mt76: schedule status timeout at dma completion (Íñigo Huguet) [2043453]
- mt76: substitute sk_buff_head status_list with spinlock_t status_lock (Íñigo Huguet) [2043453]
- mt76: remove mt76_wcid pointer from mt76_tx_status_check signature (Íñigo Huguet) [2043453]
- mt76: introduce packet_id idr (Íñigo Huguet) [2043453]
- mt76: mt7921: add 6GHz support (Íñigo Huguet) [2043453]
- mt76: add 6GHz support (Íñigo Huguet) [2043453]
- mt76: connac: enable hw amsdu @ 6GHz (Íñigo Huguet) [2043453]
- mt76: connac: add 6GHz support to mt76_connac_mcu_uni_add_bss (Íñigo Huguet) [2043453]
- mt76: connac: add 6GHz support to mt76_connac_mcu_sta_tlv (Íñigo Huguet) [2043453]
- mt76: connac: set 6G phymode in single-sku support (Íñigo Huguet) [2043453]
- mt76: connac: add 6GHz support to mt76_connac_mcu_set_channel_domain (Íñigo Huguet) [2043453]
- mt76: connac: enable 6GHz band for hw scan (Íñigo Huguet) [2043453]
- mt76: connac: set 6G phymode in mt76_connac_get_phy_mode{,v2} (Íñigo Huguet) [2043453]
- mt76: mt7915: add mib counters to ethtool stats (Íñigo Huguet) [2043453]
- mt76: mt7915: add more MIB registers (Íñigo Huguet) [2043453]
- mt76: mt7915: add tx mu/su counters to mib (Íñigo Huguet) [2043453]
- mt76: mt7915: add some per-station tx stats to ethtool (Íñigo Huguet) [2043453]
- mt76: mt7915: add tx stats gathered from tx-status callbacks (Íñigo Huguet) [2043453]
- mt76: mt7915: add ethtool stats support (Íñigo Huguet) [2043453]
- mt76: mt7921: fix retrying release semaphore without end (Íñigo Huguet) [2043453]
- mt76: mt7921: robustify hardware initialization flow (Íñigo Huguet) [2043453]
- mt76: mt7915: fix possible infinite loop release semaphore (Íñigo Huguet) [2043453]
- mt76: mt7915: honor all possible error conditions in mt7915_mcu_init() (Íñigo Huguet) [2043453]
- mt76: move spin_lock_bh to spin_lock in tasklet (Íñigo Huguet) [2043453]
- mt76: mt7921: remove mt7921_sta_stats (Íñigo Huguet) [2043453]
- mt76: mt7921: remove mcu rate reporting code (Íñigo Huguet) [2043453]
- mt76: mt7921: report tx rate directly from tx status (Íñigo Huguet) [2043453]
- mt76: mt7921: add support for tx status reporting (Íñigo Huguet) [2043453]
- mt76: mt7921: start reworking tx rate reporting (Íñigo Huguet) [2043453]
- mt76: mt7615: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043453]
- mt76: mt7915: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043453]
- mt76: mt7915: enable configured beacon tx rate (Íñigo Huguet) [2043453]
- mt76: disable BH around napi_schedule() calls (Íñigo Huguet) [2043453]
- mt76: fill boottime_ns in Rx path (Íñigo Huguet) [2043453]
- mt76: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2043453]
- mt76: fix boolreturn.cocci warnings (Íñigo Huguet) [2043453]
- mt76: mt7921: update mib counters dumping phy stats (Íñigo Huguet) [2043453]
- mt76: mt7921: always wake device if necessary in debugfs (Íñigo Huguet) [2043453]
- mt76: mt7915: rename debugfs tx-queues (Íñigo Huguet) [2043453]
- mt76: mt7915: rework debugfs queue info (Íñigo Huguet) [2043453]
- mt76: mt7921: move mt7921_queue_rx_skb to mac.c (Íñigo Huguet) [2043453]
- mt76: mt7915: fix WMM index on DBDC cards (Íñigo Huguet) [2043453]
- mt76: mt7915: improve code readability in mt7915_mcu_sta_bfer_ht (Íñigo Huguet) [2043453]
- mt76: mt7915: introduce bss coloring support (Íñigo Huguet) [2043453]
- mt76: mt7915: add LED support (Íñigo Huguet) [2043453]
- mt76: mt7915: fix potential NPE in TXS processing (Íñigo Huguet) [2043453]
- mt76: mt7915: fix he_mcs capabilities for 160mhz (Íñigo Huguet) [2043453]
- mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD (Íñigo Huguet) [2043453]
- mt76: mt7915: update mac timing settings (Íñigo Huguet) [2043453]
- mt76: mt7921: fix endianness warnings in mt7921_mac_decode_he_mu_radiotap (Íñigo Huguet) [2043453]
- mt76: mt7921: fix kernel warning from cfg80211_calculate_bitrate (Íñigo Huguet) [2043453]
- mt76: mt7921: fix firmware usage of RA info using legacy rates (Íñigo Huguet) [2043453]
- mt76: mt7915: add HE-LTF into fixed rate command (Íñigo Huguet) [2043453]
- mt76: mt7921: report HE MU radiotap (Íñigo Huguet) [2043453]
- mt76: mt7615: move mt7615_mcu_set_p2p_oppps in mt76_connac module (Íñigo Huguet) [2043453]
- mt76: overwrite default reg_ops if necessary (Íñigo Huguet) [2043453]
- mt76: mt7921: introduce mt7921_mcu_set_beacon_filter utility routine (Íñigo Huguet) [2043453]
- mt76: mt7921: get rid of mt7921_mac_set_beacon_filter (Íñigo Huguet) [2043453]
- mt76: mt7921: get rid of monitor_vif (Íñigo Huguet) [2043453]
- mt76: connac: add support for limiting to maximum regulatory Tx power (Íñigo Huguet) [2043453]
- mt76: connac: fix GTK rekey offload failure on WPA mixed mode (Íñigo Huguet) [2043453]
- mt76: mt7921: fix dma hang in rmmod (Íñigo Huguet) [2043453]
- mt76: add support for setting mcast rate (Íñigo Huguet) [2043453]
- mt76: mt7915: fix bit fields for HT rate idx (Íñigo Huguet) [2043453]
- mt76: mt7915: switch proper tx arbiter mode in testmode (Íñigo Huguet) [2043453]
- mt76: mt7915: fix potential overflow of eeprom page index (Íñigo Huguet) [2043453]
- mt76: mt7921: send EAPOL frames at lowest rate (Íñigo Huguet) [2043453]
- mt76: mt7915: send EAPOL frames at lowest rate (Íñigo Huguet) [2043453]
- mt76: mt7915: add control knobs for thermal throttling (Íñigo Huguet) [2043453]
- mt76: mt7921: Add mt7922 support (Íñigo Huguet) [2043453]
- mt76: mt7615: fix skb use-after-free on mac reset (Íñigo Huguet) [2043453]
- mt76: mt7921: Fix out of order process by invalid event pkt (Íñigo Huguet) [2043453]
- mt76: mt7915: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043453]
- mt76: mt7921: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043453]
- mt76: add mt76_default_basic_rate more devices can rely on (Íñigo Huguet) [2043453]
- mt76: mt7921: introduce testmode support (Íñigo Huguet) [2043453]
- mt76: mt7915: remove mt7915_sta_stats (Íñigo Huguet) [2043453]
- mt76: mt7915: report tx rate directly from tx status (Íñigo Huguet) [2043453]
- mt76: mt7915: cleanup -Wunused-but-set-variable (Íñigo Huguet) [2043453]
- mt76: mt7915: take RCU read lock when calling ieee80211_bss_get_elem() (Íñigo Huguet) [2043453]
- mt76: mt7915: fix an off-by-one bound check (Íñigo Huguet) [2043453]
- mt76: mt7921: add .set_sar_specs support (Íñigo Huguet) [2043453]
- mt76: mt7915: adapt new firmware to update BA winsize for Rx session (Íñigo Huguet) [2043453]
- mt76: mt7915: report HE MU radiotap (Íñigo Huguet) [2043453]
- mt76: mt76x02: fix endianness warnings in mt76x02_mac.c (Íñigo Huguet) [2043453]
- mt76: mt7921: fix survey-dump reporting (Íñigo Huguet) [2043453]
- mt76: fix build error implicit enumeration conversion (Íñigo Huguet) [2043453]
- mt76: mt7921: enable aspm by default (Íñigo Huguet) [2043453]
- mt76: connac: fix mt76_connac_gtk_rekey_tlv usage (Íñigo Huguet) [2043453]
- mt76: mt7915: fix calling mt76_wcid_alloc with incorrect parameter (Íñigo Huguet) [2043453]
- mt76: mt7915: fix info leak in mt7915_mcu_set_pre_cal() (Íñigo Huguet) [2043453]
- mt76: mt7615: fix endianness warning in mt7615_mac_write_txwi (Íñigo Huguet) [2043453]
- mt76: mt7921: fix endianness warning in mt7921_update_txs (Íñigo Huguet) [2043453]
- mt76: mt7915: fix endianness warning in mt7915_mac_add_txs_skb (Íñigo Huguet) [2043453]
- mt76: mt7921: avoid unnecessary spin_lock/spin_unlock in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043453]
- mt76: mt7921: fix endianness in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043453]
- mwifiex: Try waking the firmware until we get an interrupt (Íñigo Huguet) [2043453]
- mwifiex: Read a PCI register after writing the TX ring write pointer (Íñigo Huguet) [2043453]
- fq_codel: implement L4S style ce_threshold_ect1 marking (Íñigo Huguet) [2043453]
- net: add skb_get_dsfield() helper (Íñigo Huguet) [2043453]
- wireless: Remove redundant 'flush_workqueue()' calls (Íñigo Huguet) [2043453]
- mt7601u: Remove redundant initialization of variable ret (Íñigo Huguet) [2043453]
- rtlwifi: rtl8192ee: Remove redundant initialization of variable version (Íñigo Huguet) [2043453]
- ath10k: fix max antenna gain unit (Íñigo Huguet) [2043453]
- ath9k: fix an IS_ERR() vs NULL check (Íñigo Huguet) [2043453]
- ath11k: Identify DFS channel when sending scan channel list command (Íñigo Huguet) [2043453]
- ath9k: support DT ieee80211-freq-limit property to limit channels (Íñigo Huguet) [2043453]
- ath11k: Change number of TCL rings to one for QCA6390 (Íñigo Huguet) [2043453]
- ath11k: Handle MSI enablement during rmmod and SSR (Íñigo Huguet) [2043453]
- ath: dfs_pattern_detector: Fix possible null-pointer dereference in channel_detector_create() (Íñigo Huguet) [2043453]
- ath11k: Use kcalloc() instead of kzalloc() (Íñigo Huguet) [2043453]
- ath11k: Remove redundant assignment to variable fw_size (Íñigo Huguet) [2043453]
- ath11k: fix m68k and xtensa build failure in ath11k_peer_assoc_h_smps() (Íñigo Huguet) [2043453]
- ath11k: Fix spelling mistake "incompaitiblity" -> "incompatibility" (Íñigo Huguet) [2043453]
- ath11k: Remove unused variable in ath11k_dp_rx_mon_merg_msdus() (Íñigo Huguet) [2043453]
- ath9k: Fix potential interrupt storm on queue reset (Íñigo Huguet) [2043453]
- ath9k: add option to reset the wifi chip via debugfs (Íñigo Huguet) [2043453]
- ath10k: Don't always treat modem stop events as crashes (Íñigo Huguet) [2043453]
- rtl8xxxu: Use lower tx rates for the ack packet (Íñigo Huguet) [2043453]
- brcmfmac: Add DMI nvram filename quirk for Cyberbook T116 tablet (Íñigo Huguet) [2043453]
- rtw88: refine fw_crash debugfs to show non-zero while triggering (Íñigo Huguet) [2043453]
- rtw88: fix RX clock gate setting while fifo dump (Íñigo Huguet) [2043453]
- net: qrtr: combine nameservice into main module (Íñigo Huguet) [2043453]
- ath10k: sdio: Add missing BH locking around napi_schdule() (Íñigo Huguet) [2043453]
- ath10k: Fix missing frame timestamp for beacon/probe-resp (Íñigo Huguet) [2043453]
- ath10k: high latency fixes for beacon buffer (Íñigo Huguet) [2043453]
- ath11k: Change DMA_FROM_DEVICE to DMA_TO_DEVICE when map reinjected packets (Íñigo Huguet) [2043453]
- ath11k: support SMPS configuration for 6 GHz (Íñigo Huguet) [2043453]
- ath11k: add 6 GHz params in peer assoc command (Íñigo Huguet) [2043453]
- ieee80211: Add new A-MPDU factor macro for HE 6 GHz peer caps (Íñigo Huguet) [2043453]
- ath11k: indicate to mac80211 scan complete with aborted flag for ATH11K_SCAN_STARTING state (Íñigo Huguet) [2043453]
- ath11k: indicate scan complete for scan canceled when scan running (Íñigo Huguet) [2043453]
- ath11k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED (Íñigo Huguet) [2043453]
- ath11k: add HTT stats support for new stats (Íñigo Huguet) [2043453]
- ath11k: Change masking and shifting in htt stats (Íñigo Huguet) [2043453]
- ath11k: Remove htt stats fixed size array usage (Íñigo Huguet) [2043453]
- ath11k: Replace HTT_DBG_OUT with scnprintf (Íñigo Huguet) [2043453]
- ath11k: Rename macro ARRAY_TO_STRING to PRINT_ARRAY_TO_BUF (Íñigo Huguet) [2043453]
- ath11k: Fix memory leak in ath11k_qmi_driver_event_work (Íñigo Huguet) [2043453]
- ath11k: Fix inaccessible debug registers (Íñigo Huguet) [2043453]
- ath11k: Drop MSDU with length error in DP rx path (Íñigo Huguet) [2043453]
- ath11k: copy cap info of 6G band under WMI_HOST_WLAN_5G_CAP for WCN6855 (Íñigo Huguet) [2043453]
- ath11k: enable 6G channels for WCN6855 (Íñigo Huguet) [2043453]
- ath11k: re-enable ht_cap/vht_cap for 5G band for WCN6855 (Íñigo Huguet) [2043453]
- ath11k: fix survey dump collection in 6 GHz (Íñigo Huguet) [2043453]
- ath11k: fix packet drops due to incorrect 6 GHz freq value in rx status (Íñigo Huguet) [2043453]
- ath11k: add channel 2 into 6 GHz channel list (Íñigo Huguet) [2043453]
- mac80211: MBSSID support in interface handling (Íñigo Huguet) [2043453]
- ath11k: Add wmi peer create conf event in wmi_tlv_event_id (Íñigo Huguet) [2043453]
- ath11k: Avoid "No VIF found" warning message (Íñigo Huguet) [2043453]
- ath11k: Fix crash during firmware recovery on reo cmd ring access (Íñigo Huguet) [2043453]
- ath11k: Assign free_vdev_map value before ieee80211_register_hw (Íñigo Huguet) [2043453]
- ath11k: Add vdev start flag to disable hardware encryption (Íñigo Huguet) [2043453]
- ath11k: Avoid race during regd updates (Íñigo Huguet) [2043453]
- ath11k: Avoid reg rules update during firmware recovery (Íñigo Huguet) [2043453]
- ath11k: Update pdev tx and rx firmware stats (Íñigo Huguet) [2043453]
- ath11k: Fix pktlog lite rx events (Íñigo Huguet) [2043453]
- ath11k: Add support for RX decapsulation offload (Íñigo Huguet) [2043453]
- ath11k: fix some sleeping in atomic bugs (Íñigo Huguet) [2043453]
- ath11k: qmi: avoid error messages when dma allocation fails (Íñigo Huguet) [2043453]
- ath11k: Replace one-element array with flexible-array member (Íñigo Huguet) [2043453]
- ath11k: add caldata download support from EEPROM (Íñigo Huguet) [2043453]
- ath11k: add caldata file for multiple radios (Íñigo Huguet) [2043453]
- ath11k: clean up BDF download functions (Íñigo Huguet) [2043453]
- ath11k: use hw_params to access board_size and cal_offset (Íñigo Huguet) [2043453]
- ath11k: Wstringop-overread warning (Íñigo Huguet) [2043453]
- ath11k: Add spectral scan support for QCN9074 (Íñigo Huguet) [2043453]
- ath11k: Fix the spectral minimum FFT bin count (Íñigo Huguet) [2043453]
- ath11k: Introduce spectral hw configurable param (Íñigo Huguet) [2043453]
- ath11k: Refactor spectral FFT bin size (Íñigo Huguet) [2043453]
- ath11k: add support for 80P80 and 160 MHz bandwidth (Íñigo Huguet) [2043453]
- ath11k: add support for setting fixed HE rate/gi/ltf (Íñigo Huguet) [2043453]
- nl80211: MBSSID and EMA support in AP mode (Íñigo Huguet) [2043453]
- nl80211: don't kfree() ERR_PTR() value (Íñigo Huguet) [2043453]
- cfg80211: always free wiphy specific regdomain (Íñigo Huguet) [2043453]
- mac80211: save transmit power envelope element and power constraint (Íñigo Huguet) [2043453]
- mac80211: add parse regulatory info in 6 GHz operation information (Íñigo Huguet) [2043453]
- ieee80211: add power type definition for 6 GHz (Íñigo Huguet) [2043453]
- mac80211: twt: don't use potentially unaligned pointer (Íñigo Huguet) [2043453]
- cfg80211: AP mode driver offload for FILS association crypto (Íñigo Huguet) [2043453]
- ath11k: monitor mode clean up to use separate APIs (Íñigo Huguet) [2043453]
- ath11k: add separate APIs for monitor mode (Íñigo Huguet) [2043453]
- ath11k: move static function ath11k_mac_vdev_setup_sync to top (Íñigo Huguet) [2043453]
- rtw88: 8821c: correct 2.4G tx power for type 2/4 NIC (Íñigo Huguet) [2043453]
- rtw88: 8821c: support RFE type4 wifi NIC (Íñigo Huguet) [2043453]
- brcmfmac: Replace zero-length array with flexible array member (Íñigo Huguet) [2043453]
- mac80211_hwsim: enable 6GHz channels (Íñigo Huguet) [2043453]
- mac80211: use ieee802_11_parse_elems() in ieee80211_prep_channel() (Íñigo Huguet) [2043453]
- nl80211: don't put struct cfg80211_ap_settings on stack (Íñigo Huguet) [2043453]
- mac80211: always allocate struct ieee802_11_elems (Íñigo Huguet) [2043453]
- mac80211: mlme: find auth challenge directly (Íñigo Huguet) [2043453]
- mac80211: move CRC into struct ieee802_11_elems (Íñigo Huguet) [2043453]
- mac80211: mesh: clean up rx_bcn_presp API (Íñigo Huguet) [2043453]
- mac80211: reduce stack usage in debugfs (Íñigo Huguet) [2043453]
- nl80211: prefer struct_size over open coded arithmetic (Íñigo Huguet) [2043453]
- mac80211: check hostapd configuration parsing twt requests (Íñigo Huguet) [2043453]
- cfg80211: honour V=1 in certificate code generation (Íñigo Huguet) [2043453]
- rt2x00: remove duplicate USB device ID (Íñigo Huguet) [2043453]
- mwifiex: Fix copy-paste mistake when creating virtual interface (Íñigo Huguet) [2043453]
- mwifiex: Properly initialize private structure on interface type changes (Íñigo Huguet) [2043453]
- mwifiex: Handle interface type changes from AP to STATION (Íñigo Huguet) [2043453]
- mwifiex: Allow switching interface type from P2P_CLIENT to P2P_GO (Íñigo Huguet) [2043453]
- mwifiex: Update virtual interface counters right after setting bss_type (Íñigo Huguet) [2043453]
- mwifiex: Use helper function for counting interface types (Íñigo Huguet) [2043453]
- mwifiex: Run SET_BSS_MODE when changing from P2P to STATION vif-type (Íñigo Huguet) [2043453]
- mwifiex: Use function to check whether interface type change is allowed (Íñigo Huguet) [2043453]
- mwifiex: Small cleanup for handling virtual interface type changes (Íñigo Huguet) [2043453]
- rtw88: move adaptivity mechanism to firmware (Íñigo Huguet) [2043453]
- rtw88: support adaptivity for ETSI/JP DFS region (Íñigo Huguet) [2043453]
- rtw88: add regulatory strategy by chip type (Íñigo Huguet) [2043453]
- rtw88: upgrade rtw_regulatory mechanism and mapping (Íñigo Huguet) [2043453]
- brcmfmac: fix incorrect error prints (Íñigo Huguet) [2043453]
- ath11k: Align bss_chan_info structure with firmware (Íñigo Huguet) [2043453]
- ath11k: add support in survey dump with bss_chan_info (Íñigo Huguet) [2043453]
- ath11k: Rename atf_config to flag1 in target_resource_config (Íñigo Huguet) [2043453]
- ath11k: fix 4addr multicast packet tx (Íñigo Huguet) [2043453]
- ath11k: fix 4-addr tx failure for AP and STA modes (Íñigo Huguet) [2043453]
- ath9k: owl-loader: fetch pci init values through nvmem (Íñigo Huguet) [2043453]
- ath9k: fetch calibration data via nvmem subsystem (Íñigo Huguet) [2043453]
- ath9k: Use tasklet_disable_in_atomic() (Íñigo Huguet) [2043453]
- mt76: fix wrong conflict resolution in previous backport (Íñigo Huguet) [2043453]
- mac80211: Allow HE operation to be longer than expected. (Íñigo Huguet) [2043453]
- revert ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2043453]
- RDMA/mlx5: Delete right entry from MR signature database (Amir Tzin) [1982191]
- net/mlx5e: Fix select queue to consider SKBTX_HW_TSTAMP (Amir Tzin) [1982191]
- net/mlx5e: Don't update netdev RQs with PTP-RQ (Amir Tzin) [1982191]
- net/mlx5e: Fix an error code in mlx5e_arfs_create_tables() (Amir Tzin) [1982191]
- net/mlx5e: Fix conflict with HW TS and CQE compression (Amir Tzin) [1982191]
- net/mlx5e: Fix HW TS with CQE compression according to profile (Amir Tzin) [1982191]
- mlx5e: add add missing BH locking around napi_schdule() (Amir Tzin) [1982191]
- net/mlx5: Don't overwrite HCA capabilities when setting MSI-X count (Amir Tzin) [1982191]
- net/mlx5: Fix err prints and return when creating termination table (Amir Tzin) [1982191]
- RDMA/mlx5: Verify that DM operation is reasonable (Amir Tzin) [1982191]
- RDMA/mlx5: Expose private query port (Amir Tzin) [1982191]
- RDMA/mlx5: Fix type assignment for ICM DM (Amir Tzin) [1982191]
- net/mlx5: DR, Add support for isolate_vl_tc QP (Amir Tzin) [1982191]
- net/mlx5: DR, Add support for force-loopback QP (Amir Tzin) [1982191]
- net/mlx5: DR, Add support for matching tunnel GTP-U (Amir Tzin) [1982191]
- net/mlx5: DR, Set flex parser for TNL_MPLS dynamically (Amir Tzin) [1982191]
- net/mlx5: DR, Add support for matching on geneve TLV option (Amir Tzin) [1982191]
- net/mlx5: DR, Set STEv0 ICMP flex parser dynamically (Amir Tzin) [1982191]
- net/mlx5: DR, Add support for dynamic flex parser (Amir Tzin) [1982191]
- net/mlx5: DR, Remove protocol-specific flex_parser_3 definitions (Amir Tzin) [1982191]
- net/mlx5: mlx5_ifc updates for flex parser (Amir Tzin) [1982191]
- net/mlx5: E-Switch, Improve error messages in term table creation (Amir Tzin) [1982191]
- net/mlx5: DR, Rename an argument in dr_rdma_segments (Amir Tzin) [1982191]
- net/mlx5e: RX, Add checks for calculated Striding RQ attributes (Amir Tzin) [1982191]
- net/mlx5e: Fix possible non-initialized struct usage (Amir Tzin) [1982191]
- mlx5: implement ethtool standard stats (Amir Tzin) [1982191]
- net/mlx5: Enhance diagnostics info for TX/RX reporters (Amir Tzin) [1982191]
- net/mlx5: Add helper to initialize 1PPS (Amir Tzin) [1982191]
- net/mlx5e: Add ethtool extended link state (Amir Tzin) [1982191 1982232]
- net/mlx5: Add register layout to support extended link state (Amir Tzin) [1982191 1982232]
- net/mlx5: Allocate FC bulk structs with kvzalloc() instead of kzalloc() (Amir Tzin) [1982191]
- net/mlx5e: Cleanup safe switch channels API by passing params (Amir Tzin) [1982191]
- net/mlx5e: Refactor on-the-fly configuration changes (Amir Tzin) [1982191]
- net/mlx5e: Use mlx5e_safe_switch_channels when channels are closed (Amir Tzin) [1982191]
- net/mlx5e: Allow mlx5e_safe_switch_channels to work with channels closed (Amir Tzin) [1982191]
- mlx5: implement ethtool::get_fec_stats (Amir Tzin) [1982191]
- net/mlx5e: Fix RQ creation flow for queues which doesn't support XDP (Amir Tzin) [1982191]
- net/mlx5: Remove return statement exist at the end of void function (Amir Tzin) [1982191]
- net/mlx5: Add a blank line after declarations (Amir Tzin) [1982191]
- net/mlx5: DR, Alloc cmd buffer with kvzalloc() instead of kzalloc() (Amir Tzin) [1982191]
- net/mlx5: DR, Use variably sized data structures for different actions (Amir Tzin) [1982191]
- RDMA/mlx5: Expose UAPI to query DM (Amir Tzin) [1982191 1926606 1926603]
- RDMA/mlx5: Add support in MEMIC operations (Amir Tzin) [1982191 1926606 1926603]
- RDMA/mlx5: Add support to MODIFY_MEMIC command (Amir Tzin) [1982191 1926606 1926603]
- RDMA/mlx5: Re-organize the DM code (Amir Tzin) [1982191 1926606 1926603]
- RDMA/mlx5: Move all DM logic to separate file (Amir Tzin) [1982191 1926606 1926603]
- net/mlx5: Add MEMIC operations related bits (Amir Tzin) [1982191 1926606 1926603]
- net/mlx5: Add support for DSFP module EEPROM dumps (Amir Tzin) [1982191 1982233]
- net/mlx5: Implement get_module_eeprom_by_page() (Amir Tzin) [1982191 1982233]
- net/mlx5: Refactor module EEPROM query (Amir Tzin) [1982191 1982233]
- IB/mlx5: Reduce max order of memory allocated for xlt update (Amir Tzin) [1982191]
- net/mlx5: Implement sriov_get_vf_total_msix/count() callbacks (Amir Tzin) [1982191 1982230]
- net/mlx5: Dynamically assign MSI-X vectors count (Amir Tzin) [1982191 1982230]
- net/mlx5: Add dynamic MSI-X capabilities bits (Amir Tzin) [1982191 1982230]
- net/mlx5e: Dynamic alloc vlan table for netdev when needed (Amir Tzin) [1982191]
- net/mlx5e: Dynamic alloc arfs table for netdev when needed (Amir Tzin) [1982191]
- net/mlx5: Use ida_alloc_range() instead of ida_simple_alloc() (Amir Tzin) [1982191]
- net/mlx5e: Update ethtool setting of CQE compression (Amir Tzin) [1982191]
- net/mlx5e: Allow coexistence of CQE compression and HW TS PTP (Amir Tzin) [1982191]
- net/mlx5e: Add PTP Flow Steering support (Amir Tzin) [1982191]
- net/mlx5e: Introduce Flow Steering ANY API (Amir Tzin) [1982191]
- net/mlx5e: Introduce Flow Steering UDP API (Amir Tzin) [1982191]
- net/mlx5e: Cleanup Flow Steering level (Amir Tzin) [1982191]
- net/mlx5e: Add PTP RQ to RX reporter (Amir Tzin) [1982191]
- net/mlx5e: Refactor RX reporter diagnostics (Amir Tzin) [1982191]
- net:mlx5e: Add PTP-TIR and PTP-RQT (Amir Tzin) [1982191]
- net/mlx5e: Add PTP-RX statistics (Amir Tzin) [1982191]
- net/mlx5e: Add RQ to PTP channel (Amir Tzin) [1982191]
- net/mlx5e: Add states to PTP channel (Amir Tzin) [1982191]
- RDMA/mlx5: Set ODP caps only if device profile support ODP (Amir Tzin) [1982191]
- net/mlx5e: Cleanup PTP (Amir Tzin) [1982191]
- net/mlx5e: Generalize PTP implementation (Amir Tzin) [1982191]
- net/mlx5e: Generalize direct-TIRs and direct-RQTs API (Amir Tzin) [1982191]
- net/mlx5e: Generalize close RQ (Amir Tzin) [1982191]
- net/mlx5e: Generalize RQ activation (Amir Tzin) [1982191]
- net/mlx5e: Generalize open RQ (Amir Tzin) [1982191]
- net/mlx5: Add helper to set time-stamp translator on a queue (Amir Tzin) [1982191]
- net/mlx5e: Allow creating mpwqe info without channel (Amir Tzin) [1982191]
- net/mlx5e: alloc the correct size for indirection_rqt (Amir Tzin) [1982191]
- net: ethernet: indir_table.h is included twice (Amir Tzin) [1982191 1982195]
- RDMA/mlx5: Create ODP EQ only when ODP MR is created (Amir Tzin) [1982191]
- RDMA/mlx5: Add missing returned error check of mlx5_ib_dereg_mr (Amir Tzin) [1982191]
- net/mlx5: Move devlink port from mlx5e priv to mlx5e resources (Amir Tzin) [1982191]
- net/mlx5e: Allow to match on ICMP parameters (Amir Tzin) [1982191]
- net/mlx5: Display the command index in command mailbox dump (Amir Tzin) [1982191]
- net/mlx5e: allocate 'indirection_rqt' buffer dynamically (Amir Tzin) [1982191]
- net/mlx5e: Dump ICOSQ WQE descriptor on CQE with error events (Amir Tzin) [1982191]
- net/mlx5e: Use net_prefetchw instead of prefetchw in MPWQE TX datapath (Amir Tzin) [1982191]
- net/mlx5e: Remove redundant newline in NL_SET_ERR_MSG_MOD (Amir Tzin) [1982191]
- net/mlx5: Read congestion counters from all ports when lag is active (Amir Tzin) [1982191]
- net/mlx5: remove unneeded semicolon (Amir Tzin) [1982191]
- net/mlx5: DR, Remove unneeded rx_decap_l3 function for STEv1 (Amir Tzin) [1982191]
- net/mlx5: Use order-0 allocations for EQs (Amir Tzin) [1982191]
- net/mlx5: Add IFC bits needed for single FDB mode (Amir Tzin) [1982191]
- net/mlx5: E-Switch, Refactor send to vport to be more generic (Amir Tzin) [1982191 1982195]
- RDMA/mlx5: Use representor E-Switch when getting netdev and metadata (Amir Tzin) [1982191]
- net/mlx5: E-Switch, Add eswitch pointer to each representor (Amir Tzin) [1982191 1982195]
- net/mlx5: E-Switch, Add match on vhca id to default send rules (Amir Tzin) [1982191 1982195]
- net/mlx5: Remove unused mlx5_core_health member recover_work (Amir Tzin) [1982191]
- net/mlx5: simplify the return expression of mlx5_esw_offloads_pair() (Amir Tzin) [1982191 1982195]
- net/mlx5: Cleanup prototype warning (Amir Tzin) [1982191]
- RDMA/mlx5: Allow larger pages in DevX umem (Amir Tzin) [1982191]
- RDMA/mlx5: Rename mlx5_mr_cache_invalidate() to revoke_mr() (Amir Tzin) [1982191]
- RDMA/mlx5: Consolidate MR destruction to mlx5_ib_dereg_mr() (Amir Tzin) [1982191]
- RDMA/mlx5: Use a union inside mlx5_ib_mr (Amir Tzin) [1982191]
- platform/mellanox: mlxbf-tmfifo: Fix a memory barrier issue (Amir Tzin) [2018145]
- mmc: dw_mmc-bluefield: : Fix the license information (Amir Tzin) [2018145]
- mmc: dw_mmc-bluefield: simplify the probe() function (Amir Tzin) [2018145]
- benet: mark device 0xe220 (Lancer) as deprecated (Michal Schmidt) [2054409]
- myri10ge: mark as deprecated (Michal Schmidt) [2054409]
- liquidio: mark as deprecated, not unmaintained (Michal Schmidt) [2054409]
- netxen_nic: remove unmaintained mark, keep deprecated (Michal Schmidt) [2054409]
- bnx2: mark as deprecated, not unmaintained (Michal Schmidt) [2054409]
- SUNRPC: Don't dereference xprt->snd_task if it's a cookie (Dave Wysochanski) [2046545]
- SUNRPC: Add source address/port to rpc_socket* traces (Dave Wysochanski) [2046545]
- netfilter: conntrack: re-init state for retransmitted syn-ack (Florian Westphal) [2043093]
- netfilter: conntrack: move synack init code to helper (Florian Westphal) [2043093]

* Wed Feb 23 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-370.el8]
- ibmvnic: remove unused defines (Diego Domingos) [2047920]
- ibmvnic: Update driver return codes (Diego Domingos) [2047920]
- ARM: iop32x: disable N2100 PCI parity reporting (Josef Oskera) [2031880]
- r8169: fix incorrect mac address assignment (Josef Oskera) [2031880]
- r8169: Add device 10ec:8162 to driver r8169 (Josef Oskera) [2031880]
- ethernet: r8169: use eth_hw_addr_set() (Josef Oskera) [2031880]
- net: phy: realtek: add support for RTL8365MB-VC internal PHYs (Josef Oskera) [2031880]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Josef Oskera) [2031880]
- r8169: enable ASPM L0s state (Josef Oskera) [2031880]
- r8169: rename rtl_csi_access_enable to rtl_set_aspm_entry_latency (Josef Oskera) [2031880]
- r8169: change the L0/L1 entrance latencies for RTL8106e (Josef Oskera) [2031880]
- Revert "r8169: avoid link-up interrupt issue on RTL8106e if user enables ASPM" (Josef Oskera) [2031880]
- r8169: Avoid duplicate sysfs entry creation error (Josef Oskera) [2031880]
- r8169: Avoid memcpy() over-reading of ETH_SS_STATS (Josef Oskera) [2031880]
- r8169: avoid link-up interrupt issue on RTL8106e if user enables ASPM (Josef Oskera) [2031880]
- net: phy: realtek: net: Fix less than zero comparison of a u16 (Josef Oskera) [2031880]
- net: phy: realtek: add delay to fix RXC generation issue (Josef Oskera) [2031880]
- net: phy: realtek: add dt property to enable ALDPS mode (Josef Oskera) [2031880]
- net: phy: realtek: add dt property to disable CLKOUT clock (Josef Oskera) [2031880]
- r8169: Fix fall-through warning for Clang (Josef Oskera) [2031880]
- r8169: use KBUILD_MODNAME instead of own module name definition (Josef Oskera) [2031880]
- r8169: keep pause settings on interface down/up cycle (Josef Oskera) [2031880]
- r8169: add support for pause ethtool ops (Josef Oskera) [2031880]
- r8169: use mac-managed PHY PM (Josef Oskera) [2031880]
- r8169: remove rtl_hw_start_8168c_3 (Josef Oskera) [2031880]
- r8169: add support for ethtool get_ringparam (Josef Oskera) [2031880]
- r8169: use lower_32_bits/upper_32_bits macros (Josef Oskera) [2031880]
- net: phy: make PHY PM ops a no-op if MAC driver manages PHY PM (Josef Oskera) [2031880]
- mm/gup: remove unused get_user_pages_locked() (Chris von Recklinghausen) [2048650]
- mm: change lookup_node() to use get_user_pages_fast() (Chris von Recklinghausen) [2048650]
- mm/gup: remove unused pin_user_pages_locked() (Chris von Recklinghausen) [2048650]
- mm/gup: follow_pfn_pte(): -EEXIST cleanup (Chris von Recklinghausen) [2048650]
- mm: fix invalid page pointer returned with FOLL_PIN gups (Chris von Recklinghausen) [2048650]
- mm: fix typos in comments (Chris von Recklinghausen) [2048650]
- vfio/iommu_type1: replace kfree with kvfree (Alex Williamson) [2046547]
- vfio/pci: Fix error return code in vfio_ecap_init() (Alex Williamson) [2046547]
- vfio/pci: Add missing range check in vfio_pci_mmap (Alex Williamson) [2046547]
- vfio/mdev: Do not allow a mdev_type to have a NULL parent pointer (Alex Williamson) [2046547]
- vfio/mdev: Make to_mdev_device() into a static inline (Alex Williamson) [2046547]
- vfio/iommu_type1: Mantain a counter for non_pinned_groups (Alex Williamson) [2046547]
- vfio/iommu_type1: Fix some sanity checks in detach group (Alex Williamson) [2046547]
- vfio/iommu_type1: Populate full dirty when detach non-pinned group (Alex Williamson) [2046547]
- vfio/pci: Move dummy_resources_list init in vfio_pci_probe() (Alex Williamson) [2046547]
- vfio/virqfd: Drain events from eventfd in virqfd_wakeup() (Alex Williamson) [2046547]
- ext4: fix direct I/O read error (Lukas Czerner) [1868258]
- usb: xhci: Extend support for runtime power management for AMD's Yellow carp. (Renjith Pananchikkal) [2015775]
- usb: xhci: Enable runtime-pm by default on AMD Yellow Carp platform (Renjith Pananchikkal) [2015775]
- thunderbolt: Enable retry logic for intra-domain control packets (David Arcari) [2028287]
- nvme-fabrics: fix state check in nvmf_ctlr_matches_baseopts() (Gopal Tiwari) [2043755]
- smb3: do not error on fsync when readonly (Ronnie Sahlberg) [2037811]
- cifs: serialize all mount attempts (Ronnie Sahlberg) [2008434]
- ALSA: memalloc: Unify x86 SG-buffer handling (take#3) (Jaroslav Kysela) [2049437]
- ALSA: usb-audio: add mapping for MSI MPG X570S Carbon Max Wifi. (Jaroslav Kysela) [2049437]
- ALSA: usb-audio: Drop CONFIG_PM ifdefs (Jaroslav Kysela) [2049437]
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink (Jaroslav Kysela) [2049437]
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table (Jaroslav Kysela) [2049437]
- ALSA: usb-audio: Use int for dB map values (Jaroslav Kysela) [2049437]
- ALSA: hda/tegra: Fix Tegra194 HDA reset failure (Jaroslav Kysela) [2049437]
- ALSA: hda/realtek: Use ALC285_FIXUP_HP_GPIO_LED on another HP laptop (Jaroslav Kysela) [2049437]
- ALSA: hda: Add new AlderLake-P variant PCI ID (Jaroslav Kysela) [2049437]
- ALSA: hda: Add AlderLake-N PCI ID (Jaroslav Kysela) [2049437]
- ALSA: hda: use swap() to make code cleaner (Jaroslav Kysela) [2049437]
- ALSA: Fix some typo (Jaroslav Kysela) [2049437]
- ALSA: hda/hdmi: Consider ELD is invalid when no SAD is present (Jaroslav Kysela) [2049437]
- ALSA: hda: Remove redundant runtime PM calls (Jaroslav Kysela) [2049437]
- ALSA: hda: Do disconnect jacks at codec unbind (Jaroslav Kysela) [2049437]
- ALSA: hda: intel: More comprehensive PM runtime setup for controller driver (Jaroslav Kysela) [2049437]
- ASoC: SOF: Intel: fix build issue related to CODEC_PROBE_ENTRIES (Jaroslav Kysela) [2049437]
- ASoC: cs42l42: Report initial jack state (Jaroslav Kysela) [2049437]
- ALSA: hda/realtek: Re-order quirk entries for Lenovo (Jaroslav Kysela) [2049437]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2020 (Jaroslav Kysela) [2049437]
- ALSA: hda/realtek: Add speaker fixup for some Yoga 15ITL5 devices (Jaroslav Kysela) [2049437]
- tools headers UAPI: Sync sound/asound.h with the kernel sources (Jaroslav Kysela) [2049437]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2049437]
- tools include UAPI: Sync sound/asound.h copy (Jaroslav Kysela) [2049437]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2049437]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2049437]
- ASoC: SOF: handle paused streams during system suspend (Jaroslav Kysela) [2049437]
- ASoC: SOF: sof-audio: setup sched widgets during pipeline complete step (Jaroslav Kysela) [2049437]
- ASoC: SOF: free widgets in sof_tear_down_pipelines() for static pipelines (Jaroslav Kysela) [2049437]
- ALSA: hda/cs8409: Fix Jack detection after resume (Jaroslav Kysela) [2049437]
- ALSA: hda/cs8409: Increase delay during jack detection (Jaroslav Kysela) [2049437]
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus Master after reboot from Windows (Jaroslav Kysela) [2049437]
- ASoC: Intel: catpt: Test dmaengine_submit() result before moving on (Jaroslav Kysela) [2049437]
- ASoC: amd: Fix dependency for SPI master (Jaroslav Kysela) [2049437]
- ALSA: usb-audio: Drop superfluous '0' in Presonus Studio 1810c's ID (Jaroslav Kysela) [2049437]
- ALSA: oss: fix compile error when OSS_DEBUG is enabled (Jaroslav Kysela) [2049437]
- ALSA: hda: Make proper use of timecounter (Jaroslav Kysela) [2049437]
- ALSA: led: Use restricted type for iface assignment (Jaroslav Kysela) [2049437]
- ALSA: hda: Fix potential deadlock at codec unbinding (Jaroslav Kysela) [2049437]
- ALSA: hda: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2049437]
- ALSA: PCM: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2049437]
- ALSA: jack: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2049437]
- ASoC: Intel: sof_sdw: fix jack detection on HP Spectre x360 convertible (Jaroslav Kysela) [2049437]
- kernel: fork: properly initialize mm->mm_rh in dup_mm() and mm_alloc() (Rafael Aquini) [2047242]
- vdpa/mlx5: Fix tracking of current number of VQs (Cindy Lu) [2052849]
- vdpa/mlx5: Fix is_index_valid() to refer to features (Cindy Lu) [2052849]
- vdpa: Protect vdpa reset with cf_mutex (Cindy Lu) [2052849]
- vdpa: Avoid taking cf_mutex lock on get status (Cindy Lu) [2052849]
- vdpa/vdpa_sim_net: Report max device capabilities (Cindy Lu) [2052849]
- vdpa: Use BIT_ULL for bit operations (Cindy Lu) [2052849]
- vdpa/vdpa_sim: Configure max supported virtqueues (Cindy Lu) [2052849]
- vdpa/mlx5: Report max device capabilities (Cindy Lu) [2052849]
- vdpa: Support reporting max device capabilities (Cindy Lu) [2052849]
- vdpa/mlx5: Restore cur_num_vqs in case of failure in change_num_qps() (Cindy Lu) [2052849]
- vdpa: Add support for returning device configuration information (Cindy Lu) [2052849]
- vdpa/mlx5: Support configuring max data virtqueue (Cindy Lu) [2052849]
- vdpa/mlx5: Fix config_attr_mask assignment (Cindy Lu) [2052849]
- vdpa: Allow to configure max data virtqueues (Cindy Lu) [2052849]
- vdpa: Read device configuration only if FEATURES_OK (Cindy Lu) [2052849]
- vdpa: Sync calls set/get config/status with cf_mutex (Cindy Lu) [2052849]
- vdpa/mlx5: Distribute RX virtqueues in RQT object (Cindy Lu) [2052849]
- vdpa: Provide interface to read driver features (Cindy Lu) [2052849]
- vdpa/mlx5: Fix wrong configuration of virtio_version_1_0 (Cindy Lu) [2052849]
- vdpa: Mark vdpa_config_ops.get_vq_notification as optional (Cindy Lu) [2052849]
- vdpa: Avoid duplicate call to vp_vdpa get_status (Cindy Lu) [2052849]
- net/mlx5_vdpa: Offer VIRTIO_NET_F_MTU when setting MTU (Cindy Lu) [2052849]
- vdpa: add driver_override support (Cindy Lu) [2052849]
- docs: document sysfs ABI for vDPA bus (Cindy Lu) [2052849]
- ifcvf/vDPA: fix misuse virtio-net device config size for blk dev (Cindy Lu) [2052849]
- Revert "efi/libstub: arm64: Double check image alignment at entry" (Vitaly Kuznetsov) [2046303]
- ethtool: ioctl: fix potential NULL deref in ethtool_set_coalesce() (William Zhao) [2046342]
- cifs: Do not leak EDEADLK to dgetents64 for STATUS_USER_SESSION_DELETED (Ronnie Sahlberg) [1994393]
- cifs: constify pathname arguments in a bunch of helpers (Ronnie Sahlberg) [1994393]
- cgroup: Use open-time cgroup namespace for process migration perm checks (Chris von Recklinghausen) [2035766]
- cgroup: Allocate cgroup_file_ctx for kernfs_open_file->priv (Chris von Recklinghausen) [2035766]
- cgroup: Use open-time credentials for process migraton perm checks (Chris von Recklinghausen) [2035766]
- cgroup: make per-cgroup pressure stall tracking configurable (Chris von Recklinghausen) [2035766]
- powerpc/idle: Don't corrupt back chain when going idle (Laurent Vivier) [2052793]
- powerpc64/idle: Fix SP offsets when saving GPRs (Laurent Vivier) [2052793]
- sfc: ef10: implement ethtool::get_fec_stats (Íñigo Huguet) [2042798]
- sfc: The RX page_ring is optional (Íñigo Huguet) [2042798]
- sfc: Check null pointer of rx_queue->page_ring (Íñigo Huguet) [2042798]
- sfc_ef100: potential dereference of null pointer (Íñigo Huguet) [2042798]
- sfc: Don't use netif_info before net_device setup (Íñigo Huguet) [2042798]
- sfc: Export fibre-specific supported link modes (Íñigo Huguet) [2042798]
- sfc: Fix reading non-legacy supported link modes (Íñigo Huguet) [2042798]
- ethernet: constify references to netdev->dev_addr in drivers (Íñigo Huguet) [2042798]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Íñigo Huguet) [2042798]
- ethernet: use eth_hw_addr_set() (Íñigo Huguet) [2042798]
- sfc: last resort fallback for lack of xdp tx queues (Íñigo Huguet) [2042798 1995444]
- sfc: fallback for lack of xdp tx queues (Íñigo Huguet) [2042798 1995444]
- ext4: fix potential uninitialized access to retval in kmmpd (Lukas Czerner) [2046355]
- ext4: fix possible UAF when remounting r/o a mmp-protected file system (Lukas Czerner) [2046355]
- ext4: fix memory leak in ext4_fill_super (Lukas Czerner) [2046355]
- quota: check block number when reading the block in quota file (Lukas Czerner) [2046999]
- quota: correct error number in free_dqentry() (Lukas Czerner) [2046999]
- quota: Fix memory leak when handling corrupted quota file (Lukas Czerner) [2046999]
- quota: Sanity-check quota file headers on load (Lukas Czerner) [2046999]
- quota: clear padding in v2r1_mem2diskdqb() (Lukas Czerner) [2046999]
- quota: Check that quota is not dirty before release (Lukas Czerner) [2046999]
- quota: fix livelock in dquot_writeback_dquots (Lukas Czerner) [2046999]
- ext4: fix e2fsprogs checksum failure for mounted filesystem (Lukas Czerner) [1937180]
- ext4: prevent partial update of the extent blocks (Lukas Czerner) [2035877]
- ext4: check for inconsistent extents between index and leaf block (Lukas Czerner) [2035877]
- ext4: check for out-of-order index extents in ext4_valid_extent_entries() (Lukas Czerner) [2035877]
- ext4: avoid trim error on fs with small groups (Lukas Czerner) [2046355]
- ext4: fix null-ptr-deref in '__ext4_journal_ensure_credits' (Lukas Czerner) [2046355]
- ext4: make sure to reset inode lockdep class when quota enabling fails (Lukas Czerner) [2046355]
- ext4: make sure quota gets properly shutdown on error (Lukas Czerner) [2046355]
- ext4: Fix BUG_ON in ext4_bread when write quota data (Lukas Czerner) [2046355]
- ext4: refresh the ext4_ext_path struct after dropping i_data_sem. (Lukas Czerner) [2046355]
- ext4: ensure enough credits in ext4_ext_shift_path_extents (Lukas Czerner) [2046355]
- ext4: fix potential infinite loop in ext4_dx_readdir() (Lukas Czerner) [2046355]
- ext4: fix loff_t overflow in ext4_max_bitmap_size() (Lukas Czerner) [2046355]
- ext4: fix reserved space counter leakage (Lukas Czerner) [2046355]
- ext4: fix race writing to an inline_data file while its xattrs are changing (Lukas Czerner) [2046355]
- ext4: fix potential htree corruption when growing large_dir directories (Lukas Czerner) [2046355]
- ext4: use ext4_grp_locked_error in mb_find_extent (Lukas Czerner) [2046355]
- ext4: correct the cache_nr in tracepoint ext4_es_shrink_exit (Lukas Czerner) [2046355]
- ext4: remove check for zero nr_to_scan in ext4_es_scan() (Lukas Czerner) [2046355]
- ext4: return error code when ext4_fill_flex_info() fails (Lukas Czerner) [2046355]
- ext4: cleanup in-core orphan list if ext4_truncate() failed to get a transaction handle (Lukas Czerner) [2046355]
- ext4: fix kernel infoleak via ext4_extent_header (Lukas Czerner) [2046355]
- ext4: fix memory leak in ext4_fill_super (Lukas Czerner) [2046355]
- ext4: fix bug on in ext4_es_cache_extent as ext4_split_extent_at failed (Lukas Czerner) [2046355]
- ext4: fix error code in ext4_commit_super (Lukas Czerner) [2046355]
- crash_core, vmcoreinfo: append 'SECTION_SIZE_BITS' to vmcoreinfo (Pingfan Liu) [2046631]
- arm64/crash_core: Export TCR_EL1.T1SZ in vmcoreinfo (Pingfan Liu) [2046631]
- arm64: kernel: arch_crash_save_vmcoreinfo() should depend on CONFIG_CRASH_CORE (Mark Salter) [2046631]
- Revert "[arm64] arm64, vmcoreinfo : Append 'MAX_PHYSMEM_BITS' to vmcoreinfo" (Pingfan Liu) [2046631]
- crash_core, vmcoreinfo: Append 'MAX_PHYSMEM_BITS' to vmcoreinfo (Pingfan Liu) [2046631]
- ibmvnic: don't release napi in __ibmvnic_open() (Gustavo Walbon) [2051793]

* Mon Feb 21 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-369.el8]
- EDAC/igen6: Add Intel Alder Lake SoC support (Aristeu Rozanski) [1971965 1783145]
- EDAC/igen6: Add Intel Tiger Lake SoC support (Aristeu Rozanski) [1971965 1783145]
- EDAC/igen6: Add Intel ICL-NNPI SoC support (Aristeu Rozanski) [1971965 1783145]
- EDAC/i10nm: Add support for high bandwidth memory (Aristeu Rozanski) [1971965 1783145]
- EDAC/i10nm: Add detection of memory levels for ICX/SPR servers (Aristeu Rozanski) [1971965 1783145]
- EDAC/skx_common: Add new ADXL components for 2-level memory (Aristeu Rozanski) [1971965 1783145]
- EDAC, skx: Retrieve and print retry_rd_err_log registers (Aristeu Rozanski) [1971965 1783145]
- EDAC, skx_common: Refactor so that we initialize "dev" in result of adxl decode. (Aristeu Rozanski) [1971965 1783145]
- selinux: parse contexts for mount options early (Scott Mayhew) [1984355]
- selinux: try to use preparsed sid before calling parse_sid() (Scott Mayhew) [1984355]
- selinux: Fix selinux_sb_mnt_opts_compat() (Scott Mayhew) [1984355]
- selinux: access superblock_security_struct in LSM blob way (Scott Mayhew) [1984355]
- selinux: minor tweaks to selinux_add_opt() (Scott Mayhew) [1984355]
- selinux: fix potential memleak in selinux_add_opt() (Scott Mayhew) [1984355]
- selinux: fix sleeping function called from invalid context (Scott Mayhew) [1984355]
- LSM: Infrastructure management of the superblock (Scott Mayhew) [1984355]
- selinux: drop super_block backpointer from superblock_security_struct (Scott Mayhew) [1984355]
- selinux: remove redundant allocation and helper functions (Scott Mayhew) [1984355]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [1970036 1988269]
- ath11k: add string type to search board data in board-2.bin for WCN6855 (Íñigo Huguet) [1970036 1988269]
- firmware: smccc: Fix check for ARCH_SOC_ID not implemented (Vitaly Kuznetsov) [2053450]
- bpf, arm64: Use emit_addr_mov_i64() for BPF_PSEUDO_FUNC (Yauheni Kaliuta) [2051789]
- bpf/selftests: disable a verifier test for powerpc (Viktor Malik) [2046032]
- bpf/selftests: allow disabling verifier tests (Viktor Malik) [2046032]
- vfs: check dentry is still valid in get_link() (Ian Kent) [2014846]
- xfs: don't expose internal symlink metadata buffers to the vfs (Brian Foster) [2014846]
- scsi: vmw_pvscsi: Set residual data length conditionally (Cathy Avery) [2052345]
- scsi: mpt3sas: Fix incorrect system timestamp (Tomas Henzl) [2026212]
- scsi: mpt3sas: Fix system going into read-only mode (Tomas Henzl) [2026212]
- scsi: mpt3sas: Fix kernel panic during drive powercycle test (Tomas Henzl) [2026212]
- scsi: mpt3sas: Clean up some inconsistent indenting (Tomas Henzl) [2026212]
- scsi: scsi_transport_srp: Don't block target in SRP_PORT_LOST state (Ewan D. Milne) [2028290]
- blktrace: switch trace spinlock to a raw spinlock (Wander Lairson Costa) [1905749]
- blktrace: Fix uaf in blk_trace access after removing by sysfs (Wander Lairson Costa) [1905749]
- blk-wbt: export internal state via debugfs (Ming Lei) [2047313]
- platform/x86: ISST: Fix optimization with use of numa (Prarit Bhargava) [2023820]
- platform/x86: ISST: Use numa node id for cpu pci dev mapping (Prarit Bhargava) [2023818]
- platform/x86: ISST: Optimize CPU to PCI device mapping (Prarit Bhargava) [2023818]
- efi/x86: drop task_lock() from efi_switch_mm() (Fernando Pacheco) [2035415]
- configs: enable LOGITECH_FF (Benjamin Tissoires) [1945987]
- Input: joydev - prevent use of not validated data in JSIOCSBTNMAP ioctl (Benjamin Tissoires) [1974089]
- Input: joydev - prevent potential read overflow in ioctl (Benjamin Tissoires) [1974089]
- xfs: Fix CIL throttle hang when CIL space used going backwards (Thiago Becker) [2040371]
- netfilter: nf_conntrack_netbios_ns: fix helper module alias (Florian Westphal) [2038015]
- selftests: nft_concat_range: add test for reload with no element add/del (Florian Westphal) [2046309]
- netfilter: fix regression in looped (broad|multi)cast's MAC handling (Florian Westphal) [2046309]
- selftests: netfilter: Add correctness test for mac,net set type (Florian Westphal) [2046309]
- netfilter: flowtable: fix IPv6 tunnel addr match (Florian Westphal) [2046309]
- netfilter: conntrack: don't increment invalid counter on NF_REPEAT (Florian Westphal) [2046309]
- netfilter: nft_set_pipapo: allocate pcpu scratch maps on clone (Florian Westphal) [2046309]
- netfilter: nft_payload: do not update layer 4 checksum when mangling fragments (Florian Westphal) [2046309]
- netfilter: ipvs: Fix reuse connection if RS weight is 0 (Florian Westphal) [2046309]
- netfilter: ctnetlink: do not erase error code with EINVAL (Florian Westphal) [2046309]
- netfilter: ctnetlink: fix filtering with CTA_TUPLE_REPLY (Florian Westphal) [2046309]
- netfilter: nfnetlink_queue: fix OOB when mac header was cleared (Florian Westphal) [2046309]
- netfilter: nft_dynset: relax superfluous check on set updates (Florian Westphal) [2046309]
- netfilter: use kvmalloc_array to allocate memory for hashtable (Phil Sutter) [2001762]
- netfilter: nf_tables: skip netdev events generated on netns removal (Phil Sutter) [2053436]
- xfrm: add state hashtable keyed by seq (Sabrina Dubroca) [1926538]

* Wed Feb 16 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-368.el8]
- cgroup/cpuset: Fix "suspicious RCU usage" lockdep warning (Waiman Long) [2050418]
- cpuset: Fix the bug that subpart_cpus updated wrongly in update_cpumask() (Waiman Long) [2050418]
- IB/rdmavt: Validate remote_addr during loopback atomic tests (Kamal Heib) [2033480]
- in wb_init, use gfp instead of GFP_KERNEL when allocating bw_dwork (Chris von Recklinghausen) [2046179]
- scsi: bnx2fc: Make bnx2fc_recv_frame() mp safe (John Meneghini) [2051691]
- scsi: bnx2fc: Flush destroy_work queue before calling bnx2fc_interface_put() (John Meneghini) [1973208]
- nvme: drop unused variable ctrl in nvme_setup_cmd (John Meneghini) [2033384]
- nvme: increment request genctr on completion (John Meneghini) [2033384]
- nvme-pci: Fix abort command id (John Meneghini) [2033384]
- nvme: add command id quirk for apple controllers (John Meneghini) [2033384]
- nvme: move nvme_multi_css into nvme.h (John Meneghini) [2033384]
- nvme: code command_id with a genctr for use-after-free validation (John Meneghini) [2033384]
- nvme-pci: limit maximum queue depth to 4095 (John Meneghini) [2033384]
- params: lift param_set_uint_minmax to common code (John Meneghini) [2033384]
- CI: Enable baseline realtime checks (Veronika Kabatova)
- CI: Rename pipelines to include release names (Veronika Kabatova)
- sched/pelt: Relax the sync of load_sum with load_avg (Phil Auld) [2037123]
- sched/pelt: Relax the sync of runnable_sum with runnable_avg (Phil Auld) [2037123]
- sched/pelt: Continue to relax the sync of util_sum with util_avg (Phil Auld) [2037123]
- sched/pelt: Relax the sync of util_sum with util_avg (Phil Auld) [2037123]
- cifs: fix memory leak of smb3_fs_context_dup::server_hostname (Ronnie Sahlberg) [2044670]
- cifs: To match file servers, make sure the server hostname matches (Ronnie Sahlberg) [2044670]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [1837402]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [1837402]
- ovl: fix deadlock in splice write (Miklos Szeredi) [2028998]
- selinux: fix NULL-pointer dereference when hashtab allocation fails (Ondrej Mosnacek) [2021467]
- selinux: fix double free of cond_list on error paths (Ondrej Mosnacek) [2043605]
- ibmvnic: remove unused ->wait_capability (Diego Domingos) [2049368]
- ibmvnic: don't spin in tasklet (Diego Domingos) [2049368]
- ibmvnic: init ->running_cap_crqs early (Diego Domingos) [2049368]
- ibmvnic: Allow extra failures before disabling (Diego Domingos) [2049368]
- hpsa: add new messaging (Tomas Henzl) [1801777]
- aacraid: add new messaging (Tomas Henzl) [2044365]
- Revert "[scsi] Revert "[scsi] aacraid: add removed id table"" (Tomas Henzl) [2044365]
- mpt3sas: Add new messaging (Tomas Henzl) [2044366]
- Revert "[scsi] mpt*: remove certain deprecated pci-ids" (Tomas Henzl) [2044366]
- mptsas: add new messaging (Tomas Henzl) [2044366]
- sctp: hold endpoint before calling cb in sctp_transport_lookup_process (Xin Long) [2043822]
- sctp: use call_rcu to free endpoint (Xin Long) [2043822]
- sctp: move hlist_node and hashent out of sctp_ep_common (Xin Long) [2043822]
- net: Use nlmsg_unicast() instead of netlink_unicast() (Xin Long) [2043822]
- video: hyperv_fb: Fix validation of screen resolution (Mohammed Gamal) [1952821]
- powerpc/pseries: extract host bridge from pci_bus prior to bus removal (Diego Domingos) [2051509]
- dm: properly fix redundant bio-based IO accounting (Mike Snitzer) [2051803]
- dm: revert partial fix for redundant bio-based IO accounting (Mike Snitzer) [2051803]
- block: add bio_start_io_acct_time() to control start_time (Mike Snitzer) [2051803]
- block: document iostat changes for disk busy time accounting (Mike Snitzer) [2051803]

* Thu Feb 10 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-367.el8]
- tee: optee: Fix incorrect page free bug (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: handle lookup of shm with reference count 0 (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: smc_abi.c: add missing #include <linux/mm.h> (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: isolate smc abi (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: refactor driver with internal callbacks (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: simplify optee_release() (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: Fix missing devices unregister during optee_remove (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee/optee/shm_pool: fix application of sizeof to pointer (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: Correct inappropriate usage of TEE_SHM_DMA_BUF flag (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: add tee_shm_alloc_kernel_buf() (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: Clear stale cache entries during initialization (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: fix tee out of memory failure seen during kexec reboot (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: Refuse to load the driver under the kdump kernel (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: Fix memory leak when failing to register shm pages (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: use export_uuid() to copy client UUID (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: do not check memref size on return from Secure World (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: fix build error caused by recent optee tracepoints feature (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: add invoke_fn tracepoints (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: simplify i2c access (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: remove need_resched() before cond_resched() (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: sync OP-TEE headers (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: replace might_sleep with cond_resched (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- drivers: optee: fix i2c build issue (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: convert get_user_pages() --> pin_user_pages() (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- drivers: optee: allow op-tee to access devices on the i2c bus (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- driver: tee: Handle NULL pointer indication from client (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: enable support for multi-stage bus enumeration (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: use uuid for sysfs driver entry (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: Add support for session login client UUID generation (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: enable support to register kernel memory (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: remove unnecessary NULL check in tee_shm_alloc() (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: don't assign shm id for private shms (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: remove unused tee_shm_priv_alloc() (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: tee_shm_op_mmap(): use TEE_SHM_USER_MAPPED (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: remove redundant teedev in struct tee_shm (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: remove linked list of struct tee_shm (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: Fix multi page dynamic shm pool alloc (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: model OP-TEE as a platform device/driver (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: fix device enumeration error handling (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: Fix dynamic shm pool allocations (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee/shm: untag user pointers in tee_shm_register (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: add might_sleep for RPC requests (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 282 (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- optee: allow to work without static shared memory (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: update optee_msg.h and optee_smc.h to dual license (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: add missing of_node_put after of_device_is_available (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: Fix unsigned comparison with less than zero (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: fix possible error pointer ctx dereferencing (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: Initialize some structs using memset instead of braces (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: add TEE bus device enumeration support (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: add supp_nowait flag in tee_context struct (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: log message if dynamic shm is enabled (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: add kernel internal client interface (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: take DT status property into account (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- tee: optee: making OPTEE_SHM_NUM_PRIV_PAGES configurable via Kconfig (Chris von Recklinghausen) [2030755] {CVE-2021-44733}
- x86/mce: Add Xeon Sapphire Rapids to list of CPUs that support PPIN (David Arcari) [2035286]
- regset: kill ->get() (Prarit Bhargava) [2032854]
- arm64: switch to ->regset_get() (Prarit Bhargava) [2032854]
- arm64: take fetching compat reg out of pt_regs into a new helper (Prarit Bhargava) [2032854]
- powerpc: switch to ->regset_get() (Prarit Bhargava) [2032854]
- s390: switch to ->regset_get() (Prarit Bhargava) [2032854]
- introduction of regset ->get() wrappers, switching ELF coredumps to those (Prarit Bhargava) [2032854]
- mm/page_alloc.c: do not warn allocation failure on zone DMA if no managed pages (Baoquan He) [2024011]
- dma/pool: create dma atomic pool only if dma zone has managed pages (Baoquan He) [2024011]
- mm_zone: add function to check if managed dma zone exists (Baoquan He) [2024011]
- tipc: discard MSG_CRYPTO msgs when key_exchange_enabled is not set (Xin Long) [2043825]
- tipc: delete the unlikely branch in tipc_aead_encrypt (Xin Long) [2043825]
- tipc: check for null after calling kmemdup (Xin Long) [2043825]
- tipc: only accept encrypted MSG_CRYPTO msgs (Xin Long) [2043825]
- powerpc/pseries: use slab context cpumask allocation in CPU hotplug init (Waiman Long) [2048220]
- powerpc/pseries: Fix build error when NUMA=n (Waiman Long) [2048220]
- lpfc: Add new messaging (Ewan D. Milne) [1841323]
- cpu/hotplug: Cure the cpusets trainwreck (Phil Auld) [1904593]
- scsi: ses: Fix unsigned comparison with less than zero (Tomas Henzl) [1995086]
- scsi: ses: Retry failed Send/Receive Diagnostic commands (Tomas Henzl) [1995086]
- serial: exar: Fix GPIO configuration for Sealevel cards based on XR17V35X (John W. Linville) [2022906]
- PCI: vmd: Add indirection layer to vmd irq lists (Scott Wood) [2048202]
- redhat/configs: Enable CONFIG_PCI_HYPERV on Aarch64 (Vitaly Kuznetsov) [2024853]
- PCI: hv: Add arm64 Hyper-V vPCI support (Vitaly Kuznetsov) [2024853]
- PCI: hv: Make the code arch neutral by adding arch specific interfaces (Vitaly Kuznetsov) [2024853]
- PCI: hv: Remove unnecessary use of hx (Vitaly Kuznetsov) [2024853]
- nvme-rdma: fix possible use-after-free in transport error_recovery work (Chris Leech) [1988361]
- nvme-tcp: fix possible use-after-free in transport error_recovery work (Chris Leech) [1988361]
- nvme: fix a possible use-after-free in controller reset during load (Chris Leech) [1988361]
- ipv6: check return value of ipv6_skip_exthdr (Sabrina Dubroca) [2046234]
- selftests: Calculate udpgso segment count without header adjustment (Xin Long) [2044133]
- udp: using datalen to cap ipv6 udp max gso segments (Xin Long) [2044133]
- inet_diag: fix kernel-infoleak for UDP sockets (Xin Long) [2044133]
- udp: using datalen to cap max gso segments (Xin Long) [2044133]
- [s390] s390/cpumf: Support for CPU Measurement Facility CSVN 7 (Mete Durlu) [2048980]
- [s390] s390/cpumf: Support for CPU Measurement Sampling Facility LS bit (Mete Durlu) [2048980]
- tools/power/x86/intel-speed-select: v1.10 release (Prarit Bhargava) [2023909]
- tools/power/x86/intel-speed-select: Fix uncore memory frequency display (Prarit Bhargava) [2023909]
- platform/x86: ISST: Account for increased timeout in some cases (Prarit Bhargava) [2023909]
- tools/power/x86/intel-speed-select: Add options to force online (Prarit Bhargava) [2023909]
- tools/power/x86/intel-speed-select: Drop __DATE__ and __TIME__ macros (Prarit Bhargava) [2023909]
- tools/power/x86/intel-speed-select: v1.9 release (Prarit Bhargava) [2023909]
- tools/power/x86/intel-speed-select: Process mailbox read error for core-power (Prarit Bhargava) [2023909]
- tools/power/x86/intel-speed-select: Increase string size (Prarit Bhargava) [2023909]
- qla2xxx: Add new messaging (Ewan D. Milne) [1900072]

* Wed Feb 09 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-366.el8]
- platform/x86: amd-pmc: only use callbacks for suspend (David Arcari) [2016039]
- platform/x86: amd-pmc: Add support for AMD Smart Trace Buffer (David Arcari) [2016039]
- platform/x86: amd-pmc: Simplify error handling and store the pci_dev in amd_pmc_dev structure (David Arcari) [2016039]
- platform/x86: amd-pmc: Fix s2idle failures on certain AMD laptops (David Arcari) [2016039]
- platform/x86: amd-pmc: Make CONFIG_AMD_PMC depend on RTC_CLASS (David Arcari) [2016039]
- platform/x86: amd-pmc: Drop check for valid alarm time (David Arcari) [2016039]
- platform/x86: amd-pmc: Downgrade dev_info message to dev_dbg (David Arcari) [2016039]
- platform/x86: amd-pmc: fix compilation without CONFIG_RTC_SYSTOHC_DEVICE (David Arcari) [2016039]
- platform/x86: amd-pmc: Add special handling for timer based S0i3 wakeup (David Arcari) [2016039]
- platform/x86: amd-pmc: adjust arguments for `amd_pmc_send_cmd` (David Arcari) [2016039]
- platform/x86: amd-pmc: Add alternative acpi id for PMC controller (David Arcari) [2016039]
- platform/x86: amd-pmc: Add a message to print resume time info (David Arcari) [2016039]
- platform/x86: amd-pmc: Send command to dump data after clearing OS_HINT (David Arcari) [2016039]
- platform/x86: amd-pmc: Fix compilation when CONFIG_DEBUGFS is disabled (David Arcari) [2016039]
- platform/x86: amd-pmc: Export Idlemask values based on the APU (David Arcari) [2016039]
- platform/x86: amd-pmc: Check s0i3 cycle status (David Arcari) [2016039]
- scsi: lpfc: Fix non-recovery of remote ports following an unsolicited LOGO (Dick Kennedy) [2027558]
- sch_api: Don't skip qdisc attach on ingress (Davide Caratti) [2044806]
- sch_qfq: prevent shift-out-of-bounds in qfq_init_qdisc (Davide Caratti) [2044806]
- flow_offload: return EOPNOTSUPP for the unsupported mpls action type (Davide Caratti) [2044806]
- selftests: bpf: Less strict size check in sockopt_sk (Felix Maurer) [2025809]
- net-zerocopy: Fast return if inq < PAGE_SIZE (Felix Maurer) [2025809]
- tcp: Fix sign comparison bug in getsockopt(TCP_ZEROCOPY_RECEIVE) (Felix Maurer) [2025809]
- tcp-zerocopy: Ensure excess getsockopt buffer is zeroed (Felix Maurer) [2025809]
- tcp-zerocopy: Update returned getsockopt() optlen. (Felix Maurer) [2025809]
- tcp-zerocopy: Fix getsockopt buffer size check (Felix Maurer) [2025809]
- gre: Don't accidentally set RTO_ONLINK in gre_fill_metadata_dst() (Guillaume Nault) [2046339]
- net: fix use-after-free in tw_timer_handler (Guillaume Nault) [2046339]
- ALSA: core: Fix SSID quirk lookup for subvendor=0 (Jaroslav Kysela) [2003613]
- ASoC: tegra30: i2s: Restore hardware state on runtime PM resume (Jaroslav Kysela) [2003613]
- ALSA: RHEL - update kernel configs for RHEL 8.6 (Jaroslav Kysela) [2003613]
- ASoC: remove module namespaces (Jaroslav Kysela) [2003613]
- ASoC: codecs: rt5682(s): use the older clock API calls, but keep some modern (Jaroslav Kysela) [2003613]
- ASoC: arizona-jack: Cleanup logging (Jaroslav Kysela) [2003613]
- ASoC: arizona-jack: Use snd_soc_jack to report jack events (Jaroslav Kysela) [2003613]
- ASoC: arizona-jack: convert into a helper library for codec drivers (Jaroslav Kysela) [2003613]
- ASoC: arizona-jack: Use arizona->dev for runtime-pm (Jaroslav Kysela) [2003613]
- ASoC: arizona-jack: Move jack-detect variables to struct arizona_priv (Jaroslav Kysela) [2003613]
- ASoC/extcon: arizona: Move arizona jack code to sound/soc/codecs/arizona-jack.c (Jaroslav Kysela) [2003613]
- extcon: arizona: Always use pm_runtime_get_sync() when we need the device to be awake (Jaroslav Kysela) [2003613]
- extcon: arizona: Fix flags parameter to the gpiod_get("wlf,micd-pol") call (Jaroslav Kysela) [2003613]
- extcon: arizona: Fix various races on driver unbind (Jaroslav Kysela) [2003613]
- extcon: arizona: Fix some issues when HPDET IRQ fires after the jack has been unplugged (Jaroslav Kysela) [2003613]
- extcon: arizona: Fix runtime PM imbalance on error (Jaroslav Kysela) [2003613]
- extcon: arizona: Factor out microphone and button detection (Jaroslav Kysela) [2003613]
- extcon: arizona: Factor out microphone impedance into a function (Jaroslav Kysela) [2003613]
- extcon: arizona: Invert logic of check in arizona_hpdet_do_id (Jaroslav Kysela) [2003613]
- extcon: arizona: Remove excessive WARN_ON (Jaroslav Kysela) [2003613]
- extcon: arizona: Remove unnecessary sets of ACCDET_MODE (Jaroslav Kysela) [2003613]
- extcon: arizona: Tidy up transition from mic to headphone detect (Jaroslav Kysela) [2003613]
- extcon: arizona: Clear jack status regardless of detection type (Jaroslav Kysela) [2003613]
- extcon: arizona: Move pdata extraction to probe (Jaroslav Kysela) [2003613]
- extcon: arizona: Make rev A register sequences atomic (Jaroslav Kysela) [2003613]
- extcon: arizona: Correct clean up if arizona_identify_headphone fails (Jaroslav Kysela) [2003613]
- extcon: arizona: Switch to use device_property_count_u32() (Jaroslav Kysela) [2003613]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Jaroslav Kysela) [2003613]
- extcon: arizona: Correct error handling on regmap_update_bits_check (Jaroslav Kysela) [2003613]
- extcon: arizona: Disable mic detect if running when driver is removed (Jaroslav Kysela) [2003613]
- mfd: arizona: Fix rumtime PM imbalance on error (Jaroslav Kysela) [2003613]
- mfd: arizona: Split of_match table into I2C and SPI versions (Jaroslav Kysela) [2003613]
- mfd: arizona: Make some symbols static (Jaroslav Kysela) [2003613]
- mfd: arizona: Add support for ACPI enumeration of WM5102 connected over SPI (Jaroslav Kysela) [2003613]
- mfd: arizona: Add MODULE_SOFTDEP("pre: arizona_ldo1") (Jaroslav Kysela) [2003613]
- mfd: arizona: Drop arizona-extcon cells (Jaroslav Kysela) [2003613]
- mfd: arizona: Replace arizona_of_get_type() with device_get_match_data() (Jaroslav Kysela) [2003613]
- mfd: arizona: Ensure 32k clock is put on driver unbind and error (Jaroslav Kysela) [2003613]
- mfd: arizona: Remove BUG_ON usage (Jaroslav Kysela) [2003613]
- mfd: arizona: Switch to using devm_gpiod_get() (Jaroslav Kysela) [2003613]
- mfd: arizona: Fix undefined behavior (Jaroslav Kysela) [2003613]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jaroslav Kysela) [2003613]
- mfd: arizona: Correct calling of runtime_put_sync (Jaroslav Kysela) [2003613]
- mfd: arizona: Don't use regmap_read_poll_timeout (Jaroslav Kysela) [2003613]
- clkdev: Hold clocks_mutex while iterating clocks list (Jaroslav Kysela) [2003613]
- clkdev: add managed clkdev lookup registration (Jaroslav Kysela) [2003613]
- genirq: Add IRQF_NO_AUTOEN for request_irq/nmi() (Jaroslav Kysela) [2003613]
- ALSA: es1688: Avoid devres management for es1688 object creation (Jaroslav Kysela) [2003613]
- ALSA: gus: Fix repeated probes of snd_gus_create() (Jaroslav Kysela) [2003613]
- ALSA: x86: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: x86: simplify with sync_stop PCM ops (Jaroslav Kysela) [2003613]
- ALSA: x86: fix spelling mistakes (Jaroslav Kysela) [2003613]
- ALSA: virtio: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2003613]
- ALSA: emux: fix spelling mistakes (Jaroslav Kysela) [2003613]
- ALSA: synth: missing check for possible NULL after the call to kstrdup (Jaroslav Kysela) [2003613]
- ALSA: synth: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: sparc: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ASoC: tegra: Set driver name explicitly (Jaroslav Kysela) [2003613]
- ASoC: tegra30: i2s: Remove handing of disabled runtime PM (Jaroslav Kysela) [2003613]
- ASoC: tegra30: i2s: Use devm_clk_get() (Jaroslav Kysela) [2003613]
- ASoC: tegra30: i2s: Correct driver removal order (Jaroslav Kysela) [2003613]
- ASoC: tegra20: spdif: Remove handing of disabled runtime PM (Jaroslav Kysela) [2003613]
- ASoC: tegra20: i2s: Remove handing of disabled runtime PM (Jaroslav Kysela) [2003613]
- ASoC: tegra20: i2s: Use devm_clk_get() (Jaroslav Kysela) [2003613]
- ASoC: tegra20: i2s: Add system level suspend-resume callbacks (Jaroslav Kysela) [2003613]
- ASoC: tegra20: i2s: Add reset control (Jaroslav Kysela) [2003613]
- ASoC: tegra20: i2s: Correct driver removal order (Jaroslav Kysela) [2003613]
- ASoC: tegra: tegra20_das: align function prototypes (Jaroslav Kysela) [2003613]
- ASoC: tegra: tegra20_das: clarify expression (Jaroslav Kysela) [2003613]
- ASoC: tegra: remove unneeded semicolon (Jaroslav Kysela) [2003613]
- ASoC: tegra: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [2003613]
- ASoC: tegra20: ac97: Add reset control (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add support for SoundWire of TGL-H-RVP (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: add mutual exclusion between PCH DMIC and RT715 (Jaroslav Kysela) [2003613]
- ASoC: codecs: wsa881x: fix return values from kcontrol put (Jaroslav Kysela) [2003613]
- ASoc: wm8731: Drop empty spi_driver remove callback (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: channel -> channels rename (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: Fix TAS2505/TAS2521 channel count (Jaroslav Kysela) [2003613]
- ASoC: wcd9335: Disable irq on slave ports in the remove function (Jaroslav Kysela) [2003613]
- ASoC: wcd9335: Fix a double irq free in the remove function (Jaroslav Kysela) [2003613]
- ASoC: wcd9335: Fix a memory leak in the error handling path of the probe function (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: make array clocks static, makes object smaller (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: Fix TAS2505/TAS2521 processing block selection (Jaroslav Kysela) [2003613]
- ASoC: da7218: Drop CONFIG_OF ifdef (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: Fix TAS2505 volume controls (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: Make aic32x4_remove() return void (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: add support for TAS2505 (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic32x4: add type to device private data struct (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic31xx: fix reversed bclk/wclk master bits (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic31xx: Fix jack detection after suspend (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic31xx: Make regmap cache only on probe() (Jaroslav Kysela) [2003613]
- ASoC: sigmadsp: Remove the repeated declaration (Jaroslav Kysela) [2003613]
- ASoC: rt286: Remove redundant assignment to d_len_code (Jaroslav Kysela) [2003613]
- ASoC: codecs: rt1019: clarify expression (Jaroslav Kysela) [2003613]
- ASoC: rt1019: Add non_legacy_dai_naming config (Jaroslav Kysela) [2003613]
- ASoC: rk3328: fix missing clk_disable_unprepare() on error in rk3328_platform_probe() (Jaroslav Kysela) [2003613]
- ASoC: mediatek: mt6359: Fix unexpected error in bind/unbind flow (Jaroslav Kysela) [2003613]
- ASoc: codecs: mt6359: remove useless initializations (Jaroslav Kysela) [2003613]
- ASoC: mediatek: mt6359: convert to use module_platform_driver (Jaroslav Kysela) [2003613]
- ASoC: ics43432: add CMM-4030D-261 support (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: Fix return value in hdmi_codec_set_jack() (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: Get ELD in before reporting plugged event (Jaroslav Kysela) [2003613]
- ASoC: cs53l30: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cs43130: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cs42l52: Minor tidy up of error paths (Jaroslav Kysela) [2003613]
- ASoC: cs42l73: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cs4265: Minor tidy up of error paths (Jaroslav Kysela) [2003613]
- ASoC: cs35l36: Remove unneeded variable initialisation (Jaroslav Kysela) [2003613]
- ASoC: cs35l35: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cs35l35: Correct errata handling (Jaroslav Kysela) [2003613]
- ASoC: cs35l34: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cs35l33: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cirrus: Add helper function for reading the device ID (Jaroslav Kysela) [2003613]
- ASoC: cs35l32: Add missing regmap use_single config (Jaroslav Kysela) [2003613]
- ASoC: cs35l32: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: adav80x: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: codecs: Fix fall-through warnings for Clang (Jaroslav Kysela) [2003613]
- ASoC: codecs: Use fallthrough pseudo-keyword (Jaroslav Kysela) [2003613]
- ASoC: ab8500: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: codecs: fix spelling mistake in Kconfig "comunicate" -> "communicate" (Jaroslav Kysela) [2003613]
- ASoC: 88pm860x: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: amd: renoir: Remove redundant assignment to pdm_ctrl and pdm_enable and pdm_dma_enable (Jaroslav Kysela) [2003613]
- ASoC: amd: add missing break (Jaroslav Kysela) [2003613]
- ALSA: sh: Fix compile warning wrt const (Jaroslav Kysela) [2003613]
- ALSA: sh: Fix unused variable warnings (Jaroslav Kysela) [2003613]
- ALSA: sh: Constify snd_device_ops definitions (Jaroslav Kysela) [2003613]
- ALSA: sh: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [2003613]
- ALSA: sh: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ALSA: aica: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ALSA: sh: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [2003613]
- ALSA: ps3: fix spelling typo of values (Jaroslav Kysela) [2003613]
- ALSA: ppc: drop if block with always false condition (Jaroslav Kysela) [2003613]
- ALSA: ppc: remove redundant checks in PS3 driver probe (Jaroslav Kysela) [2003613]
- ALSA: ppc: fix error return code in snd_pmac_probe() (Jaroslav Kysela) [2003613]
- ALSA: ppc: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [2003613]
- ALSA: ppc: Constify snd_device_ops definitions (Jaroslav Kysela) [2003613]
- ALSA: ppc: keywest: remove outdated comment (Jaroslav Kysela) [2003613]
- ALSA: poewrmac: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: pcmcia: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: pci: vx222: fix kernel-doc warning (Jaroslav Kysela) [2003613]
- ALSA: Remove trailing semicolon in macros (Jaroslav Kysela) [2003613]
- ALSA: hda: generic: Remove redundant assignment to dac (Jaroslav Kysela) [2003613]
- ALSA: hda: Allow model option to specify PCI SSID alias (Jaroslav Kysela) [2003613]
- ALSA: asihpi: fix comment syntax in file headers (Jaroslav Kysela) [2003613]
- ALSA: harmony: Drop superfluous address setup (Jaroslav Kysela) [2003613]
- ALSA: parisc: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: vx: fix kernel-doc warning (Jaroslav Kysela) [2003613]
- ALSA: aloop: Constify ops structs (Jaroslav Kysela) [2003613]
- ASoC: SOF: Drop resindex_dma_base, dma_engine, dma_size from sof_dev_desc (Jaroslav Kysela) [2003613]
- ALSA: wavefront: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: wavefront: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: sscape: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: sc6000: Use explicit cast for __iomem pointer (Jaroslav Kysela) [2003613]
- ALSA: sc6000: Assign vport directly on card's private_data (Jaroslav Kysela) [2003613]
- ALSA: sc6000: Fix incorrect sizeof operator (Jaroslav Kysela) [2003613]
- ALSA: sc6000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: sb: Fix fall-through warnings for Clang (Jaroslav Kysela) [2003613]
- Revert "ALSA: sb: fix a missing check of snd_ctl_add" (Jaroslav Kysela) [2003613]
- ALSA: sb: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: sb8: Add a comment note regarding an unused pointer (Jaroslav Kysela) [2003613]
- ALSA: sb: Fix potential ABBA deadlock in CSP driver (Jaroslav Kysela) [2003613]
- ALSA: sb: Fix potential double-free of CSP mixer elements (Jaroslav Kysela) [2003613]
- ALSA: sb: Minor coding style fixes (Jaroslav Kysela) [2003613]
- ALSA: sb: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: sb: Fix two use after free in snd_sb_qsound_build (Jaroslav Kysela) [2003613]
- ALSA: emu8000: Fix a use after free in snd_emu8000_create_mixer (Jaroslav Kysela) [2003613]
- ALSA: opti9xx: fix missing { } around an if block (Jaroslav Kysela) [2003613]
- ALSA: opti9xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: opti9xx: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: opl3sa2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: opl3sa2: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: msnd: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: msnd: Use proper mmap method (Jaroslav Kysela) [2003613]
- ALSA: gus: Fix repeated probe for ISA interwave card (Jaroslav Kysela) [2003613]
- Revert "ALSA: gus: add a check of the status of snd_ctl_add" (Jaroslav Kysela) [2003613]
- ALSA: gus: fix null pointer dereference on pointer block (Jaroslav Kysela) [2003613]
- ALSA: gus: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: gus: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: gus: Replace unsafe strcpy() with strscpy() (Jaroslav Kysela) [2003613]
- ALSA: galaxy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: Replace with fallthrough pseudo keyword in the remaining places (Jaroslav Kysela) [2003613]
- ALSA: es18xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: es18xx: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: isa: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: es1688: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: wss: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cs423x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cs423x: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- sound/oss/dmasound: Remove superfluous "break" (Jaroslav Kysela) [2003613]
- sound/oss/dmasound: Remove superfluous "break" (Jaroslav Kysela) [2003613]
- ALSA: cmi8330: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: isa: Fix error return code in snd_cmi8330_probe() (Jaroslav Kysela) [2003613]
- ALSA: cmi8330: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: cmi8328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: azt2320: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: azt2320: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: als100: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: als100: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: adlib: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ad1848: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ad1816a: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ad1816a: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: i2c: tea6330t: Remove redundant initialization of variable err (Jaroslav Kysela) [2003613]
- ALSA: i2c: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: hda: intel-sdw-acpi: add missing include files (Jaroslav Kysela) [2003613]
- ALSA: Use fallthrough pseudo-keyword (Jaroslav Kysela) [2003613]
- ALSA: aoa: remove unnecessary oom message (Jaroslav Kysela) [2003613]
- ALSA: arm: Remove unnecessary variables (Jaroslav Kysela) [2003613]
- ALSA: ac97: fix PM reference leak in ac97_bus_remove() (Jaroslav Kysela) [2003613]
- ALSA: ac97: Constify static struct attribute_group (Jaroslav Kysela) [2003613]
- ALSA: virtio: fix kernel-doc (Jaroslav Kysela) [2003613]
- ALSA: virtio: use module_virtio_driver() to simplify the code (Jaroslav Kysela) [2003613]
- ALSA: virtio: introduce device suspend/resume support (Jaroslav Kysela) [2003613]
- ALSA: virtio: introduce PCM channel map support (Jaroslav Kysela) [2003613]
- ALSA: virtio: introduce jack support (Jaroslav Kysela) [2003613]
- ALSA: virtio: PCM substream operators (Jaroslav Kysela) [2003613]
- ALSA: virtio: handling control and I/O messages for the PCM device (Jaroslav Kysela) [2003613]
- ALSA: virtio: build PCM devices and substream hardware descriptors (Jaroslav Kysela) [2003613]
- ALSA: virtio: handling control messages (Jaroslav Kysela) [2003613]
- ALSA: virtio: add virtio sound driver (Jaroslav Kysela) [2003613]
- uapi: virtio_ids: add a sound device type ID from OASIS spec (Jaroslav Kysela) [2003613]
- ALSA: firewire: Fix C++ style comments in uapi header (Jaroslav Kysela) [2003613]
- ALSA: uapi: Fix a C++ style comment in asound.h (Jaroslav Kysela) [2003613]
- ASoC: topology: Fix stub for snd_soc_tplg_component_remove() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: indicate dai_fmt if exist (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: indicate missing CPU/Codec numbers for debug (Jaroslav Kysela) [2003613]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK/BCLK_ES bits (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: tidyup dev_dbg() to use 1 line (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: tidyup debug info for clock (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Increase maximum DAI links limit to 512 (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: add simple_props_to_xxx() macro (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: Use set_jack ops to set jack (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Multi) (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Single) (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Multi) (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Single) (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Nulti) (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Single) (Jaroslav Kysela) [2003613]
- ASoC: add Audio Graph Card2 Custom Sample (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2: add Codec2Codec support (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2: add DPCM support (Jaroslav Kysela) [2003613]
- ASoC: audio-graph-card2: add Multi CPU/Codec support (Jaroslav Kysela) [2003613]
- ASoC: add Audio Graph Card2 driver (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: add codec2codec support (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: add asoc_graph_is_ports0() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Fixup CPU endpoint hw_params in a BE<->BE link (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: respawn Platform Support (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Avoid over-allocating DLCs (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: tidyup graph_parse_node() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: tidyup graph_dai_link_of_dpcm() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: add simple_link_init() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: add simple_parse_node() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: Fix breakage on kontron-sl28-var3-ads2 (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: tidyup graph_dai_link_of_dpcm() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: add simple_link_init() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: add simple_parse_node() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: add graph_link_init() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: add graph_parse_node() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: remove Platform support (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: remove unused "node" from graph_parse_mclk_fs() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: remove "audio-graph-card, " preix support (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: check ports if exists (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: move audio_graph_remove() to simple-card-utils.c (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add driver remove() callback (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: move audio_graph_card_probe() to simple-card-utils.c (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Allocate link info structure on heap (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Increase maximum number of links to 128 (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Propagate errors on too many links (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: use simple_props_to_xxx() macro (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: use asoc_link_to_xxx() macro (Jaroslav Kysela) [2003613]
- ASoC: simple-card: use simple_props_to_xxx() macro (Jaroslav Kysela) [2003613]
- ASoC: simple-card: use asoc_link_to_xxx() macro (Jaroslav Kysela) [2003613]
- ASoC: simple-card: remove unused variable from simple_parse_of() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: tidyup asoc_simple_parse_convert() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: multi support at asoc_simple_canonicalize_cpu/platform() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: care multi DAI at asoc_simple_clean_reference() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: remove asoc_simple_parse_xxx() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: use for_each_prop_xxx() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: remove li->dais/li->conf (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: setup dai_props cpu_dai/codec_dai at initial timing (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: share dummy DAI and reduce memory (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: enable flexible CPU/Codec/Platform (Jaroslav Kysela) [2003613]
- ASoC: simple-card: fix possible uninitialized single_cpu local variable (Jaroslav Kysela) [2003613]
- ASoC: simple-card: cleanup graph_for_each_link() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: count DAI / link numbers as in order (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: cleanup graph_for_each_link() (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: count DAI / link numbers as in order (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: alloc dai_link information for CPU/Codec/Platform (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils.c: remove old comment (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Do not handle device clock (Jaroslav Kysela) [2003613]
- ASoC: generic: simple-card-utils: remove useless assignment (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: Fix device module clock (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Rename functions needed for export (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Expose helpers from audio graph (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Expose new members for asoc_simple_priv (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Support empty Codec endpoint (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Identify 'no_pcm' DAI links for DPCM (Jaroslav Kysela) [2003613]
- ASoC: audio-graph: Use of_node and DAI for DPCM DAI link names (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Drop superfluous snd_dma_buffer_sync() declaration (Jaroslav Kysela) [2003613]
- ASoC: SOF: dai: include new flags for DAI_CONFIG (Jaroslav Kysela) [2003613]
- ASoC: SOF: dai: mirror group_id definition added in firmware (Jaroslav Kysela) [2003613]
- ALSA: core: Use READ_ONCE() / WRITE_ONCE() for power state change (Jaroslav Kysela) [2003613]
- ALSA: hda_audio_ext: fix kernel-doc (Jaroslav Kysela) [2003613]
- ALSA: make snd_kcontrol_new name a normal string (Jaroslav Kysela) [2003613]
- ASoC: constify of_phandle_args in snd_soc_get_dai_name() (Jaroslav Kysela) [2003613]
- ASoC: tas2770: Fix setting of high sample rates (Jaroslav Kysela) [2003613]
- ASoC: rt5682: fix the wrong jack type detected (Jaroslav Kysela) [2003613]
- ASoC: tegra: Restore headphones jack name on Nyan Big (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add DAPM switches for headphones and mic jack (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: pci-tgl: add new ADL-P variant (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: pci-tgl: add ADL-N support (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Retry codec probing if it fails (Jaroslav Kysela) [2003613]
- ASoC: amd: fix uninitialized variable in snd_acp6x_probe() (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use normal system sleep for ADX (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use normal system sleep for AMX (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use normal system sleep for Mixer (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use normal system sleep for MVC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use normal system sleep for SFC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Balance runtime PM count (Jaroslav Kysela) [2003613]
- ASoC: SOF: hda: reset DAI widget before reconfiguring it (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Set the max SPI speed for the whole device (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on CML (Jaroslav Kysela) [2003613]
- ASoC: soc-acpi: Set mach->id field on comp_ids matches (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in Mixer (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in ADX (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in AMX (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in SFC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in MVC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in AHUB (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in DSPK (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in DMIC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in I2S (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix kcontrol put callback in ADMAIF (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix wrong value type in MVC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix wrong value type in SFC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix wrong value type in DSPK (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix wrong value type in DMIC (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix wrong value type in I2S (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix wrong value type in ADMAIF (Jaroslav Kysela) [2003613]
- ASoC: topology: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2003613]
- ASoC: SOF: build compression interface into snd_sof.ko (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Re-detect the combo jack after resuming (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Avoid the unexpected IRQ event during going to suspend (Jaroslav Kysela) [2003613]
- ASoC: rt1011: revert 'I2S Reference' to SOC_ENUM_EXT (Jaroslav Kysela) [2003613]
- ASoC: rt9120: Add the compatibility with rt9120s (Jaroslav Kysela) [2003613]
- ASoC: rt9120: Fix clock auto sync issue when fs is the multiple of 48 (Jaroslav Kysela) [2003613]
- ASoC: rt9120: Update internal ocp level to the correct value (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: Add support for SKU 0B12 product (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add SKU 0B29 SoundWire configuration (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: Add support for SKU 0B29 product (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add SKU 0B13 SoundWire configuration (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: Add support for SKU 0B13 product (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: Add support for SKU 0B11 product (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: Add support for SKU 0B00 and 0B01 products (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add SKU 0AF3 SoundWire configuration (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: Add support for SKU 0AF3 product (Jaroslav Kysela) [2003613]
- ASoC: DAPM: Cover regression by kctl change notification fix (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: fix hotplug when only codec is suspended (Jaroslav Kysela) [2003613]
- ASoC: SOF:control: Fix variable type in snd_sof_refresh_control() (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Change monitor widgets to siggens (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic3x: Make aic3x_remove() return void (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: use const for all uses of snd_soc_acpi_codecs (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi-cht: shrink tables using compatible IDs (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi-byt: shrink tables using compatible IDs (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: use comp_ids to enumerate rt5682s (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: detect codec variant in probe function (Jaroslav Kysela) [2003613]
- ASoC: soc-acpi: add comp_ids field for machine driver matching (Jaroslav Kysela) [2003613]
- ASoC: Stop dummy from overriding hwparams (Jaroslav Kysela) [2003613]
- ASoC: topology: Change topology device to card device (Jaroslav Kysela) [2003613]
- ASoC: topology: Use correct device for prints (Jaroslav Kysela) [2003613]
- ASoC: topology: Check for dapm widget completeness (Jaroslav Kysela) [2003613]
- ASoC: topology: Add header payload_size verification (Jaroslav Kysela) [2003613]
- ASoC: core: Remove invalid snd_soc_component_set_jack call (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: select CONFIG_SND_SOC_ACPI (Jaroslav Kysela) [2003613]
- ASoC: Intel: glk_rt5682_max98357a: support ALC5682I-VS codec (Jaroslav Kysela) [2003613]
- ASoC: es8316: add support for ESSX8336 ACPI _HID (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Correct configuring of switch inversion from ts-inv (Jaroslav Kysela) [2003613]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: fix Kconfig dependencies (Jaroslav Kysela) [2003613]
- ASoC: rt5682-i2c: Use devm_clk_get_optional for optional clock (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on JSL (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Fix return value check in acp_machine_select() (Jaroslav Kysela) [2003613]
- ASoC: max98520: add max98520 audio amplifier driver (Jaroslav Kysela) [2003613]
- ASoC: nau8821: clarify out-of-bounds check (Jaroslav Kysela) [2003613]
- ASoC: nau8821: fix kernel-doc (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: use 'static' qualifier (Jaroslav Kysela) [2003613]
- ASoC: topology: handle endianness warning (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: SND_SOC_AMD_ACP_COMMON should depend on X86 && PCI (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: SND_SOC_AMD_{LEGACY_MACH,SOF_MACH} should depend on X86 && PCI && I2C (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Wrap AMD Audio ACP components in SND_SOC_AMD_ACP_COMMON (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: free_irq() before powering-down on probe() fail (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Reset and power-down on remove() and failed probe() (Jaroslav Kysela) [2003613]
- ASoC: nau8825: add clock management for power saving (Jaroslav Kysela) [2003613]
- ASoC: nau8825: add set_jack coponment support (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Prevent NULL pointer deref in interrupt handler (Jaroslav Kysela) [2003613]
- ASoC: wm8962: Convert to devm_clk_get_optional() (Jaroslav Kysela) [2003613]
- ASoC: fix unmet dependency on GPIOLIB for SND_SOC_MAX98357A (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Make cs35l41_remove() return void (Jaroslav Kysela) [2003613]
- ASoC: tegra: Set default card name for Trimslice (Jaroslav Kysela) [2003613]
- ASoC: tegra: Restore AC97 support (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add acp_machine struct for renoir platform. (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Downsizing the DAC volume scale (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Remove unused runtime_suspend/runtime_resume callbacks (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Minor error paths fixups (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Add support for ACPI table match entry (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Use device_property API instead of of_property (Jaroslav Kysela) [2003613]
- ASoC: Intel: Move soc_intel_is_foo() helpers to a generic header (Jaroslav Kysela) [2003613]
- ASoC: amd: enable Yellow Carp platform machine driver build (Jaroslav Kysela) [2003613]
- ASoC: amd: add YC machine driver using dmic (Jaroslav Kysela) [2003613]
- ASoC: amd: create platform device for acp6x machine driver (Jaroslav Kysela) [2003613]
- ASoC: amd: enable Yellow carp acp6x drivers build (Jaroslav Kysela) [2003613]
- ASoC: amd: add acp6x pdm driver pm ops (Jaroslav Kysela) [2003613]
- ASoC: amd: add acp6x pci driver pm ops (Jaroslav Kysela) [2003613]
- ASoC: amd: add acp6x pdm driver dma ops (Jaroslav Kysela) [2003613]
- ASoC: amd: add acp6x irq handler (Jaroslav Kysela) [2003613]
- ASoC: amd: add acp6x pdm platform driver (Jaroslav Kysela) [2003613]
- ASoC: amd: add platform devices for acp6x pdm driver and dmic driver (Jaroslav Kysela) [2003613]
- ASoC: amd: add acp6x init/de-init functions (Jaroslav Kysela) [2003613]
- ASoC: amd: add Yellow Carp ACP PCI driver (Jaroslav Kysela) [2003613]
- ASoC: amd: add Yellow Carp ACP6x IP register header (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add support for RT5682-VS codec (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add support for Maxim amplifier codec (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add SOF audio support on Chrome board (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add legacy sound card support for Chrome audio (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add generic machine driver support for ACP cards (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add callback for machine driver on ACP (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: Add I2S support on Renoir platform (Jaroslav Kysela) [2003613]
- ASoC: amd: Add common framework to support I2S on ACP SOC (Jaroslav Kysela) [2003613]
- ASoC: soc-core: tidyup empty function (Jaroslav Kysela) [2003613]
- ASoC: soc-component: add snd_soc_component_is_codec() (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step2 (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step1 (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Always enable TS_PLUG and TS_UNPLUG interrupts (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Fix WARN in remove() if running without an interrupt (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Mark OSC_SWITCH_STATUS register volatile (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Set correct SRC MCLK (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Allow time for HP/ADC to power-up after enable (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Use PLL for SCLK > 12.288MHz (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Don't claim to support 192k (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Defer probe if request_threaded_irq() returns EPROBE_DEFER (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Don't set defaults for volatile registers (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Correct some register default values (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Always configure both ASP TX channels (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Don't reconfigure the PLL while it is running (Jaroslav Kysela) [2003613]
- ASoC: soc-component: improve error reporting for register access (Jaroslav Kysela) [2003613]
- ASoC: amd: enable vangogh platform machine driver build (Jaroslav Kysela) [2003613]
- ASoC: amd: add vangogh machine driver (Jaroslav Kysela) [2003613]
- ASoc: amd: create platform device for VG machine driver (Jaroslav Kysela) [2003613]
- ASoC: test-component: add Test Component for Sound debug/test (Jaroslav Kysela) [2003613]
- ASoC: rt5682: fix a little pop while playback (Jaroslav Kysela) [2003613]
- ASoC: rt1011: Fix 'I2S Reference' enum control (Jaroslav Kysela) [2003613]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2003613]
- ASoC: amd: vangogh: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [2003613]
- ASoC: rt9120: Drop rt9210 audio amplifier support (Jaroslav Kysela) [2003613]
- ASoC: rt1011: Fix 'I2S Reference' enum control caused error (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Ensure 0dB full scale volume is used for headsets (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5651: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5651: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5651: Use temporary variable for struct device (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5651: switch to using devm_fwnode_gpiod_get() (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5651: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Use temporary variable for struct device (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2003613]
- ASoC: amd: Kconfig: Select fch clock support with machine driver (Jaroslav Kysela) [2003613]
- ASoC: soc-core: fix null-ptr-deref in snd_soc_del_component_unlocked() (Jaroslav Kysela) [2003613]
- ASoC: SOF: prepare code to allocate IPC messages in fw_ready (Jaroslav Kysela) [2003613]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: restore mixer functionality (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Fix hp pop produced immediately after resuming (Jaroslav Kysela) [2003613]
- ASoC: SOF: Introduce fragment elapsed notification API (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: Use newly introduced generic IPC stream ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: Make Intel IPC stream ops generic (Jaroslav Kysela) [2003613]
- ASoC: SOF: Introduce snd_sof_mailbox_read / snd_sof_mailbox_write callbacks (Jaroslav Kysela) [2003613]
- ASoC: SOF: pipelines: Harmonize all functions to use struct snd_sof_dev (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: do not power down primary core during topology removal (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: Dump registers and stack when SOF_DBG_DUMP_REGS is set (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-loader: Drop SOF_DBG_DUMP_REGS flag from dbg_dump calls (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: Drop SOF_DBG_DUMP_REGS flag when firmware start fails (Jaroslav Kysela) [2003613]
- ASoC: SOF: core: Clean up snd_sof_get_status() prints (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: hda: Drop 'error' prefix from error dump functions (Jaroslav Kysela) [2003613]
- ASoC: SOF: Introduce macro to set the firmware state (Jaroslav Kysela) [2003613]
- ASoC: SOF: ops: Force DSP panic dumps to be printed (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Re-enable dumps after successful IPC tx (Jaroslav Kysela) [2003613]
- ASoC: SOF: debug: Print out the fw_state along with the DSP dump (Jaroslav Kysela) [2003613]
- ASoC: SOF: Drop SOF_DBG_DUMP_FORCE_ERR_LEVEL and sof_dev_dbg_or_err (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: hda-loader: Use snd_sof_dsp_dbg_dump() for DSP dump (Jaroslav Kysela) [2003613]
- ASoC: SOF: debug: Add SOF_DBG_DUMP_OPTIONAL flag for DSP dumping (Jaroslav Kysela) [2003613]
- ASoC: SOF: debug/ops: Move the IPC and DSP dump functions out from the header (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: atom: No need to do a DSP dump in atom_run() (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: Print the DSP dump if boot fails (Jaroslav Kysela) [2003613]
- ASoC: SOF: Print the dbg_dump and ipc_dump once to reduce kernel log noise (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc and dsp dump: Add markers for better visibility (Jaroslav Kysela) [2003613]
- ASoC: SOF: debug: Swap the dsp_dump and ipc_dump sequence for fw_exception (Jaroslav Kysela) [2003613]
- ASoC: SOF: core: debug: force all processing on primary core (Jaroslav Kysela) [2003613]
- ASoC: max98927: Handle reset gpio when probing i2c (Jaroslav Kysela) [2003613]
- ASoC: DAPM: Fix missing kctl change notifications (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcht_es8316: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcht_es8316: Switch to use gpiod_get_optional() (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcht_es8316: Use temporary variable for struct device (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcht_es8316: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2003613]
- ASoC: SOF: OF: Add fw_path and tplg_path parameters (Jaroslav Kysela) [2003613]
- ASoC: amd: acp-rt5645: Constify static snd_soc_ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: return error if sof_connect_dai_widget() fails (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: allow for dynamic pipelines override for debug (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: show clks_control value in dynamic debug (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-dai: improve SSP DAI handling for dynamic pipelines (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: add new flags for DAI_CONFIG (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: add missing quirk for Dell SKU 0A45 (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add missing quirk for TGL SDCA single amp (Jaroslav Kysela) [2003613]
- ASoC: Intel: add machine driver for SOF+ES8336 (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: apl/glk/tgl: add entry for devices based on ES8336 codec (Jaroslav Kysela) [2003613]
- ASoC: Intel: cht_bsw_nau8824: Set card.components string (Jaroslav Kysela) [2003613]
- ASoC: nau8824: Add a nau8824_components() helper (Jaroslav Kysela) [2003613]
- ASoC: nau8824: Add DMI quirk mechanism for active-high jack-detect (Jaroslav Kysela) [2003613]
- ASoC: nau8824: Fix NAU8824_JACK_LOGIC define (Jaroslav Kysela) [2003613]
- ASoC: rt5651: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2003613]
- ASoC: es8316: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2003613]
- ASoC: nau8821: new driver (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: Add kernel parameter for topology verification (Jaroslav Kysela) [2003613]
- ASoC: SOF: Add support for dynamic pipelines (Jaroslav Kysela) [2003613]
- treewide: Use fallthrough pseudo-keyword (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: make sure DAI widget is set up before IPC (Jaroslav Kysela) [2003613]
- ASoC: SOF: Introduce widget use_count (Jaroslav Kysela) [2003613]
- ASoC: SOF: Don't set up widgets during topology parsing (Jaroslav Kysela) [2003613]
- ASoC: SOF: restore kcontrols for widget during set up (Jaroslav Kysela) [2003613]
- ASoC: SOF: Add new fields to snd_sof_route (Jaroslav Kysela) [2003613]
- AsoC: dapm: export a couple of functions (Jaroslav Kysela) [2003613]
- ASoC: SOF: sof-audio: add helpers for widgets, kcontrols and dai config set up (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: Add new token for dynamic pipeline (Jaroslav Kysela) [2003613]
- ASoC: SOF: control: Add access field in struct snd_sof_control (Jaroslav Kysela) [2003613]
- ASoC: topology: change the complete op in snd_soc_tplg_ops to return int (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Fix HP noise caused by SAR mode switch when the system resumes (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Enable ASRC auto-disable to fix pop during jack plug-in while playback (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp (Jaroslav Kysela) [2003613]
- ASoC: tegra: Constify static snd_soc_ops (Jaroslav Kysela) [2003613]
- ASoC: rt5682: move clk related code to rt5682_i2c_probe (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Use clk_hw based APIs for registration (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Drop usage of __clk_get_name() (Jaroslav Kysela) [2003613]
- ASoC: SOF: Change SND_SOC_SOF_TOPLEVEL from config to menuconfig (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Revise the macro RT5682S_PLLB_SRC_MASK (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Use dev_dbg instead of pr_debug (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Remove the volatile SW reset register from reg_default (Jaroslav Kysela) [2003613]
- ASoC: nau8824: Fix headphone vs headset, button-press detection no longer working (Jaroslav Kysela) [2003613]
- ASoC: intel: sof_rt5682: update platform device name for Maxim amplifier (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Make the error prints consistent in tx_wait_done() (Jaroslav Kysela) [2003613]
- ASoC: SOF: prefix some terse and cryptic dev_dbg() with __func__ (Jaroslav Kysela) [2003613]
- ASoC: SOF: add error handling to snd_sof_ipc_msg_data() (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: add header file for ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: pm: fix a stale comment (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-stream: Print stream name on STREAM_SD_OFFSET timeout (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-dai: fix potential locking issue (Jaroslav Kysela) [2003613]
- ASoC: ak4458: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: ak5558: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: dwc-i2s: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: ak4671: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: alc5623: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: bcm: Convert to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: cpcap: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: codecs: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2003613]
- ASoC: ad193x: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: tegra: Constify static snd_soc_dai_ops structs (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Use two thresholds and increased wait time for manual type detection (Jaroslav Kysela) [2003613]
- ASoC: adau1977: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: adau17x1: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: adau1701: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: adau1373: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: adau1372: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: ad1836: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: ep93xx: Convert to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: samsung: add missing "fallthrough;" (Jaroslav Kysela) [2003613]
- ASoC: ak4642: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: wcd9335: Use correct version to initialize Class H (Jaroslav Kysela) [2003613]
- ASoC: alc5632: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: ak4104: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: ak4118: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: zl38060: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: cs4341: Add SPI device ID table (Jaroslav Kysela) [2003613]
- ASoC: pcm179x: Add missing entries SPI to device ID table (Jaroslav Kysela) [2003613]
- ASoC: pl1022_rdk: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: pl1022_ds: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: mpc8610_hpcd: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: imx-sgtl5000: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: imx-es8328: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: imx-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: fsl_sai: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: fsl-mqs: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: fsl-esai: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: fsl-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: eureka-tlv320: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: cros_ec_codec: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2003613]
- ASoC: pcm512x: Mend accesses to the I2S_1 and I2S_2 registers (Jaroslav Kysela) [2003613]
- ASoC: codecs: max98390: simplify getting the adapter of a client (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: Update to modern clocking terminology (Jaroslav Kysela) [2003613]
- ASoC: SOF: Remove struct sof_ops_table and sof_get_ops() macro (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: make rt5682s_aif2_dai_ops and rt5682s_soc_component_dev (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add Tegra210 based Mixer driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add Tegra210 based ADX driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add Tegra210 based AMX driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add Tegra210 based SFC driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add Tegra210 based MVC driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add routes for few AHUB modules (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: Don't reconnect an already active BE (Jaroslav Kysela) [2003613]
- ASoC: compress/component: Use module_get_when_open/put_when_close for cstream (Jaroslav Kysela) [2003613]
- ASoC: soc-component: Convert the mark_module to void* (Jaroslav Kysela) [2003613]
- ASoC: SOF: Rename sof_arch_ops to dsp_arch_ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Remove redundant error check from sof_ipc_tx_message_unlocked (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Print 0x prefix for errors in ipc_trace/stream_message() (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Clarify the parameter name for ipc_trace_message() (Jaroslav Kysela) [2003613]
- ASoC: SOF: trace: Omit error print when waking up trace sleepers (Jaroslav Kysela) [2003613]
- misc: cs35l41: Remove unused pdn variable (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx8m: add SAI1 info (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Minor fix all errors reported by checkpatch.pl script (Jaroslav Kysela) [2003613]
- ASoC: SOF: core: Move probe work related code under a single if () branch (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Implement Manual Type detection as fallback (Jaroslav Kysela) [2003613]
- ASoC: SOF: sof-probes: Correct the function names used for snd_soc_cdai_ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Rename hda-compress.c to hda-probes.c (Jaroslav Kysela) [2003613]
- ASoC: SOF: probe: Merge and clean up the probe and compress files (Jaroslav Kysela) [2003613]
- ASoC: SOF: compress: move and export sof_probe_compr_ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: pcm: Remove non existent CONFIG_SND_SOC_SOF_COMPRESS reference (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Add probe message logging to ipc_log_header() (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: Re-phrase the missing firmware error to avoid duplication (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: release_firmware() on load failure to avoid batching (Jaroslav Kysela) [2003613]
- ASoC: SOF: debug: No need to export the snd_sof_debugfs_io_item() (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: Use the generic ops for region debugfs handling (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2003613]
- ASoC: SOF: debug: Add generic API and ops for DSP regions (Jaroslav Kysela) [2003613]
- ASoC: SOF: core: Do not use 'bar' as parameter for block_read/write (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: No need to export snd_sof_fw_parse_ext_data() (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: Do not initialize the snd_sof_dsp_ops.read64 (Jaroslav Kysela) [2003613]
- ASoC: SOF: ipc: Remove snd_sof_dsp_mailbox_init() (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: bdw: Set the mailbox offset directly in bdw_probe (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: imx8m: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: imx8: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Fix a bunch of trivial code formating/style issues (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Fixup the error messages (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Don't overwrite returned error code (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Combine adjacent register writes (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Use regmap_read_poll_timeout to wait for OTP boot (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: Fix use of an uninitialised variable (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: load_firmware callback is mandatory, treat it like that (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: Relocate inline definitions from hda.h to hda.c for sdw (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: Remove boot_firmware skl and iccmax_icl declarations (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-dsp: Declare locally used functions as static (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: Do no initialize resindex_dma_base (Jaroslav Kysela) [2003613]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_mx98360a board (Jaroslav Kysela) [2003613]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015 board (Jaroslav Kysela) [2003613]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015p board (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: support ALC5682I-VS codec (Jaroslav Kysela) [2003613]
- ASoC: SOF: Fix DSP oops stack dump output contents (Jaroslav Kysela) [2003613]
- ASoC: pcm5102a: increase rate from 192k to 384k (Jaroslav Kysela) [2003613]
- ASoC: rt1011: add i2s reference control for rt1011 (Jaroslav Kysela) [2003613]
- ASoC: SOF: Handle control change notification from firmware (Jaroslav Kysela) [2003613]
- ASoC: SOF: control: fix a typo in put operations for kcontrol (Jaroslav Kysela) [2003613]
- ASoC: rt5682s: Add driver for ALC5682I-VS codec (Jaroslav Kysela) [2003613]
- ASoC: SOF: core: allow module parameter to override dma trace Kconfig (Jaroslav Kysela) [2003613]
- ASoC: soc-topology: Move template info print soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2003613]
- ASoC: amd: acp: declare and add prefix to 'bt_uart_enable' symbol (Jaroslav Kysela) [2003613]
- ASoC: cs35l41: CS35L41 Boosted Smart Amplifier (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: tag SoundWire BEs as non-atomic (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: Fix CONFIG_SND_SOC_SDW_MOCKUP select (Jaroslav Kysela) [2003613]
- ASoC: rt5682: fix headset background noise when S3 state (Jaroslav Kysela) [2003613]
- ASoC: Revert PCM trigger changes (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: protect BE dailink state changes in trigger (Jaroslav Kysela) [2003613]
- ASoC: dwc: Get IRQ optionally (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Fix the vol+ button detection issue (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Make rt5640_jack_gpio/rt5640_jack2_gpio static (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: remove duplicate include (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: move common ATOM stuff to module (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: byt: prepare split between Baytrail and Merrifield (Jaroslav Kysela) [2003613]
- ASoC: rt1015: remove possible unused variable `bclk_ms' (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Mark hp_elitepad_1000g2_jack?_check functions static (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Select first entry for singular pipe config arrays (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Properly configure modules with generic extension (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Support modules with generic extension (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Support multiple format configs (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Simplify m_state for loadable modules (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Fix passing loadable flag for module (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Fix module configuration for KPB and MIXER (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Fix module resource and format selection (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Select proper format for NHLT blob (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: Leave data as is when invoking TLV IPCs (Jaroslav Kysela) [2003613]
- ASoC: Intel: kbl_da7219_max98927: Fix format selection for max98373 (Jaroslav Kysela) [2003613]
- ASoC: intel: atom: Revert PCM buffer address setup workaround again (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Add support for HP Elite Pad 1000G2 jack-detect (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytct_rt5640: Add a separate "Headset Mic 2" DAPM pin for the mic on the 2nd jack (Jaroslav Kysela) [2003613]
- ASoC: rt5640: Add rt5640_set_ovcd_params() helper (Jaroslav Kysela) [2003613]
- ASoC: rt5640: Add optional hp_det_gpio parameter to rt5640_detect_headset() (Jaroslav Kysela) [2003613]
- ASoC: rt5640: Delay requesting IRQ until the machine-drv calls set_jack (Jaroslav Kysela) [2003613]
- ASoC: rt5640: Move rt5640_disable_jack_detect() up in the rt5640.c file (Jaroslav Kysela) [2003613]
- ASoC: intel: atom: Fix breakage for PCM buffer address setup (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Use cfg-lineout:2 in the components string (Jaroslav Kysela) [2003613]
- ASoC: tegra30: i2s: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2003613]
- ASoC: tegra30: i2s: Use of_device_get_match_data (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Use of_device_get_match_data (Jaroslav Kysela) [2003613]
- ASoC: soc-ac97: cleanup cppcheck warning (Jaroslav Kysela) [2003613]
- ASoC: soc-component: cleanup cppcheck warning at snd_soc_pcm_component_pm_runtime_get() (Jaroslav Kysela) [2003613]
- ASoC: soc-jack: cleanup cppcheck warning for CONFIG_GPIOLIB (Jaroslav Kysela) [2003613]
- ASoC: soc-jack: cleanup cppcheck warning at snd_soc_jack_report() (Jaroslav Kysela) [2003613]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_pcm_dai_new() (Jaroslav Kysela) [2003613]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_dai_link_set_capabilities() (Jaroslav Kysela) [2003613]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_copy_user() (Jaroslav Kysela) [2003613]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_new() (Jaroslav Kysela) [2003613]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_hw_params() (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw_rt711*: keep codec device reference until remove (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: pass card information to init/exit functions (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: handle errors with acpi_dev_get_first_match_dev() (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: harden codec property handling (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Remove unused variable in rt5682_i2c_remove() (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: make DMI L1 selection more robust (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: simplify logic for DMI_L1 handling (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-stream: remove always true condition (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Kconfig: clarify DMI L1 option description (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Properly turn off regulators if wrong device ID (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Implement remove callback (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Disable irq on shutdown (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Adjust headset volume button threshold again (Jaroslav Kysela) [2003613]
- ASoC: Intel: Fix platform ID matching (Jaroslav Kysela) [2003613]
- ASoC: rt1015p: add new acpi id and comapatible id (Jaroslav Kysela) [2003613]
- ASoC: max98390: Add support change dsm param name (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Update module authors (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Assume 24-bit samples are in 32-bit slots (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Validate dai_set_sysclk() frequency (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Add PLL configuration for 44.1kHz/16-bit (Jaroslav Kysela) [2003613]
- ASoC: rt5640: Silence warning message about missing interrupt (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Fix mono playback (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Constrain sample rate to prevent illegal SCLK (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Fix LRCLK frame start edge (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: PLL must be running when changing MCLK_SRC_SEL (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Add support for set_jack calls (Jaroslav Kysela) [2003613]
- ASoC: mt6359-accdet.c: remove useless assignments (Jaroslav Kysela) [2003613]
- ASoC: max98090: remove duplicate status reads and useless assignmment (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at soc_dapm_dai_stream_event() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_new_controls() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_weak_routes() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_add_routes() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_del_route() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_run() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_check_event() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_dai_link() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_pga() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_set_mixer_path_status() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_connect_mux() (Jaroslav Kysela) [2003613]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_wcache_lookup() (Jaroslav Kysela) [2003613]
- ASoC: amd: vangogh: Drop superfluous mmap callback (Jaroslav Kysela) [2003613]
- ASoC: sprd: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: qcom: qdsp6: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: mpc5200: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: fsl_dma: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: fsl_asrc_dma: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: fsl: imx-pcm-fiq: Use managed buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: bcm: Use managed PCM buffer allocation (Jaroslav Kysela) [2003613]
- ALSA: pxa2xx: Use managed PCM buffer allocation (Jaroslav Kysela) [2003613]
- ASoC: rt5514: make array div static const, makes object smaller (Jaroslav Kysela) [2003613]
- ASoC: codecs: ad193x: add support for 96kHz and 192kHz playback rates (Jaroslav Kysela) [2003613]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_xr_sx() (Jaroslav Kysela) [2003613]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_get_xr_sx() (Jaroslav Kysela) [2003613]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_limit_volume() (Jaroslav Kysela) [2003613]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_volsw_sx() (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw_max98373: remove useless inits (Jaroslav Kysela) [2003613]
- ASoC: Intel: update sof_pcm512x quirks (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Use DMI string to search for adl_mx98373_rt5682 variant (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: add quirk for Dell XPS 9710 (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Remove duplicate control for WNF filter frequency (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Fix inversion of ADC Notch Switch control (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda-ipc: fix reply size checking (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Kconfig: fix SoundWire dependencies (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Fix HP ElitePad 1000 G2 quirk (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Add support for a second headset mic input (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Add support for a second headphones output (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Add a byt_rt5640_get_codec_dai() helper (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Add line-out support (Jaroslav Kysela) [2003613]
- ASoC: Intel: bytcr_rt5640: Move "Platform Clock" routes to the maps for the matching in-/output (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: add snd_sof_dsp_check_sdw_irq ops (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: move sof_intel_dsp_desc() forward (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: hda: remove HDA_DSP_REG_SNDW_WAKE_STS definition (Jaroslav Kysela) [2003613]
- ASoC: SOF: intel: add sdw_shim/alh_base to sof_intel_dsp_desc (Jaroslav Kysela) [2003613]
- ASoC: soc-topology: cleanup cppcheck warning at snd_soc_find_dai_link() (Jaroslav Kysela) [2003613]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_kcontrol_elems_load() (Jaroslav Kysela) [2003613]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dapm_widget_elems_load() (Jaroslav Kysela) [2003613]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dai_elems_load() (Jaroslav Kysela) [2003613]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_process_headers() (Jaroslav Kysela) [2003613]
- ASoC: amd: Fix reference to PCM buffer address (Jaroslav Kysela) [2003613]
- soundwire: add flag to ignore all command/control for mockup devices (Jaroslav Kysela) [2003613]
- ASoC: nau8824: Fix open coded prefix handling (Jaroslav Kysela) [2003613]
- ASoC: uniphier: Fix reference to PCM buffer address (Jaroslav Kysela) [2003613]
- ASoC: xilinx: Fix reference to PCM buffer address (Jaroslav Kysela) [2003613]
- ASoC: intel: atom: Fix reference to PCM buffer address (Jaroslav Kysela) [2003613]
- ASoC: intel: skylake: Drop superfluous mmap callback (Jaroslav Kysela) [2003613]
- ASoC: amd: Drop superfluous mmap callbacks (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Fix bclk calculation for mono (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Don't allow SND_SOC_DAIFMT_LEFT_J (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Correct definition of ADC Volume control (Jaroslav Kysela) [2003613]
- ASoC: v253_init: eliminate pointer to string (Jaroslav Kysela) [2003613]
- ASoC: samsung: Constify static snd_soc_ops (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_routing() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_simple_widgets() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_add_controls() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_unregister_component() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_daifmt_parse_format() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_get_dai_name() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_set_dmi_name() (Jaroslav Kysela) [2003613]
- ASoC: Intel: Fix spelling contraction "cant" -> "can't" (Jaroslav Kysela) [2003613]
- ASoC: component: Remove misplaced prefix handling in pin control functions (Jaroslav Kysela) [2003613]
- ASoC: amd: fix an IS_ERR() vs NULL bug in probe (Jaroslav Kysela) [2003613]
- ASoC: rt5682: enable SAR ADC power saving mode during suspend (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_runtime_setup_be_chan() (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_be_is_active() (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_get_playback_capture() (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_components_close() (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_apply_msb() (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: enforce exclusion between HDaudio and SoundWire (Jaroslav Kysela) [2003613]
- ASoC: topology: Select SND_DYNAMIC_MINORS (Jaroslav Kysela) [2003613]
- ASoC: rt1015: Remove unnecessary flush work on rt1015 driver (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_da7219_mx98360a: fail to initialize soundcard (Jaroslav Kysela) [2003613]
- ASoC: amd: Use dev_probe_err helper (Jaroslav Kysela) [2003613]
- ASoC: amd: Don't show messages about deferred probing by default (Jaroslav Kysela) [2003613]
- ASoC: amd: enable stop_dma_first flag for cz_dai_7219_98357 dai link (Jaroslav Kysela) [2003613]
- ASoC: amd: enable vangogh acp5x driver build (Jaroslav Kysela) [2003613]
- ASoC: amd: add vangogh i2s dma driver pm ops (Jaroslav Kysela) [2003613]
- ASoC: amd: add vangogh pci driver pm ops (Jaroslav Kysela) [2003613]
- ASoC: amd: add vangogh i2s dai driver ops (Jaroslav Kysela) [2003613]
- ASoC: amd: add vangogh i2s controller driver (Jaroslav Kysela) [2003613]
- ASoC: amd: add ACP5x pcm dma driver ops (Jaroslav Kysela) [2003613]
- ASoC: amd: irq handler changes for ACP5x PCM dma driver (Jaroslav Kysela) [2003613]
- ASoC: amd: add ACP5x PCM platform driver (Jaroslav Kysela) [2003613]
- ASoC: amd: create acp5x platform devices (Jaroslav Kysela) [2003613]
- ASoc: amd: add acp5x init/de-init functions (Jaroslav Kysela) [2003613]
- ASoC: amd: add Vangogh ACP PCI driver (Jaroslav Kysela) [2003613]
- ASoC: amd: add Vangogh ACP5x IP register header (Jaroslav Kysela) [2003613]
- ASoC: amd: renoir: Run hibernation callbacks (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Adjust headset volume button threshold (Jaroslav Kysela) [2003613]
- ASOC: Intel: sof_sdw: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Fix the issue of garbled recording after powerd_dbus_suspend (Jaroslav Kysela) [2003613]
- ASoC: amd: reverse stop sequence for stoneyridge platform (Jaroslav Kysela) [2003613]
- ASoC: soc-pcm: add a flag to reverse the stop sequence (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: sof_sdw: add SoundWire mockup codecs for tests (Jaroslav Kysela) [2003613]
- ASoC: soc-acpi: tgl: add table for SoundWire mockup devices (Jaroslav Kysela) [2003613]
- ASoC: soc-acpi: cnl: add table for SoundWire mockup devices (Jaroslav Kysela) [2003613]
- ASoC: codecs: add SoundWire mockup device support (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: update quirk for jack detection in ADL RVP (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: include rt711.h for RT711 JD mode (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: extends SOF_RT711_JDSRC to 4 bits (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: code refactor for max98360a (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: code refactor for max98357a (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: Enable Bluetooth offload on tgl and adl (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_cs42l42: add support for jsl_cs4242_mx98360a (Jaroslav Kysela) [2003613]
- ASoC: Intel: maxim-common: support max98360a (Jaroslav Kysela) [2003613]
- ASoC: Intel: maxim-common: support max98357a (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_cs42l42: support arbitrary DAI link sequence (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Update ADL descriptor to use ACPI power states (Jaroslav Kysela) [2003613]
- ASoC: rt5631: Fix regcache sync errors on resume (Jaroslav Kysela) [2003613]
- ASoC: amd: fix spelling mistakes (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_cs42l42: use helper function to get bclk frequency (Jaroslav Kysela) [2003613]
- ASoC: SOF: add a helper to get topology configured bclk (Jaroslav Kysela) [2003613]
- ASoC: tegra: Use ADMAIF component for DMA allocations (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: fix xrun issue on platform with max98373 (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: tegra: mark runtime-pm functions as __maybe_unused (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Remove handing of disabled runtime PM (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Correct suspend-resume callbacks (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Reset global variable (Jaroslav Kysela) [2003613]
- ASoC: tegra30: ahub: Switch to use reset-bulk API (Jaroslav Kysela) [2003613]
- ASoC: tegra: ahub: Reset hardware properly (Jaroslav Kysela) [2003613]
- ASoC: tegra: ahub: Use clk_bulk helpers (Jaroslav Kysela) [2003613]
- ASoC: tegra: ahub: Add missing resets (Jaroslav Kysela) [2003613]
- ASoC: tegra: tegra210_admaif: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: tegra20: spdif: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: tegra20: i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: simple-card: Fill in driver name (Jaroslav Kysela) [2003613]
- ASoC: SOF: imx: Add missing of_node_put() in imx8_probe() (Jaroslav Kysela) [2003613]
- ASoC: Intel: skl_hda_dsp_generic: Update Kconfig documentation (Jaroslav Kysela) [2003613]
- ASoC: Intel: use MODULE_DEVICE_TABLE with platform_device_id tables (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add ull suffix for SoundWire _ADR values (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: fix signed/unsigned warning (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_da7219_max98373: shrink platform_id below 20 characters (Jaroslav Kysela) [2003613]
- ASoC: Intel: kbl_da7219_max98357a: shrink platform_id below 20 characters (Jaroslav Kysela) [2003613]
- ASoC: Intel: glk_rt5682_max98357a: shrink platform_id below 20 characters (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_rt5682: shrink platform_id names below 20 characters (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: remove hdac-hdmi support (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: use mach data for ADL RVP DMIC count (Jaroslav Kysela) [2003613]
- ASoC: tegra: Fix a NULL vs IS_ERR() check (Jaroslav Kysela) [2003613]
- ASoC: rt711: add two jack detection modes (Jaroslav Kysela) [2003613]
- ASoC: samsung: s3c24xx-i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: samsung: s3c2412-i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: samsung: pcm: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: samsung: i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: remove snd_soc_of_parse_daifmt() (Jaroslav Kysela) [2003613]
- ASoC: simple-card-utils: switch to use snd_soc_daifmt_parse_format/clock_provider() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: add snd_soc_daifmt_parse_format/clock_provider() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: add snd_soc_daifmt_clock_provider_fliped() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: add snd_soc_daifmt_clock_provider_from_bitmap() (Jaroslav Kysela) [2003613]
- ASoC: rt711-sdca-sdw: fix race condition on system suspend (Jaroslav Kysela) [2003613]
- ASoC: rt5682-sdw: fix race condition on system suspend (Jaroslav Kysela) [2003613]
- ASoC: rt711-sdw: fix race condition on system suspend (Jaroslav Kysela) [2003613]
- ASoC: rt700-sdw: fix race condition on system suspend (Jaroslav Kysela) [2003613]
- ASoC: fsi: fix spelling mistake (Jaroslav Kysela) [2003613]
- ASoC: Intel: bdw-rt5677: remove unnecessary oom message (Jaroslav Kysela) [2003613]
- ASoC: spear: spdif_out: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: sprd: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: Fix the error return code in snd_soc_of_parse_audio_routing() (Jaroslav Kysela) [2003613]
- ASoC: sti: sti_uniperif: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: stm32: spdifrx: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: stm32: sai: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: stm32: i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: make hdmi_codec_controls static (Jaroslav Kysela) [2003613]
- ASoC: rockchip: spdif: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: rockchip: pdm: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: rockchip: i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Correct definition of CS42L42_ADC_PDN_MASK (Jaroslav Kysela) [2003613]
- ASoC: hisilicon: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: jz4740-i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: img-spdif-out: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: img-spdif-in: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: img-parallel-out: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: img-i2s-out: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: img-i2s-in: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: dwc: dwc-i2s: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ASoC: tegra: Squash utils into common machine driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Specify components string for each card (Jaroslav Kysela) [2003613]
- ASoC: tegra: Unify ASoC machine drivers (Jaroslav Kysela) [2003613]
- ASoC: tegra: SND_SOC_TEGRA_AUDIO_GRAPH_CARD should depend on SND_SOC_TEGRA (Jaroslav Kysela) [2003613]
- ASoC: tegra20-spdif: remove "default m" (Jaroslav Kysela) [2003613]
- ASoC: tegra: Add audio graph based card driver (Jaroslav Kysela) [2003613]
- ASoC: tegra: Set driver_name=tegra for all machine drivers (Jaroslav Kysela) [2003613]
- ASoC: rt5640: Make codec selectable (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: Add a prepare hook (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: Add iec958 controls (Jaroslav Kysela) [2003613]
- ASoC: rt5645: Avoid upgrading static warnings to errors (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: Rework to support more controls (Jaroslav Kysela) [2003613]
- ASoC: soc-core: don't use discriminatory terms on snd_soc_runtime_get_dai_fmt() (Jaroslav Kysela) [2003613]
- ASoC: rt711-sdca: handle mbq_regmap in rt711_sdca_io_init (Jaroslav Kysela) [2003613]
- ASoC: rt711-sdca-sdw: add readable for SDW_SDCA_CTL() registers (Jaroslav Kysela) [2003613]
- ASoC: rt5682-sdw: set regcache_cache_only false before reading RT5682_DEVICE_ID (Jaroslav Kysela) [2003613]
- ASoC: rt5682: Fix a problem with error handling in the io init function of the soundwire (Jaroslav Kysela) [2003613]
- ASoC: rt715-sdca: fix clock stop prepare timeout issue (Jaroslav Kysela) [2003613]
- ASoC: rt715-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt715-sdca-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt711-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt711-sdca-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt700-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt5682-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt1316-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: rt1308-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: max98373-sdw: use first_hw_init flag on resume (Jaroslav Kysela) [2003613]
- ASoC: max98373-sdw: add missing memory allocation check (Jaroslav Kysela) [2003613]
- ASoC: hdmi-codec: add .auto_selectable_formats support (Jaroslav Kysela) [2003613]
- ASoC: fsi: add .auto_selectable_formats support (Jaroslav Kysela) [2003613]
- ASoC: pcm3168a: add .auto_selectable_formats support (Jaroslav Kysela) [2003613]
- ASoC: ak4613: add .auto_selectable_formats support (Jaroslav Kysela) [2003613]
- ASoC: soc-core: add snd_soc_runtime_get_dai_fmt() (Jaroslav Kysela) [2003613]
- ASoC: soc-core: move snd_soc_runtime_set_dai_fmt() to upside (Jaroslav Kysela) [2003613]
- ASoC: Intel: Skylake: use DEVICE_ATTR_RO macro (Jaroslav Kysela) [2003613]
- mfd: arizona: Allow building arizona MFD-core as module (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: pci-tgl: add ADL-M support (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: don't print ROM status if cl_dsp_init() fails (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: clean up hda_dsp_dump() (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: Constify sof_probe_compressed_ops (Jaroslav Kysela) [2003613]
- ASoC: wm5110: Constify static struct snd_compress_ops (Jaroslav Kysela) [2003613]
- ASoC: wm5102: Constify static struct snd_compress_ops (Jaroslav Kysela) [2003613]
- ASoC: cs47125: Constify static struct snd_compress_ops (Jaroslav Kysela) [2003613]
- ASoC: cs42l52: use DEVICE_ATTR_WO macro (Jaroslav Kysela) [2003613]
- ASoC: cs35l3x: Use neutral language in amp drivers (Jaroslav Kysela) [2003613]
- ASoC: cs43130: Use DEVICE_ATTR_RO macro (Jaroslav Kysela) [2003613]
- ASoC: wm8962: Use DEVICE_ATTR_WO macro (Jaroslav Kysela) [2003613]
- ASoC: cs42l56: use DEVICE_ATTR_WO macro (Jaroslav Kysela) [2003613]
- ASoC: tlv320aic26: use DEVICE_ATTR_RW macro (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Check jack status before reporting button events (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Add support for 2400000 Bit clock (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Add support for 2304000 Bit clock (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: Fix 1536000 Bit Clock instability (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: add quirk support for Brya and BT-offload (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: add SOF_RT715_DAI_ID_FIX for AlderLake (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: remove .nonatomic for BE dailinks (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_sdw: add support for Bluetooth offload (Jaroslav Kysela) [2003613]
- ASoC: Intel: common: Add entries for sdw codecs in ADL match table (Jaroslav Kysela) [2003613]
- ASoC: Intel: soc-acpi: add entries for i2s machines in ADL match table (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: Remove conditions against CONFIG_PCI (Jaroslav Kysela) [2003613]
- ASoC: SOF: ops: don't return void value (Jaroslav Kysela) [2003613]
- ASoC: SOF: topology: fix assignment to use le32_to_cpu (Jaroslav Kysela) [2003613]
- ASoC: SOF: loader: Use snd_sof_dsp_block_read() instead sof_block_read() (Jaroslav Kysela) [2003613]
- ASoC: SOF: ops: print out the polling register (Jaroslav Kysela) [2003613]
- ASoC: SOF: pci: No need to cast second time to save the desc (Jaroslav Kysela) [2003613]
- ASoC: SOF: Check desc->ops directly in acpi/pci/of probe functions (Jaroslav Kysela) [2003613]
- ASoC: topology: Fix using uninitialized pointer (Jaroslav Kysela) [2003613]
- ASoC: soc-dai: fix up hw params only if it is needed (Jaroslav Kysela) [2003613]
- ASoC: soc-core: use DEVICE_ATTR_RO macro (Jaroslav Kysela) [2003613]
- ASoC: topology: Add support for multiple kcontrol types to a widget (Jaroslav Kysela) [2003613]
- ASoC: intel/boards: add missing MODULE_DEVICE_TABLE (Jaroslav Kysela) [2003613]
- ASoC: cs43130: handle errors in cs43130_probe() properly (Jaroslav Kysela) [2003613]
- Revert "ASoC: cs43130: fix a NULL pointer dereference" (Jaroslav Kysela) [2003613]
- ASoC: cs42l42: make HSBIAS_SENSE_EN optional (Jaroslav Kysela) [2003613]
- ASoC: wm2200: remove include of wmfw.h (Jaroslav Kysela) [2003613]
- ASoC: wm_adsp: mark more data structures with the const qualifier (Jaroslav Kysela) [2003613]
- ASoC: Intel: bxt_da7219_max98357a: shrink platform_id below 20 characters (Jaroslav Kysela) [2003613]
- ASoC: Intel: sof_cs42l42: shrink platform id below 20 characters (Jaroslav Kysela) [2003613]
- ASoC: Intel: add sof-cs42l42 machine driver (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: create sof-maxim-common module (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: handle hda-dsp-common as a module (Jaroslav Kysela) [2003613]
- ASoC: Intel: boards: add support for adl boards in sof-rt5682 (Jaroslav Kysela) [2003613]
- ASoC: Intel: Boards: tgl_max98373: Add BT offload support (Jaroslav Kysela) [2003613]
- ASoC: SOF: Intel: hda: fix index used in inner loop (Jaroslav Kysela) [2003613]
- ALSA: fireworks: add support for Loud Onyx 1200f quirk (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for MOTU Track 16 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for MOTU Traveler mk3 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: remove TODO for interaction with userspace about control message (Jaroslav Kysela) [2003613]
- ALSA: oxfw: fix functional regression for Mackie Onyx 1640i in v5.14 or later (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: export meter information to userspace as float value (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: refine parser for meter information in register DSP models (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix null pointer dereference when polling hwdep character device (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: notify event for parameter change in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: queue event for parameter change in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add ioctl command to read cached parameters in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: parse messages for input parameters in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: parse messages for line input parameters in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: parse messages for output parameters in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: parse messages for mixer output parameters in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: parse messages for mixer source parameters in register-DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add ioctl command to read cached hardware meter (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add message parser for meter information in command DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add message parser to gather meter information in register DSP model (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix truncated bytes in message tracepoints (Jaroslav Kysela) [2003613]
- ALSA: oxfw: fix transmission method for Loud models based on OXFW971 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for MOTU 896HD (Jaroslav Kysela) [2003613]
- ALSA: oxfw: fix functioal regression for silence in Apogee Duet FireWire (Jaroslav Kysela) [2003613]
- ALSA: bebob: correct duplicated entries with TerraTec OUI (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: Fix 'amdtp_domain_start()' when no AMDTP_OUT_STREAM stream is found (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix register handling for 896 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix register handling for 828 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: use macro instead of magic number for clock source in v3 protocol (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: code refactoring for source detection of sampling clock in v3 protocol (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: code refactoring for packet format detection in v2 protocol (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: use macro instead of magic number for clock source in v2 protocol (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for AES/EBU clock source in v2 protocol (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: code refactoring for detection of clock source in v2 protocol (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix detection for S/PDIF source on optical interface in v2 protocol (Jaroslav Kysela) [2003613]
- ALSA: bebob: add support for ToneWeal FW66 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix rx packet format at higher rate for MOTU 828 mk3 Hybrid (Jaroslav Kysela) [2003613]
- ALSA: bebob: fix rx packet format for Yamaha GO44/GO46, Terratec Phase 24/x24 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix stream format for MOTU 8pre FireWire (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for MOTU 896 (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for MOTU 828 (Jaroslav Kysela) [2003613]
- ALSA: bebob: Fix bit flag quirk constants (Jaroslav Kysela) [2003613]
- ALSA: firewire: fill Kconfig with entries for devices based on DICE ASICs (Jaroslav Kysela) [2003613]
- ALSA: bebob: correct device entries for Phonic Helix Board and FireFly series (Jaroslav Kysela) [2003613]
- ALSA: bebob: code refactoring for M-Audio models (Jaroslav Kysela) [2003613]
- ALSA: bebob: correct device entry for Acoustic Reality eAR Master One, Eroica, Figaro, and Ciaccona (Jaroslav Kysela) [2003613]
- ALSA: bebob: correct device entry for Mackie D.2 FireWire option card (Jaroslav Kysela) [2003613]
- ALSA: fireworks: fulfil device entries (Jaroslav Kysela) [2003613]
- ALSA: bebob: fulfil device entries (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: replace in_interrupt() with in_softirq() (Jaroslav Kysela) [2003613]
- ALSA: bebob: code refactoring for model-dependent quirks (Jaroslav Kysela) [2003613]
- ALSA: bebob: delete workaround for protocol version 3 (Jaroslav Kysela) [2003613]
- ALSA: bebob: dismiss sleep after breaking connections (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: obsolete workqueue for period update (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: operate for period elapse event in process context (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: delete unused kernel API (Jaroslav Kysela) [2003613]
- ALSA: fireface: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: firewire-tascam: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: firewire-digi00x: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: dice: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: oxfw: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: fireworks: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: bebob: cease from delayed card registration (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: add support for hybrid model of MOTU Ultralite mk3 (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: remove useless operations for kernel preemption (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: fix error codes for allocation failure (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: fix error return code in snd_motu_stream_reserve_duplex() (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: sequence replay for source packet header (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: cache event ticks in source packet header per data block (Jaroslav Kysela) [2003613]
- ALSA: firewire-motu: use macro for magic numbers relevant to IEC 61883-1 (Jaroslav Kysela) [2003613]
- ALSA: bebob: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: dice: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: dice: wait just for NOTIFY_CLOCK_ACCEPTED after GLOBAL_CLOCK_SELECT operation (Jaroslav Kysela) [2003613]
- ALSA: fireface: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: firewire-tascam: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: firewire-digi00x: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: oxfw: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: fireworks: perform sequence replay for media clock recovery (Jaroslav Kysela) [2003613]
- ALSA: fireworks: delete SYTMATCH clock source (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: support NO_PERIOD_WAKEUP in ALSA PCM runtime (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: transfer rx packets on-the-fly when replaying (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: replay sequence of incoming packets for outgoing packets (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: add replay target to cache sequence of packet (Jaroslav Kysela) [2003613]
- ALSA: bebob: distinguish M-Audio ProFire Lightbridge quirk (Jaroslav Kysela) [2003613]
- ALSA: bebob: cancel switching connection order (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: obsolete callbacked member (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: drop initial NODATA or empty packet (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for transfer delay (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for generation of data block sequence (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for generation of syt sequence (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for generation of packet descriptors (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: pool sequence of packet in IT context independently (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: add flag to unaware of syt in CIP header (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: Fix uninitialized variable err issue (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: change waking up timing to process packets (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: start processing content of packet at the same cycle in several IT contexts (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring to start several IT/IR contexts (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: skip initial packets instead of scheduling IR context (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: start processing content of packet at the same cycle in several IR contexts (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for selection of IT context header length (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for calculation of context payload (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for size of CIP header (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: insert descriptor for skipped cycle (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: check cycle continuity (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for check of CIP header about payload size (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for parser of IR context header (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for helper function to compute OHCI 1394 cycle (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for sequence descriptor' (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: handle the case that empty isochronous packet payload for CIP (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring to refer the same frame count per period in domain structure (Jaroslav Kysela) [2003613]
- ALSA: oxfw: add quirk flag for blocking transmission method (Jaroslav Kysela) [2003613]
- ALSA: oxfw: code refactoring for wrong_dbs quirk (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib: code refactoring for jumbo payload quirk (Jaroslav Kysela) [2003613]
- ALSA: oxfw: code refactoring for jumbo-payload quirk in OXFW970 (Jaroslav Kysela) [2003613]
- ALSA: oxfw: add comment for the type of ASICs (Jaroslav Kysela) [2003613]
- ALSA: oxfw: add explicit device entry for Loud Technologies Mackie Onyx Sattelite (Jaroslav Kysela) [2003613]
- ALSA: oxfw: add explicit device entry for Loud Technologies Tapco Link.FireWire 4x6 (Jaroslav Kysela) [2003613]
- ALSA: oxfw: code refactoring to detect mackie models (Jaroslav Kysela) [2003613]
- ALSA: oxfw: code refactoring for existent device entry with specifier_id and version (Jaroslav Kysela) [2003613]
- ALSA: firewire-lib/motu: use int type for the value of bitwise OR with enumerator-constant (Jaroslav Kysela) [2003613]
- Revert "ALSA: bebob/oxfw: fix Kconfig entry for Mackie d.2 Pro" (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix quirk for Clevo NJ51CU (Jaroslav Kysela) [2003613]
- ALSA: hda/hdmi: Disable silent stream on GLK (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add new alc285-hp-amp-init model (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Amp init fixup for HP ZBook 15 G6 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek - Add headset Mic support for Lenovo ALC897 platform (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2003613]
- ALSA: hda/hdmi: fix HDA codec entry table order for ADL-P (Jaroslav Kysela) [2003613]
- ALSA: hda: Add Intel DG2 PCI ID and HDMI codec vid (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Set PMSG_ON earlier inside cs8409 driver (Jaroslav Kysela) [2003613]
- ALSA: ctxfi: Fix out-of-range access (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix LED on HP ProBook 435 G7 (Jaroslav Kysela) [2003613]
- ALSA: cmipci: Drop stale variable assignment (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for ASRock NUC Box 1100 (Jaroslav Kysela) [2003613]
- ALSA: hda: fix general protection fault in azx_runtime_idle (Jaroslav Kysela) [2003613]
- ALSA: hda: Free card instance properly at probe errors (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for HP EliteBook 840 G7 mute LED (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for ASUS UX550VE (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add a quirk for Acer Spin SP513-54N (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Headset fixup for Clevo NH77HJQ (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for Clevo PC70HS (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 mute LED (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix mic mute LED for the HP Spectre x360 14 (Jaroslav Kysela) [2003613]
- ALSA: ISA: not for M68K (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fixes HP Spectre x360 15-eb1xxx speakers (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for Clevo PC50HS (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix the mic type detection issue for ASUS G551JW (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo 13s Gen2 (Jaroslav Kysela) [2003613]
- ALSA: hda: intel: Allow repeatedly probing on codec configuration errors (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek - ALC236 headset MIC recording issue (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add quirk for Clevo X170KM-G (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Complete partial device name to avoid ambiguity (Jaroslav Kysela) [2003613]
- ALSA: hda - Enable headphone mic on Dell Latitude laptops with ALC3254 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Enable 4-speaker output for Dell Precision 5560 laptop (Jaroslav Kysela) [2003613]
- ALSA: hda: Use position buffer for SKL+ again (Jaroslav Kysela) [2003613]
- ALSA: hda: Reduce udelay() at SKL+ position reporting (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Setup Dolphin Headset Mic as Phantom Jack (Jaroslav Kysela) [2003613]
- ALSA: pcxhr: "fix" PCXHR_REG_TO_PORT definition (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Quirks to enable speaker output for Lenovo Legion 7i 15IMHG05, Yoga 7i 14ITL5/15ITL5, and 13s Gen2 laptops. (Jaroslav Kysela) [2003613]
- Revert "ALSA: hda: Drop workaround for a hang at shutdown again" (Jaroslav Kysela) [2003613]
- ALSA: vx222: fix null-ptr-deref (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Initialize Codec only in init fixup. (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Ensure Type Detection is only run on startup when necessary (Jaroslav Kysela) [2003613]
- ALSA: hda: Disable runtime resume at shutdown (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup (Jaroslav Kysela) [2003613]
- ALSA: hda: Code refactoring snd_hda_pick_fixup() (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS ROG Strix G17 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Limit mic boost on HP ProBook 445 G8 (Jaroslav Kysela) [2003613]
- ALSA: hda/analog - Sink ad198x_shutup() and shuffle CONFIG_PM guards (Jaroslav Kysela) [2003613]
- ALSA: hda/sigmatel - Sink stac_shutup() into stac_suspend() (Jaroslav Kysela) [2003613]
- ALSA: hda: Drop workaround for a hang at shutdown again (Jaroslav Kysela) [2003613]
- ALSA: hda/via: Apply runtime PM workaround for ASUS B23E (Jaroslav Kysela) [2003613]
- ALSA: hda: Fix hang during shutdown due to link reset (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15 9510 laptop (Jaroslav Kysela) [2003613]
- ALSA: hda: Nuke unused reboot_notify callback (Jaroslav Kysela) [2003613]
- ALSA: hda: Suspend codec at shutdown (Jaroslav Kysela) [2003613]
- ALSA: hda: conexant: Turn off EAPD at suspend, too (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Prevent pops and clicks during suspend (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Unmute/Mute codec when stream starts/stops (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Follow correct CS42L42 power down sequence for suspend (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Remove unnecessary delays (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Use timeout rather than retries for I2C transaction waits (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Set fixed sample rate of 48kHz for CS42L42 (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Enable Full Scale Volume for Line Out Codec on Dolphin (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Add support for dolphin (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Add Support to disable jack type detection for CS42L42 (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Support multiple sub_codecs for Suspend/Resume/Unsol events (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Move codec properties to its own struct (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Separate CS8409, CS42L42 and project functions (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Support i2c bulk read/write functions (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Avoid re-setting the same page as the last access (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Avoid setting the same I2C address for every access (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Dont disable I2C clock between consecutive accesses (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Generalize volume controls (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Prevent I2C access during suspend time (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Simplify CS42L42 jack detect. (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Mask CS42L42 wake events (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Disable unsolicited response for the first boot (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Disable unsolicited responses during suspend (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Disable unnecessary Ring Sense for Cyborg/Warlock/Bullseye (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Reduce HS pops/clicks for Cyborg (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Mask all CS42L42 interrupts on initialization (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Use enums for register names and coefficients (Jaroslav Kysela) [2003613]
- ALSA: hda/cs8409: Move arrays of configuration to a new file (Jaroslav Kysela) [2003613]
- ALSA: hda/cirrus: Move CS8409 HDA bridge to separate module (Jaroslav Kysela) [2003613]
- ALSA: hda - fix the 'Capture Switch' value change notifications (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 650 G8 Notebook PC (Jaroslav Kysela) [2003613]
- ALSA: pci: cs46xx: Fix set up buffer type properly (Jaroslav Kysela) [2003613]
- ALSA: hda: Add quirk for ASUS Flow x13 (Jaroslav Kysela) [2003613]
- ALSA: pci/korg1212: completely remove 'set but not used' warnings (Jaroslav Kysela) [2003613]
- ALSA: pcxhr: use __func__ to get funcion's name in an output message (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: add mic quirk for Acer SF314-42 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix headset mic for Acer SWIFT SF314-56 (ALC256) (Jaroslav Kysela) [2003613]
- ALSA: korg1212: Fix wrongly shuffled firmware loader code (Jaroslav Kysela) [2003613]
- ALSA: als300: Fix missing chip initialization (Jaroslav Kysela) [2003613]
- ALSA: cs4281: Fix missing chip initialization (Jaroslav Kysela) [2003613]
- ALSA: hda/hdmi: Add quirk to force pin connectivity on NUC10 (Jaroslav Kysela) [2003613]
- ALSA: nm256: Fix error return code in snd_nm256_create() (Jaroslav Kysela) [2003613]
- ALSA: ymfpci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: vx222: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: trident: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: pci: rme: Fix unaligned buffer addresses (Jaroslav Kysela) [2003613]
- ALSA: pci: rme: Set up buffer type properly (Jaroslav Kysela) [2003613]
- ALSA: rme9652: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: rme9652: don't disable if not enabled (Jaroslav Kysela) [2003613]
- ALSA: hdspm: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: hdspm: don't disable if not enabled (Jaroslav Kysela) [2003613]
- ALSA: hdspm: Fix fall-through warnings for Clang (Jaroslav Kysela) [2003613]
- ALSA: hdsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: riptide: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: riptide: Replace tasklet with threaded irq (Jaroslav Kysela) [2003613]
- ALSA: riptide: convert tasklets to use new tasklet_setup() API (Jaroslav Kysela) [2003613]
- ALSA: oxygen: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: nm256: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: lx6464es: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: lola: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: korg1212: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ice1712: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: emu10k1x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: emu10k1: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: echoaudio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cs5535audio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cs46xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ca0106: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: aw2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: au88x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: via82xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: sonicvibes: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: sis7019: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: rme96: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: rme32: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: maestro3: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: fm801: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: es1968: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: es1938: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ens137x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cs5530: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cs4281: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: cmipci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: bt87x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: azt3328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: als4000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: als300: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: ad1889: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: hda: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: atiixp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: intel8x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix pop noise and 2 Front Mic issues on a machine (Jaroslav Kysela) [2003613]
- ALSA: hdmi: Expose all pins on MSI MS-7C94 board (Jaroslav Kysela) [2003613]
- ALSA: intel8x0: Skip ac97 clock measurement on VM (Jaroslav Kysela) [2003613]
- ALSA: hda/hdmi: Add option to enable all pins forcibly (Jaroslav Kysela) [2003613]
- ALSA: ice1724: Remove superfluous loop over model table (Jaroslav Kysela) [2003613]
- ALSA: hda/ca0132: remove redundant initialization of variable status (Jaroslav Kysela) [2003613]
- ALSA: intel8x0: Fix breakage at ac97 clock measurement (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute led of the HP Pavilion 15-eh1xxx series (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 630 G8 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 445 G8 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 450 G8 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek - Add ALC285 HP init procedure (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek - Add type for ALC287 (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook 830 G8 Notebook PC (Jaroslav Kysela) [2003613]
- ALSA: hda: Release codec display power during shutdown/reboot (Jaroslav Kysela) [2003613]
- ALSA: hda: Release controller display power during shutdown/reboot (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Apply LED fixup for HP Dragonfly G1, too (Jaroslav Kysela) [2003613]
- ALSA: hdsp: fix a test for copy_to_user() failure (Jaroslav Kysela) [2003613]
- ALSA: hda: Add IRQ check for platform_get_irq() (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Fix bass speaker DAC mapping for Asus UM431D (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Improve fixup for HP Spectre x360 15-df0xxx (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Add another ALC236 variant support (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook x360 830 G8 (Jaroslav Kysela) [2003613]
- ALSA: hda/tegra: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [2003613]
- ALSA: trident: Fix build error (Jaroslav Kysela) [2003613]
- ALSA: trident: Drop shadow TLB pointer table (Jaroslav Kysela) [2003613]
- ALSA: ymfpci: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: vx222: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: trident: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: rme9652: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: hdsp: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: riptide: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: pcxhr: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: nm256: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: mixart: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: korg1212: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: ice1712: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: emu10k1x: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: emu10k1: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: echoaudio: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: cs5535audio: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: cs46xx: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: ca0106: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: au88x0: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: ac97: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: via82xx: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: sonicvibes: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: rme96: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: rme32: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: maestro3: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: intel8x0: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: fm801: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: es1968: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: es1938: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: ens137x: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: cs4281: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: cmipci: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: bt87x: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: azt3328: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: atiixp: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: als4000: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: als300: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: ak4531: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: ad1889: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: hda/realtek: Change device names for quirks to barebone names (Jaroslav Kysela) [2003613]
- ALSA: hda/ca0132: Make a const array static, makes object smaller (Jaroslav Kysela) [2003613]
- ALSA: pci: lx6464es: remove useless self-comparison (Jaroslav Kysela) [2003613]
- ALSA: drivers: opl3: Fix incorrect use of vp->state (Jaroslav Kysela) [2003613]
- ALSA: pcsp: Make hrtimer forwarding more robust (Jaroslav Kysela) [2003613]
- ALSA: pcsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: dummy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: aloop: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: mpu401: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: serial-u16550: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: mtpav: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: virmidi: Allocate resources with device-managed APIs (Jaroslav Kysela) [2003613]
- ALSA: vx: Manage vx_core object with devres (Jaroslav Kysela) [2003613]
- ALSA: aloop: Fix spelling mistake "synchronization" -> "synchronization" (Jaroslav Kysela) [2003613]
- ALSA: serial: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: opl3: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: vx: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: mpu401: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: drivers: opl3: fix useless self-comparison (Jaroslav Kysela) [2003613]
- ALSA: hda: intel-sdw-acpi: go through HDAS ACPI at max depth of 2 (Jaroslav Kysela) [2003613]
- ALSA: hda: intel-sdw-acpi: harden detection of controller (Jaroslav Kysela) [2003613]
- ALSA: intel-dsp-config: add quirk for CML devices based on ES8336 codec (Jaroslav Kysela) [2003613]
- ALSA: intel-dsp-config: add quirk for JSL devices based on ES8336 codec (Jaroslav Kysela) [2003613]
- ALSA: hda: avoid write to STATESTS if controller is in reset (Jaroslav Kysela) [2003613]
- ALSA: intel-dsp-config: add quirk for APL/GLK/TGL devices based on ES8336 codec (Jaroslav Kysela) [2003613]
- ALSA: hda: hdac_ext_stream: fix potential locking issues (Jaroslav Kysela) [2003613]
- ALSA: hda: hdac_stream: fix potential locking issue in snd_hdac_stream_assign() (Jaroslav Kysela) [2003613]
- ALSA: hda: intel-dsp-cfg: add missing ElkhartLake PCI ID (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: usx2y - use GFP_NOIO flag (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Reorder snd_djm_devices[] entries (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Don't start stream for capture at prepare (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Switch back to non-latency mode at a later point (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add quirk for Audient iD14 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Line6 HX-Stomp XL USB_ID for 48k-fixed quirk (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 400 (Jaroslav Kysela) [2003613]
- ALSA: ua101: fix division by zero at probe (Jaroslav Kysela) [2003613]
- ALSA: line6: fix control and interrupt message timeouts (Jaroslav Kysela) [2003613]
- ALSA: 6fire: fix control and bulk message timeouts (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: fix null pointer dereference on pointer cs_desc (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix microphone sound on Jieli webcam. (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Provide quirk for Sennheiser GSP670 Headset (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Initialize every feature unit once at probe time (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Drop superfluous error message after disconnection (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Downgrade error message in get_ctl_value_v2() (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: add Schiit Hel device to quirk table (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add quirk for VF0770 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Less restriction for low-latency playback mode (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add support for the Pioneer DJM 750MK2 Mixer/Soundcard (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Pass JOINT_DUPLEX info flag for implicit fb streams (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Enable rate validation for Scarlett devices (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix packet size calculation regression (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: disable implicit feedback sync for Behringer UFX1204 and UFX1604 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Avoid killing in-flight URBs during draining (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Improved lowlatency playback support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add spinlock to stop_urbs() (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Check available frames for the next packet size (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Disable low-latency mode for implicit feedback sync (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Disable low-latency playback for free-wheel mode (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Rename early_playback_start flag with lowlatency_playback (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix possible race at sync of urb completions (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Restrict rates for the shared clocks (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix a missing error check in scarlett gen2 mixer (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: fix comment reference in __uac_clock_find_source (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Prefer struct_size over open coded arithmetic (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Unify mixer resume and reset_resume procedure (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 800 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add lowlatency module option (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Work around for XRUN with low latency playback (Jaroslav Kysela) [2003613]
- ASoC: dmaengine: Introduce module option prealloc_buffer_size_kbytes (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move set-interface-first workaround into common quirk (Jaroslav Kysela) [2003613]
- ALSA: doc: Fix indentation warning (Jaroslav Kysela) [2003613]
- ALSA: hda: Update documentation for aliasing via the model option (Jaroslav Kysela) [2003613]
- ALSA: doc: Add the description of quirk_flags option for snd-usb-audio (Jaroslav Kysela) [2003613]
- ALSA: doc: Fix reference to mixart.rst (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Update the documentation for the new delayed_register option (Jaroslav Kysela) [2003613]
- ALSA: hda - Update descriptions about new position_fix values (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix regression on Sony WALKMAN NW-A45 DAC (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Input source control - digidesign mbox (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: make array static const, makes object smaller (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add quirk_flags module option (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move generic DSD raw detection into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move ignore_ctl_error check into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move autosuspend quirk into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move rate validation quirk into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move interface setup delay into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move control message delay quirk into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move ITF-USB DSD quirk handling into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move clock setup quirk into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move playback_first flag into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move tx_length quirk handling to quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move txfr_quirk handling to quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Move media-controller API quirk into quirk_flags (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Introduce quirk_flags field (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Avoid unnecessary or invalid connector selection at resume (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 600 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix superfluous autosuspend recovery (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: fix incorrect clock source setting (Jaroslav Kysela) [2003613]
- ALSA: scarlett2: Fix line out/speaker switching notifications (Jaroslav Kysela) [2003613]
- ALSA: scarlett2: Correct channel mute status after mute button pressed (Jaroslav Kysela) [2003613]
- ALSA: scarlett2: Fix Direct Monitor control name for 2i2 (Jaroslav Kysela) [2003613]
- ALSA: scarlett2: Fix Mute/Dim/MSD Mode control names (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add registration quirk for JBL Quantum headsets (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add missing proc text entry for BESPOKEN type (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Reduce latency at playback start, take#2 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: fix spelling mistakes (Jaroslav Kysela) [2003613]
- ALSA: usx2y: fix spelling mistakes (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix for loop increment in scarlett2_usb_get_config (Jaroslav Kysela) [2003613]
- ALSA: scarlett2: Fix scarlett2_*_ctl_put() return values again (Jaroslav Kysela) [2003613]
- ALSA: scarlett2: Fix pad count for 18i8 Gen 3 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add support for the talkback feature (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Update get_config to do endian conversion (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add speaker switching support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Update mux controls to allow updates (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add sw_hw_ctls and mux_ctls (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Split up sw_hw_enum_ctl_put() (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Label 18i8 Gen 3 line outputs correctly (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add direct monitor support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add phantom power switch support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add "air" switch support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add support for Solo and 2i2 Gen 3 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Allow bit-level access to config (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Move get config above set config (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add Gen 3 MSD mode switch (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add support for "input-other" notify (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add Gen 3 mixer support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix wrong resume call (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix Level Meter control (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Split struct scarlett2_ports (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Allow arbitrary ordering of mux entries (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add mute support (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add scarlett2_vol_ctl_write() helper (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Remove repeated device info comments (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Move info lookup out of init function (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Improve device info lookup (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Reformat scarlett2_config_items[] (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Merge common line in capture strings (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add "Sync Status" control (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Always enable interrupt polling (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix 6i6 Gen 2 line out descriptions (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Update initialisation sequence (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add usb_tx/rx functions (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix OOB access at proc output (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Remove hard-coded USB #defines (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Don't copy struct scarlett2_config (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix union usage in mixer control callbacks (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix scarlett2_*_ctl_put() return values (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix data_mutex lock (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Add temp variable for consistency (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Rename struct scarlett2_mixer_data (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Rename buttons/interrupts/vol (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Remove redundant info->button_count (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Remove interrupt debug message (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Remove unused/useless code (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Coding style improvements (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Fix 18i8 Gen 2 PCM Input count (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Remove incorrect S/PDIF comment (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: fix rate on Ozone Z90 USB headset (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Add support for Denon DN-X1600 (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Read mux at init time (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: scarlett2: Read mixer volumes at init time (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Factor out DSD bitrev copy function (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Refactoring delay account code (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Pre-calculate buffer byte size (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Make snd_usb_pcm_delay() static (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Remove the repeated declaration (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Fix uninitialized variable at __uac_clock_find_source() (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Handle error for the current selector gracefully (Jaroslav Kysela) [2003613]
- ALSA: usb-audio: Refactoring UAC2/3 clock setup code (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Nuke pcm_list (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Cleanup probe and disconnect callbacks (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Don't call free_pages_exact() with NULL address (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Fix shmem initialization (Jaroslav Kysela) [2003613]
- ALSA: usxy2: Fix potential doubly allocations (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Fix potential memory leaks (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Avoid self-killing (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Fix potential leaks of uninitialized memory (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Coding style fixes (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Fix spaces (Jaroslav Kysela) [2003613]
- ALSA: usx2y: Avoid camelCase (Jaroslav Kysela) [2003613]
- module: remove never implemented MODULE_SUPPORTED_DEVICE (Jaroslav Kysela) [2003613]
- ALSA: pcm: Allow exact buffer preallocation (Jaroslav Kysela) [2003613]
- ALSA: core: Add device-managed request_dma() (Jaroslav Kysela) [2003613]
- ALSA: core: use DEVICE_ATTR_*() macro (Jaroslav Kysela) [2003613]
- ALSA: core: Fix double calls of snd_card_free() via devres (Jaroslav Kysela) [2003613]
- ALSA: core: Add managed card creation (Jaroslav Kysela) [2003613]
- ALSA: pcm: Fix mmap without buffer preallocation (Jaroslav Kysela) [2003613]
- ALSA: pcm: Call substream ack() method upon compat mmap commit (Jaroslav Kysela) [2003613]
- ALSA: pcm: Fix mmap breakage without explicit buffer setup (Jaroslav Kysela) [2003613]
- ALSA: pcm - fix mmap capability check for the snd-dummy driver (Jaroslav Kysela) [2003613]
- ALSA: pcm: fix divide error in snd_pcm_lib_ioctl (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Catch call with NULL snd_dma_buffer pointer (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Remove a stale comment (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Use proper SG helpers for noncontig allocations (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Fix a typo in snd_dma_buffer_sync() description (Jaroslav Kysela) [2003613]
- ALSA: PCM: Fix NULL dereference at mmap checks (Jaroslav Kysela) [2003613]
- ALSA: pcm: Check mmap capability of runtime dma buffer at first (Jaroslav Kysela) [2003613]
- ALSA: pcm: Fix mmap capability check (Jaroslav Kysela) [2003613]
- ALSA: pcm: use krealloc_array() (Jaroslav Kysela) [2003613]
- ALSA: pcm: Add SNDRV_PCM_INFO_EXPLICIT_SYNC flag (Jaroslav Kysela) [2003613]
- ALSA: pcm: Add more disconnection checks at file ops (Jaroslav Kysela) [2003613]
- mm: don't include asm/pgtable.h if linux/mm.h is already included (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Fix mmap of SG-buffer with WC pages (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Support for non-coherent page allocation (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Support for non-contiguous page allocation (Jaroslav Kysela) [2003613]
- ALSA: pcm: Unify snd_pcm_delay() and snd_pcm_hwsync() (Jaroslav Kysela) [2003613]
- ALSA: core: Fix build error due to missing PAGE_SIZE (Jaroslav Kysela) [2003613]
- ALSA: pcm: Workaround for a wrong offset in SYNC_PTR compat ioctl (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Count continuous pages in vmalloc buffer handler (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Store snd_dma_buffer.addr for continuous pages, too (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Fix pgprot for WC mmap on x86 (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Support WC allocation on all architectures (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Correctly name as WC (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Minor refactoring (Jaroslav Kysela) [2003613]
- ALSA: memalloc: Fix regression with SNDRV_DMA_TYPE_CONTINUOUS (Jaroslav Kysela) [2003613]
- ALSA: core: Add device-managed page allocator helper (Jaroslav Kysela) [2003613]
- ALSA: core: Add continuous and vmalloc mmap ops (Jaroslav Kysela) [2003613]
- ALSA: core: Move mmap handler into memalloc ops (Jaroslav Kysela) [2003613]
- ALSA: core: Abstract memory alloc helpers (Jaroslav Kysela) [2003613]
- ALSA: pcm: add snd_pcm_period_elapsed() variant without acquiring lock of PCM substream (Jaroslav Kysela) [2003613]
- ALSA: pcm: Block the release until the system resume finishes (Jaroslav Kysela) [2003613]
- ALSA: Drop superfluous argument from snd_power_wait() (Jaroslav Kysela) [2003613]
- ALSA: pcm: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: core: Drop snd_sgbuf_get_ptr() (Jaroslav Kysela) [2003613]
- ALSA: jack: Check the return value of kstrdup() (Jaroslav Kysela) [2003613]
- ALSA: seq: oss: Fix error check at system port creation (Jaroslav Kysela) [2003613]
- ALSA: seq: Fix comments of wrong client number for MIDI Passthrough (Jaroslav Kysela) [2003613]
- ALSA: pcm: oss: Handle missing errors in snd_pcm_oss_change_params*() (Jaroslav Kysela) [2003613]
- ALSA: pcm: oss: Limit the period size to 16MB (Jaroslav Kysela) [2003613]
- ALSA: pcm: oss: Fix negative period/buffer sizes (Jaroslav Kysela) [2003613]
- ALSA: iec958: Split status creation and fill (Jaroslav Kysela) [2003613]
- ALSA: rawmidi - fix the uninitalized user_pversion (Jaroslav Kysela) [2003613]
- ALSA: rawmidi: introduce SNDRV_RAWMIDI_IOCTL_USER_PVERSION (Jaroslav Kysela) [2003613]
- ALSA: rawmidi: fix incorrect array bounds check on clock_names (Jaroslav Kysela) [2003613]
- ALSA: rawmidi: Add framing mode (Jaroslav Kysela) [2003613]
- ALSA: seq: Fix racy deletion of subscriber (Jaroslav Kysela) [2003613]
- ALSA: seq: Fix a potential UAF by wrong private_free call order (Jaroslav Kysela) [2003613]
- ALSA: seq: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: timer: Unconditionally unlink slave instances, too (Jaroslav Kysela) [2003613]
- ALSA: timer: Fix use-after-free problem (Jaroslav Kysela) [2003613]
- ALSA: mixer: fix deadlock in snd_mixer_oss_set_volume (Jaroslav Kysela) [2003613]
- ALSA: mixer: oss: Fix racy access to slots (Jaroslav Kysela) [2003613]
- ALSA: oss: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: core: Fix assignment in if condition (Jaroslav Kysela) [2003613]
- ALSA: core: control_led: use strscpy instead of strlcpy (Jaroslav Kysela) [2003613]
- ALSA: control_led - use DEVICE_ATTR_*() macro (Jaroslav Kysela) [2003613]
- ALSA: ctl: Fix copy of updated id with element read/write (Jaroslav Kysela) [2003613]
- ALSA: compress: Initialize mutex in snd_compress_new() (Jaroslav Kysela) [2003613]
- ALSA: control: Minor optimization for SNDRV_CTL_IOCTL_POWER_STATE (Jaroslav Kysela) [2003613]
- ALSA: control: Drop superfluous snd_power_wait() calls (Jaroslav Kysela) [2003613]
- ALSA: control: Track in-flight control read/write/tlv accesses (Jaroslav Kysela) [2003613]
- ALSA: compress: Drop unused functions (Jaroslav Kysela) [2003613]
- regmap: sdw-mbq: use MODULE_LICENSE("GPL") (Jaroslav Kysela) [2003613]
- regmap: sdw: use no_pm routines for SoundWire 1.2 MBQ (Jaroslav Kysela) [2003613]
- regmap: sdw: use _no_pm functions in regmap_read/write (Jaroslav Kysela) [2003613]
- soundwire: stream: Fix test for DP prepare complete (Jaroslav Kysela) [2003613]
- soundwire/ASoC: add leading zeroes in peripheral device name (Jaroslav Kysela) [2003613]
- soundwire: bandwidth allocation: improve error messages (Jaroslav Kysela) [2003613]
- soundwire: dmi-quirks: remove duplicate initialization (Jaroslav Kysela) [2003613]
- soundwire: cadence: remove the repeated declaration (Jaroslav Kysela) [2003613]
- soundwire: bus: stop dereferencing invalid slave pointer (Jaroslav Kysela) [2003613]
- soundwire: bus: add missing \n in dynamic debug (Jaroslav Kysela) [2003613]
- soundwire: bus: handle -ENODATA errors in clock stop/start sequences (Jaroslav Kysela) [2003613]
- soundwire: qcom: add debugfs entry for soundwire register dump (Jaroslav Kysela) [2003613]
- soundwire: debugfs: use controller id and link_id for debugfs (Jaroslav Kysela) [2003613]
- soundwire: cadence: do not extend reset delay (Jaroslav Kysela) [2003613]
- soundwire: intel: conditionally exit clock stop mode on system suspend (Jaroslav Kysela) [2003613]
- soundwire: intel: skip suspend/resume/wake when link was not started (Jaroslav Kysela) [2003613]
- soundwire: intel: fix potential race condition during power down (Jaroslav Kysela) [2003613]
- soundwire: intel: introduce shim and alh base (Jaroslav Kysela) [2003613]
- soundwire: move intel sdw register definitions to sdw_intel.h (Jaroslav Kysela) [2003613]
- soundwire: cadence: override PDI configurations to create loopback (Jaroslav Kysela) [2003613]
- soundwire: cadence: add debugfs interface for PDI loopbacks (Jaroslav Kysela) [2003613]
- soundwire: stream: don't program mockup device ports (Jaroslav Kysela) [2003613]
- soundwire: bus: squelch error returned by mockup devices (Jaroslav Kysela) [2003613]
- soundwire: stream: don't abort bank switch on Command_Ignored/-ENODATA (Jaroslav Kysela) [2003613]
- soundwire: cadence: add paranoid check on self-clearing bits (Jaroslav Kysela) [2003613]
- soundwire: dmi-quirks: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2003613]
- soundwire: bus: update Slave status in sdw_clear_slave_status (Jaroslav Kysela) [2003613]
- soundwire: cadence: Remove ret variable from sdw_cdns_irq() (Jaroslav Kysela) [2003613]
- soundwire: bus: filter out more -EDATA errors on clock stop (Jaroslav Kysela) [2003613]
- soundwire: dmi-quirks: add ull suffix for SoundWire _ADR values (Jaroslav Kysela) [2003613]
- soundwire: export sdw_update() and sdw_update_no_pm() (Jaroslav Kysela) [2003613]
- soundwire: bus: Make sdw_nwrite() data pointer argument const (Jaroslav Kysela) [2003613]
- soundwire: intel: move to auxiliary bus (Jaroslav Kysela) [2003613]
- soundwire: add missing kernel-doc description (Jaroslav Kysela) [2003613]
- soundwire: cadence_master: always set CMD_ACCEPT (Jaroslav Kysela) [2003613]
- soundwire: bus: only use CLOCK_STOP_MODE0 and fix confusions (Jaroslav Kysela) [2003613]
- software node: Handle software node injection to an existing device properly (Mark Langsdorf) [2032600]
- software node: Allow node addition to already existing device (Mark Langsdorf) [2032600]
- driver core: clear deferred probe reason on probe retry (Mark Langsdorf) [2032600]
- driver core: add deferring probe reason to devices_deferred property (Mark Langsdorf) [2032600]
- driver core: Fix locking bug in deferred_probe_timeout_work_func() (Mark Langsdorf) [2032600]
- PM: runtime: Fix race getting/putting suppliers at probe (Mark Langsdorf) [2032600]
- PM: runtime: Fix ordering in pm_runtime_get_suppliers() (Mark Langsdorf) [2032600]
- PM: runtime: Defer suspending suppliers (Mark Langsdorf) [2032600]
- software node: Fix device_add_software_node() (Mark Langsdorf) [2032600]
- software node: Fix node registration (Mark Langsdorf) [2032600]
- drivers/base/memory: don't store phys_device in memory blocks (Mark Langsdorf) [2032600]
- arch_numa: fix common code printing of phys_addr_t (Mark Langsdorf) [2032600]
- driver core: platform: Drop of_device_node_put() wrapper (Mark Langsdorf) [2032600]
- regmap: sdw-mbq: use MODULE_LICENSE("GPL") (Mark Langsdorf) [2032600]
- regmap: sdw: use no_pm routines for SoundWire 1.2 MBQ (Mark Langsdorf) [2032600]
- regmap: sdw: use _no_pm functions in regmap_read/write (Mark Langsdorf) [2032600]
- PM: domains: Mark fwnodes when their powerdomain is added/removed (Mark Langsdorf) [2032600]
- driver core: fw_devlink: Handle suppliers that don't use driver core (Mark Langsdorf) [2032600]
- driver core: Add fw_devlink.strict kernel param (Mark Langsdorf) [2032600]
- driver core: platform: Emit a warning if a remove callback returned non-zero (Mark Langsdorf) [2032600]
- PM: domains: Simplify the calculation of variables (Mark Langsdorf) [2032600]
- PM: sleep: Use dev_printk() when possible (Mark Langsdorf) [2032600]
- media: software_node: Add support for fwnode_graph*() family of functions (Mark Langsdorf) [2032600]
- media: software_node: unregister software_nodes in reverse order (Mark Langsdorf) [2032600]
- media: software_node: Enforce parent before child ordering of nodes arrays (Mark Langsdorf) [2032600]
- media: device property: Call fwnode_graph_get_endpoint_by_id() for fwnode->secondary (Mark Langsdorf) [2032600]
- media: device property: Return true in fwnode_device_is_available for NULL ops (Mark Langsdorf) [2032600]
- media: software_node: Fix refcounts in software_node_get_next_child() (Mark Langsdorf) [2032600]
- PM: domains: Add "performance" column to debug summary (Mark Langsdorf) [2032600]
- PM: domains: Make of_genpd_add_subdomain() return -EPROBE_DEFER (Mark Langsdorf) [2032600]
- PM: domains: Make set_performance_state() callback optional (Mark Langsdorf) [2032600]
- PM: domains: use device's next wakeup to determine domain idle state (Mark Langsdorf) [2032600]
- PM: domains: inform PM domain of a device's next wakeup (Mark Langsdorf) [2032600]
- PM: runtime: Fix resposible -> responsible in runtime.c (Mark Langsdorf) [2032600]
- PM: domains: Restore comment indentation for generic_pm_domain.child_links (Mark Langsdorf) [2032600]
- PM: domains: Fix up terminology with parent/child (Mark Langsdorf) [2032600]
- regmap: Assign boolean values to a bool variable (Mark Langsdorf) [2032600]
- software node: Introduce device_add_software_node() (Mark Langsdorf) [2032600]
- numa: Move numa implementation to common code (Mark Langsdorf) [2032600]
- arm64, numa: Change the numa init functions name to be generic (Mark Langsdorf) [2032600]
- driver core: fw_devlink_relax_cycle() can be static (Mark Langsdorf) [2032600]
- driver core: Handle cycles in device links created by fw_devlink (Mark Langsdorf) [2032600]
- driver core: Have fw_devlink use DL_FLAG_INFERRED (Mark Langsdorf) [2032600]
- driver core: Add device link support for INFERRED flag (Mark Langsdorf) [2032600]
- drivers: base: Kconfig: fix spelling mistake "heterogenous" -> "heterogeneous" (Mark Langsdorf) [2032600]
- driver core: Add debug logs for device link related probe deferrals (Mark Langsdorf) [2032600]
- drivers: base: remove unused function find_bus() (Mark Langsdorf) [2032600]
- PM: runtime: Drop runtime PM references to supplier on link removal (Mark Langsdorf) [2032600]
- dmaengine: idxd: Add wq occupancy information to sysfs attribute (Julia Denham) [1971887]
- vdpa/mlx5: Forward only packets with allowed MAC address (Cindy Lu) [2031595]
- vdpa/mlx5: Support configuration of MAC (Cindy Lu) [2031595]
- vdpa/mlx5: Fix clearing of VIRTIO_NET_F_MAC feature bit (Cindy Lu) [2031595]
- vdpa_sim_net: Enable user to set mac address and mtu (Cindy Lu) [2031595]
- vdpa: Enable user to set mac and mtu of vdpa device (Cindy Lu) [2031595]
- vdpa: Use kernel coding style for structure comments (Cindy Lu) [2031595]
- vdpa: Introduce query of device config layout (Cindy Lu) [2031595]
- vdpa: Introduce and use vdpa device get, set config helpers (Cindy Lu) [2031595]
- vdpa/mlx5: Propagate link status from device to vdpa driver (Cindy Lu) [2031595]
- vdpa/mlx5: Rename control VQ workqueue to vdpa wq (Cindy Lu) [2031595]
- vdpa/mlx5: Remove mtu field from vdpa net device (Cindy Lu) [2031595]
- eni_vdpa: add vDPA driver for Alibaba ENI (Cindy Lu) [2031595]
- vdpa: add new attribute VDPA_ATTR_DEV_MIN_VQ_SIZE (Cindy Lu) [2031595]
- virtio_vdpa: setup correct vq size with callbacks get_vq_num_{max,min} (Cindy Lu) [2031595]
- vdpa: min vq num of vdpa device cannot be greater than max vq num (Cindy Lu) [2031595]
- vdpa: add new callback get_vq_num_min in vdpa_config_ops (Cindy Lu) [2031595]
- vp_vdpa: add vq irq offloading support (Cindy Lu) [2031595]
- vdpa: fix typo (Cindy Lu) [2031595]
- vhost-vdpa: Fix the wrong input in config_cb (Cindy Lu) [2031595]
- vhost_vdpa: unset vq irq before freeing irq (Cindy Lu) [2031595]
- vdpa: potential uninitialized return in vhost_vdpa_va_map() (Cindy Lu) [2031595]
- vdpa/mlx5: Avoid executing set_vq_ready() if device is reset (Cindy Lu) [2031595]
- vdpa/mlx5: Clear ready indication for control VQ (Cindy Lu) [2031595]
- vdpa: Support transferring virtual addressing during DMA mapping (Cindy Lu) [2031595]
- vdpa: factor out vhost_vdpa_pa_map() and vhost_vdpa_pa_unmap() (Cindy Lu) [2031595]
- vdpa: Add an opaque pointer for vdpa_config_ops.dma_map() (Cindy Lu) [2031595]
- vhost-iotlb: Add an opaque pointer for vhost IOTLB (Cindy Lu) [2031595]
- vhost-vdpa: Handle the failure of vdpa_reset() (Cindy Lu) [2031595]
- vdpa: Add reset callback in vdpa_config_ops (Cindy Lu) [2031595]
- vdpa: Fix some coding style issues (Cindy Lu) [2031595]
- vdpa: Make use of PFN_PHYS/PFN_UP/PFN_DOWN helper macro (Cindy Lu) [2031595]
- vdpa_sim: Use iova_shift() for the size passed to alloc_iova() (Cindy Lu) [2031595]
- vdpa/mlx5: Add multiqueue support (Cindy Lu) [2031595]
- vdpa/mlx5: Add support for control VQ and MAC setting (Cindy Lu) [2031595]
- vdpa/mlx5: Ensure valid indices are provided (Cindy Lu) [2031595]
- vdpa/mlx5: Decouple virtqueue callback from struct mlx5_vdpa_virtqueue (Cindy Lu) [2031595]
- vdpa/mlx5: function prototype modifications in preparation to control VQ (Cindy Lu) [2031595]
- vdpa/mlx5: Remove redundant header file inclusion (Cindy Lu) [2031595]
- vDPA/ifcvf: enable multiqueue and control vq (Cindy Lu) [2031595]
- vDPA/ifcvf: detect and use the onboard number of queues directly (Cindy Lu) [2031595]
- vDPA/ifcvf: implement management netlink framework for ifcvf (Cindy Lu) [2031595]
- vDPA/ifcvf: introduce get_dev_type() which returns virtio dev id (Cindy Lu) [2031595]
- vdpa/mlx5: Fix queue type selection logic (Cindy Lu) [2031595]
- vdpa/mlx5: Avoid destroying MR on empty iotlb (Cindy Lu) [2031595]
- virtio_vdpa: reject invalid vq indices (Cindy Lu) [2031595]
- vdpa: Add documentation for vdpa_alloc_device() macro (Cindy Lu) [2031595]
- vDPA/ifcvf: Fix return value check for vdpa_alloc_device() (Cindy Lu) [2031595]
- vp_vdpa: Fix return value check for vdpa_alloc_device() (Cindy Lu) [2031595]
- vdpa_sim: Fix return value check for vdpa_alloc_device() (Cindy Lu) [2031595]
- vhost: Fix the calculation in vhost_overflow() (Cindy Lu) [2031595]
- vhost-vdpa: Fix integer overflow in vhost_vdpa_process_iotlb_update() (Cindy Lu) [2031595]
- iommu/vt-d: Fix unmap_pages support (Jerry Snitselaar) [2027765]
- dm sysfs: use default_groups in kobj_type (Benjamin Marzinski) [2047358]
- dm space map common: add bounds check to sm_ll_lookup_bitmap() (Benjamin Marzinski) [2047358]
- dm btree: add a defensive bounds check to insert_at() (Benjamin Marzinski) [2047358]
- dm btree remove: change a bunch of BUG_ON() calls to proper errors (Benjamin Marzinski) [2047358]
- dm btree spine: eliminate duplicate le32_to_cpu() in node_check() (Benjamin Marzinski) [2047358]
- dm btree spine: remove extra node_check function declaration (Benjamin Marzinski) [2047358]
- selftests/bpf: Adding delay in socketmap_listen to reduce flakyness (Felix Maurer) [2026433]
- net: openvswitch: Fix ct_state nat flags for conns arriving from tc (Marcelo Ricardo Leitner) [2040334]
- net: openvswitch: Fix matching zone id for invalid conns arriving from tc (Marcelo Ricardo Leitner) [2040452]
- net/sched: flow_dissector: Fix matching on zone id for invalid conns (Marcelo Ricardo Leitner) [2040452]
- net/sched: Extend qdisc control block with tc control block (Marcelo Ricardo Leitner) [2040452]
- mm: Fix an use-after-free error in mm_struct (Waiman Long) [2046161]
- rh_flags: Rename rh_features to rh_flags (Prarit Bhargava) [2021700]
- redhat: add initial rpminspect configuration (Augusto Caringi)

* Fri Feb 04 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-365.el8]
- can: raw: raw_setsockopt(): fix raw_rcv panic for sock UAF (Balazs Nemeth) [2026692]
- drm/vmwgfx: Fix stale file descriptors on failed usercopy (Dave Airlie) [2047602] {CVE-2022-22942}
- drm/i915: Flush TLBs before releasing backing store (Dave Airlie) [2044329] {CVE-2022-0330}
- [s390] s390/pci: move pseudo-MMIO to prevent MIO overlap (Mete Durlu) [2047757]
- [s390] scsi: zfcp: Fix failed recovery on gone remote port with non-NPIV FCP devices (Mete Durlu) [2048919]
- tun: fix bonding active backup with arp monitoring (Jonathan Toppins) [2024964]
- x86/hyperv: Properly deal with empty cpumasks in hyperv_flush_tlb_multi() (Vitaly Kuznetsov) [2044237]
- xfs: check sb_meta_uuid for dabuf buffer recovery (Bill O'Donnell) [2020764]
- vfs: fs_context: fix up param length parsing in legacy_parse_param (Carlos Maiolino) [2040586] {CVE-2022-0185}
- KVM: nVMX: Allow VMREAD when Enlightened VMCS is in use (Vitaly Kuznetsov) [2012105]
- KVM: nVMX: Implement evmcs_field_offset() suitable for handle_vmread() (Vitaly Kuznetsov) [2012105]
- KVM: nVMX: Rename vmcs_to_field_offset{,_table} (Vitaly Kuznetsov) [2012105]
- KVM: nVMX: eVMCS: Filter out VM_EXIT_SAVE_VMX_PREEMPTION_TIMER (Vitaly Kuznetsov) [2012105]
- KVM: nVMX: Also filter MSR_IA32_VMX_TRUE_PINBASED_CTLS when eVMCS (Vitaly Kuznetsov) [2012105]
- KVM: nVMX: Use INVALID_GPA for pointers used in nVMX. (Vitaly Kuznetsov) [2012105]
- x86/kvm: Always inline evmcs_write64() (Vitaly Kuznetsov) [2012105]
- powerpc/powernv: Remove POWER9 PVR version check for entry and uaccess flushes (Diego Domingos) [2030954]
- powerpc/pesries: Get STF barrier requirement from H_GET_CPU_CHARACTERISTICS (Diego Domingos) [2030954]
- powerpc/security: Add a security feature for STF barrier (Diego Domingos) [2030954]
- powerpc/pseries: Get entry and uaccess flush required bits from H_GET_CPU_CHARACTERISTICS (Diego Domingos) [2030954]
- drm/nouveau/disp/dp: add support for eDP link rates (Ben Skeggs) [2043523]
- drm/nouveau/disp/dp: add support for hbr3 (Ben Skeggs) [2043523]
- drm/nouveau/disp/dp: add support for lttprs (Ben Skeggs) [2043523]
- drm/nouveau/disp/dp: fixup cr/eq delays for 1.4 (Ben Skeggs) [2043523]
- drm/nouveau/disp/dp: add support for tps4 (Ben Skeggs) [2043523]
- drm/nouveau/disp/dp: generate supported link rates table at detect time (Ben Skeggs) [2043523]
- drm/nouveau/disp/dp: explicitly control scrambling when setting pattern (Ben Skeggs) [2043523]
- drm/nouveau/disp: remove some remnant of a rework (Ben Skeggs) [2043523]
- drm/nouveau: recognise GA106 (Ben Skeggs) [2043523]
- redhat/scripts: Update merge-subtrees.sh (Prarit Bhargava)

* Tue Feb 01 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-364.el8]
- pinctrl: amd: Fix wakeups when IRQ is shared with SCI (Renjith Pananchikkal) [2039124]
- bonding: fix ad_actor_system option setting to default (Jonathan Toppins) [2042564 1931881]
- bonding: make tx_rebalance_counter an atomic (Jonathan Toppins) [2042564]
- bonding: Fix a use-after-free problem when bond_sysfs_slave_add() failed (Jonathan Toppins) [2042564]
- bonding: 3ad: pass parameter bond_params by reference (Jonathan Toppins) [2042564]
- bonding: complain about missing route only once for A/B ARP probes (Jonathan Toppins) [2042564]
- bonding: improve nl error msg when device can't be enslaved because of IFF_MASTER (Jonathan Toppins) [2042564]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2042564]
- bonding: add new option lacp_active (Jonathan Toppins) [2042564]
- bonding: 3ad: fix the concurrency between __bond_release_one() and bond_3ad_state_machine_handler() (Jonathan Toppins) [2042564]
- bonding: fix build issue (Jonathan Toppins) [2042564]
- bonding: fix incorrect return value of bond_ipsec_offload_ok() (Jonathan Toppins) [2042564]
- bonding: fix suspicious RCU usage in bond_ipsec_offload_ok() (Jonathan Toppins) [2042564]
- bonding: Add struct bond_ipesc to manage SA (Jonathan Toppins) [2042564]
- bonding: disallow setting nested bonding + ipsec offload (Jonathan Toppins) [2042564]
- bonding: fix suspicious RCU usage in bond_ipsec_del_sa() (Jonathan Toppins) [2042564]
- bonding: fix null dereference in bond_ipsec_add_sa() (Jonathan Toppins) [2042564]
- bonding: fix suspicious RCU usage in bond_ipsec_add_sa() (Jonathan Toppins) [2042564]
- net: bonding: Use per-cpu rr_tx_counter (Jonathan Toppins) [2042564]
- bonding: remove redundant initialization of variable ret (Jonathan Toppins) [2042564]
- net: bonding: Use strscpy_pad() instead of manually-truncated strncpy() (Jonathan Toppins) [2042564]
- bonding: init notify_work earlier to avoid uninitialized use (Jonathan Toppins) [2042564]
- bonding: 3ad: Fix the conflict between bond_update_slave_arr and the state machine (Jonathan Toppins) [2042564]
- scsi: lpfc: Update lpfc version to 14.0.0.4 (Dick Kennedy) [2034276]
- scsi: lpfc: Add additional debugfs support for CMF (Dick Kennedy) [2034276]
- scsi: lpfc: Cap CMF read bytes to MBPI (Dick Kennedy) [2034276]
- scsi: lpfc: Adjust CMF total bytes and rxmonitor (Dick Kennedy) [2034276]
- scsi: lpfc: Trigger SLI4 firmware dump before doing driver cleanup (Dick Kennedy) [2034276]
- scsi: lpfc: Fix NPIV port deletion crash (Dick Kennedy) [2034276]
- scsi: lpfc: Fix lpfc_force_rscn ndlp kref imbalance (Dick Kennedy) [2034276]
- scsi: lpfc: Change return code on I/Os received during link bounce (Dick Kennedy) [2034276]
- scsi: lpfc: Fix leaked lpfc_dmabuf mbox allocations with NPIV (Dick Kennedy) [2034276]
- ppp: ensure minimum packet size in ppp_write() (Guillaume Nault) [2042937]
- KVM: VMX: switch blocked_vcpu_on_cpu_lock to raw spinlock (Marcelo Tosatti) [2034126]
- configs: Enable CONFIG_THINKPAD_LMI on x86_64 (Mark Pearson) [2030772]
- platform/x86: think-lmi: Abort probe on analyze failure (Mark Pearson) [2030772]
- platform/x86: think-lmi: add debug_cmd (Mark Pearson) [2030772]
- platform/x86: think-lmi: Fix possible mem-leaks on tlmi_analyze() error-exit (Mark Pearson) [2030772]
- platform/x86: think-lmi: Split kobject_init() and kobject_add() calls (Mark Pearson) [2030772]
- platform/x86: think-lmi: Move pending_reboot_attr to the attributes sysfs dir (Mark Pearson) [2030772]
- platform/x86: think-lmi: Add pending_reboot support (Mark Pearson) [2030772]
- platform/x86: think-lmi: Move kfree(setting->possible_values) to tlmi_attr_setting_release() (Mark Pearson) [2030772]
- platform/x86: think-lmi: Split current_value to reflect only the value (Mark Pearson) [2030772]
- platform/x86: think-lmi: Fix issues with duplicate attributes (Mark Pearson) [2030772]
- platform/x86: think-lmi: Return EINVAL when kbdlang gets set to a 0 length string (Mark Pearson) [2030772]
- platform/x86: think-lmi: Add missing MODULE_DEVICE_TABLE (Mark Pearson) [2030772]
- platform/x86: think-lmi: Avoid potential read before start of the buffer (Mark Pearson) [2030772]
- platform/x86: think-lmi: Fix check for admin password being set (Mark Pearson) [2030772]
- platform/x86: dell-wmi-sysman/think-lmi: Make fw_attr_class global static (Mark Pearson) [2030772]
- platform/x86: thinkpad-lmi: Remove unused display_name member from struct tlmi_pwd_setting (Mark Pearson) [2030772]
- platform/x86: think-lmi: Add WMI interface support on Lenovo platforms (Mark Pearson) [2030772]
- platform/x86: dell-wmi-sysman: fw_attr_inuse can be static (Mark Pearson) [2030772]
- platform/x86: dell-wmi-sysman: Use firmware_attributes_class helper (Mark Pearson) [2030772]
- platform/x86: firmware_attributes_class: Create helper file for handling firmware-attributes class registration events (Mark Pearson) [2030772]
- x86/apic: Handle missing global clockevent gracefully (Lenny Szubowicz) [2033197]
- RDMA/core: Don't infoleak GRH fields (Kamal Heib) [2036597]
- RDMA/uverbs: Check for null return of kmalloc_array (Kamal Heib) [2036597]
- RDMA/sa_query: Use strscpy_pad instead of memcpy to copy a string (Kamal Heib) [2036597]
- RDMA/rw: switch to dma_map_sgtable() (Kamal Heib) [2036597]
- RDMA/cma: Ensure rdma_addr_cancel() happens before issuing more requests (Kamal Heib) [2036597]
- RDMA/cma: Fix listener leak in rdma_cma_listen_on_all() failure (Kamal Heib) [2036597]
- RDMA/iwcm: Release resources if iw_cm module initialization fails (Kamal Heib) [2036597]
- net: Set true network header for ECN decapsulation (Antoine Tenart) [2045059]
- powerpc/bpf: Update ldimm64 instructions during extra pass (Yauheni Kaliuta) [2035973]
- selftests: bpf: Fix bind on used port (Felix Maurer) [2025795]
- bpf/selftests: Fix namespace mount setup in tc_redirect (Jiri Olsa) [2036016]
- selftests/bpf: Fix possible/online index mismatch in perf_buffer test (Yauheni Kaliuta) [2039602]
- selftests/bpf: Fix perf_buffer test on system with offline cpus (Yauheni Kaliuta) [2039602]
- tracing: Tag trace_percpu_buffer as a percpu pointer (Jerome Marchand) [2031604]
- tracing: Fix check for trace_percpu_buffer validity in get_trace_buf() (Jerome Marchand) [2031604]
- hwmon: (k10temp) Support up to 12 CCDs on AMD Family of processors (David Arcari) [2022539]
- hwmon: (k10temp) Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (David Arcari) [2022539]
- hwmon: (k10temp) Remove unused definitions (David Arcari) [2022539]
- x86/amd_nb: Add AMD Family 19h Models (10h-1Fh) and (A0h-AFh) PCI IDs (David Arcari) [2022539]
- hwmon: (k10temp) Remove residues of current and voltage (David Arcari) [2022539]
- hwmon: (k10temp) Update driver documentation (David Arcari) [2022539]
- hwmon: (k10temp) Update documentation and add temp2_input info (David Arcari) [2022539]
- docs: hwmon: k10temp: convert to ReST format (David Arcari) [2022539]
- mptcp: fix deadlock in __mptcp_push_pending() (Davide Caratti) [2043598]
- mptcp: clear 'kern' flag from fallback sockets (Davide Caratti) [2043598]
- mptcp: remove tcp ulp setsockopt support (Davide Caratti) [2043598]
- mptcp: never allow the PM to close a listener subflow (Davide Caratti) [2043598]

* Fri Jan 28 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-363.el8]
- redhat: set LC_ALL=C before sorting config content (Frantisek Hrbata)
- net: mana: Add RX fencing (Mohammed Gamal) [2030132]
- net: mana: Add XDP support (Mohammed Gamal) [2030132]
- net: mana: Fix memory leak in mana_hwc_create_wq (Mohammed Gamal) [2030132]
- net: mana: Fix spelling mistake "calledd" -> "called" (Mohammed Gamal) [2030132]
- net: mana: Support hibernation and kexec (Mohammed Gamal) [2030132]
- net: mana: Improve the HWC error handling (Mohammed Gamal) [2030132]
- net: mana: Report OS info to the PF driver (Mohammed Gamal) [2030132]
- net: mana: Fix the netdev_err()'s vPort argument in mana_init_port() (Mohammed Gamal) [2030132]
- net: mana: Allow setting the number of queues while the NIC is down (Mohammed Gamal) [2030132]
- net: stmmac: Add GFP_DMA32 for rx buffers if no 64 capability (Mark Salter) [1989540]
- net: stmmac: Fix potential integer overflow (Mark Salter) [1989540]
- net: stmmac: fix issue where clk is being unprepared twice (Mark Salter) [1989540]
- net: stmmac: fix kernel panic due to NULL pointer dereference of mdio_bus_data (Mark Salter) [1989540]
- net: stmmac: fix system hang if change mac address after interface ifdown (Mark Salter) [1989540]
- net: stmmac: correct clocks enabled in stmmac_vlan_rx_kill_vid() (Mark Salter) [1989540]
- net: remove the mutex_acquire from __lock_sock_fast (Xin Long) [2026612]
- net: core: Correct the sock::sk_lock.owned lockdep annotations (Xin Long) [2026612]
- inet: use bigger hash table for IP ID generation (Xin Long) [2039969] {CVE-2021-45486}
- net: revert "net: get rid of an signed integer overflow in ip_idents_reserve()" (Xin Long) [2039969]
- net/mlx5: DR, Use FW API when updating FW-owned flow table (Michal Schmidt) [2042651]
- ipv6: Continue processing multipath route even if gateway attribute is invalid (Hangbin Liu) [2041375]
- ipv6: Check attribute length for RTA_GATEWAY when deleting multipath route (Hangbin Liu) [2041375]
- ipv6: Do cleanup if attribute validation fails in multipath route (Hangbin Liu) [2041375]
- ipv6: Check attribute length for RTA_GATEWAY in multipath route (Hangbin Liu) [2041375]
- rtw89: fix maybe-uninitialized error (Íñigo Huguet) [2033291]
- rtw89: enable driver and device RTL8852AE (Íñigo Huguet) [2033291]
- rtw89: fix maybe-uninitialized error (RHEL only) (Íñigo Huguet) [2033291]
- rtw89: 8852a: correct bit definition of dfs_en (Íñigo Huguet) [2033291]
- rtw89: coex: Update COEX to 5.5.8 (Íñigo Huguet) [2033291]
- rtw89: coex: Cancel PS leaving while C2H comes (Íñigo Huguet) [2033291]
- rtw89: coex: Update BT counters while receiving report (Íñigo Huguet) [2033291]
- rtw89: coex: Define LPS state for BTC using (Íñigo Huguet) [2033291]
- rtw89: coex: Add MAC API to get BT polluted counter (Íñigo Huguet) [2033291]
- rtw89: coex: Not to send H2C when WL not ready and count H2C (Íñigo Huguet) [2033291]
- rtw89: coex: correct C2H header length (Íñigo Huguet) [2033291]
- rtw89: don't kick off TX DMA if failed to write skb (Íñigo Huguet) [2033291]
- rtw89: remove cch_by_bw which is not used (Íñigo Huguet) [2033291]
- rtw89: fix sending wrong rtwsta->mac_id to firmware to fill address CAM (Íñigo Huguet) [2033291]
- rtw89: fix incorrect channel info during scan (Íñigo Huguet) [2033291]
- rtw89: update scan_mac_addr during scanning period (Íñigo Huguet) [2033291]
- rtw89: use inline function instead macro to set H2C and CAM (Íñigo Huguet) [2033291]
- rtw89: add const in the cast of le32_get_bits() (Íñigo Huguet) [2033291]
- rtw89: add AXIDMA and TX FIFO dump in mac_mem_dump (Íñigo Huguet) [2033291]
- rtw89: fix potentially access out of range of RF register array (Íñigo Huguet) [2033291]
- rtw89: remove unneeded variable (Íñigo Huguet) [2033291]
- rtw89: remove unnecessary conditional operators (Íñigo Huguet) [2033291]
- rtw89: update rtw89_regulatory map to R58-R31 (Íñigo Huguet) [2033291]
- rtw89: update tx power limit/limit_ru tables to R54 (Íñigo Huguet) [2033291]
- rtw89: update rtw89 regulation definition to R58-R31 (Íñigo Huguet) [2033291]
- rtw89: fill regd field of limit/limit_ru tables by enum (Íñigo Huguet) [2033291]
- rtw89: update partition size of firmware header on skb->data (Íñigo Huguet) [2033291]
- rtw89: Fix variable dereferenced before check 'sta' (Íñigo Huguet) [2033291]
- rtw89: fix return value in hfc_pub_cfg_chk (Íñigo Huguet) [2033291]
- rtw89: remove duplicate register definitions (Íñigo Huguet) [2033291]
- rtw89: fix error function parameter (Íñigo Huguet) [2033291]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2033291]
- rtw89: fix return value check in rtw89_cam_send_sec_key_cmd() (Íñigo Huguet) [2033291]
- rtw89: Remove redundant check of ret after call to rtw89_mac_enable_bb_rf (Íñigo Huguet) [2033291]
- rtw89: Fix two spelling mistakes in debug messages (Íñigo Huguet) [2033291]
- rtw89: add Realtek 802.11ax driver (Íñigo Huguet) [2033291]
- powerpc/doc: Fix htmldocs errors (Diego Domingos) [2004798]
- pseries/drmem: update LMBs after LPM (Diego Domingos) [2004798]
- powerpc/pseries: Add support for FORM2 associativity (Diego Domingos) [2004798]
- powerpc/pseries: Add a helper for form1 cpu distance (Diego Domingos) [2004798]
- powerpc/pseries: Consolidate different NUMA distance update code paths (Diego Domingos) [2004798]
- powerpc/pseries: Rename TYPE1_AFFINITY to FORM1_AFFINITY (Diego Domingos) [2004798]
- powerpc/pseries: rename min_common_depth to primary_domain_index (Diego Domingos) [2004798]
- powerpc/numa: Fix build when CONFIG_NUMA=n (Diego Domingos) [2004798]
- pseries/hotplug-memory: hot-add: skip redundant LMB lookup (Diego Domingos) [2004798]
- selftests: icmp_redirect: pass xfail=0 to log_test() (Hangbin Liu) [2041308]
- selftests: net: Correct ping6 expected rc from 2 to 1 (Hangbin Liu) [2041308]
- mt76: enable new device MT7921E (Íñigo Huguet) [2024056 1972045]
- vrf: Reset IPCB/IP6CB when processing outbound pkts in vrf dev xmit (Antoine Tenart) [2044254]
- SUNRPC: prevent port reuse on transports which don't request it. (Benjamin Coddington) [2016646]
- SUNRPC: Fix races when closing the socket (Benjamin Coddington) [2016646]
- SUNRPC: Prevent immediate close+reconnect (Benjamin Coddington) [2016646]
- SUNRPC: Clean up scheduling of autoclose (Benjamin Coddington) [2016646]
- SUNRPC: Fix potential memory corruption (Benjamin Coddington) [2016646]
- sunrpc: remove unnecessary test in rpc_task_set_client() (Benjamin Coddington) [2016646]
- SUNRPC: Replace use of socket sk_callback_lock with sock_lock (Benjamin Coddington) [2016646]
- arm64: numa: simplify dummy_numa_init() (Vitaly Kuznetsov) [2029774]
- ACPI: NUMA: Process hotpluggable memblocks when !CONFIG_MEMORY_HOTPLUG (Vitaly Kuznetsov) [2029774]
- s390/sclp: fix Secure-IPL facility detection (Stefan Schulze Frielinghaus) [2039182]
- powerpc/pseries/mobility: ignore ibm, platform-facilities updates (Diego Domingos) [2031827]
- of: Fix property name in of_node_get_device_type (Diego Domingos) [2031827]
- of: Add device_type access helper functions (Diego Domingos) [2031827]
- powerpc/watchdog: help remote CPUs to flush NMI printk output (Diego Domingos) [2030259]
- powerpc/watchdog: Fix wd_smp_last_reset_tb reporting (Diego Domingos) [2030259]
- powerpc/watchdog: read TB close to where it is used (Diego Domingos) [2030259]
- powerpc/watchdog: Avoid holding wd_smp_lock over printk and smp_send_nmi_ipi (Diego Domingos) [2030259]
- powerpc/watchdog: tighten non-atomic read-modify-write access (Diego Domingos) [2030259]
- powerpc/watchdog: Fix missed watchdog reset due to memory ordering race (Diego Domingos) [2030259]
- selftests/sgx: Fix corrupted cpuid macro invocation (Vladis Dronov) [1920030]
- x86/sgx: Fix minor documentation issues (Vladis Dronov) [1920030]
- selftests/sgx: Add test for multiple TCS entry (Vladis Dronov) [1920030]
- selftests/sgx: Enable multiple thread support (Vladis Dronov) [1920030]
- selftests/sgx: Add page permission and exception test (Vladis Dronov) [1920030]
- selftests/sgx: Rename test properties in preparation for more enclave tests (Vladis Dronov) [1920030]
- selftests/sgx: Provide per-op parameter structs for the test enclave (Vladis Dronov) [1920030]
- selftests/sgx: Add a new kselftest: Unclobbered_vdso_oversubscribed (Vladis Dronov) [1920030]
- selftests/sgx: Move setup_test_encl() to each TEST_F() (Vladis Dronov) [1920030]
- selftests/sgx: Encpsulate the test enclave creation (Vladis Dronov) [1920030]
- selftests/sgx: Dump segments and /proc/self/maps only on failure (Vladis Dronov) [1920030]
- selftests/sgx: Create a heap for the test enclave (Vladis Dronov) [1920030]
- selftests/sgx: Make data measurement for an enclave segment optional (Vladis Dronov) [1920030]
- selftests/sgx: Assign source for each segment (Vladis Dronov) [1920030]
- selftests/sgx: Fix a benign linker warning (Vladis Dronov) [1920030]
- x86/sgx: Fix free page accounting (Vladis Dronov) [1920030]
- x86/sgx: Add check for SGX pages to ghes_do_memory_failure() (Vladis Dronov) [1920030]
- x86/sgx: Add hook to error injection address validation (Vladis Dronov) [1920030]
- x86/sgx: Hook arch_memory_failure() into mainline code (Vladis Dronov) [1920030]
- x86/sgx: Add SGX infrastructure to recover from poison (Vladis Dronov) [1920030]
- x86/sgx: Initial poison handling for dirty and free pages (Vladis Dronov) [1920030]
- x86/sgx: Add infrastructure to identify SGX EPC pages (Vladis Dronov) [1920030]
- x86/sgx: Add new sgx_epc_page flag bit to mark free pages (Vladis Dronov) [1920030]
- selftests/sgx: Fix Q1 and Q2 calculation in sigstruct.c (Vladis Dronov) [1920030]
- selftests/sgx: remove checks for file execute permissions (Vladis Dronov) [1920030]
- selftests/sgx: Refine the test enclave to have storage (Vladis Dronov) [1920030]
- selftests/sgx: Add EXPECT_EEXIT() macro (Vladis Dronov) [1920030]
- selftests/sgx: Dump enclave memory map (Vladis Dronov) [1920030]
- selftests/sgx: Migrate to kselftest harness (Vladis Dronov) [1920030]
- selftests/sgx: Rename 'eenter' and 'sgx_call_vdso' (Vladis Dronov) [1920030]
- x86/sgx: Add missing xa_destroy() when virtual EPC is destroyed (Vladis Dronov) [1920030]
- x86/sgx: Correct kernel-doc's arg name in sgx_encl_release() (Vladis Dronov) [1920030]
- x86: Fix leftover comment typos (Vladis Dronov) [1920030]
- mm,hwpoison: return -EHWPOISON to denote that the page has already been poisoned (Vladis Dronov) [1920030]
- mm/memory-failure: use a mutex to avoid memory_failure() races (Vladis Dronov) [1920030]
- mm,hwpoison: take free pages off the buddy freelists (Vladis Dronov) [1920030]
- sched/fair: Consider SMT in ASYM_PACKING load balance (Prarit Bhargava) [1971924]
- sched/fair: Carve out logic to mark a group for asymmetric packing (Prarit Bhargava) [1971924]
- sched/fair: Provide update_sg_lb_stats() with sched domain statistics (Prarit Bhargava) [1971924]
- sched/fair: Optimize checking for group_asym_packing (Prarit Bhargava) [1971924]
- sched/topology: Introduce sched_group::flags (Prarit Bhargava) [1971924]
- x86/sched: Decrease further the priorities of SMT siblings (Prarit Bhargava) [1971924]

* Wed Jan 26 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-362.el8]
- nvme-fc: remove freeze/unfreeze around update_nr_hw_queues (Ewan D. Milne) [1996109]
- nvme-fc: avoid race between time out and tear down (Ewan D. Milne) [1996109]
- nvme-fc: update hardware queues before using them (Ewan D. Milne) [1996109]
- igbvf: Refactor trace (Corinna Vinschen) [2039886]
- igbvf: fix double free in `igbvf_probe` (Corinna Vinschen) [2039886]
- mm/memory_hotplug: remove is_mem_section_removable() (David Hildenbrand) [2008072]
- powerpc/pseries/hotplug-memory: stop checking is_mem_section_removable() (David Hildenbrand) [2008072]
- drivers/base/memory.c: indicate all memory blocks as removable (David Hildenbrand) [2008072]
- drivers/base/memory.c: fixup documentation of removable/phys_index/block_size_bytes (David Hildenbrand) [2008072]
- Revert "mpi3mr: mark as tech preview" (Tomas Henzl) [1989634]
- scsi: core: Avoid printing an error if target_alloc() returns -ENXIO (Tomas Henzl) [1977833]
- scsi: mpi3mr: Use scnprintf() instead of snprintf() (Tomas Henzl) [1998599]
- scsi: mpi3mr: Fix duplicate device entries when scanning through sysfs (Tomas Henzl) [1998599]
- scsi: mpi3mr: Clean up mpi3mr_print_ioc_info() (Tomas Henzl) [1989634]
- scsi: mpi3mr: Set up IRQs in resume path (Tomas Henzl) [1991577]
- Revert "scsi: lpfc: ls_rjt erroneus FLOGIs" (Dick Kennedy) [2032488]
- pseries/eeh: Fix the kdump kernel crash during eeh_pseries_init (Steve Best) [2028253]
- arm64: smp: Add missing prototype for some smp.c functions (Mark Salter) [1996738]
- irqchip/gic-v3-its: Remove unnecessary oom message (Mark Salter) [1996738]
- irqchip/gic-v2m: Remove unnecessary oom message (Mark Salter) [1996738]
- irqchip/gic: Split vGIC probing information from the GIC code (Mark Salter) [1996738]
- irqchip/gic-v3: Workaround inconsistent PMR setting on NMI entry (Mark Salter) [1996738]
- irqchip/gic-v3: Do not enable irqs when handling spurious interrups (Mark Salter) [1996738]
- irqchip/gic-v4.1: Disable vSGI upon (GIC CPUIF < v4.1) detection (Mark Salter) [1996738]
- irqchip/gic-v3: Fix OF_BAD_ADDR error handling (Mark Salter) [1996738]
- arm64: Move ICH_ sysreg bits from arm-gic-v3.h to sysreg.h (Mark Salter) [1996738]
- irqchip/gic-v3-its: Drop the setting of PTZ altogether (Mark Salter) [1996738]
- irqchip/gic-v3-its: Add a cache invalidation right after vPE unmapping (Mark Salter) [1996738]
- irqchip/gic-v3: Fix typos in PMR/RPR SCR_EL3.FIQ handling explanation (Mark Salter) [1996738]
- genirq/msi: Initialize msi_alloc_info before calling msi_domain_prepare_irqs() (Mark Salter) [1996738]
- irqchip/gic: Spelling s/REturn/Return/ (Mark Salter) [1996738]
- irqchip/gic-v3-its: Unconditionally save/restore the ITS state on suspend (Mark Salter) [1996738]
- irq-chip/gic-v3-its: Fix crash if ITS is in a proximity domain without processor or memory (Mark Salter) [1996738]
- irqchip/gic: Cleanup Franken-GIC handling (Mark Salter) [1996738]
- arm64: Implement panic_smp_self_stop() (Mark Salter) [1996738]
- arm64: Improve parking of stopped CPUs (Mark Salter) [1996738]
- genirq: Allow interrupts to be excluded from /proc/interrupts (Mark Salter) [1996738]
- irqchip/gic-v3: Support pseudo-NMIs when SCR_EL3.FIQ == 0 (Mark Salter) [1996738]
- irqchip/gic-v3: Spell out when pseudo-NMIs are enabled (Mark Salter) [1996738]
- irqchip/gic-v2, v3: Prevent SW resends entirely (Mark Salter) [1996738]
- irqchip/git-v3-its: Implement irq_retrigger callback for device-triggered LPIs (Mark Salter) [1996738]
- irqchip/gic-v2, v3: Implement irq_chip->irq_retrigger() (Mark Salter) [1996738]
- irqchip/gic-v4.1: Use GFP_ATOMIC flag in allocate_vpe_l1_table() (Mark Salter) [1996738]
- irqchip/gic-v4.1: Ensure accessing the correct RD when writing INVALLR (Mark Salter) [1996738]
- irqchip/gic-v3: Remove unused register definition (Mark Salter) [1996738]
- drivers/irqchip: Use new macro ACPI_DECLARE_SUBTABLE_PROBE_ENTRY (Mark Salter) [1996738]
- drivers/acpi: Add new macro ACPI_DECLARE_SUBTABLE_PROBE_ENTRY (Mark Salter) [1996738]
- KVM: arm64: vgic-v4: Plug race between non-residency and v4.1 doorbell (Mark Salter) [1996738]
- irqchip/gic: Atomically update affinity (Mark Salter) [1996738]
- irqchip/gic-v4.1: Use readx_poll_timeout_atomic() to fix sleep in atomic (Mark Salter) [1996738]
- irqchip/gic-v2, v3: Drop extra IRQ_NOAUTOEN setting for (E)PPIs (Mark Salter) [1996738]
- irqchip/gic-v3-its: Balance initial LPI affinity across CPUs (Mark Salter) [1996738]
- irqchip/gic-v3-its: Track LPI distribution on a per CPU basis (Mark Salter) [1996738]
- irqchip/gic-v3: Fix missing "__init" for gic_smp_init() (Mark Salter) [1996738]
- selftests/bpf: Enlarge select() timeout for test_maps (Jiri Benc) [1869444]
- PCI: Do not enable AtomicOps on VFs (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Fix stats counters (Selvin Xavier) [1987081 1984339 2001893]
- RDMA/bnxt_re: Prefer kcalloc over open coded arithmetic (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Remove unpaired rtnl unlock in bnxt_re_dev_init() (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Add missing spin lock initialization (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Fix uninitialized struct bit field rsvd1 (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Update ABI to pass wqe-mode to user space (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Enable global atomic ops if platform supports (Selvin Xavier) [1987081 1984339]
- RDMA/bnxt_re: Drop unnecessary NULL checks after container_of (Selvin Xavier) [1987081 1984339]
- dm btree remove: fix use after free in rebalance_children() (Benjamin Marzinski) [2034424]
- dm table: log table creation error code (Benjamin Marzinski) [2034424]
- dm: make workqueue names device-specific (Benjamin Marzinski) [2034424]
- dm writecache: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2034424]
- dm crypt: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2034424]
- dm: fix mempool NULL pointer race when completing IO (Benjamin Marzinski) [2034424]
- dm rq: don't queue request to blk-mq during DM suspend (Benjamin Marzinski) [1891486]
- dm verity: skip redundant verity_handle_err() on I/O errors (Benjamin Marzinski) [2034424]
- dm writecache: add event counters (Benjamin Marzinski) [2034424]
- dm writecache: report invalid return from writecache_map helpers (Benjamin Marzinski) [2034424]
- dm writecache: further writecache_map() cleanup (Benjamin Marzinski) [2034424]
- dm writecache: factor out writecache_map_remap_origin() (Benjamin Marzinski) [2034424]
- dm writecache: split up writecache_map() to improve code readability (Benjamin Marzinski) [2034424]
- dm btree remove: assign new_root only when removal succeeds (Benjamin Marzinski) [2034424]
- dm ps io affinity: remove redundant continue statement (Benjamin Marzinski) [2034424]
- dm: rearrange core declarations for extended use from dm-zone.c (Benjamin Marzinski) [2034424]
- dm space map disk: cache a small number of index entries (Benjamin Marzinski) [2034424]
- dm space maps: improve performance with inc/dec on ranges of blocks (Benjamin Marzinski) [2034424]
- dm space maps: don't reset space map allocation cursor when committing (Benjamin Marzinski) [2034424]
- dm btree: improve btree residency (Benjamin Marzinski) [2034424]
- dm integrity: fix sparse warnings (Benjamin Marzinski) [2034424]
- dm: replace dm_vcalloc() (Benjamin Marzinski) [2034424]
- dm integrity: add the "reset_recalculate" feature flag (Benjamin Marzinski) [2034424]
- dm cache: remove needless request_queue NULL pointer checks (Benjamin Marzinski) [2034424]
- dm thin: remove needless request_queue NULL pointer check (Benjamin Marzinski) [2034424]
- dm ioctl: replace device hash with red-black tree (Benjamin Marzinski) [2034424]
- recordmcount.pl: fix typo in s390 mcount regex (Jerome Marchand) [2025890]
- recordmcount.pl: look for jgnop instruction as well as bcrl on s390 (Jerome Marchand) [2025890]
- KVM: x86: Wait for IPIs to be delivered when handling Hyper-V TLB flush hypercall (Vitaly Kuznetsov) [1868572]
- HID: magicmouse: prevent division by 0 on scroll (Benjamin Tissoires) [2022814]
- HID: input: set usage type to key on keycode remap (Benjamin Tissoires) [2022814]
- HID: input: Fix parsing of HID_CP_CONSUMER_CONTROL fields (Benjamin Tissoires) [2022814]
- HID: u2fzero: properly handle timeouts in usb_submit_urb (Benjamin Tissoires) [2022814]
- HID: u2fzero: clarify error check and length calculations (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2022814]
- HID: u2fzero: ignore incomplete packets without data (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2022814]
- HID: wacom: Add new Intuos BT (CTL-4100WL/CTL-6100WL) device IDs (Benjamin Tissoires) [2022814]
- HID: apple: Fix logical maximum and usage maximum of Magic Keyboard JIS (Benjamin Tissoires) [2022814]
- HID: betop: fix slab-out-of-bounds Write in betop_probe (Benjamin Tissoires) [2022814]
- HID: usbhid: Simplify code in hid_submit_ctrl() (Benjamin Tissoires) [2022814]
- HID: usbhid: Fix warning caused by 0-length input reports (Benjamin Tissoires) [2022814]
- HID: usbhid: Fix flood of "control queue full" messages (Benjamin Tissoires) [2022814]
- HID: sony: Fix more ShanWan clone gamepads to not rumble when plugged in. (Benjamin Tissoires) [2022814]
- HID: sony: support for the ghlive ps4 dongles (Benjamin Tissoires) [2022814]
- HID: thrustmaster: clean up Makefile and adapt quirks (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Fix Elan touchpad regression (Benjamin Tissoires) [2022814]
- HID: asus: Prevent Claymore sending suspend event (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Add dyndbg prints for debugging (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Add support for PM suspend and resume (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Move hid probe after sensor is enabled (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Add command response to check command status (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Fix period data field to enable sensor (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: battery: provide CAPACITY property for newer devices (Benjamin Tissoires) [2022814]
- HID: thrustmaster: Fix memory leak in thrustmaster_interrupts() (Benjamin Tissoires) [2022814]
- HID: thrustmaster: Fix memory leak in remove (Benjamin Tissoires) [2022814]
- HID: thrustmaster: Fix memory leaks in probe (Benjamin Tissoires) [2022814]
- HID: elo: update the reference count of the usb device structure (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: Use 'atomic_inc_return' instead of hand-writing it (Benjamin Tissoires) [2022814]
- HID: ft260: fix device removal due to USB disconnect (Benjamin Tissoires) [2022814]
- HID: apple: Add missing scan code event for keys handled by hid-apple (Benjamin Tissoires) [2022814]
- HID: cmedia: add support for HS-100B mute button (Benjamin Tissoires) [2022814]
- HID: i2c-hid: goodix: Use the devm variant of regulator_register_notifier() (Benjamin Tissoires) [2022814]
- HID: wacom: Refactor touch input mute checks into a common function (Benjamin Tissoires) [2022814]
- HID: wacom: Avoid sending empty sync events (Benjamin Tissoires) [2022814]
- HID: wacom: Short-circuit processing of touch when it is disabled (Benjamin Tissoires) [2022814]
- HID: wacom: set initial hardware touch switch state to 'off' (Benjamin Tissoires) [2022814]
- HID: wacom: Skip processing of touches with negative slot values (Benjamin Tissoires) [2022814]
- HID: wacom: Re-enable touch by default for Cintiq 24HDT / 27QHDT (Benjamin Tissoires) [2022814]
- HID: Kconfig: Fix spelling mistake "Uninterruptable" -> "Uninterruptible" (Benjamin Tissoires) [2022814]
- HID: apple: Add support for Keychron K1 wireless keyboard (Benjamin Tissoires) [2022814]
- HID: usbhid: free raw_report buffers in usbhid_stop (Benjamin Tissoires) [2022814]
- HID: fix typo in Kconfig (Benjamin Tissoires) [2022814]
- HID: ft260: fix format type warning in ft260_word_show() (Benjamin Tissoires) [2022814]
- HID: i2c-hid: goodix: Tie the reset line to true state of the regulator (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Use correct MMIO register for DMA address (Benjamin Tissoires) [2022814]
- HID: magicmouse: high-resolution scroll threshold (Benjamin Tissoires) [2022814]
- HID: magicmouse: enable high-resolution scroll (Benjamin Tissoires) [2022814]
- HID: asus: Remove check for same LED brightness on set (Benjamin Tissoires) [2022814]
- HID: input: do not report stylus battery state as "full" (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: use async resume function (Benjamin Tissoires) [2022814]
- HID: thrustmaster: Switch to kmemdup() when allocate change_request (Benjamin Tissoires) [2022814]
- HID: multitouch: Disable event reporting on suspend when the device is not a wakeup-source (Benjamin Tissoires) [2022814]
- HID: logitech-dj: Implement may_wakeup ll-driver callback (Benjamin Tissoires) [2022814]
- HID: usbhid: Implement may_wakeup ll-driver callback (Benjamin Tissoires) [2022814]
- HID: core: Add hid_hw_may_wakeup() function (Benjamin Tissoires) [2022814]
- HID: input: Add support for Programmable Buttons (Benjamin Tissoires) [2022814]
- HID: wacom: Correct base usage for capacitive ExpressKey status bits (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Add initial support for HPD sensor (Benjamin Tissoires) [2022814 1961759]
- HID: amd_sfh: Extend ALS support for newer AMD platform (Benjamin Tissoires) [2022814 1961759]
- HID: amd_sfh: Extend driver capabilities for multi-generation support (Benjamin Tissoires) [2022814 1961759]
- HID: surface-hid: Fix get-report request (Benjamin Tissoires) [2022814]
- HID: sony: fix freeze when inserting ghlive ps3/wii dongles (Benjamin Tissoires) [2022814]
- HID: usbkbd: Avoid GFP_ATOMIC when GFP_KERNEL is possible (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ipc: Specify that EHL no cache snooping (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ishtp: Add dma_no_cache_snooping() callback (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Set ISH driver depends on x86 (Benjamin Tissoires) [2022814]
- HID: hid-input: add Surface Go battery quirk (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Fix minor typos in comments (Benjamin Tissoires) [2022814]
- HID: magicmouse: fix NULL-deref on disconnect (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ipc: Add Alder Lake device IDs (Benjamin Tissoires) [2022814]
- HID: i2c-hid: fix format string mismatch (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Fix memory leak in amd_sfh_work (Benjamin Tissoires) [2022814]
- HID: amd_sfh: Use devm_kzalloc() instead of kzalloc() (Benjamin Tissoires) [2022814]
- HID: ft260: improve error handling of ft260_hid_feature_report_get() (Benjamin Tissoires) [2022814]
- HID: asus: Cleanup Asus T101HA keyboard-dock handling (Benjamin Tissoires) [2022814]
- HID: magicmouse: fix crash when disconnecting Magic Trackpad 2 (Benjamin Tissoires) [2022814]
- HID: gt683r: add missing MODULE_DEVICE_TABLE (Benjamin Tissoires) [2022814]
- HID: pidff: fix error return code in hid_pidff_init() (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: initialize level variable (Benjamin Tissoires) [2022814]
- HID: multitouch: Disable event reporting on suspend on the Asus T101HA touchpad (Benjamin Tissoires) [2022814]
- HID: core: Remove extraneous empty line before EXPORT_SYMBOL_GPL(hid_check_keys_pressed) (Benjamin Tissoires) [2022814]
- HID: usbmouse: Avoid GFP_ATOMIC when GFP_KERNEL is possible (Benjamin Tissoires) [2022814]
- HID: hid-sensor-custom: Process failure of sensor_hub_set_feature() (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Skip ELAN power-on command after reset (Benjamin Tissoires) [2022814]
- HID: usbhid: fix info leak in hid_submit_ctrl (Benjamin Tissoires) [2022814]
- HID: Add BUS_VIRTUAL to hid_connect logging (Benjamin Tissoires) [2022814]
- HID: input: replace outdated HID numbers+comments with macros (Benjamin Tissoires) [2022814]
- HID: multitouch: set Stylus suffix for Stylus-application devices, too (Benjamin Tissoires) [2022814]
- HID: multitouch: require Finger field to mark Win8 reports as MT (Benjamin Tissoires) [2022814]
- HID: remove the unnecessary redefinition of a macro (Benjamin Tissoires) [2022814]
- HID: quirks: Add quirk for Lenovo optical mouse (Benjamin Tissoires) [2022814]
- HID: asus: filter G713/G733 key event to prevent shutdown (Benjamin Tissoires) [2022814]
- HID: lg-g15 + ite: Add MODULE_AUTHOR (Benjamin Tissoires) [2022814]
- HID: lg-g15: Add support for the Logitech Z-10 speakers (Benjamin Tissoires) [2022814]
- HID: lg-g15: Make the LED-name used by lg_g15_register_led() a parameter (Benjamin Tissoires) [2022814]
- HID: lg-g15: Add a lg_g15_init_input_dev() helper function (Benjamin Tissoires) [2022814]
- HID: lg-g15: Add a lg_g15_handle_lcd_menu_keys() helper function (Benjamin Tissoires) [2022814]
- HID: lg-g15: Remove unused size argument from lg_*_event() functions (Benjamin Tissoires) [2022814]
- HID: hid-sensor-hub: Return error for hid_set_field() failure (Benjamin Tissoires) [2022814]
- HID: ft260: check data size in ft260_smbus_write() (Benjamin Tissoires) [2022814]
- HID: surface-hid: Fix integer endian conversion (Benjamin Tissoires) [2022814]
- HID: hid-debug: recognize KEY_ASSISTANT and KEY_KBD_LAYOUT_NEXT (Benjamin Tissoires) [2022814]
- HID: hid-input: add mapping for emoji picker key (Benjamin Tissoires) [2022814]
- HID: a4tech: use A4_2WHEEL_MOUSE_HACK_B8 for A4TECH NB-95 (Benjamin Tissoires) [2022814]
- HID: logitech-dj/hidpp: Add info/warn/err messages about 27 MHz keyboard encryption (Benjamin Tissoires) [2022814]
- HID: quirks: Add HID_QUIRK_NO_INIT_REPORTS quirk for Dell K15A keyboard-dock (Benjamin Tissoires) [2022814]
- HID: thrustmaster: fix return value check in thrustmaster_probe() (Benjamin Tissoires) [2022814]
- HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for Saitek X65 (Benjamin Tissoires) [2022814]
- HID: do not use down_interruptible() when unbinding devices (Benjamin Tissoires) [2022814]
- HID: asus: Filter keyboard EC for old ROG keyboard (Benjamin Tissoires) [2022814]
- HID: semitek: new driver for GK6X series keyboards (Benjamin Tissoires) [2022814]
- HID: wacom: Setup pen input capabilities to the targeted tools (Benjamin Tissoires) [2022814]
- HID: hid-sensor-hub: Move 'hsdev' description to correct struct definition (Benjamin Tissoires) [2022814]
- HID: hid-sensor-hub: Remove unused struct member 'quirks' (Benjamin Tissoires) [2022814]
- HID: wacom_sys: Demote kernel-doc abuse (Benjamin Tissoires) [2022814]
- HID: hid-sensor-custom: Remove unused variable 'ret' (Benjamin Tissoires) [2022814]
- HID: hid-uclogic-params: Ensure function names are present and correct in kernel-doc headers (Benjamin Tissoires) [2022814]
- HID: hid-uclogic-rdesc: Kernel-doc is for functions and structs (Benjamin Tissoires) [2022814]
- HID: hid-logitech-hidpp: Fix conformant kernel-doc header and demote abuses (Benjamin Tissoires) [2022814]
- HID: hid-picolcd_core: Remove unused variable 'ret' (Benjamin Tissoires) [2022814]
- HID: hid-kye: Fix incorrect function name for kye_tablet_enable() (Benjamin Tissoires) [2022814]
- HID: hid-core: Fix incorrect function name in header (Benjamin Tissoires) [2022814]
- HID: hid-alps: Correct struct misnaming (Benjamin Tissoires) [2022814]
- HID: usbhid: hid-pidff: Demote a couple kernel-doc abuses (Benjamin Tissoires) [2022814]
- HID: usbhid: Repair a formatting issue in a struct description (Benjamin Tissoires) [2022814]
- HID: ishtp-hid-client: Fix 'suggest-attribute=format' compiler warning (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ishtp-fw-loader: Fix a bunch of formatting issues (Benjamin Tissoires) [2022814]
- HID: ishtp-hid-client: Fix incorrect function name report_bad_packet() (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ipc: Correct fw_reset_work_fn() function name in header (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Fix potential copy/paste error (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Fix a little doc-rot (Benjamin Tissoires) [2022814]
- HID: intel-ish: Fix a naming disparity and a formatting error (Benjamin Tissoires) [2022814]
- HID: intel-ish: Supply some missing param descriptions (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: pci-ish: Remove unused variable 'ret' (Benjamin Tissoires) [2022814]
- HID: ishtp-hid-client: Move variable to where it's actually used (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Remove unused variable 'err' (Benjamin Tissoires) [2022814]
- HID: hid-thrustmaster: Demote a bunch of kernel-doc abuses (Benjamin Tissoires) [2022814]
- HID: input: map battery capacity (00850065) (Benjamin Tissoires) [2022814]
- HID: magicmouse: fix reconnection of Magic Mouse 2 (Benjamin Tissoires) [2022814]
- HID: magicmouse: fix 3 button emulation of Mouse 2 (Benjamin Tissoires) [2022814]
- HID: magicmouse: add Apple Magic Mouse 2 support (Benjamin Tissoires) [2022814]
- HID: lenovo: Add support for Thinkpad X1 Tablet Thin keyboard (Benjamin Tissoires) [2022814]
- HID: lenovo: Rework how the tp10ubkbd code decides which USB interface to use (Benjamin Tissoires) [2022814]
- HID: lenovo: Set default_triggers for the mute and micmute LEDs (Benjamin Tissoires) [2022814]
- HID: lenovo: Map mic-mute button to KEY_F20 instead of KEY_MICMUTE (Benjamin Tissoires) [2022814]
- HID: lenovo: Set LEDs max_brightness value (Benjamin Tissoires) [2022814]
- HID: lenovo: Remove lenovo_led_brightness_get() (Benjamin Tissoires) [2022814]
- HID: lenovo: Check hid_get_drvdata() returns non NULL in lenovo_event() (Benjamin Tissoires) [2022814]
- HID: lenovo: Fix lenovo_led_set_tp10ubkbd() error handling (Benjamin Tissoires) [2022814]
- HID: lenovo: Use brightness_set_blocking callback for setting LEDs brightness (Benjamin Tissoires) [2022814]
- HID: elan: Remove elan_mute_led_get_brigtness() (Benjamin Tissoires) [2022814]
- HID: elan: Set default_trigger for the mute LED (Benjamin Tissoires) [2022814]
- HID: elan: Silence mute LED errors being logged when the device is unplugged (Benjamin Tissoires) [2022814]
- HID: fix memdup.cocci warnings (Benjamin Tissoires) [2022814]
- HID: surface-hid: Add support for legacy keyboard interface (Benjamin Tissoires) [2022814]
- HID: Add support for Surface Aggregator Module HID transport (Benjamin Tissoires) [2022814]
- HID: thrustmaster: introduce proper USB dependency (Benjamin Tissoires) [2022814]
- HID: intel_ish-hid: HBM: Use connected standby state bit during suspend/resume (Benjamin Tissoires) [2022814]
- HID: ft260: fix an error message in ft260_i2c_write_read() (Benjamin Tissoires) [2022814]
- HID: support for initialization of some Thrustmaster wheels (Benjamin Tissoires) [2022814]
- HID: wacom: set EV_KEY and EV_ABS only for non-HID_GENERIC type of devices (Benjamin Tissoires) [2022814]
- HID: ft260: add usb hid to i2c host bridge driver (Benjamin Tissoires) [2022814]
- iio: Add relative sensitivity support (Benjamin Tissoires) [2022814]
- iio: hid-sensors: Move get sensitivity attribute to hid-sensor-common (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Make remove callback return void (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Simplify logic in ishtp_cl_device_remove() (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Drop if block with an always false condition (Benjamin Tissoires) [2022814]
- AMD_SFH: Add DMI quirk table for BIOS-es which don't set the activestatus bits (Benjamin Tissoires) [2022814]
- AMD_SFH: Add sensor_mask module parameter (Benjamin Tissoires) [2022814]
- AMD_SFH: Removed unused activecontrolstatus member from the amd_mp2_dev struct (Benjamin Tissoires) [2022814]
- HID: wacom: Assign boolean values to a bool variable (Benjamin Tissoires) [2022814]
- HID cp2112: fix support for multiple gpiochips (Benjamin Tissoires) [2022814]
- HID: alps: fix error return code in alps_input_configured() (Benjamin Tissoires) [2022814]
- HID: asus: Add support for 2021 ASUS N-Key keyboard (Benjamin Tissoires) [2022814]
- HID: hiddev: Return specific error codes on connect failure (Benjamin Tissoires) [2022814]
- HID: plantronics: Workaround for double volume key presses (Benjamin Tissoires) [2022814]
- HID: logitech-dj: Handle newer quad/bt2.0 receivers in HID proxy mode (Benjamin Tissoires) [2022814]
- HID: logitech-dj: Use hid-ids.h defines for USB device-ids for all supported devices (Benjamin Tissoires) [2022814]
- HID: google: add don USB id (Benjamin Tissoires) [2022814]
- HID: i2c-hid: acpi: Drop redundant ACPI_PTR() (Benjamin Tissoires) [2022814]
- HID: i2c-hid: acpi: Move GUID out of function and described it (Benjamin Tissoires) [2022814]
- HID: i2c-hid: acpi: Switch to new style i2c-driver probe function (Benjamin Tissoires) [2022814]
- HID: i2c-hid: acpi: Get ACPI companion only once and reuse it (Benjamin Tissoires) [2022814]
- HID: playstation: add DualSense player LED support. (Benjamin Tissoires) [2022814]
- HID: playstation: add microphone mute support for DualSense. (Benjamin Tissoires) [2022814]
- HID: playstation: add initial DualSense lightbar support. (Benjamin Tissoires) [2022814]
- HID: wacom: Ignore attempts to overwrite the touch_max value from HID (Benjamin Tissoires) [2022814]
- HID: playstation: fix array size comparison (off-by-one) (Benjamin Tissoires) [2022814]
- HID: playstation: fix unused variable in ps_battery_get_property. (Benjamin Tissoires) [2022814]
- HID: playstation: report DualSense hardware and firmware version. (Benjamin Tissoires) [2022814]
- HID: playstation: add DualSense classic rumble support. (Benjamin Tissoires) [2022814]
- HID: playstation: add DualSense Bluetooth support. (Benjamin Tissoires) [2022814]
- HID: playstation: track devices in list. (Benjamin Tissoires) [2022814]
- HID: playstation: add DualSense accelerometer and gyroscope support. (Benjamin Tissoires) [2022814]
- HID: playstation: add DualSense touchpad support. (Benjamin Tissoires) [2022814]
- HID: playstation: add DualSense battery support. (Benjamin Tissoires) [2022814]
- HID: playstation: use DualSense MAC address as unique identifier. (Benjamin Tissoires) [2022814]
- HID: playstation: initial DualSense USB support. (Benjamin Tissoires) [2022814]
- HID: ite: Enable QUIRK_TOUCHPAD_ON_OFF_REPORT on Acer Aspire Switch 10E (Benjamin Tissoires) [2022814]
- HID: Ignore battery for Elan touchscreen on HP Spectre X360 15-df0xxx (Benjamin Tissoires) [2022814]
- HID: logitech-dj: add support for the new lightspeed connection iteration (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ipc: Add Tiger Lake H PCI device ID (Benjamin Tissoires) [2022814]
- HID: logitech-dj: add support for keyboard events in eQUAD step 4 Gaming (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Add I2C_HID_QUIRK_NO_IRQ_AFTER_RESET for ITE8568 EC on Voyo Winpad A15 (Benjamin Tissoires) [2022814]
- HID: displays: convert sysfs sprintf/snprintf family to sysfs_emit (Benjamin Tissoires) [2022814]
- HID: wacom: convert sysfs sprintf/snprintf family to sysfs_emit (Benjamin Tissoires) [2022814]
- HID: lg-g15: make a const array static, makes object smaller (Benjamin Tissoires) [2022814]
- HID: google: Get HID report on probe to confirm tablet switch state (Benjamin Tissoires) [2022814]
- HID: hid-input: avoid splitting keyboard, system and consumer controls (Benjamin Tissoires) [2022814]
- HID: correct kernel-doc notation in hid-quirks.c (Benjamin Tissoires) [2022814]
- HID: correct kernel-doc notation in <linux/hid*.h> (Benjamin Tissoires) [2022814]
- HID: wacom: Correct NULL dereference on AES pen proximity (Benjamin Tissoires) [2022814]
- HID: multitouch: Set to high latency mode on suspend. (Benjamin Tissoires) [2022814]
- HID: multitouch: Apply MT_QUIRK_CONFIDENCE quirk for multi-input devices (Benjamin Tissoires) [2022814]
- HID: hid-sensor-custom: Add custom sensor iio support (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Introduce goodix-i2c-hid using i2c-hid core (Benjamin Tissoires) [2022814]
- redhat: HID: enable I2C_HID_ACPI (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Reorganize so ACPI and OF are separate modules (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: add support for Unified Battery (1004) feature (Benjamin Tissoires) [2022814]
- HID: sony: Add support for tilt on guitar hero guitars (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: Add product ID for MX Ergo in Bluetooth mode (Benjamin Tissoires) [2022814]
- HID: chicony: Add Wireless Radio Control feature for Chicony devices (Benjamin Tissoires) [2022814]
- HID: Ignore battery for Elan touchscreen on ASUS UX550 (Benjamin Tissoires) [2022814]
- HID: logitech-dj: add the G602 receiver (Benjamin Tissoires) [2022814]
- HID: core: detect and skip invalid inputs to snto32() (Benjamin Tissoires) [2022814]
- HID: uclogic: Improve support for Trust Panora (Benjamin Tissoires) [2022814]
- HID: wiimote: remove h from printk format specifier (Benjamin Tissoires) [2022814]
- HID: uclogic: remove h from printk format specifier (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ipc: Address EHL Sx resume issues (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: ipc: finish power flow for EHL OOB (Benjamin Tissoires) [2022814]
- HID: sony: select CONFIG_CRC32 (Benjamin Tissoires) [2022814]
- HID: sfh: fix address space confusion (Benjamin Tissoires) [2022814]
- HID: multitouch: Enable multi-input for Synaptics pointstick/touchpad device (Benjamin Tissoires) [2022814]
- HID: wacom: Fix memory leakage caused by kfifo_alloc (Benjamin Tissoires) [2022814]
- HID: i2c-hid: add Vero K147 to descriptor override (Benjamin Tissoires) [2022814]
- HID: ite: Add support for Acer S1002 keyboard-dock (Benjamin Tissoires) [2022814]
- HID: sony: support for ghlive ps3/wii u dongles (Benjamin Tissoires) [2022814]
- HID: hidraw: Add additional hidraw input/output report ioctls. (Benjamin Tissoires) [2022814]
- HID: Increase HID maximum report size to 16KB (Benjamin Tissoires) [2022814]
- HID: elecom: drop stray comment (Benjamin Tissoires) [2022814]
- HID: mf: add support for 0079:1846 Mayflash/Dragonrise USB Gamecube Adapter (Benjamin Tissoires) [2022814]
- HID: elecom: add support for EX-G M-XGL20DLBK wireless mouse (Benjamin Tissoires) [2022814]
- HID: elecom: rewrite report based on model specific parameters (Benjamin Tissoires) [2022814]
- HID: wacom: Constify attribute_groups (Benjamin Tissoires) [2022814]
- HID: input: Fix fall-through warnings for Clang (Benjamin Tissoires) [2022814]
- HID: usbhid: Fix fall-through warnings for Clang (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: Add hid_device_id for V470 bluetooth mouse (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: Remove unnecessary assignment to variable rv (Benjamin Tissoires) [2022814]
- HID: sony: Workaround for DS4 dongle hotplug kernel crash. (Benjamin Tissoires) [2022814]
- HID: sony: Don't use fw_version/hw_version for sysfs cleanup. (Benjamin Tissoires) [2022814]
- HID: sony: Report more accurate DS4 power status. (Benjamin Tissoires) [2022814]
- SFH: fix error return check for -ERESTARTSYS (Benjamin Tissoires) [2022814]
- HID: Add Logitech Dinovo Edge battery quirk (Benjamin Tissoires) [2022814]
- HID: logitech-hidpp: Add HIDPP_CONSUMER_VENDOR_KEYS quirk for the Dinovo Edge (Benjamin Tissoires) [2022814]
- HID: add HID_QUIRK_INCREMENT_USAGE_ON_DUPLICATE for Gamevice devices (Benjamin Tissoires) [2022814]
- HID: mcp2221: Fix GPIO output handling (Benjamin Tissoires) [2022814]
- HID: hid-sensor-hub: Fix issue with devices with no report ID (Benjamin Tissoires) [2022814]
- HID: hid-input: occasionally report stylus battery even if not changed (Benjamin Tissoires) [2022814]
- timekeeping: Add missing _ns functions for coarse accessors (Benjamin Tissoires) [2022814]
- HID: i2c-hid: show the error when failing to fetch the HID descriptor (Benjamin Tissoires) [2022814]
- AMD_SFH: Fix for incorrect Sensor index (Benjamin Tissoires) [2022814]
- HID: asus: Add support for ASUS N-Key keyboard (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Put ACPI enumerated devices in D3 on shutdown (Benjamin Tissoires) [2022814]
- HID: add support for Sega Saturn (Benjamin Tissoires) [2022814]
- HID: cypress: Support Varmilo Keyboards' media hotkeys (Benjamin Tissoires) [2022814]
- HID: ite: Replace ABS_MISC 120/121 events with touchpad on/off keypresses (Benjamin Tissoires) [2022814]
- SFH: Create HID report to Enable support of AMD sensor fusion Hub (SFH) (Benjamin Tissoires) [2022814]
- SFH:Transport Driver to add support of AMD Sensor Fusion Hub (SFH) (Benjamin Tissoires) [2022814]
- redhat: HID: enable AMD_SFH_HUB (Benjamin Tissoires) [1965674]
- SFH: PCIe driver to add support of AMD sensor fusion hub (Benjamin Tissoires) [2022814]
- HID: uclogic: Add ID for Trust Flex Design Tablet (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Enable wakeup capability from Suspend-to-Idle (Benjamin Tissoires) [2022814]
- HID: add vivaldi HID driver (Benjamin Tissoires) [2022814]
- HID: i2c-hid: fix kerneldoc warnings in i2c-hid-core.c (Benjamin Tissoires) [2022814]
- HID: core: fix kerneldoc warnings in hid-core.c (Benjamin Tissoires) [2022814]
- HID: multitouch: Lenovo X1 Tablet Gen2 trackpoint and buttons (Benjamin Tissoires) [2022814]
- HID: alps: clean up indentation issue (Benjamin Tissoires) [2022814]
- HID: intel-ish-hid: simplify the return expression of ishtp_bus_remove_device() (Benjamin Tissoires) [2022814]
- HID: hid-debug: fix nonblocking read semantics wrt EIO/ERESTARTSYS (Benjamin Tissoires) [2022814]
- HID: i2c-hid: Prefer asynchronous probe (Benjamin Tissoires) [2022814]
- HID: wiimote: narrow spinlock range in wiimote_hid_event() (Benjamin Tissoires) [2022814]
- HID: wiimote: make handlers[] const (Benjamin Tissoires) [2022814]
- HID: logitech-dj: Fix spelling in comment (Benjamin Tissoires) [2022814]
- HID: apple: Add support for Matias wireless keyboard (Benjamin Tissoires) [2022814]
- Input: elan_i2c - reduce the resume time for controller in Whitebox (Benjamin Tissoires) [2022814]
- Input: parkbd - switch to use module_parport_driver() (Benjamin Tissoires) [2022814]
- Input: i8042 - fix typos in comments (Benjamin Tissoires) [2022814]
- Input: elantech - Prepare a complete software node for the device (Benjamin Tissoires) [2022814]
- Input: apbps2 - remove useless variable (Benjamin Tissoires) [2022814]
- Input: elan_i2c - fix a typo in parameter name (Benjamin Tissoires) [2022814]
- Input: i8042 - fix Pegatron C15B ID entry (Benjamin Tissoires) [2022814]
- Input: elan_i2c - reduce the resume time for new devices (Benjamin Tissoires) [2022814]
- Input: i8042 - add ASUS Zenbook Flip to noselftest list (Benjamin Tissoires) [2022814]
- Input: add missing dependencies on CONFIG_HAS_IOMEM (Benjamin Tissoires) [2022814]
- ARM: 9048/1: sa1111: make sa1111 bus's remove callback return void (Benjamin Tissoires) [2022814]
- Input: synaptics - replace NOOP with suitable commentary (Benjamin Tissoires) [2022814]
- Input: i8042 - unbreak Pegatron C15B (Benjamin Tissoires) [2022814]
- Input: parkbd - convert comma to semicolon (Benjamin Tissoires) [2022814]
- Input: elantech - fix protocol errors for some trackpoints in SMBus mode (Benjamin Tissoires) [2022814]
- Input: elan_i2c - add new trackpoint report type 0x5F (Benjamin Tissoires) [2022814]
- Input: i8042 - add Acer laptops to the i8042 reset list (Benjamin Tissoires) [2022814]
- Input: i8042 - add ByteSpeed touchpad to noloop table (Benjamin Tissoires) [2022814]
- Input: i8042 - fix error return code in i8042_setup_aux() (Benjamin Tissoires) [2022814]
- Input: libps2 - fix fall-through warnings for Clang (Benjamin Tissoires) [2022814]
- Input: synaptics - demote non-conformant kernel-doc header (Benjamin Tissoires) [2022814]
- Input: elan_i2c_core - move header inclusion inside (Benjamin Tissoires) [2022814]
- Input: elan_i2c - fix firmware update on newer ICs (Benjamin Tissoires) [2022814]
- Input: elantech - demote obvious abuse of kernel-doc header (Benjamin Tissoires) [2022814]
- Input: i8042 - allow insmod to succeed on devices without an i8042 controller (Benjamin Tissoires) [2022814]
- Input: synaptics - enable InterTouch for ThinkPad T14 Gen 1 (Benjamin Tissoires) [2022814]
- Input: synaptics - enable InterTouch for ThinkPad P1/X1E gen 2 (Benjamin Tissoires) [2022814]
- Input: synaptics-rmi4 - rename f30_data to gpio_data (Benjamin Tissoires) [2022814]
- Input: sun4i-ps2 - fix handling of platform_get_irq() error (Benjamin Tissoires) [2022814]
- Input: allocate keycode for Fn + right shift (Benjamin Tissoires) [2022814]
- Input: allocate keycodes for notification-center, pickup-phone and hangup-phone (Benjamin Tissoires) [2022814]
- HID: cp2112: Use irqchip template (Benjamin Tissoires) [2022814]
- HID: mcp2221: Replace HTTP links with HTTPS ones (Benjamin Tissoires) [2022814]
- treewide: replace '---help---' in Kconfig files with 'help' (Benjamin Tissoires) [2022814]
- HID: asus: Add depends on USB_HID to HID_ASUS Kconfig option (Benjamin Tissoires) [2022814]
- HID: asus: Fix mute and touchpad-toggle keys on Medion Akoya E1239T (Benjamin Tissoires) [2022814]
- HID: asus: Add support for multi-touch touchpad on Medion Akoya E1239T (Benjamin Tissoires) [2022814]
- HID: asus: Add report_size to struct asus_touchpad_info (Benjamin Tissoires) [2022814]
- HID: asus: Add hid_is_using_ll_driver(usb_hid_driver) check (Benjamin Tissoires) [2022814]
- HID: asus: Simplify skipping of mappings for Asus T100CHI keyboard-dock (Benjamin Tissoires) [2022814]
- HID: asus: Only set EV_REP if we are adding a mapping (Benjamin Tissoires) [2022814]
- HID: mcp2221: add gpiolib dependency (Benjamin Tissoires) [2022814]
- HID: mcp2221: add GPIO functionality support (Benjamin Tissoires) [2022814]
- HID: mcp2221: add usb to i2c-smbus host bridge (Benjamin Tissoires) [2022814]
- HID: asus: Ignore Asus vendor-page usage-code 0xff events (Benjamin Tissoires) [2022814]
- HID: sb0540: add support for Creative SB0540 IR receivers (Benjamin Tissoires) [2022814]
- gpio: pass lookup and descriptor flags to request_own (Benjamin Tissoires) [2022814]
- HID: hid-asus: select CONFIG_POWER_SUPPLY (Benjamin Tissoires) [2022814]
- HID: hid-asus: Add BT keyboard dock battery monitoring support (Benjamin Tissoires) [2022814]
- HID: hid-asus: Add Transbook T90CHI support (Benjamin Tissoires) [2022814]
- HID: asus: Add support for the ASUS T101HA keyboard dock (Benjamin Tissoires) [2022814]
- HID: asus: Add support for the ASUS FX503VD laptop (Benjamin Tissoires) [2022814]
- HID: asus: Add event handler to catch unmapped Asus Vendor UsagePage codes (Benjamin Tissoires) [2022814]
- af_unix: fix garbage collect vs MSG_PEEK (Patrick Talbert) [2031975] {CVE-2021-0920}
- net: add kerneldoc comment for sk_peer_lock (Guillaume Nault) [2037782]
- af_unix: fix races in sk_peer_pid and sk_peer_cred accesses (Guillaume Nault) [2037782] {CVE-2021-4203}
- netfilter: nat: force port remap to prevent shadowing well-known ports (Florian Westphal) [2006167] {CVE-2021-3773}
- netfilter: conntrack: tag conntracks picked up in local out hook (Florian Westphal) [2006167]
- selftests: nft_nat: switch port shadow test cases to socat (Florian Westphal) [2006167]
- selftests: nft_nat: Simplify port shadow notrack test (Florian Westphal) [2006167]
- selftests: nft_nat: Improve port shadow test stability (Florian Westphal) [2006167]
- selftests: nft_nat: add udp hole punch test case (Florian Westphal) [2006167]
- ipv6: use prandom_u32() for ID generation (Hangbin Liu) [2040158] {CVE-2021-45485}
- igc: fix tunnel offloading (Corinna Vinschen) [1910885]
- virtio/vsock: fix the transport to work with VMADDR_CID_ANY (Stefano Garzarella) [2026442]
- vhost/vsock: cleanup removing `len` variable (Stefano Garzarella) [2026442]
- vhost/vsock: fix incorrect used length reported to the guest (Stefano Garzarella) [2026442]
- vsock: prevent unnecessary refcnt inc for nonblocking connect (Stefano Garzarella) [2026442]
- vsock/virtio: avoid potential deadlock when vsock device remove (Stefano Garzarella) [2026442]
- VSOCK: handle VIRTIO_VSOCK_OP_CREDIT_REQUEST (Stefano Garzarella) [2026442]
- vsock: notify server to shutdown when client has pending signal (Stefano Garzarella) [2026442]
- virtio/vsock: simplify credit update function API (Stefano Garzarella) [2026442]
- virtio/vsock: set packet's type in virtio_transport_send_pkt_info() (Stefano Garzarella) [2026442]
- net: vlan: fix underflow for the real_dev refcnt (Balazs Nemeth) [2026375]
- net: vlan: fix a UAF in vlan_dev_real_dev() (Balazs Nemeth) [2026375]

* Mon Jan 24 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-361.el8]
- xfs: map unwritten blocks in XFS_IOC_{ALLOC,FREE}SP just like fallocate (Carlos Maiolino) [2034865] {CVE-2021-4155}
- isdn: cpai: check ctr->cnr to avoid array index out of bound (Chris von Recklinghausen) [2016491] {CVE-2021-43389}
- vt: keyboard: avoid signed integer overflow in k_ascii (Chris von Recklinghausen) [2017044] {CVE-2020-13974}
- USB: serial: pl2303: fix GC type detection (Torez Smith) [1975985]
- usb: dwc3: leave default DMA for PCI devices (Torez Smith) [1975985]
- usb: xhci: tegra: Check padctrl interrupt presence in device tree (Torez Smith) [1975985]
- usb: dwc3: core: Revise GHWPARAMS9 offset (Torez Smith) [1975985]
- xhci: Fix USB 3.1 enumeration issues by increasing roothub power-on-good delay (Torez Smith) [1975985]
- usb: typec: tipd: Remove dependency on "connector" child fwnode (Torez Smith) [1975985]
- usb: xhci: tegra: mark PM functions as __maybe_unused (Torez Smith) [1975985]
- media: ttusb-dec: avoid release of non-acquired mutex (Torez Smith) [1975985]
- ABI: sysfs-devices-removable: make a table valid as ReST markup (Torez Smith) [1975985]
- usb: dwc3: core: balance phy init and exit (Torez Smith) [1975985]
- USB: serial: pl2303: fix GL type detection (Torez Smith) [1975985]
- usb: xhci-mtk: Do not use xhci's virt_dev in drop_endpoint (Torez Smith) [1975985]
- usb: xhci-mtk: fix issue of out-of-bounds array access (Torez Smith) [1975985]
- usb: dwc3: Decouple USB 2.0 L1 & L2 events (Torez Smith) [1975985]
- media: em28xx-input: fix refcount bug in em28xx_usb_disconnect (Torez Smith) [1975985]
- media: dvb-usb: Fix error handling in dvb_usb_i2c_init (Torez Smith) [1975985]
- power: supply: Fix build error when CONFIG_POWER_SUPPLY is not enabled. (Torez Smith) [1975985]
- thunderbolt: test: split up test cases in tb_test_credit_alloc_all (Torez Smith) [1975985]
- thunderbolt: Handle ring interrupt by reading interrupt status register (Torez Smith) [1975985]
- thunderbolt: Add vendor specific NHI quirk for auto-clearing interrupt status (Torez Smith) [1975985]
- thunderbolt: Fix port linking by checking all adapters (Torez Smith) [1975985]
- thunderbolt: Do not read control adapter config space (Torez Smith) [1975985]
- thunderbolt: Add authorized value to the KOBJ_CHANGE uevent (Torez Smith) [1975985]
- usb: typec: tcpm: Raise vdm_sm_running flag only when VDM SM is running (Torez Smith) [1975985]
- usb: dwc3: gadget: Stop EP0 transfers during pullup disable (Torez Smith) [1975985]
- usb: dwc3: gadget: Fix dwc3_calc_trbs_left() (Torez Smith) [1975985]
- Revert "USB: serial: ch341: fix character loss at high transfer rates" (Torez Smith) [1975985]
- USB: serial: option: add new VID/PID to support Fibocom FG150 (Torez Smith) [1975985]
- usb: typec: tcpm: Fix VDMs sometimes not being forwarded to alt-mode drivers (Torez Smith) [1975985]
- Revert "usb: dwc3: gadget: Use list_replace_init() before traversing lists" (Torez Smith) [1975985]
- usb: typec: tcpm: Keep other events when receiving FRS and Sourcing_vbus events (Torez Smith) [1975985]
- usb: dwc3: gadget: Avoid runtime resume if disabling pullup (Torez Smith) [1975985]
- usb: dwc3: gadget: Use list_replace_init() before traversing lists (Torez Smith) [1975985]
- USB: serial: ftdi_sio: add device ID for Auto-M3 OP-COM v2 (Torez Smith) [1975985]
- USB: serial: pl2303: fix GT type detection (Torez Smith) [1975985]
- USB: serial: option: add Telit FD980 composition 0x1056 (Torez Smith) [1975985]
- USB: serial: pl2303: fix HX type detection (Torez Smith) [1975985]
- media: rtl28xxu: fix zero-length control request (Torez Smith) [1975985]
- media: Revert "media: rtl28xxu: fix zero-length control request" (Torez Smith) [1975985]
- USB: serial: ch341: fix character loss at high transfer rates (Torez Smith) [1975985]
- usb: otg-fsm: Fix hrtimer list corruption (Torez Smith) [1975985]
- USB: usbtmc: Fix RCU stall warning (Torez Smith) [1975985]
- USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick (Torez Smith) [1975985]
- Revert "USB: quirks: ignore remote wake-up on Fibocom L850-GL LTE modem" (Torez Smith) [1975985]
- usb: dwc2: gadget: Fix sending zero length packet in DDMA mode. (Torez Smith) [1975985]
- usb: dwc2: Skip clock gating on Samsung SoCs (Torez Smith) [1975985]
- usb: dwc2: gadget: Fix GOUTNAK flow for Slave mode. (Torez Smith) [1975985]
- usb: xhci: avoid renesas_usb_fw.mem when it's unusable (Torez Smith) [1975985]
- usb: dwc3: avoid NULL access of usb_gadget_driver (Torez Smith) [1975985]
- usb: typec: stusb160x: Don't block probing of consumer of "connector" nodes (Torez Smith) [1975985]
- usb: typec: stusb160x: register role switch before interrupt registration (Torez Smith) [1975985]
- USB: usb-storage: Add LaCie Rugged USB3-FW to IGNORE_UAS (Torez Smith) [1975985]
- usb: hub: Disable USB 3 device initiated lpm if exit latency is too high (Torez Smith) [1975985]
- usb: hub: Fix link power management max exit latency (MEL) calculations (Torez Smith) [1975985]
- usb: typec: tipd: Don't block probing of consumer of "connector" nodes (Torez Smith) [1975985]
- xhci: Fix lost USB 2 remote wake (Torez Smith) [1975985]
- USB: serial: cp210x: fix comments for GE CS1000 (Torez Smith) [1975985]
- USB: core: Fix incorrect pipe calculation in do_proc_control() (Torez Smith) [1975985]
- USB: serial: option: add support for u-blox LARA-R6 family (Torez Smith) [1975985]
- thunderbolt: test: Reinstate a few casts of bitfields (Torez Smith) [1975985]
- USB: cdc-acm: blacklist Heimann USB Appset device (Torez Smith) [1975985]
- usb: xhci-mtk: allow multiple Start-Split in a microframe (Torez Smith) [1975985]
- usb: ftdi-elan: remove redundant continue statement in a while-loop (Torez Smith) [1975985]
- thunderbolt: test: Remove some casts which are no longer required (Torez Smith) [1975985]
- xhci: remove redundant continue statement (Torez Smith) [1975985]
- usb: dwc3: Fix debugfs creation flow (Torez Smith) [1975985]
- docs: driver-api: usb: avoid using ReST :doc:`foo` markup (Torez Smith) [1975985]
- xhci: solve a double free problem while doing s4 (Torez Smith) [1975985]
- xhci: handle failed buffer copy to URB sg list and fix a W=1 copiler warning (Torez Smith) [1975985]
- xhci: Add adaptive interrupt rate for isoch TRBs with XHCI_AVOID_BEI quirk (Torez Smith) [1975985]
- xhci: Remove unused defines for ERST_SIZE and ERST_ENTRIES (Torez Smith) [1975985]
- usb: typec: Add the missed altmode_id_remove() in typec_register_altmode() (Torez Smith) [1975985]
- usb: typec: tcpm: Relax disconnect threshold during power negotiation (Torez Smith) [1975985]
- usb: typec: tcpm: Ignore Vsafe0v in PR_SWAP_SNK_SRC_SOURCE_ON state (Torez Smith) [1975985]
- usb: typec: tcpci: Fix up sink disconnect thresholds for PD (Torez Smith) [1975985]
- usb: core: hub: Disable autosuspend for Cypress CY7C65632 (Torez Smith) [1975985]
- usb: host: xhci-tegra: Use devm_platform_get_and_ioremap_resource() (Torez Smith) [1975985]
- usb: host: xhci-tegra: Add missing of_node_put() in tegra_xusb_probe() (Torez Smith) [1975985]
- usb: host: xhci-tegra: add missing put_device() in tegra_xusb_probe() (Torez Smith) [1975985]
- media: usb: cpia2: Fixed Coding Style issues (Torez Smith) [1975985]
- media: ttusb-dec: cleanup an error handling logic (Torez Smith) [1975985]
- cypress_m8: switch data_bits to real character bits (Torez Smith) [1975985]
- thunderbolt: Fix DROM handling for USB4 DROM (Torez Smith) [1975985]
- usb: xhci: tegra: Enable ELPG for runtime/system PM (Torez Smith) [1975985]
- usb: xhci: tegra: Unlink power domain devices (Torez Smith) [1975985]
- thunderbolt: Bond lanes only when dual_link_port != NULL in alloc_dev_default() (Torez Smith) [1975985]
- thunderbolt: No need to include <linux/acpi.h> in usb4_port.c (Torez Smith) [1975985]
- thunderbolt: Poll 10ms for REG_FW_STS_NVM_AUTH_DONE to be set (Torez Smith) [1975985]
- thunderbolt: Add device links only when software connection manager is used (Torez Smith) [1975985]
- thunderbolt: Add support for Intel Alder Lake (Torez Smith) [1975985]
- usb: typec: mux: Fix copy-paste mistake in typec_mux_match (Torez Smith) [1975985]
- usb: typec: ucsi: Clear PPM capability data in ucsi_init() error path (Torez Smith) [1975985]
- usb: typec: wcove: Use LE to CPU conversion when accessing msg->header (Torez Smith) [1975985]
- usb: typec: ucsi: Fix a comment in ucsi_init() (Torez Smith) [1975985]
- USB: dwc3: remove debugfs root dentry storage (Torez Smith) [1975985]
- USB: serial: cp210x: fix CP2102N-A01 modem control (Torez Smith) [1975985]
- USB: serial: cp210x: fix alternate function for CP2102N QFN20 (Torez Smith) [1975985]
- usb: dwc2: Don't reset the core after setting turnaround time (Torez Smith) [1975985]
- usb: dwc3: support 64 bit DMA in platform driver (Torez Smith) [1975985]
- USB: core: Avoid WARNings for 0-length descriptor requests (Torez Smith) [1975985]
- usb: dwc3: core: fix kernel panic when do reboot (Torez Smith) [1975985]
- usb: dwc3: ep0: fix NULL pointer exception (Torez Smith) [1975985]
- usb: typec: intel_pmc_mux: Put ACPI device using acpi_dev_put() (Torez Smith) [1975985]
- usb: typec: intel_pmc_mux: Add missed error check for devm_ioremap_resource() (Torez Smith) [1975985]
- usb: typec: intel_pmc_mux: Put fwnode in error case during ->probe() (Torez Smith) [1975985]
- usb: typec: tcpm: Do not finish VDM AMS for retrying Responses (Torez Smith) [1975985]
- media: cinergyt2: make properties const (Torez Smith) [1975985]
- media: dvd_usb: memory leak in cinergyt2_fe_attach (Torez Smith) [1975985]
- USB: serial: ftdi_sio: add NovaTech OrionMX product ID (Torez Smith) [1975985]
- usb: typec: tcpm: cancel send discover hrtimer when unregister tcpm port (Torez Smith) [1975985]
- usb: typec: tcpm: cancel frs hrtimer when unregister tcpm port (Torez Smith) [1975985]
- usb: typec: tcpm: cancel vdm and state machine hrtimer when unregister tcpm port (Torez Smith) [1975985]
- usb: typec: tcpm: Properly handle Alert and Status Messages (Torez Smith) [1975985]
- usb: dwc3: meson-g12a: Disable the regulator in the error handling path of the probe (Torez Smith) [1975985]
- usb: typec: tcpm: Fix misuses of AMS invocation (Torez Smith) [1975985]
- usb: typec: tcpm: Introduce snk_vdo_v1 for SVDM version 1.0 (Torez Smith) [1975985]
- dt-bindings: connector: Add PD rev 2.0 VDO definition (Torez Smith) [1975985]
- usb: typec: tcpm: Correct the responses in SVDM Version 2.0 DFP (Torez Smith) [1975985]
- Revert "usb: dwc3: core: Add shutdown callback for dwc3" (Torez Smith) [1975985]
- dt-bindings: connector: Replace BIT macro with generic bit ops (Torez Smith) [1975985]
- media: gspca: ov519: replace RIGHT SINGLE QUOTATION MARK (Torez Smith) [1975985]
- usb: typec: intel_pmc_mux: Update IOM port status offset for AlderLake (Torez Smith) [1975985]
- usb: pd: Set PD_T_SINK_WAIT_CAP to 310ms (Torez Smith) [1975985]
- usb: dwc3: gadget: Bail from dwc3_gadget_exit() if dwc->gadget is NULL (Torez Smith) [1975985]
- usb: dwc3: gadget: Disable gadget IRQ during pullup disable (Torez Smith) [1975985]
- usb: dwc3: debugfs: Add and remove endpoint dirs dynamically (Torez Smith) [1975985]
- Revert "usb: typec: mux: Remove requirement for the "orientation-switch" device property" (Torez Smith) [1975985]
- media: rtl28xxu: fix zero-length control request (Torez Smith) [1975985]
- media: gspca/sunplus: fix zero-length control requests (Torez Smith) [1975985]
- media: gspca/gl860: fix zero-length control requests (Torez Smith) [1975985]
- media: gspca/sq905: fix control-request direction (Torez Smith) [1975985]
- media: dtv5100: fix control-request directions (Torez Smith) [1975985]
- media: drivers/media/usb/gspca/cpia1.c : fix spelling typo (Torez Smith) [1975985]
- media: drivers/media/usb/em28xx/em28xx-cards.c : fix typo issues (Torez Smith) [1975985]
- media: zr364xx: fix memory leak in zr364xx_start_readpipe (Torez Smith) [1975985]
- media: em28xx: Fix possible memory leak of em28xx struct (Torez Smith) [1975985]
- thunderbolt: Check for NVM authentication status after the operation started (Torez Smith) [1975985]
- thunderbolt: Add WRITE_ONLY and AUTHENTICATE_ONLY NVM operations for retimers (Torez Smith) [1975985]
- thunderbolt: Allow router NVM authenticate separately (Torez Smith) [1975985]
- thunderbolt: Move nvm_write_ops to tb.h (Torez Smith) [1975985]
- thunderbolt: Log the link as TBT instead of TBT3 (Torez Smith) [1975985]
- thunderbolt: Add support for retimer NVM upgrade when there is no link (Torez Smith) [1975985]
- thunderbolt: Add additional USB4 port operations for retimer access (Torez Smith) [1975985]
- thunderbolt: Add support for ACPI _DSM to power on/off retimers (Torez Smith) [1975985]
- thunderbolt: Add USB4 port devices (Torez Smith) [1975985]
- thunderbolt: Add KUnit tests for credit allocation (Torez Smith) [1975985]
- thunderbolt: Allocate credits according to router preferences (Torez Smith) [1975985]
- USB: core: Check buffer length matches wLength for control transfers (Torez Smith) [1975985]
- usb: typec: ucsi: Fix copy/paste issue for 'ucsi_set_drvdata()' (Torez Smith) [1975985]
- usb: dwc2: gadget: Repair 'dwc2_hsotg_core_init_disconnected()'s documentation (Torez Smith) [1975985]
- usb: dwc2: pci: Fix possible copy/paste issue (Torez Smith) [1975985]
- usb: dwc2: hcd_queue: Fix typeo in function name 'dwc2_hs_pmap_unschedule()' (Torez Smith) [1975985]
- usb: dwc2: params: Fix naming of 'dwc2_get_hwparams()' in the docs (Torez Smith) [1975985]
- usb: common: ulpi: Add leading underscores for function name '__ulpi_register_driver()' (Torez Smith) [1975985]
- usb: dwc2: platform: Provide function name for 'dwc2_check_core_version()' (Torez Smith) [1975985]
- driver core: Move the "removable" attribute from USB to core (Torez Smith) [1975985]
- usb: dwc3: trace: Remove unused fields in dwc3_log_trb (Torez Smith) [1975985]
- usb: typec: mux: Remove requirement for the "orientation-switch" device property (Torez Smith) [1975985]
- usb: typec: mux: Use device type instead of device name for matching (Torez Smith) [1975985]
- usb: common: usb-conn-gpio: use usb_role_string() to print role status (Torez Smith) [1975985]
- usb: roles: add helper usb_role_string() (Torez Smith) [1975985]
- USB: serial: omninet: update driver description (Torez Smith) [1975985]
- USB: serial: omninet: add device id for Zyxel Omni 56K Plus (Torez Smith) [1975985]
- USB: serial: quatech2: fix control-request directions (Torez Smith) [1975985]
- usb: typec: tcpci: Make symbol 'tcpci_apply_rc' static (Torez Smith) [1975985]
- USB: usbfs: remove double evaluation of usb_sndctrlpipe() (Torez Smith) [1975985]
- usb: typec: tcpm: Respond Not_Supported if no snk_vdo (Torez Smith) [1975985]
- usb: typec: tcpm: Properly interrupt VDM AMS (Torez Smith) [1975985]
- media: lmedm04: delete lme2510_get_adapter_count() (Torez Smith) [1975985]
- media: dvb-usb: fix wrong definition (Torez Smith) [1975985]
- USB: core: WARN if pipe direction != setup packet direction (Torez Smith) [1975985]
- USB: trancevibrator: fix control-request direction (Torez Smith) [1975985]
- USB: dwc2: drop irq-flags initialisations (Torez Smith) [1975985]
- usb: typec: tcpci: Implement callback for apply_rc (Torez Smith) [1975985]
- usb: typec: tcpm: Move TCPC to APPLY_RC state during PR_SWAP (Torez Smith) [1975985]
- usb: typec: tcpm: Refactor logic to enable/disable auto vbus dicharge (Torez Smith) [1975985]
- usb: typec: tcpm: Fix up PR_SWAP when vsafe0v is signalled (Torez Smith) [1975985]
- usb: atm: cxacru: Fix typo in comment (Torez Smith) [1975985]
- usb: isp1760: remove platform data struct and code (Torez Smith) [1975985]
- usb: fix spelling mistakes in header files (Torez Smith) [1975985]
- USB: serial: digi_acceleport: add chars_in_buffer locking (Torez Smith) [1975985]
- USB: serial: digi_acceleport: reduce chars_in_buffer over-reporting (Torez Smith) [1975985]
- usb: Restore the usb_header label (Torez Smith) [1975985]
- usb: typec: tcpm: Use LE to CPU conversion when accessing msg->header (Torez Smith) [1975985]
- usb: typec: mux: Fix matching with typec_altmode_desc (Torez Smith) [1975985]
- misc/uss720: fix memory leak in uss720_probe (Torez Smith) [1975985]
- usb: dwc3: gadget: Properly track pending and queued SG (Torez Smith) [1975985]
- USB: usbfs: Don't WARN about excessively large memory allocations (Torez Smith) [1975985]
- usb: common: usb-conn-gpio: use dev_err_probe() to print log (Torez Smith) [1975985]
- usb: common: usb-conn-gpio: fix NULL pointer dereference of charger (Torez Smith) [1975985]
- Revert "USB: Add reset-resume quirk for WD19's Realtek Hub" (Torez Smith) [1975985]
- USB: Verify the port status when timeout happens during port suspend (Torez Smith) [1975985]
- usb: typec: wcove: Fx wrong kernel doc format (Torez Smith) [1975985]
- media: pvrusb2: fix warning in pvr2_i2c_core_done (Torez Smith) [1975985]
- media: rtl2832_sdr/vivid/airspy/hackrf/msi2500: drop memset of fmt.sdr.reserved (Torez Smith) [1975985]
- media: cpia2: fix memory leak in cpia2_usb_probe (Torez Smith) [1975985]
- media: s2255drv: remove redundant assignment to variable field (Torez Smith) [1975985]
- media: gspca: properly check for errors in po1030_probe() (Torez Smith) [1975985]
- Revert "media: gspca: Check the return value of write_bridge for timeout" (Torez Smith) [1975985]
- media: gspca: mt9m111: Check write_bridge for timeout (Torez Smith) [1975985]
- Revert "media: gspca: mt9m111: Check write_bridge for timeout" (Torez Smith) [1975985]
- Revert "media: usb: gspca: add a missed check for goto_low_power" (Torez Smith) [1975985]
- usb: core: hcd: use map_urb_for_dma for single step set feature urb (Torez Smith) [1975985]
- usb: dwc3: pci: Fix DEFINE for Intel Elkhart Lake (Torez Smith) [1975985]
- usb: core: hub: fix race condition about TRSMRCY of resume (Torez Smith) [1975985]
- usb: typec: tcpm: Fix SINK_DISCOVERY current limit for Rp-default (Torez Smith) [1975985]
- xhci: Add reset resume quirk for AMD xhci controller. (Torez Smith) [1975985]
- usb: xhci: Increase timeout for HC halt (Torez Smith) [1975985]
- xhci: Do not use GFP_KERNEL in (potentially) atomic context (Torez Smith) [1975985]
- xhci: Fix giving back cancelled URBs even if halted endpoint can't reset (Torez Smith) [1975985]
- xhci-pci: Allow host runtime PM as default for Intel Alder Lake xHCI (Torez Smith) [1975985]
- usb: typec: tcpm: Don't block probing of consumers of "connector" nodes (Torez Smith) [1975985]
- usb: xhci-mtk: use first-fit for LS/FS (Torez Smith) [1975985]
- usb: xhci-mtk: remove unnecessary assignments in periodic TT scheduler (Torez Smith) [1975985]
- usb: xhci-mtk: remove unnecessary setting of has_ippc (Torez Smith) [1975985]
- usb: xhci-mtk: use bitfield instead of bool (Torez Smith) [1975985]
- usb: typec: tcpm: Fix wrong handling for Not_Supported in VDM AMS (Torez Smith) [1975985]
- usb: typec: tcpm: Send DISCOVER_IDENTITY from dedicated work (Torez Smith) [1975985]
- usb: typec: ucsi: Retrieve all the PDOs instead of just the first 4 (Torez Smith) [1975985]
- usb: dwc3: omap: improve extcon initialization (Torez Smith) [1975985]
- usb: typec: ucsi: Put fwnode in any case during ->probe() (Torez Smith) [1975985]
- usb: dwc2: Remove obsolete MODULE_ constants from platform.c (Torez Smith) [1975985]
- usb: dwc3: imx8mp: fix error return code in dwc3_imx8mp_probe() (Torez Smith) [1975985]
- usb: dwc3: imx8mp: detect dwc3 core node via compatible string (Torez Smith) [1975985]
- usb: dwc3: gadget: Return success always for kick transfer in ep queue (Torez Smith) [1975985]
- usb: dwc3: gadget: Free gadget structure only after freeing endpoints (Torez Smith) [1975985]
- usb: dwc2: Fix gadget DMA unmap direction (Torez Smith) [1975985]
- usb: dwc3: gadget: Rename EOPF event macros to Suspend (Torez Smith) [1975985]
- usb: dwc3: gadget: Enable suspend events (Torez Smith) [1975985]
- usb: Restore the reference to ch9.h (Torez Smith) [1975985]
- usb: dwc3: core: Add missing GHWPARAMS9 doc (Torez Smith) [1975985]
- usb: dwc3: pci: Enable usb2-gadget-lpm-disable for Intel Merrifield (Torez Smith) [1975985]
- cdc-wdm: untangle a circular dependency between callback and softint (Torez Smith) [1975985]
- usb: dwc3: remove repeated setting of current_dr_role (Torez Smith) [1975985]
- USB: serial: pl2303: add device id for ADLINK ND-6530 GC (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: add startech.com device id (Torez Smith) [1975985]
- USB: serial: option: add Telit LE910-S1 compositions 0x7010, 0x7011 (Torez Smith) [1975985]
- USB: serial: ftdi_sio: add IDs for IDS GmbH Products (Torez Smith) [1975985]
- usb: Fix up movement of USB core kerneldoc location (Torez Smith) [1975985]
- usb: dwc3: gadget: Handle DEV_TXF_FLUSH_BYPASS capability (Torez Smith) [1975985]
- usb: dwc3: Capture new capability register GHWPARAMS9 (Torez Smith) [1975985]
- usb: dwc3: core: Do core softreset when switch mode (Torez Smith) [1975985]
- usb: dwc2: Get rid of useless error checks in suspend interrupt (Torez Smith) [1975985]
- usb: dwc2: Update dwc2_handle_usb_suspend_intr function. (Torez Smith) [1975985]
- usb: dwc2: Add exit hibernation mode before removing drive (Torez Smith) [1975985]
- usb: dwc2: Add hibernation exiting flow by system resume (Torez Smith) [1975985]
- usb: dwc2: Add hibernation entering flow by system suspend (Torez Smith) [1975985]
- usb: dwc2: Allow exit hibernation in urb enqueue (Torez Smith) [1975985]
- usb: dwc2: Move exit hibernation to dwc2_port_resume() function (Torez Smith) [1975985]
- usb: dwc2: Move enter hibernation to dwc2_port_suspend() function (Torez Smith) [1975985]
- usb: dwc2: Clear GINTSTS_RESTOREDONE bit after restore is generated. (Torez Smith) [1975985]
- usb: dwc2: Clear fifo_map when resetting core. (Torez Smith) [1975985]
- usb: dwc2: Allow exiting hibernation from gpwrdn rst detect (Torez Smith) [1975985]
- usb: dwc2: Fix hibernation between host and device modes. (Torez Smith) [1975985]
- usb: dwc2: Fix host mode hibernation exit with remote wakeup flow. (Torez Smith) [1975985]
- usb: dwc2: Reset DEVADDR after exiting gadget hibernation. (Torez Smith) [1975985]
- usb: dwc2: Update exit hibernation when port reset is asserted (Torez Smith) [1975985]
- usb: dwc3: gadget: Remove FS bInterval_m1 limitation (Torez Smith) [1975985]
- usb: xhci-mtk: remove bus status check (Torez Smith) [1975985]
- usb: dwc2: Enable RPi in ACPI mode (Torez Smith) [1975985]
- USB: Add reset-resume quirk for WD19's Realtek Hub (Torez Smith) [1975985]
- usb: storage: datafab: remove redundant assignment of variable result (Torez Smith) [1975985]
- usb: misc: adutux: fix whitespace coding style issue (Torez Smith) [1975985]
- usb: dwc3: gadget: Fix START_TRANSFER link state check (Torez Smith) [1975985]
- usb: typec: tcpm: Fix error while calculating PPS out values (Torez Smith) [1975985]
- usb: xhci-mtk: remove unused members (Torez Smith) [1975985]
- usb: xhci-mtk: use clock bulk to get clocks (Torez Smith) [1975985]
- usb: xhci-mtk: add support runtime PM (Torez Smith) [1975985]
- usb: xhci-mtk: check return value in suspend/resume hooks (Torez Smith) [1975985]
- usb: typec: tcpm: Allow slow charging loops to comply to pSnkStby (Torez Smith) [1975985]
- usb: typec: tcpm: Honour pSnkStdby requirement during negotiation (Torez Smith) [1975985]
- usb: dwc3: gadget: Check for disabled LPM quirk (Torez Smith) [1975985]
- usb: dwc3: core: Add shutdown callback for dwc3 (Torez Smith) [1975985]
- usb: dwc3: gadget: Ignore Packet Pending bit (Torez Smith) [1975985]
- USB: Add LPM quirk for Lenovo ThinkPad USB-C Dock Gen2 Ethernet (Torez Smith) [1975985]
- usb: typec: silence a static checker warning (Torez Smith) [1975985]
- USB: cdc-acm: add more Maxlinear/Exar models to ignore list (Torez Smith) [1975985]
- USB: serial: xr: add copyright notice (Torez Smith) [1975985]
- USB: serial: xr: reset FIFOs on open (Torez Smith) [1975985]
- USB: serial: xr: add support for XR22801, XR22802, XR22804 (Torez Smith) [1975985]
- USB: serial: xr: add support for XR21B1411 (Torez Smith) [1975985]
- USB: serial: xr: add support for XR21B1421, XR21B1422 and XR21B1424 (Torez Smith) [1975985]
- USB: serial: xr: add type abstraction (Torez Smith) [1975985]
- USB: serial: xr: drop type prefix from shared defines (Torez Smith) [1975985]
- USB: serial: xr: move pin configuration to probe (Torez Smith) [1975985]
- USB: serial: xr: rename GPIO-pin defines (Torez Smith) [1975985]
- USB: serial: xr: rename GPIO-mode defines (Torez Smith) [1975985]
- USB: serial: xr: add support for XR21V1412 and XR21V1414 (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: clean up termios CSIZE handling (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: use kernel types consistently (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: add port-command helpers (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: clean up vendor-request helpers (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: drop unnecessary packed attributes (Torez Smith) [1975985]
- USB: serial: io_ti: drop unnecessary packed attributes (Torez Smith) [1975985]
- USB: serial: io_ti: use kernel types consistently (Torez Smith) [1975985]
- USB: serial: io_ti: add read-port-command helper (Torez Smith) [1975985]
- USB: serial: io_ti: add send-port-command helper (Torez Smith) [1975985]
- USB: serial: io_ti: clean up vendor-request helpers (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: drop drain delay for 3410 (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: reduce drain delay to one char (Torez Smith) [1975985]
- USB: serial: io_ti: document reason for drain delay (Torez Smith) [1975985]
- usb: dwc2: Add exit clock gating before removing driver (Torez Smith) [1975985]
- usb: dwc2: Add clock gating exiting flow by system resume (Torez Smith) [1975985]
- usb: dwc2: Add clock gating entering flow by system suspend (Torez Smith) [1975985]
- usb: dwc2: Allow exit clock gating in urb enqueue (Torez Smith) [1975985]
- usb: dwc2: Update exit clock gating when port is resumed (Torez Smith) [1975985]
- usb: dwc2: Update enter clock gating when port is suspended (Torez Smith) [1975985]
- usb: dwc2: Add exit clock gating when port reset is asserted (Torez Smith) [1975985]
- usb: dwc2: Add exit clock gating from session request interrupt (Torez Smith) [1975985]
- usb: dwc2: Add exit clock gating from wakeup interrupt (Torez Smith) [1975985]
- usb: dwc2: Allow entering clock gating from USB_SUSPEND interrupt (Torez Smith) [1975985]
- usb: dwc2: Add host clock gating support functions (Torez Smith) [1975985]
- usb: dwc2: Add device clock gating support functions (Torez Smith) [1975985]
- Revert "usb: Link the ports to the connectors they are attached to" (Torez Smith) [1975985]
- USB: serial: cp210x: add gpio-configuration debug printk (Torez Smith) [1975985]
- USB: serial: cp210x: provide gpio valid mask (Torez Smith) [1975985]
- usb: dwc3: qcom: Detect DWC3 DT-nodes using compatible string (Torez Smith) [1975985]
- usb: dwc3: qcom: Remove redundant dev_err call in dwc3_qcom_probe() (Torez Smith) [1975985]
- usb: core: reduce power-on-good delay time of root hub (Torez Smith) [1975985]
- USB:ehci:fix Kunpeng920 ehci hardware problem (Torez Smith) [1975985]
- USB: serial: do not use tty class device for debugging (Torez Smith) [1975985]
- USB: cdc-acm: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: cdc-acm: fix unprivileged TIOCCSERIAL (Torez Smith) [1975985]
- Revert "USB: cdc-acm: fix rounding error in TIOCSSERIAL" (Torez Smith) [1975985]
- usb: typec: tcpm: Add support for altmodes (Torez Smith) [1975985]
- usb: typec: Add typec_port_register_altmodes() (Torez Smith) [1975985]
- usb: roles: Call try_module_get() from usb_role_switch_find_by_fwnode() (Torez Smith) [1975985]
- usb: dwc3: xilinx: Remove the extra freeing of clocks (Torez Smith) [1975985]
- usb: dwc3: Resolve kernel-doc warning for Xilinx DWC3 driver (Torez Smith) [1975985]
- usb: core: hub: Fix PM reference leak in usb_port_resume() (Torez Smith) [1975985]
- usb: dwc3: pci: add support for the Intel Alder Lake-M (Torez Smith) [1975985]
- usb: typec: Link all ports during connector registration (Torez Smith) [1975985]
- usb: Iterator for ports (Torez Smith) [1975985]
- usb: Link the ports to the connectors they are attached to (Torez Smith) [1975985]
- usb: typec: Port mapping utility (Torez Smith) [1975985]
- usb: typec: tcpm: update power supply once partner accepts (Torez Smith) [1975985]
- usb: typec: tcpm: Address incorrect values of tcpm psy for pps supply (Torez Smith) [1975985]
- usb: typec: tcpm: Address incorrect values of tcpm psy for fixed supply (Torez Smith) [1975985]
- usb: dwc2: Add exit partial power down before removing driver (Torez Smith) [1975985]
- usb: dwc2: Fix partial power down exiting by system resume (Torez Smith) [1975985]
- usb: dwc2: Update partial power down entering by system suspend (Torez Smith) [1975985]
- usb: dwc2: Fix session request interrupt handler (Torez Smith) [1975985]
- usb: dwc2: Allow exit partial power down in urb enqueue (Torez Smith) [1975985]
- usb: dwc2: Add part. power down exit from dwc2_conn_id_status_change(). (Torez Smith) [1975985]
- usb: dwc2: Add exit partial power down when port reset is asserted (Torez Smith) [1975985]
- usb: dwc2: Add exit partial power down when port is resumed (Torez Smith) [1975985]
- usb: dwc2: Add enter partial power down when port is suspended (Torez Smith) [1975985]
- usb: dwc2: Update port suspend/resume function definitions. (Torez Smith) [1975985]
- usb: dwc2: Add partial power down exit flow in wakeup intr. (Torez Smith) [1975985]
- usb: dwc2: Update enter and exit partial power down functions (Torez Smith) [1975985]
- usb: dwc2: Add host partial power down functions (Torez Smith) [1975985]
- usb: dwc2: Add device partial power down functions (Torez Smith) [1975985]
- media: gscpa/stv06xx: fix memory leak (Torez Smith) [1975985]
- media: gspca: Fix memory leak in probe (Torez Smith) [1975985]
- media: dvb-usb: avoid -Wempty-body warnings (Torez Smith) [1975985]
- media: flexcop: avoid -Wempty-body warning (Torez Smith) [1975985]
- media: dvb-usb: fix memory leak in dvb_usb_adapter_init (Torez Smith) [1975985]
- media: dvb-usb-remote: fix dvb_usb_nec_rc_key_to_event type mismatch (Torez Smith) [1975985]
- thunderbolt: Add details to router uevent (Torez Smith) [1975985]
- USB: serial: io_edgeport: drop unused definitions (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: switch to 30-second closing wait (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: drop closing_wait module parameter (Torez Smith) [1975985]
- USB: serial: io_ti: switch to 30-second closing wait (Torez Smith) [1975985]
- USB: serial: io_ti: drop closing_wait module parameter (Torez Smith) [1975985]
- USB: serial: ftdi_sio: clean up TIOCSSERIAL (Torez Smith) [1975985]
- USB: serial: ftdi_sio: simplify TIOCGSERIAL permission check (Torez Smith) [1975985]
- USB: serial: ftdi_sio: ignore baud_base changes (Torez Smith) [1975985]
- USB: serial: stop reporting legacy UART types (Torez Smith) [1975985]
- USB: serial: add generic support for TIOCSSERIAL (Torez Smith) [1975985]
- USB: serial: fix return value for unsupported ioctls (Torez Smith) [1975985]
- USB: serial: whiteheat: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: usb_wwan: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: usb_wwan: fix unprivileged TIOCCSERIAL (Torez Smith) [1975985]
- USB: serial: usb_wwan: fix TIOCSSERIAL jiffies conversions (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: fix TIOCSSERIAL permission check (Torez Smith) [1975985]
- USB: serial: ti_usb_3410_5052: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: ssu100: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: quatech2: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: pl2303: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: opticon: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: mos7840: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: mos7720: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: io_ti: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: io_edgeport: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: ftdi_sio: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- USB: serial: ark3116: fix TIOCGSERIAL implementation (Torez Smith) [1975985]
- media: em28xx/em28xx.h: Remove duplicate struct declaration (Torez Smith) [1975985]
- media: cx231xx/cx231xx.h: Remove repeated struct declaration (Torez Smith) [1975985]
- xhci: prevent double-fetch of transfer and transfer event TRBs (Torez Smith) [1975985]
- xhci: fix potential array out of bounds with several interrupters (Torez Smith) [1975985]
- xhci: check control context is valid before dereferencing it. (Torez Smith) [1975985]
- xhci: check port array allocation was successful before dereferencing it (Torez Smith) [1975985]
- media: em28xx: fix memory leak (Torez Smith) [1975985]
- usb: typec: Declare the typec_class static (Torez Smith) [1975985]
- usb: typec: Organize the private headers properly (Torez Smith) [1975985]
- usb: xhci-mtk: support quirk to disable usb2 lpm (Torez Smith) [1975985]
- usb: xhci-mtk: fix oops when unbind driver (Torez Smith) [1975985]
- usb: xhci-mtk: fix wrong remainder of bandwidth budget (Torez Smith) [1975985]
- usb: dwc2: delete duplicate word in the comment (Torez Smith) [1975985]
- usb: dwc2: add parenthess and space around * (Torez Smith) [1975985]
- usb: dwc3: add cancelled reasons for dwc3 requests (Torez Smith) [1975985]
- usb: dwc3: fix incorrect kernel-doc comment syntax in files (Torez Smith) [1975985]
- usb: dwc3: st: fix incorrect kernel-doc comment syntax in file (Torez Smith) [1975985]
- usb: dwc3: imx8mp: fix incorrect kernel-doc comment syntax (Torez Smith) [1975985]
- USB: serial: xr: claim both interfaces (Torez Smith) [1975985]
- USB: serial: add support for multi-interface functions (Torez Smith) [1975985]
- USB: serial: refactor endpoint classification (Torez Smith) [1975985]
- USB: serial: drop unused suspending flag (Torez Smith) [1975985]
- USB: serial: xr: fix CSIZE handling (Torez Smith) [1975985]
- USB: serial: iuu_phoenix: remove redundant variable 'error' (Torez Smith) [1975985]
- usb: dwc3: Create helper function getting MDWIDTH (Torez Smith) [1975985]
- usb: xhci-mtk: remove MODULE_ALIAS (Torez Smith) [1975985]
- usb: xhci-mtk: drop CONFIG_OF (Torez Smith) [1975985]
- usb: misc: usbsevseg: update to use usb_control_msg_send() (Torez Smith) [1975985]
- usb: misc: ezusb: update to use usb_control_msg_send() (Torez Smith) [1975985]
- usb: dwc3: gadget: modify the scale in vbus_draw callback (Torez Smith) [1975985]
- usb: xhci-mtk: add support ip-sleep wakeup for mT8192 (Torez Smith) [1975985]
- usb: xhci-mtk: support ip-sleep wakeup for MT8183 (Torez Smith) [1975985]
- usb: dwc3: trace: Print register read and write offset (Torez Smith) [1975985]
- usb: typec: tcpci_maxim: Make symbol 'max_tcpci_tcpci_write_table' static (Torez Smith) [1975985]
- usbip: tools: add usage of device mode in usbip_list.c (Torez Smith) [1975985]
- usbip: tools: add options and examples in man page related to device mode (Torez Smith) [1975985]
- tools: usbip: list.h: fix kernel-doc for list_del() (Torez Smith) [1975985]
- xhci: Fix uninitialized errors (Torez Smith) [1975985]
- usb: typec: Fix a typo (Torez Smith) [1975985]
- usb: xhci: Remove unused function (Torez Smith) [1975985]
- usb: xhci: Rewrite xhci_create_usb3_bos_desc() (Torez Smith) [1975985]
- usb: xhci: Fix port minor revision (Torez Smith) [1975985]
- usb: xhci: Init root hub SSP rate (Torez Smith) [1975985]
- thunderbolt: Unlock on error path in tb_domain_add() (Torez Smith) [1975985]
- usb: core: sysfs: Check for SSP rate in speed attr (Torez Smith) [1975985]
- usb: core: hub: Print speed name based on ssp rate (Torez Smith) [1975985]
- usb: core: hub: Remove port_speed_is_ssp() (Torez Smith) [1975985]
- usb: core: Track SuperSpeed Plus GenXxY (Torez Smith) [1975985]
- usb: dwc3: gadget: Avoid continuing preparing TRBs during teardown (Torez Smith) [1975985]
- USB: xhci: drop workaround for forced irq threading (Torez Smith) [1975985]
- usb: dwc3: Add driver for Xilinx platforms (Torez Smith) [1975985]
- USB: core: rename usb_driver_claim_interface() data parameter (Torez Smith) [1975985]
- USB: core: drop outdated interface-binding comment (Torez Smith) [1975985]
- media: media/usb: fix kernel-doc header issues (Torez Smith) [1975985]
- media: gspca/sq905.c: fix uninitialized variable (Torez Smith) [1975985]
- media: media/usb/gspca/w996Xcf.c: /** -> /* (Torez Smith) [1975985]
- media: flexcop-usb: delete unneeded return (Torez Smith) [1975985]
- thunderbolt: Add KUnit tests for DMA tunnels (Torez Smith) [1975985]
- thunderbolt: Add support for USB4 DROM (Torez Smith) [1975985]
- thunderbolt: Check quirks in tb_switch_add() (Torez Smith) [1975985]
- thunderbolt: Add KUnit tests for XDomain properties (Torez Smith) [1975985]
- thunderbolt: Drop unused tb_port_set_initial_credits() (Torez Smith) [1975985]
- thunderbolt: Use dedicated flow control for DMA tunnels (Torez Smith) [1975985]
- thunderbolt: Allow multiple DMA tunnels over a single XDomain connection (Torez Smith) [1975985]
- thunderbolt: Add support for maxhopid XDomain property (Torez Smith) [1975985]
- thunderbolt: Add tb_property_copy_dir() (Torez Smith) [1975985]
- thunderbolt: Align XDomain protocol timeouts with the spec (Torez Smith) [1975985]
- thunderbolt: Use pseudo-random number as initial property block generation (Torez Smith) [1975985]
- thunderbolt: Do not re-establish XDomain DMA paths automatically (Torez Smith) [1975985]
- thunderbolt: Decrease control channel timeout for software connection manager (Torez Smith) [1975985]
- thunderbolt: Disable retry logic for intra-domain control packets (Torez Smith) [1975985]
- thunderbolt: Do not pass timeout for tb_cfg_reset() (Torez Smith) [1975985]
- thunderbolt: Add more logging to XDomain connections (Torez Smith) [1975985]
- usb: typec: tcpm: PD3.0 sinks can send Discover Identity even in device mode (Torez Smith) [1975985]
- drivers: usb: Fix a typo in dwc3-qcom.c (Torez Smith) [1975985]
- usb: webcam: Invalid size of Processing Unit Descriptor (Torez Smith) [1975985]
- usb: typec: tcpci: Added few missing TCPCI register definitions (Torez Smith) [1975985]
- USB: serial: pl2303: TA & TB alternate divider with non-standard baud rates (Torez Smith) [1975985]
- USB: serial: pl2303: add device-type names (Torez Smith) [1975985]
- USB: serial: pl2303: tighten type HXN (G) detection (Torez Smith) [1975985]
- USB: serial: pl2303: rename legacy PL2303H type (Torez Smith) [1975985]
- USB: serial: pl2303: amend and tighten type detection (Torez Smith) [1975985]
- USB: serial: pl2303: clean up type detection (Torez Smith) [1975985]
- USB: serial: io_edgeport: drop unneeded forward declarations (Torez Smith) [1975985]
- USB: serial: keyspan: drop unneeded forward declarations (Torez Smith) [1975985]
- usb: typec: tipd: Separate file for tracepoint creation (Torez Smith) [1975985]
- usb: typec: tps6598x: Move the driver under its own subdirectory (Torez Smith) [1975985]
- usb: typec: tps6598x: Fix tracepoint header file (Torez Smith) [1975985]
- usb: typec: tcpci: Refactor tcpc_presenting_cc1_rd macro (Torez Smith) [1975985]
- thunderbolt: debugfs: Show all accessible dwords (Torez Smith) [1975985]
- media: fix incorrect kernel doc usages (Torez Smith) [1975985]
- media: drivers/media/usb: fix memory leak in zr364xx_probe (Torez Smith) [1975985]
- media: anysee: simplify the return expression of anysee_ci_* function (Torez Smith) [1975985]
- media: media/usb:Remove superfluous "breaks" in the ttusb_dec.c (Torez Smith) [1975985]
- media: media/usb:Remove superfluous "breaks" (Torez Smith) [1975985]
- media: usbtv: constify static structs (Torez Smith) [1975985]
- media: em28xx: Add pid for bulk revision of Hauppauge 461eV2 (Torez Smith) [1975985]
- media: em28xx: Add pid for bulk revision of Hauppauge 461e (Torez Smith) [1975985]
- media: dvb-usb: Fix use-after-free access (Torez Smith) [1975985]
- media: dvb-usb: Fix memory leak at error in dvb_usb_device_init() (Torez Smith) [1975985]
- media: dvb-usb: make dvb_usb_device_properties const (Torez Smith) [1975985]
- usb: typec: tps6598x: Fix return value check in tps6598x_probe() (Torez Smith) [1975985]
- usb: typec: stusb160x: fix return value check in stusb160x_probe() (Torez Smith) [1975985]
- usb: typec: tcpm: turn tcpm_ams_finish into void function (Torez Smith) [1975985]
- usb: typec: tcpci: Check ROLE_CONTROL while interpreting CC_STATUS (Torez Smith) [1975985]
- usb: common: move function's kerneldoc next to its definition (Torez Smith) [1975985]
- usb: xhci-mtk: print debug info of endpoint interval (Torez Smith) [1975985]
- usb: common: add function to get interval expressed in us unit (Torez Smith) [1975985]
- usb: xhci-mtk: support to build xhci-mtk-hcd.ko (Torez Smith) [1975985]
- usb: xhci-mtk: remove declaration of xhci_mtk_setup() (Torez Smith) [1975985]
- usb: xhci-mtk: add some schedule error number (Torez Smith) [1975985]
- usb: xhci-mtk: rebuild the way to get bandwidth domain (Torez Smith) [1975985]
- usb: xhci-mtk: use @tt_info to check the FS/LS device is under a HS hub (Torez Smith) [1975985]
- usb: xhci-mtk: add a member @speed in mu3h_sch_ep_info struct (Torez Smith) [1975985]
- usb: xhci-mtk: use clear type instead of void (Torez Smith) [1975985]
- usb: xhci-mtk: remove unnecessary members of mu3h_sch_tt struct (Torez Smith) [1975985]
- usb: xhci-mtk: add a function to get bandwidth boundary (Torez Smith) [1975985]
- usb: xhci-mtk: add a function to (un)load bandwidth info (Torez Smith) [1975985]
- usb: xhci-mtk: use @sch_tt to check whether need do TT schedule (Torez Smith) [1975985]
- usb: xhci-mtk: add only one extra CS for FS/LS INTR (Torez Smith) [1975985]
- usb: xhci-mtk: get the microframe boundary for ESIT (Torez Smith) [1975985]
- usb: dwc3: Fix dereferencing of null dwc->usb_psy (Torez Smith) [1975985]
- media: uvc: don't do DMA on stack (Torez Smith) [1975985]
- usb: dwc3: document usb_psy in struct dwc3 (Torez Smith) [1975985]
- media: uvcvideo: Fix pixel format change for Elgato Cam Link 4K (Torez Smith) [1975985]
- USB: typec: tcpm: create debugfs subdir for the driver (Torez Smith) [1975985]
- usb: dwc2: Add STM32 related debugfs entries (Torez Smith) [1975985]
- media: uvcvideo: Support devices that report an OT as an entity source (Torez Smith) [1975985]
- media: uvcvideo: Fix XU id print in forward scan (Torez Smith) [1975985]
- USB: typec: fusb302: create debugfs subdir for the driver (Torez Smith) [1975985]
- media: uvcvideo: Use dma_alloc_noncontiguous API (Torez Smith) [1975985]
- USB: host: uhci: remove dentry pointer for debugfs (Torez Smith) [1975985]
- media: uvc: strncpy -> strscpy (Torez Smith) [1975985]
- media: uvcvideo: Rename debug functions (Torez Smith) [1975985]
- media: uvcvideo: use dev_printk() for uvc_trace() (Torez Smith) [1975985]
- media: uvcvideo: New macro uvc_trace_cont (Torez Smith) [1975985]
- USB: core: no need to save usb_devices_root (Torez Smith) [1975985]
- media: uvcvideo: Use dev_ printk aliases (Torez Smith) [1975985]
- usb: dwc3: add an alternate path in vbus_draw callback (Torez Smith) [1975985]
- media: uvcvideo: Add Privacy control based on EXT_GPIO (Torez Smith) [1975985]
- usb: dwc3: add a power supply for current control (Torez Smith) [1975985]
- media: uvcvideo: Implement UVC_EXT_GPIO_UNIT (Torez Smith) [1975985]
- usb: typec: tps6598x: Add trace event for data status (Torez Smith) [1975985]
- media: uvcvideo: Allow entity-defined get_info and get_cur (Torez Smith) [1975985]
- media: uvcvideo: Provide sync and async uvc_ctrl_status_event (Torez Smith) [1975985]
- usb: typec: tps6598x: Add trace event for power status register (Torez Smith) [1975985]
- media: uvcvideo: Allow entities with no pads (Torez Smith) [1975985]
- usb: typec: tps6598x: Add trace event for status register (Torez Smith) [1975985]
- media: uvcvideo: Allow extra entities (Torez Smith) [1975985]
- usb: typec: tps6598x: Add trace event for IRQ events (Torez Smith) [1975985]
- tty: make everyone's write_room return >= 0 (Torez Smith) [1975985]
- media: uvcvideo: Move guid to entity (Torez Smith) [1975985]
- USB: serial: xr: fix NULL-deref on disconnect (Torez Smith) [1975985]
- media: uvcvideo: Accept invalid bFormatIndex and bFrameIndex values (Torez Smith) [1975985]
- thunderbolt: Drop unused functions tb_switch_is_[ice|tiger]_lake() (Torez Smith) [1975985]
- media: uvcvideo: Force UVC version to 1.0a for 1bcf:0b40 (Torez Smith) [1975985]
- thunderbolt: debugfs: Handle fail reading block (Torez Smith) [1975985]
- media: uvcvideo: Use DIV_ROUND_CLOSEST directly to make it readable (Torez Smith) [1975985]
- media: usb: uvc: no need to check return value of debugfs_create functions (Torez Smith) [1975985]
- media: uvcvideo: Convey full colorspace information to V4L2 (Torez Smith) [1975985]
- driver core: fw_devlink: Detect supplier devices that will never be added (Torez Smith) [1975985]
- media: uvcvideo: Ensure all probed info is returned to v4l2 (Torez Smith) [1975985]
- media: uvcvideo: Silence shift-out-of-bounds warning (Torez Smith) [1975985]
- media: uvcvideo: Fix dereference of out-of-bound list iterator (Torez Smith) [1975985]
- media: zr364xx: fix memory leaks in probe() (Torez Smith) [1975985]
- media: uvcvideo: Cleanup uvc_ctrl_add_info() error handling (Torez Smith) [1975985]
- USB: serial: xr: fix B0 handling (Torez Smith) [1975985]
- media: uvcvideo: Fix uvc_ctrl_fixup_xu_info() not having any effect (Torez Smith) [1975985]
- USB: serial: xr: fix pin configuration (Torez Smith) [1975985]
- media: uvcvideo: Replace HTTP links with HTTPS ones (Torez Smith) [1975985]
- USB: serial: xr: fix gpio-mode handling (Torez Smith) [1975985]
- media: uvcvideo: Set media controller entity functions (Torez Smith) [1975985]
- USB: serial: xr: simplify line-speed logic (Torez Smith) [1975985]
- media: uvcvideo: Add mapping for HEVC payloads (Torez Smith) [1975985]
- USB: serial: xr: clean up line-settings handling (Torez Smith) [1975985]
- media: uvcvideo: Fix annotation for uvc_video_clock_update() (Torez Smith) [1975985]
- USB: serial: xr: document vendor-request recipient (Torez Smith) [1975985]
- USB: serial: xr: use termios flag helpers (Torez Smith) [1975985]
- USB: serial: xr: use subsystem usb_device at probe (Torez Smith) [1975985]
- media: media/usb: rename VFL_TYPE_GRABBER to _VIDEO (Torez Smith) [1975985]
- USB: serial: xr: fix interface leak at disconnect (Torez Smith) [1975985]
- media: rename VFL_TYPE_GRABBER to _VIDEO (Torez Smith) [1975985]
- USB: serial: xr: fix NULL-deref at probe (Torez Smith) [1975985]
- USB: cdc-acm: ignore Exar XR21V141X when serial driver is built (Torez Smith) [1975985]
- media: uvcvideo: drop error check of debugfs_create_dir() (Torez Smith) [1975985]
- USB: serial: add MaxLinear/Exar USB to Serial driver (Torez Smith) [1975985]
- media: uvcvideo: Fix a typo in UVC_METATADA_BUF_SIZE (Torez Smith) [1975985]
- media: uvcvideo: Fix error path in control parsing failure (Torez Smith) [1975985]
- media: drivers/media: don't set pix->priv = 0 (Torez Smith) [1975985]
- media: Bulk remove BUG_ON(in_interrupt()) (Torez Smith) [1975985]
- media: zr364xx: propagate errors from zr364xx_start_readpipe() (Torez Smith) [1975985]
- media: uvcvideo: Add a D4M camera description (Torez Smith) [1975985]
- media: em28xx: Enable Hauppauge 461e rev2 (Torez Smith) [1975985]
- crypto: qat - fix definition of ring reset results (Vladis Dronov) [1960307]
- crypto: qat - add support for compression for 4xxx (Vladis Dronov) [1960307]
- crypto: qat - allow detection of dc capabilities for 4xxx (Vladis Dronov) [1960307]
- crypto: qat - add PFVF support to enable the reset of ring pairs (Vladis Dronov) [1960307]
- crypto: qat - add PFVF support to the GEN4 host driver (Vladis Dronov) [1960307]
- crypto: qat - config VFs based on ring-to-svc mapping (Vladis Dronov) [1960307]
- crypto: qat - exchange ring-to-service mappings over PFVF (Vladis Dronov) [1960307]
- crypto: qat - support fast ACKs in the PFVF protocol (Vladis Dronov) [1960307]
- crypto: qat - exchange device capabilities over PFVF (Vladis Dronov) [1960307]
- crypto: qat - introduce support for PFVF block messages (Vladis Dronov) [1960307]
- crypto: qat - store the ring-to-service mapping (Vladis Dronov) [1960307]
- crypto: qat - store the PFVF protocol version of the endpoints (Vladis Dronov) [1960307]
- crypto: qat - improve the ACK timings in PFVF send (Vladis Dronov) [1960307]
- crypto: qat - leverage read_poll_timeout in PFVF send (Vladis Dronov) [1960307]
- crypto: qat - leverage bitfield.h utils for PFVF messages (Vladis Dronov) [1960307]
- crypto: qat - abstract PFVF messages with struct pfvf_message (Vladis Dronov) [1960307]
- crypto: qat - set PFVF_MSGORIGIN just before sending (Vladis Dronov) [1960307]
- crypto: qat - make PFVF send and receive direction agnostic (Vladis Dronov) [1960307]
- crypto: qat - make PFVF message construction direction agnostic (Vladis Dronov) [1960307]
- crypto: qat - add the adf_get_pmisc_base() helper function (Vladis Dronov) [1960307]
- crypto: qat - support the reset of ring pairs on PF (Vladis Dronov) [1960307]
- crypto: qat - extend crypto capability detection for 4xxx (Vladis Dronov) [1960307]
- crypto: qat - set COMPRESSION capability for QAT GEN2 (Vladis Dronov) [1960307]
- crypto: qat - set CIPHER capability for QAT GEN2 (Vladis Dronov) [1960307]
- crypto: qat - get compression extended capabilities (Vladis Dronov) [1960307]
- crypto: qat - improve logging of PFVF messages (Vladis Dronov) [1960307]
- crypto: qat - fix VF IDs in PFVF log messages (Vladis Dronov) [1960307]
- crypto: qat - do not rely on min version (Vladis Dronov) [1960307]
- crypto: qat - refactor pfvf version request messages (Vladis Dronov) [1960307]
- crypto: qat - pass the PF2VF responses back to the callers (Vladis Dronov) [1960307]
- crypto: qat - use enums for PFVF protocol codes (Vladis Dronov) [1960307]
- crypto: qat - reorganize PFVF protocol definitions (Vladis Dronov) [1960307]
- crypto: qat - reorganize PFVF code (Vladis Dronov) [1960307]
- crypto: qat - abstract PFVF receive logic (Vladis Dronov) [1960307]
- crypto: qat - abstract PFVF send function (Vladis Dronov) [1960307]
- crypto: qat - differentiate between pf2vf and vf2pf offset (Vladis Dronov) [1960307]
- crypto: qat - add pfvf_ops (Vladis Dronov) [1960307]
- crypto: qat - relocate PFVF disabled function (Vladis Dronov) [1960307]
- crypto: qat - relocate PFVF VF related logic (Vladis Dronov) [1960307]
- crypto: qat - relocate PFVF PF related logic (Vladis Dronov) [1960307]
- crypto: qat - handle retries due to collisions in adf_iov_putmsg() (Vladis Dronov) [1960307]
- crypto: qat - split PFVF message decoding from handling (Vladis Dronov) [1960307]
- crypto: qat - re-enable interrupts for legacy PFVF messages (Vladis Dronov) [1960307]
- crypto: qat - change PFVF ACK behaviour (Vladis Dronov) [1960307]
- crypto: qat - move interrupt code out of the PFVF handler (Vladis Dronov) [1960307]
- crypto: qat - move VF message handler to adf_vf2pf_msg.c (Vladis Dronov) [1960307]
- crypto: qat - move vf2pf interrupt helpers (Vladis Dronov) [1960307]
- crypto: qat - refactor PF top half for PFVF (Vladis Dronov) [1960307]
- crypto: qat - fix undetected PFVF timeout in ACK loop (Vladis Dronov) [1960307]
- crypto: qat - do not handle PFVF sources for qat_4xxx (Vladis Dronov) [1960307]
- crypto: qat - simplify adf_enable_aer() (Vladis Dronov) [1960307]
- crypto: qat - share adf_enable_pf2vf_comms() from adf_pf2vf_msg.c (Vladis Dronov) [1960307]
- crypto: qat - extract send and wait from adf_vf2pf_request_version() (Vladis Dronov) [1960307]
- crypto: qat - add VF and PF wrappers to common send function (Vladis Dronov) [1960307]
- crypto: qat - rename pfvf collision constants (Vladis Dronov) [1960307]
- crypto: qat - move pfvf collision detection values (Vladis Dronov) [1960307]
- crypto: qat - make pfvf send message direction agnostic (Vladis Dronov) [1960307]
- crypto: qat - use hweight for bit counting (Vladis Dronov) [1960307]
- crypto: qat - remove duplicated logic across GEN2 drivers (Vladis Dronov) [1960307]
- crypto: qat - fix handling of VF to PF interrupts (Vladis Dronov) [1960307]
- crypto: qat - remove unnecessary collision prevention step in PFVF (Vladis Dronov) [1960307]
- crypto: qat - disregard spurious PFVF interrupts (Vladis Dronov) [1960307]
- crypto: qat - detect PFVF collision after ACK (Vladis Dronov) [1960307]
- crypto: qat - power up 4xxx device (Vladis Dronov) [1960307]
- crypto: qat - remove unneeded packed attribute (Vladis Dronov) [1960307]
- crypto: qat - free irq in case of failure (Vladis Dronov) [1960307]
- crypto: qat - free irqs only if allocated (Vladis Dronov) [1960307]
- crypto: qat - remove unmatched CPU affinity to cluster IRQ (Vladis Dronov) [1960307]
- crypto: qat - replace deprecated MSI API (Vladis Dronov) [1960307]
- crypto: qat - store vf.compatible flag (Vladis Dronov) [1960307]
- crypto: qat - do not export adf_iov_putmsg() (Vladis Dronov) [1960307]
- crypto: qat - flush vf workqueue at driver removal (Vladis Dronov) [1960307]
- crypto: qat - remove the unnecessary get_vintmsk_offset() (Vladis Dronov) [1960307]
- crypto: qat - fix naming of PF/VF enable functions (Vladis Dronov) [1960307]
- crypto: qat - complete all the init steps before service notification (Vladis Dronov) [1960307]
- crypto: qat - move IO virtualization functions (Vladis Dronov) [1960307]
- crypto: qat - fix naming for init/shutdown VF to PF notifications (Vladis Dronov) [1960307]
- crypto: qat - protect interrupt mask CSRs with a spinlock (Vladis Dronov) [1960307]
- crypto: qat - move pf2vf interrupt [en|dis]able to adf_vf_isr.c (Vladis Dronov) [1960307]
- crypto: qat - fix reuse of completion variable (Vladis Dronov) [1960307]
- crypto: qat - remove intermediate tasklet for vf2pf (Vladis Dronov) [1960307]
- crypto: qat - rename compatibility version definition (Vladis Dronov) [1960307]
- crypto: qat - prevent spurious MSI interrupt in PF (Vladis Dronov) [1960307]
- crypto: qat - prevent spurious MSI interrupt in VF (Vladis Dronov) [1960307]
- crypto: qat - handle both source of interrupt in VF ISR (Vladis Dronov) [1960307]
- crypto: qat - do not ignore errors from enable_vf2pf_comms() (Vladis Dronov) [1960307]
- crypto: qat - enable interrupts only after ISR allocation (Vladis Dronov) [1960307]
- crypto: qat - remove empty sriov_configure() (Vladis Dronov) [1960307]
- crypto: qat - use proper type for vf_mask (Vladis Dronov) [1960307]
- crypto: qat - fix a typo in a comment (Vladis Dronov) [1960307]
- crypto: qat - disable AER if an error occurs in probe functions (Vladis Dronov) [1960307]
- crypto: qat - set DMA mask to 48 bits for Gen2 (Vladis Dronov) [1960307]
- crypto: qat - simplify code and axe the use of a deprecated API (Vladis Dronov) [1960307]
- crypto: qat - ratelimit invalid ioctl message and print the invalid cmd (Vladis Dronov) [1960307]
- lib: crc8: pointer to data block should be const (Vladis Dronov) [1960307]
- redhat/configs: disable CONFIG_HYPERV_BALLOON on Aarch64 (Vitaly Kuznetsov) [2035292]
- net/mlx5e: Fix possible use-after-free deleting fdb rule (Amir Tzin) [2000003]
- e1000e: Fix packet loss on Tiger Lake and later (Ken Cox) [1952803]
- e1000e: Separate TGP board type from SPT (Ken Cox) [1952803]
- e1000e: Add support for the next LOM generation (Ken Cox) [1952803]
- e1000e: Add support for Lunar Lake (Ken Cox) [1952803]
- ACPI: tables: FPDT: Do not print FW_BUG message if record types are reserved (Mark Langsdorf) [1999906]
- powerpc/xmon: Dump XIVE information for online-only processors. (Steve Best) [2037639]
- of: net: pass the dst buffer to of_get_mac_address() (Petr Oros) [2026468]
- net: ethernet: improve eth_platform_get_mac_address (Petr Oros) [2026468]
- net: ethernet: fix similar warning reported by kbuild test robot (Petr Oros) [2026468]
- net: ethernet: support of_get_mac_address new ERR_PTR error (Petr Oros) [2026468]
- [s390] s390: add HWCAP_S390_PCI_MIO to ELF hwcaps (Mete Durlu) [2030641]
- [s390] s390: make PCI mio support a machine flag (Mete Durlu) [2030641]
- Allocate bw_dwork as a pointer and introduce a backpointer in the work struct (Nico Pache) [1990580]
- writeback: use READ_ONCE for unlocked reads of writeback stats (Nico Pache) [1990580]
- writeback: rename domain_update_bandwidth() (Nico Pache) [1990580]
- writeback: fix bandwidth estimate for spiky workload (Nico Pache) [1990580]
- writeback: reliably update bandwidth estimation (Nico Pache) [1990580]
- writeback: track number of inodes under writeback (Nico Pache) [1990580]
- bdi: replace BDI_CAP_NO_{WRITEBACK,ACCT_DIRTY} with a single flag (Nico Pache) [1990580]
- bdi: invert BDI_CAP_NO_ACCT_WB (Nico Pache) [1990580]
- bdi: replace BDI_CAP_STABLE_WRITES with a queue and a sb flag (Nico Pache) [1990580]
- mm: use SWP_SYNCHRONOUS_IO more intelligently (Nico Pache) [1990580]
- bdi: remove BDI_CAP_SYNCHRONOUS_IO (Nico Pache) [1990580]
- bcache: inherit the optimal I/O size (Nico Pache) [1990580]
- fs: remove the unused SB_I_MULTIROOT flag (Nico Pache) [1990580]
- Revert "bdi: replace BDI_CAP_NO_{WRITEBACK,ACCT_DIRTY} with a single flag" (Nico Pache) [1990580]
- mm/page_io.c: annotate refault stalls from swap_readpage (Nico Pache) [1990580]
- mmc: mmc_spi: Enable stable writes (Nico Pache) [1990580]
- virtio-blk: modernize sysfs attribute creation (Nico Pache) [1990580]
- aoe: register default groups with device_add_disk() (Nico Pache) [1990580]
- block: make QUEUE_SYSFS_BIT_FNS more useful (Nico Pache) [1990580]
- block: add helper macros for queue sysfs entries (Nico Pache) [1990580]
- cifs: sanitize multiple delimiters in prepath (Thiago Becker) [2031200]
- igc: Fix typo in i225 LTR functions (Corinna Vinschen) [1970667]
- igc: AF_XDP zero-copy metadata adjust breaks SKBs on XDP_PASS (Corinna Vinschen) [1970667]
- igc: Change Device Reset to Port Reset (Corinna Vinschen) [1970667]
- igc: Add new device ID (Corinna Vinschen) [1970667]
- igc: Remove media type checking on the PHY initialization (Corinna Vinschen) [1970667]
- igc: Update I226_K device ID (Corinna Vinschen) [1970667]
- net: intel: igc_ptp: fix build for UML (Corinna Vinschen) [1970667]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Corinna Vinschen) [1970667]
- igc: Add support for CBS offloading (Corinna Vinschen) [1970667]
- igc: Simplify TSN flags handling (Corinna Vinschen) [1970667]
- igc: Use default cycle 'start' and 'end' values for queues (Corinna Vinschen) [1970667]
- igc: Add support for PTP getcrosststamp() (Corinna Vinschen) [1970667]
- igc: Enable PCIe PTM (Corinna Vinschen) [1970667]
- igc: Use num_tx_queues when iterating over tx_ring queue (Corinna Vinschen) [1970667]
- igc: fix page fault when thunderbolt is unplugged (Corinna Vinschen) [1970667]
- igc: Increase timeout value for Speed 100/1000/2500 (Corinna Vinschen) [1970667]
- igc: Set QBVCYCLET_S to 0 for TSN Basic Scheduling (Corinna Vinschen) [1970667]
- igc: Remove phy->type checking (Corinna Vinschen) [1970667]
- igc: Remove _I_PHY_ID checking (Corinna Vinschen) [1970667]
- igc: Check if num of q_vectors is smaller than max before array access (Corinna Vinschen) [1970667]
- Revert "igc: Export LEDs" (Corinna Vinschen) [1970667]
- igc: Export LEDs (Corinna Vinschen) [1970667]
- igc: Make flex filter more flexible (Corinna Vinschen) [1970667]
- igc: Allow for Flex Filters to be installed (Corinna Vinschen) [1970667]
- igc: Integrate flex filter into ethtool ops (Corinna Vinschen) [1970667]
- igc: Add possibility to add flex filter (Corinna Vinschen) [1970667]
- igc: Fix an error handling path in 'igc_probe()' (Corinna Vinschen) [1970667]
- igc: change default return of igc_read_phy_reg() (Corinna Vinschen) [1970667]
- igc: Fix use-after-free error during reset (Corinna Vinschen) [1970667]
- intel: Remove rcu_read_lock() around XDP program invocation (Corinna Vinschen) [1970667]
- igc: Enable HW VLAN Insertion and HW VLAN Stripping (Corinna Vinschen) [1970667]
- igc: Indentation fixes (Corinna Vinschen) [1970667]
- igc: Remove unused MDICNFG register (Corinna Vinschen) [1970667]
- igc: Remove unused asymmetric pause bit from igc defines (Corinna Vinschen) [1970667]
- igc: Update driver to use ethtool_sprintf (Corinna Vinschen) [1970667]
- igc: add correct exception tracing for XDP (Corinna Vinschen) [1970667]
- igb/igc: use strongly typed pointer (Corinna Vinschen) [1970667]
- intel: remove checker warning (Corinna Vinschen) [1970667]
- igc: Enable TX via AF_XDP zero-copy (Corinna Vinschen) [1970667]
- igc: Enable RX via AF_XDP zero-copy (Corinna Vinschen) [1970667]
- igc: Replace IGC_TX_FLAGS_XDP flag by an enum (Corinna Vinschen) [1970667]
- igc: Introduce igc_unmap_tx_buffer() helper (Corinna Vinschen) [1970667]
- igc: Introduce TX/RX stats helpers (Corinna Vinschen) [1970667]
- igc: Refactor XDP rxq info registration (Corinna Vinschen) [1970667]
- igc: Refactor igc_clean_rx_ring() (Corinna Vinschen) [1970667]
- igc: Refactor __igc_xdp_run_prog() (Corinna Vinschen) [1970667]
- igc: Move igc_xdp_is_enabled() (Corinna Vinschen) [1970667]
- igc: use XDP helpers (Corinna Vinschen) [1970667]
- igc: Expose LPI counters (Corinna Vinschen) [1970667]
- igc: enable auxiliary PHC functions for the i225 (Corinna Vinschen) [1970667]
- igc: Enable internal i225 PPS (Corinna Vinschen) [1970667]
- igc: Add support for XDP_REDIRECT action (Corinna Vinschen) [1970667]
- igc: Add support for XDP_TX action (Corinna Vinschen) [1970667]
- igc: Add initial XDP support (Corinna Vinschen) [1970667]
- drivers: net: mhi: fix error path in mhi_net_newlink (Íñigo Huguet) [2004141]
- cfg80211: correct bridge/4addr mode check (Íñigo Huguet) [2004141]
- cfg80211: fix management registrations locking (Íñigo Huguet) [2004141]
- cfg80211: scan: fix RCU in cfg80211_add_nontrans_list() (Íñigo Huguet) [2004141]
- mac80211: mesh: fix HE operation element length check (Íñigo Huguet) [2004141]
- mwifiex: avoid null-pointer-subtraction warning (Íñigo Huguet) [2004141]
- Revert "brcmfmac: use ISO3166 country code and 0 rev as fallback" (Íñigo Huguet) [2004141]
- iwlwifi: pcie: add configuration of a Wi-Fi adapter on Dell XPS 15 (Íñigo Huguet) [2004141]
- mac80211: Fix Ptk0 rekey documentation (Íñigo Huguet) [2004141]
- mac80211: check return value of rhashtable_init (Íñigo Huguet) [2004141]
- mac80211: fix use-after-free in CCMP/GCMP RX (Íñigo Huguet) [2004141]
- mac80211-hwsim: fix late beacon hrtimer handling (Íñigo Huguet) [2004141]
- mac80211: mesh: fix potentially unaligned access (Íñigo Huguet) [2004141]
- mac80211: limit injected vht mcs/nss in ieee80211_parse_tx_radiotap (Íñigo Huguet) [2004141]
- mac80211: Drop frames from invalid MAC address in ad-hoc mode (Íñigo Huguet) [2004141]
- mac80211: Fix ieee80211_amsdu_aggregate frag_tail bug (Íñigo Huguet) [2004141]
- Revert "mac80211: do not use low data rates for data frames with no ack flag" (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: missing unlock in iwl_mvm_wowlan_program_keys() (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: Fix off by ones in iwl_mvm_wowlan_get_rsc_v5_data() (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Fix possible NULL dereference (Íñigo Huguet) [2004141]
- iwlwifi: fix printk format warnings in uefi.c (Íñigo Huguet) [2004141]
- iwlwifi: pnvm: Fix a memory leak in 'iwl_pnvm_get_from_fs()' (Íñigo Huguet) [2004141]
- iwlwifi: bump FW API to 66 for AX devices (Íñigo Huguet) [2004141]
- iwlwifi Add support for ax201 in Samsung Galaxy Book Flex2 Alpha (Íñigo Huguet) [2004141]
- iwlwifi: mvm: add rtnl_lock() in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2004141]
- net: qrtr: revert check in qrtr_endpoint_post() (Íñigo Huguet) [2004141]
- net: qrtr: make checks in qrtr_endpoint_post() stricter (Íñigo Huguet) [2004141]
- intel: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2004141]
- mwifiex: pcie: add reset_d3cold quirk for Surface gen4+ devices (Íñigo Huguet) [2004141]
- mwifiex: pcie: add DMI-based quirk implementation for Surface devices (Íñigo Huguet) [2004141]
- brcmfmac: pcie: fix oops on failure to resume and reprobe (Íñigo Huguet) [2004141]
- brcmfmac: Add WPA3 Personal with FT to supported cipher suites (Íñigo Huguet) [2004141]
- rtlwifi: rtl8192de: Fix initialization of place in _rtl92c_phy_get_rightchnlplace() (Íñigo Huguet) [2004141]
- rtw88: add quirk to disable pci caps on HP Pavilion 14-ce0xxx (Íñigo Huguet) [2004141]
- ath9k: fix sleeping in atomic context (Íñigo Huguet) [2004141]
- ath9k: fix OOB read ar9300_eeprom_restore_internal (Íñigo Huguet) [2004141]
- iwlwifi: mvm: don't use FW key ID in beacon protection (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Fix scan channel flags settings (Íñigo Huguet) [2004141]
- iwlwifi: mvm: support broadcast TWT alone (Íñigo Huguet) [2004141]
- iwlwifi: mvm: introduce iwl_stored_beacon_notif_v3 (Íñigo Huguet) [2004141]
- iwlwifi: move get pnvm file name to a separate function (Íñigo Huguet) [2004141]
- iwlwifi: mvm: add support for responder config command version 9 (Íñigo Huguet) [2004141]
- iwlwifi: mvm: add support for range request command version 13 (Íñigo Huguet) [2004141]
- iwlwifi: allow debug init in RF-kill (Íñigo Huguet) [2004141]
- iwlwifi: mvm: don't schedule the roc_done_wk if it is already running (Íñigo Huguet) [2004141]
- iwlwifi: yoyo: support for new DBGI_SRAM region (Íñigo Huguet) [2004141]
- iwlwifi: add 'Rx control frame to MBSSID' HE capability (Íñigo Huguet) [2004141]
- iwlwifi: fw: fix debug dump data declarations (Íñigo Huguet) [2004141]
- iwlwifi: api: remove datamember from struct (Íñigo Huguet) [2004141]
- iwlwifi: fix __percpu annotation (Íñigo Huguet) [2004141]
- iwlwifi: pcie: avoid dma unmap/remap in crash dump (Íñigo Huguet) [2004141]
- iwlwifi: acpi: fill in SAR tables with defaults (Íñigo Huguet) [2004141]
- iwlwifi: acpi: fill in WGDS table with defaults (Íñigo Huguet) [2004141]
- iwlwifi: bump FW API to 65 for AX devices (Íñigo Huguet) [2004141]
- iwlwifi: acpi: support reading and storing WGDS revision 2 (Íñigo Huguet) [2004141]
- iwlwifi: mvm: load regdomain at INIT stage (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Read the PPAG and SAR tables at INIT stage (Íñigo Huguet) [2004141]
- iwlwifi: mvm: trigger WRT when no beacon heard (Íñigo Huguet) [2004141]
- iwlwifi: fw: correctly limit to monitor dump (Íñigo Huguet) [2004141]
- iwlwifi: skip first element in the WTAS ACPI table (Íñigo Huguet) [2004141]
- iwlwifi: mvm: support version 11 of wowlan statuses notification (Íñigo Huguet) [2004141]
- iwlwifi: convert flat GEO profile table to a struct version (Íñigo Huguet) [2004141]
- iwlwifi: remove unused ACPI_WGDS_TABLE_SIZE definition (Íñigo Huguet) [2004141]
- iwlwifi: support reading and storing EWRD revisions 1 and 2 (Íñigo Huguet) [2004141]
- iwlwifi: acpi: support reading and storing WRDS revision 1 and 2 (Íñigo Huguet) [2004141]
- iwlwifi: pass number of chains and sub-bands to iwl_sar_set_profile() (Íñigo Huguet) [2004141]
- iwlwifi: remove ACPI_SAR_NUM_TABLES definition (Íñigo Huguet) [2004141]
- iwlwifi: convert flat SAR profile table to a struct version (Íñigo Huguet) [2004141]
- iwlwifi: rename ACPI_SAR_NUM_CHAIN_LIMITS to ACPI_SAR_NUM_CHAINS (Íñigo Huguet) [2004141]
- iwlwifi: mvm: fix access to BSS elements (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Refactor setting of SSIDs for 6GHz scan (Íñigo Huguet) [2004141]
- iwlwifi: mvm: silently drop encrypted frames for unknown station (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: implement RSC command version 5 (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: make key reprogramming iteration optional (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: add separate key iteration for GTK type (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: refactor TSC/RSC configuration (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: remove fixed cmd_flags argument (Íñigo Huguet) [2004141]
- iwlwifi: mvm: d3: separate TKIP data from key iteration (Íñigo Huguet) [2004141]
- iwlwifi: mvm: simplify __iwl_mvm_set_sta_key() (Íñigo Huguet) [2004141]
- iwlwifi: mvm: support new station key API (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Fix umac scan request probe parameters (Íñigo Huguet) [2004141]
- iwlwifi: pcie: implement Bz reset flow (Íñigo Huguet) [2004141]
- iwlwifi: implement Bz NMI behaviour (Íñigo Huguet) [2004141]
- iwlwifi: pcie: implement Bz device startup (Íñigo Huguet) [2004141]
- iwlwifi: read MAC address from correct place on Bz (Íñigo Huguet) [2004141]
- iwlwifi: give Bz devices their own name (Íñigo Huguet) [2004141]
- iwlwifi: split off Bz devices into their own family (Íñigo Huguet) [2004141]
- iwlwifi: yoyo: cleanup internal buffer allocation in D3 (Íñigo Huguet) [2004141]
- iwlwifi: mvm: treat MMPDUs in iwl_mvm_mac_tx() as bcast (Íñigo Huguet) [2004141]
- iwlwifi: mvm: clean up number of HW queues (Íñigo Huguet) [2004141]
- iwlwifi: mvm: avoid static queue number aliasing (Íñigo Huguet) [2004141]
- iwlwifi: use DEFINE_MUTEX() for mutex lock (Íñigo Huguet) [2004141]
- iwlwifi: remove trailing semicolon in macro definition (Íñigo Huguet) [2004141]
- iwlwifi: mvm: fix a memory leak in iwl_mvm_mac_ctxt_beacon_changed (Íñigo Huguet) [2004141]
- iwlwifi: mvm: fix old-style static const declaration (Íñigo Huguet) [2004141]
- iwlwifi: mvm: remove check for vif in iwl_mvm_vif_from_mac80211() (Íñigo Huguet) [2004141]
- iwlwifi: pcie: remove spaces from queue names (Íñigo Huguet) [2004141]
- iwlwifi: mvm: restrict FW SMPS request (Íñigo Huguet) [2004141]
- iwlwifi: mvm: set replay counter on key install (Íñigo Huguet) [2004141]
- iwlwifi: mvm: remove trigger EAPOL time event (Íñigo Huguet) [2004141]
- iwlwifi: iwl-dbg-tlv: add info about loading external dbg bin (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Add support for hidden network scan on 6GHz band (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Do not use full SSIDs in 6GHz scan (Íñigo Huguet) [2004141]
- iwlwifi: print PNVM complete notification status in hexadecimal (Íñigo Huguet) [2004141]
- iwlwifi: pcie: dump error on FW reset handshake failures (Íñigo Huguet) [2004141]
- iwlwifi: prepare for synchronous error dumps (Íñigo Huguet) [2004141]
- iwlwifi: pcie: free RBs during configure (Íñigo Huguet) [2004141]
- iwlwifi: pcie: optimise struct iwl_rx_mem_buffer layout (Íñigo Huguet) [2004141]
- iwlwifi: mvm: avoid FW restart while shutting down (Íñigo Huguet) [2004141]
- iwlwifi: nvm: enable IEEE80211_HE_PHY_CAP10_HE_MU_M1RU_MAX_LTF (Íñigo Huguet) [2004141]
- iwlwifi: mvm: set BROADCAST_TWT_SUPPORTED in MAC policy (Íñigo Huguet) [2004141]
- iwlwifi: iwl-nvm-parse: set STBC flags for HE phy capabilities (Íñigo Huguet) [2004141]
- cfg80211: use wiphy DFS domain if it is self-managed (Íñigo Huguet) [2004141]
- mac80211: parse transmit power envelope element (Íñigo Huguet) [2004141]
- ieee80211: add definition for transmit power envelope element (Íñigo Huguet) [2004141]
- ieee80211: add definition of regulatory info in 6 GHz operation information (Íñigo Huguet) [2004141]
- mac80211: introduce individual TWT support in AP mode (Íñigo Huguet) [2004141]
- ieee80211: add TWT element definitions (Íñigo Huguet) [2004141]
- brcmsmac: make array addr static const, makes object smaller (Íñigo Huguet) [2004141]
- rtw88: Remove unnecessary check code (Íñigo Huguet) [2004141]
- rtw88: wow: fix size access error of probe request (Íñigo Huguet) [2004141]
- rtw88: wow: report wow reason through mac80211 api (Íñigo Huguet) [2004141]
- rtw88: wow: build wow function only if CONFIG_PM is on (Íñigo Huguet) [2004141]
- rtw88: refine the setting of rsvd pages for different firmware (Íñigo Huguet) [2004141]
- rtw88: use read_poll_timeout instead of fixed sleep (Íñigo Huguet) [2004141]
- rtw88: 8822ce: set CLKREQ# signal to low during suspend (Íñigo Huguet) [2004141]
- rtw88: change beacon filter default mode (Íñigo Huguet) [2004141]
- rtw88: 8822c: add tx stbc support under HT mode (Íñigo Huguet) [2004141]
- rtw88: adjust the log level for failure of tx report (Íñigo Huguet) [2004141]
- rtl8xxxu: Fix the handling of TX A-MPDU aggregation (Íñigo Huguet) [2004141]
- rtl8xxxu: disable interrupt_in transfer for 8188cu and 8192cu (Íñigo Huguet) [2004141]
- mwifiex: make arrays static const, makes object smaller (Íñigo Huguet) [2004141]
- mwifiex: usb: Replace one-element array with flexible-array member (Íñigo Huguet) [2004141]
- mwifiex: drop redundant null-pointer check in mwifiex_dnld_cmd_to_fw() (Íñigo Huguet) [2004141]
- rtlwifi: rtl8192de: make arrays static const, makes object smaller (Íñigo Huguet) [2004141]
- rtlwifi: rtl8192de: Remove redundant variable initializations (Íñigo Huguet) [2004141]
- ray_cs: Split memcpy() to avoid bounds check warning (Íñigo Huguet) [2004141]
- ray_cs: use *ph to print small buffer (Íñigo Huguet) [2004141]
- brcmfmac: add 43752 SDIO ids and initialization (Íñigo Huguet) [2004141]
- brcmfmac: Set SDIO workqueue as WQ_HIGHPRI (Íñigo Huguet) [2004141]
- brcmfmac: use separate firmware for 43430 revision 2 (Íñigo Huguet) [2004141]
- brcmfmac: support chipsets with different core enumeration space (Íñigo Huguet) [2004141]
- brcmfmac: add xtlv support to firmware interface layer (Íñigo Huguet) [2004141]
- brcmfmac: increase core revision column aligning core list (Íñigo Huguet) [2004141]
- brcmfmac: use different error value for invalid ram base address (Íñigo Huguet) [2004141]
- brcmfmac: firmware: Fix firmware loading (Íñigo Huguet) [2004141]
- net: qrtr: fix another OOB Read in qrtr_endpoint_post (Íñigo Huguet) [2004141]
- cfg80211: fix BSS color notify trace enum confusion (Íñigo Huguet) [2004141]
- mac80211: fix locking in ieee80211_restart_work() (Íñigo Huguet) [2004141]
- mac80211: Fix insufficient headroom issue for AMSDU (Íñigo Huguet) [2004141]
- mac80211: add support for BSS color change (Íñigo Huguet) [2004141]
- nl80211: add support for BSS coloring (Íñigo Huguet) [2004141]
- mac80211: Use flex-array for radiotap header bitmap (Íñigo Huguet) [2004141]
- mac80211: radiotap: Use BIT() instead of shifts (Íñigo Huguet) [2004141]
- mac80211: Remove unnecessary variable and label (Íñigo Huguet) [2004141]
- mac80211: include <linux/rbtree.h> (Íñigo Huguet) [2004141]
- mac80211: Fix monitor MTU limit so that A-MSDUs get through (Íñigo Huguet) [2004141]
- mac80211: remove unnecessary NULL check in ieee80211_register_hw() (Íñigo Huguet) [2004141]
- mac80211: Reject zero MAC address in sta_info_insert_check() (Íñigo Huguet) [2004141]
- mt76: fix enum type mismatch (Íñigo Huguet) [2004141]
- bus: mhi: core: Improve debug messages for power up (Íñigo Huguet) [2004141]
- bus: mhi: core: Replace DMA allocation wrappers with original APIs (Íñigo Huguet) [2004141]
- bus: mhi: core: Add range checks for BHI and BHIe (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Set register access length for MHI driver (Íñigo Huguet) [2004141]
- ath11k: set register access length for MHI driver (Íñigo Huguet) [2004141]
- bus: mhi: Add MMIO region length to controller structure (Íñigo Huguet) [2004141]
- bus: mhi: core: Set BHI and BHIe pointers to NULL in clean-up (Íñigo Huguet) [2004141]
- bus: mhi: core: Set BHI/BHIe offsets on power up preparation (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Add Cinterion MV31-W PCIe to MHI (Íñigo Huguet) [2004141]
- Revert "mhi: Fix networking tree build." (Íñigo Huguet) [2004141]
- mhi: Fix networking tree build. (Íñigo Huguet) [2004141]
- brcmfmac: firmware: Allow per-board firmware binaries (Íñigo Huguet) [2004141]
- iwlwifi: add new so-jf devices (Íñigo Huguet) [2004141]
- iwlwifi: add new SoF with JF devices (Íñigo Huguet) [2004141]
- iwlwifi: pnvm: accept multiple HW-type TLVs (Íñigo Huguet) [2004141]
- cfg80211: Fix possible memory leak in function cfg80211_bss_update (Íñigo Huguet) [2004141]
- nl80211: limit band information in non-split data (Íñigo Huguet) [2004141]
- mac80211: fix enabling 4-address mode on a sta vif after assoc (Íñigo Huguet) [2004141]
- mac80211: fix starting aggregation sessions on mesh interfaces (Íñigo Huguet) [2004141]
- mac80211: Do not strip skb headroom on monitor frames (Íñigo Huguet) [2004141]
- net: mhi: Remove MBIM protocol (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Fix inbound IPCR channel (Íñigo Huguet) [2004141]
- bus: mhi: core: Validate channel ID when processing command completions (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Apply no-op for wake using sideband wake boolean (Íñigo Huguet) [2004141]
- net: mhi: Improve MBIM packet counting (Íñigo Huguet) [2004141]
- bus: mhi: pci-generic: configurable network interface MRU (Íñigo Huguet) [2004141]
- mt76: mt7921: Fix fall-through warning for Clang (Íñigo Huguet) [2004141]
- mt76: mt7921: continue to probe driver when fw already downloaded (Íñigo Huguet) [2004141]
- ath11k: Remove some duplicate code (Íñigo Huguet) [2004141]
- ath: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2004141]
- iwlwifi: acpi: remove unused function iwl_acpi_eval_dsm_func() (Íñigo Huguet) [2004141]
- rtw88: fix c2h memory leak (Íñigo Huguet) [2004141]
- brcmfmac: support parse country code map from DT (Íñigo Huguet) [2004141]
- bus: mhi: pci-generic: Add missing 'pci_disable_pcie_error_reporting()' calls (Íñigo Huguet) [2004141]
- bus: mhi: Wait for M2 state during system resume (Íñigo Huguet) [2004141]
- bus: mhi: core: Fix power down latency (Íñigo Huguet) [2004141]
- brcmfmac: Silence error messages about unsupported firmware features (Íñigo Huguet) [2004141]
- cfg80211: Add wiphy_info_once() (Íñigo Huguet) [2004141]
- mac80211: Switch to a virtual time-based airtime scheduler (Íñigo Huguet) [2004141]
- Revert "mac80211: HE STA disassoc due to QOS NULL not sent" (Íñigo Huguet) [2004141]
- mac80211: remove iwlwifi specific workaround NDPs of null_response (Íñigo Huguet) [2004141]
- mac80211: fix NULL ptr dereference during mesh peer connection for non HE devices (Íñigo Huguet) [2004141]
- mac80211: Enable power save after receiving NULL packet ACK (Íñigo Huguet) [2004141]
- mac80211: add HE 6 GHz capability only if supported (Íñigo Huguet) [2004141]
- mac80211: notify driver on mgd TX completion (Íñigo Huguet) [2004141]
- mac80211: always include HE 6GHz capability in probe request (Íñigo Huguet) [2004141]
- mac80211: add vendor-specific capabilities to assoc request (Íñigo Huguet) [2004141]
- cfg80211: allow advertising vendor-specific capabilities (Íñigo Huguet) [2004141]
- cfg80211: set custom regdomain after wiphy registration (Íñigo Huguet) [2004141]
- cfg80211: Support hidden AP discovery over 6GHz band (Íñigo Huguet) [2004141]
- mac80211: conditionally advertise HE in probe requests (Íñigo Huguet) [2004141]
- cfg80211: add cfg80211_any_usable_channels() (Íñigo Huguet) [2004141]
- cfg80211: reg: improve bad regulatory warning (Íñigo Huguet) [2004141]
- nl80211: Fix typo pmsr->pmsr (Íñigo Huguet) [2004141]
- mac80211: fix some spelling mistakes (Íñigo Huguet) [2004141]
- cfg80211: remove ieee80211_get_he_sta_cap() (Íñigo Huguet) [2004141]
- mac80211: remove use of ieee80211_get_he_sta_cap() (Íñigo Huguet) [2004141]
- cfg80211: trace more information in assoc trace event (Íñigo Huguet) [2004141]
- mac80211: improve AP disconnect message (Íñigo Huguet) [2004141]
- mac80211: rearrange struct txq_info for fewer holes (Íñigo Huguet) [2004141]
- ieee80211: add defines for HE PHY cap byte 10 (Íñigo Huguet) [2004141]
- mac80211: Properly WARN on HW scan before restart (Íñigo Huguet) [2004141]
- nl80211/cfg80211: add BSS color to NDP ranging parameters (Íñigo Huguet) [2004141]
- mac80211: add to bss_conf if broadcast TWT is supported (Íñigo Huguet) [2004141]
- mac80211: move SMPS mode setting after ieee80211_prep_connection (Íñigo Huguet) [2004141]
- mac80211: free skb in WEP error case (Íñigo Huguet) [2004141]
- mac80211: handle rate control (RC) racing with chanctx definition (Íñigo Huguet) [2004141]
- ieee80211: define timing measurement in extended capabilities IE (Íñigo Huguet) [2004141]
- mac80211_hwsim: record stats in non-netlink path (Íñigo Huguet) [2004141]
- ieee80211: add the value for Category '6' in "rtw_ieee80211_category" (Íñigo Huguet) [2004141]
- mac80211: remove iwlwifi specific workaround that broke sta NDP tx (Íñigo Huguet) [2004141]
- mac80211: allow SMPS requests only in client mode (Íñigo Huguet) [2004141]
- mac80211: check per vif offload_flags in Tx path (Íñigo Huguet) [2004141]
- mac80211: add rate control support for encap offload (Íñigo Huguet) [2004141]
- mac80211: call ieee80211_tx_h_rate_ctrl() when dequeue (Íñigo Huguet) [2004141]
- mac80211: move A-MPDU session check from minstrel_ht to mac80211 (Íñigo Huguet) [2004141]
- cfg80211: expose the rfkill device to the low level driver (Íñigo Huguet) [2004141]
- wireless: add check of field VHT Extended NSS BW Capable for 160/80+80 MHz setting (Íñigo Huguet) [2004141]
- mac80211_hwsim: add concurrent channels scanning support over virtio (Íñigo Huguet) [2004141]
- mac80211: don't open-code LED manipulations (Íñigo Huguet) [2004141]
- mac80211: consider per-CPU statistics if present (Íñigo Huguet) [2004141]
- cfg80211: fix default HE tx bitrate mask in 2G band (Íñigo Huguet) [2004141]
- mac80211: remove the repeated declaration (Íñigo Huguet) [2004141]
- mac80211: refactor rc_no_data_or_no_ack_use_min function (Íñigo Huguet) [2004141]
- mac80211: do not use low data rates for data frames with no ack flag (Íñigo Huguet) [2004141]
- mac80211: add ieee80211_is_tx_data helper function (Íñigo Huguet) [2004141]
- mac80211: simplify ieee80211_add_station() (Íñigo Huguet) [2004141]
- mac80211: use sdata->skb_queue for TDLS (Íñigo Huguet) [2004141]
- mac80211: refactor SKB queue processing a bit (Íñigo Huguet) [2004141]
- mac80211: unify queueing SKB to iface (Íñigo Huguet) [2004141]
- mac80211: minstrel_ht: ignore frame that was sent with noAck flag (Íñigo Huguet) [2004141]
- cfg80211: clean up variable use in cfg80211_parse_colocated_ap() (Íñigo Huguet) [2004141]
- cfg80211: remove CFG80211_MAX_NUM_DIFFERENT_CHANNELS (Íñigo Huguet) [2004141]
- mac80211: Remove redundant assignment to ret (Íñigo Huguet) [2004141]
- net: wireless: wext_compat.c: Remove redundant assignment to ps (Íñigo Huguet) [2004141]
- wireless: wext-spy: Fix out-of-bounds warning (Íñigo Huguet) [2004141]
- ath11k: Avoid memcpy() over-reading of he_cap (Íñigo Huguet) [2004141]
- mt7601u: add USB device ID for some versions of XiaoDu WiFi Dongle. (Íñigo Huguet) [2004141]
- mwifiex: Avoid memset() over-write of WEP key_material (Íñigo Huguet) [2004141]
- rtlwifi: rtl8192de: Fully initialize curvecount_val (Íñigo Huguet) [2004141]
- rtw88: coex: remove unnecessary variable and label (Íñigo Huguet) [2004141]
- rtw88: add quirks to disable pci capabilities (Íñigo Huguet) [2004141]
- rtw88: refine unwanted h2c command (Íñigo Huguet) [2004141]
- rtw88: dump FW crash via devcoredump (Íñigo Huguet) [2004141]
- rtw88: notify fw when driver in scan-period to avoid potential problem (Íñigo Huguet) [2004141]
- rtw88: add rtw_fw_feature_check api (Íñigo Huguet) [2004141]
- rtw88: 8822c: update RF parameter tables to v62 (Íñigo Huguet) [2004141]
- rtw88: Remove duplicate include of coex.h (Íñigo Huguet) [2004141]
- rtw88: 8822c: fix lc calibration timing (Íñigo Huguet) [2004141]
- rtw88: add path diversity (Íñigo Huguet) [2004141]
- rtw88: add beacon filter support (Íñigo Huguet) [2004141]
- iwlwifi: bump FW API to 64 for AX devices (Íñigo Huguet) [2004141]
- iwlwifi: fw: dump TCM error table if present (Íñigo Huguet) [2004141]
- iwlwifi: add 9560 killer device (Íñigo Huguet) [2004141]
- iwlwifi: move error dump to fw utils (Íñigo Huguet) [2004141]
- iwlwifi: support loading the reduced power table from UEFI (Íñigo Huguet) [2004141]
- iwlwifi: move UEFI code to a separate file (Íñigo Huguet) [2004141]
- iwlwifi: mvm: introduce iwl_wowlan_get_status_cmd (Íñigo Huguet) [2004141]
- iwlwifi: mvm: introduce iwl_wowlan_kek_kck_material_cmd_v4 (Íñigo Huguet) [2004141]
- iwlwifi: mvm: update iwl_wowlan_patterns_cmd (Íñigo Huguet) [2004141]
- iwlwifi: mvm: introduce iwl_proto_offload_cmd_v4 (Íñigo Huguet) [2004141]
- iwlwifi: fix NUM_IWL_UCODE_TLV_* definitions to avoid sparse errors (Íñigo Huguet) [2004141]
- iwlwifi: pcie: free some DMA memory earlier (Íñigo Huguet) [2004141]
- iwlwifi: mvm: fill phy_data.d1 for no-data RX (Íñigo Huguet) [2004141]
- iwlwifi: pcie: fix context info freeing (Íñigo Huguet) [2004141]
- iwlwifi: pcie: free IML DMA memory allocation (Íñigo Huguet) [2004141]
- iwlwifi: mvm: support LONG_GROUP for WOWLAN_GET_STATUSES version (Íñigo Huguet) [2004141]
- iwlwifi: support ver 6 of WOWLAN_CONFIGURATION and ver 10 of WOWLAN_GET_STATUSES (Íñigo Huguet) [2004141]
- iwlwifi: mvm: don't request mac80211 to disable/enable sta's queues (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Explicitly stop session protection before unbinding (Íñigo Huguet) [2004141]
- iwlwifi: pcie: remove TR/CR tail allocations (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Read acpi dsm to get unii4 enable/disable bitmap. (Íñigo Huguet) [2004141]
- iwlwifi: pcie: fix some kernel-doc comments (Íñigo Huguet) [2004141]
- iwlwifi: advertise broadcast TWT support (Íñigo Huguet) [2004141]
- iwlwifi: mvm: support LMR feedback (Íñigo Huguet) [2004141]
- iwlwifi: correct HE capabilities (Íñigo Huguet) [2004141]
- iwlwifi: mvm: Call NMI instead of REPLY_ERROR (Íñigo Huguet) [2004141]
- iwlwifi: mvm: fix error print when session protection ends (Íñigo Huguet) [2004141]
- iwlwifi: mvm: honour firmware SMPS requests (Íñigo Huguet) [2004141]
- iwlwifi: mvm: apply RX diversity per PHY context (Íñigo Huguet) [2004141]
- iwlwifi: mvm: don't request SMPS in AP mode (Íñigo Huguet) [2004141]
- iwlwifi: pcie: identify the RF module (Íñigo Huguet) [2004141]
- iwlwifi: yoyo: support region TLV version 2 (Íñigo Huguet) [2004141]
- iwlwifi: remove duplicate iwl_ax201_cfg_qu_hr declaration (Íñigo Huguet) [2004141]
- iwlwifi: pcie: remove CSR_HW_RF_ID_TYPE_CHIP_ID (Íñigo Huguet) [2004141]
- iwlwifi: pcie: print interrupt number, not index (Íñigo Huguet) [2004141]
- iwlwifi: pcie: Add support for AX231 radio module with Ma devices (Íñigo Huguet) [2004141]
- iwlwifi: increase PNVM load timeout (Íñigo Huguet) [2004141]
- iwlwifi: pcie: handle pcim_iomap_table() failures better (Íñigo Huguet) [2004141]
- iwlwifi: mvm: don't change band on bound PHY contexts (Íñigo Huguet) [2004141]
- iwlwifi: remove unused REMOTE_WAKE_CONFIG_CMD definitions (Íñigo Huguet) [2004141]
- iwlwifi: mvm: fix indentation in some scan functions (Íñigo Huguet) [2004141]
- iwlwifi: mvm: pass the clock type to iwl_mvm_get_sync_time() (Íñigo Huguet) [2004141]
- iwlwifi: mvm: support BIOS enable/disable for 11ax in Russia (Íñigo Huguet) [2004141]
- ath11k: Enable QCN9074 device (Íñigo Huguet) [2004141]
- ath10k: demote chan info without scan request warning (Íñigo Huguet) [2004141]
- rtl8xxxu: avoid parsing short RX packet (Íñigo Huguet) [2004141]
- rtl8xxxu: Fix device info for RTL8192EU devices (Íñigo Huguet) [2004141]
- mt76: mt7921: allow chip reset during device restart (Íñigo Huguet) [2004141]
- mt76: mt7615: set macwork timeout according to runtime-pm (Íñigo Huguet) [2004141]
- mt76: mt7663s: enable runtime-pm (Íñigo Huguet) [2004141]
- mt76: mt7663s: rely on mt76_connac_pm_ref/mt76_connac_pm_unref in tx path (Íñigo Huguet) [2004141]
- mt76: mt7663s: rely on pm reference counting (Íñigo Huguet) [2004141]
- mt76: sdio: do not run mt76_txq_schedule directly (Íñigo Huguet) [2004141]
- mt76: mt7921: enable HE BFee capability (Íñigo Huguet) [2004141]
- mt76: disable TWT capabilities for the moment (Íñigo Huguet) [2004141]
- mt76: fix iv and CCMP header insertion (Íñigo Huguet) [2004141]
- mt76: mt7921: fix the coredump is being truncated (Íñigo Huguet) [2004141]
- mt76: mt7921: fix kernel warning when reset on vif is not sta (Íñigo Huguet) [2004141]
- mt76: mt7921: introduce dedicated control for deep_sleep (Íñigo Huguet) [2004141]
- mt76: mt7921: limit txpower according to userlevel power (Íñigo Huguet) [2004141]
- mt76: mt7921: improve code readability for mt7921_update_txs (Íñigo Huguet) [2004141]
- mt76: mt7915: fix IEEE80211_HE_PHY_CAP7_MAX_NC for station mode (Íñigo Huguet) [2004141]
- mt76: use SPDX header file comment style (Íñigo Huguet) [2004141]
- mt76: add a space between comment char and SPDX tag (Íñigo Huguet) [2004141]
- mt76: mt7915: improve MU stability (Íñigo Huguet) [2004141]
- mt76: mt7921: add deep sleep control to runtime-pm knob (Íñigo Huguet) [2004141]
- mt76: mt7921: enable deep sleep at runtime (Íñigo Huguet) [2004141]
- mt76: mt7915: introduce mt7915_mcu_set_txbf() (Íñigo Huguet) [2004141]
- mt76: make mt76_update_survey() per phy (Íñigo Huguet) [2004141]
- mt76: move mt76_get_next_pkt_id in mt76.h (Íñigo Huguet) [2004141]
- mt76: reduce rx buffer size to 2048 (Íñigo Huguet) [2004141]
- mt76: connac: fix the maximum interval schedule scan can support (Íñigo Huguet) [2004141]
- mt76: mt7915: fix rx fcs error count in testmode (Íñigo Huguet) [2004141]
- mt76: testmode: move chip-specific stats dump before common stats (Íñigo Huguet) [2004141]
- mt76: connac: add mt76_connac_mcu_get_nic_capability utility routine (Íñigo Huguet) [2004141]
- mt76: connac: check band caps in mt76_connac_mcu_set_rate_txpower (Íñigo Huguet) [2004141]
- mt76: mt7915: drop the use of repeater entries for station interfaces (Íñigo Huguet) [2004141]
- mt76: mt7921: enable VHT BFee capability (Íñigo Huguet) [2004141]
- mt76: mt7921: make mt7921_set_channel static (Íñigo Huguet) [2004141]
- mt76: mt7921: wake the device before dumping power table (Íñigo Huguet) [2004141]
- mt76: connac: add mt76_connac_power_save_sched in mt76_connac_pm_unref (Íñigo Huguet) [2004141]
- mt76: connac: fix UC entry is being overwritten (Íñigo Huguet) [2004141]
- mt76: mt7615: update radar parameters (Íñigo Huguet) [2004141]
- mt76: mt7915: setup drr group for peers (Íñigo Huguet) [2004141]
- mt76: mt7921: enable random mac address during sched_scan (Íñigo Huguet) [2004141]
- mt76: mt7921: remove mt7921_get_wtbl_info routine (Íñigo Huguet) [2004141]
- mt76: mt7915: fix MT_EE_CAL_GROUP_SIZE (Íñigo Huguet) [2004141]
- mt76: mt7915: improve error recovery reliability (Íñigo Huguet) [2004141]
- mt76: mt7921: enable hw offloading for wep keys (Íñigo Huguet) [2004141]
- mt76: mt7915: read all eeprom fields from fw in efuse mode (Íñigo Huguet) [2004141]
- mt76: mt7921: set MT76_RESET during mac reset (Íñigo Huguet) [2004141]
- mt76: mt7921: introduce mac tx done handling (Íñigo Huguet) [2004141]
- mt76: allow hw driver code to overwrite wiphy interface_modes (Íñigo Huguet) [2004141]
- mt76: mt7921: update statistic in active mode only (Íñigo Huguet) [2004141]
- mt76: mt7915: use mt7915_mcu_get_mib_info() to get survey data (Íñigo Huguet) [2004141]
- mt76: mt7615: fix potential overflow on large shift (Íñigo Huguet) [2004141]
- mt76: testmode: remove undefined behaviour in mt76_testmode_alloc_skb (Íñigo Huguet) [2004141]
- mt76: testmode: remove unnecessary function calls in mt76_testmode_free_skb (Íñigo Huguet) [2004141]
- mt76: testmode: fix memory leak in mt76_testmode_alloc_skb (Íñigo Huguet) [2004141]
- mt76: mt7615: remove useless if condition in mt7615_add_interface() (Íñigo Huguet) [2004141]
- mt76: mt7915: use mt7915_mcu_get_txpower_sku() to get per-rate txpower (Íñigo Huguet) [2004141]
- mt76: mt7615: add .offset_tsf callback (Íñigo Huguet) [2004141]
- mt76: mt7915: add .offset_tsf callback (Íñigo Huguet) [2004141]
- mt76: mt7921: reset wfsys during hw probe (Íñigo Huguet) [2004141]
- mt76: mt7921: do not schedule hw reset if the device is not running (Íñigo Huguet) [2004141]
- mt76: mt7921: return proper error value in mt7921_mac_init (Íñigo Huguet) [2004141]
- mt76: mt7921: enable runtime pm by default (Íñigo Huguet) [2004141]
- mt76: mt7921: fix OMAC idx usage (Íñigo Huguet) [2004141]
- mt76: mt7921: fix invalid register access in wake_work (Íñigo Huguet) [2004141]
- mt76: mt7921: avoid unnecessary consecutive WiFi resets (Íñigo Huguet) [2004141]
- mt76: connac: update BA win size in Rx direction (Íñigo Huguet) [2004141]
- mt76: connac: add bss color support for sta mode (Íñigo Huguet) [2004141]
- mt76: mt7615: add thermal sensor device support (Íñigo Huguet) [2004141]
- mt76: mt7915: add thermal cooling device support (Íñigo Huguet) [2004141]
- mt76: mt7915: add thermal sensor device support (Íñigo Huguet) [2004141]
- mt76: mt7921: fix reset under the deep sleep is enabled (Íñigo Huguet) [2004141]
- mt76: mt7921: add back connection monitor support (Íñigo Huguet) [2004141]
- mt76: mt7921: consider the invalid value for to_rssi (Íñigo Huguet) [2004141]
- mt76: connac: fix WoW with disconnetion and bitmap pattern (Íñigo Huguet) [2004141]
- mt76: connac: fw_own rely on all packet memory all being free (Íñigo Huguet) [2004141]
- mt76: mt7921: Don't alter Rx path classifier (Íñigo Huguet) [2004141]
- mt76: mt7921: fix mt7921_wfsys_reset sequence (Íñigo Huguet) [2004141]
- mt76: mt7663: enable hw rx header translation (Íñigo Huguet) [2004141]
- mt76: mt7615: free irq if mt7615_mmio_probe fails (Íñigo Huguet) [2004141]
- mt76: mt76x0: use dev_debug instead of dev_err for hw_rf_ctrl (Íñigo Huguet) [2004141]
- mt76: mt7921: enable rx csum offload (Íñigo Huguet) [2004141]
- mt76: mt7921: enable rx header traslation offload (Íñigo Huguet) [2004141]
- mt76: connac: add missing configuration in mt76_connac_mcu_wtbl_hdr_trans_tlv (Íñigo Huguet) [2004141]
- mt76: mt7921: enable rx hw de-amsdu (Íñigo Huguet) [2004141]
- mt76: mt7915: fix a signedness bug in mt7915_mcu_apply_tx_dpd() (Íñigo Huguet) [2004141]
- mt76: mt7615: fix NULL pointer dereference in tx_prepare_skb() (Íñigo Huguet) [2004141]
- mt76: fix possible NULL pointer dereference in mt76_tx (Íñigo Huguet) [2004141]
- mt76: mt7915: add .set_bitrate_mask() callback (Íñigo Huguet) [2004141]
- mt76: mt7915: cleanup mt7915_mcu_sta_rate_ctrl_tlv() (Íñigo Huguet) [2004141]
- mt76: mt7915: fix tssi indication field of DBDC NICs (Íñigo Huguet) [2004141]
- mt76: move mt76_rates in mt76 module (Íñigo Huguet) [2004141]
- mac80211: reset profile_periodicity/ema_ap (Íñigo Huguet) [2004141]
- mac80211: handle various extensible elements correctly (Íñigo Huguet) [2004141]
- cfg80211: avoid double free of PMSR request (Íñigo Huguet) [2004141]
- cfg80211: make certificate generation more robust (Íñigo Huguet) [2004141]
- mac80211: minstrel_ht: fix sample time check (Íñigo Huguet) [2004141]
- mt76: mt7915: add support for tx status reporting (Íñigo Huguet) [2004141]
- mt76: mt7915: rework tx rate reporting (Íñigo Huguet) [2004141]
- mt76: dma: use ieee80211_tx_status_ext to free packets when tx fails (Íñigo Huguet) [2004141]
- mt76: improve tx status codepath (Íñigo Huguet) [2004141]
- mt76: intialize tx queue entry wcid to 0xffff by default (Íñigo Huguet) [2004141]
- mt76: mt7603: avoid use of ieee80211_tx_info_clear_status (Íñigo Huguet) [2004141]
- mt76: mt7615: avoid use of ieee80211_tx_info_clear_status (Íñigo Huguet) [2004141]
- mt76: mt7615: fix fixed-rate tx status reporting (Íñigo Huguet) [2004141]
- mt76: mt7915: move mt7915_queue_rx_skb to mac.c (Íñigo Huguet) [2004141]
- mt76: mt7915: disable ASPM (Íñigo Huguet) [2004141]
- mt76: mt7915: add MSI support (Íñigo Huguet) [2004141]
- ath11k: send beacon template after vdev_start/restart during csa (Íñigo Huguet) [2004141]
- ath10k: Use devm_platform_get_and_ioremap_resource() (Íñigo Huguet) [2004141]
- ath10k: remove the repeated declaration (Íñigo Huguet) [2004141]
- ath10k: Fix an error code in ath10k_add_interface() (Íñigo Huguet) [2004141]
- ath11k: Fix an error handling path in ath11k_core_fetch_board_data_api_n() (Íñigo Huguet) [2004141]
- ath: Fix wrong function name in comments (Íñigo Huguet) [2004141]
- rtlwifi: Fix spelling of 'download' (Íñigo Huguet) [2004141]
- rtlwifi: Remove redundant assignments to ul_enc_algo (Íñigo Huguet) [2004141]
- rtlwifi: rtl8723ae: remove redundant initialization of variable rtstatus (Íñigo Huguet) [2004141]
- rtlwifi: btcoex: 21a 2ant: Delete several duplicate condition branch codes (Íñigo Huguet) [2004141]
- rtlwifi: 8821a: btcoexist: add comments to explain why if-else branches are identical (Íñigo Huguet) [2004141]
- rt2x00: do not set timestamp for injected frames (Íñigo Huguet) [2004141]
- rndis_wlan: simplify is_associated() (Íñigo Huguet) [2004141]
- rt2x00: remove leading spaces before tabs (Íñigo Huguet) [2004141]
- rtlwifi: Fix wrong function name in comments (Íñigo Huguet) [2004141]
- brcmsmac: Remove the repeated declaration (Íñigo Huguet) [2004141]
- brcmsmac: mac80211_if: Fix a resource leak in an error handling path (Íñigo Huguet) [2004141]
- brcmsmac: Drop unnecessary NULL check after container_of (Íñigo Huguet) [2004141]
- brcmsmac: improve readability on addresses copy (Íñigo Huguet) [2004141]
- brcmfmac: Add clm_blob firmware files to modinfo (Íñigo Huguet) [2004141]
- brcmfmac: Delete second brcm folder hierarchy (Íñigo Huguet) [2004141]
- brcmfmac: Fix a double-free in brcmf_sdio_bus_reset (Íñigo Huguet) [2004141]
- brcmfmac: Demote non-compliant kernel-doc headers (Íñigo Huguet) [2004141]
- brcmfmac: correctly report average RSSI in station info (Íñigo Huguet) [2004141]
- brcmfmac: fix setting of station info chains bitmask (Íñigo Huguet) [2004141]
- brcmfmac: use ISO3166 country code and 0 rev as fallback (Íñigo Huguet) [2004141]
- ath10k: remove unused more_frags variable (Íñigo Huguet) [2004141]
- ath10k: add missing error return code in ath10k_pci_probe() (Íñigo Huguet) [2004141]
- ath10k: go to path err_unsupported when chip id is not supported (Íñigo Huguet) [2004141]
- ath11k: don't call ath11k_pci_set_l1ss for WCN6855 (Íñigo Huguet) [2004141]
- ath11k: add support for WCN6855 (Íñigo Huguet) [2004141]
- ath11k: add support to get peer id for WCN6855 (Íñigo Huguet) [2004141]
- ath11k: setup WBM_IDLE_LINK ring once again (Íñigo Huguet) [2004141]
- ath11k: setup REO for WCN6855 (Íñigo Huguet) [2004141]
- ath11k: add dp support for WCN6855 (Íñigo Huguet) [2004141]
- ath11k: add hw reg support for WCN6855 (Íñigo Huguet) [2004141]
- ath9k: Fix kernel NULL pointer dereference during ath_reset_internal() (Íñigo Huguet) [2004141]
- mwifiex: bring down link before deleting interface (Íñigo Huguet) [2004141]
- mt76: mt7615: Use devm_platform_get_and_ioremap_resource() (Íñigo Huguet) [2004141]
- wwan: core: add WWAN common private data for netdev (Íñigo Huguet) [2004141]
- wwan: core: support default netdev creation (Íñigo Huguet) [2004141]
- wwan: core: no more hold netdev ops owning module (Íñigo Huguet) [2004141]
- net: mhi_net: Update the transmit handler prototype (Íñigo Huguet) [2004141]
- bus: mhi: pci-generic: Fix hibernation (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Fix possible use-after-free in mhi_pci_remove() (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: T99W175: update channel name from AT to DUN (Íñigo Huguet) [2004141]
- mac80211: drop multicast fragments (Íñigo Huguet) [2004141]
- mac80211: move interface shutdown out of wiphy lock (Íñigo Huguet) [2004141]
- cfg80211: shut down interfaces on failed resume (Íñigo Huguet) [2004141]
- cfg80211: fix phy80211 symlink creation (Íñigo Huguet) [2004141]
- mac80211: fix 'reset' debugfs locking (Íñigo Huguet) [2004141]
- mac80211: fix deadlock in AP/VLAN handling (Íñigo Huguet) [2004141]
- mac80211: Fix NULL ptr deref for injected rate info (Íñigo Huguet) [2004141]
- mac80211: fix skb length check in ieee80211_scan_rx() (Íñigo Huguet) [2004141]
- mac80211: correct ieee80211_iterate_active_interfaces_mtx() locking comments (Íñigo Huguet) [2004141]
- cfg80211: call cfg80211_leave_ocb when switching away from OCB (Íñigo Huguet) [2004141]
- mac80211_hwsim: drop pending frames on stop (Íñigo Huguet) [2004141]
- mac80211: remove warning in ieee80211_get_sband() (Íñigo Huguet) [2004141]
- mt76: mt7921: remove leftover 80+80 HE capability (Íñigo Huguet) [2004141]
- mt76: mt7615: do not set MT76_STATE_PM at bootstrap (Íñigo Huguet) [2004141]
- ath9k: ar9003_mac: read STBC indicator from rx descriptor (Íñigo Huguet) [2004141]
- ath10k/ath11k: fix spelling mistake "requed" -> "requeued" (Íñigo Huguet) [2004141]
- mwifiex: re-fix for unaligned accesses (Íñigo Huguet) [2004141]
- mt76: mt76x0e: fix device hang during suspend/resume (Íñigo Huguet) [2004141]
- mt76: mt7921: fix max aggregation subframes setting (Íñigo Huguet) [2004141]
- mt76: connac: fix HT A-MPDU setting field in STA_REC_PHY (Íñigo Huguet) [2004141]
- mt76: connac: do not schedule mac_work if the device is not running (Íñigo Huguet) [2004141]
- mt76: mt7921: fix possible AOOB issue in mt7921_mcu_tx_rate_report (Íñigo Huguet) [2004141]
- brcmfmac: properly check for bus register errors (Íñigo Huguet) [2004141]
- Revert "brcmfmac: add a check for the status of usb_register" (Íñigo Huguet) [2004141]
- net: rtlwifi: properly check for alloc_workqueue() failure (Íñigo Huguet) [2004141]
- Revert "rtlwifi: fix a potential NULL pointer dereference" (Íñigo Huguet) [2004141]
- wl3501_cs: Fix out-of-bounds warnings in wl3501_mgmt_join (Íñigo Huguet) [2004141]
- wl3501_cs: Fix out-of-bounds warnings in wl3501_send_pkt (Íñigo Huguet) [2004141]
- iwlwifi: mvm: tt: Replace thermal_notify_framework (Íñigo Huguet) [2004141]
- mt76: debugfs: introduce napi_threaded node (Íñigo Huguet) [2004141]
- wl3501: fix typo of 'Networks' in comment (Íñigo Huguet) [2004141]
- mt76: use threaded NAPI (Íñigo Huguet) [2004141]
- net: mhi_net: make mhi_wwan_ops static (Íñigo Huguet) [2004141]
- net: mhi_net: Register wwan_ops for link creation (Íñigo Huguet) [2004141]
- net: mhi: remove pointless conditional before kfree_skb() (Íñigo Huguet) [2004141]
- net: mhi: Allow decoupled MTU/MRU (Íñigo Huguet) [2004141]
- net: mhi: Add support for non-linear MBIM skb processing (Íñigo Huguet) [2004141]
- bus: mhi: fix typo in comments for struct mhi_channel_config (Íñigo Huguet) [2004141]
- bus: mhi: core: Fix shadow declarations (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Constify mhi_controller_config struct definitions (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Introduce Foxconn T99W175 support (Íñigo Huguet) [2004141]
- bus: mhi: core: Sanity check values from remote device before use (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Add FIREHOSE channels (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Implement PCI shutdown callback (Íñigo Huguet) [2004141]
- bus: mhi: Improve documentation on channel transfer setup APIs (Íñigo Huguet) [2004141]
- bus: mhi: core: Remove __ prefix for MHI channel unprepare function (Íñigo Huguet) [2004141]
- bus: mhi: core: Check channel execution environment before issuing reset (Íñigo Huguet) [2004141]
- bus: mhi: core: Clear configuration from channel context during reset (Íñigo Huguet) [2004141]
- bus: mhi: core: Hold device wake for channel update commands (Íñigo Huguet) [2004141]
- bus: mhi: core: Update debug messages to use client device (Íñigo Huguet) [2004141]
- bus: mhi: core: Improvements to the channel handling state machine (Íñigo Huguet) [2004141]
- bus: mhi: core: Clear context for stopped channels from remove() (Íñigo Huguet) [2004141]
- bus: mhi: core: Allow sending the STOP channel command (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Add SDX65 based modem support (Íñigo Huguet) [2004141]
- bus: mhi: core: Remove pre_init flag used for power purposes (Íñigo Huguet) [2004141]
- bus: mhi: pm: reduce PM state change verbosity (Íñigo Huguet) [2004141]
- bus: mhi: core: Fix MHI runtime_pm behavior (Íñigo Huguet) [2004141]
- bus: mhi: core: Move to polling method to wait for MHI ready (Íñigo Huguet) [2004141]
- bus: mhi: core: Introduce internal register poll helper function (Íñigo Huguet) [2004141]
- bus: mhi: core: Improve state strings for debug messages (Íñigo Huguet) [2004141]
- bus: mhi: core: Wait for MHI READY state in most scenarios (Íñigo Huguet) [2004141]
- bus: mhi: core: Identify Flash Programmer as a mission mode use case (Íñigo Huguet) [2004141]
- bus: mhi: core: Add support for Flash Programmer execution environment (Íñigo Huguet) [2004141]
- bus: mhi: core: Handle EDL mode entry appropriately (Íñigo Huguet) [2004141]
- bus: mhi: core: Wait for ready after an EDL firmware download (Íñigo Huguet) [2004141]
- bus: mhi: core: Rely on accurate method to determine EDL mode (Íñigo Huguet) [2004141]
- bus: mhi: core: Check state before processing power_down (Íñigo Huguet) [2004141]
- bus: mhi: core: Return EAGAIN if MHI ring is full (Íñigo Huguet) [2004141]
- net: export dev_set_threaded symbol (Íñigo Huguet) [2004141]
- bus: mhi: core: remove redundant initialization of variables state and ee (Íñigo Huguet) [2004141]
- bus: mhi: Make firmware image optional for controller (Íñigo Huguet) [2004141]
- bus: mhi: core: Add missing checks for MMIO register entries (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Add support for runtime PM (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Use generic PCI power management (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: No-Op for device_wake operations (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Add SDX24 based modem support (Íñigo Huguet) [2004141]
- bus: mhi: Early MHI resume failure in non M3 state (Íñigo Huguet) [2004141]
- bus: mhi: core: Update debug prints to include local device state (Íñigo Huguet) [2004141]
- bus: mhi: core: Process execution environment changes serially (Íñigo Huguet) [2004141]
- bus: mhi: core: Download AMSS image from appropriate function (Íñigo Huguet) [2004141]
- bus: mhi: core: Destroy SBL devices when moving to mission mode (Íñigo Huguet) [2004141]
- bus: mhi: core: Rename debugfs directory name (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Introduce quectel EM1XXGR-L support (Íñigo Huguet) [2004141]
- bus: mhi: pci_generic: Parametrable element count for events (Íñigo Huguet) [2004141]
- ath10k: Detect conf_mutex held ath10k_drain_tx() calls (Íñigo Huguet) [2004141]
- net: mhi: Add mbim proto (Íñigo Huguet) [2004141]
- net: mhi: Add rx_length_errors stat (Íñigo Huguet) [2004141]
- net: mhi: Create mhi.h (Íñigo Huguet) [2004141]
- net: mhi: Add dedicated folder (Íñigo Huguet) [2004141]
- net: mhi: Add protocol support (Íñigo Huguet) [2004141]
- net: mhi-net: Add re-aggregation of fragmented packets (Íñigo Huguet) [2004141]
- net: mhi: Get rid of local rx queue count (Íñigo Huguet) [2004141]
- net: mhi: Get RX queue size from MHI core (Íñigo Huguet) [2004141]
- net: mhi: Set wwan device type (Íñigo Huguet) [2004141]
- net: mhi: Add raw IP mode support (Íñigo Huguet) [2004141]
- net: mhi: Fix unexpected queue wake (Íñigo Huguet) [2004141]
- net: Add mhi-net driver (Íñigo Huguet) [2004141]
- ipv4: make exception cache less predictible (Antoine Tenart) [2015111] {CVE-2021-20322}
- ipv4: use siphash instead of Jenkins in fnhe_hashfun() (Antoine Tenart) [2015111] {CVE-2021-20322}
- iommu/dma: Account for min_align_mask w/swiotlb (Jerry Snitselaar) [2018601]
- swiotlb: Support aligned swiotlb buffers (Jerry Snitselaar) [2018601]
- iommu/dma: Check CONFIG_SWIOTLB more broadly (Jerry Snitselaar) [2018601]
- iommu/dma: Fold _swiotlb helpers into callers (Jerry Snitselaar) [2018601]
- iommu/dma: Skip extra sync during unmap w/swiotlb (Jerry Snitselaar) [2018601]
- iommu/dma: Fix arch_sync_dma for map (Jerry Snitselaar) [2018601]
- iommu/dma: Fix sync_sg with swiotlb (Jerry Snitselaar) [2018601]
- redhat/configs: Add CONFIG_DMA_RESTRICTED_POOL (Jerry Snitselaar) [2018601]
- swiotlb: use depends on for DMA_RESTRICTED_POOL (Jerry Snitselaar) [2018601]
- powerpc/svm: Don't issue ultracalls if !mem_encrypt_active() (Jerry Snitselaar) [2018601]
- s390/pv: fix the forcing of the swiotlb (Jerry Snitselaar) [2018601]
- swiotlb: Free tbl memory in swiotlb_exit() (Jerry Snitselaar) [2018601]
- swiotlb: Emit diagnostic in swiotlb_exit() (Jerry Snitselaar) [2018601]
- swiotlb: Convert io_default_tlb_mem to static allocation (Jerry Snitselaar) [2018601]
- swiotlb: fix implicit debugfs declarations (Jerry Snitselaar) [2018601]
- swiotlb: Add restricted DMA pool initialization (Jerry Snitselaar) [2018601]
- swiotlb: Add restricted DMA alloc/free support (Jerry Snitselaar) [2018601]
- swiotlb: Refactor swiotlb_tbl_unmap_single (Jerry Snitselaar) [2018601]
- swiotlb: Move alloc_size to swiotlb_find_slots (Jerry Snitselaar) [2018601]
- swiotlb: Use is_swiotlb_force_bounce for swiotlb data bouncing (Jerry Snitselaar) [2018601]
- swiotlb: Update is_swiotlb_active to add a struct device argument (Jerry Snitselaar) [2018601]
- swiotlb: Update is_swiotlb_buffer to add a struct device argument (Jerry Snitselaar) [2018601]
- swiotlb: Set dev->dma_io_tlb_mem to the swiotlb pool used (Jerry Snitselaar) [2018601]
- swiotlb: Refactor swiotlb_create_debugfs (Jerry Snitselaar) [2018601]
- swiotlb: Refactor swiotlb init functions (Jerry Snitselaar) [2018601]
- of: Drop superfluous ULL suffix for ~0 (Jerry Snitselaar) [2018601]
- dma-mapping: fix 32-bit overflow with CONFIG_ARM_LPAE=n (Jerry Snitselaar) [2018601]
- of/device: Update dma_range_map only when dev has valid dma-ranges (Jerry Snitselaar) [2018601]
- drivers core: Fix oops when driver probe fails (Jerry Snitselaar) [2018601]
- drivers core: Free dma_range_map when driver probe failed (Jerry Snitselaar) [2018601]
- driver core: Postpone DMA tear-down until after devres release for probe failure (Jerry Snitselaar) [2018601]
- powerpc/pseries/iommu: Fix window size for direct mapping with pmem (Jerry Snitselaar) [2018601]
- dma-mapping: add a dma_init_global_coherent helper (Jerry Snitselaar) [2018601]
- dma-mapping: simplify dma_init_coherent_memory (Jerry Snitselaar) [2018601]
- dma-debug: fix debugfs initialization order (Jerry Snitselaar) [2018601]
- dma-debug: teach add_dma_entry() about DMA_ATTR_SKIP_CPU_SYNC (Jerry Snitselaar) [2018601]
- dma-debug: fix sg checks in debug_dma_map_sg() (Jerry Snitselaar) [2018601]
- swiotlb-xen: ensure to issue well-formed XENMEM_exchange requests (Jerry Snitselaar) [2018601]
- dma-debug: prevent an error message from causing runtime problems (Jerry Snitselaar) [2018601]
- swiotlb-xen: drop DEFAULT_NSLABS (Jerry Snitselaar) [2018601]
- swiotlb-xen: arrange to have buffer info logged (Jerry Snitselaar) [2018601]
- swiotlb-xen: drop leftover __ref (Jerry Snitselaar) [2018601]
- swiotlb-xen: limit init retries (Jerry Snitselaar) [2018601]
- swiotlb-xen: suppress certain init retries (Jerry Snitselaar) [2018601]
- swiotlb-xen: maintain slab count properly (Jerry Snitselaar) [2018601]
- swiotlb-xen: fix late init retry (Jerry Snitselaar) [2018601]
- swiotlb-xen: avoid double free (Jerry Snitselaar) [2018601]
- dma-mapping: handle vmalloc addresses in dma_common_{mmap,get_sgtable} (Jerry Snitselaar) [2018601]
- dma-debug: report -EEXIST errors in add_dma_entry (Jerry Snitselaar) [2018601]
- dma-mapping: remove a trailing space (Jerry Snitselaar) [2018601]
- dma-mapping: add unlikely hint to error path in dma_mapping_error (Jerry Snitselaar) [2018601]
- dma-mapping: remove a pointless empty line in dma_alloc_coherent (Jerry Snitselaar) [2018601]
- swiotlb: Make SWIOTLB_NO_FORCE perform no allocation (Jerry Snitselaar) [2018601]
- swiotlb: remove swiotlb_nr_tbl (Jerry Snitselaar) [2018601]
- xen/swiotlb: check if the swiotlb has already been initialized (Jerry Snitselaar) [2018601]
- swiotlb: add overflow checks to swiotlb_bounce (Jerry Snitselaar) [2002023]
- swiotlb: don't override user specified size in swiotlb_adjust_size (Jerry Snitselaar) [2002023]
- swiotlb: dynamically allocate io_tlb_default_mem (Jerry Snitselaar) [2002023]
- swiotlb: move global variables into a new io_tlb_mem structure (Jerry Snitselaar) [2002023]
- xen-swiotlb: remove the unused size argument from xen_swiotlb_fixup (Jerry Snitselaar) [2018601]
- xen-swiotlb: split xen_swiotlb_init (Jerry Snitselaar) [2018601]
- swiotlb: lift the double initialization protection from xen-swiotlb (Jerry Snitselaar) [2002023]
- xen-swiotlb: remove xen_io_tlb_start and xen_io_tlb_nslabs (Jerry Snitselaar) [2018601]
- xen-swiotlb: remove xen_set_nslabs (Jerry Snitselaar) [2018601]
- xen-swiotlb: use io_tlb_end in xen_swiotlb_dma_supported (Jerry Snitselaar) [2018601]
- xen-swiotlb: use is_swiotlb_buffer in is_xen_swiotlb_buffer (Jerry Snitselaar) [2018601]
- swiotlb: split swiotlb_tbl_sync_single (Jerry Snitselaar) [2002023]
- swiotlb: manipulate orig_addr when tlb_addr has offset (Jerry Snitselaar) [2002023]
- swiotlb: move orig addr and size validation into swiotlb_bounce (Jerry Snitselaar) [2002023]
- swiotlb: remove the alloc_size parameter to swiotlb_tbl_unmap_single (Jerry Snitselaar) [2002023]
- swiotlb: Fix the type of index (Jerry Snitselaar) [2018601]
- swiotlb: Validate bounce size in the sync/unmap path (Jerry Snitselaar) [2002023]
- powerpc/svm: stop using io_tlb_start (Jerry Snitselaar) [2002023]
- nvme-pci: set min_align_mask (Jerry Snitselaar) [2002023]
- swiotlb: respect min_align_mask (Jerry Snitselaar) [2002023]
- swiotlb: don't modify orig_addr in swiotlb_tbl_sync_single (Jerry Snitselaar) [2002023]
- swiotlb: refactor swiotlb_tbl_map_single (Jerry Snitselaar) [2002023]
- swiotlb: clean up swiotlb_tbl_unmap_single (Jerry Snitselaar) [2002023]
- swiotlb: factor out a nr_slots helper (Jerry Snitselaar) [2002023]
- swiotlb: factor out an io_tlb_offset helper (Jerry Snitselaar) [2002023]
- swiotlb: add a IO_TLB_SIZE define (Jerry Snitselaar) [2002023]
- driver core: add a min_align_mask field to struct device_dma_parameters (Jerry Snitselaar) [2002023]
- sdhci: stop poking into swiotlb internals (Jerry Snitselaar) [2018601]
- driver core: lift dma_default_coherent into common code (Jerry Snitselaar) [2018601]
- dma-pool: no need to check return value of debugfs_create functions (Jerry Snitselaar) [2018601]
- powerpc/dma: Fallback to dma_ops when persistent memory present (Jerry Snitselaar) [2018601]
- dma-mapping: Allow mixing bypass and mapped DMA operation (Jerry Snitselaar) [2018601]
- dma-mapping: remove the dma_direct_set_offset export (Jerry Snitselaar) [2018601]
- dma-mapping: move more functions to dma-map-ops.h (Jerry Snitselaar) [2018601]
- dma-mapping: merge <linux/dma-noncoherent.h> into <linux/dma-map-ops.h> (Jerry Snitselaar) [2018601]
- dma-mapping: move large parts of <linux/dma-direct.h> to kernel/dma (Jerry Snitselaar) [2018601]
- dma-mapping: add (back) arch_dma_mark_clean for ia64 (Jerry Snitselaar) [2018601]
- dma-mapping: move dma-debug.h to kernel/dma/ (Jerry Snitselaar) [2018601]
- dma-mapping: split <linux/dma-mapping.h> (Jerry Snitselaar) [2018601]
- dma-mapping: introduce DMA range map, supplanting dma_pfn_offset (Jerry Snitselaar) [2018601]
- of: Make of_dma_get_range() private (Jerry Snitselaar) [2018601]
- swiotlb: fix comment on swiotlb_bounce() (Jerry Snitselaar) [2018601]
- xen/arm: introduce phys/dma translations in xen_dma_sync_for_* (Jerry Snitselaar) [2018601]
- swiotlb-xen: add struct device * parameter to xen_dma_sync_for_device (Jerry Snitselaar) [2018601]
- swiotlb-xen: add struct device * parameter to xen_dma_sync_for_cpu (Jerry Snitselaar) [2018601]
- swiotlb-xen: introduce phys_to_dma/dma_to_phys translations (Jerry Snitselaar) [2018601]
- swiotlb-xen: remove XEN_PFN_PHYS (Jerry Snitselaar) [2018601]
- swiotlb-xen: add struct device * parameter to is_xen_swiotlb_buffer (Jerry Snitselaar) [2018601]
- swiotlb-xen: add struct device * parameter to xen_bus_to_phys (Jerry Snitselaar) [2018601]
- swiotlb-xen: add struct device * parameter to xen_phys_to_bus (Jerry Snitselaar) [2018601]
- swiotlb-xen: use vmalloc_to_page on vmalloc virt addresses (Jerry Snitselaar) [2018601]
- swiotlb-xen: Convert to use macro (Jerry Snitselaar) [2018601]
- swiotlb-xen: merge xen_unmap_single into xen_swiotlb_unmap_page (Jerry Snitselaar) [2018601]
- swiotlb-xen: remove xen_swiotlb_dma_mmap and xen_swiotlb_dma_get_sgtable (Jerry Snitselaar) [2018601]
- xen/swiotlb: remember having called xen_create_contiguous_region() (Jerry Snitselaar) [2018601]
- xen/swiotlb: simplify range_straddles_page_boundary() (Jerry Snitselaar) [2018601]
- xen/swiotlb: fix condition for calling xen_destroy_contiguous_region() (Jerry Snitselaar) [2018601]
- xen/swiotlb: don't initialize swiotlb twice on arm64 (Jerry Snitselaar) [2018601]
- xen-swiotlb: use actually allocated size on check physical continuous (Jerry Snitselaar) [2018601]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Corinna Vinschen) [2039882]
- igb: Fix removal of unicast MAC filters of VFs (Corinna Vinschen) [2039882]
- net: ena: Fix error handling when calculating max IO queues number (Petr Oros) [2038158]
- net: ena: Fix wrong rx request id by resetting device (Petr Oros) [2038158]
- net: ena: Fix undefined state when tx request id is out of bounds (Petr Oros) [2038158]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Petr Oros) [2038158]
- ena: Remove rcu_read_lock() around XDP program invocation (Petr Oros) [2038158]
- net: ena: make symbol 'ena_alloc_map_page' static (Petr Oros) [2038158]
- net: ena: fix DMA mapping function issues in XDP (Petr Oros) [2038158]
- net: ena: re-organize code to improve readability (Petr Oros) [2038158]
- net: ena: Use dev_alloc() in RX buffer allocation (Petr Oros) [2038158]
- net: ena: aggregate doorbell common operations into a function (Petr Oros) [2038158]
- net: ena: fix RST format in ENA documentation file (Petr Oros) [2038158]
- net: ena: Remove module param and change message severity (Petr Oros) [2038158]
- net: ena: add jiffies of last napi call to stats (Petr Oros) [2038158]
- net: ena: use build_skb() in RX path (Petr Oros) [2038158]
- net: ena: Improve error logging in driver (Petr Oros) [2038158]
- net: ena: Remove unused code (Petr Oros) [2038158]
- net: ena: optimize data access in fast-path code (Petr Oros) [2038158]
- kasan, slub: reset tag when printing address (Nico Pache) [1954335]
- kasan: fix Kconfig check of CC_HAS_WORKING_NOSANITIZE_ADDRESS (Nico Pache) [1954335]
- Documentation: kunit: add tips for using current->kunit_test (Nico Pache) [1954335]
- kunit: fix -Wunused-function warning for __kunit_fail_current_test (Nico Pache) [1954335]
- kunit: support failure from dynamic analysis tools (Nico Pache) [1954335]
- Add KASAN KUNIT Tests to Redhat kernel-modules-internal (Nico Pache) [1954335]
- kasan, mm: fix resetting page_alloc tags for HW_TAGS (Nico Pache) [1954335]
- kasan, mm: fix conflicts with init_on_alloc/free (Nico Pache) [1954335]
- powerpc/uaccess: get rid of small constant size cases in raw_copy_{to,from}_user() (Nico Pache) [1954335]
- kasan: remove redundant config option (Nico Pache) [1954335]
- kasan: fix hwasan build for gcc (Nico Pache) [1954335]
- lib/test_kasan_module.c: suppress unused var warning (Nico Pache) [1954335]
- kasan: fix conflict with page poisoning (Nico Pache) [1954335]
- kasan: fix per-page tags for non-page_alloc pages (Nico Pache) [1954335]
- kasan: fix KASAN_STACK dependency for HW_TAGS (Nico Pache) [1954335]
- kasan: clarify that only first bug is reported in HW_TAGS (Nico Pache) [1954335]
- kasan: inline HW_TAGS helper functions (Nico Pache) [1954335]
- kasan: ensure poisoning size alignment (Nico Pache) [1954335]
- kasan, mm: optimize krealloc poisoning (Nico Pache) [1954335]
- kasan, mm: fail krealloc on freed objects (Nico Pache) [1954335]
- kasan: rework krealloc tests (Nico Pache) [1954335]
- kasan: unify large kfree checks (Nico Pache) [1954335]
- kasan: clean up setting free info in kasan_slab_free (Nico Pache) [1954335]
- kasan: optimize large kmalloc poisoning (Nico Pache) [1954335]
- kasan, mm: optimize kmalloc poisoning (Nico Pache) [1954335]
- kasan, mm: don't save alloc stacks twice (Nico Pache) [1954335]
- kasan: don't run tests when KASAN is not enabled (Nico Pache) [1954335]
- kasan: add a test for kmem_cache_alloc/free_bulk (Nico Pache) [1954335]
- kasan: add proper page allocator tests (Nico Pache) [1954335]
- kasan: fix bug detection via ksize for HW_TAGS mode (Nico Pache) [1954335]
- kasan: move _RET_IP_ to inline wrappers (Nico Pache) [1954335]
- kasan: fix memory corruption in kasan_bitops_tags test (Nico Pache) [1954335]
- kasan: rename CONFIG_TEST_KASAN_MODULE (Nico Pache) [1954335]
- kasan: add match-all tag tests (Nico Pache) [1954335]
- kasan: add macros to simplify checking test constraints (Nico Pache) [1954335]
- kasan: clean up comments in tests (Nico Pache) [1954335]
- kasan: clarify HW_TAGS impact on TBI (Nico Pache) [1954335]
- kasan: prefix global functions with kasan_ (Nico Pache) [1954335]
- kasan: fix stack traces dependency for HW_TAGS (Nico Pache) [1954335]
- kasan: make addr_has_metadata() return true for valid addresses (Nico Pache) [1954335]
- kasan: add explicit preconditions to kasan_report() (Nico Pache) [1954335]
- kasan: fix HW_TAGS boot parameters (Nico Pache) [1954335]
- kasan: fix null pointer dereference in kasan_record_aux_stack (Nico Pache) [1954335]
- kasan: update documentation (Nico Pache) [1954335]
- kasan, mm: allow cache merging with no metadata (Nico Pache) [1954335]
- kasan: sanitize objects when metadata doesn't fit (Nico Pache) [1954335]
- kasan: clarify comment in __kasan_kfree_large (Nico Pache) [1954335]
- kasan: simplify assign_tag and set_tag calls (Nico Pache) [1954335]
- kasan: don't round_up too much (Nico Pache) [1954335]
- kasan, mm: rename kasan_poison_kfree (Nico Pache) [1954335]
- kasan, mm: check kasan_enabled in annotations (Nico Pache) [1954335]
- kasan: add and integrate kasan boot parameters (Nico Pache) [1954335]
- kasan: inline (un)poison_range and check_invalid_free (Nico Pache) [1954335]
- kasan: open-code kasan_unpoison_slab (Nico Pache) [1954335]
- kasan: inline random_tag for HW_TAGS (Nico Pache) [1954335]
- kasan: inline kasan_reset_tag for tag-based modes (Nico Pache) [1954335]
- kasan: remove __kasan_unpoison_stack (Nico Pache) [1954335]
- kasan: allow VMAP_STACK for HW_TAGS mode (Nico Pache) [1954335]
- kasan, arm64: unpoison stack only with CONFIG_KASAN_STACK (Nico Pache) [1954335]
- kasan: introduce set_alloc_info (Nico Pache) [1954335]
- kasan: rename get_alloc/free_info (Nico Pache) [1954335]
- kasan: simplify quarantine_put call site (Nico Pache) [1954335]
- kasan: add documentation for hardware tag-based mode (Nico Pache) [1954335]
- kasan, mm: reset tags when accessing metadata (Nico Pache) [1954335]
- kasan, arm64: print report from tag fault handler (Nico Pache) [1954335]
- kasan, arm64: implement HW_TAGS runtime (Nico Pache) [1954335]
- kasan, arm64: expand CONFIG_KASAN checks (Nico Pache) [1954335]
- string.h: fix incompatibility between FORTIFY_SOURCE and KASAN (Nico Pache) [1954335]
- kasan, x86, s390: update undef CONFIG_KASAN (Nico Pache) [1954335]
- kasan: define KASAN_GRANULE_SIZE for HW_TAGS (Nico Pache) [1954335]
- arm64: kasan: add arch layer for memory tagging helpers (Nico Pache) [1954335]
- kasan, mm: untag page address in free_reserved_area (Nico Pache) [1954335]
- mm: Allow non-direct-map arguments to free_reserved_area() (Nico Pache) [1954335]
- kasan: introduce CONFIG_KASAN_HW_TAGS (Nico Pache) [1954335]
- kasan: separate metadata_fetch_row for each mode (Nico Pache) [1954335]
- kasan: rename SHADOW layout macros to META (Nico Pache) [1954335]
- kasan: rename print_shadow_for_address to print_memory_metadata (Nico Pache) [1954335]
- kasan: rename addr_has_shadow to addr_has_metadata (Nico Pache) [1954335]
- kasan, arm64: rename kasan_init_tags and mark as __init (Nico Pache) [1954335]
- kasan, arm64: move initialization message (Nico Pache) [1954335]
- kasan, arm64: only use kasan_depth for software modes (Nico Pache) [1954335]
- kasan, arm64: only init shadow for software modes (Nico Pache) [1954335]
- kasan: decode stack frame only with KASAN_STACK_ENABLE (Nico Pache) [1954335]
- kasan: hide invalid free check implementation (Nico Pache) [1954335]
- kasan: don't duplicate config dependencies (Nico Pache) [1954335]
- kasan: rename report and tags files (Nico Pache) [1954335]
- kasan: define KASAN_MEMORY_PER_SHADOW_PAGE (Nico Pache) [1954335]
- kasan: split out shadow.c from common.c (Nico Pache) [1954335]
- kasan: only build init.c for software modes (Nico Pache) [1954335]
- kasan: rename KASAN_SHADOW_* to KASAN_GRANULE_* (Nico Pache) [1954335]
- kasan: rename (un)poison_shadow to (un)poison_range (Nico Pache) [1954335]
- fork: support VMAP_STACK with KASAN_VMALLOC (Nico Pache) [1954335]
- kasan: shadow declarations only for software modes (Nico Pache) [1954335]
- kasan: group vmalloc code (Nico Pache) [1954335]
- kasan: KASAN_VMALLOC depends on KASAN_GENERIC (Nico Pache) [1954335]
- kasan: drop unnecessary GPL text from comment headers (Nico Pache) [1954335]
- kasan: update documentation for generic kasan (Nico Pache) [1954335]
- kasan: print workqueue stack (Nico Pache) [1954335]
- kasan: fix object remaining in offline per-cpu quarantine (Nico Pache) [1954335]
- kasan: adopt KUNIT tests to SW_TAGS mode (Nico Pache) [1954335]
- docs: kasan.rst: add two missing blank lines (Nico Pache) [1954335]
- mm: kasan: do not panic if both panic_on_warn and kasan_multishot set (Nico Pache) [1954335]
- KASAN: Testing Documentation (Nico Pache) [1954335]
- KASAN: port KASAN Tests to KUnit (Nico Pache) [1954335]
- KUnit: KASAN Integration (Nico Pache) [1954335]
- kasan/kunit: add KUnit Struct to Current Task (Nico Pache) [1954335]
- kasan: remove mentions of unsupported Clang versions (Nico Pache) [1954335]
- kbuild: move CFLAGS_{KASAN,UBSAN,KCSAN} exports to relevant Makefiles (Nico Pache) [1954335]
- s390/kasan: make shadow memory noexec (Nico Pache) [1954335]
- kasan: adjust kasan_stack_oob for tag-based mode (Nico Pache) [1954335]
- kasan: allow enabling stack tagging for tag-based mode (Nico Pache) [1954335]
- kasan: don't tag stacks allocated with pagealloc (Nico Pache) [1954335]
- lib/test_kasan.c: fix KASAN unit tests for tag-based KASAN (Nico Pache) [1954335]
- kasan: remove kasan_unpoison_stack_above_sp_to() (Nico Pache) [1954335]
- kasan: add tests for call_rcu stack recording (Nico Pache) [1954335]
- kprobes: Remove show_registers() function prototype (Nico Pache) [1954335]
- kasan: stop tests being eliminated as dead code with FORTIFY_SOURCE (Nico Pache) [1954335]
- kasan: move kasan_report() into report.c (Nico Pache) [1954335]
- kasan: stackdepot: move filter_irq_stacks() to stackdepot.c (Nico Pache) [1954335]
- lib/stackdepot.c: check depot_index before accessing the stack slab (Nico Pache) [1954335]
- lib/stackdepot: Remove obsolete functions (Nico Pache) [1954335]
- kasan: add test for invalid size in memmove (Nico Pache) [1954335]
- mm/memory-failure.c: use page_shift() in add_to_kill() (Nico Pache) [1954335]
- x86: get rid of small constant size cases in raw_copy_{to,from}_user() (Nico Pache) [1954335]
- s390/kasan: add KASAN_VMALLOC support (Nico Pache) [1954335]
- s390: move vmalloc option parsing to startup code (Nico Pache) [1954335]
- kasan: add test for vmalloc (Nico Pache) [1954335]
- ehea: replace with page_shift() in ehea_is_hugepage() (Nico Pache) [1954335]
- mm: introduce page_shift() (Nico Pache) [1954335]
- lib/test_kasan.c: add roundtrip tests (Nico Pache) [1954335]
- lib/test_kasan: Add test for double-kzfree detection (Nico Pache) [1954335]
- lib/test_kasan: add bitops tests (Nico Pache) [1954335]
- asm-generic, x86: add bitops instrumentation for KASAN (Nico Pache) [1954335]
- x86: use static_cpu_has in uaccess region to avoid instrumentation (Nico Pache) [1954335]
- x86/asm: Use stricter assembly constraints in bitops (Nico Pache) [1954335]
- x86/asm: Remove dead __GNUC__ conditionals (Nico Pache) [1954335]
- s390/kasan: adapt disabled_wait usage to avoid build error (Nico Pache) [1954335]
- s390: simplify disabled_wait (Nico Pache) [1954335]
- lib/test_kasan.c: add tests for several string/memory API functions (Nico Pache) [1954335]
- arm64: Fix typo in a comment in arch/arm64/mm/kasan_init.c (Nico Pache) [1954335]
- kprobes: Remove jprobe stub API (Nico Pache) [1954335]
- Documentation/kprobes: Add how to change the execution path (Nico Pache) [1954335]
- kprobes/x86: Do not disable preempt on int3 path (Nico Pache) [1954335]
- bpf/error-inject/kprobes: Clear current_kprobe and enable preempt in kprobe (Nico Pache) [1954335]
- s390/kprobes: Don't call the ->break_handler() in s390 kprobes code (Nico Pache) [1954335]
- powerpc/kprobes: Don't call the ->break_handler() in powerpc kprobes code (Nico Pache) [1954335]
- arm64/kprobes: Don't call the ->break_handler() in arm64 kprobes code (Nico Pache) [1954335]
- kprobes/x86: Don't call the ->break_handler() in x86 kprobes (Nico Pache) [1954335]
- kprobes: Don't check the ->break_handler() in generic kprobes code (Nico Pache) [1954335]
- kprobes/x86: Remove jprobe implementation (Nico Pache) [1954335]
- s390/kprobes: Remove jprobe implementation (Nico Pache) [1954335]
- powerpc/kprobes: Remove jprobe powerpc implementation (Nico Pache) [1954335]
- arm64/kprobes: Remove jprobe implementation (Nico Pache) [1954335]
- kprobes: Remove jprobe API implementation (Nico Pache) [1954335]
- Documentation/kprobes: Remove jprobes related leftover (Nico Pache) [1954335]
- redhat: config: explicitly set CONFIG_ARM64_VA_BITS_48 for ARM64 (Nico Pache) [1954335]
- arm64: mm: use a 48-bit ID map when possible on 52-bit VA builds (Nico Pache) [1954335]
- arm64: mm: limit linear region to 51 bits for KVM in nVHE mode (Nico Pache) [1954335]
- Documentation/arm64: fix RST layout of memory.rst (Nico Pache) [1954335]
- arm64: mm: Remove MAX_USER_VA_BITS definition (Nico Pache) [1954335]
- arm64: Use simpler arithmetics for the linear map macros (Nico Pache) [1954335]
- arm64: mm: use single quantity to represent the PA to VA translation (Nico Pache) [1954335]
- kasan/arm64: fix CONFIG_KASAN_SW_TAGS && KASAN_INLINE (Nico Pache) [1954335]
- arm64: Do not pass tagged addresses to __is_lm_address() (Nico Pache) [1954335]
- arm64: Fix kernel address detection of __is_lm_address() (Nico Pache) [1954335]
- arm64: mm: extend linear region for 52-bit VA configurations (Nico Pache) [1954335]
- arm64: Fix kcore macros after 52-bit virtual addressing fallout (Nico Pache) [1954335]
- arm64: fix fixmap copy for 16K pages and 48-bit VA (Nico Pache) [1954335]
- arm64: memory: rename VA_START to PAGE_END (Nico Pache) [1954335]
- arm64: memory: Simplify _VA_START and _PAGE_OFFSET definitions (Nico Pache) [1954335]
- arm64: memory: fix flipped VA space fallout (Nico Pache) [1954335]
- arm64: memory: Fix virt_addr_valid() using __is_lm_address() (Nico Pache) [1954335]
- arm64: memory: Ensure address tag is masked in conversion macros (Nico Pache) [1954335]
- arm64: mm: Simplify definition of virt_addr_valid() (Nico Pache) [1954335]
- docs: arm64: Add layout and 52-bit info to memory document (Nico Pache) [1954335]
- arm64: mm: Remove vabits_user (Nico Pache) [1954335]
- arm64: mm: Introduce 52-bit Kernel VAs (Nico Pache) [1954335]
- arm64: mm: Modify calculation of VMEMMAP_SIZE (Nico Pache) [1954335]
- arm64: mm: Separate out vmemmap (Nico Pache) [1954335]
- arm64: mm: Logic to make offset_ttbr1 conditional (Nico Pache) [1954335]
- arm64: mm: Introduce vabits_actual (Nico Pache) [1954335]
- arm64: Print physical address of page table base in show_pte() (Nico Pache) [1954335]
- arm64: mm: Introduce VA_BITS_MIN (Nico Pache) [1954335]
- arm64: dump: De-constify VA_START and KASAN_SHADOW_START (Nico Pache) [1954335]
- arm64: kasan: Switch to using KASAN_SHADOW_OFFSET (Nico Pache) [1954335]
- arm64: mm: Flip kernel VA space (Nico Pache) [1954335]
- arm64: mm: Remove bit-masking optimisations for PAGE_OFFSET and VMEMMAP_START (Nico Pache) [1954335]
- arm64: dump: Use consistent capitalisation for page-table dumps (Nico Pache) [1954335]
- kernel/rwsem: Use proper directories for rwsem_init.c (Scott Wood) [2040087]
- redhat: Cleanup use of mark_hardware_removed (Prarit Bhargava) [2019378]
- redhat: Cleanup use of mark_hardware_unsupported (Prarit Bhargava) [2019378]
- redhat: clean up mark_hardware_deprecated() (Prarit Bhargava) [2019378]
- nvme: Mark NVMe over FC Target support unmaintained (Prarit Bhargava) [2019378]
- hdlc_fr: Mark driver unmaintained (Prarit Bhargava) [2019378]
- sfc: Mark siena driver deprecated (Prarit Bhargava) [2019378]
- qla3xxx: Mark driver unmaintained (Prarit Bhargava) [2019378]
- netxen: Mark nic driver unmaintained (Prarit Bhargava) [2019378]
- ethoc: Mark driver unmaintained (Prarit Bhargava) [2019378]
- dnet: Mark driver unmaintained (Prarit Bhargava) [2019378]
- drivers/pci/pci-driver.c: Fix if/ifdef typo (Prarit Bhargava) [2019378]
- kernel/rh_taint.c: Update to new messaging (Prarit Bhargava) [2019378]
- drm/i915/dmc: Change max DMC FW size on ADL-P (Michel Dänzer) [1988103]
- drm/i915: Add workaround numbers to GEN7_COMMON_SLICE_CHICKEN1 whitelisting (Michel Dänzer) [1988103]
- drm/i915: Fix Memory BW formulae for ADL-P (Michel Dänzer) [1988103]
- drm/i915: Restore memory mapping for DPT FBs across system suspend/resume (Michel Dänzer) [1988103]
- drm/i915: Factor out i915_ggtt_suspend_vm/i915_ggtt_resume_vm() (Michel Dänzer) [1988103]
- drm/i915/adlp/fb: Remove restriction on CCS AUX plane strides (Michel Dänzer) [1988103]
- drm/i915/adlp/fb: Remove restriction on semiplanar UV plane offset (Michel Dänzer) [1988103]
- drm/i915/fb: Rename i915_color_plane_view::stride to mapping_stride (Michel Dänzer) [1988103]
- drm/i915/adlp/fb: Fix remapping of linear CCS AUX surfaces (Michel Dänzer) [1988103]
- drm/i915/fb: Factor out functions to remap contiguous FB obj pages (Michel Dänzer) [1988103]
- drm/i915/adlp/fb: Prevent the mapping of redundant trailing padding NULL pages (Michel Dänzer) [1988103]
- drm/i915: Add functions to check for RC CCS CC and MC CCS modifiers (Michel Dänzer) [1988103]
- drm/i915: Move is_ccs_modifier() to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915: Add a platform independent way to check for CCS AUX planes (Michel Dänzer) [1988103]
- drm/i915: Handle CCS CC planes separately from CCS AUX planes (Michel Dänzer) [1988103]
- drm/i915: Add a platform independent way to get the RC CCS CC plane (Michel Dänzer) [1988103]
- drm/i915: Move intel_format_info_is_yuv_semiplanar() to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915: Unexport is_semiplanar_uv_plane() (Michel Dänzer) [1988103]
- drm/i915: Simplify the modifier check for interlaced scanout support (Michel Dänzer) [1988103]
- drm/i915: Add tiling attribute to the modifier descriptor (Michel Dänzer) [1988103]
- drm/i915: Move intel_get_format_info() to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915: Add a table with a descriptor for all i915 modifiers (Michel Dänzer) [1988103]
- drm/i915/adlp: Implement workaround 16013190616 (Michel Dänzer) [1988103]
- drm/i915/adlp: Extend PSR2 support in transcoder B (Michel Dänzer) [1988103]
- drm/i915/display: Wait PSR2 get out of deep sleep to update pipe (Michel Dänzer) [1988103]
- drm/i915/display/adlp: Allow PSR2 to be enabled (Michel Dänzer) [1988103]
- drm/i915/display/adlp: Optimize PSR2 power-savings in corner cases (Michel Dänzer) [1988103]
- drm/i915/display: Fix glitches when moving cursor with PSR2 selective fetch enabled (Michel Dänzer) [1988103]
- drm/i915/display: Handle frontbuffer rendering when PSR2 selective fetch is enabled (Michel Dänzer) [1988103]
- drm/i915/display: Drop unnecessary frontbuffer flushes (Michel Dänzer) [1988103]
- drm/i915/display/psr: Do full fetch when handling multi-planar formats (Michel Dänzer) [1988103]
- drm/i915/display/psr: Handle plane and pipe restrictions at every page flip (Michel Dänzer) [1988103]
- drm/i915/display: Only keep PSR enabled if there is active planes (Michel Dänzer) [1988103]
- drm/i915/display: Match PSR2 selective fetch sequences with specification (Michel Dänzer) [1988103]
- drm/i915/display/dmc: Set DC_STATE_DEBUG_MASK_CORES after firmware load (Michel Dänzer) [1988103]
- drm/i915: Nuke intel_prepare_shared_dpll() (Michel Dänzer) [1988103]
- drm/i915: Fold ibx_pch_dpll_prepare() into ibx_pch_dpll_enable() (Michel Dänzer) [1988103]
- drm/i915: Fold i9xx_set_pll_dividers() into i9xx_enable_pll() (Michel Dänzer) [1988103]
- drm/i915: Reuse ilk_needs_fb_cb_tune() for the reduced clock as well (Michel Dänzer) [1988103]
- drm/i915: Call {vlv,chv}_prepare_pll() from {vlv,chv}_enable_pll() (Michel Dänzer) [1988103]
- drm/i915: Program DPLL P1 dividers consistently (Michel Dänzer) [1988103]
- drm/i915: Remove the 'reg' local variable (Michel Dänzer) [1988103]
- drm/i915: Clean up variable names in old dpll functions (Michel Dänzer) [1988103]
- drm/i915: Clean dpll calling convention (Michel Dänzer) [1988103]
- drm/i915: Constify struct dpll all over (Michel Dänzer) [1988103]
- drm/i915: Extract ilk_update_pll_dividers() (Michel Dänzer) [1988103]
- drm/i915: Clean up gen2 DPLL readout (Michel Dänzer) [1988103]
- drm/i915: Set output_types to EDP for vlv/chv DPLL forcing (Michel Dänzer) [1988103]
- drm/i915: Silence __iomem sparse warn (Michel Dänzer) [1988103]
- drm/i915: split fdi link training from display vtable. (Michel Dänzer) [1988103]
- drm/i915: split irq hotplug function from display vtable (Michel Dänzer) [1988103]
- drm/i915: split cdclk functions from display vtable. (Michel Dänzer) [1988103]
- drm/i915: split audio functions from display vtable (Michel Dänzer) [1988103]
- drm/i915: split color functions from display vtable (Michel Dänzer) [1988103]
- drm/i915: split watermark vfuncs from display vtable. (Michel Dänzer) [1988103]
- drm/i915: split clock gating init from display vtable (Michel Dänzer) [1988103]
- drm/i915/display: add intel_fdi_link_train wrapper. (Michel Dänzer) [1988103]
- drm/i915: add wrappers around cdclk vtable funcs. (Michel Dänzer) [1988103]
- drm/i915/wm: provide wrappers around watermark vfuncs calls (v3) (Michel Dänzer) [1988103]
- drm/i915: make update_wm take a dev_priv. (Michel Dänzer) [1988103]
- drm/i915/pm: drop get_fifo_size vfunc. (Michel Dänzer) [1988103]
- drm/i915: Clean up pre-skl wm calling convention (Michel Dänzer) [1988103]
- drm/i915/dmc: Update to DMC v2.12 (Michel Dänzer) [1988103]
- drm/i915: Implement PSF GV point support (Michel Dänzer) [1988103]
- drm/i915: Extend QGV point restrict mask to 0x3 (Michel Dänzer) [1988103]
- drm/i915/display: Disable audio, DRRS and PSR before planes (Michel Dänzer) [1988103]
- drm/i915: Make display workaround upper bounds exclusive (Michel Dänzer) [1988103]
- drm/i915: Program DFR enable/disable as a GT workaround (Michel Dänzer) [1988103]
- drm/i915/step: s/<platform>_revid_tbl/<platform>_revids (Michel Dänzer) [1988103]
- drm/i915/display: Settle on "adl-x" in WA comments (Michel Dänzer) [1988103]
- drm/i915: Settle on "adl-x" in WA comments (Michel Dänzer) [1988103]
- drm/i915/display/adlp: Disable underrun recovery (Michel Dänzer) [1988103]
- drm/i915/tc: Fix system hang on ADL-P during TypeC PHY disconnect (Michel Dänzer) [1988103]
- drm/i915/tc: Drop extra TC cold blocking from intel_tc_port_connected() (Michel Dänzer) [1988103]
- drm/i915/tc: Fix TypeC PHY connect/disconnect logic on ADL-P (Michel Dänzer) [1988103]
- drm/i915/icl/tc: Remove the ICL special casing during TC-cold blocking (Michel Dänzer) [1988103]
- drm/i915/tc: Avoid using legacy AUX PW in TBT mode (Michel Dänzer) [1988103]
- drm/i915/tc: Refactor TC-cold block/unblock helpers (Michel Dänzer) [1988103]
- drm/i915/tc: Add a mode for the TypeC PHY's disconnected state (Michel Dänzer) [1988103]
- drm/i915/tc: Don't keep legacy TypeC ports in connected state w/o a sink (Michel Dänzer) [1988103]
- drm/i915/tc: Add/use helpers to retrieve TypeC port properties (Michel Dänzer) [1988103]
- drm/i915/tc: Check for DP-alt, legacy sinks before taking PHY ownership (Michel Dänzer) [1988103]
- drm/i915/tc: Remove waiting for PHY complete during releasing ownership (Michel Dänzer) [1988103]
- drm/i915/adlp/tc: Fix PHY connected check for Thunderbolt mode (Michel Dänzer) [1988103]
- drm/i915: Force a TypeC PHY disconnect during suspend/shutdown (Michel Dänzer) [1988103]
- drm/i915/adlp: Add support for remapping CCS FBs (Michel Dänzer) [1988103]
- drm/i915: Follow a new->old platform check order in intel_fb_stride_alignment (Michel Dänzer) [1988103]
- drm/i915/adlp: Assert that VMAs in DPT start at 0 (Michel Dänzer) [1988103]
- drm/i915/adlp: Require always a power-of-two sized CCS surface stride (Michel Dänzer) [1988103]
- drm/i915: Use tile block based dimensions for CCS origin x, y check (Michel Dänzer) [1988103]
- drm/i915/fb: move user framebuffer stuff to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915/display: split out dpt out of intel_display.c (Michel Dänzer) [1988103]
- drm/i915/fb: move intel_surf_alignment() to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915: add HAS_ASYNC_FLIPS feature macro (Michel Dänzer) [1988103]
- drm/i915/fb: move intel_fb_align_height() to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915/fb: move intel_tile_width_bytes() to intel_fb.c (Michel Dänzer) [1988103]
- drm/i915/display/adlp: Add new PSR2 workarounds (Michel Dänzer) [1988103]
- drm/i915: Program chicken bit during DP MST sequence on TGL+ (Michel Dänzer) [1988103]
- drm/i915/display: Workaround cursor left overs with PSR2 selective fetch enabled (Michel Dänzer) [1988103]
- drm/i915/display/adlp: Fix PSR2_MAN_TRK_CTL_SU_REGION_END_ADDR calculation (Michel Dänzer) [1988103]
- drm/i915: Update memory bandwidth parameters (Michel Dänzer) [1988103]
- drm/i915/dp: fix for ADL_P/S dp/edp max source rates (Michel Dänzer) [1988103]
- drm/i915/dp: fix DG1 and RKL max source rates (Michel Dänzer) [1988103]
- drm/i915/dp: fix EHL/JSL max source rates calculation (Michel Dänzer) [1988103]
- drm/i915/dp: fix TGL and ICL max source rates (Michel Dänzer) [1988103]
- drm/i915/dp: Fix eDP max rate for display 11+ (Michel Dänzer) [1988103]
- drm/i915/dp: fix DG2 max source rate check (Michel Dänzer) [1988103]
- drm/i915/dg2: add DG2 UHBR source rates (Michel Dänzer) [1988103]
- drm/i915/display: remove explicit CNL handling from intel_dp.c (Michel Dänzer) [1988103]
- drm/i915/dsi/xelpd: Enable mipi dsi support. (Michel Dänzer) [1988103]
- drm/i915/dsi/xelpd: Add WA to program LP to HS wakeup guardband (Michel Dänzer) [1988103]
- drm/i915/display: Update small joiner ram size (Michel Dänzer) [1988103]
- drm/i915/adl_p: Also disable underrun recovery with MSO (Michel Dänzer) [1988103]
- drm/i915/display/adl_p: Correctly program MBUS DBOX A credits (Michel Dänzer) [1988103]
- drm/i915: Apply CMTG clock disabling WA while DPLL0 is enabled (Michel Dänzer) [1988103]
- drm/i915/adl_p: Add ddi buf translation tables for combo PHY (Michel Dänzer) [1988103]
- drm/i915/adl_s: Update ddi buf translation tables (Michel Dänzer) [1988103]
- drm/i915: Add the missing adls vswing tables (Michel Dänzer) [1988103]
- drm/i915/adlp: Add workaround to disable CMTG clock gating (Michel Dänzer) [1988103]
- drm/i915/adl_p: Allow underrun recovery when possible (Michel Dänzer) [1988103]
- drm/i915: Add dummy IS_DG2 definition (Michel Dänzer) [1988103]
- drm/i915: Extend Wa_1406941453 to adl-p (Michel Dänzer) [1988103]
- drm/i915/display/adl_p: Implement PSR changes (Michel Dänzer) [1988103]
- drm/i915/debugfs: DISPLAY_VER 13 lpsp capability (Michel Dänzer) [1988103]
- drm/i915/adlp: Add ADL-P GuC/HuC firmware files (Michel Dänzer) [1988103]
- drm/i915/huc: Update TGL and friends to HuC 7.9.3 (Michel Dänzer) [1988103]
- drm/i915/guc: Update firmware to v62.0.0 (Michel Dänzer) [1988103]
- drm/i915/guc: Introduce unified HXG messages (Michel Dänzer) [1988103]
- drm/i915/display/adl_p: Implement Wa_16011303918 (Michel Dänzer) [1988103]
- drm/i915/xelpd: Handle PSR2 SDP indication in the prior scanline (Michel Dänzer) [1988103]
- drm/i915/display/psr: Handle SU Y granularity (Michel Dänzer) [1988103]
- drm/i915/display/adl_p: Implement Wa_16011168373 (Michel Dänzer) [1988103]
- drm/i915/display/adl_p: Implement Wa_22012278275 (Michel Dänzer) [1988103]
- drm/i915: Nuke buf_trans hdmi functions (Michel Dänzer) [1988103]
- drm/i915: Clean up jsl/ehl buf trans functions (Michel Dänzer) [1988103]
- drm/i915: Fix ehl edp hbr2 vswing table (Michel Dänzer) [1988103]
- drm/i915: Deduplicate icl DP HBR2 vs. eDP HBR3 table (Michel Dänzer) [1988103]
- drm/i915: Fix dg1 buf trans tables (Michel Dänzer) [1988103]
- drm/i915: Introduce rkl_get_combo_buf_trans() (Michel Dänzer) [1988103]
- drm/i915: Clean up hsw/bdw/skl/kbl buf trans funcs (Michel Dänzer) [1988103]
- drm/i915: Introduce encoder->get_buf_trans() (Michel Dänzer) [1988103]
- drm/i915: Store the HDMI default entry in the bug trans struct (Michel Dänzer) [1988103]
- drm/i915; Return the whole buf_trans struct from get_buf_trans() (Michel Dänzer) [1988103]
- drm/i915: Introduce intel_get_buf_trans() (Michel Dänzer) [1988103]
- drm/i915: Wrap the buf trans tables into a struct (Michel Dänzer) [1988103]
- drm/i915: Rename dkl phy buf trans tables (Michel Dänzer) [1988103]
- drm/i915: Wrap the platform specific buf trans structs into a union (Michel Dänzer) [1988103]
- drm/i915: Introduce hsw_get_buf_trans() (Michel Dänzer) [1988103]
- drm/i915: s/intel/hsw/ for hsw/bdw/skl buf trans (Michel Dänzer) [1988103]
- drm/i915/adl_p: Load DMC (Michel Dänzer) [1988103]
- drm/i915/adl_p: Pipe B DMC Support (Michel Dänzer) [1988103]
- drm/i915/xelpd: Pipe A DMC plugging (Michel Dänzer) [1988103]
- drm/i915/dmc: Introduce DMC_FW_MAIN (Michel Dänzer) [1988103]
- drm/i915/adl_p: Add initial ADL_P Workarounds (Michel Dänzer) [1988103]
- drm/i915/xelpd: break feature inheritance (Michel Dänzer) [1988103]
- backlight: backlight: Make of_find_backlight static (Jérôme Glisse) [1988103]
- backlight: backlight: Drop backlight_put() (Jérôme Glisse) [1988103]
- backlight: backlight: Introduce backlight_get_brightness() (Jérôme Glisse) [1988103]
- backlight: backlight: Drop extern from prototypes (Jérôme Glisse) [1988103]
- backlight: generic_bl: Remove this driver as it is unused (Michel Dänzer) [1988103]
- backlight: backlight: Document enums in backlight.h (Jérôme Glisse) [1988103]
- backlight: backlight: Document inline functions in backlight.h (Jérôme Glisse) [1988103]
- backlight: backlight: Improve backlight_device documentation (Jérôme Glisse) [1988103]
- backlight: backlight: Improve backlight_properties documentation (Jérôme Glisse) [1988103]
- backlight: backlight: Improve backlight_ops documentation (Jérôme Glisse) [1988103]
- backlight: backlight: Add backlight_is_blank() (Jérôme Glisse) [1988103]
- backlight: Add backlight_device_get_by_name() (Jérôme Glisse) [1988103]
- backlight: Expose brightness curve type through sysfs (Michel Dänzer) [1988103]
- backlight: Remove obsolete comment for ->state (Jérôme Glisse) [1988103]
- x86/gpu: add JasperLake to gen11 early quirks (Michel Dänzer) [1988103]
- drm/i915/adl_p: ADL_P device info enabling (Michel Dänzer) [1988103]
- redhat/configs: Disable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1988103]
- drm/amd/display: Reduce stack size for dml31 UseMinimumDCFCLK (Michel Dänzer) [1988103]
- drm/amd/display: Reduce stack size for dml31_ModeSupportAndSystemConfigurationFull (Michel Dänzer) [1988103]
- drm/amdgpu: Initialize max/min_dpm_level (Michel Dänzer) [1988103]
- redhat/configs: Disable CONFIG_HSA_AMD_SVM for now (Michel Dänzer) [1988103]
- i915: Convert to older tasklet API (Michel Dänzer) [1988103]
- drm/ttm: Include asm/pgtable.h (Michel Dänzer) [1988103]
- Merge DRM changes from upstream v5.13..v5.14.21 (Michel Dänzer) [1988103]
- PCI: Add support for dev_groups to struct pci_driver (Jérôme Glisse) [1988103]
- drm: Initialize some local variables to avoid compiler warnings (Jérôme Glisse) [1988103]
- drm: Use swiotlb_nr_tbl instead of is_swiotlb_active (Jérôme Glisse) [1988103]
- i915: Use mdev_type_kobj_to_group_id instead of mtype_get_type_group_id (Jérôme Glisse) [1988103]
- i915: Convert to older tasklet API (Jérôme Glisse) [1988103]
- drm: Drop const from list_sort compare function prototypes (Jérôme Glisse) [1988103]
- Merge DRM changes from upstream v5.12.14..v5.13 (Michel Dänzer) [1988103]
- vfio/mdev: add helper to get index of mdev_type sysfs file (Jérôme Glisse) [1988103]
- drm/syncobj: make lockdep complain on WAIT_FOR_SUBMIT v3 (Jérôme Glisse) [1988103]
- Revert "drm/i915: Implement Wa_1508744258" (Michel Dänzer) [1988103]
- Revert "drm/i915: Add the missing adls vswing tables" (Michel Dänzer) [1988103]
- x86/gpu: Add Alderlake-S stolen memory support (Michel Dänzer) [1988103]
- x86/gpu: add RKL stolen memory support (Michel Dänzer) [1988103]
- x86/gpu: add TGL stolen memory support (Michel Dänzer) [1988103]
- x86/gpu: add ElkhartLake to gen11 early quirks (Michel Dänzer) [1988103]
- x86/gpu: reserve ICL's graphics stolen memory (Michel Dänzer) [1988103]
- selftest/x86/signal: Include test cases for validating sigaltstack (Prarit Bhargava) [1837321]
- x86/signal: Detect and prevent an alternate signal stack overflow (Prarit Bhargava) [1837321]
- selftest/sigaltstack: Use the AT_MINSIGSTKSZ aux vector if available (Prarit Bhargava) [1837321]
- x86/fpu: Additional cleanups (Prarit Bhargava) [1837321]
- binfmt_elf: Respect error return from `regset->active' (Prarit Bhargava) [1837321]
- x86/fpu: Optimize out sigframe xfeatures when in init state (Prarit Bhargava) [1837321]
- Documentation/x86: Add documentation for using dynamic XSTATE features (Prarit Bhargava) [1837321]
- selftests/x86/amx: Add context switch test (Prarit Bhargava) [1837321]
- selftests/x86/amx: Add test cases for AMX state management (Prarit Bhargava) [1837321]
- x86/fpu: Include vmalloc.h for vzalloc() (Prarit Bhargava) [1837321]
- x86/fpu/amx: Enable the AMX feature in 64-bit mode (Prarit Bhargava) [1837321]
- x86/fpu: Add XFD handling for dynamic states (Prarit Bhargava) [1837321]
- x86/fpu: Calculate the default sizes independently (Prarit Bhargava) [1837321]
- x86/fpu/amx: Define AMX state components and have it used for boot-time checks (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Prepare XSAVE feature table for gaps in state component numbers (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Add fpstate_realloc()/free() (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Add XFD #NM handler (Prarit Bhargava) [1837321]
- x86/fpu: Update XFD state where required (Prarit Bhargava) [1837321]
- x86/fpu: Add sanity checks for XFD (Prarit Bhargava) [1837321]
- x86/fpu: Add XFD state to fpstate (Prarit Bhargava) [1837321]
- x86/msr-index: Add MSRs for XFD (Prarit Bhargava) [1837321]
- x86/cpufeatures: Add eXtended Feature Disabling (XFD) feature bit (Prarit Bhargava) [1837321]
- x86/fpu: Reset permission and fpstate on exec() (Prarit Bhargava) [1837321]
- x86/fpu: Prepare fpu_clone() for dynamically enabled features (Prarit Bhargava) [1837321]
- x86/fpu/signal: Prepare for variable sigframe length (Prarit Bhargava) [1837321]
- x86/signal: Use fpu::__state_user_size for sigalt stack validation (Prarit Bhargava) [1837321]
- x86/fpu: Add basic helpers for dynamically enabled features (Prarit Bhargava) [1837321]
- x86/arch_prctl: Add controls for dynamic XSTATE components (Prarit Bhargava) [1837321]
- x86/fpu: Add fpu_state_config::legacy_features (Prarit Bhargava) [1837321]
- x86/fpu: Add members to struct fpu to cache permission information (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Provide xstate_calculate_size() (Prarit Bhargava) [1837321]
- x86/signal: Implement sigaltstack size validation (Prarit Bhargava) [1837321]
- signal: Add an optional check for altstack size (Prarit Bhargava) [1837321]
- x86/fpu: Remove old KVM FPU interface (Prarit Bhargava) [1837321]
- x86/kvm: Convert FPU handling to a single swap buffer (Prarit Bhargava) [1837321]
- x86/fpu: Provide infrastructure for KVM FPU cleanup (Prarit Bhargava) [1837321]
- x86/fpu: Prepare for sanitizing KVM FPU code (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Move remaining xfeature helpers to core (Prarit Bhargava) [1837321]
- x86/fpu: Rework restore_regs_from_fpstate() (Prarit Bhargava) [1837321]
- x86/fpu: Mop up xfeatures_mask_uabi() (Prarit Bhargava) [1837321]
- x86/fpu: Move xstate feature masks to fpu_*_cfg (Prarit Bhargava) [1837321]
- x86/fpu: Move xstate size to fpu_*_cfg (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Cleanup size calculations (Prarit Bhargava) [1837321]
- x86/fpu: Cleanup fpu__init_system_xstate_size_legacy() (Prarit Bhargava) [1837321]
- x86/fpu: Provide struct fpu_config (Prarit Bhargava) [1837321]
- x86/fpu/signal: Use fpstate for size and features (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Use fpstate for copy_uabi_to_xstate() (Prarit Bhargava) [1837321]
- x86/fpu: Use fpstate in __copy_xstate_to_uabi_buf() (Prarit Bhargava) [1837321]
- x86/fpu: Use fpstate in fpu_copy_kvm_uabi_to_fpstate() (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Use fpstate for xsave_to_user_sigframe() (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Use fpstate for os_xsave() (Prarit Bhargava) [1837321]
- x86/fpu: Use fpstate::size (Prarit Bhargava) [1837321]
- x86/fpu: Add size and mask information to fpstate (Prarit Bhargava) [1837321]
- x86/process: Move arch_thread_struct_whitelist() out of line (Prarit Bhargava) [1837321]
- x86/fpu: Do not leak fpstate pointer on fork (Prarit Bhargava) [1837321]
- x86/fpu: Remove fpu::state (Prarit Bhargava) [1837321]
- x86/math-emu: Convert to fpstate (Prarit Bhargava) [1837321]
- x86/fpu/core: Convert to fpstate (Prarit Bhargava) [1837321]
- x86/fpu/signal: Convert to fpstate (Prarit Bhargava) [1837321]
- x86/fpu/regset: Convert to fpstate (Prarit Bhargava) [1837321]
- x86/fpu: Convert tracing to fpstate (Prarit Bhargava) [1837321]
- x86/KVM: Convert to fpstate (Prarit Bhargava) [1837321]
- x86/fpu: Replace KVMs xstate component clearing (Prarit Bhargava) [1837321]
- x86/fpu: Convert restore_fpregs_from_fpstate() to struct fpstate (Prarit Bhargava) [1837321]
- x86/fpu: Convert fpstate_init() to struct fpstate (Prarit Bhargava) [1837321]
- fpu/types.h: KABI fix Part I (Prarit Bhargava) [1837321]
- x86/fpu: Provide struct fpstate (Prarit Bhargava) [1837321]
- x86/fpu: Replace KVMs home brewed FPU copy to user (Prarit Bhargava) [1837321]
- x86/fpu: Provide a proper function for ex_handler_fprestore() (Prarit Bhargava) [1837321]
- x86/fpu: Replace the includes of fpu/internal.h (Prarit Bhargava) [1837321]
- x86/fpu: Mop up the internal.h leftovers (Prarit Bhargava) [1837321]
- x86/sev: Include fpu/xcr.h (Prarit Bhargava) [1837321]
- x86/fpu: Remove internal.h dependency from fpu/signal.h (Prarit Bhargava) [1837321]
- x86/fpu: Move fpstate functions to api.h (Prarit Bhargava) [1837321]
- x86/fpu: Move mxcsr related code to core (Prarit Bhargava) [1837321]
- x86/fpu: Move fpregs_restore_userregs() to core (Prarit Bhargava) [1837321]
- x86/fpu: Make WARN_ON_FPU() private (Prarit Bhargava) [1837321]
- x86/fpu: Move legacy ASM wrappers to core (Prarit Bhargava) [1837321]
- x86/fpu: Move os_xsave() and os_xrstor() to core (Prarit Bhargava) [1837321]
- x86/fpu: Make os_xrstor_booting() private (Prarit Bhargava) [1837321]
- x86/fpu: Clean up CPU feature tests (Prarit Bhargava) [1837321]
- x86/fpu: Move context switch and exit to user inlines into sched.h (Prarit Bhargava) [1837321]
- x86/fpu: Mark fpu__init_prepare_fx_sw_frame() as __init (Prarit Bhargava) [1837321]
- x86/fpu: Rework copy_xstate_to_uabi_buf() (Prarit Bhargava) [1837321]
- x86/fpu: Replace KVMs home brewed FPU copy from user (Prarit Bhargava) [1837321]
- x86/fpu: Move KVMs FPU swapping to FPU core (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Mark all init only functions __init (Prarit Bhargava) [1837321]
- x86/fpu/xstate: Provide and use for_each_xfeature() (Prarit Bhargava) [1837321]
- x86/fpu: Cleanup xstate xcomp_bv initialization (Prarit Bhargava) [1837321]
- x86/fpu: Do not inherit FPU context for kernel and IO worker threads (Prarit Bhargava) [1837321]
- x86/process: Clone FPU in copy_thread() (Prarit Bhargava) [1837321]
- x86/fpu: Remove pointless memset in fpu_clone() (Prarit Bhargava) [1837321]
- x86/fpu: Cleanup the on_boot_cpu clutter (Prarit Bhargava) [1837321]
- x86/fpu: Restrict xsaves()/xrstors() to independent states (Prarit Bhargava) [1837321]
- x86/pkru: Remove useless include (Prarit Bhargava) [1837321]
- x86/fpu: Update stale comments (Prarit Bhargava) [1837321]
- x86/fpu: Remove pointless argument from switch_fpu_finish() (Prarit Bhargava) [1837321]
- x86/fpu: Mask out the invalid MXCSR bits properly (Prarit Bhargava) [1837321]
- x86/fpu: Restore the masking out of reserved MXCSR bits (Prarit Bhargava) [1837321]
- x86/fpu/signal: Fix missed conversion to correct boolean retval in save_xstate_epilog() (Prarit Bhargava) [1837321]
- x86/fpu/signal: Change return code of restore_fpregs_from_user() to boolean (Prarit Bhargava) [1837321]
- x86/fpu/signal: Change return code of check_xstate_in_sigframe() to boolean (Prarit Bhargava) [1837321]
- x86/fpu/signal: Change return type of __fpu_restore_sig() to boolean (Prarit Bhargava) [1837321]
- x86/fpu/signal: Change return type of fpu__restore_sig() to boolean (Prarit Bhargava) [1837321]
- x86/signal: Change return type of restore_sigcontext() to boolean (Prarit Bhargava) [1837321]
- x86/fpu/signal: Change return type of copy_fpregs_to_sigframe() helpers to boolean (Prarit Bhargava) [1837321]
- x86/fpu/signal: Change return type of copy_fpstate_to_sigframe() to boolean (Prarit Bhargava) [1837321]
- x86/fpu/signal: Move xstate clearing out of copy_fpregs_to_sigframe() (Prarit Bhargava) [1837321]
- x86/fpu/signal: Move header zeroing out of xsave_to_user_sigframe() (Prarit Bhargava) [1837321]
- x86/fpu/signal: Clarify exception handling in restore_fpregs_from_user() (Prarit Bhargava) [1837321]
- x86/elf: Support a new ELF aux vector AT_MINSIGSTKSZ (Prarit Bhargava) [1837321]
- uapi/auxvec: Define the aux vector AT_MINSIGSTKSZ (Prarit Bhargava) [1837321]
- x86: get rid of get_user_ex() in restore_sigcontext() (Prarit Bhargava) [1837321]
- x86: get rid of get_user_ex() in ia32_restore_sigcontext() (Prarit Bhargava) [1837321]
- x86: Remove force_iret() (Prarit Bhargava) [1837321]
- x86/uaccess, signal: Fix AC=1 bloat (Prarit Bhargava) [1837321]
- x86/ia32: Fix ia32_restore_sigcontext() AC leak (Prarit Bhargava) [1837321]
- x86/tsc: Add tsc_early_khz command line parameter (Prarit Bhargava) [1957375]
- x86/debug: Support negative polarity DR6 bits (Prarit Bhargava) [2017958]

* Sun Jan 16 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-360.el8]
- KVM: SVM: Do not terminate SEV-ES guests on GHCB validation failure (Vitaly Kuznetsov) [2032931]
- KVM: SEV: Fall back to vmalloc for SEV-ES scratch area if necessary (Vitaly Kuznetsov) [2032931]
- KVM: SEV: Return appropriate error codes if SEV-ES scratch setup fails (Vitaly Kuznetsov) [2032931]
- KVM: SEV: Refactor out sev_es_state struct (Vitaly Kuznetsov) [2032931]
- s390: mm: Fix secure storage access exception handling (Thomas Huth) [1984910]
- KVM: PPC: Book3S HV: Make idle_kvm_start_guest() return 0 if it went to guest (Jon Maloy) [2018960] {CVE-2021-43056}
- KVM: PPC: Book3S HV: Fix stack handling in idle_kvm_start_guest() (Jon Maloy) [2018960] {CVE-2021-43056}
- KVM: arm64: selftests: arch_timer: Support vCPU migration (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add arch_timer test (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add host support for vGIC (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add basic GICv3 support (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add light-weight spinlock support (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add guest support to get the vcpuid (Gavin Shan) [2024808]
- KVM: arm64: selftests: Maintain consistency for vcpuid type (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add support to disable and enable local IRQs (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add basic support to generate delays (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add basic support for arch_timers (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add support for cpu_relax (Gavin Shan) [2024808]
- KVM: arm64: selftests: Introduce ARM64_SYS_KVM_REG (Gavin Shan) [2024808]
- tools: arm64: Import sysreg.h (Gavin Shan) [2024808]
- KVM: arm64: selftests: Add MMIO readl/writel support (Gavin Shan) [2024808]
- selftests: KVM: Introduce psci_cpu_on_test (Gavin Shan) [2024808]
- KVM: arm64: selftests: get-reg-list: actually enable pmu regs in pmu sublist (Gavin Shan) [2024808]
- KVM: arm64: Update MAINTAINERS to include selftests (Gavin Shan) [2024808]
- KVM: arm64: selftests: get-reg-list: Split base and pmu registers (Gavin Shan) [2024808]
- KVM: arm64: selftests: get-reg-list: Remove get-reg-list-sve (Gavin Shan) [2024808]
- KVM: arm64: selftests: get-reg-list: Provide config selection option (Gavin Shan) [2024808]
- KVM: arm64: selftests: get-reg-list: Prepare to run multiple configs at once (Gavin Shan) [2024808]
- KVM: arm64: selftests: get-reg-list: Introduce vcpu configs (Gavin Shan) [2024808]
- sctp: make the raise timer more simple and accurate (Xin Long) [2020474]
- Enable flowtable ipv4/ipv6 support (Phil Sutter) [1850324]
- ip6_vti: initialize __ip6_tnl_parm struct in vti6_siocdevprivate (William Zhao) [1941928]
- svcrdma: Fix a crash in svcrdma_counter_handler (Benjamin Coddington) [2037213]
- fbcon: Fix global-out-of-bounds read in fbcon_get_font() (Lyude Paul) [1904374]
- bnxt_en: Clean up completion ring page arrays completely (Ken Cox) [1987074]
- bnxt_en: Fix error recovery regression (Ken Cox) [1987074]
- bnxt_en: Fix possible unintended driver initiated error recovery (Ken Cox) [1987074]
- bnxt_en: Fix UDP tunnel logic (Ken Cox) [1987074]
- bnxt_en: Fix asic.rev in devlink dev info command (Ken Cox) [1987074]
- bnxt_en: fix read of stored FW_PSID version on P5 devices (Ken Cox) [1987074]
- bnxt_en: fix stored FW_PSID version masks (Ken Cox) [1987074]
- bnxt_en: fix kernel doc warnings in bnxt_hwrm.c (Ken Cox) [1987074]
- bnxt_en: Fix 64-bit doorbell operation on 32-bit kernels (Ken Cox) [1987074]
- bnxt_en: support multiple HWRM commands in flight (Ken Cox) [1987074]
- bnxt_en: remove legacy HWRM interface (Ken Cox) [1987074]
- bnxt_en: update all firmware calls to use the new APIs (Ken Cox) [1987074]
- bnxt_en: use link_lock instead of hwrm_cmd_lock to protect link_info (Ken Cox) [1987074]
- bnxt_en: add support for HWRM request slices (Ken Cox) [1987074]
- bnxt_en: add HWRM request assignment API (Ken Cox) [1987074]
- bnxt_en: discard out of sequence HWRM responses (Ken Cox) [1987074]
- bnxt_en: introduce new firmware message API based on DMA pools (Ken Cox) [1987074]
- bnxt_en: move HWRM API implementation into separate file (Ken Cox) [1987074]
- bnxt_en: Refactor the HWRM_VER_GET firmware calls (Ken Cox) [1987074]
- bnxt_en: remove DMA mapping for KONG response (Ken Cox) [1987074]
- bnxt: count discards due to memory allocation errors (Ken Cox) [1987074]
- bnxt: count packets discarded because of netpoll (Ken Cox) [1987074]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [1987074]
- bnxt_en: Add missing DMA memory barriers (Ken Cox) [1987074]
- bnxt_en: Disable aRFS if running on 212 firmware (Ken Cox) [1987074]
- bnxt: count Tx drops (Ken Cox) [1987074]
- bnxt: make sure xmit_more + errors does not miss doorbells (Ken Cox) [1987074]
- bnxt: disable napi before canceling DIM (Ken Cox) [1987074]
- bnxt: don't lock the tx queue from napi poll (Ken Cox) [1987074]
- bnxt_en: Use register window 6 instead of 5 to read the PHC (Ken Cox) [1987074]
- bnxt_en: Update firmware call to retrieve TX PTP timestamp (Ken Cox) [1987074]
- bnxt_en: Update firmware interface to 1.10.2.52 (Ken Cox) [1987074]
- bnxt_en: Increase maximum RX ring size if jumbo ring is not used (Ken Cox) [1987074]
- bnxt_en: Don't use static arrays for completion ring pages (Ken Cox) [1987074]
- bnxt_en: Add missing periodic PHC overflow check (Ken Cox) [1987074]
- bnxt_en: Log if an invalid signal detected on TSIO pin (Ken Cox) [1987074]
- bnxt_en: Event handler for PPS events (Ken Cox) [1987074 1990156]
- bnxt_en: 1PPS functions to configure TSIO pins (Ken Cox) [1987074 1990156]
- bnxt_en: 1PPS support for 5750X family chips (Ken Cox) [1987074 1990156]
- bnxt_en: Do not read the PTP PHC during chip reset (Ken Cox) [1987074 1990156]
- bnxt_en: Move bnxt_ptp_init() from bnxt_open() back to bnxt_init_one() (Ken Cox) [1987074 1990156]
- bnxt_en: Fix PTP capability discovery (Ken Cox) [1987074]
- bnxt_en: Move bnxt_ptp_init() to bnxt_open() (Ken Cox) [1987074]
- bnxt: Remove rcu_read_lock() around XDP program invocation (Ken Cox) [1987074]
- bnxt_en: Enable hardware PTP support (Ken Cox) [1987074]
- bnxt_en: Transmit and retrieve packet timestamps (Ken Cox) [1987074]
- bnxt_en: Get the RX packet timestamp (Ken Cox) [1987074]
- bnxt_en: Get the full 48-bit hardware timestamp periodically (Ken Cox) [1987074]
- bnxt_en: Add PTP clock APIs, ioctls, and ethtool methods (Ken Cox) [1987074]
- bnxt_en: Get PTP hardware capability from firmware (Ken Cox) [1987074]
- bnxt_en: Update firmware interface to 1.10.2.47 (Ken Cox) [1987074]
- bnxt_en: Fix fall-through warnings for Clang (Ken Cox) [1987074]
- bnxt_en: Fix and improve .ndo_features_check(). (Ken Cox) [1987074]
- bnxt_en: Implement .ndo_features_check(). (Ken Cox) [1987074]
- bnxt_en: Support IFF_SUPP_NOFCS feature to transmit without ethernet FCS. (Ken Cox) [1987074]
- bnxt_en: Call bnxt_approve_mac() after the PF gives up control of the VF MAC. (Ken Cox) [1987074]
- bnxt_en: Move bnxt_approve_mac(). (Ken Cox) [1987074]
- bnxt_en: allow VF config ops when PF is closed (Ken Cox) [1987074]
- bnxt_en: Add support for fw managed link down feature. (Ken Cox) [1987074]
- bnxt_en: Add a new phy_flags field to the main driver structure. (Ken Cox) [1987074]
- bnxt_en: report signal mode in link up messages (Ken Cox) [1987074]
- bnxt: add more ethtool standard stats (Ken Cox) [1987074]
- bnxt: implement ethtool standard stats (Ken Cox) [1987074]
- bnxt: implement ethtool::get_fec_stats (Ken Cox) [1987074]
- bnxt_en: Free and allocate VF-Reps during error recovery. (Ken Cox) [1987074]
- bnxt_en: Refactor __bnxt_vf_reps_destroy(). (Ken Cox) [1987074]
- bnxt_en: Refactor bnxt_vf_reps_create(). (Ken Cox) [1987074]
- bnxt_en: Invalidate health register mapping at the end of probe. (Ken Cox) [1987074]
- bnxt_en: Treat health register value 0 as valid in bnxt_try_reover_fw(). (Ken Cox) [1987074]
- bnxt_en: Enhance retry of the first message to the firmware. (Ken Cox) [1987074]
- bnxt_en: Set BNXT_STATE_FW_RESET_DET flag earlier for the RDMA driver. (Ken Cox) [1987074]
- bnxt_en: check return value of bnxt_hwrm_func_resc_qcaps (Ken Cox) [1987074]
- bnxt_en: don't fake firmware response success when PCI is disabled (Ken Cox) [1987074]
- bnxt_en: Improve wait for firmware commands completion (Ken Cox) [1987074]
- bnxt_en: Improve the status_reliable flag in bp->fw_health. (Ken Cox) [1987074]
- Bluetooth: fix use-after-free error in lock_sock_nested() (Gopal Tiwari) [2005689]
- rpmspec: add release string to kernel doc directory name (Jan Stancek) [1824836]
- cpufreq: intel_pstate: Fix cpu->pstate.turbo_freq initialization (Mark Langsdorf) [2031830]
- ACPI: CPPC: Add NULL pointer check to cppc_get_perf() (Mark Langsdorf) [2031830]
- cpufreq: intel_pstate: hybrid: Rework HWP calibration (Mark Langsdorf) [2031830]
- ACPI: CPPC: Introduce cppc_get_nominal_perf() (Mark Langsdorf) [2031830]
- cpufreq: Replace deprecated CPU-hotplug functions (Mark Langsdorf) [2031830]
- cpufreq: intel_pstate: hybrid: Fix build with CONFIG_ACPI unset (Mark Langsdorf) [2031830]
- cpufreq: intel_pstate: hybrid: CPU-specific scaling factor (Mark Langsdorf) [2031830]
- cpufreq: intel_pstate: hybrid: Avoid exposing two global attributes (Mark Langsdorf) [2031830]
- ASoC: amd: renoir: Run hibernation callbacks (Renjith Pananchikkal) [1987617]
- hugetlb: fix hugetlb cgroup refcounting during vma split (Waiman Long) [2032811]
- hugetlb_cgroup: fix imbalanced css_get and css_put pair for shared mappings (Waiman Long) [2032811]
- mm/hugetlb: change hugetlb_reserve_pages() to type bool (Waiman Long) [2032811]
- hugetlb: fix an error code in hugetlb_reserve_pages() (Waiman Long) [2032811]
- hugetlb_cgroup: fix offline of hugetlb cgroup with reservations (Waiman Long) [2032811]
- hugetlb_cgroup: fix reservation accounting (Waiman Long) [2032811]
- mm/hugetlb: narrow the hugetlb_lock protection area during preparing huge page (Waiman Long) [2032811]
- mm/hugetlb: a page from buddy is not on any list (Waiman Long) [2032811]
- mm/hugetlb: not necessary to coalesce regions recursively (Waiman Long) [2032811]
- selftests/vm/write_to_hugetlbfs.c: fix unused variable warning (Waiman Long) [2032811]
- hugetlb_cgroup: add hugetlb_cgroup reservation tests (Waiman Long) [2032811]
- hugetlb: support file_region coalescing again (Waiman Long) [2032811]
- hugetlb_cgroup: support noreserve mappings (Waiman Long) [2032811]
- hugetlb_cgroup: add accounting for shared mappings (Waiman Long) [2032811]
- hugetlb: disable region_add file_region coalescing (Waiman Long) [2032811]
- hugetlb_cgroup: add reservation accounting for private mappings (Waiman Long) [2032811]
- mm/hugetlb_cgroup: fix hugetlb_cgroup migration (Waiman Long) [2032811]
- hugetlb_cgroup: add interface for charge/uncharge hugetlb reservations (Waiman Long) [2032811]
- hugetlb_cgroup: add hugetlb_cgroup reservation counter (Waiman Long) [2032811]
- mm/vma: move VM_NO_KHUGEPAGED into generic header (Waiman Long) [2032811]
- mm/cma.c: switch to bitmap_zalloc() for cma bitmap allocation (Waiman Long) [2032811]
- hugetlb: remove duplicated code (Waiman Long) [2032811]
- hugetlb: region_chg provides only cache entry (Waiman Long) [2032811]
- arm64/mm: Refactor __do_page_fault() (Waiman Long) [2032811]
- arm64/mm: Drop task_struct argument from __do_page_fault() (Waiman Long) [2032811]
- hugetlbfs: always use address space in inode for resv_map pointer (Waiman Long) [2032811]
- mm: remove redundant 'default n' from Kconfig-s (Waiman Long) [2032811]
- hugetlbfs: fix potential over/underflow setting node specific nr_hugepages (Waiman Long) [2032811]
- hugetlb: allow to free gigantic pages regardless of the configuration (Waiman Long) [2032811]
- mm/cma.c: fix crash on CMA allocation if bitmap allocation fails (Waiman Long) [2032811]
- mm/cma.c: fix the bitmap status to show failed allocation reason (Waiman Long) [2032811]
- mm/cma_debug.c: fix the break condition in cma_maxchunk_get() (Waiman Long) [2032811]
- mm: no need to check return value of debugfs_create functions (Waiman Long) [2032811]
- x86/mm: Break out user address space handling (Waiman Long) [2032811]
- fs: add vfs_parse_fs_param_source() helper (Waiman Long) [2034609]
- cgroup: verify that source is a string (Waiman Long) [2034609]
- ice: Fix E810 PTP reset flow (Jonathan Toppins) [2013478]
- ice: Use div64_u64 instead of div_u64 in adjfine (Jonathan Toppins) [2013478]
- ice: Don't put stale timestamps in the skb (Jonathan Toppins) [2013478]
- ice: Fix problems with DSCP QoS implementation (Jonathan Toppins) [2030400]
- ice: fix software generating extra interrupts (Jonathan Toppins) [2030400]
- ice: fix rate limit update after coalesce change (Jonathan Toppins) [2030400]
- ice: update dim usage and moderation (Jonathan Toppins) [2030400]
- ice: make use of ice_for_each_* macros (Jonathan Toppins) [2030400]
- ice: Remove boolean vlan_promisc flag from function (Jonathan Toppins) [2030400]
- ice: check whether PTP is initialized in ice_ptp_release() (Jonathan Toppins) [2030400]
- ice: devlink: Make devlink_register to be void (Jonathan Toppins) [2030400]
- ice: split ice_ring onto Tx/Rx separate structs (Jonathan Toppins) [2030400]
- ice: Prefer kcalloc over open coded arithmetic (Jonathan Toppins) [2030400]
- ice: Fix macro name for IPv4 fragment flag (Jonathan Toppins) [2030400]
- ice: refactor devlink getter/fallback functions to void (Jonathan Toppins) [2030400]
- ice: Fix link mode handling (Jonathan Toppins) [2030400]
- ice: Add feature bitmap, helpers and a check for DSCP (Jonathan Toppins) [2030400]
- ice: Add DSCP support (Jonathan Toppins) [2030400]

* Mon Jan 10 2022 Augusto Caringi <acaringi@redhat.com> [4.18.0-359.el8]
- fanotify: Make waits for fanotify events only killable (Miklos Szeredi) [1897416]
- fanotify: Use interruptible wait when waiting for permission events (Miklos Szeredi) [1897416]
- fanotify: Track permission event state (Miklos Szeredi) [1897416]
- fanotify: Simplify cleaning of access_list (Miklos Szeredi) [1897416]
- fsnotify: Create function to remove event from notification list (Miklos Szeredi) [1897416]
- fanotify: Move locking inside get_one_event() (Miklos Szeredi) [1897416]
- fanotify: Fold dequeue_event() into process_access_response() (Miklos Szeredi) [1897416]
- fanotify: rename struct fanotify_{,perm_}event_info (Miklos Szeredi) [1897416]
- RDMA/mlx5: Fix crash when unbind multiport slave (Amir Tzin) [1997386]
- redhat: Fix mock.cfg cleanup in redhat/Makefile (Benjamin Coddington)
- timekeeping: Use proper clock specifier names in functions (Josef Oskera) [2026471]
- leds: ledtrig-activity: use ktime_get_boot_ns() (Josef Oskera) [2026471]
- iio: use timespec64 based interfaces for iio_get_time_ns() (Josef Oskera) [2026471]
- drivers: net: netdevsim: fix devlink_trap selftests failing (Petr Oros) [2021837]
- netdevsim: remove max_vfs dentry (Petr Oros) [2021837]
- netdevsim: Fix unsigned being compared to less than zero (Petr Oros) [2021837]
- devlink: Protect rate list with lock while switching modes (Petr Oros) [2021837]
- devlink: Remove eswitch mode check for mode set call (Petr Oros) [2021837]
- devlink: Decrease refcnt of parent rate object on leaf destroy (Petr Oros) [2021837]
- docs: networking: devlink: avoid using ReST :doc:`foo` markup (Petr Oros) [2021837]
- testing: selftests: drivers: net: netdevsim: devlink: add test case for hard drop statistics (Petr Oros) [2021837]
- drivers: net: netdevsim: add devlink trap_drop_counter_get implementation (Petr Oros) [2021837]
- testing: selftests: net: forwarding: add devlink-required functionality to test (hard) dropped stats field (Petr Oros) [2021837]
- net: core: devlink: add dropped stats traps field (Petr Oros) [2021837]
- devlink: Fix error message in devlink_rate_set_ops_supported() (Petr Oros) [2021837]
- Documentation: devlink rate objects (Petr Oros) [2021837]
- selftest: netdevsim: Add devlink rate grouping test (Petr Oros) [2021837]
- netdevsim: Allow setting parent node of rate objects (Petr Oros) [2021837]
- devlink: Allow setting parent node of rate objects (Petr Oros) [2021837]
- selftest: netdevsim: Add devlink rate nodes test (Petr Oros) [2021837]
- netdevsim: Implement support for devlink rate nodes (Petr Oros) [2021837]
- devlink: Introduce rate nodes (Petr Oros) [2021837]
- selftest: netdevsim: Add devlink port shared/max tx rate test (Petr Oros) [2021837]
- netdevsim: Implement devlink rate leafs tx rate support (Petr Oros) [2021837]
- devlink: Allow setting tx rate for devlink rate leaf objects (Petr Oros) [2021837]
- selftest: netdevsim: Add devlink rate test (Petr Oros) [2021837]
- netdevsim: Register devlink rate leaf objects per VF (Petr Oros) [2021837]
- devlink: Introduce rate object (Petr Oros) [2021837]
- netdevsim: Implement legacy/switchdev mode for VFs (Petr Oros) [2021837]
- netdevsim: Implement VFs (Petr Oros) [2021837]
- netdevsim: Implement port types and indexing (Petr Oros) [2021837]
- netdevsim: Disable VFs on nsim_dev_reload_destroy() call (Petr Oros) [2021837]
- netdevsim: Add max_vfs to bus_dev (Petr Oros) [2021837]
- devlink: append split port number to the port name (Petr Oros) [2021837]
- devlink: Correct VIRTUAL port to not have phys_port attributes (Petr Oros) [2021837]
- docs: net: add missing devlink health cmd - trigger (Petr Oros) [2021837]
- docs: net: tweak devlink health documentation (Petr Oros) [2021837]
- devlink: fix typo in documentation (Petr Oros) [2021837]
- devlink: Extend devlink port documentation for subfunctions (Petr Oros) [2021837]
- udp: Validate checksum in udp_read_sock() (Jiri Benc) [1947007]
- bpf, sockmap: sk_skb data_end access incorrect when src_reg = dst_reg (Jiri Benc) [1947007]
- bpf: sockmap, strparser, and tls are reusing qdisc_skb_cb and colliding (Jiri Benc) [1947007]
- selftests, bpf: Add one test for sockmap with strparser (Jiri Benc) [1947007]
- selftests, bpf: Fix test_txmsg_ingress_parser error (Jiri Benc) [1947007]
- skmsg: Lose offset info in sk_psock_skb_ingress (Jiri Benc) [1947007]
- bpf, sockmap: Fix potential memory leak on unlikely error case (Jiri Benc) [1947007]
- tcp_bpf: Fix one concurrency problem in the tcp_bpf_send_verdict function (Jiri Benc) [1947007]
- bpf, sockmap, tcp: sk_prot needs inuse_idx set for proc stats (Jiri Benc) [1947007]
- bpf, sockmap: Fix memleak on ingress msg enqueue (Jiri Benc) [1947007]
- bpf, sockmap: On cleanup we additionally need to remove cached skb (Jiri Benc) [1947007]
- skmsg: Increase sk->sk_drops when dropping packets (Jiri Benc) [1947007]
- skmsg: Pass source psock to sk_psock_skb_redirect() (Jiri Benc) [1947007]
- skmsg: Teach sk_psock_verdict_apply() to return errors (Jiri Benc) [1947007]
- skmsg: Fix a memory leak in sk_psock_verdict_apply() (Jiri Benc) [1947007]
- skmsg: Clear skb redirect pointer before dropping it (Jiri Benc) [1947007]
- udp: Fix a memory leak in udp_read_sock() (Jiri Benc) [1947007]
- selftests/bpf: Retry for EAGAIN in udp_redir_to_connected() (Jiri Benc) [1947007]
- skmsg: Improve udp_bpf_recvmsg() accuracy (Jiri Benc) [1947007]
- bpf: Limit static tcp-cc functions in the .BTF_ids list to x86 (Jiri Benc) [1947007]
- flow_dissector: Fix out-of-bounds warning in __skb_flow_bpf_to_target() (Jiri Benc) [1947007]
- sock_map: Fix a potential use-after-free in sock_map_close() (Jiri Benc) [1947007]
- skmsg: Pass psock pointer to ->psock_update_sk_prot() (Jiri Benc) [1947007]
- bpf, udp: Remove some pointless comments (Jiri Benc) [1947007]
- selftests/bpf: Add a test case for loading BPF_SK_SKB_VERDICT (Jiri Benc) [1947007]
- selftests/bpf: Add a test case for udp sockmap (Jiri Benc) [1947007]
- sock_map: Update sock type checks for UDP (Jiri Benc) [1947007]
- udp: Implement udp_bpf_recvmsg() for sockmap (Jiri Benc) [1947007]
- skmsg: Extract __tcp_bpf_recvmsg() and tcp_bpf_wait_data() (Jiri Benc) [1947007]
- udp: Implement ->read_sock() for sockmap (Jiri Benc) [1947007]
- sock: Introduce sk->sk_prot->psock_update_sk_prot() (Jiri Benc) [1947007]
- sock_map: Introduce BPF_SK_SKB_VERDICT (Jiri Benc) [1947007]
- sock_map: Kill sock_map_link_no_progs() (Jiri Benc) [1947007]
- sock_map: Simplify sock_map_link() a bit (Jiri Benc) [1947007]
- skmsg: Use GFP_KERNEL in sk_psock_create_ingress_msg() (Jiri Benc) [1947007]
- skmsg: Use rcu work for destroying psock (Jiri Benc) [1947007]
- skmsg: Avoid lock_sock() in sk_psock_backlog() (Jiri Benc) [1947007]
- net: Introduce skb_send_sock() for sock_map (Jiri Benc) [1947007]
- skmsg: Introduce a spinlock to protect ingress_msg (Jiri Benc) [1947007]
- skmsg: Lock ingress_skb when purging (Jiri Benc) [1947007]
- bpf: tcp: Limit calling some tcp cc functions to CONFIG_DYNAMIC_FTRACE (Jiri Benc) [1947007]
- bpf: tcp: Fix an error in the bpf_tcp_ca_kfunc_ids list (Jiri Benc) [1947007]
- bpf: tcp: Remove comma which is causing build error (Jiri Benc) [1947007]
- bpf: tcp: Put some tcp cong functions in allowlist for bpf-tcp-cc (Jiri Benc) [1947007]
- tcp: Rename bictcp function prefix to cubictcp (Jiri Benc) [1947007]
- bpf: Add getter and setter for SO_REUSEPORT through bpf_{g,s}etsockopt (Jiri Benc) [1947007]
- bpf, devmap: Move drop error path to devmap for XDP_REDIRECT (Jiri Benc) [1947007]
- xsk: Update rings for load-acquire/store-release barriers (Jiri Benc) [1947007]
- skmsg: Add function doc for skb->_sk_redir (Jiri Benc) [1947007]
- skmsg: Remove unused sk_psock_stop() declaration (Jiri Benc) [1947007]
- skmsg: Get rid of sk_psock_bpf_run() (Jiri Benc) [1947007]
- skmsg: Make __sk_psock_purge_ingress_msg() static (Jiri Benc) [1947007]
- sock_map: Make sock_map_prog_update() static (Jiri Benc) [1947007]
- sock_map: Rename skb_parser and skb_verdict (Jiri Benc) [1947007]
- skmsg: Move sk_redir from TCP_SKB_CB to skb (Jiri Benc) [1947007]
- bpf: Compute data_end dynamically with JIT code (Jiri Benc) [1947007]
- skmsg: Get rid of struct sk_psock_parser (Jiri Benc) [1947007]
- bpf: Clean up sockmap related Kconfigs (Jiri Benc) [1947007]
- xsk: Build skb by page (aka generic zerocopy xmit) (Jiri Benc) [1947007]
- xsk: Respect device's headroom and tailroom on generic xmit path (Jiri Benc) [1947007]
- virtio-net: Support IFF_TX_SKB_NO_LINEAR flag (Jiri Benc) [1947007]
- net: Add priv_flags for allow tx skb without linear (Jiri Benc) [1947007]
- netdevice: Add missing IFF_PHONY_HEADROOM self-definition (Jiri Benc) [1947007]
- skmsg: Make sk_psock_destroy() static (Jiri Benc) [1947007]
- skmsg: Use fallthrough pseudo-keyword (Jiri Benc) [1947007]
- net: dev_is_mac_header_xmit() true for ARPHRD_RAWIP (Jiri Benc) [1947007]
- virtio_net: Account for tx bytes and packets on sending xdp_frames (Jiri Benc) [1947007]
- inet: udp{4|6}_lib_lookup_skb() skb argument is const (Jiri Benc) [1947007]
- inet: constify inet_sdif() argument (Jiri Benc) [1947007]
- udp: move gro declarations to net/udp.h (Jiri Benc) [1947007]
- net: move tcp gro declarations to net/tcp.h (Jiri Benc) [1947007]
- tcp: add declarations to avoid warnings (Jiri Benc) [1947007]
- tcp: remove indirect calls for icsk->icsk_af_ops->send_check (Jiri Benc) [1947007]
- tcp: remove indirect calls for icsk->icsk_af_ops->queue_xmit (Jiri Benc) [1947007]
- net: remove unused skb_send_sock() (Jiri Benc) [1947007]
- net: Use skb_frag_off accessors (Jiri Benc) [1947007]
- net: Use skb accessors in network core (Jiri Benc) [1947007]
- skbuff: fix compilation warnings in skb_dump() (Jiri Benc) [1947007]
- skbuff: increase verbosity when dumping skb data (Jiri Benc) [1947007]
- net: dump more useful information in netdev_rx_csum_fault() (Jiri Benc) [1947007]
- net: avoid indirect calls in L4 checksum calculation (Jiri Benc) [1947007]
- net/core: Allow the compiler to verify declaration and definition consistency (Jiri Benc) [1947007]
- efi/arm64: Drop erroneous '__pure' attribute from set_nokaslr() (Vitaly Kuznetsov) [2026995]
- drm/nouveau: clean up all clients on device removal (Karol Herbst) [1901903] {CVE-2020-27820}
- drm/nouveau: Add a dedicated mutex for the clients list (Karol Herbst) [1901903] {CVE-2020-27820}
- drm/nouveau: use drm_dev_unplug() during device removal (Karol Herbst) [1901903] {CVE-2020-27820}
- block: avoid to quiesce queue in elevator_init_mq (Ming Lei) [2025759]
- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue and disk_release() (Ming Lei) [2021399]
- PCI/portdrv: Enable Bandwidth Notification only if port supports it (Myron Stowe) [1981738]
- cifs: keep referral server sessions alive (Ronnie Sahlberg) [2030880]
- cifs: check pointer before freeing (Ronnie Sahlberg) [2030880]
- cifs: constify path argument of ->make_node() (Ronnie Sahlberg) [2030880]
- cifs: constify get_normalized_path() properly (Ronnie Sahlberg) [2030880]
- cifs: don't cargo-cult strndup() (Ronnie Sahlberg) [2030880]
- cifs: cleanup misc.c (Ronnie Sahlberg) [2030880]
- cifs: get rid of @noreq param in __dfs_cache_find() (Ronnie Sahlberg) [2030880]
- cifs: do not send tree disconnect to ipc shares (Ronnie Sahlberg) [2030880]
- cifs: fix doc warnings in cifs_dfs_ref.c (Ronnie Sahlberg) [2030880]
- cifs: introduce helper for finding referral server to improve DFS target resolution (Ronnie Sahlberg) [2030880]
- cifs: check all path components in resolved dfs target (Ronnie Sahlberg) [2030880]
- cifs: fix DFS failover (Ronnie Sahlberg) [2030880]
- Enable CONFIG_SCHED_CLUSTER (Phil Auld) [1920645]
- sched,x86: Don't use cluster topology for x86 hybrid CPUs (Phil Auld) [1920645]
- arch_topology: Fix missing clear cluster_cpumask in remove_cpu_topology() (Phil Auld) [1920645]
- x86/smp: Factor out parts of native_smp_prepare_cpus() (Phil Auld) [1920645]
- sched,x86: Fix L2 cache mask (Phil Auld) [1920645]
- sched: Add cluster scheduler level for x86 (Phil Auld) [1920645]
- sched: Add cluster scheduler level in core and related Kconfig for ARM64 (Phil Auld) [1920645]
- topology: Represent clusters of CPUs within a die (Phil Auld) [1920645]
- cpumask: Omit terminating null byte in cpumap_print_{list,bitmask}_to_buf (Phil Auld) [1920645]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Phil Auld) [1920645]
- topology: use bin_attribute to break the size limitation of cpumap ABI (Phil Auld) [1920645]
- cpumask: introduce cpumap_print_list/bitmask_to_buf to support large bitmask and list (Phil Auld) [1920645]
- x86/cpu: Add get_llc_id() helper function (Phil Auld) [1920645]
- x86/smp: Add a per-cpu view of SMT state (Phil Auld) [1920645]
- ARM: 8943/1: Fix topology setup in case of CPU hotplug for CONFIG_SCHED_MC (Phil Auld) [1920645]
- arm: Use common cpu_topology structure and functions. (Phil Auld) [1920645]
- cpu-topology: Move cpu topology code to common code. (Phil Auld) [1920645]
- netfilter: ctnetlink: allow to filter dump by status bits (Florian Westphal) [1991526]
- netfilter: ctnetlink: add and use a helper for mark parsing (Florian Westphal) [1991526]
- netfilter: ctnetlink: suspicious RCU usage in ctnetlink_dump_helpinfo (Florian Westphal) [1991526]
- netfilter: ctnetlink: add timeout and protoinfo to destroy events (Florian Westphal) [1991526]
- netfilter: ctnetlink: fix mark based dump filtering regression (Florian Westphal) [1991526]
- netfilter: ctnetlink: memleak in filter initialization error path (Florian Westphal) [1991526]
- netfilter: ctnetlink: add kernel side filtering for dump (Florian Westphal) [1991526]
- netfilter: ctnetlink: don't dump ct extensions of unconfirmed conntracks (Florian Westphal) [1991526]
- netfilter: ctnetlink: be more strict when NF_CONNTRACK_MARK is not set (Florian Westphal) [1991526]
- netfilter: ctnetlink: Fix regression in conntrack entry deletion (Florian Westphal) [1991526]
- netfilter: ctnetlink: Resolve conntrack L3-protocol flush regression (Florian Westphal) [1991526]
- netfilter: ctnetlink: always honor CTA_MARK_MASK (Florian Westphal) [1991526]
- netfilter: ctnetlink: must check mark attributes vs NULL (Florian Westphal) [1991526]
- netfilter: ctnetlink: Support L3 protocol-filter on flush (Florian Westphal) [1991526]
- netfilter: nftables: fix incorrect increment of loop counter (Phil Sutter) [1983635]
- netfilter: nf_tables: initialize set before expression setup (Phil Sutter) [1983635]
- netfilter: nftables: add set expression flags (Phil Sutter) [1983635]
- netfilter: nft_dynset: report EOPNOTSUPP on missing set feature (Phil Sutter) [1983635]
- netfilter: nft_dynset: dump expressions when set definition contains no expressions (Phil Sutter) [1983635]
- netfilter: nft_dynset: honor stateful expressions in set definition (Phil Sutter) [1983635]
- netfilter: nf_tables: do not leave dangling pointer in nf_tables_set_alloc_name (Phil Sutter) [1983635]
- netfilter: nftables: clone set element expression template (Phil Sutter) [1983635]
- netfilter: nftables: relax check for stateful expressions in set definition (Phil Sutter) [1983635]
- netfilter: nftables: netlink support for several set element expressions (Phil Sutter) [1983635]
- netfilter: nf_tables: skip set types that do not support for expressions (Phil Sutter) [1983635]
- netfilter: nft_dynset: allow dynamic updates of non-anonymous set (Phil Sutter) [1983635]
- netfilter: nftables: generalize set extension to support for several expressions (Phil Sutter) [1983635]
- netfilter: nf_tables: do not update stateful expressions if lookup is inverted (Phil Sutter) [1983635]
- netfilter: nftables: move nft_expr before nft_set (Phil Sutter) [1983635]
- netfilter: nf_tables: Align nft_expr private data to 64-bit (Phil Sutter) [1983635]
- netfilter: nftables: generalize set expressions support (Phil Sutter) [1983635]
- netfilter: nft_dynset: validate set expression definition (Phil Sutter) [1983635]
- netfilter: nf_tables: add nft_set_elem_expr_destroy() and use it (Phil Sutter) [1983635]
- netfilter: nf_tables: fix double-free on set expression from the error path (Phil Sutter) [1983635]
- netfilter: nf_tables: allow to specify stateful expression in set definition (Phil Sutter) [1983635]
- netfilter: nf_tables: bogus EBUSY when deleting set after flush (Phil Sutter) [1983635]
- netfilter: nf_tables: pass context to nft_set_destroy() (Phil Sutter) [1983635]
- netfilter: nf_tables: move nft_expr_clone() to nf_tables_api.c (Phil Sutter) [1983635]
- netfilter: nf_tables: relocate header content to consumer (Phil Sutter) [1983635]
- netfilter: nft_lookup: update element stateful expression (Phil Sutter) [1983635]
- netfilter: nf_tables: add nft_set_elem_update_expr() helper function (Phil Sutter) [1983635]
- netfilter: nf_tables: add elements with stateful expressions (Phil Sutter) [1983635]
- netfilter: nf_tables: statify nft_expr_init() (Phil Sutter) [1983635]
- netfilter: nf_tables: add nft_set_elem_expr_alloc() (Phil Sutter) [1983635]
- netfilter: nf_tables: enable set expiration time for set elements (Phil Sutter) [1983635]
- hugetlbfs: flush TLBs correctly after huge_pmd_unshare (Rafael Aquini) [2026376] {CVE-2021-4002}
- tlb: mmu_gather: add tlb_flush_*_range APIs (Rafael Aquini) [2026376] {CVE-2021-4002}
- ACPI: PM: Do not turn off power resources in unknown state (Mark Langsdorf) [1997696]
- ACPI: PRM: Find PRMT table before parsing it (Mark Langsdorf) [1997696]
- ACPI: NFIT: Fix support for virtual SPA ranges (Mark Langsdorf) [1997696]
- ACPI: DPTF: Fix reading of attributes (Mark Langsdorf) [1997696]
- ACPI: PM: Add support for upcoming AMD uPEP HID AMDI007 (Mark Langsdorf) [1997696]
- ACPI: Kconfig: Fix table override from built-in initrd (Mark Langsdorf) [1997696]
- ACPI: video: Add quirk for the Dell Vostro 3350 (Mark Langsdorf) [1997696]
- ACPI: AMBA: Fix resource name in /proc/iomem (Mark Langsdorf) [1997696]
- ACPI: PM: postpone bringing devices to D0 unless we need them (Mark Langsdorf) [1997696]
- ACPI: tables: Add custom DSDT file as makefile prerequisite (Mark Langsdorf) [1997696]
- ACPI: bgrt: Use sysfs_emit (Mark Langsdorf) [1997696]
- ACPI: bgrt: Fix CFI violation (Mark Langsdorf) [1997696]
- ACPI: EC: trust DSDT GPE for certain HP laptop (Mark Langsdorf) [1997696]
- ACPI: scan: Simplify acpi_table_events_fn() (Mark Langsdorf) [1997696]
- ACPI: sysfs: Remove tailing return statement in void function (Mark Langsdorf) [1997696]
- ACPI: sysfs: Use __ATTR_RO() and __ATTR_RW() macros (Mark Langsdorf) [1997696]
- ACPI: sysfs: Sort headers alphabetically (Mark Langsdorf) [1997696]
- ACPI: sysfs: Refactor param_get_trace_state() to drop dead code (Mark Langsdorf) [1997696]
- ACPI: sysfs: Unify pattern of memory allocations (Mark Langsdorf) [1997696]
- ACPI: sysfs: Allow bitmap list to be supplied to acpi_mask_gpe (Mark Langsdorf) [1997696]
- ACPI: sysfs: Make sparse happy about address space in use (Mark Langsdorf) [1997696]
- ACPI: scan: Fix race related to dropping dependencies (Mark Langsdorf) [1997696]
- ACPI: scan: Reorganize acpi_device_add() (Mark Langsdorf) [1997696]
- ACPI: scan: Fix device object rescan in acpi_scan_clear_dep() (Mark Langsdorf) [1997696]
- ACPI: scan: Make acpi_walk_dep_device_list() (Mark Langsdorf) [1997696]
- ACPI: scan: Rearrange acpi_dev_get_first_consumer_dev_cb() (Mark Langsdorf) [1997696]
- ACPI: scan: Define acpi_bus_put_acpi_device() as static inline (Mark Langsdorf) [1997696]
- ACPI: NVS: fix doc warnings in nvs.c (Mark Langsdorf) [1997696]
- ACPI: sysfs: fix doc warnings in device_sysfs.c (Mark Langsdorf) [1997696]
- ACPI: APEI: fix synchronous external aborts in user-mode (Mark Langsdorf) [1997696]
- mfd: tps68470: Remove tps68470 MFD driver (Mark Langsdorf) [1997696]
- ACPI: power: Use dev_dbg() to print some messages (Mark Langsdorf) [1997696]
- ACPI: Add quirks for AMD Renoir/Lucienne CPUs to force the D3 hint (Mark Langsdorf) [1997696]
- ACPI: processor_throttling: Fix several coding style issues (Mark Langsdorf) [1997696]
- ACPI: sysfs: Drop four redundant return statements (Mark Langsdorf) [1997696]
- ACPI: video: Drop three redundant return statements (Mark Langsdorf) [1997696]
- ACPI: sleep: Fix acpi_pm_pre_suspend() kernel-doc (Mark Langsdorf) [1997696]
- ACPI: processor_throttling: Remove redundant initialization of 'obj' (Mark Langsdorf) [1997696]
- ACPI: utils: Introduce acpi_get_local_address() (Mark Langsdorf) [1997696]
- ACPI: scan: initialize local variable to avoid garbage being returned (Mark Langsdorf) [1997696]
- ACPI: Remove redundant clearing of context->ret.pointer from acpi_run_osc() (Mark Langsdorf) [1997696]
- redhat/configs: Add Enable CONFIG_ACPI_PRMT (Mark Langsdorf) [1997696]
- ACPI: PRM: Deal with table not present or no module found (Mark Langsdorf) [1997696]
- ACPI: Do not singal PRM support if not enabled (Mark Langsdorf) [1997696]
- ACPI: Kconfig: Provide help text for the ACPI_PRMT option (Mark Langsdorf) [1997696]
- ACPI: PRM: make symbol 'prm_module_list' static (Mark Langsdorf) [1997696]
- ACPI: Correct \_SB._OSC bit definition for PRM (Mark Langsdorf) [1997696]
- ACPI: Add \_SB._OSC bit for PRM (Mark Langsdorf) [1997696]
- ACPI: PRM: implement OperationRegion handler for the PlatformRtMechanism subtype (Mark Langsdorf) [1997696]
- ACPICA: Add PRMT module header to facilitate parsing (Mark Langsdorf) [1997696]
- ACPI: scan: Add function to fetch dependent of ACPI device (Mark Langsdorf) [1997696]
- ACPI: scan: Extend acpi_walk_dep_device_list() (Mark Langsdorf) [1997696]
- i2c: core: Restore acpi_walk_dep_device_list() getting called after registering the ACPI i2c devs (Mark Langsdorf) [1997696]
- ACPI: NUMA: fix typo in a comment (Mark Langsdorf) [1997696]
- ACPI: sysfs: Fix a buffer overrun problem with description_show() (Mark Langsdorf) [1997696]
- ACPI: LPSS: Use kstrtol() instead of simple_strtol() (Mark Langsdorf) [1997696]
- ACPI: tables: FPDT: Add missing acpi_put_table() in acpi_init_fpdt() (Mark Langsdorf) [1997696]
- ACPI: tables: PPTT: Populate cache-id if provided by firmware (Mark Langsdorf) [1997696]
- ACPI: OSL: Use DEFINE_RES_IO_NAMED() to simplify code (Mark Langsdorf) [1997696]
- ACPI: bus: Call kobject_put() in acpi_init() error path (Mark Langsdorf) [1997696]
- ACPI: bus: Remove unneeded assignment (Mark Langsdorf) [1997696]
- ACPI: sleep: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: sbs: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: scan: Unify the log message printing (Mark Langsdorf) [1997696]
- ACPI: sbshc: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: sysfs: Cleanup message printing (Mark Langsdorf) [1997696]
- ACPI: reboot: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: processor_throttling: Cleanup the printing messages (Mark Langsdorf) [1997696]
- ACPI: processor_perflib: Cleanup print messages (Mark Langsdorf) [1997696]
- ACPI: processor_thermal: Remove unused PREFIX for printing (Mark Langsdorf) [1997696]
- ACPI: pci_root: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: osl: Remove the duplicated PREFIX for message printing (Mark Langsdorf) [1997696]
- ACPI: nvs: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: glue: Clean up the printing messages (Mark Langsdorf) [1997696]
- ACPI: event: Use pr_*() macros to replace printk() (Mark Langsdorf) [1997696]
- ACPI: bus: Use pr_*() macros to replace printk() (Mark Langsdorf) [1997696]
- ACPI: blacklist: Unify the message printing (Mark Langsdorf) [1997696]
- ACPI: cmos_rtc: Using pr_fmt() and remove PREFIX (Mark Langsdorf) [1997696]
- ACPI: scan: Constify acpi_dma_supported() helper function (Mark Langsdorf) [1997696]
- ACPICA: Update version to 20210604 (Mark Langsdorf) [1997696]
- ACPICA: Add support for PlatformRtMechanism OperationRegion handler (Mark Langsdorf) [1997696]
- ACPICA: iASL: add disassembler support for PRMT (Mark Langsdorf) [1997696]
- ACPICA: Add the CFMWS structure definition to the CEDT table (Mark Langsdorf) [1997696]
- ACPICA: Add defines for the CXL Host Bridge Structure (CHBS) (Mark Langsdorf) [1997696]
- ACPICA: iASL: Add support for the BDAT ACPI table (Mark Langsdorf) [1997696]
- ACPICA: Add _PLD panel positions (Mark Langsdorf) [1997696]
- ACPICA: Use ACPI_FALLTHROUGH (Mark Langsdorf) [1997696]
- ACPICA: iASL Table Compiler: Add full support for RGRT ACPI table (Mark Langsdorf) [1997696]
- ACPICA: iASL: Add support for the SVKL table (Mark Langsdorf) [1997696]
- ACPICA: iASL: Finish support for the IVRS ACPI table (Mark Langsdorf) [1997696]
- ACPICA: Add SVKL table headers (Mark Langsdorf) [1997696]
- ACPICA: ACPI 6.4: MADT: add Multiprocessor Wakeup Mailbox Structure (Mark Langsdorf) [1997696]
- ACPI: power: Rework turning off unused power resources (Mark Langsdorf) [1997696]
- ACPI: power: Save the last known state of each power resource (Mark Langsdorf) [1997696]
- ACPI: power: Use u8 as the power resource state data type (Mark Langsdorf) [1997696]
- ACPI: configfs: Replace ACPI_INFO() with pr_debug() (Mark Langsdorf) [1997696]
- ACPI: ipmi: Remove address space handler in error path (Mark Langsdorf) [1997696]
- ACPI: EC: Make more Asus laptops use ECDT _GPE (Mark Langsdorf) [1997696]
- ACPI: event: Remove redundant initialization of local variable (Mark Langsdorf) [1997696]
- ACPI: sbshc: Fix fall-through warning for Clang (Mark Langsdorf) [1997696]
- ACPI: PM / fan: Put fan device IDs into separate header file (Mark Langsdorf) [1997696]
- ACPI: APEI: Don't warn if ACPI is disabled (Mark Langsdorf) [1997696]
- ACPI: processor idle: Fix up C-state latency if not ordered (Mark Langsdorf) [1997696]
- ACPI: scan: Rearrange dep_unmet initialization (Mark Langsdorf) [1997696]
- ACPI: DPTF: Add battery participant for Intel SoCs (Mark Langsdorf) [1997696]
- md/raid5: avoid device_lock in read_one_chunk() (Nigel Croxon) [1985919]
- md: add comments in md_integrity_register (Nigel Croxon) [1985919]
- md: check level before create and exit io_acct_set (Nigel Croxon) [1985919]
- md/raid10: enable io accounting (Nigel Croxon) [1985919]
- md/raid1: enable io accounting (Nigel Croxon) [1985919]
- md/raid5: avoid redundant bio clone in raid5_read_one_chunk (Nigel Croxon) [1985919]
- md/raid5: move checking badblock before clone bio in raid5_read_one_chunk (Nigel Croxon) [1985919]
- md: add io accounting for raid0 and raid5 (Nigel Croxon) [1985919]
- md: revert io stats accounting (Nigel Croxon) [1985919]
- md/raid5: remove an incorrect assert in in_chunk_boundary (Nigel Croxon) [1985919]
- md: use rdev_read_only in restart_array (Nigel Croxon) [1985919]
- md/raid6: refactor raid5_read_one_chunk (Nigel Croxon) [1985919]
- md: remove md_bio_alloc_sync (Nigel Croxon) [1985919]
- md: simplify sync_page_io (Nigel Croxon) [1985919]
- md: remove bio_alloc_mddev (Nigel Croxon) [1985919]
- md: use part_[begin|end]_io_acct instead of disk_[begin|end]_io_acct (Nigel Croxon) [1985919]
- md: improve io stats accounting (Nigel Croxon) [1985919]

* Tue Dec 28 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-358.el8]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Corinna Vinschen) [1970663]
- igbvf: convert to strongly typed descriptors (Corinna Vinschen) [1970663]
- intel: call csum functions with well formatted arguments (Corinna Vinschen) [1970663]
- igb: handle vlan types with checker enabled (Corinna Vinschen) [1970663]
- igb: fix netpoll exit with traffic (Corinna Vinschen) [1970662]
- igb: unbreak I2C bit-banging on i350 (Corinna Vinschen) [1970662]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Corinna Vinschen) [1970662]
- igb: Avoid memcpy() over-reading of ETH_SS_STATS (Corinna Vinschen) [1970662]
- igb: Add counter to i21x doublecheck (Corinna Vinschen) [1970662]
- igb: Fix position of assignment to *ring (Corinna Vinschen) [1970662]
- igb: Check if num of q_vectors is smaller than max before array access (Corinna Vinschen) [1970662]
- igb: Fix an error handling path in 'igb_probe()' (Corinna Vinschen) [1970662]
- igb: Fix use-after-free error during reset (Corinna Vinschen) [1970662]
- intel: Remove rcu_read_lock() around XDP program invocation (Corinna Vinschen) [1970662]
- igb: add correct exception tracing for XDP (Corinna Vinschen) [1970662]
- igb: Fix XDP with PTP enabled (Corinna Vinschen) [1970662]
- igb: Fix -Wunused-const-variable warning (Corinna Vinschen) [1970662]
- igb: override two checker warnings (Corinna Vinschen) [1970662]
- igb: fix assignment on big endian machines (Corinna Vinschen) [1970662]
- igb: handle vlan types with checker enabled (Corinna Vinschen) [1970662]
- igb/igc: use strongly typed pointer (Corinna Vinschen) [1970662]
- intel: remove checker warning (Corinna Vinschen) [1970662]
- i40e: Fix NULL pointer dereference in i40e_dbg_dump_desc (Stefan Assmann) [1970651]
- i40e: Fix pre-set max number of queues for VF (Stefan Assmann) [1970651]
- i40e: Fix failed opcode appearing if handling messages from VF (Stefan Assmann) [1970651]
- i40e: Fix display error code in dmesg (Stefan Assmann) [1970651]
- i40e: Fix creation of first queue by omitting it if is not power of two (Stefan Assmann) [1970651]
- i40e: Fix warning message and call stack during rmmod i40e driver (Stefan Assmann) [1970651]
- i40e: Fix ping is lost after configuring ADq on VF (Stefan Assmann) [1970651]
- i40e: Fix changing previously set num_queue_pairs for PFs (Stefan Assmann) [1970651]
- i40e: Fix NULL ptr dereference on VSI filter sync (Stefan Assmann) [1970651]
- i40e: Fix correct max_pkt_size on VF RX queue (Stefan Assmann) [1970651]
- ethernet: constify references to netdev->dev_addr in drivers (Stefan Assmann) [1970651]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Stefan Assmann) [1970651]
- i40e: Fix ATR queue selection (Stefan Assmann) [1970651]
- i40e: Fix spelling mistake "dissable" -> "disable" (Stefan Assmann) [1970651]
- iavf: do not override the adapter state in the watchdog task (again) (Stefan Assmann) [1970650]
- iavf: missing unlocks in iavf_watchdog_task() (Stefan Assmann) [1970650]
- iavf: Fix reporting when setting descriptor count (Stefan Assmann) [1970650]
- iavf: restore MSI state on reset (Stefan Assmann) [1970650]
- iavf: Fix displaying queue statistics shown by ethtool (Stefan Assmann) [1970650]
- iavf: Refactor string format to avoid static analysis warnings (Stefan Assmann) [1970650]
- iavf: Refactor text of informational message (Stefan Assmann) [1970650]
- iavf: Fix static code analysis warning (Stefan Assmann) [1970650]
- iavf: Refactor iavf_mac_filter struct memory usage (Stefan Assmann) [1970650]
- iavf: Enable setting RSS hash key (Stefan Assmann) [1970650]
- iavf: Add trace while removing device (Stefan Assmann) [1970650]
- iavf: return errno code instead of status code (Stefan Assmann) [1970650]
- iavf: Log info when VF is entering and leaving Allmulti mode (Stefan Assmann) [1970650]
- iavf: Add change MTU message (Stefan Assmann) [1970650]
- iavf: Fix VLAN feature flags after VFR (Stefan Assmann) [1970650]
- iavf: Fix refreshing iavf adapter stats on ethtool request (Stefan Assmann) [1970650]
- iavf: Fix deadlock occurrence during resetting VF interface (Stefan Assmann) [1970650]
- iavf: Prevent changing static ITR values if adaptive moderation is on (Stefan Assmann) [1970650]
- iavf: Restore VLAN filters after link down (Stefan Assmann) [1970650]
- iavf: Fix for setting queues to 0 (Stefan Assmann) [1970650]
- iavf: Fix for the false positive ASQ/ARQ errors while issuing VF reset (Stefan Assmann) [1970650]
- iavf: validate pointers (Stefan Assmann) [1970650]
- iavf: prevent accidental free of filter structure (Stefan Assmann) [1970650]
- iavf: Fix failure to exit out from last all-multicast mode (Stefan Assmann) [1970650]
- iavf: don't clear a lock we don't hold (Stefan Assmann) [1970650]
- iavf: free q_vectors before queues in iavf_disable_vf (Stefan Assmann) [1970650]
- iavf: check for null in iavf_fix_features (Stefan Assmann) [1970650]
- iavf: Fix return of set the new channel count (Stefan Assmann) [1970650]
- iavf: Fix kernel BUG in free_msi_irqs (Stefan Assmann) [1970650]
- iavf: Add helper function to go from pci_dev to adapter (Stefan Assmann) [1970650]
- iavf: Combine init and watchdog state machines (Stefan Assmann) [1970650]
- iavf: Add __IAVF_INIT_FAILED state (Stefan Assmann) [1970650]
- iavf: Refactor iavf state machine tracking (Stefan Assmann) [1970650]
- iavf: fix double unlock of crit_lock (Stefan Assmann) [1970650]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Stefan Assmann) [1970650]
- iavf: Fix ping is lost after untrusted VF had tried to change MAC (Stefan Assmann) [1970650]
- iavf: use mutexes for locking of critical sections (Stefan Assmann) [1970650]
- qed: rdma - don't wait for resources under hw error recovery flow (Manish Chopra) [1998195]
- qed: Handle management FW error (Manish Chopra) [1998195]
- qede: Fix memset corruption (Manish Chopra) [1998195]
- qed: Enable automatic recovery on error condition. (Manish Chopra) [1998195]
- qed: Fix the VF msix vectors flow (Manish Chopra) [1998195]
- qed: Fix null-pointer dereference in qed_rdma_create_qp() (Manish Chopra) [1998195]
- qed: qed ll2 race condition fixes (Manish Chopra) [1998195]
- qed: Remove duplicated include of kernel.h (Manish Chopra) [1998195]
- qed: Remove redundant prints from the iWARP SYN handling (Manish Chopra) [1998195]
- qed: Skip DORQ attention handling during recovery (Manish Chopra) [1998195]
- qed: Avoid db_recovery during recovery (Manish Chopra) [1998195]
- qede: fix crash in rmmod qede while automatic debug collection (Manish Chopra) [1998195]
- RDMA/qedr: Improve error logs for rdma_alloc_tid error return (Manish Chopra) [1998195]
- RDMA/qed: Use accurate error num in qed_cxt_dynamic_ilt_alloc (Manish Chopra) [1998195]
- net: qed: remove unneeded return variables (Manish Chopra) [1998195]
- net: qede: Fix end of loop tests for list_for_each_entry (Manish Chopra) [1998195]
- qede: Remove rcu_read_lock() around XDP program invocation (Manish Chopra) [1998195]
- net: qed: Fix memcpy() overflow of qed_dcbx_params() (Manish Chopra) [1998195]
- net: qede: Use list_for_each_entry() to simplify code (Manish Chopra) [1998195]
- qed: Fix duplicate included linux/kernel.h (Manish Chopra) [1998195]
- qed: Add IP services APIs support (Manish Chopra) [1998195]
- qed: Add NVMeTCP Offload IO Level FW Initializations (Manish Chopra) [1998195]
- qed: Add NVMeTCP Offload IO Level FW and HW HSI (Manish Chopra) [1998195]
- qed: Add support of HW filter block (Manish Chopra) [1998195]
- qed: Add NVMeTCP Offload Connection Level FW and HW HSI (Manish Chopra) [1998195]
- qed: Add NVMeTCP Offload PF Level FW and HW HSI (Manish Chopra) [1998195]
- qed: Add TCP_ULP FW resource layout (Manish Chopra) [1998195]
- net: qed: remove redundant initialization of variable rc (Manish Chopra) [1998195]
- net: qed: remove unused including <linux/version.h> (Manish Chopra) [1998195]
- qede: remove unused including <linux/version.h> (Manish Chopra) [1998195]
- linux/qed: Mundane spelling fixes throughout the file (Manish Chopra) [1998195]
- qed: Fix fall-through warnings for Clang (Manish Chopra) [1998195]
- RDMA/qedr: Use true and false for bool variable (Manish Chopra) [1998195]
- qede: preserve per queue stats across up/down of interface (Manish Chopra) [1998195]
- qede: add per queue coalesce support for qede driver (Manish Chopra) [1998195]
- qede: add netpoll support for qede driver (Manish Chopra) [1998195]
- RDMA/qedr: Remove in_irq() usage from debug output (Manish Chopra) [1998195]
- linux/qed: fix spelling typo in qed_chain.h (Manish Chopra) [1998195]
- qed: select CONFIG_CRC32 (Manish Chopra) [1998195]
- IB/qedr: Fix fall-through warnings for Clang (Manish Chopra) [1998195]
- RDMA/qedr: Endianness warnings cleanup (Manish Chopra) [1998195]
- qed/qed_ll2: Replace one-element array with flexible-array member (Manish Chopra) [1998195]
- net: qed: use true,false for bool variables (Manish Chopra) [1998195]
- RDMA/qedr: Fix reported max_pkeys (Manish Chopra) [1998195]
- qed: align adjacent indent (Manish Chopra) [1998195]
- qed: fix kconfig help entries (Manish Chopra) [1998195]
- sched/cputime: Fix getrusage(RUSAGE_THREAD) with nohz_full (Phil Auld) [1992387]
- net: tg3: fix obsolete check of !err (Ken Cox) [1987082]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [1987082]
- tg3: Remove unused PHY_BRCM flags (Ken Cox) [1987082]
- net: check skb sec_path when re-initializing slow_gro in gro_list_prepare (Xin Long) [2030476]
- e1000e: Fix the max snoop/no-snoop latency for 10M (Ken Cox) [1970665]
- net/e1000e: Fix spelling mistake "The" -> "This" (Ken Cox) [1970665]
- e1000e: Add space to the debug print (Ken Cox) [1970665]
- e1000e: Additional PHY power saving in S0ix (Ken Cox) [1970665]
- e1000e: Add polling mechanism to indicate CSME DPG exit (Ken Cox) [1970665]
- e1000e: Add handshake with the CSME to support S0ix (Ken Cox) [1970665]
- e1000e: Fix an error handling path in 'e1000_probe()' (Ken Cox) [1970665]
- e1000e: Check the PCIm state (Ken Cox) [1970665]
- net: e1000e: fix misspell word "retreived" (Ken Cox) [1970665]
- net: e1000e: remove repeated word "slot" for netdev.c (Ken Cox) [1970665]
- net: e1000e: remove repeated word "the" for ich8lan.c (Ken Cox) [1970665]
- ppc64: Fix incorrect qrwlock use in debug kernel (Waiman Long) [2027200]
- locking: Remove spin_lock_flags() etc (Waiman Long) [2027200]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2007903]
- Bluetooth: btusb: Add the new support IDs for WCN6855 (Gopal Tiwari) [2007903]
- Bluetooth: btusb: re-definition for board_id in struct qca_version (Gopal Tiwari) [2007903]
- Bluetooth: btusb: Add support using different nvm for variant WCN6855 controller (Gopal Tiwari) [2007903]
- bpf/selftests: enable atomic_bounds test (Viktor Malik) [2030572]
- Revert "bpf: Remove atomics tests from test_progs" (Viktor Malik) [2030572]
- bpf/selftests: disable tests failing on RHEL 8.6 (Viktor Malik) [2025797 2025801 2025810 2025812 2025813]
- bpf/selftests: allow disabling prog_tests (Viktor Malik) [2030572]
- xfs: drop experimental warnings for bigtime and inobtcount (Bill O'Donnell) [2022903]
- libxfs: expose inobtcount in xfs geometry (Bill O'Donnell) [2022903]
- xfs: enable new inode btree counters feature (Bill O'Donnell) [2022903]
- xfs: enable big timestamps (Bill O'Donnell) [2022903]
- selftests: net: bridge: fix typo in vlan_filtering dependency test (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for vlan_filtering dependency (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast_router tests (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast query and query response interval tests (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast_querier_interval tests (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast_membership_interval test (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast_startup_query_count/interval tests (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast_last_member_count/interval tests (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast igmp/mld version tests (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast querier test (Ivan Vecera) [2019055]
- selftests: net: bridge: add vlan mcast snooping control test (Ivan Vecera) [2019055]
- selftests: net: bridge: update IGMP/MLD membership interval value (Ivan Vecera) [2019055]
- net: bridge: mcast: use multicast_membership_interval for IGMPv3 (Ivan Vecera) [2019055]
- net: bridge: fix under estimation in br_get_linkxstats_size() (Ivan Vecera) [2019055]
- net: bridge: use nla_total_size_64bit() in br_get_linkxstats_size() (Ivan Vecera) [2019055]
- net: bridge: mcast: Associate the seqcount with its protecting lock. (Ivan Vecera) [2019055]
- net: bridge: mcast: fix vlan port router deadlock (Ivan Vecera) [2019055]
- net: bridge: use mld2r_ngrec instead of icmpv6_dataun (Ivan Vecera) [2019055]
- net: bridge: change return type of br_handle_ingress_vlan_tunnel (Ivan Vecera) [2019055]
- net: bridge: vlan: convert mcast router global option to per-vlan entry (Ivan Vecera) [2019055]
- net: bridge: mcast: br_multicast_set_port_router takes multicast context as argument (Ivan Vecera) [2019055]
- net: bridge: mcast: toggle also host vlan state in br_multicast_toggle_vlan (Ivan Vecera) [2019055]
- net: bridge: mcast: use the correct vlan group helper (Ivan Vecera) [2019055]
- net: bridge: vlan: account for router port lists when notifying (Ivan Vecera) [2019055]
- net: bridge: vlan: enable mcast snooping for existing master vlans (Ivan Vecera) [2019055]
- net: bridge: mcast: account for ipv6 size when dumping querier state (Ivan Vecera) [2019055]
- net: bridge: mcast: drop sizeof for nest attribute's zero size (Ivan Vecera) [2019055]
- net: bridge: mcast: don't dump querier state if snooping is disabled (Ivan Vecera) [2019055]
- net: bridge: vlan: dump mcast ctx querier state (Ivan Vecera) [2019055]
- net: bridge: mcast: dump ipv6 querier state (Ivan Vecera) [2019055]
- net: bridge: mcast: dump ipv4 querier state (Ivan Vecera) [2019055]
- net: bridge: mcast: consolidate querier selection for ipv4 and ipv6 (Ivan Vecera) [2019055]
- net: bridge: mcast: make sure querier port/address updates are consistent (Ivan Vecera) [2019055]
- net: bridge: mcast: record querier port device ifindex instead of pointer (Ivan Vecera) [2019055]
- net: bridge: vlan: use br_rports_fill_info() to export mcast router ports (Ivan Vecera) [2019055]
- net: bridge: mcast: use the proper multicast context when dumping router ports (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast router global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast querier global option (Ivan Vecera) [2019055]
- net: bridge: mcast: querier and query state affect only current context type (Ivan Vecera) [2019055]
- net: bridge: mcast: move querier state to the multicast context (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast startup query interval global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast query response interval global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast query interval global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast querier interval global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast membership interval global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast last member interval global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast startup query count global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast last member count global option (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for mcast igmp/mld version global options (Ivan Vecera) [2019055]
- net: switchdev: zero-initialize struct switchdev_notifier_fdb_info emitted by drivers towards the bridge (Ivan Vecera) [2019055]
- net: bridge: fix flags interpretation for extern learn fdb entries (Ivan Vecera) [2019055]
- net: bridge: vlan: fix global vlan option range dumping (Ivan Vecera) [2019055]
- net: bridge: fix memleak in br_add_if() (Ivan Vecera) [2019055]
- net: make switchdev_bridge_port_{,unoffload} loosely coupled with the bridge (Ivan Vecera) [2019055]
- net: bridge: switchdev: fix incorrect use of FDB flags when picking the dst device (Ivan Vecera) [2019055]
- net: bridge: validate the NUD_PERMANENT bit when adding an extern_learn FDB entry (Ivan Vecera) [2019055]
- net: bridge: switchdev: treat local FDBs the same as entries towards the bridge (Ivan Vecera) [2019055]
- net: bridge: switchdev: replay the entire FDB for each port (Ivan Vecera) [2019055]
- net: bridge: add a helper for retrieving port VLANs from the data path (Ivan Vecera) [2019055]
- net: bridge: update BROPT_VLAN_ENABLED before notifying switchdev in br_vlan_filter_toggle (Ivan Vecera) [2019055]
- net: bridge: fix build when setting skb->offload_fwd_mark with CONFIG_NET_SWITCHDEV=n (Ivan Vecera) [2019055]
- net: bridge: switchdev: allow the TX data plane forwarding to be offloaded (Ivan Vecera) [2019055]
- net: switchdev: fix FDB entries towards foreign ports not getting propagated to us (Ivan Vecera) [2019055]
- net: bridge: move the switchdev object replay helpers to "push" mode (Ivan Vecera) [2019055]
- net: bridge: guard the switchdev replay helpers against a NULL notifier block (Ivan Vecera) [2019055]
- net: bridge: switchdev: let drivers inform which bridge ports are offloaded (Ivan Vecera) [2019055]
- net: bridge: switchdev: recycle unused hwdoms (Ivan Vecera) [2019055]
- net: bridge: disambiguate offload_fwd_mark (Ivan Vecera) [2019055]
- net: bridge: multicast: add context support for host-joined groups (Ivan Vecera) [2019055]
- net: bridge: multicast: add mdb context support (Ivan Vecera) [2019055]
- net: bridge: multicast: fix igmp/mld port context null pointer dereferences (Ivan Vecera) [2019055]
- net: switchdev: recurse into __switchdev_handle_fdb_del_to_device (Ivan Vecera) [2019055]
- net: switchdev: remove stray semicolon in switchdev_handle_fdb_del_to_device shim (Ivan Vecera) [2019055]
- net: bridge: vlan: add mcast snooping control (Ivan Vecera) [2019055]
- net: bridge: vlan: notify when global options change (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for dumping global vlan options (Ivan Vecera) [2019055]
- net: bridge: vlan: add support for global options (Ivan Vecera) [2019055]
- net: bridge: multicast: include router port vlan id in notifications (Ivan Vecera) [2019055]
- net: bridge: multicast: add vlan querier and query support (Ivan Vecera) [2019055]
- net: bridge: multicast: check if should use vlan mcast ctx (Ivan Vecera) [2019055]
- net: bridge: multicast: use the port group to port context helper (Ivan Vecera) [2019055]
- net: bridge: multicast: add helper to get port mcast context from port group (Ivan Vecera) [2019055]
- net: bridge: add vlan mcast snooping knob (Ivan Vecera) [2019055]
- net: bridge: multicast: add vlan state initialization and control (Ivan Vecera) [2019055]
- net: bridge: vlan: add global and per-port multicast context (Ivan Vecera) [2019055]
- net: bridge: multicast: use multicast contexts instead of bridge or port (Ivan Vecera) [2019055]
- net: bridge: multicast: factor out bridge multicast context (Ivan Vecera) [2019055]
- net: bridge: multicast: factor out port multicast context (Ivan Vecera) [2019055]
- net: switchdev: introduce a fanout helper for SWITCHDEV_FDB_{ADD,DEL}_TO_DEVICE (Ivan Vecera) [2019055]
- net: switchdev: introduce helper for checking dynamically learned FDB entries (Ivan Vecera) [2019055]
- net: bridge: do not replay fdb entries pointing towards the bridge twice (Ivan Vecera) [2019055]
- net: bridge: multicast: fix MRD advertisement router port marking race (Ivan Vecera) [2019055]
- net: bridge: multicast: fix PIM hello router port marking race (Ivan Vecera) [2019055]
- net: bridge: sync fdb to new unicast-filtering ports (Ivan Vecera) [2019055]
- net: bridge: allow br_fdb_replay to be called for the bridge device (Ivan Vecera) [2019055]
- net: bridge: switchdev: send FDB notifications for host addresses (Ivan Vecera) [2019055]
- net: bridge: use READ_ONCE() and WRITE_ONCE() compiler barriers for fdb->dst (Ivan Vecera) [2019055]
- net: bridge: allow the switchdev replay functions to be called for deletion (Ivan Vecera) [2019055]
- net: bridge: constify variables in the replay helpers (Ivan Vecera) [2019055]
- net: bridge: ignore switchdev events for LAG ports which didn't request replay (Ivan Vecera) [2019055]
- net: switchdev: add a context void pointer to struct switchdev_notifier_info (Ivan Vecera) [2019055]
- net: bridge: include the is_local bit in br_fdb_replay (Ivan Vecera) [2019055]
- net: bridge: mrp: Update the Test frames for MRA (Ivan Vecera) [2019055]
- bridge: cfm: remove redundant return (Ivan Vecera) [2019055]
- net: bridge: remove redundant continue statement (Ivan Vecera) [2019055]
- net: bridge: fix vlan tunnel dst refcnt when egressing (Ivan Vecera) [2019055]
- net: bridge: fix vlan tunnel dst null pointer dereference (Ivan Vecera) [2019055]
- net: bridge: mrp: Update ring transitions. (Ivan Vecera) [2019055]
- net: bridge: remove redundant assignment (Ivan Vecera) [2019055]
- net: bridge: fix br_multicast_is_router stub when igmp is disabled (Ivan Vecera) [2019055]
- net: bridge: fix build when IPv6 is disabled (Ivan Vecera) [2019055]
- net: bridge: mcast: export multicast router presence adjacent to a port (Ivan Vecera) [2019055]
- net: bridge: mcast: add ip4+ip6 mcast router timers to mdb netlink (Ivan Vecera) [2019055]
- net: bridge: mcast: split multicast router state for IPv4 and IPv6 (Ivan Vecera) [2019055]
- net: bridge: mcast: split router port del+notify for mcast router split (Ivan Vecera) [2019055]
- net: bridge: mcast: prepare add-router function for mcast router split (Ivan Vecera) [2019055]
- net: bridge: mcast: prepare expiry functions for mcast router split (Ivan Vecera) [2019055]
- net: bridge: mcast: prepare is-router function for mcast router split (Ivan Vecera) [2019055]
- net: bridge: mcast: prepare query reception for mcast router split (Ivan Vecera) [2019055]
- net: bridge: mcast: prepare mdb netlink for mcast router split (Ivan Vecera) [2019055]
- net: bridge: mcast: add wrappers for router node retrieval (Ivan Vecera) [2019055]
- net: bridge: mcast: rename multicast router lists and timers (Ivan Vecera) [2019055]
- bridge: Fix possible races between assigning rx_handler_data and setting IFF_BRIDGE_PORT bit (Ivan Vecera) [2019055]
- net: bridge: mcast: fix broken length + header check for MRDv6 Adv. (Ivan Vecera) [2019055]
- net: bridge: fix error in br_multicast_add_port when CONFIG_NET_SWITCHDEV=n (Ivan Vecera) [2019055]
- net: bridge: propagate error code and extack from br_mc_disabled_update (Ivan Vecera) [2019055]
- net: bridge: Fix missing return assignment from br_vlan_replay_one call (Ivan Vecera) [2019055]
- bridge: mrp: Disable roles before deleting the MRP instance (Ivan Vecera) [2019055]
- net: bridge: add helper to replay VLANs installed on port (Ivan Vecera) [2019055]
- net: bridge: add helper to replay port and local fdb entries (Ivan Vecera) [2019055]
- net: bridge: add helper to replay port and host-joined mdb entries (Ivan Vecera) [2019055]
- net: bridge: add helper to retrieve the current ageing time (Ivan Vecera) [2019055]
- net: bridge: add helper for retrieving the current bridge port STP state (Ivan Vecera) [2019055]
- net: bridge: when suppression is enabled exclude RARP packets (Ivan Vecera) [2019055]
- net: bridge: declare br_vlan_tunnel_lookup argument tunnel_id as __be64 (Ivan Vecera) [2019055]
- Documentation: networking: switchdev: add missing "and" word (Ivan Vecera) [2019055]
- Documentation: networking: switchdev: separate bulleted items with new line (Ivan Vecera) [2019055]
- Documentation: networking: switchdev: fix command for static FDB entries (Ivan Vecera) [2019055]
- Documentation: networking: switchdev: clarify device driver behavior (Ivan Vecera) [2019055]
- net: bridge: mcast: factor out common allow/block EHT handling (Ivan Vecera) [2019055]
- net: bridge: mcast: remove unreachable EHT code (Ivan Vecera) [2019055]
- net: bridge: Fix fall-through warnings for Clang (Ivan Vecera) [2019055]
- bridge: mrp: Update br_mrp to use new return values of br_mrp_switchdev (Ivan Vecera) [2019055]
- bridge: mrp: Extend br_mrp_switchdev to detect better the errors (Ivan Vecera) [2019055]
- bridge: mrp: Add 'enum br_mrp_hw_support' (Ivan Vecera) [2019055]
- switchdev: mrp: Extend ring_role_mrp and in_role_mrp (Ivan Vecera) [2019055]
- switchdev: mrp: Remove CONFIG_BRIDGE_MRP (Ivan Vecera) [2019055]
- net: bridge: fix br_vlan_filter_toggle stub when CONFIG_BRIDGE_VLAN_FILTERING=n (Ivan Vecera) [2019055]
- net: bridge: fix switchdev_port_attr_set stub when CONFIG_SWITCHDEV=n (Ivan Vecera) [2019055]
- net: bridge: propagate extack through switchdev_port_attr_set (Ivan Vecera) [2019055]
- net: bridge: propagate extack through store_bridge_parm (Ivan Vecera) [2019055]
- net: bridge: remove __br_vlan_filter_toggle (Ivan Vecera) [2019055]
- net: switchdev: pass flags and mask to both {PRE_,}BRIDGE_FLAGS attributes (Ivan Vecera) [2019055]
- net: bridge: don't print in br_switchdev_set_port_flag (Ivan Vecera) [2019055]
- net: bridge: offload all port flags at once in br_setport (Ivan Vecera) [2019055]
- net: switchdev: propagate extack to port attributes (Ivan Vecera) [2019055]
- switchdev: mrp: Remove SWITCHDEV_ATTR_ID_MRP_PORT_STAT (Ivan Vecera) [2019055]
- bridge: mrp: Fix the usage of br_mrp_port_switchdev_set_state (Ivan Vecera) [2019055]
- net: bridge: mcast: Use ERR_CAST instead of ERR_PTR(PTR_ERR()) (Ivan Vecera) [2019055]
- net: bridge: add warning comments to avoid extending sysfs (Ivan Vecera) [2019055]
- net: bridge: mcast: drop hosts limit sysfs support (Ivan Vecera) [2019055]
- net: bridge: multicast: make tracked EHT hosts limit configurable (Ivan Vecera) [2019055]
- net: bridge: multicast: add per-port EHT hosts limit (Ivan Vecera) [2019055]
- net: switchdev: use obj-$(CONFIG_NET_SWITCHDEV) form in net/Makefile (Ivan Vecera) [2019055]
- net: switchdev: don't set port_obj_info->handled true when -EOPNOTSUPP (Ivan Vecera) [2019055]
- net: bridge: multicast: fix br_multicast_eht_set_entry_lookup indentation (Ivan Vecera) [2019055]
- bridge: Use PTR_ERR_OR_ZERO instead if(IS_ERR(...)) + PTR_ERR (Ivan Vecera) [2019055]
- net: mrp: move struct definitions out of uapi (Ivan Vecera) [2019055]
- net: mrp: fix definitions of MRP test packets (Ivan Vecera) [2019055]
- net: bridge: multicast: mark IGMPv3/MLDv2 fast-leave deletes (Ivan Vecera) [2019055]
- net: bridge: multicast: handle block pg delete for all cases (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT host filter_mode handling (Ivan Vecera) [2019055]
- net: bridge: multicast: optimize TO_INCLUDE EHT timeouts (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT include and exclude handling (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT allow/block handling (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT host delete function (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT source set handling functions (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT host handling functions (Ivan Vecera) [2019055]
- net: bridge: multicast: add EHT structures and definitions (Ivan Vecera) [2019055]
- net: bridge: multicast: calculate idx position without changing ptr (Ivan Vecera) [2019055]
- net: bridge: multicast: __grp_src_block_incl can modify pg (Ivan Vecera) [2019055]
- net: bridge: multicast: pass host src address to IGMPv3/MLDv2 functions (Ivan Vecera) [2019055]
- net: bridge: multicast: rename src_size to addr_size (Ivan Vecera) [2019055]
- net: bridge: check vlan with eth_type_vlan() method (Ivan Vecera) [2019055]
- net: switchdev: delete the transaction object (Ivan Vecera) [2019055]
- mlxsw: spectrum_switchdev: remove transactional logic for VLAN objects (Ivan Vecera) [2019055]
- net: switchdev: remove the transaction structure from port attributes (Ivan Vecera) [2019055]
- net: switchdev: delete switchdev_port_obj_add_now (Ivan Vecera) [2019055]
- net: switchdev: remove the transaction structure from port object notifiers (Ivan Vecera) [2019055]
- net: switchdev: remove vid_begin -> vid_end range from VLAN objects (Ivan Vecera) [2019055]
- net: bridge: fix misspellings using codespell tool (Ivan Vecera) [2019055]
- net: bridge: notify switchdev of disappearance of old FDB entry upon migration (Ivan Vecera) [2019055]
- bridge: Fix a deadlock when enabling multicast snooping (Ivan Vecera) [2019055]
- bridge: mrp: Implement LC mode for MRP (Ivan Vecera) [2019055]
- net: bridge: switch to net core statistics counters handling (Ivan Vecera) [2019055]
- net: bridge: replace struct br_vlan_stats with pcpu_sw_netstats (Ivan Vecera) [2019055]
- bridge: mrp: Use hlist_head instead of list_head for mrp (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 *,g auto-add (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 exclude timeout (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 exc -> block report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 inc -> block report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 exc -> to_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 exc -> is_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 exc -> is_include report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 exc -> allow report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 inc -> to_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 inc -> is_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 inc -> is_include report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for mldv2 inc -> allow report (Ivan Vecera) [2019055]
- selftests: net: bridge: add initial MLDv2 include test (Ivan Vecera) [2019055]
- selftests: net: bridge: factor out and rename sg state functions (Ivan Vecera) [2019055]
- selftests: net: lib: add support for IPv6 mcast packet test (Ivan Vecera) [2019055]
- selftests: net: bridge: factor out mcast_packet_test (Ivan Vecera) [2019055]
- net: bridge: mcast: fix stub definition of br_multicast_querier_exists (Ivan Vecera) [2019055]
- net: bridge: explicitly convert between mdb entry state and port group flags (Ivan Vecera) [2019055]
- net: bridge: mcast: add support for raw L2 multicast groups (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 *,g auto-add (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 exclude timeout (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 exc -> block report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 inc -> block report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 exc -> to_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 exc -> is_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 exc -> is_include report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 exc -> allow report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 inc -> to_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 inc -> is_exclude report (Ivan Vecera) [2019055]
- selftests: net: bridge: add test for igmpv3 inc -> is_include report (Ivan Vecera) [2019055]
- selftests: net: bridge: add tests for igmpv3 is_include and inc -> allow reports (Ivan Vecera) [2019055]
- selftests: net: bridge: igmp: add IGMPv3 entries' state helpers (Ivan Vecera) [2019055]
- selftests: net: bridge: igmp: check for specific udp ip protocol (Ivan Vecera) [2019055]
- selftests: net: bridge: igmp: add support for packet source address (Ivan Vecera) [2019055]
- selftests: net: bridge: rename current igmp tests to igmpv2 (Ivan Vecera) [2019055]
- net: bridge: fix uninitialized variables when BRIDGE_CFM is disabled (Ivan Vecera) [2019055]
- bridge: cfm: Netlink Notifications. (Ivan Vecera) [2019055]
- bridge: cfm: Netlink GET status Interface. (Ivan Vecera) [2019055]
- bridge: cfm: Netlink GET configuration Interface. (Ivan Vecera) [2019055]
- bridge: cfm: Netlink SET configuration Interface. (Ivan Vecera) [2019055]
- bridge: cfm: Kernel space implementation of CFM. CCM frame RX added. (Ivan Vecera) [2019055]
- bridge: cfm: Kernel space implementation of CFM. CCM frame TX added. (Ivan Vecera) [2019055]
- bridge: cfm: Kernel space implementation of CFM. MEP create/delete. (Ivan Vecera) [2019055]
- bridge: uapi: cfm: Added EtherType used by the CFM protocol. (Ivan Vecera) [2019055]
- bridge: cfm: Add BRIDGE_CFM to Kconfig. (Ivan Vecera) [2019055]
- net: bridge: extend the process of special frames (Ivan Vecera) [2019055]
- bridge: Netlink interface fix. (Ivan Vecera) [2019055]
- net: bridge: mcast: remove only S,G port groups from sg_port hash (Ivan Vecera) [2019055]
- net: switchdev: Fixed kerneldoc warning (Ivan Vecera) [2019055]
- net: bridge: mcast: when forwarding handle filter mode and blocked flag (Ivan Vecera) [2019055]
- net: bridge: mcast: handle host state (Ivan Vecera) [2019055]
- net: bridge: mcast: add support for blocked port groups (Ivan Vecera) [2019055]
- net: bridge: mcast: handle port group filter modes (Ivan Vecera) [2019055]
- net: bridge: mcast: install S,G entries automatically based on reports (Ivan Vecera) [2019055]
- net: bridge: mcast: add sg_port rhashtable (Ivan Vecera) [2019055]
- net: bridge: mcast: add rt_protocol field to the port group struct (Ivan Vecera) [2019055]
- net: bridge: mcast: when igmpv3/mldv2 are enabled lookup (S,G) first, then (*,G) (Ivan Vecera) [2019055]
- net: bridge: mdb: add support for add/del/dump of entries with source (Ivan Vecera) [2019055]
- net: bridge: mdb: add support to extend add/del commands (Ivan Vecera) [2019055]
- net: bridge: mcast: rename br_ip's u member to dst (Ivan Vecera) [2019055]
- net: bridge: mcast: use br_ip's src for src groups and querier address (Ivan Vecera) [2019055]
- net: bridge: add src field to br_ip (Ivan Vecera) [2019055]
- net: bridge: mdb: use extack in br_mdb_add() and br_mdb_add_group() (Ivan Vecera) [2019055]
- net: bridge: mdb: move all port and bridge checks to br_mdb_add (Ivan Vecera) [2019055]
- net: bridge: mdb: use extack in br_mdb_parse() (Ivan Vecera) [2019055]
- net: bridge: delete duplicated words (Ivan Vecera) [2019055]
- net: bridge: mcast: don't ignore return value of __grp_src_toex_excl (Ivan Vecera) [2019055]
- __netif_receive_skb_core: don't untag vlan from skb on DSA master (Ivan Vecera) [2019055]
- bridge: mcast: Fix incomplete MDB dump (Ivan Vecera) [2019055]
- net: bridge: mcast: fix unused br var when lockdep isn't defined (Ivan Vecera) [2019055]
- net: bridge: mcast: destroy all entries via gc (Ivan Vecera) [2019055]
- net: bridge: mcast: improve IGMPv3/MLDv2 query processing (Ivan Vecera) [2019055]
- net: bridge: mcast: support for IGMPV3/MLDv2 BLOCK_OLD_SOURCES report (Ivan Vecera) [2019055]
- net: bridge: mcast: support for IGMPV3/MLDv2 CHANGE_TO_INCLUDE/EXCLUDE report (Ivan Vecera) [2019055]
- net: bridge: mcast: support for IGMPV3/MLDv2 MODE_IS_INCLUDE/EXCLUDE report (Ivan Vecera) [2019055]
- net: bridge: mcast: support for IGMPv3/MLDv2 ALLOW_NEW_SOURCES report (Ivan Vecera) [2019055]
- net: bridge: mcast: delete expired port groups without srcs (Ivan Vecera) [2019055]
- net: bridge: mdb: use mdb and port entries in notifications (Ivan Vecera) [2019055]
- net: bridge: mdb: push notifications in __br_mdb_add/del (Ivan Vecera) [2019055]
- net: bridge: mcast: add support for group query retransmit (Ivan Vecera) [2019055]
- net: bridge: mcast: add support for group-and-source specific queries (Ivan Vecera) [2019055]
- net: bridge: mcast: add support for src list and filter mode dumping (Ivan Vecera) [2019055]
- net: bridge: mcast: add support for group source list (Ivan Vecera) [2019055]
- net: bridge: mcast: factor out port group del (Ivan Vecera) [2019055]
- net: bridge: mdb: arrange internal structs so fast-path fields are close (Ivan Vecera) [2019055]
- netlink: consistently use NLA_POLICY_EXACT_LEN() (Ivan Vecera) [2019055]
- net: bridge: Add port attribute IFLA_BRPORT_MRP_IN_OPEN (Ivan Vecera) [2019055]
- bridge: mrp: Extend br_mrp_fill_info (Ivan Vecera) [2019055]
- bridge: uapi: mrp: Extend MRP_INFO attributes for interconnect status (Ivan Vecera) [2019055]
- bridge: mrp: Extend MRP netlink interface for configuring MRP interconnect (Ivan Vecera) [2019055]
- bridge: mrp: Implement the MRP Interconnect API (Ivan Vecera) [2019055]
- bridge: switchdev: mrp: Extend MRP API for switchdev for MRP Interconnect (Ivan Vecera) [2019055]
- bridge: mrp: Add br_mrp_in_port_open function (Ivan Vecera) [2019055]
- bridge: mrp: Rename br_mrp_port_open to br_mrp_ring_port_open (Ivan Vecera) [2019055]
- bridge: mrp: Extend br_mrp for MRP interconnect (Ivan Vecera) [2019055]
- bridge: mrp: Extend bridge interface (Ivan Vecera) [2019055]
- bridge: uapi: mrp: Extend MRP attributes for MRP interconnect (Ivan Vecera) [2019055]
- switchdev: mrp: Extend switchdev API for MRP Interconnect (Ivan Vecera) [2019055]
- net: bridge: fix undefined br_vlan_can_enter_range in tunnel code (Ivan Vecera) [2019055]
- net: switchdev: kerneldoc fixes (Ivan Vecera) [2019055]
- net: bridge: notify on vlan tunnel changes done via the old api (Ivan Vecera) [2019055]
- bridge: Extend br_fill_ifinfo to return MPR status (Ivan Vecera) [2019055]
- bridge: mrp: Add br_mrp_fill_info (Ivan Vecera) [2019055]
- bridge: uapi: mrp: Extend MRP attributes to get the status (Ivan Vecera) [2019055]
- bridge: mrp: Fix endian conversion and some other warnings (Ivan Vecera) [2019055]
- net: bridge: add a flag to avoid refreshing fdb when changing/adding (Ivan Vecera) [2019055]
- net: bridge: add option to allow activity notifications for any fdb entries (Ivan Vecera) [2019055]
- net: neighbor: add fdb extended attribute (Ivan Vecera) [2019055]
- net: bridge: fdb_add_entry takes ndm as argument (Ivan Vecera) [2019055]
- bridge: mrp: Validate when setting the port role (Ivan Vecera) [2019055]
- bridge: uapi: mrp: Fix MRP_PORT_ROLE (Ivan Vecera) [2019055]
- bridge: mrp: Add support for role MRA (Ivan Vecera) [2019055]
- bridge: mrp: Set the priority of MRP instance (Ivan Vecera) [2019055]
- bridge: mrp: Update MRP frame type (Ivan Vecera) [2019055]
- bridge: multicast: work around clang bug (Ivan Vecera) [2019055]
- bridge: mrp: Rework the MRP netlink interface (Ivan Vecera) [2019055]
- bridge: mrp: Fix out-of-bounds read in br_mrp_parse (Ivan Vecera) [2019055]
- bridge: mrp: Restore port state when deleting MRP instance (Ivan Vecera) [2019055]
- switchdev: mrp: Remove the variable mrp_ring_state (Ivan Vecera) [2019055]
- bridge: mrp: Add br_mrp_unique_ifindex function (Ivan Vecera) [2019055]
- net: bridge: allow enslaving some DSA master network devices (Ivan Vecera) [2019055]
- net: remove newlines in NL_SET_ERR_MSG_MOD (Ivan Vecera) [2019055]
- net: bridge: return false in br_mrp_enabled() (Ivan Vecera) [2019055]
- docs: networking: convert switchdev.txt to ReST (Ivan Vecera) [2019055]
- net: bridge: Add checks for enabling the STP. (Ivan Vecera) [2019055]
- bridge: mrp: Integrate MRP into the bridge (Ivan Vecera) [2019055]
- bridge: mrp: Implement netlink interface to configure MRP (Ivan Vecera) [2019055]
- bridge: mrp: Connect MRP API with the switchdev API (Ivan Vecera) [2019055]
- bridge: switchdev: mrp: Implement MRP API for switchdev (Ivan Vecera) [2019055]
- switchdev: mrp: Extend switchdev API to offload MRP (Ivan Vecera) [2019055]
- bridge: mrp: Add MRP interface. (Ivan Vecera) [2019055]
- net: bridge: Add port attribute IFLA_BRPORT_MRP_RING_OPEN (Ivan Vecera) [2019055]
- bridge: mrp: Extend bridge interface (Ivan Vecera) [2019055]
- bridge: mrp: Update Kconfig (Ivan Vecera) [2019055]
- bridge: uapi: mrp: Add mrp attributes. (Ivan Vecera) [2019055]
- net: bridge: vlan options: move the tunnel command to the nested attribute (Ivan Vecera) [2019055]
- net: bridge: vlan options: nest the tunnel id into a tunnel info attribute (Ivan Vecera) [2019055]
- net: bridge: vlan: include stats in dumps if requested (Ivan Vecera) [2019055]
- net: bridge: vlan options: add support for tunnel mapping set/del (Ivan Vecera) [2019055]
- net: bridge: vlan options: add support for tunnel id dumping (Ivan Vecera) [2019055]
- net: bridge: vlan tunnel: constify bridge and port arguments (Ivan Vecera) [2019055]
- net: bridge: vlan options: rename br_vlan_opts_eq to br_vlan_opts_eq_range (Ivan Vecera) [2019055]
- net: switchdev: do not propagate bridge updates across bridges (Ivan Vecera) [2019055]
- bridge: br_stp: Use built-in RCU list checking (Ivan Vecera) [2019055]
- net: switchdev: Replace zero-length array with flexible-array member (Ivan Vecera) [2019055]
- net: bridge: vlan: add per-vlan state (Ivan Vecera) [2019055]
- net: bridge: vlan: add basic option setting support (Ivan Vecera) [2019055]
- net: bridge: vlan: add basic option dumping support (Ivan Vecera) [2019055]
- net: bridge: check port state before br_allowed_egress (Ivan Vecera) [2019055]
- net: bridge: vlan: notify on vlan add/delete/change flags (Ivan Vecera) [2019055]
- net: bridge: vlan: add rtnetlink group and notify support (Ivan Vecera) [2019055]
- net: bridge: vlan: add rtm range support (Ivan Vecera) [2019055]
- net: bridge: vlan: add del rtm message support (Ivan Vecera) [2019055]
- net: bridge: vlan: add new rtm message support (Ivan Vecera) [2019055]
- net: bridge: vlan: add rtm definitions and dump support (Ivan Vecera) [2019055]
- net: bridge: netlink: add extack error messages when processing vlans (Ivan Vecera) [2019055]
- net: bridge: vlan: add helpers to check for vlan id/range validity (Ivan Vecera) [2019055]
- net: bridge: add STP xstats (Ivan Vecera) [2019055]
- treewide: Use sizeof_field() macro (Ivan Vecera) [2019055]
- bridge: implement get_link_ksettings ethtool method (Ivan Vecera) [2019055]
- net: bridge: fdb: eliminate extra port state tests from fast-path (Ivan Vecera) [2019055]
- net: bridge: fdb: restore unlikely() when taking over externally added entries (Ivan Vecera) [2019055]
- net: bridge: fdb: avoid two atomic bitops in br_fdb_external_learn_add() (Ivan Vecera) [2019055]
- net: bridge: fdb: br_fdb_update can take flags directly (Ivan Vecera) [2019055]
- net: bridge: Populate the pvid flag in br_vlan_get_info (Ivan Vecera) [2019055]
- net: fix __ip_mc_inc_group usage (Ivan Vecera) [2019055]
- net: bridge: mdb: allow add/delete for host-joined groups (Ivan Vecera) [2019055]
- net: bridge: mdb: dump host-joined entries as well (Ivan Vecera) [2019055]
- net: bridge: mdb: factor out mdb filling (Ivan Vecera) [2019055]
- net: bridge: mdb: move vlan comments (Ivan Vecera) [2019055]
- net: bridge: mcast: add delete due to fast-leave mdb flag (Ivan Vecera) [2019055]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Ivan Vecera) [2019055]
- treewide: Add SPDX license identifier for missed files (Ivan Vecera) [2019055]
- treewide: Add SPDX license identifier - Makefile/Kconfig (Ivan Vecera) [2019055]
- bridge: Fix error path for kobject_init_and_add() (Ivan Vecera) [2019055]
- bridge: only include nf_queue.h if needed (Ivan Vecera) [2019055]
- bridge: broute: make broute a real ebtables table (Ivan Vecera) [2019055]
- bridge: netfilter: unroll NF_HOOK helper in bridge input path (Ivan Vecera) [2019055]
- bridge: reduce size of input cb to 16 bytes (Ivan Vecera) [2019055]
- net: bridge: update multicast stats from maybe_deliver() (Ivan Vecera) [2019055]
- net: bridge: mcast: remove unused br_ip_equal function (Ivan Vecera) [2019055]
- net: bridge: optimize backup_port fdb convergence (Ivan Vecera) [2019055]
- net: bridge: use netif_is_bridge_port() (Ivan Vecera) [2019055]
- net: bridge: use eth_broadcast_addr() to assign broadcast address (Ivan Vecera) [2019055]
- tools headers uapi: Update linux/in.h copy (Ivan Vecera) [2019055]
- switchdev: Remove unused transaction item queue (Ivan Vecera) [2019055]
- bridge: remove redundant check on err in br_multicast_ipv4_rcv (Ivan Vecera) [2019055]
- net: Fix ip_mc_{dec,inc}_group allocation context (Ivan Vecera) [2019055]
- bridge: remove duplicated include from br_multicast.c (Ivan Vecera) [2019055]
- bridge: Snoop Multicast Router Advertisements (Ivan Vecera) [2019055]
- bridge: join all-snoopers multicast address (Ivan Vecera) [2019055]
- bridge: simplify ip_mc_check_igmp() and ipv6_mc_check_mld() internals (Ivan Vecera) [2019055]
- tools include uapi: Sync linux/if_link.h copy with the kernel sources (Ivan Vecera) [2019055]
- net: bridge: fix a bug on using a neighbour cache entry without checking its state (Ivan Vecera) [2019055]
- net: bridge: remove unneeded variable 'err' (Ivan Vecera) [2019055]
- net: bridge: remove redundant checks for null p->dev and p->br (Ivan Vecera) [2019055]
- net: bridge: export supported boolopts (Ivan Vecera) [2019055]
- net: bridge: add no_linklocal_learn bool option (Ivan Vecera) [2019055]
- net: bridge: add support for user-controlled bool options (Ivan Vecera) [2019055]
- bridge: use __vlan_hwaccel helpers (Ivan Vecera) [2019055]
- netfilter: bridge: define INT_MIN & INT_MAX in userspace (Ivan Vecera) [2019055]
- docs: fix some broken documentation references (Ivan Vecera) [2019055]
- bridge: Switch to bitmap_zalloc() (Ivan Vecera) [2019055]
- netfilter: bridge: Expose nf_tables bridge hook priorities through uapi (Ivan Vecera) [2019055]
- net: bridge: add support for backup port (Ivan Vecera) [2019055]
- net: bridge: add support for raw sysfs port options (Ivan Vecera) [2019055]
- docs: networking: Convert bridge.txt to rst (Ivan Vecera) [2019055]
- net: switchdev: consolidate RH_KABI macros usage (Ivan Vecera) [2019055]
- kcov: Remove kcov include from sched.h and move it to its users. (Josef Oskera) [2026467]
- tasklets: Provide tasklet_disable_in_atomic() (Ivan Vecera) [2026475]
- tasklets: Use static inlines for stub implementations (Ivan Vecera) [2026475]
- net: sock: introduce sk_error_report (Ivan Vecera) [2026469]
- redhat: Add CONFIG_RHEL_DIFFERENCES (Prarit Bhargava) [2021571]

* Wed Dec 22 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-357.el8]
- serial: 8520_port: Fix function param documentation (Waiman Long) [1970241]
- serial: 8250: Optimize irq enable after console write (Waiman Long) [1970241]
- serial: 8250: Fix rs485 delay after console write (Waiman Long) [1970241]
- serial: 8250: Support console on software emulated rs485 ports (Waiman Long) [1970241]
- serial: 8250: Generalize rs485 software emulation (Waiman Long) [1970241]
- serial: 8250: Deduplicate rs485 active_timer assignment (Waiman Long) [1970241]
- serial: 8250: Sanitize rs485 config harder (Waiman Long) [1970241]
- serial: 8250: Deduplicate ->rs485_config() callback (Waiman Long) [1970241]
- serial: 8250: Support rs485 devicetree properties (Waiman Long) [1970241]
- serial: 8250_port: Don't use power management for kernel console (Waiman Long) [1970241]
- console: Introduce ->exit() callback (Waiman Long) [1970241]
- console: Don't notify user space when unregister non-listed console (Waiman Long) [1970241]
- tty: 8250_of: Use software emulated RS485 direction control (Waiman Long) [1970241]
- serial: 8250: Add MSR/MCR TIOCM conversion wrapper functions (Waiman Long) [1970241]
- serial: 8250_of: Use of_device_get_match_data() (Waiman Long) [1970241]
- serial: 8250_of: Fix for lack of interrupt support (Waiman Long) [1970241]
- serial: 8250: of: Defer probe on missing IRQ (Waiman Long) [1970241]
- serial: 8250: of: Correct of_platform_serial_setup() error handling (Waiman Long) [1970241]
- mm/vmstat: protect per cpu variables with preempt disable on RT (Scott Wood) [2011667]
- mm, slub: convert kmem_cpu_slab protection to local_lock (Scott Wood) [2011667]
- mm, slub: use migrate_disable() on PREEMPT_RT (Scott Wood) [2011667]
- mm, slub: protect put_cpu_partial() with disabled irqs instead of cmpxchg (Scott Wood) [2011667]
- mm, slub: make slab_lock() disable irqs with PREEMPT_RT (Scott Wood) [2011667]
- mm: slub: make object_map_lock a raw_spinlock_t (Scott Wood) [2011667]
- mm: slub: move flush_cpu_slab() invocations __free_slab() invocations out of IRQ context (Scott Wood) [2011667]
- mm, slab: split out the cpu offline variant of flush_slab() (Scott Wood) [2011667]
- mm, slub: don't disable irqs in slub_cpu_dead() (Scott Wood) [2011667]
- mm, slub: only disable irq with spin_lock in __unfreeze_partials() (Scott Wood) [2011667]
- mm, slub: separate detaching of partial list in unfreeze_partials() from unfreezing (Scott Wood) [2011667]
- mm, slub: detach whole partial list at once in unfreeze_partials() (Scott Wood) [2011667]
- mm, slub: discard slabs in unfreeze_partials() without irqs disabled (Scott Wood) [2011667]
- mm, slub: move irq control into unfreeze_partials() (Scott Wood) [2011667]
- mm, slub: call deactivate_slab() without disabling irqs (Scott Wood) [2011667]
- mm, slub: make locking in deactivate_slab() irq-safe (Scott Wood) [2011667]
- mm, slub: move reset of c->page and freelist out of deactivate_slab() (Scott Wood) [2011667]
- mm, slub: stop disabling irqs around get_partial() (Scott Wood) [2011667]
- mm, slub: check new pages with restored irqs (Scott Wood) [2011667]
- mm, slub: validate slab from partial list or page allocator before making it cpu slab (Scott Wood) [2011667]
- mm, slub: restore irqs around calling new_slab() (Scott Wood) [2011667]
- mm, slub: move disabling irqs closer to get_partial() in ___slab_alloc() (Scott Wood) [2011667]
- mm, slub: do initial checks in ___slab_alloc() with irqs enabled (Scott Wood) [2011667]
- mm, slub: move disabling/enabling irqs to ___slab_alloc() (Scott Wood) [2011667]
- mm, slub: simplify kmem_cache_cpu and tid setup (Scott Wood) [2011667]
- mm, slub: restructure new page checks in ___slab_alloc() (Scott Wood) [2011667]
- mm, slub: return slab page from get_partial() and set c->page afterwards (Scott Wood) [2011667]
- mm, slub: dissolve new_slab_objects() into ___slab_alloc() (Scott Wood) [2011667]
- mm, slub: extract get_partial() from new_slab_objects() (Scott Wood) [2011667]
- mm, slub: remove redundant unfreeze_partials() from put_cpu_partial() (Scott Wood) [2011667]
- mm, slub: don't disable irq for debug_check_no_locks_freed() (Scott Wood) [2011667]
- mm, slub: allocate private object map for validate_slab_cache() (Scott Wood) [2011667]
- mm, slub: allocate private object map for debugfs listings (Scott Wood) [2011667]
- mm, slub: don't call flush_all() from slab_debug_trace_open() (Scott Wood) [2011667]
- mm/slub.c: drop lockdep_assert_held() from put_map() (Scott Wood) [2011667]
- mm/slub.c: replace cpu_slab->partial with wrapped APIs (Scott Wood) [2011667]
- mm/slub.c: replace kmem_cache->cpu_partial with wrapped APIs (Scott Wood) [2011667]
- sched/rt, mm: Use CONFIG_PREEMPTION (Scott Wood) [2011667]
- tcp: fix page frag corruption on page fault (Paolo Abeni) [1996074]
- net: fix sk_page_frag() recursion from memory reclaim (Paolo Abeni) [1996074]
- net: udp6: replace __UDP_INC_STATS() with __UDP6_INC_STATS() (Xin Long) [2020407]
- net: udp: annotate data race around udp_sk(sk)->corkflag (Xin Long) [2020407]
- net/ipv4/udp_tunnel_core.c: remove superfluous header files from udp_tunnel_core.c (Xin Long) [2020407]
- udp_tunnel: Fix udp_tunnel_nic work-queue type (Xin Long) [2020407]
- net, gro: Set inner transport header offset in tcp/udp GRO hook (Xin Long) [2020407]
- bareudp: Add extack support to bareudp_configure() (Guillaume Nault) [1946040]
- bareudp: Move definition of struct bareudp_conf to bareudp.c (Guillaume Nault) [1946040]
- bareudp: Remove bareudp_dev_create() (Guillaume Nault) [1946040]
- net: bareudp: simplify error paths calling dellink (Guillaume Nault) [1946040]
- mptcp: re-arm retransmit timer if data is pending (Paolo Abeni) [2019493]
- mptcp: remove tx_pending_data (Paolo Abeni) [2019493]
- mptcp: do not shrink snd_nxt when recovering (Paolo Abeni) [2019493]
- mptcp: drop unused sk in mptcp_push_release (Paolo Abeni) [2019493]
- selftests: mptcp: fix proto type in link_failure tests (Paolo Abeni) [2019493]
- selftests: mptcp: add testcase for active-back (Paolo Abeni) [2019493]
- mptcp: backup flag from incoming MPJ ack option (Paolo Abeni) [2019493]
- mptcp: add mibs for stale subflows processing (Paolo Abeni) [2019493]
- mptcp: faster active backup recovery (Paolo Abeni) [2019493]
- mptcp: cleanup sysctl data and helpers (Paolo Abeni) [2019493]
- mptcp: handle pending data on closed subflow (Paolo Abeni) [2019493]
- mptcp: less aggressive retransmission strategy (Paolo Abeni) [2019493]
- mptcp: more accurate timeout (Paolo Abeni) [2019493]
- mptcp: stop relying on tcp_tx_skb_cache (Paolo Abeni) [2019493]
- tcp: expose the tcp_mark_push() and tcp_skb_entail() helpers (Paolo Abeni) [2019493]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2009340]
- KVM: X86: Fix when shadow_root_level=5 && guest root_level<4 (Vitaly Kuznetsov) [2009340]
- KVM: x86: inhibit APICv when KVM_GUESTDBG_BLOCKIRQ active (Vitaly Kuznetsov) [2009340]
- KVM: x86/xen: Fix get_attr of KVM_XEN_ATTR_TYPE_SHARED_INFO (Vitaly Kuznetsov) [2009340]
- KVM: x86: Use rw_semaphore for APICv lock to allow vCPU parallelism (Vitaly Kuznetsov) [2009340]
- KVM: selftests: test KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009340]
- x86/sgx/virt: implement SGX_IOC_VEPC_REMOVE ioctl (Vitaly Kuznetsov) [2009340]
- x86/sgx/virt: extract sgx_vepc_remove_page (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Complete prefetch for trailing SPTEs for direct, legacy MMU (Vitaly Kuznetsov) [2009340]
- KVM: x86: Do not mark all registers as avail/dirty during RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: x86: SVM: don't set VMLOAD/VMSAVE intercepts on vCPU reset (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Unregister posted interrupt wakeup handler on hardware unsetup (Vitaly Kuznetsov) [2009340]
- Revert "x86/kvm: fix vcpu-id indexed array sizes" (Vitaly Kuznetsov) [2009340]
- KVM: X86: Cache CR3 in prev_roots when PCID is disabled (Vitaly Kuznetsov) [2009340]
- KVM: X86: Fix tlb flush for tdp in kvm_invalidate_pcid() (Vitaly Kuznetsov) [2009340]
- KVM: X86: Don't reset mmu context when toggling X86_CR4_PGE (Vitaly Kuznetsov) [2009340]
- KVM: X86: Don't reset mmu context when X86_CR4_PCIDE 1->0 (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: kvm_faultin_pfn has to return false if pfh is returned (Vitaly Kuznetsov) [2009340]
- KVM: x86: Take srcu lock in post_kvm_run_save() (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: fix another issue with string I/O VMGEXITs (Vitaly Kuznetsov) [2009340]
- KVM: x86/xen: Fix kvm_xen_has_interrupt() sleeping in kvm_vcpu_block() (Vitaly Kuznetsov) [2009340]
- KVM: x86: switch pvclock_gtod_sync_lock to a raw spinlock (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Refactor help message for -s backing_src (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Change backing_src flag to -s in demand_paging_test (Vitaly Kuznetsov) [2009340]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: go over the sev_pio_data buffer in multiple passes if needed (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: keep INS functions together (Vitaly Kuznetsov) [2009340]
- KVM: x86: remove unnecessary arguments from complete_emulator_pio_in (Vitaly Kuznetsov) [2009340]
- KVM: x86: split the two parts of emulator_pio_in (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: clean up kvm_sev_es_ins/outs (Vitaly Kuznetsov) [2009340]
- KVM: x86: leave vcpu->arch.pio.count alone in emulator_pio_in_out (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: rename guest_ins_data to sev_pio_data (Vitaly Kuznetsov) [2009340]
- KVM: SEV: Flush cache on non-coherent systems before RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009340]
- KVM: MMU: Reset mmu->pkru_mask to avoid stale data (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: promptly process interrupts delivered while in guest mode (Vitaly Kuznetsov) [2009340]
- KVM: x86: check for interrupts before deciding whether to exit the fast path (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: reduce ghcb_sa_len to 32 bits (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove redundant handling of bus lock vmexit (Vitaly Kuznetsov) [2009340]
- KVM: x86: WARN if APIC HW/SW disable static keys are non-zero on unload (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: fix length of string I/O (Vitaly Kuznetsov) [2009340]
- KVM: SEV-ES: Set guest_state_protected after VMSA update (Vitaly Kuznetsov) [2009340]
- KVM: kvm_stat: do not show halt_wait_ns (Vitaly Kuznetsov) [2009340]
- Revert "KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET" (Vitaly Kuznetsov) [2009340]
- KVM: s390: restore old debugfs names (Vitaly Kuznetsov) [2009340]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009340]
- tools headers UAPI: Synch KVM's svm.h header with the kernel (Vitaly Kuznetsov) [2009340]
- KVM: selftests: introduce P44V64 for z196 and EC12 (Vitaly Kuznetsov) [2009340]
- KVM: selftests: introduce P47V64 for s390x (Vitaly Kuznetsov) [2009340]
- x86/sev: Use "SEV: " prefix for messages from sev.c (Vitaly Kuznetsov) [2009340]
- KVM: stats: remove dead stores (Vitaly Kuznetsov) [2009340]
- kvm: x86: Add AMD PMU MSRs to msrs_to_save_all[] (Vitaly Kuznetsov) [2009340]
- kvm: fix objtool relocation warning (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Ensure all migrations are performed when test is affined (Vitaly Kuznetsov) [2009340]
- KVM: x86: Swap order of CPUID entry "index" vs. "significant flag" checks (Vitaly Kuznetsov) [2009340]
- x86/kvmclock: Move this_cpu_pvti into kvmclock.h (Vitaly Kuznetsov) [2009340]
- selftests: KVM: Don't clobber XMM register when read (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Fix a TSX_CTRL_CPUID_CLEAR field mask issue (Vitaly Kuznetsov) [2009340]
- selftests: KVM: Explicitly use movq to read xmm registers (Vitaly Kuznetsov) [2009340]
- selftests: KVM: Call ucall_init when setting up in rseq_test (Vitaly Kuznetsov) [2009340]
- KVM: X86: Synchronize the shadow pagetable before link it (Vitaly Kuznetsov) [2009340]
- KVM: X86: Fix missed remote tlb flush in rmap_write_protect() (Vitaly Kuznetsov) [2009340]
- KVM: x86: nSVM: don't copy virt_ext from vmcb12 (Vitaly Kuznetsov) [2009340]
- KVM: x86: nSVM: test eax for 4K alignment for GP errata workaround (Vitaly Kuznetsov) [2009340]
- KVM: x86: selftests: test simultaneous uses of V_IRQ from L1 and L0 (Vitaly Kuznetsov) [2009340]
- KVM: x86: nSVM: restore int_vector in svm_clear_vintr (Vitaly Kuznetsov) [2009340]
- KVM: x86: nVMX: re-evaluate emulation_required on nested VM exit (Vitaly Kuznetsov) [2009340]
- KVM: x86: nVMX: don't fail nested VM entry on invalid guest state if !from_vmentry (Vitaly Kuznetsov) [2009340]
- KVM: x86: VMX: synthesize invalid VM exit when emulating invalid guest state (Vitaly Kuznetsov) [2009340]
- KVM: x86: nSVM: refactor svm_leave_smm and smm_enter_smm (Vitaly Kuznetsov) [2009340]
- KVM: x86: SVM: call KVM_REQ_GET_NESTED_STATE_PAGES on exit from SMM mode (Vitaly Kuznetsov) [2009340]
- KVM: x86: reset pdptrs_from_userspace when exiting smm (Vitaly Kuznetsov) [2009340]
- KVM: x86: nSVM: restore the L1 host state prior to resuming nested guest on SMM exit (Vitaly Kuznetsov) [2009340]
- KVM: KVM: Use cpumask_available() to check for NULL cpumask when kicking vCPUs (Vitaly Kuznetsov) [2009340]
- KVM: Clean up benign vcpu->cpu data races when kicking vCPUs (Vitaly Kuznetsov) [2009340]
- KVM: x86: Fix stack-out-of-bounds memory access from ioapic_write_indirect() (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Create a separate dirty bitmap per slot (Vitaly Kuznetsov) [2009340]
- KVM: SEV: Allow some commands for mirror VM (Vitaly Kuznetsov) [2009340]
- KVM: SEV: Update svm_vm_copy_asid_from for SEV-ES (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Fix nested bus lock VM exit (Vitaly Kuznetsov) [2009340]
- KVM: x86: Identify vCPU0 by its vcpu_idx instead of its vCPUs array entry (Vitaly Kuznetsov) [2009340]
- KVM: x86: Query vcpu->vcpu_idx directly and drop its accessor (Vitaly Kuznetsov) [2009340]
- kvm: fix wrong exception emulation in check_rdtsc (Vitaly Kuznetsov) [2009340]
- KVM: SEV: Pin guest memory for write for RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009340]
- KVM: SVM: fix missing sev_decommission in sev_receive_start (Vitaly Kuznetsov) [2009340]
- KVM: SEV: Acquire vcpu mutex when updating VMSA (Vitaly Kuznetsov) [2009340]
- KVM: do not shrink halt_poll_ns below grow_start (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: fix comments of handle_vmon() (Vitaly Kuznetsov) [2009340]
- KVM: x86: Handle SRCU initialization failure during page track init (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove defunct "nr_active_uret_msrs" field (Vitaly Kuznetsov) [2009340]
- selftests: KVM: Align SMCCC call with the spec in steal_time (Vitaly Kuznetsov) [2009340]
- selftests: KVM: Fix check for !POLLIN in demand_paging_test (Vitaly Kuznetsov) [2009340]
- KVM: x86: Clear KVM's cached guest CR3 at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: x86: Mark all registers as avail/dirty at vCPU creation (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add a test for KVM_RUN+rseq to detect task migration bugs (Vitaly Kuznetsov) [2009340]
- tools: Move x86 syscall number fallbacks to .../uapi/ (Vitaly Kuznetsov) [2009340]
- selftests: kvm: fix get_run_delay() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009340]
- selftests: kvm: move get_run_delay() into lib/test_util (Vitaly Kuznetsov) [2009340]
- selftests:kvm: fix get_trans_hugepagesz() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009340]
- selftests:kvm: fix get_warnings_count() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009340]
- tools: rename bitmap_alloc() to bitmap_zalloc() (Vitaly Kuznetsov) [2009340]
- KVM: Drop unused kvm_dirty_gfn_invalid() (Vitaly Kuznetsov) [2009340]
- KVM: MMU: mark role_regs and role accessors as maybe unused (Vitaly Kuznetsov) [2009340]
- x86/kvm: Don't enable IRQ when IRQ enabled in kvm_wait (Vitaly Kuznetsov) [2009340]
- KVM: stats: Add VM stat for remote tlb flush requests (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Move lpage_disallowed_link further "down" in kvm_mmu_page (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Relocate kvm_mmu_page.tdp_mmu_page for better cache locality (Vitaly Kuznetsov) [2009340]
- Revert "KVM: x86: mmu: Add guest physical address check in translate_gpa()" (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Remove unused field mmio_cached in struct kvm_mmu_page (Vitaly Kuznetsov) [2009340]
- KVM: VMX: avoid running vmx_handle_exit_irqoff in case of emulation (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Don't freak out if pml5_root is NULL on 4-level host (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Add 5-level page table support for SVM (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Support shadowing NPT when 5-level paging is enabled in host (Vitaly Kuznetsov) [2009340]
- KVM: x86: Allow CPU to force vendor-specific TDP level (Vitaly Kuznetsov) [2009340]
- KVM: x86: clamp host mapping level to max_level in kvm_mmu_max_mapping_level (Vitaly Kuznetsov) [2009340]
- KVM: x86: implement KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009340]
- KVM: SVM: split svm_handle_invalid_exit (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Avoid collision with !PRESENT SPTEs in TDP MMU lpage stats (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Remove redundant spte present check in mmu_set_spte (Vitaly Kuznetsov) [2009340]
- KVM: stats: Add halt polling related histogram stats (Vitaly Kuznetsov) [2009340]
- KVM: stats: Add halt_wait_ns stats for all architectures (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add checks for histogram stats bucket_size field (Vitaly Kuznetsov) [2009340]
- KVM: stats: Update doc for histogram statistics (Vitaly Kuznetsov) [2009340]
- KVM: stats: Support linear and logarithmic histogram statistics (Vitaly Kuznetsov) [2009340]
- KVM: SVM: AVIC: drop unsupported AVIC base relocation code (Vitaly Kuznetsov) [2009340]
- KVM: SVM: call avic_vcpu_load/avic_vcpu_put when enabling/disabling AVIC (Vitaly Kuznetsov) [2009340]
- KVM: SVM: move check for kvm_vcpu_apicv_active outside of avic_vcpu_{put|load} (Vitaly Kuznetsov) [2009340]
- KVM: SVM: avoid refreshing avic if its state didn't change (Vitaly Kuznetsov) [2009340]
- KVM: SVM: remove svm_toggle_avic_for_irq_window (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Deactivate APICv only when AutoEOI feature is in use (Vitaly Kuznetsov) [2009340]
- KVM: SVM: add warning for mistmatch between AVIC vcpu state and AVIC inhibition (Vitaly Kuznetsov) [2009340]
- KVM: x86: APICv: fix race in kvm_request_apicv_update on SVM (Vitaly Kuznetsov) [2009340]
- KVM: x86: don't disable APICv memslot when inhibited (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: allow APICv memslot to be enabled but invisible (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: allow kvm_faultin_pfn to return page fault handling code (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: rename try_async_pf to kvm_faultin_pfn (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: add comment explaining arguments to kvm_zap_gfn_range (Vitaly Kuznetsov) [2009340]
- KVM: Allow to have arch-specific per-vm debugfs files (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Unconditionally clear nested.pi_pending on nested VM-Enter (Vitaly Kuznetsov) [2009340]
- KVM: x86: Clean up redundant ROL16(val, n) macro definition (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move declaration of kvm_spurious_fault() to x86.h (Vitaly Kuznetsov) [2009340]
- KVM: x86: Kill off __ex() and __kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Hide VMCS control calculators in vmx.c (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Drop caching of KVM's desired sec exec controls for vmcs01 (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Pull KVM L0's desired controls directly from vmcs01 (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Reset DR6 only when KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009340]
- KVM: X86: Set host DR6 only on VMX and for KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009340]
- KVM: X86: Remove unneeded KVM_DEBUGREG_RELOAD (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Use vmx_need_pf_intercept() when deciding if L0 wants a #PF (Vitaly Kuznetsov) [2009340]
- kvm: vmx: Sync all matching EPTPs when injecting nested EPT fault (Vitaly Kuznetsov) [2009340]
- KVM: x86: remove dead initialization (Vitaly Kuznetsov) [2009340]
- KVM: x86: Allow guest to set EFER.NX=1 on non-PAE 32-bit kernels (Vitaly Kuznetsov) [2009340]
- x86: Fix typo s/ECLR/ELCR/ for the PIC register (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Use current VMCS to query WAITPKG support for MSR emulation (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Move vcpu_args_set into perf_test_util (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Support multiple slots in dirty_log_perf_test (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Leverage vcpu->last_used_slot for rmap_add and rmap_recycle (Vitaly Kuznetsov) [2009340]
- KVM: Cache the last used slot index per vCPU (Vitaly Kuznetsov) [2009340]
- KVM: Move last_used_slot logic out of search_memslots (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix per-cpu counter corruption on 32-bit builds (Vitaly Kuznetsov) [2009340]
- KVM: xen: do not use struct gfn_to_hva_cache (Vitaly Kuznetsov) [2009340]
- KVM: selftests: fix hyperv_clock test (Vitaly Kuznetsov) [2009340]
- KVM: SVM: improve the code readability for ASID management (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Fix off-by-one indexing when nullifying last used SEV VMCB (Vitaly Kuznetsov) [2009340]
- KVM: Do not leak memory for duplicate debugfs directories (Vitaly Kuznetsov) [2009340]
- KVM: x86/pmu: Introduce pmc->is_paused to reduce the call time of perf interfaces (Vitaly Kuznetsov) [2009340]
- KVM: X86: Optimize zapping rmap (Vitaly Kuznetsov) [2009340]
- KVM: X86: Optimize pte_list_desc with per-array counter (Vitaly Kuznetsov) [2009340]
- KVM: X86: MMU: Tune PTE_LIST_EXT to be bigger (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Test access to XMM fast hypercalls (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Check if guest is allowed to use XMM registers for hypercall input (Vitaly Kuznetsov) [2009340]
- KVM: x86: Introduce trace_kvm_hv_hypercall_done() (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Check access to hypercall before reading XMM registers (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: remove useless kvm_clear_*_queue (Vitaly Kuznetsov) [2009340]
- KVM: x86: Preserve guest's CR0.CD/NW on INIT (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Drop redundant clearing of vcpu->arch.hflags at INIT/RESET (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Emulate #INIT in response to triple fault shutdown (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Move RESET-only VMWRITE sequences to init_vmcs() (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove redundant write to set vCPU as active at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Smush x2APIC MSR bitmap adjustments into single function (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove unnecessary initialization of msr_bitmap_mode (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Don't redo x2APIC MSR bitmaps when userspace filter is changed (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Remove obsolete MSR bitmap refresh at nested transitions (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove obsolete MSR bitmap refresh at vCPU RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move setting of sregs during vCPU RESET/INIT to common x86 (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Don't _explicitly_ reconfigure user return MSRs on vCPU INIT (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Refresh list of user return MSRs after setting guest CPUID (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Skip pointless MSR bitmap update when setting EFER (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Stuff save->dr6 at during VMSA sync, not at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Drop redundant writes to vmcb->save.cr4 at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Tweak order of cr0/cr4/efer writes at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Don't evaluate "emulation required" on nested VM-Exit (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Skip emulation required checks during pmode/rmode transitions (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Process CR0.PG side effects after setting CR0 assets (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Skip the permission_fault() check on MMIO if CR0.PG=0 (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Pull GUEST_CR3 from the VMCS iff CR3 load exiting is disabled (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Do not clear CR3 load/store exiting bits if L1 wants 'em (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Fold ept_update_paging_mode_cr0() back into vmx_set_cr0() (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove direct write to vcpu->arch.cr0 during vCPU RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Invert handling of CR0.WP for EPT without unrestricted guest (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Don't bother writing vmcb->save.rip at vCPU RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move EDX initialization at vCPU RESET to common code (Vitaly Kuznetsov) [2009340]
- KVM: x86: Consolidate APIC base RESET initialization code (Vitaly Kuznetsov) [2009340]
- KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Stuff vcpu->arch.apic_base directly at vCPU RESET (Vitaly Kuznetsov) [2009340]
- KVM: x86: Set BSP bit in reset BSP vCPU's APIC base by default (Vitaly Kuznetsov) [2009340]
- KVM: x86: Don't force set BSP bit when local APIC is managed by userspace (Vitaly Kuznetsov) [2009340]
- KVM: x86: Migrate the PIT only if vcpu0 is migrated, not any BSP (Vitaly Kuznetsov) [2009340]
- KVM: x86: Remove defunct BSP "update" in local APIC reset (Vitaly Kuznetsov) [2009340]
- KVM: x86: WARN if the APIC map is dirty without an in-kernel local APIC (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Drop explicit MMU reset at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Remove explicit MMU reset in enter_rmode() (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Fall back to KVM's hardcoded value for EDX at RESET/INIT (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Require exact CPUID.0x1 match when stuffing EDX at INIT (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Set EDX at INIT with CPUID.0x1, Family-Model-Stepping (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Zero out GDTR.base and IDTR.base on INIT (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Set LDTR to its architecturally defined value on nested VM-Exit (Vitaly Kuznetsov) [2009340]
- KVM: x86: Flush the guest's TLB on INIT (Vitaly Kuznetsov) [2009340]
- KVM: x86: APICv: drop immediate APICv disablement on current vCPU (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: fast_page_fault support for the TDP MMU (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Make walk_shadow_page_lockless_{begin,end} interoperate with the TDP MMU (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix use of enums in trace_fast_page_fault (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Rename cr2_or_gpa to gpa in fast_page_fault (Vitaly Kuznetsov) [2009340]
- KVM: Introduce kvm_get_kvm_safe() (Vitaly Kuznetsov) [2009340]
- x86/kvm: remove non-x86 stuff from arch/x86/kvm/ioapic.h (Vitaly Kuznetsov) [2009340]
- KVM: X86: Add per-vm stat for max rmap list size (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Return old SPTE from mmu_spte_clear_track_bits() (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Refactor shadow walk in __direct_map() to reduce indentation (Vitaly Kuznetsov) [2009340]
- KVM: x86: Hoist kvm_dirty_regs check out of sync_regs() (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Mark VM as bugged if page fault returns RET_PF_INVALID (Vitaly Kuznetsov) [2009340]
- KVM: x86: Use KVM_BUG/KVM_BUG_ON to handle bugs that are fatal to the VM (Vitaly Kuznetsov) [2009340]
- KVM: Export kvm_make_all_cpus_request() for use in marking VMs as bugged (Vitaly Kuznetsov) [2009340]
- KVM: Add infrastructure and macro to mark VM as bugged (Vitaly Kuznetsov) [2009340]
- KVM: Get rid of kvm_get_pfn() (Vitaly Kuznetsov) [2009340]
- KVM: arm64: Use get_page() instead of kvm_get_pfn() (Vitaly Kuznetsov) [2009340]
- KVM: x86: accept userspace interrupt only if no event is injected (Vitaly Kuznetsov) [2009340]
- KVM: add missing compat KVM_CLEAR_DIRTY_LOG (Vitaly Kuznetsov) [2009340]
- KVM: use cpu_relax when halt polling (Vitaly Kuznetsov) [2009340]
- KVM: SVM: use vmcb01 in svm_refresh_apicv_exec_ctrl (Vitaly Kuznetsov) [2009340]
- KVM: SVM: tweak warning about enabled AVIC on nested entry (Vitaly Kuznetsov) [2009340]
- KVM: SVM: svm_set_vintr don't warn if AVIC is active but is about to be deactivated (Vitaly Kuznetsov) [2009340]
- KVM: SVM: delay svm_vcpu_init_msrpm after svm->vmcb is initialized (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Introduce access_tracking_perf_test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Fix missing break in dirty_log_perf_test arg parsing (Vitaly Kuznetsov) [2009340]
- x86/kvm: fix vcpu-id indexed array sizes (Vitaly Kuznetsov) [2009340]
- KVM: x86: Check the right feature bit for MSR_KVM_ASYNC_PF_ACK access (Vitaly Kuznetsov) [2009340]
- KVM: Documentation: Fix KVM_CAP_ENFORCE_PV_FEATURE_CPUID name (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: Swap the parameter order for svm_copy_vmrun_state()/svm_copy_vmloadsave_state() (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: Rename nested_svm_vmloadsave() to svm_copy_vmloadsave_state() (Vitaly Kuznetsov) [2009340]
- docs: virt: kvm: api.rst: replace some characters (Vitaly Kuznetsov) [2009340]
- docs: kvm: properly format code blocks and lists (Vitaly Kuznetsov) [2009340]
- docs: kvm: fix build warnings (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Address extra memslot parameters in vm_vaddr_alloc (Vitaly Kuznetsov) [2009340]
- kvm: debugfs: fix memory leak in kvm_create_vm_debugfs (Vitaly Kuznetsov) [2009340]
- Revert "KVM: x86: WARN and reject loading KVM if NX is supported but not enabled" (Vitaly Kuznetsov) [2009340]
- KVM: selftests: x86: Address missing vm_install_exception_handler conversions (Vitaly Kuznetsov) [2009340]
- KVM: selftests: change pthread_yield to sched_yield (Vitaly Kuznetsov) [2009340]
- KVM: x86: rename apic_access_page_done to apic_access_memslot_enabled (Vitaly Kuznetsov) [2009340]
- kvm: x86: disable the narrow guest module parameter on unload (Vitaly Kuznetsov) [2009340]
- selftests: kvm: Allows userspace to handle emulation errors. (Vitaly Kuznetsov) [2009340]
- kvm: x86: Allow userspace to handle emulation errors (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Let guest use GBPAGES if supported in hardware and TDP is on (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Get CR4.SMEP from MMU, not vCPU, in shadow page fault (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Get CR0.WP from MMU, not vCPU, in shadow page fault (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Drop redundant rsvd bits reset for nested NPT (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Optimize and clean up so called "last nonleaf level" logic (Vitaly Kuznetsov) [2009340]
- KVM: x86: Enhance comments for MMU roles and nested transition trickiness (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: WARN on any reserved SPTE value when making a valid SPTE (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Add helpers to do full reserved SPTE checks w/ generic MMU (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role to determine PTTYPE (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Collapse 32-bit PAE and 64-bit statements for helpers (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Add a helper to calculate root from role_regs (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Add helper to update paging metadata (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Don't update nested guest's paging bitmasks if CR0.PG=0 (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Consolidate reset_rsvds_bits_mask() calls (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU role_regs to get LA57, and drop vCPU LA57 helper (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Get nested MMU's root level from the MMU's role (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Drop "nx" from MMU context now that there are no readers (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role to get EFER.NX during MMU configuration (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role/role_regs to compute context's metadata (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role to detect EFER.NX in guest page walk (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's roles to compute last non-leaf level (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role to compute PKRU bitmask (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role to compute permission bitmask (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Drop vCPU param from reserved bits calculator (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role to get CR4.PSE for computing rsvd bits (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Don't grab CR4.PSE for calculating shadow reserved bits (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Always set new mmu_role immediately after checking old role (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Set CR4.PKE/LA57 in MMU role iff long mode is active (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Do not set paging-related bits in MMU role if CR0.PG=0 (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Add accessors to query mmu_role bits (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Rename "nxe" role bit to "efer_nx" for macro shenanigans (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU's role_regs, not vCPU state, to compute mmu_role (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Ignore CR0 and CR4 bits in nested EPT MMU role (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Consolidate misc updates into shadow_mmu_init_context() (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Add struct and helpers to retrieve MMU role bits from regs (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Grab shadow root level from mmu_role for shadow MMUs (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Move nested NPT reserved bit calculation into MMU proper (Vitaly Kuznetsov) [2009340]
- KVM: x86: Read and pass all CR0/CR4 role bits to shadow MMU helper (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Drop smep_andnot_wp check from "uses NX" for shadow MMUs (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: Add a comment to document why nNPT uses vmcb01, not vCPU state (Vitaly Kuznetsov) [2009340]
- KVM: x86: Fix sizes used to pass around CR0, CR4, and EFER (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Rename unsync helper and update related comments (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Drop the intermediate "transient" __kvm_sync_page() (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: comment on kvm_mmu_get_page's syncing of pages (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: WARN and zap SP when sync'ing if MMU role mismatches (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Use MMU role to check for matching guest page sizes (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Unconditionally zap unsync SPs when creating >4k SP at GFN (Vitaly Kuznetsov) [2009340]
- Revert "KVM: MMU: record maximum physical address width in kvm_mmu_extended_role" (Vitaly Kuznetsov) [2009340]
- KVM: x86: Alert userspace that KVM_SET_CPUID{,2} after KVM_RUN is broken (Vitaly Kuznetsov) [2009340]
- KVM: debugfs: Reuse binary stats descriptors (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add selftest for KVM statistics data binary interface (Vitaly Kuznetsov) [2009340]
- KVM: stats: Add documentation for binary statistics interface (Vitaly Kuznetsov) [2009340]
- KVM: stats: Support binary stats retrieval for a VCPU (Vitaly Kuznetsov) [2009340]
- KVM: stats: Support binary stats retrieval for a VM (Vitaly Kuznetsov) [2009340]
- KVM: stats: Add fd-based API to read binary stats data (Vitaly Kuznetsov) [2009340]
- KVM: stats: Separate generic stats from architecture specific ones (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Don't WARN on a NULL shadow page in TDP MMU check (Vitaly Kuznetsov) [2009340]
- KVM: sefltests: Add x86-64 test to verify MMU reacts to CPUID updates (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add hugepage support for x86-64 (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Genericize upper level page table entry struct (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add PTE helper for x86-64 in preparation for hugepages (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Rename x86's page table "address" to "pfn" (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add wrapper to allocate page table page (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Unconditionally allocate EPT tables in memslot 0 (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Unconditionally use memslot '0' for page table allocations (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Unconditionally use memslot 0 for vaddr allocations (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Use "standard" min virtual address for CPUID test alloc (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Use alloc page helper for xAPIC IPI test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Use alloc_page helper for x86-64's GDT/IDT/TSS allocations (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Lower the min virtual address for misc page allocations (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add helpers to allocate N pages of virtual memory (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Use "standard" min virtual address for Hyper-V pages (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Unconditionally use memslot 0 for x86's GDT/TSS setup (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Unconditionally use memslot 0 when loading elf binary (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Zero out the correct page in the Hyper-V features test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Remove errant asm/barrier.h include to fix arm64 build (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix uninitialized boolean variable flush (Vitaly Kuznetsov) [2009340]
- KVM: selftests: fix triple fault if ept=0 in dirty_log_test (Vitaly Kuznetsov) [2009340]
- KVM: x86: Print CPU of last attempted VM-entry when dumping VMCS/VMCB (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Dynamically compute max VMCS index for vmcs12 (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Skip #PF(RSVD) intercepts when emulating smaller maxphyaddr (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Remove redundant root_hpa checks (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Refactor is_tdp_mmu_root into is_tdp_mmu (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Remove redundant is_tdp_mmu_enabled check (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Remove redundant is_tdp_mmu_root check (Vitaly Kuznetsov) [2009340]
- KVM: x86: Stub out is_tdp_mmu_root on 32-bit hosts (Vitaly Kuznetsov) [2009340]
- KVM: x86: WARN and reject loading KVM if NX is supported but not enabled (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Refuse to load kvm_amd if NX support is not available (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Refuse to load kvm_intel if EPT and NX are disabled (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix TDP MMU page table level (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix pf_fixed count in tdp_mmu_map_handle_target_level() (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix return value in tdp_mmu_map_handle_target_level() (Vitaly Kuznetsov) [2009340]
- KVM: LAPIC: Keep stored TMCCT register value 0 after KVM_SET_LAPIC (Vitaly Kuznetsov) [2009340]
- KVM: X86: Introduce KVM_HC_MAP_GPA_RANGE hypercall (Vitaly Kuznetsov) [2009340]
- KVM: switch per-VM stats to u64 (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Grab nx_lpage_splits as an unsigned long before division (Vitaly Kuznetsov) [2009340]
- KVM: x86: Check for pending interrupts when APICv is getting disabled (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Drop redundant checks on vmcs12 in EPTP switching emulation (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: WARN if subtly-impossible VMFUNC conditions occur (Vitaly Kuznetsov) [2009340]
- KVM: x86: Drop pointless @reset_roots from kvm_init_mmu() (Vitaly Kuznetsov) [2009340]
- KVM: x86: Defer MMU sync on PCID invalidation (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Use fast PGD switch when emulating VMFUNC[EPTP_SWITCH] (Vitaly Kuznetsov) [2009340]
- KVM: x86: Use KVM_REQ_TLB_FLUSH_GUEST to handle INVPCID(ALL) emulation (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Free only guest_mode (L2) roots on INVVPID w/o EPT (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Consolidate VM-Enter/VM-Exit TLB flush and MMU sync logic (Vitaly Kuznetsov) [2009340]
- KVM: x86: Drop skip MMU sync and TLB flush params from "new PGD" helpers (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: Move TLB flushing logic (or lack thereof) to dedicated helper (Vitaly Kuznetsov) [2009340]
- KVM: x86: Uncondtionally skip MMU sync/TLB flush in MOV CR3's PGD switch (Vitaly Kuznetsov) [2009340]
- KVM: x86: Invalidate all PGDs for the current PCID on MOV CR3 w/ flush (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Don't clobber nested MMU's A/D status on EPTP switch (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Ensure 64-bit shift when checking VMFUNC bitmap (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Sync all PGDs on nested transition with shadow paging (Vitaly Kuznetsov) [2009340]
- KVM: x86: avoid loading PDPTRs after migration when possible (Vitaly Kuznetsov) [2009340]
- KVM: x86: Introduce KVM_GET_SREGS2 / KVM_SET_SREGS2 (Vitaly Kuznetsov) [2009340]
- KVM: x86: introduce kvm_register_clear_available (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: delay loading of PDPTRs to KVM_REQ_GET_NESTED_STATE_PAGES (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: refactor the CR3 reload on migration (Vitaly Kuznetsov) [2009340]
- KVM: x86: Always load PDPTRs on CR3 load for SVM w/o NPT and a PAE guest (Vitaly Kuznetsov) [2009340]
- KVM: nSVM: Drop pointless pdptrs_changed() check on nested transition (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Drop obsolete (and pointless) pdptrs_changed() check (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Introduce hyperv_features test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Move evmcs.h to x86_64/ (Vitaly Kuznetsov) [2009340]
- KVM: selftests: move Hyper-V MSR definitions to hyperv.h (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_X64_EX_PROCESSOR_MASKS_RECOMMENDED bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_X64_CLUSTER_IPI_RECOMMENDED bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_X64_REMOTE_TLB_FLUSH_RECOMMENDED bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_DEBUGGING privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_SIGNAL_EVENTS privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_POST_MESSAGES privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Check access to HVCALL_NOTIFY_LONG_SPIN_WAIT hypercall (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Prepare to check access to Hyper-V hypercalls (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_STIMER_DIRECT_MODE_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Inverse the default in hv_check_msr_access() (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_FEATURE_DEBUG_MSRS_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_FEATURE_GUEST_CRASH_MSR_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_ACCESS_REENLIGHTENMENT privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_ACCESS_FREQUENCY_MSRS privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_APIC_ACCESS_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_SYNTIMER_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_SYNIC_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_REFERENCE_TSC_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_RESET_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_VP_INDEX_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_TIME_REF_COUNT_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_VP_RUNTIME_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Honor HV_MSR_HYPERCALL_AVAILABLE privilege bit (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Prepare to check access to Hyper-V MSRs (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Cache guest CPUID leaves determining features availability (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Introduce KVM_CAP_HYPERV_ENFORCE_CPUID (Vitaly Kuznetsov) [2009340]
- asm-generic/hyperv: add HV_STATUS_ACCESS_DENIED definition (Vitaly Kuznetsov) [2009340]
- KVM: SVM: hyper-v: Direct Virtual Flush support (Vitaly Kuznetsov) [2009340]
- KVM: SVM: hyper-v: Enlightened MSR-Bitmap support (Vitaly Kuznetsov) [2009340]
- KVM: SVM: hyper-v: Remote TLB flush for SVM (Vitaly Kuznetsov) [2009340]
- KVM: SVM: Software reserved fields (Vitaly Kuznetsov) [2009340]
- KVM: x86: hyper-v: Move the remote TLB flush logic out of vmx (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: nSVM: Add a new VCPU statistic to show if VCPU is in guest mode (Vitaly Kuznetsov) [2009340]
- KVM: x86: Drop "pre_" from enter/leave_smm() helpers (Vitaly Kuznetsov) [2009340]
- KVM: x86: Drop .post_leave_smm(), i.e. the manual post-RSM MMU reset (Vitaly Kuznetsov) [2009340]
- KVM: x86: Rename SMM tracepoint to make it reflect reality (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move "entering SMM" tracepoint into kvm_smm_changed() (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move (most) SMM hflags modifications into kvm_smm_changed() (Vitaly Kuznetsov) [2009340]
- KVM: x86: Invoke kvm_smm_changed() immediately after clearing SMM flag (Vitaly Kuznetsov) [2009340]
- KVM: x86: Replace .set_hflags() with dedicated .exiting_smm() helper (Vitaly Kuznetsov) [2009340]
- KVM: x86: Emulate triple fault shutdown if RSM emulation fails (Vitaly Kuznetsov) [2009340]
- KVM: x86: Drop vendor specific functions for APICv/AVIC enablement (Vitaly Kuznetsov) [2009340]
- KVM: x86: Use common 'enable_apicv' variable for both APICv and AVIC (Vitaly Kuznetsov) [2009340]
- kvm: x86: implement KVM PM-notifier (Vitaly Kuznetsov) [2009340]
- kvm: add PM-notifier (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Introduce x2APIC register manipulation functions (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Hoist APIC functions out of individual tests (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Move APIC definitions into a separate file (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Disable vmcs02 posted interrupts if vmcs12 PID isn't mappable (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Fail on MMIO completion for nested posted interrupts (Vitaly Kuznetsov) [2009340]
- KVM: x86: Add a return code to kvm_apic_accept_events (Vitaly Kuznetsov) [2009340]
- KVM: x86: Add a return code to inject_pending_event (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Add a return code to vmx_complete_nested_posted_interrupt (Vitaly Kuznetsov) [2009340]
- KVM: x86: Remove guest mode check from kvm_check_nested_events (Vitaly Kuznetsov) [2009340]
- KVM: selftests: x86: Add vmx_nested_tsc_scaling_test (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Enable nested TSC scaling (Vitaly Kuznetsov) [2009340]
- KVM: X86: Add vendor callbacks for writing the TSC multiplier (Vitaly Kuznetsov) [2009340]
- KVM: X86: Move write_l1_tsc_offset() logic to common code and rename it (Vitaly Kuznetsov) [2009340]
- KVM: X86: Add functions that calculate the nested TSC fields (Vitaly Kuznetsov) [2009340]
- KVM: X86: Add functions for retrieving L2 TSC fields from common code (Vitaly Kuznetsov) [2009340]
- KVM: nVMX: Add a TSC multiplier field in VMCS12 (Vitaly Kuznetsov) [2009340]
- KVM: X86: Add a ratio parameter to kvm_scale_tsc() (Vitaly Kuznetsov) [2009340]
- KVM: X86: Rename kvm_compute_tsc_offset() to kvm_compute_l1_tsc_offset() (Vitaly Kuznetsov) [2009340]
- KVM: X86: Store L1's TSC scaling ratio in 'struct kvm_vcpu_arch' (Vitaly Kuznetsov) [2009340]
- math64.h: Add mul_s64_u64_shr() (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Add a field to control memslot rmap allocation (Vitaly Kuznetsov) [2009340]
- KVM: mmu: Add slots_arch_lock for memslot arch fields (Vitaly Kuznetsov) [2009340]
- KVM: mmu: Refactor memslot copy (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Factor out allocating memslot rmap (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Deduplicate rmap freeing (Vitaly Kuznetsov) [2009340]
- KVM: x86: Do not write protect huge page in initially-all-set mode (Vitaly Kuznetsov) [2009340]
- KVM: x86: Support write protecting only large pages (Vitaly Kuznetsov) [2009340]
- KVM: hyper-v: Advertise support for fast XMM hypercalls (Vitaly Kuznetsov) [2009340]
- KVM: x86: kvm_hv_flush_tlb use inputs from XMM registers (Vitaly Kuznetsov) [2009340]
- KVM: hyper-v: Collect hypercall params into struct (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move FPU register accessors into fpu.h (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Make is_nx_huge_page_enabled an inline function (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Fix kvm_check_cap() assertion (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add aarch64/debug-exceptions test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Add exception handling support for aarch64 (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Move GUEST_ASSERT_EQ to utils header (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Introduce UCALL_UNHANDLED for unhandled vector reporting (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Complete x86_64/sync_regs_test ucall (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Rename vm_handle_exception (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Fix compiling errors when initializing the static structure (Vitaly Kuznetsov) [2009340]
- selftests: kvm: Add support for customized slot0 memory size (Vitaly Kuznetsov) [2009340]
- selftests: kvm: fix overlapping addresses in memslot_perf_test (Vitaly Kuznetsov) [2009340]
- selftests: kvm: do only 1 memslot_perf_test run by default (Vitaly Kuznetsov) [2009340]
- KVM: X86: Use _BITUL() macro in UAPI headers (Vitaly Kuznetsov) [2009340]
- KVM: selftests: create alias mappings when using shared memory (Vitaly Kuznetsov) [2009340]
- KVM: selftests: add shmem backing source type (Vitaly Kuznetsov) [2009340]
- KVM: selftests: refactor vm_mem_backing_src_type flags (Vitaly Kuznetsov) [2009340]
- KVM: selftests: allow different backing source types (Vitaly Kuznetsov) [2009340]
- KVM: selftests: compute correct demand paging size (Vitaly Kuznetsov) [2009340]
- KVM: selftests: simplify setup_demand_paging error handling (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Print a message if /dev/kvm is missing (Vitaly Kuznetsov) [2009340]
- KVM: selftests: trivial comment/logging fixes (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Fix hang in hardware_disable_test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Ignore CPUID.0DH.1H in get_cpuid_test (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Fix 32-bit truncation of vm_get_max_gfn() (Vitaly Kuznetsov) [2009340]
- KVM: selftests: add a memslot-related performance benchmark (Vitaly Kuznetsov) [2009340]
- KVM: selftests: Keep track of memslots more efficiently (Vitaly Kuznetsov) [2009340]
- selftests: kvm: fix potential issue with ELF loading (Vitaly Kuznetsov) [2009340]
- selftests: kvm: make allocation of extra memory take effect (Vitaly Kuznetsov) [2009340]
- docs: virt: api.rst: fix a pointer to SGX documentation (Vitaly Kuznetsov) [2009340]
- docs: vcpu-requests.rst: fix reference for atomic ops (Vitaly Kuznetsov) [2009340]
- x86/msr: Rename MSR_K8_SYSCFG to MSR_AMD64_SYSCFG (Vitaly Kuznetsov) [2009340]
- x86/sev: Move GHCB MSR protocol and NAE definitions in a common header (Vitaly Kuznetsov) [2009340]
- x86/sev-es: Rename sev-es.{ch} to sev.{ch} (Vitaly Kuznetsov) [2009340]
- x86/sev-es: Replace open-coded hlt-loops with sev_es_terminate() (Vitaly Kuznetsov) [2009340]
- tools/kvm_stat: Fix documentation typo (Vitaly Kuznetsov) [2009340]
- KVM: x86: Hide RDTSCP and RDPID if MSR_TSC_AUX probing failed (Vitaly Kuznetsov) [2009340]
- KVM: x86: Tie Intel and AMD behavior for MSR_TSC_AUX to guest CPU model (Vitaly Kuznetsov) [2009340]
- KVM: x86: Move uret MSR slot management to common x86 (Vitaly Kuznetsov) [2009340]
- KVM: x86: Export the number of uret MSRs to vendor modules (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Disable loading of TSX_CTRL MSR the more conventional way (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Use common x86's uret MSR list as the one true list (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Use flag to indicate "active" uret MSRs instead of sorting list (Vitaly Kuznetsov) [2009340]
- KVM: VMX: Configure list of user return MSRs at module init (Vitaly Kuznetsov) [2009340]
- KVM: x86: Add support for RDPID without RDTSCP (Vitaly Kuznetsov) [2009340]
- selftests: kvm: remove reassignment of non-absolute variables (Vitaly Kuznetsov) [2009340]
- doc/kvm: Fix wrong entry for KVM_CAP_X86_MSR_FILTER (Vitaly Kuznetsov) [2009340]
- KVM: x86/mmu: Fix kdoc of __handle_changed_spte (Vitaly Kuznetsov) [2009340]
- KVM: documentation: fix sphinx warnings (Vitaly Kuznetsov) [2009340]
- KVM: x86: document behavior of measurement ioctls with len==0 (Vitaly Kuznetsov) [2009340]
- documentation/kvm: additional explanations on KVM_SET_BOOT_CPU_ID (Vitaly Kuznetsov) [2009340]
- docs: kvm: Fix a typo ("althought") (Vitaly Kuznetsov) [2009340]
- KVM: move EXIT_FASTPATH_REENTER_GUEST to common code (Vitaly Kuznetsov) [2009340]
- mm, kvm: account kvm_vcpu_mmap to kmemcg (Vitaly Kuznetsov) [2009340]
- x86/kvm: Use msi_msg shadow structs (Vitaly Kuznetsov) [2009340]
- ceph: fix up non-directory creation in SGID directories (Jeffrey Layton) [2017796]
- ceph: initialize pathlen variable in reconnect_caps_cb (Jeffrey Layton) [2017796]
- ceph: initialize i_size variable in ceph_sync_read (Jeffrey Layton) [2017796]
- ceph: fix duplicate increment of opened_inodes metric (Jeffrey Layton) [2017796]
- ceph: add a new metric to keep track of remote object copies (Jeffrey Layton) [2017796]
- libceph, ceph: move ceph_osdc_copy_from() into cephfs code (Jeffrey Layton) [2017796]
- ceph: clean-up metrics data structures to reduce code duplication (Jeffrey Layton) [2017796]
- ceph: split 'metric' debugfs file into several files (Jeffrey Layton) [2017796]
- ceph: return the real size read when it hits EOF (Jeffrey Layton) [2017796]
- ceph: properly handle statfs on multifs setups (Jeffrey Layton) [2017796]
- ceph: shut down mount on bad mdsmap or fsmap decode (Jeffrey Layton) [2017796]
- ceph: fix mdsmap decode when there are MDS's beyond max_mds (Jeffrey Layton) [2017796]
- ceph: ignore the truncate when size won't change with Fx caps issued (Jeffrey Layton) [2017796]
- ceph: don't rely on error_string to validate blocklisted session. (Jeffrey Layton) [2017796]
- ceph: just use ci->i_version for fscache aux info (Jeffrey Layton) [2017796]
- ceph: shut down access to inode when async create fails (Jeffrey Layton) [2017796]
- ceph: refactor remove_session_caps_cb (Jeffrey Layton) [2017796]
- ceph: fix auth cap handling logic in remove_session_caps_cb (Jeffrey Layton) [2017796]
- ceph: drop private list from remove_session_caps_cb (Jeffrey Layton) [2017796]
- ceph: don't use -ESTALE as special return code in try_get_cap_refs (Jeffrey Layton) [2017796]
- ceph: print inode numbers instead of pointer values (Jeffrey Layton) [2017796]
- ceph: enable async dirops by default (Jeffrey Layton) [2017796]
- libceph: drop ->monmap and err initialization (Jeffrey Layton) [2017796]
- ceph: convert to noop_direct_IO (Jeffrey Layton) [2017796]
- ceph: fix off by one bugs in unsafe_request_wait() (Jeffrey Layton) [2017796]
- ceph: fix handling of "meta" errors (Jeffrey Layton) [2017796]
- ceph: drop the mdsc_get_session/put_session dout messages (Jeffrey Layton) [2017796]
- ceph: lockdep annotations for try_nonblocking_invalidate (Jeffrey Layton) [2017796]
- ceph: don't WARN if we're forcibly removing the session caps (Jeffrey Layton) [2017796]
- ceph: don't WARN if we're force umounting (Jeffrey Layton) [2017796]
- ceph: remove the capsnaps when removing caps (Jeffrey Layton) [2017796]
- ceph: request Fw caps before updating the mtime in ceph_write_iter (Jeffrey Layton) [2017796]
- ceph: reconnect to the export targets on new mdsmaps (Jeffrey Layton) [2017796]
- ceph: print more information when we can't find snaprealm (Jeffrey Layton) [2017796]
- ceph: add ceph_change_snap_realm() helper (Jeffrey Layton) [2017796]
- ceph: remove redundant initializations from mdsc and session (Jeffrey Layton) [2017796]
- ceph: cancel delayed work instead of flushing on mdsc teardown (Jeffrey Layton) [2017796]
- ceph: add a new vxattr to return auth mds for an inode (Jeffrey Layton) [2017796]
- ceph: flush the mdlog before waiting on unsafe reqs (Jeffrey Layton) [2017796]
- ceph: flush mdlog before umounting (Jeffrey Layton) [2017796]
- ceph: make iterate_sessions a global symbol (Jeffrey Layton) [2017796]
- ceph: make ceph_create_session_msg a global symbol (Jeffrey Layton) [2017796]
- ceph: fix comment about short copies in ceph_write_end (Jeffrey Layton) [2017796]
- ceph: fix memory leak on decode error in ceph_handle_caps (Jeffrey Layton) [2017796]
- RDMA/irdma: Fix a potential memory allocation issue in 'irdma_prm_add_pble_mem()' (Kamal Heib) [1970672]
- RDMA/irdma: Don't arm the CQ more than two times if no CE for this CQ (Kamal Heib) [1970672]
- RDMA/irdma: Fix a user-after-free in add_pble_prm (Kamal Heib) [1970672]
- RDMA/irdma: Report correct WC errors (Kamal Heib) [1970672]
- RDMA/irdma: Do not hold qos mutex twice on QP resume (Kamal Heib) [1970672]
- RDMA/irdma: Set VLAN in UD work completion correctly (Kamal Heib) [1970672]
- RDMA/irdma: Process extended CQ entries correctly (Kamal Heib) [1970672]
- RDMA/irdma: Report correct WC error when there are MW bind errors (Kamal Heib) [1970672]
- RDMA/irdma: Report correct WC error when transport retry counter is exceeded (Kamal Heib) [1970672]
- RDMA/irdma: Validate number of CQ entries on create CQ (Kamal Heib) [1970672]
- RDMA/irdma: Skip CQP ring during a reset (Kamal Heib) [1970672]
- RDMA/irdma: Remove the repeated declaration (Kamal Heib) [1970672]
- RDMA/irdma: Use correct kconfig symbol for AUXILIARY_BUS (Kamal Heib) [1970672]
- RDMA/irdma: Change returned type of irdma_setup_virt_qp to void (Kamal Heib) [1970672]
- RDMA/irdma: Change the returned type of irdma_set_hw_rsrc to void (Kamal Heib) [1970672]
- RDMA/irdma: change the returned type of irdma_sc_repost_aeq_entries to void (Kamal Heib) [1970672]
- RDMA/irdma: Check vsi pointer before using it (Kamal Heib) [1970672]
- RDMA/irdma: Change the returned type to void (Kamal Heib) [1970672]
- RDMA/irdma: Make spdxcheck.py happy (Kamal Heib) [1970672]
- RDMA/irdma: Fix unused variable total_size warning (Kamal Heib) [1970672]
- RDMA/irdma: Fix potential overflow expression in irdma_prm_get_pbles (Kamal Heib) [1970672]
- RDMA/irdma: Check contents of user-space irdma_mem_reg_req object (Kamal Heib) [1970672]
- RDMA/irdma: Remove use of kmap() (Kamal Heib) [1970672]
- RDMA/irdma: Use the queried port attributes (Kamal Heib) [1970672]
- RDMA/irdma: Check return value from ib_umem_find_best_pgsz (Kamal Heib) [1970672]
- RDMA: Split the alloc_hw_stats() ops to port and device variants (Kamal Heib) [1970672]
- RDMA/irdma: Store PBL info address a pointer type (Kamal Heib) [1970672]
- RDMA/irdma: Use list_last_entry/list_first_entry (Kamal Heib) [1970672]
- RDMA/irdma: Use list_move instead of list_del/list_add (Kamal Heib) [1970672]
- RDMA/irdma: Fix return error sign from irdma_modify_qp (Kamal Heib) [1970672]
- RDMA/irdma: Fix spelling mistake "Allocal" -> "Allocate" (Kamal Heib) [1970672]
- RDMA/irdma: remove redundant initialization of variable val (Kamal Heib) [1970672]
- RDMA/irdma: remove extraneous indentation on a statement (Kamal Heib) [1970672]
- RDMA/irdma: Fix issues with u8 left shift operation (Kamal Heib) [1970672]
- RDMA/irdma: Add irdma Kconfig/Makefile and remove i40iw (Kamal Heib) [1970672]
- RDMA/irdma: Add ABI definitions (Kamal Heib) [1970672]
- RDMA/irdma: Add dynamic tracing for CM (Kamal Heib) [1970672]
- RDMA/irdma: Add miscellaneous utility definitions (Kamal Heib) [1970672]
- RDMA/irdma: Add user/kernel shared libraries (Kamal Heib) [1970672]
- RDMA/irdma: Add RoCEv2 UD OP support (Kamal Heib) [1970672]
- RDMA/irdma: Implement device supported verb APIs (Kamal Heib) [1970672]
- RDMA/irdma: Add PBLE resource manager (Kamal Heib) [1970672]
- RDMA/irdma: Add connection manager (Kamal Heib) [1970672]
- RDMA/irdma: Add QoS definitions (Kamal Heib) [1970672]
- RDMA/irdma: Add privileged UDA queue implementation (Kamal Heib) [1970672]
- RDMA/irdma: Add HMC backing store setup functions (Kamal Heib) [1970672]
- RDMA/irdma: Implement HW Admin Queue OPs (Kamal Heib) [1970672]
- RDMA/irdma: Implement device initialization definitions (Kamal Heib) [1970672]
- RDMA/irdma: Register auxiliary driver and implement private channel OPs (Kamal Heib) [1970672]
- i40e: Register auxiliary devices to provide RDMA (Kamal Heib) [1970672]
- i40e: Prep i40e header for aux bus conversion (Kamal Heib) [1970672]
- i40e: Replace one-element array with flexible-array member (Kamal Heib) [1970672]
- ibmvnic: drop bad optimization in reuse_tx_pools() (Gustavo Walbon) [2028722]
- ibmvnic: drop bad optimization in reuse_rx_pools() (Gustavo Walbon) [2028722]
- /proc/<pid>/cmdline: add back the setproctitle() special case (Ian Kent) [1979446]
- /proc/<pid>/cmdline: remove all the special cases (Ian Kent) [1979446]
- perf tests vmlinux-kallsyms: Ignore hidden symbols (Michael Petlan) [1903157]
- net/sched: sch_ets: don't remove idle classes from the round-robin list (Davide Caratti) [2013073]
- net/sched: sch_ets: don't peek at classes beyond 'nbands' (Davide Caratti) [2013073]
- net/sched: sch_ets: properly init all active DRR list handles (Davide Caratti) [2013073]
- serial: 8250: fix racy uartclk update (Puneet Sethi) [1784121]
- serial: 8250: Skip uninitialized TTY port baud rate update (Puneet Sethi) [1784121]
- serial: 8250: Discard RTS/DTS setting from clock update method (Puneet Sethi) [1784121]
- serial: 8250: Add 8250 port clock update method (Puneet Sethi) [1784121]
- serial: 8250_dw: drop bogus uartclk optimisation (Puneet Sethi) [1784121]
- serial: 8250_lpss: Enable PSE UART Auto Flow Control (Puneet Sethi) [1784121]
- serial: 8250_lpss: Extract dw8250_do_set_termios() for common use (Puneet Sethi) [1784121]
- serial: 8250_dw: Fix the trivial typo in the comment (Puneet Sethi) [1784121]
- serial: 8250_dw: Re-use temporary variable for of_node (Puneet Sethi) [1784121]
- serial: 8250_dw: Drop wrong use of ACPI_PTR() (Puneet Sethi) [1784121]
- serial: 8250_lpss: Enable DMA on Intel Elkhart Lake (Puneet Sethi) [1784121]
- serial: 8250_dw: Add device HID for new AMD UART controller (Puneet Sethi) [1784121]
- serial: 8250_dw: Fix clk-notifier/port suspend deadlock (Puneet Sethi) [1784121]
- serial: 8250_dw: Fix common clocks usage race condition (Puneet Sethi) [1784121]
- serial: 8250_dw: Pass the same rate to the clk round and set rate methods (Puneet Sethi) [1784121]
- serial: 8250_dw: Simplify the ref clock rate setting procedure (Puneet Sethi) [1784121]
- serial: 8250_dw: Use devm_clk_get_optional() to get the input clock (Puneet Sethi) [1784121]
- serial: 8250_dw: Avoid double error messaging when IRQ absent (Puneet Sethi) [1784121]
- serial: 8250_dw: switch to use 8250_dwlib library (Puneet Sethi) [1784121]
- serial: 8250_dw: use pointer to uart local variable (Puneet Sethi) [1784121]
- serial: 8250_dw: Use a unified new dev variable in remove (Puneet Sethi) [1784121]
- serial: 8250_dw: always set baud rate in dw8250_set_termios (Puneet Sethi) [1784121]
- serial: 8250_dw: add fractional divisor support (Puneet Sethi) [1784121]
- serial: 8250_dw: Introduce IO accessors to extended registers (Puneet Sethi) [1784121]
- dmaengine: dw: Program xBAR hardware for Elkhart Lake (Puneet Sethi) [1784121]
- dmaengine: dw: Make it dependent to HAS_IOMEM (Puneet Sethi) [1784121]
- dmaengine dw: Revert "dmaengine: dw: Enable runtime PM" (Puneet Sethi) [1784121]
- dmaengine: dw: Enable runtime PM (Puneet Sethi) [1784121]
- dmaengine: dw: Add DMA-channels mask cell support (Puneet Sethi) [1784121]
- dmaengine: dw: Ignore burst setting for memory peripherals (Puneet Sethi) [1784121]
- dmaengine: dw: Discard dlen from the dev-to-mem xfer width calculation (Puneet Sethi) [1784121]
- dmaengine: dw: Activate FIFO-mode for memory peripherals only (Puneet Sethi) [1784121]
- dmaengine: dw: Initialize max_sg_burst capability (Puneet Sethi) [1784121]
- dmaengine: dw: Introduce max burst length hw config (Puneet Sethi) [1784121]
- dmaengine: dw: Initialize min and max burst DMA device capability (Puneet Sethi) [1784121]
- dmaengine: dw: Set DMA device max segment size parameter (Puneet Sethi) [1784121]
- dmaengine: dw: Take HC_LLP flag into account for noLLP auto-config (Puneet Sethi) [1784121]
- dmaengine: Introduce DMA-device device_caps callback (Puneet Sethi) [1784121]
- dmaengine: Introduce max SG burst capability (Puneet Sethi) [1784121]
- dmaengine: Introduce min burst length capability (Puneet Sethi) [1784121]
- dmaengine: dw: Initialize channel before each transfer (Puneet Sethi) [1784121]
- dmaengine: dw: Replace 'objs' by 'y' (Puneet Sethi) [1784121]
- dmaengine: dw: Register ACPI DMA controller for PCI that has companion (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Mark 'hclk' clock optional (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Split OF helpers to separate module (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Split ACPI helpers to separate module (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Move handle check to dw_dma_acpi_controller_register() (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Switch to acpi_dma_controller_register() (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Use devm_platform_ioremap_resource() (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Enable iDMA 32-bit on Intel Elkhart Lake (Puneet Sethi) [1784121]
- dmaengine: dw: platform: Use struct dw_dma_chip_pdata (Puneet Sethi) [1784121]
- dmaengine: dw: Export struct dw_dma_chip_pdata for wider use (Puneet Sethi) [1784121]
- dmaengine: dw: Update Intel Elkhart Lake Service Engine acronym (Puneet Sethi) [1784121]
- dmaengine: dw: Enable iDMA 32-bit on Intel Elkhart Lake (Puneet Sethi) [1784121]
- dmaengine: dw: Distinguish ->remove() between DW and iDMA 32-bit (Puneet Sethi) [1784121]
- dmaengine: dw: convert to SPDX identifiers (Puneet Sethi) [1784121]
- dmaengine: dw: Don't pollute CTL_LO on iDMA 32-bit (Puneet Sethi) [1784121]
- dmaengine: dw: Reset DRAIN bit when resume the channel (Puneet Sethi) [1784121]
- dmaengine: dw: Split DW and iDMA 32-bit operations (Puneet Sethi) [1784121]
- dmaengine: dw: Remove unused internal property (Puneet Sethi) [1784121]
- dmaengine: dw: Add missed multi-block support for iDMA 32-bit (Puneet Sethi) [1784121]
- dmaengine: dw: drop useless LIST_HEAD (Puneet Sethi) [1784121]
- dmaengine: dw: Fix FIFO size for Intel Merrifield (Puneet Sethi) [1784121]
- dmaengine: dw-dmac: implement dma protection control setting (Puneet Sethi) [1784121]
- dmaengine: dw: remove dma_slave_config direction usage (Puneet Sethi) [1784121]
- dmaengine: dw: Add alternative ACPI HIDs for Cherry Trail DMA controllers (Puneet Sethi) [1784121]
- perf/arm-cmn: Fix invalid pointer when access dtc object sharing the same IRQ number (Mark Langsdorf) [1997732]
- drivers/perf: Simplify EVENT ATTR macro in SMMU PMU driver (Mark Langsdorf) [1997732]
- perf/smmuv3: Don't trample existing events with global filter (Mark Langsdorf) [1997732]
- perf: qcom: Remove redundant dev_err call in qcom_l3_cache_pmu_probe() (Mark Langsdorf) [1997732]
- perf: arm_spe: use DEVICE_ATTR_RO macro (Mark Langsdorf) [1997732]
- perf: xgene_pmu: use DEVICE_ATTR_RO macro (Mark Langsdorf) [1997732]
- perf: qcom: use DEVICE_ATTR_RO macro (Mark Langsdorf) [1997732]
- perf: arm_pmu: use DEVICE_ATTR_RO macro (Mark Langsdorf) [1997732]
- drivers/perf: arm-cci: Fix checkpatch spacing error (Mark Langsdorf) [1997732]
- drivers/perf: arm-cmn: Add space after ',' (Mark Langsdorf) [1997732]
- drivers/perf: arm_pmu: Fix some coding style issues (Mark Langsdorf) [1997732]
- drivers/perf: arm_spe_pmu: Fix some coding style issues (Mark Langsdorf) [1997732]
- drivers/perf: Remove redundant dev_err call in tx2_uncore_pmu_init_dev() (Mark Langsdorf) [1997732]
- perf/arm-smmuv3: Use irq_set_affinity() (Mark Langsdorf) [1997732]
- perf/arm-dsu: Use irq_set_affinity() (Mark Langsdorf) [1997732]
- perf/arm-dmc620: Use irq_set_affinity() (Mark Langsdorf) [1997732]
- perf/arm-cmn: Use irq_set_affinity() (Mark Langsdorf) [1997732]
- perf/arm-ccn: Use irq_set_affinity() (Mark Langsdorf) [1997732]
- perf/arm-ccn: Clean up CPU hotplug handling (Mark Langsdorf) [1997732]
- perf/arm-cci: Remove broken race mitigation (Mark Langsdorf) [1997732]
- genirq: Export affinity setter for modules (Mark Langsdorf) [1997732]
- perf/arm_pmu_platform: Clean up with dev_printk (Mark Langsdorf) [1997732]
- perf/arm_pmu_platform: Fix error handling (Mark Langsdorf) [1997732]
- perf/arm_pmu_platform: Use dev_err_probe() for IRQ errors (Mark Langsdorf) [1997732]
- drivers/perf: Simplify the SMMUv3 PMU event attributes (Mark Langsdorf) [1997732]
- perf: Constify static struct attribute_group (Mark Langsdorf) [1997732]
- perf: qcom: Constify static struct attribute_group (Mark Langsdorf) [1997732]
- drivers/perf: Add support for ARMv8.3-SPE (Mark Langsdorf) [1997732]
- driver/perf: Remove ARM_SMMU_V3_PMU dependency on ARM_SMMU_V3 (Mark Langsdorf) [1997732]
- perf/smmuv3: Support sysfs identifier file (Mark Langsdorf) [1997732]
- perf: remove duplicate check on fwnode (Mark Langsdorf) [1997732]
- redhat/configs: enable ARM_DMC620_PMU memory controller perf counters (Mark Langsdorf) [1997732]
- perf/arm_dmc620_pmu: Fix error return code in dmc620_pmu_device_probe() (Mark Langsdorf) [1997732]
- drivers/perf: Prevent forced unbinding of ARM_DMC620_PMU drivers (Mark Langsdorf) [1997732]
- driver/perf: Add PMU driver for the ARM DMC-620 memory controller (Mark Langsdorf) [1997732]
- drivers/perf: thunderx2_pmu: Fix memory resource error handling (Mark Langsdorf) [1997732]
- drivers/perf: xgene_pmu: Fix uninitialized resource struct (Mark Langsdorf) [1997732]
- perf: arm_dsu: Support DSU ACPI devices (Mark Langsdorf) [1997732]
- perf/smmuv3: To simplify code for ioremap page in pmcg (Mark Langsdorf) [1997732]
- drivers/perf: Prevent forced unbinding of PMU drivers (Mark Langsdorf) [1997732]
- drivers/perf: Fix kernel panic when rmmod PMU modules during perf sampling (Mark Langsdorf) [1997732]
- pmu/smmuv3: Clear IRQ affinity hint on device removal (Mark Langsdorf) [1997732]
- drivers/perf: arm_spe_pmu: Avoid duplicate printouts (Mark Langsdorf) [1997732]
- drivers/perf: arm_dsu_pmu: Avoid duplicate printouts (Mark Langsdorf) [1997732]
- drivers/perf: Open access for CAP_PERFMON privileged process (Mark Langsdorf) [1997732]
- perf/smmuv3: Remove the leftover put_cpu() in error path (Mark Langsdorf) [1997732]
- perf: arm-ccn: Enable stats for CCN-512 interconnect (Mark Langsdorf) [1997732]
- perf/smmuv3: use devm_platform_ioremap_resource() to simplify code (Mark Langsdorf) [1997732]
- perf/arm-cci: use devm_platform_ioremap_resource() to simplify code (Mark Langsdorf) [1997732]
- perf/arm-ccn: use devm_platform_ioremap_resource() to simplify code (Mark Langsdorf) [1997732]
- perf: xgene: use devm_platform_ioremap_resource() to simplify code (Mark Langsdorf) [1997732]
- perf/smmuv3: Validate groups for global filtering (Mark Langsdorf) [1997732]
- perf/smmuv3: Validate group size (Mark Langsdorf) [1997732]
- perf/smmuv3: Enable HiSilicon Erratum 162001800 quirk (Mark Langsdorf) [1997732]
- perf/smmuv3: Add MSI irq support (Mark Langsdorf) [1997732]
- perf/smmuv3: Add arm64 smmuv3 pmu driver (Mark Langsdorf) [1997732]
- perf: xgene: Remove set but not used variable 'config' (Mark Langsdorf) [1997732]
- perf/drivers: Strengthen exclusion checks with PERF_PMU_CAP_NO_EXCLUDE (Mark Langsdorf) [1997732]
- For drivers that do not support context exclusion let's advertise the PERF_PMU_CAP_NO_EXCLUDE capability. This ensures that perf will prevent us from handling events where any exclusion flags are set. Let's also remove the now unnecessary check for exclusion flags. (Mark Langsdorf) [1997732]
- perf/core, arch/arm: Use PERF_PMU_CAP_NO_EXCLUDE conditionally (Mark Langsdorf) [1997732]
- drivers/perf: arm-ccn: Use devm_ioremap_resource() to map memory (Mark Langsdorf) [1997732]
- drivers/perf: Initialise return value in armpmu_request_irqs() (Mark Langsdorf) [1997732]
- perf/arm-cci: Remove VLA usage (Mark Langsdorf) [1997732]
- tools/power turbostat: version 2021.05.04 (Prarit Bhargava) [2030472]
- tools/power turbostat: Support "turbostat --hide idle" (Prarit Bhargava) [2030472]
- tools/power turbostat: elevate priority of interval mode (Prarit Bhargava) [2030472]
- tools/power turbostat: formatting (Prarit Bhargava) [2030472]
- tools/power turbostat: rename tcc variables (Prarit Bhargava) [2030472]
- tools/power turbostat: save original CPU model (Prarit Bhargava) [2030472]
- tools/power turbostat: add TCC Offset support (Prarit Bhargava) [2030472]
- tools/power turbostat: Fix Core C6 residency on Atom CPUs (Prarit Bhargava) [2030472]
- tools/power turbostat: Print the C-state Pre-wake settings (Prarit Bhargava) [2030472]
- tools/power turbostat: unmark non-kernel-doc comment (Prarit Bhargava) [2030472]
- tools/power/turbostat: Remove Package C6 Retention on Ice Lake Server (Prarit Bhargava) [2030472]
- tools/power turbostat: Fix offset overflow issue in index converting (Prarit Bhargava) [2030472]
- tools/power/turbostat: Fix turbostat for AMD Zen CPUs (Prarit Bhargava) [2030472]
- Revert "tools/power turbostat: adjust for temperature offset" (Prarit Bhargava) [2030472]
- tools/power turbostat: Fix DRAM Energy Unit on SKX (Prarit Bhargava) [2030472]
- tools/power turbostat: print microcode patch level (Prarit Bhargava) [2030472]
- tools/power turbostat: add built-in-counter for IPC -- Instructions per Cycle (Prarit Bhargava) [2030472]

* Wed Dec 15 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-356.el8]
- [s390] virtio: write back F_VERSION_1 before validate (Claudio Imbrenda) [2026234]
- cpufreq: powernv: Fix init_chip_info initialization in numa=off (Steve Best) [2017665]
- tcp: don't free a FIN sk_buff in tcp_remove_empty_skb() (Guillaume Nault) [2016210]
- tipc: fix size validations for the MSG_CRYPTO type (Xin Long) [2020507] {CVE-2021-43267}
- tipc: increase timeout in tipc_sk_enqueue() (Xin Long) [2020401]
- Revert "tipc: Return the correct errno code" (Xin Long) [2020401]
- tipc: fix an use-after-free issue in tipc_recvmsg (Xin Long) [2020401]
- tipc: keep the skb in rcv queue until the whole data is read (Xin Long) [2020401]
- powerpc/perf: Fix cycles/instructions as PM_CYC/PM_INST_CMPL in power10 (Steve Best) [2025400]
- PCI: Increase D3 delay for AMD Renoir/Cezanne XHCI (Myron Stowe) [2028298]
- media: uvcvideo: Avoid cyclic entity chains due to malformed USB descriptors (Dean Nelson) [1921871] {CVE-2020-0404}
- sctp: fix transport encap_port update in sctp_vtag_verify (Xin Long) [2020393]
- sctp: account stream padding length for reconf chunk (Xin Long) [2020393]
- sctp: break out if skb_header_pointer returns NULL in sctp_rcv_ootb (Xin Long) [2020393]
- net: cipso: fix warnings in netlbl_cipsov4_add_std (Balazs Nemeth) [2026691]
- net/sched: act_ct: fix err check for nf_conntrack_confirm (Davide Caratti) [2018109]
- net/sched: act_ct: Fix byte count on fragmented packets (Davide Caratti) [2018109]
- mqprio: Correct stats in mqprio_dump_class_stats(). (Davide Caratti) [2018109]
- net_sched: fix NULL deref in fifo_set_limit() (Davide Caratti) [2018109]
- net: sched: flower: protect fl_walk() with rcu (Davide Caratti) [2018109]
- fq_codel: reject silly quantum parameters (Davide Caratti) [2018109]
- net: sched: Fix qdisc_rate_table refcount leak when get tcf_block failed (Davide Caratti) [2018109]
- sch_htb: Fix inconsistency when leaf qdisc creation fails (Davide Caratti) [2018109]
- net: sched: fix lockdep_set_class() typo error for sch->seqlock (Davide Caratti) [2018109]
- net: sched: cls_api: Fix the the wrong parameter (Davide Caratti) [2018109]
- net/sched: act_vlan: Fix modify to allow 0 (Davide Caratti) [2018109]
- net-sysfs: initialize uid and gid before calling net_ns_get_ownership (Xin Long) [1979820]
- net: fix sysfs permssions when device changes network namespace (Xin Long) [1979820]
- net-sysfs: add queue_change_owner() (Xin Long) [1979820]
- net-sysfs: add netdev_change_owner() (Xin Long) [1979820]
- drivers/base/power: add dpm_sysfs_change_owner() (Xin Long) [1979820]
- device: add device_change_owner() (Xin Long) [1979820]
- sysfs: Fix regression when adding a file to an existing group (Xin Long) [1979820]
- bridge: make sure objects belong to container's owner (Xin Long) [1979820]
- net: create reusable function for getting ownership info of sysfs inodes (Xin Long) [1979820]
- net-sysfs: make sure objects belong to container's owner (Xin Long) [1979820]
- net-sysfs: require net admin in the init ns for setting tx_maxrate (Xin Long) [1979820]
- driver core: set up ownership of class devices in sysfs (Xin Long) [1979820]
- kobject: kset_create_and_add() - fetch ownership info from parent (Xin Long) [1979820]
- sysfs, kobject: allow creating kobject belonging to arbitrary users (Xin Long) [1979820]
- NFSv42: Fix pagecache invalidation after COPY/CLONE (Benjamin Coddington) [2017166]
- SUNRPC: fix sign error causing rpcsec_gss drops (Benjamin Coddington) [2017166]
- nfsd4: Handle the NFSv4 READDIR 'dircount' hint being zero (Benjamin Coddington) [2017166]
- nfsd: fix error handling of register_pernet_subsys() in init_nfsd() (Benjamin Coddington) [2017166]
- SUNRPC: Simplify socket shutdown when not reusing TCP ports (Benjamin Coddington) [2017166]
- nfsd4: Fix forced-expiry locking (Benjamin Coddington) [2017166]
- SUNRPC/xprtrdma: Fix reconnection locking (Benjamin Coddington) [2017166]
- NFSv4/pnfs: The layout barrier indicate a minimal value for the seqid (Benjamin Coddington) [2017166]
- NFSv4/pNFS: Always allow update of a zero valued layout barrier (Benjamin Coddington) [2017166]
- NFSv4/pNFS: Fix a layoutget livelock loop (Benjamin Coddington) [2017166]
- xprtrdma: Put rpcrdma_reps before waking the tear-down completion (Benjamin Coddington) [2017166]
- NFSD: Fix TP_printk() format specifier in nfsd_clid_class (Benjamin Coddington) [2017166]
- NFSv42: Copy offload should update the file size when appropriate (Benjamin Coddington) [2017166]
- SUNRPC: Fix XPT_BUSY flag leakage in svc_handle_xprt()... (Benjamin Coddington) [2017166]
- NFSv4/pNFS: Return an error if _nfs4_pnfs_v3_ds_connect can't load NFSv3 (Benjamin Coddington) [2017166]
- NFSv4/pNFS: Don't call _nfs4_pnfs_v3_ds_connect multiple times (Benjamin Coddington) [2017166]
- NFSv4/pnfs: Clean up layout get on open (Benjamin Coddington) [2017166]
- NFSv4/pnfs: Fix layoutget behaviour after invalidation (Benjamin Coddington) [2017166]
- NFSv4/pnfs: Fix the layout barrier update (Benjamin Coddington) [2017166]
- NFSD: Prevent a possible oops in the nfs_dirent() tracepoint (Benjamin Coddington) [2017166]
- nfsd: remove redundant assignment to pointer 'this' (Benjamin Coddington) [2017166]
- nfs_common: fix doc warning (Benjamin Coddington) [2017166]
- nfsd4: Expose the callback address and state of each NFS4 client (Benjamin Coddington) [2017166]
- xprtrdma: Fix spelling mistakes (Benjamin Coddington) [2017166]
- NFS: nfs_find_open_context() may only select open files (Benjamin Coddington) [2017166]
- SUNRPC: Should wake up the privileged task firstly. (Benjamin Coddington) [2017166]
- SUNRPC: Fix the batch tasks count wraparound. (Benjamin Coddington) [2017166]
- nfs: update has_sec_mnt_opts after cloning lsm options from parent (Benjamin Coddington) [2017166]
- nfs: fix acl memory leak of posix_acl_create() (Benjamin Coddington) [2017166]
- rpc: remove redundant initialization of variable status (Benjamin Coddington) [2017166]
- NFSv4: Initialise connection to the server in nfs4_alloc_client() (Benjamin Coddington) [2017166]
- nfsd: Prevent truncation of an unlinked inode from blocking access to its directory (Benjamin Coddington) [2017166]
- xprtrdma: Fix a maybe-uninitialized compiler warning (Benjamin Coddington) [2017166]
- NFSv4: Fix second deadlock in nfs4_evict_inode() (Benjamin Coddington) [2017166]
- NFSv4: Fix deadlock between nfs4_evict_inode() and nfs4_opendata_get_inode() (Benjamin Coddington) [2017166]
- NFS: FMODE_READ and friends are C macros, not enum types (Benjamin Coddington) [2017166]
- NFS: Fix a potential NULL dereference in nfs_get_client() (Benjamin Coddington) [2017166]
- NFS: Fix use-after-free in nfs4_init_client() (Benjamin Coddington) [2017166]
- NFSv4: nfs4_proc_set_acl needs to restore NFS_CAP_UIDGID_NOMAP on error. (Benjamin Coddington) [2017166]
- nfs: Remove trailing semicolon in macros (Benjamin Coddington) [2017166]
- NFSv4: Fix v4.0/v4.1 SEEK_DATA return -ENOTSUPP when set NFS_V4_2 config (Benjamin Coddington) [2017166]
- NFS: Clean up reset of the mirror accounting variables (Benjamin Coddington) [2017166]
- NFS: Don't corrupt the value of pg_bytes_written in nfs_do_recoalesce() (Benjamin Coddington) [2017166]
- NFS: Fix an Oopsable condition in __nfs_pageio_add_request() (Benjamin Coddington) [2017166]
- SUNRPC: More fixes for backlog congestion (Benjamin Coddington) [2017166]
- SUNRPC: Fix Oops in xs_tcp_send_request() when transport is disconnected (Benjamin Coddington) [2017166]
- NFSv4: Fix a NULL pointer dereference in pnfs_mark_matching_lsegs_return() (Benjamin Coddington) [2017166]
- SUNRPC in case of backlog, hand free slots directly to waiting task (Benjamin Coddington) [2017166]
- pNFS/NFSv4: Remove redundant initialization of 'rd_size' (Benjamin Coddington) [2017166]
- NFS: fix an incorrect limit in filelayout_decode_layout() (Benjamin Coddington) [2017166]
- fs/nfs: Use fatal_signal_pending instead of signal_pending (Benjamin Coddington) [2017166]
- xprtrdma: Fix a NULL dereference in frwr_unmap_sync() (Benjamin Coddington) [2017166]
- sunrpc: Fix misplaced barrier in call_decode (Benjamin Coddington) [2017166]
- SUNRPC: set rq_page_end differently (Benjamin Coddington) [2017166]
- xprtrdma: Move fr_mr field to struct rpcrdma_mr (Benjamin Coddington) [2017166]
- xprtrdma: Move the Work Request union to struct rpcrdma_mr (Benjamin Coddington) [2017166]
- xprtrdma: Move fr_linv_done field to struct rpcrdma_mr (Benjamin Coddington) [2017166]
- xprtrdma: Move cqe to struct rpcrdma_mr (Benjamin Coddington) [2017166]
- xprtrdma: Move fr_cid to struct rpcrdma_mr (Benjamin Coddington) [2017166]
- xprtrdma: Remove the RPC/RDMA QP event handler (Benjamin Coddington) [2017166]
- xprtrdma: Add tracepoints showing FastReg WRs and remote invalidation (Benjamin Coddington) [2017166]
- xprtrdma: Avoid Send Queue wrapping (Benjamin Coddington) [2017166]
- xprtrdma: Do not wake RPC consumer on a failed LocalInv (Benjamin Coddington) [2017166]
- xprtrdma: Do not recycle MR after FastReg/LocalInv flushes (Benjamin Coddington) [2017166]
- xprtrdma: Clarify use of barrier in frwr_wc_localinv_done() (Benjamin Coddington) [2017166]
- xprtrdma: Rename frwr_release_mr() (Benjamin Coddington) [2017166]
- xprtrdma: rpcrdma_mr_pop() already does list_del_init() (Benjamin Coddington) [2017166]
- xprtrdma: Delete rpcrdma_recv_buffer_put() (Benjamin Coddington) [2017166]
- xprtrdma: Fix cwnd update ordering (Benjamin Coddington) [2017166]
- xprtrdma: Improve locking around rpcrdma_rep creation (Benjamin Coddington) [2017166]
- xprtrdma: Improve commentary around rpcrdma_reps_unmap() (Benjamin Coddington) [2017166]
- xprtrdma: Improve locking around rpcrdma_rep destruction (Benjamin Coddington) [2017166]
- xprtrdma: Put flushed Receives on free list instead of destroying them (Benjamin Coddington) [2017166]
- xprtrdma: Do not refresh Receive Queue while it is draining (Benjamin Coddington) [2017166]
- xprtrdma: Avoid Receive Queue wrapping (Benjamin Coddington) [2017166]
- SUNRPC: fix ternary sign expansion bug in tracing (Benjamin Coddington) [2017166]
- nfsd: Fix fall-through warnings for Clang (Benjamin Coddington) [2017166]
- nfsd: reshuffle some code (Benjamin Coddington) [2017166]
- nfsd: track filehandle aliasing in nfs4_files (Benjamin Coddington) [2017166]
- nfsd: hash nfs4_files by inode number (Benjamin Coddington) [2017166]
- NFSv4.1: Simplify layout return in pnfs_layout_process() (Benjamin Coddington) [2017166]
- NFSv4: Don't discard segments marked for return in _pnfs_return_layout() (Benjamin Coddington) [2017166]
- nfsd: ensure new clients break delegations (Benjamin Coddington) [2017166]
- NFS: Don't discard pNFS layout segments that are marked for return (Benjamin Coddington) [2017166]
- NFSv4.x: Don't return NFS4ERR_NOMATCHING_LAYOUT if we're unmounting (Benjamin Coddington) [2017166]
- nfsd: remove unused function (Benjamin Coddington) [2017166]
- svcrdma: Pass a useful error code to the send_err tracepoint (Benjamin Coddington) [2017166]
- svcrdma: Rename goto labels in svc_rdma_sendto() (Benjamin Coddington) [2017166]
- svcrdma: Don't leak send_ctxt on Send errors (Benjamin Coddington) [2017166]
- SUNRPC: Remove trace_xprt_transmit_queued (Benjamin Coddington) [2017166]
- SUNRPC: Add tracepoint that fires when an RPC is retransmitted (Benjamin Coddington) [2017166]
- SUNRPC: Move fault injection call sites (Benjamin Coddington) [2017166]
- pNFS/flexfiles: fix incorrect size check in decode_nfs_fh() (Benjamin Coddington) [2017166]
- NFSv4: Catch and trace server filehandle encoding errors (Benjamin Coddington) [2017166]
- NFSv4: Convert nfs_xdr_status tracepoint to an event class (Benjamin Coddington) [2017166]
- NFSv4: Add tracing for COMPOUND errors (Benjamin Coddington) [2017166]
- NFSv4: Don't modify the change attribute cached in the inode (Benjamin Coddington) [2017166]
- NFSv4: Fix value of decode_fsinfo_maxsz (Benjamin Coddington) [2017166]
- NFS: Fix up revalidation of space used (Benjamin Coddington) [2017166]
- NFS: NFS_INO_REVAL_PAGECACHE should mark the change attribute invalid (Benjamin Coddington) [2017166]
- NFS: Mask out unsupported attributes in nfs_getattr() (Benjamin Coddington) [2017166]
- NFS: Fix up inode cache tracing (Benjamin Coddington) [2017166]
- NFS: Deal correctly with attribute generation counter overflow (Benjamin Coddington) [2017166]
- NFSv4.2: Always flush out writes in nfs42_proc_fallocate() (Benjamin Coddington) [2017166]
- NFS: Fix attribute bitmask in _nfs42_proc_fallocate() (Benjamin Coddington) [2017166]
- NFS: nfs4_bitmask_adjust() must not change the server global bitmasks (Benjamin Coddington) [2017166]
- NFSD: Use DEFINE_SPINLOCK() for spinlock (Benjamin Coddington) [2017166]
- sunrpc: Remove unused function ip_map_lookup (Benjamin Coddington) [2017166]
- NFS: Fix fscache invalidation in nfs_set_cache_invalid() (Benjamin Coddington) [2017166]
- SUNRPC: Ensure the transport backchannel association (Benjamin Coddington) [2017166]
- nfs: hornor timeo and retrans option when mounting NFSv3 (Benjamin Coddington) [2017166]
- sunrpc: honor rpc_task's timeout value in rpcb_create() (Benjamin Coddington) [2017166]
- nfs: Fix a typo in the file nfs42xattr.c (Benjamin Coddington) [2017166]
- NFS: fs_context: validate UDP retrans to prevent shift out-of-bounds (Benjamin Coddington) [2017166]
- NFS: Fix up incorrect documentation (Benjamin Coddington) [2017166]
- NFSv4: Simplify nfs4_retry_setlk() (Benjamin Coddington) [2017166]
- UAPI: nfsfh.h: Replace one-element array with flexible-array member (Benjamin Coddington) [2017166]
- svcrdma: Clean up dto_q critical section in svc_rdma_recvfrom() (Benjamin Coddington) [2017166]
- svcrdma: Remove svc_rdma_recv_ctxt::rc_pages and ::rc_arg (Benjamin Coddington) [2017166]
- svcrdma: Remove sc_read_complete_q (Benjamin Coddington) [2017166]
- svcrdma: Single-stage RDMA Read (Benjamin Coddington) [2017166]
- SUNRPC: Move svc_xprt_received() call sites (Benjamin Coddington) [2017166]
- SUNRPC: Export svc_xprt_received() (Benjamin Coddington) [2017166]
- svcrdma: Retain the page backing rq_res.head[0].iov_base (Benjamin Coddington) [2017166]
- svcrdma: Remove unused sc_pages field (Benjamin Coddington) [2017166]
- svcrdma: Normalize Send page handling (Benjamin Coddington) [2017166]
- svcrdma: Add a "deferred close" helper (Benjamin Coddington) [2017166]
- svcrdma: Maintain a Receive water mark (Benjamin Coddington) [2017166]
- svcrdma: Use svc_rdma_refresh_recvs() in wc_receive (Benjamin Coddington) [2017166]
- svcrdma: Add a batch Receive posting mechanism (Benjamin Coddington) [2017166]
- svcrdma: Remove stale comment for svc_rdma_wc_receive() (Benjamin Coddington) [2017166]
- svcrdma: Provide an explanatory comment in CMA event handler (Benjamin Coddington) [2017166]
- svcrdma: RPCDBG_FACILITY is no longer used (Benjamin Coddington) [2017166]
- nfsd: don't ignore high bits of copy count (Benjamin Coddington) [2017166]
- nfsd: COPY with length 0 should copy to end of file (Benjamin Coddington) [2017166]
- nfsd: Fix typo "accesible" (Benjamin Coddington) [2017166]
- nfsd: Ensure knfsd shuts down when the "nfsd" pseudofs is unmounted (Benjamin Coddington) [2017166]
- nfsd: Log client tracking type log message as info instead of warning (Benjamin Coddington) [2017166]
- nfsd: helper for laundromat expiry calculations (Benjamin Coddington) [2017166]
- NFSD: Clean up NFSDDBG_FACILITY macro (Benjamin Coddington) [2017166]
- NFSD: Add a tracepoint to record directory entry encoding (Benjamin Coddington) [2017166]
- rpc: fix NULL dereference on kmalloc failure (Benjamin Coddington) [2017166]
- sunrpc: fix refcount leak for rpc auth modules (Benjamin Coddington) [2017166]
- NFSD: Repair misuse of sv_lock in 5.10.16-rt30. (Benjamin Coddington) [2017166]
- svcrdma: disable timeouts on rdma backchannel (Benjamin Coddington) [2017166]
- svcrdma: Hold private mutex while invoking rdma_accept() (Benjamin Coddington) [2017166]
- NFS: Don't set NFS_INO_INVALID_XATTR if there is no xattr cache (Benjamin Coddington) [2017166]
- NFS: Always clear an invalid mapping when attempting a buffered write (Benjamin Coddington) [2017166]
- NFS: Optimise sparse writes past the end of file (Benjamin Coddington) [2017166]
- NFS: Fix documenting comment for nfs_revalidate_file_size() (Benjamin Coddington) [2017166]
- rpcrdma: Fix comments about reverse-direction operation (Benjamin Coddington) [2017166]
- xprtrdma: Refactor invocations of offset_in_page() (Benjamin Coddington) [2017166]
- xprtrdma: Simplify rpcrdma_convert_kvec() and frwr_map() (Benjamin Coddington) [2017166]
- xprtrdma: Remove FMR support in rpcrdma_convert_iovs() (Benjamin Coddington) [2017166]
- NFS: Fix fscache read from NFS after cache error (Benjamin Coddington) [2017166]
- NFS: Ensure nfs_readpage returns promptly when internal error occurs (Benjamin Coddington) [2017166]
- NFS: Remove unnecessary inode parameter from nfs_pageio_complete_read() (Benjamin Coddington) [2017166]
- NFS: Add nfs_pageio_complete_read() and remove nfs_readpage_async() (Benjamin Coddington) [2017166]
- NFS: Call readpage_async_filler() from nfs_readpage_async() (Benjamin Coddington) [2017166]
- NFS: Refactor nfs_readpage() and nfs_readpage_async() to use nfs_readdesc (Benjamin Coddington) [2017166]
- NFS: In nfs_readpage() only increment NFSIOS_READPAGES when read succeeds (Benjamin Coddington) [2017166]
- NFS: Clean up nfs_readpage() and nfs_readpages() (Benjamin Coddington) [2017166]
- nfs: Fix fall-through warnings for Clang (Benjamin Coddington) [2017166]
- SUNRPC: Fix fall-through warnings for Clang (Benjamin Coddington) [2017166]
- net: sunrpc: xprtsock.c: Corrected few spellings ,in comments (Benjamin Coddington) [2017166]
- SUNRPC: correct error code comment in xs_tcp_setup_socket() (Benjamin Coddington) [2017166]
- nfsd: cstate->session->se_client -> cstate->clp (Benjamin Coddington) [2017166]
- nfsd: simplify nfsd4_check_open_reclaim (Benjamin Coddington) [2017166]
- nfsd: remove unused set_client argument (Benjamin Coddington) [2017166]
- nfs/blocklayout: remove cruft in bl_alloc_init_bio (Benjamin Coddington) [2017166]
- nfsd: refactor set_client (Benjamin Coddington) [2017166]
- nfsd: rename lookup_clientid->set_client (Benjamin Coddington) [2017166]
- nfsd: simplify nfsd_renew (Benjamin Coddington) [2017166]
- nfsd: simplify process_lock (Benjamin Coddington) [2017166]
- nfsd4: simplify process_lookup1 (Benjamin Coddington) [2017166]
- SUNRPC: Correct a comment (Benjamin Coddington) [2017166]
- svcrdma: DMA-sync the receive buffer in svc_rdma_recvfrom() (Benjamin Coddington) [2017166]
- svcrdma: Restore read and write stats (Benjamin Coddington) [2017166]
- svcrdma: Convert rdma_stat_sq_starve to a per-CPU counter (Benjamin Coddington) [2017166]
- svcrdma: Convert rdma_stat_recv to a per-CPU counter (Benjamin Coddington) [2017166]
- svcrdma: Refactor svc_rdma_init() and svc_rdma_clean_up() (Benjamin Coddington) [2017166]
- nfsd: remove fault injection code (Benjamin Coddington) [2017166]
- SUNRPC: Fix a NULL pointer deref in trace_svc_stats_latency() (Benjamin Coddington) [2017166]
- SUNRPC: Display RPC procedure names instead of proc numbers (Benjamin Coddington) [2017166]
- SUNRPC: Make trace_svc_process() display the RPC procedure symbolically (Benjamin Coddington) [2017166]
- EDAC/mce_amd: Do not load edac_mce_amd module on guests (Aristeu Rozanski) [2000776]
- tracing: Map all PIDs to command lines (Jerome Marchand) [1913211]
- mm/zsmalloc.c: close race window between zs_pool_dec_isolated() and zs_unregister_migration() (Rafael Aquini) [2016441]
- mm: mark the OOM reaper thread as freezable (Rafael Aquini) [2016441]
- mm/page_isolation: guard against possible putback unisolated page (Rafael Aquini) [2016441]
- mm/page_isolation: fix potential missing call to unset_migratetype_isolate() (Rafael Aquini) [2016441]
- mm/page_alloc: use accumulated load when building node fallback list (Rafael Aquini) [2016441]
- mm/vmalloc: do not adjust the search size for alignment overhead (Rafael Aquini) [2016441]
- mm/vmalloc: make sure to dump unpurged areas in /proc/vmallocinfo (Rafael Aquini) [2016441]
- Revert "mm, slub: consider rest of partial list if acquire_slab() fails" (Rafael Aquini) [2016441]
- mm, slub: consider rest of partial list if acquire_slab() fails (Rafael Aquini) [2016441]
- mm, slub: fix incorrect memcg slab count for bulk free (Rafael Aquini) [2016441]
- mm, slub: fix mismatch between reconstructed freelist depth and cnt (Rafael Aquini) [2016441]
- slub: add back check for free nonslab objects (Rafael Aquini) [2016441]
- slub: fix kmalloc_pagealloc_invalid_free unit test (Rafael Aquini) [2016441]
- slub: fix unreclaimable slab stat for bulk free (Rafael Aquini) [2016441]
- mm/slub: add taint after the errors are printed (Rafael Aquini) [2016441]
- mm/slab.c: remove useless lines in enable_cpucache() (Rafael Aquini) [2016441]
- kasan: fix tag for large allocations when using CONFIG_SLAB (Rafael Aquini) [2016441]
- mm/hmm: bypass devmap pte when all pfn requested flags are fulfilled (Rafael Aquini) [2016441]
- mm: memcontrol: set the correct memcg swappiness restriction (Rafael Aquini) [2016441]
- memcg: replace in_interrupt() by !in_task() in active_memcg() (Rafael Aquini) [2016441]
- huge tmpfs: fix split_huge_page() after FALLOC_FL_KEEP_SIZE (Rafael Aquini) [2016441]
- huge tmpfs: fix fallocate(vanilla) advance over huge pages (Rafael Aquini) [2016441]
- huge tmpfs: revert shmem's use of transhuge_vma_enabled() (Rafael Aquini) [2016441]
- mm/huge_memory.c: remove unnecessary tlb_remove_page_size() for huge zero pmd (Rafael Aquini) [2016441]
- mm/huge_memory.c: add missing read-only THP checking in transparent_hugepage_enabled() (Rafael Aquini) [2016441]
- mm/huge_memory.c: use page->deferred_list (Rafael Aquini) [2016441]
- mm/huge_memory.c: remove dedicated macro HPAGE_CACHE_INDEX_MASK (Rafael Aquini) [2016441]
- mm/thp: decrease nr_thps in file's mapping on THP split (Rafael Aquini) [2016441]
- mm/thp: fix page_address_in_vma() on file THP tails (Rafael Aquini) [2016441]
- mm/thp: try_to_unmap() use TTU_SYNC for safe splitting (Rafael Aquini) [2016441]
- mm/thp: make is_huge_zero_pmd() safe and quicker (Rafael Aquini) [2016441]
- mm/thp: fix __split_huge_pmd_locked() on shmem migration entry (Rafael Aquini) [2016441]
- mm/truncate: fix truncation for pages of arbitrary size (Rafael Aquini) [2016441]
- mm/rmap: fix potential pte_unmap on an not mapped pte (Rafael Aquini) [2016441]
- mm/rmap: correct obsolete comment of page_get_anon_vma() (Rafael Aquini) [2016441]
- mm/rmap: use page_not_mapped in try_to_unmap() (Rafael Aquini) [2016441]
- mm/rmap: fix obsolete comment in __page_check_anon_rmap() (Rafael Aquini) [2016441]
- mm/rmap: remove unneeded semicolon in page_not_mapped() (Rafael Aquini) [2016441]
- mm/rmap: correct some obsolete comments of anon_vma (Rafael Aquini) [2016441]
- mm/pgtable-generic.c: optimize the VM_BUG_ON condition in pmdp_huge_clear_flush() (Rafael Aquini) [2016441]
- mm/pgtable-generic.c: simplify the VM_BUG_ON condition in pmdp_huge_clear_flush() (Rafael Aquini) [2016441]
- mm: prevent a warning when casting void* -> enum (Rafael Aquini) [2016441]
- mm/hugeltb: simplify the return code of __vma_reservation_common() (Rafael Aquini) [2016441]
- mm,thp,shmem: make khugepaged obey tmpfs mount flags (Rafael Aquini) [2016441]
- mm/vma: make is_vma_temporary_stack() available for general use (Rafael Aquini) [2016441]
- mm/vma: make vma_is_foreign() available for general use (Rafael Aquini) [2016441]
- hugetlb: fix copy_huge_page_from_user contig page struct assumption (Rafael Aquini) [2016441]
- mm/sparsemem: pfn_to_page is not valid yet on SPARSEMEM (Rafael Aquini) [2016441]
- mm/sparse.c: use __nr_to_section(section_nr) to get mem_section (Rafael Aquini) [2016441]
- mm/huge_memory.c: thp: fix conflict of above-47bit hint address and PMD alignment (Rafael Aquini) [2016441]
- mm/huge_memory.c: make __thp_get_unmapped_area static (Rafael Aquini) [2016441]
- mm/mempolicy.c: fix checking unmapped holes for mbind (Rafael Aquini) [2016441]
- s390/mm: fix VMA and page table handling code in storage key handling functions (Rafael Aquini) [2016441]
- s390/mm: validate VMA in PGSTE manipulation functions (Rafael Aquini) [2016441]
- s390/gmap: don't unconditionally call pte_unmap_unlock() in __gmap_zap() (Rafael Aquini) [2016441]
- s390/gmap: validate VMA in __gmap_zap() (Rafael Aquini) [2016441]
- s390: mm: Fix secure storage access exception handling (Rafael Aquini) [2016441]
- powerpc/numa: Consider the max NUMA node for migratable LPAR (Rafael Aquini) [2016441]
- powerpc/64s: Fix pte update for kernel memory on radix (Rafael Aquini) [2016441]
- powerpc/mm: sanity_check_fault() should work for all, not only BOOK3S (Rafael Aquini) [2016441]
- powerpc/book3s64/pkeys: Use PVR check instead of cpu feature (Rafael Aquini) [2016441]
- powerpc/mm: Fix reporting of kernel execute faults on the 8xx (Rafael Aquini) [2016441]
- powerpc/mm/hash: Handle user access of kernel address gracefully (Rafael Aquini) [2016441]
- powerpc/mm: Add missing tracepoint for tlbie (Rafael Aquini) [2016441]
- arm64: hugetlb: avoid potential NULL dereference (Rafael Aquini) [2016441]
- arm64/numa: Report correct memblock range for the dummy node (Rafael Aquini) [2016441]
- x86/pat: Pass valid address to sanitize_phys() (Rafael Aquini) [2016441]
- x86/mm: Check for pfn instead of page in vmalloc_sync_one() (Rafael Aquini) [2016441]
- x86/mm/tlb: Revert "x86/mm: Align TLB invalidation info" (Rafael Aquini) [2016441]
- x86/mm: Report which part of kernel image is freed (Rafael Aquini) [2016441]
- mm: make free_reserved_area() return "const char *" (Rafael Aquini) [2016441]
- x86/mm/init: Remove freed kernel image areas from alias mapping (Rafael Aquini) [2016441]
- x86/mm/init: Add helper for freeing kernel image pages (Rafael Aquini) [2016441]
- x86/mm/init: Pass unconverted symbol addresses to free_init_pages() (Rafael Aquini) [2016441]
- x86/mm: Add TLB purge to free pmd/pte page interfaces (Rafael Aquini) [2016441]
- mm/mmu_notifier: Make drm-backport/linux/mmu_notifier.h use RH_MMU_NOTIFIER_V2 (Waiman Long) [1946746]
- mm/migrate: fix migrate_pgmap_owner w/o CONFIG_MMU_NOTIFIER (Waiman Long) [1946746]
- mm/notifier: add migration invalidation type (Waiman Long) [1946746]
- mm/migrate: add a flags parameter to migrate_vma (Waiman Long) [1946746]
- mm/mmu_notifiers: ensure range_end() is paired with range_start() (Waiman Long) [1946746]
- mm: track mmu notifiers in fs_reclaim_acquire/release (Waiman Long) [1946746]
- mm: mmu_notifier: fix and extend kerneldoc (Waiman Long) [1946746]
- mm/mmu_notifier: silence PROVE_RCU_LIST warnings (Waiman Long) [1946746]
- mm/mmu_notifiers: Use 'interval_sub' as the variable for mmu_interval_notifier (Waiman Long) [1946746]
- mm/mmu_notifiers: Use 'subscription' as the variable name for mmu_notifier (Waiman Long) [1946746]
- mm/mmu_notifier: Rename struct mmu_notifier_mm to mmu_notifier_subscriptions (Waiman Long) [1946746]
- mm, notifier: Catch sleeping/blocking for !blockable (Waiman Long) [1946746]
- mm/mmu_notifiers: use the right return code for WARN_ON (Waiman Long) [1946746]
- mm/mmu_notifiers: check if mmu notifier callbacks are allowed to fail (Waiman Long) [1946746]
- mm/mmu_notifier: mmu_notifier_range_update_to_read_only() helper (Waiman Long) [1946746]
- mm/mmu_notifier: pass down vma and reasons why mmu notifier is happening (Waiman Long) [1946746]
- mm/mmu_notifier: use structure for invalidate_range_start/end callback (Waiman Long) [1946746]
- Revert "mm, mmu_notifier: annotate mmu notifiers with blockable invalidate callbacks" (Waiman Long) [1946746]
- mm, mmu_notifier: be explicit about range invalition non-blocking mode (Waiman Long) [1946746]
- mm/oom_kill.c: clean up oom_reap_task_mm() (Waiman Long) [1946746]
- mm, oom: distinguish blockable mode for mmu notifiers (Waiman Long) [1946746]
- mm/mmu_notifier: helper to test if a range invalidation is blockable (Waiman Long) [1946746]
- mm/mmu_notifier: Relocate mmu_notifier_put() (Waiman Long) [1946746]
- mm/mmu_notifier: Add mmu_notifier versioning mechanism (Waiman Long) [1946746]
- af_unix: Return errno instead of NULL in unix_create1(). (Balazs Nemeth) [2026690]
- netfilter: nf_tables: fix audit memory leak in nf_tables_commit (Phil Sutter) [2028926]
- ethtool: Validate module EEPROM offset as part of policy (Ivan Vecera) [2019090]
- ethtool: Validate module EEPROM length as part of policy (Ivan Vecera) [2019090]
- ethtool: Use kernel data types for internal EEPROM struct (Ivan Vecera) [2019090]
- ethtool: Document behavior when module EEPROM bank attribute is omitted (Ivan Vecera) [2019090]
- ethtool: Decrease size of module EEPROM get policy array (Ivan Vecera) [2019090]
- ethtool: Document correct attribute type (Ivan Vecera) [2019090]
- ethtool: Use correct command name in title (Ivan Vecera) [2019090]
- net: fix mistake path for netdev_features_strings (Ivan Vecera) [2019089 2019090 2019092]
- ethtool: add a stricter length check (Ivan Vecera) [2019089 2019090 2019092]
- ethtool: Fix a typo (Ivan Vecera) [2019089 2019090 2019092]
- net: ethtool: clear heap allocations for ethtool function (Ivan Vecera) [2019090]
- ethtool: Fix NULL pointer dereference during module EEPROM dump (Ivan Vecera) [2019090]
- ethtool: stats: Fix a copy-paste error (Ivan Vecera) [2019092]
- ethtool: add missing EEPROM to list of messages (Ivan Vecera) [2019090]
- ethtool: stats: clarify the initialization to ETHTOOL_STAT_NOT_SET (Ivan Vecera) [2019092]
- ethtool: ioctl: Fix out-of-bounds warning in store_link_ksettings_for_user() (Ivan Vecera) [2019092]
- ethtool: add interface to read RMON stats (Ivan Vecera) [2019092]
- ethtool: add interface to read standard MAC Ctrl stats (Ivan Vecera) [2019092]
- ethtool: add interface to read standard MAC stats (Ivan Vecera) [2019092]
- ethtool: add a new command for reading standard stats (Ivan Vecera) [2019092]
- docs: ethtool: document standard statistics (Ivan Vecera) [2019092]
- docs: networking: extend the statistics documentation (Ivan Vecera) [2019092]
- ethtool: add FEC statistics (Ivan Vecera) [2019089]
- docs: net: statistics.rst: remove a duplicated kernel-doc (Ivan Vecera) [2019089]
- ethtool: fec_prepare_data() - jump to error handling (Ivan Vecera) [2019089]
- ethtool: move ethtool_stats_init (Ivan Vecera) [2019089]
- ethtool: wire in generic SFP module access (Ivan Vecera) [2019090]
- phy: sfp: add netlink SFP support to generic SFP code (Ivan Vecera) [2019090]
- ethtool: Add fallback to get_module_eeprom from netlink command (Ivan Vecera) [2019090]
- net: ethtool: Export helpers for getting EEPROM info (Ivan Vecera) [2019090]
- ethtool: Allow network drivers to dump arbitrary EEPROM data (Ivan Vecera) [2019090]
- docs: ethtool: correct quotes (Ivan Vecera) [2019090]
- selftests: ethtool: add a netdevsim FEC test (Ivan Vecera) [2019089]
- netdevsim: add FEC settings support (Ivan Vecera) [2019089]
- ethtool: support FEC settings over netlink (Ivan Vecera) [2019089]
- ethtool: document the enum values not defines (Ivan Vecera) [2019089]
- ethtool: fec: fix FEC_NONE check (Ivan Vecera) [2019089]
- ethtool: fec: add note about reuse of reserved (Ivan Vecera) [2019089]
- ethtool: clarify the ethtool FEC interface (Ivan Vecera) [2019089]
- ethtool: fec: sanitize ethtool_fecparam->fec (Ivan Vecera) [2019089]
- ethtool: fec: sanitize ethtool_fecparam->active_fec (Ivan Vecera) [2019089]
- ethtool: fec: sanitize ethtool_fecparam->reserved (Ivan Vecera) [2019089]
- ethtool: fec: remove long structure description (Ivan Vecera) [2019089]
- ethtool: fec: fix typo in kdoc (Ivan Vecera) [2019089]
- net: Remove redundant if statements (Petr Oros) [2026472]
- netdevice: add the case if dev is NULL (Petr Oros) [2026472]
- nvmet: use IOCB_NOWAIT only if the filesystem supports it (Chris Leech) [2015563]
- nvmet-tcp: fix incomplete data digest send (Chris Leech) [2015563]
- nvmet-tcp: fix memory leak when performing a controller reset (Chris Leech) [2015563]
- nvmet-tcp: add an helper to free the cmd buffers (Chris Leech) [2015563]
- nvmet-tcp: fix a race condition between release_queue and io_work (Chris Leech) [2015563]
- nvmet-tcp: fix use-after-free when a port is removed (Chris Leech) [2015563]
- nvmet-rdma: fix use-after-free when a port is removed (Chris Leech) [2015563]
- nvmet: fix use-after-free when a port is removed (Chris Leech) [2015563]
- nvmet-tcp: fix header digest verification (Chris Leech) [2015563]
- nvmet-tcp: fix data digest pointer calculation (Chris Leech) [2015563]
- nvmet-tcp: fix a memory leak when releasing a queue (Chris Leech) [2015563]
- nvmet: fix a width vs precision bug in nvmet_subsys_attr_serial_show() (Chris Leech) [2015563]
- nvmet: fixup buffer overrun in nvmet_subsys_attr_serial() (Chris Leech) [2015563]
- nvmet: return bool from nvmet_passthru_ctrl and nvmet_is_passthru_req (Chris Leech) [2015563]
- nvmet: looks at the passthrough controller when initializing CAP (Chris Leech) [2015563]
- nvmet: check that host sqsize does not exceed ctrl MQES (Chris Leech) [2015563]
- nvmet: avoid duplicate qid in connect cmd (Chris Leech) [2015563]
- nvmet: pass back cntlid on successful completion (Chris Leech) [2015563]
- nvmet: remove redundant assignments of variable status (Chris Leech) [2015563]
- nvme-fabrics: ignore invalid fast_io_fail_tmo values (Chris Leech) [2015563]
- nvme-tcp: fix memory leak when freeing a queue (Chris Leech) [2015563]
- nvme-tcp: validate R2T PDU in nvme_tcp_handle_r2t() (Chris Leech) [2015563]
- nvme-tcp: fix data digest pointer calculation (Chris Leech) [2015563]
- nvme-tcp: fix possible req->offset corruption (Chris Leech) [2015563]
- nvme-tcp: fix H2CData PDU send accounting (again) (Chris Leech) [2015563]
- nvme: keep ctrl->namespaces ordered (Chris Leech) [2015563]
- nvme-tcp: fix incorrect h2cdata pdu offset accounting (Chris Leech) [2015563]
- nvme-tcp: fix io_work priority inversion (Chris Leech) [2015563]
- nvme-multipath: fix ANA state updates when a namespace is not present (Chris Leech) [2015563]
- nvme: avoid race in shutdown namespace removal (Chris Leech) [2015563]
- nvme: update keep alive interval when kato is modified (Chris Leech) [2015563]
- nvme: use return value from blk_execute_rq() (Chris Leech) [2015563]
- nvme-tcp: Do not reset transport on data digest errors (Chris Leech) [2015563]
- nvme-rdma: don't update queue count when failing to set io queues (Chris Leech) [2015563]
- nvme-tcp: don't update queue count when failing to set io queues (Chris Leech) [2015563]
- nvme-tcp: pair send_mutex init with destroy (Chris Leech) [2015563]
- nvme-tcp: don't check blk_mq_tag_to_rq when receiving pdu data (Chris Leech) [2015563]
- RDMA/rxe: Bump up default maximum values used via uverbs (Kamal Heib) [2029675]

* Mon Dec 13 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-355.el8]
- scsi: qedi: Fix error codes in qedi_alloc_global_queues() (Nilesh Javali) [1983905]
- scsi: qedi: Add support for fastpath doorbell recovery (Nilesh Javali) [1983905]
- scsi: qedi: Use DEVICE_ATTR_RO() macro (Nilesh Javali) [1983905]
- scsi: qedi: Fix host removal with running sessions (Nilesh Javali) [1983905]
- scsi: qedi: Wake up if cmd_cleanup_req is set (Nilesh Javali) [1983905]
- scsi: qedi: Complete TMF works before disconnect (Nilesh Javali) [1983905]
- scsi: qedi: Pass send_iscsi_tmf task to abort (Nilesh Javali) [1983905]
- scsi: qedi: Fix cleanup session block/unblock use (Nilesh Javali) [1983905]
- scsi: qedi: Fix TMF session block/unblock use (Nilesh Javali) [1983905]
- scsi: qedi: Use GFP_NOIO for TMF allocation (Nilesh Javali) [1983905]
- scsi: qedi: Fix TMF tid allocation (Nilesh Javali) [1983905]
- scsi: qedi: Fix use after free during abort cleanup (Nilesh Javali) [1983905]
- scsi: qedi: Fix race during abort timeouts (Nilesh Javali) [1983905]
- scsi: qedi: Fix null ref during abort handling (Nilesh Javali) [1983905]
- vrf: Fix fast path output packet handling with async Netfilter rules (Antoine Tenart) [2019333]
- ipv6: do not drop vrf udp multicast packets (Antoine Tenart) [2019333]
- ipv6: handling of multicast packets received in VRF (Antoine Tenart) [2019333]
- vrf: Do not attempt to create IPv6 mcast rule if IPv6 is disabled (Antoine Tenart) [2019333]
- ipv6: add vrf table handling code for ipv6 mcast (Antoine Tenart) [2019333]
- ipv4: Allow sending multicast packets on specific i/f using VRF socket (Antoine Tenart) [2019333]
- xfs: fix I_DONTCACHE (Carlos Maiolino) [2024969]
- kernfs: don't create a negative dentry if inactive node exists (Ian Kent) [2001597]
- kernfs: also call kernfs_set_rev() for positive dentry (Ian Kent) [2001597]
- ixgbevf: use xso.real_dev instead of xso.dev in callback functions of struct xfrmdev_ops (Ken Cox) [1970656]
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup (Ken Cox) [1970653]
- ixgbe, xsk: clean up the resources in ixgbe_xsk_pool_enable error path (Ken Cox) [1970653]
- powerpc/perf: Fix missing is_sier_aviable() during build (Gustavo Walbon) [2011687]
- perf script: Fix PERF_SAMPLE_WEIGHT_STRUCT support (Michael Petlan) [2026390]
- RDMA/core: Set sgtable nents when using ib_dma_virt_map_sg() (Kamal Heib) [2025496]
- RDMA: Use the sg_table directly and remove the opencoded version from umem (Kamal Heib) [2025496]
- ovs: clear skb->tstamp in forwarding path (Antoine Tenart) [2020160]
- net: openvswitch: fix kernel-doc warnings in flow.c (Antoine Tenart) [2020160]
- openvswitch: Optimize operation for key comparison (Antoine Tenart) [2020160]
- net: openvswitch: Remove unnecessary skb_nfct() (Antoine Tenart) [2020160]
- openvswitch: meter: fix race when getting now_ms. (Antoine Tenart) [2020160]
- net: openvswitch: Use 'skb_push_rcsum()' instead of hand coding it (Antoine Tenart) [2020160]
- openvswitch: Fix a typo (Antoine Tenart) [2020160]
- openvswitch: Warn over-mtu packets only if iface is UP. (Antoine Tenart) [2020160]
- openvswitch: meter: remove rate from the bucket size calculation (Antoine Tenart) [2020160]
- net: openvswitch: use core API to update/provide stats (Antoine Tenart) [2020160]
- net: openvswitch: use new function dev_fetch_sw_netstats (Antoine Tenart) [2020160]
- net: openvswitch: use dev_sw_netstats_rx_add() (Antoine Tenart) [2020160]
- net: openvswitch: Constify static struct genl_small_ops (Antoine Tenart) [2020160]
- selftests: add a test case for mirred egress to ingress (Xin Long) [1983894]
- net: sched: act_mirred: drop dst for the direction from egress to ingress (Xin Long) [1983894]
- usb: hso: fix error handling code of hso_create_net_device (José Ignacio Tornos Martínez) [1986489] {CVE-2021-37159}
- i40e: Fix freeing of uninitialized misc IRQ vector (Stefan Assmann) [1990683]
- x86/topology: Make __max_die_per_package available unconditionally (Aristeu Rozanski) [1949284]
- x86/cpu/amd: Set __max_die_per_package on AMD (Aristeu Rozanski) [1949284]
- x86/topology: Set cpu_die_id only if DIE_TYPE found (Aristeu Rozanski) [1949284]
- x86/mce: Drop AMD-specific "DEFERRED" case from Intel severity rule list (Aristeu Rozanski) [1949284]
- EDAC/mce_amd: Add new error descriptions for existing types (Aristeu Rozanski) [1949284]
- x86/mce/amd, edac: Remove report_gart_errors (Aristeu Rozanski) [1949284]
- x86/mce/amd: Make threshold bank setting hotplug robust (Aristeu Rozanski) [1949284]
- x86/mce/amd: Cleanup threshold device remove path (Aristeu Rozanski) [1949284]
- x86/mce/amd: Straighten CPU hotplug path (Aristeu Rozanski) [1949284]
- x86/mce/amd: Sanitize thresholding device creation hotplug path (Aristeu Rozanski) [1949284]
- x86/mce/amd: Protect a not-fully initialized bank from the thresholding interrupt (Aristeu Rozanski) [1949284]
- x86/mce/amd: Init thresholding machinery only on relevant vendors (Aristeu Rozanski) [1949284]
- x86/mce/amd: Do proper cleanup on error paths (Aristeu Rozanski) [1949284]
- x86/mce/amd: Fix kobject lifetime (Aristeu Rozanski) [1949284]
- x86/mce/amd: Publish the bank pointer only after setup has succeeded (Aristeu Rozanski) [1949284]
- x86/mce/amd: Make disable_err_thresholding() static (Aristeu Rozanski) [1949284]
- x86/MCE: Determine MCA banks' init state properly (Aristeu Rozanski) [1949284]
- x86/MCE: Group AMD function prototypes in <asm/mce.h> (Aristeu Rozanski) [1949284]
- x86/MCE: Switch to use the new generic UUID API (Aristeu Rozanski) [1949284]
- ipv4: fix endianness issue in inet_rtm_getroute_build_skb() (Guillaume Nault) [2022057]
- net: igmp: fix data-race in igmp_ifc_timer_expire() (Guillaume Nault) [2022057]
- net/ipv4: swap flow ports when validating source (Guillaume Nault) [2022057]
- tools headers UAPI: Sync linux/in.h copy with the kernel sources (Guillaume Nault) [2022057]
- icmp: don't send out ICMP messages with a source address of 0.0.0.0 (Guillaume Nault) [2022057]
- cipso: correct comments of cipso_v4_cache_invalidate() (Guillaume Nault) [2022057]
- crypto: ccp - Make use of the helper macro kthread_run() (Vladis Dronov) [1997593]
- crypto: ccp - Fix whitespace in sev_cmd_buffer_len() (Vladis Dronov) [1997593]
- crypto: ccp - fix resource leaks in ccp_run_aes_gcm_cmd() (Vladis Dronov) [1997593]
- crypto: jitter - consider 32 LSB for APT (Herbert Xu) [1994390]
- rcu: Tighten rcu_advance_cbs_nowake() checks (Daniel Vacek) [2013408]
- cxgb3: Remove seeprom_write and use VPD API (Myron Stowe) [2019086]
- cxgb3: Use VPD API in t3_seeprom_wp() (Myron Stowe) [2019086]
- cxgb3: Remove t3_seeprom_read and use VPD API (Myron Stowe) [2019086]
- PCI/VPD: Use pci_read_vpd_any() in pci_vpd_size() (Myron Stowe) [2019086]
- PCI/VPD: Add pci_read/write_vpd_any() (Myron Stowe) [2019086]
- PCI/VPD: Defer VPD sizing until first access (Myron Stowe) [2019086]
- PCI/VPD: Use unaligned access helpers (Myron Stowe) [2019086]
- PCI/VPD: Clean up public VPD defines and inline functions (Myron Stowe) [2019086]
- cxgb4: Use pci_vpd_find_id_string() to find VPD ID string (Myron Stowe) [2019086]
- PCI/VPD: Add pci_vpd_find_id_string() (Myron Stowe) [2019086]
- PCI/VPD: Include post-processing in pci_vpd_find_tag() (Myron Stowe) [2019086]
- PCI/VPD: Stop exporting pci_vpd_find_info_keyword() (Myron Stowe) [2019086]
- PCI/VPD: Stop exporting pci_vpd_find_tag() (Myron Stowe) [2019086]
- scsi: cxlflash: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- cxgb4: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- cxgb4: Remove unused vpd_param member ec (Myron Stowe) [2019086]
- cxgb4: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2019086]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- bnxt: Read VPD with pci_vpd_alloc() (Myron Stowe) [2019086]
- bnx2x: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- bnx2x: Read VPD with pci_vpd_alloc() (Myron Stowe) [2019086]
- bnx2: Replace open-coded byte swapping with swab32s() (Myron Stowe) [2019086]
- bnx2: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- sfc: falcon: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- sfc: falcon: Read VPD with pci_vpd_alloc() (Myron Stowe) [2019086]
- tg3: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- tg3: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2019086]
- tg3: Read VPD with pci_vpd_alloc() (Myron Stowe) [2019086]
- sfc: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- sfc: Read VPD with pci_vpd_alloc() (Myron Stowe) [2019086]
- PCI/VPD: Add pci_vpd_check_csum() (Myron Stowe) [2019086]
- PCI/VPD: Add pci_vpd_find_ro_info_keyword() (Myron Stowe) [2019086]
- PCI/VPD: Add pci_vpd_alloc() (Myron Stowe) [2019086]
- PCI/VPD: Treat invalid VPD like missing VPD capability (Myron Stowe) [2019086]
- PCI/VPD: Determine VPD size in pci_vpd_init() (Myron Stowe) [2019086]
- PCI/VPD: Embed struct pci_vpd in struct pci_dev (Myron Stowe) [2019086]
- PCI/VPD: Remove struct pci_vpd.valid member (Myron Stowe) [2019086]
- PCI/VPD: Remove struct pci_vpd_ops (Myron Stowe) [2019086]
- PCI/VPD: Reorder pci_read_vpd(), pci_write_vpd() (Myron Stowe) [2019086]
- PCI/VPD: Remove struct pci_vpd.flag (Myron Stowe) [2019086]
- PCI/VPD: Make pci_vpd_wait() uninterruptible (Myron Stowe) [2019086]
- PCI/VPD: Remove pci_vpd_size() old_size argument (Myron Stowe) [2019086]
- PCI/VPD: Allow access to valid parts of VPD if some is invalid (Myron Stowe) [2019086]
- PCI/VPD: Don't check Large Resource Item Names for validity (Myron Stowe) [2019086]
- PCI/VPD: Reject resource tags with invalid size (Myron Stowe) [2019086]
- PCI/VPD: Treat initial 0xff as missing EEPROM (Myron Stowe) [2019086]
- PCI/VPD: Check Resource Item Names against those valid for type (Myron Stowe) [2019086]
- PCI/VPD: Correct diagnostic for VPD read failure (Myron Stowe) [2019086]
- net: create netdev->dev_addr assignment helpers (Josef Oskera) [2016478]
- scsi: ibmvfc: Fix up duplicate response detection (Steve Best) [2015732]
- scsi: core: Avoid leaving shost->last_reset with stale value if EH does not run (Ewan D. Milne) [2011330]
- libbpf: Add support for new llvm bpf relocations (Yauheni Kaliuta) [1944799]
- libbpf: Fix memory leak in strset (Yauheni Kaliuta) [1944799]
- selftests: bpf: skip test_doc_build.sh (Yauheni Kaliuta) [1944799]
- bpf: Stop caching subprog index in the bpf_pseudo_func insn (Yauheni Kaliuta) [1944799]
- redhat/configs: enable CONFIG_BPF_UNPRIV_DEFAULT_OFF (Yauheni Kaliuta) [1944799]
- kbuild: Quote OBJCOPY var to avoid a pahole call break the build (Yauheni Kaliuta) [1944799]
- bpf: Fix BPF_JIT kconfig symbol dependency (Yauheni Kaliuta) [1944799]
- bpf: Add kconfig knob for disabling unpriv bpf by default (Yauheni Kaliuta) [1944799]
- bpf, kconfig: Add consolidated menu entry for bpf with core options (Yauheni Kaliuta) [1944799]
- tools/resolve_btfids: Fix warnings (Yauheni Kaliuta) [1944799]
- tools/runqslower: Allow substituting custom vmlinux.h for the build (Yauheni Kaliuta) [1944799]
- lib/string.c: allow searching for NUL with strnchr (Yauheni Kaliuta) [1944799]
- rpmspec: update manpages installation after 5.13 rebase (bpf-helpers, bpf-syscall) (Yauheni Kaliuta) [1944799]
- libbpf: Fix segfault in static linker for objects without BTF (Yauheni Kaliuta) [1944799]
- bpf: Avoid using ARRAY_SIZE on an uninitialized pointer (Yauheni Kaliuta) [1944799]
- bpf: Remove superfluous aux sanitation on subprog rejection (Yauheni Kaliuta) [1944799]
- bpf: Clarify a bpf_bprintf_prepare macro (Yauheni Kaliuta) [1944799]
- bpf: Fix nested bpf_bprintf_prepare with more per-cpu buffers (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix the snprintf test (Yauheni Kaliuta) [1944799]
- bpf: Implement formatted output helpers with bstr_printf (Yauheni Kaliuta) [1944799]
- seq_file: Add a seq_bprintf function (Yauheni Kaliuta) [1944799]
- bpf: Notify user if we ever hit a bpf_snprintf verifier bug (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add a series of tests for bpf_snprintf (Yauheni Kaliuta) [1944799]
- bpf: Lock bpf_trace_printk's tmp buf before it is written to (Yauheni Kaliuta) [1944799]
- bpf: Add a bpf_snprintf helper (Yauheni Kaliuta) [1944799]
- bpf: Factorize bpf_trace_printk and bpf_seq_printf (Yauheni Kaliuta) [1944799]
- Stop the ad-hoc games with -Wno-maybe-initialized (Yauheni Kaliuta) [1944799]
- kbuild: compute false-positive -Wmaybe-uninitialized cases in Kconfig (Yauheni Kaliuta) [1944799]
- bpf: Fix potentially incorrect results with bpf_get_local_storage() (Yauheni Kaliuta) [1944799]
- bpf, samples: Fix xdpsock with '-M' parameter missing unload process (Yauheni Kaliuta) [1944799]
- libbpf: Don't crash on object files with no symbol tables (Yauheni Kaliuta) [1944799]
- libbpf: Fix ELF symbol visibility update logic (Yauheni Kaliuta) [1944799]
- bpf, selftests: Adjust few selftest outcomes wrt unreachable code (Yauheni Kaliuta) [1944799]
- bpf: Do not mark insn as seen under speculative path verification (Yauheni Kaliuta) [1944799]
- bpf: Inherit expanded/patched seen count from old aux data (Yauheni Kaliuta) [1944799]
- bpf, selftests: Adjust few selftest result_unpriv outcomes (Yauheni Kaliuta) [1944799]
- bpf: Fix BPF_LSM kconfig symbol dependency (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add test for l3 use of bpf_redirect_peer (Yauheni Kaliuta) [1944799]
- bpftool: Add sock_release help info for cgroup attach/prog load command (Yauheni Kaliuta) [1944799]
- bpf, offload: Reorder offload callback 'prepare' in verifier (Yauheni Kaliuta) [1944799]
- selftests/bpf: Test ringbuf mmap read-only and read-write restrictions (Yauheni Kaliuta) [1944799]
- selftests/bpf: Convert static to global in tc_redirect progs (Yauheni Kaliuta) [1944799]
- selftests/bpf: Rewrite test_tc_redirect.sh as prog_tests/tc_redirect.c (Yauheni Kaliuta) [1944799]
- libbpf: Provide GELF_ST_VISIBILITY() define for older libelf (Yauheni Kaliuta) [1944799]
- bpf: Add deny list of btf ids check for tracing programs (Yauheni Kaliuta) [1944799]
- bpf: Forbid trampoline attach for functions with variable arguments (Yauheni Kaliuta) [1944799]
- samples/bpf: Consider frame size in tx_only of xdpsock sample (Yauheni Kaliuta) [1944799]
- libbpf: Add NULL check to add_dummy_ksym_var (Yauheni Kaliuta) [1944799]
- libbpf: Fix signed overflow in ringbuf_process_ring (Yauheni Kaliuta) [1944799]
- bpf, selftests: Update array map tests for per-cpu batched ops (Yauheni Kaliuta) [1944799]
- bpf: Add batched ops support for percpu array (Yauheni Kaliuta) [1944799]
- bpf, docs: Fix literal block for example code (Yauheni Kaliuta) [1944799]
- bpf, cpumap: Bulk skb using netif_receive_skb_list (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix field existence CO-RE reloc tests (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix BPF_CORE_READ_BITFIELD() macro (Yauheni Kaliuta) [1944799]
- selftests/bpf: Use ASSERT macros in lsm test (Yauheni Kaliuta) [1944799]
- selftests/bpf: Test that module can't be unloaded with attached trampoline (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add re-attach test to lsm test (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add re-attach test to fexit_test (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add re-attach test to fentry_test (Yauheni Kaliuta) [1944799]
- bpf: Allow trampoline re-attach for tracing and lsm programs (Yauheni Kaliuta) [1944799]
- bpf: Document the pahole release info related to libbpf in bpf_devel_QA.rst (Yauheni Kaliuta) [1944799]
- selftests/bpf: Document latest Clang fix expectations for linking tests (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add map linking selftest (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add global variables linking selftest (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add function linking selftest (Yauheni Kaliuta) [1944799]
- selftests/bpf: Omit skeleton generation for multi-linked BPF object files (Yauheni Kaliuta) [1944799]
- selftests/bpf: Use -O0 instead of -Og in selftests builds (Yauheni Kaliuta) [1944799]
- libbpf: Support extern resolution for BTF-defined maps in .maps section (Yauheni Kaliuta) [1944799]
- libbpf: Add linker extern resolution support for functions and global variables (Yauheni Kaliuta) [1944799]
- libbpf: Tighten BTF type ID rewriting with error checking (Yauheni Kaliuta) [1944799]
- libbpf: Extend sanity checking ELF symbols with externs validation (Yauheni Kaliuta) [1944799]
- libbpf: Make few internal helpers available outside of libbpf.c (Yauheni Kaliuta) [1944799]
- libbpf: Factor out symtab and relos sanity checks (Yauheni Kaliuta) [1944799]
- libbpf: Refactor BTF map definition parsing (Yauheni Kaliuta) [1944799]
- libbpf: Allow gaps in BPF program sections to support overriden weak functions (Yauheni Kaliuta) [1944799]
- libbpf: Mark BPF subprogs with hidden visibility as static for BPF verifier (Yauheni Kaliuta) [1944799]
- libbpf: Suppress compiler warning when using SEC() macro with externs (Yauheni Kaliuta) [1944799]
- bpftool: Dump more info about DATASEC members (Yauheni Kaliuta) [1944799]
- bpftool: Support dumping BTF VAR's "extern" linkage (Yauheni Kaliuta) [1944799]
- bpf: Remove unnecessary map checks for ARG_PTR_TO_CONST_STR (Yauheni Kaliuta) [1944799]
- xsk: Align XDP socket batch size with DPDK (Yauheni Kaliuta) [1944799]
- bpf, doc: Fix some invalid links in bpf_devel_QA.rst (Yauheni Kaliuta) [1944799]
- net, xdp: Update pkt_type if generic XDP changes unicast MAC (Yauheni Kaliuta) [1944799]
- powerpc/ebpf32: Use standard function call for functions within 32M distance (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add docs target as all dependency (Yauheni Kaliuta) [1944799]
- bpf/selftests: Add bpf_get_task_stack retval bounds test_prog (Yauheni Kaliuta) [1944799]
- bpf/selftests: Add bpf_get_task_stack retval bounds verifier test (Yauheni Kaliuta) [1944799]
- bpf: Refine retval for bpf_get_task_stack helper (Yauheni Kaliuta) [1944799]
- samples/bpf: Fix broken tracex1 due to kprobe argument change (Yauheni Kaliuta) [1944799]
- libbpf: Introduce a BPF_SNPRINTF helper macro (Yauheni Kaliuta) [1944799]
- libbpf: Initialize the bpf_seq_printf parameters array field by field (Yauheni Kaliuta) [1944799]
- bpf: Add a ARG_PTR_TO_CONST_STR argument type (Yauheni Kaliuta) [1944799]
- bpftool: Fix a clang compilation warning (Yauheni Kaliuta) [1944799]
- selftests/bpf: Silence clang compilation warnings (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix test_cpp compilation failure with clang (Yauheni Kaliuta) [1944799]
- selftests: Set CC to clang in lib.mk if LLVM is set (Yauheni Kaliuta) [1944799]
- libbpf: Remove unused field. (Yauheni Kaliuta) [1944799]
- tools/testing: Remove unused variable (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix the ASSERT_ERR_PTR macro (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add tests for target information in bpf_link info queries (Yauheni Kaliuta) [1944799]
- bpf: Return target info when a tracing bpf_link is queried (Yauheni Kaliuta) [1944799]
- libbpf: Clarify flags in ringbuf helpers (Yauheni Kaliuta) [1944799]
- bpf: Sync bpf headers in tooling infrastucture (Yauheni Kaliuta) [1944799]
- bpf: Document PROG_TEST_RUN limitations (Yauheni Kaliuta) [1944799]
- bpf, inode: Remove second initialization of the bpf_preload_lock (Yauheni Kaliuta) [1944799]
- libbpf: Fix KERNEL_VERSION macro (Yauheni Kaliuta) [1944799]
- bpf: selftests: Specify CONFIG_DYNAMIC_FTRACE in the testing config (Yauheni Kaliuta) [1944799]
- powerpc/bpf: Reallocate BPF registers to volatile registers when possible on PPC32 (Yauheni Kaliuta) [1944799]
- powerpc/bpf: Change values of SEEN_ flags (Yauheni Kaliuta) [1944799]
- powerpc/bpf: Move common functions into bpf_jit_comp.c (Yauheni Kaliuta) [1944799]
- powerpc/bpf: Remove classical BPF support for PPC32 (Yauheni Kaliuta) [1944799]
- powerpc/bpf: Move common helpers into bpf_jit.h (Yauheni Kaliuta) [1944799]
- powerpc/bpf: Change register numbering for bpf_set/is_seen_register() (Yauheni Kaliuta) [1944799]
- libbpf: Remove redundant semi-colon (Yauheni Kaliuta) [1944799]
- bpf: Remove repeated struct btf_type declaration (Yauheni Kaliuta) [1944799]
- bpf, cgroup: Delete repeated struct bpf_prog declaration (Yauheni Kaliuta) [1944799]
- bpf: Remove unused parameter from ___bpf_prog_run (Yauheni Kaliuta) [1944799]
- bpf, selftests: test_maps generating unrecognized data section (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add an option for a debug shell in vmtest.sh (Yauheni Kaliuta) [1944799]
- bpf: Remove redundant assignment of variable id (Yauheni Kaliuta) [1944799]
- bpf: Remove unused bpf_load_pointer (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove unused defines (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove mutex and condition variable (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove thread attribute (Yauheni Kaliuta) [1944799]
- selftests: xsk: Implement bpf_link test (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove sync_mutex_tx and atomic var (Yauheni Kaliuta) [1944799]
- selftests: xsk: Refactor teardown/bidi test cases and testapp_validate (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove Tx synchronization resources (Yauheni Kaliuta) [1944799]
- selftests: xsk: Split worker thread (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove thread for netns switch (Yauheni Kaliuta) [1944799]
- samples: bpf: Do not unload prog within xdpsock (Yauheni Kaliuta) [1944799]
- libbpf: xsk: Use bpf_link (Yauheni Kaliuta) [1944799]
- selftests: xsk: Simplify frame traversal in dumping thread (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove inline keyword from source file (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove unused function (Yauheni Kaliuta) [1944799]
- selftests: xsk: Remove struct ifaceconfigobj (Yauheni Kaliuta) [1944799]
- selftests: xsk: Don't call worker_pkt_dump() for stats test (Yauheni Kaliuta) [1944799]
- libbpf: Fix memory leak when emitting final btf_ext (Yauheni Kaliuta) [1944799]
- bpf: selftests: Update clang requirement in README.rst for testing kfunc call (Yauheni Kaliuta) [1944799]
- bpf: Update bpf_design_QA.rst to clarify the kfunc call is not ABI (Yauheni Kaliuta) [1944799]
- bpf: selftests: Add kfunc_call test (Yauheni Kaliuta) [1944799]
- bpf: selftests: Bpf_cubic and bpf_dctcp calling kernel functions (Yauheni Kaliuta) [1944799]
- bpf: selftests: Rename bictcp to bpf_cubic (Yauheni Kaliuta) [1944799]
- libbpf: Support extern kernel function (Yauheni Kaliuta) [1944799]
- libbpf: Record extern sym relocation first (Yauheni Kaliuta) [1944799]
- libbpf: Rename RELO_EXTERN to RELO_EXTERN_VAR (Yauheni Kaliuta) [1944799]
- libbpf: Refactor codes for finding btf id of a kernel symbol (Yauheni Kaliuta) [1944799]
- libbpf: Refactor bpf_object__resolve_ksyms_btf_id (Yauheni Kaliuta) [1944799]
- bpf: Support bpf program calling kernel function (Yauheni Kaliuta) [1944799]
- bpf: Refactor btf_check_func_arg_match (Yauheni Kaliuta) [1944799]
- bpf: Simplify freeing logic in linfo and jited_linfo (Yauheni Kaliuta) [1944799]
- libbpf: Preserve empty DATASEC BTFs during static linking (Yauheni Kaliuta) [1944799]
- bpf: struct sock is declared twice in bpf_sk_storage header (Yauheni Kaliuta) [1944799]
- bpf: Remove unused headers (Yauheni Kaliuta) [1944799]
- libbpf: Add bpf object kern_version attribute setter (Yauheni Kaliuta) [1944799]
- bpf: selftests: Add tests for batched ops in LPM trie maps (Yauheni Kaliuta) [1944799]
- bpf: Add support for batched ops in LPM trie maps (Yauheni Kaliuta) [1944799]
- selftests/bpf: Better error messages for ima_setup.sh failures (Yauheni Kaliuta) [1944799]
- bpf: Fix NULL pointer dereference in bpf_get_local_storage() helper (Yauheni Kaliuta) [1944799]
- libbpf: Constify few bpf_program getters (Yauheni Kaliuta) [1944799]
- bpf: Fix typo 'accesible' into 'accessible' (Yauheni Kaliuta) [1944799]
- tracing: Fix various typos in comments (Yauheni Kaliuta) [1944799]
- libbpf: Skip BTF fixup if object file has no BTF (Yauheni Kaliuta) [1944799]
- bpf: Remove insn_buf[] declaration in inner block (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add multi-file statically linked BPF object file test (Yauheni Kaliuta) [1944799]
- selftests/bpf: Pass all BPF .o's through BPF static linker (Yauheni Kaliuta) [1944799]
- selftests/bpf: Re-generate vmlinux.h and BPF skeletons if bpftool changed (Yauheni Kaliuta) [1944799]
- bpftool: Add `gen object` command to perform BPF static linking (Yauheni Kaliuta) [1944799]
- bpftool: Add ability to specify custom skeleton object name (Yauheni Kaliuta) [1944799]
- libbpf: Add BPF static linker BTF and BTF.ext support (Yauheni Kaliuta) [1944799]
- libbpf: Add BPF static linker APIs (Yauheni Kaliuta) [1944799]
- libbpf: Add generic BTF type shallow copy API (Yauheni Kaliuta) [1944799]
- libbpf: Extract internal set-of-strings datastructure APIs (Yauheni Kaliuta) [1944799]
- libbpf: Rename internal memory-management helpers (Yauheni Kaliuta) [1944799]
- libbpf: Generalize BTF and BTF.ext type ID and strings iteration (Yauheni Kaliuta) [1944799]
- libbpf: Expose btf_type_by_id() internally (Yauheni Kaliuta) [1944799]
- x86: Fix various typos in comments (Yauheni Kaliuta) [1944799]
- selftests/bpf: drop custom NULL #define in skb_pkt_end selftest (Yauheni Kaliuta) [1944799]
- libbpf: provide NULL and KERNEL_VERSION macros in bpf_helpers.h (Yauheni Kaliuta) [1944799]
- bpf: net: Emit anonymous enum with BPF_TCP_CLOSE value explicitly (Yauheni Kaliuta) [1944799]
- selftests/bpf: Use nanosleep() syscall instead of sleep() in get_cgroup_id (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix warning comparing pointer to 0 (Yauheni Kaliuta) [1944799]
- selftests/bpf: Build everything in debug mode (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix maybe-uninitialized warning in xdpxceiver test (Yauheni Kaliuta) [1944799]
- bpftool: Fix maybe-uninitialized warnings (Yauheni Kaliuta) [1944799]
- libbpf: Add explicit padding to bpf_xdp_set_link_opts (Yauheni Kaliuta) [1944799]
- kernel/bpf/: Fix misspellings using codespell tool (Yauheni Kaliuta) [1944799]
- s390/bpf: Implement new atomic ops (Yauheni Kaliuta) [1944799]
- bpf: selftests: Remove unused 'nospace_err' in tests for batched ops in array maps (Yauheni Kaliuta) [1944799]
- samples: bpf: Fix a spelling typo in do_hbm_test.sh (Yauheni Kaliuta) [1944799]
- libbpf: Avoid inline hint definition from 'linux/stddef.h' (Yauheni Kaliuta) [1944799]
- libbpf: xsk: Move barriers from libbpf_util.h to xsk.h (Yauheni Kaliuta) [1944799]
- libbpf: xsk: Remove linux/compiler.h header (Yauheni Kaliuta) [1944799]
- bpf: Fix warning comparing pointer to 0 (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix warning comparing pointer to 0 (Yauheni Kaliuta) [1944799]
- bpf, xdp: Restructure redirect actions (Yauheni Kaliuta) [1944799]
- bpf, xdp: Make bpf_redirect_map() a map operation (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix compiler warning in BPF_KPROBE definition in loop6.c (Yauheni Kaliuta) [1944799]
- selftests/bpf: Fix typo in Makefile (Yauheni Kaliuta) [1944799]
- libbpf: Fix arm64 build (Yauheni Kaliuta) [1944799]
- libbpf, xsk: Add libbpf_smp_store_release libbpf_smp_load_acquire (Yauheni Kaliuta) [1944799]
- selftests, bpf: Extend test_tc_tunnel test with vxlan (Yauheni Kaliuta) [1944799]
- bpf: Add bpf_skb_adjust_room flag BPF_F_ADJ_ROOM_ENCAP_L2_ETH (Yauheni Kaliuta) [1944799]
- selftests/bpf: Simplify the calculation of variables (Yauheni Kaliuta) [1944799]
- bpf: Simplify the calculation of variables (Yauheni Kaliuta) [1944799]
- selftests: bpf: Don't run sk_lookup in verifier tests (Yauheni Kaliuta) [1944799]
- selftests: bpf: Check that PROG_TEST_RUN repeats as requested (Yauheni Kaliuta) [1944799]
- selftests: bpf: Convert sk_lookup ctx access tests to PROG_TEST_RUN (Yauheni Kaliuta) [1944799]
- bpf: Add PROG_TEST_RUN support for sk_lookup programs (Yauheni Kaliuta) [1944799]
- bpf: Consolidate shared test timing code (Yauheni Kaliuta) [1944799]
- docs/bpf: Add bpf() syscall command reference (Yauheni Kaliuta) [1944799]
- selftests/bpf: Test syscall command parsing (Yauheni Kaliuta) [1944799]
- selftests/bpf: Templatize man page generation (Yauheni Kaliuta) [1944799]
- tools/bpf: Remove bpf-helpers from bpftool docs (Yauheni Kaliuta) [1944799]
- scripts/bpf: Add syscall commands printer (Yauheni Kaliuta) [1944799]
- tools: Sync uapi bpf.h header with latest changes (Yauheni Kaliuta) [1944799]
- scripts/bpf: Abstract eBPF API target parameter (Yauheni Kaliuta) [1944799]
- bpf: Document BPF_MAP_*_BATCH syscall commands (Yauheni Kaliuta) [1944799]
- bpf: Document BPF_PROG_QUERY syscall command (Yauheni Kaliuta) [1944799]
- bpf: Document BPF_PROG_TEST_RUN syscall command (Yauheni Kaliuta) [1944799]
- bpf: Document BPF_PROG_ATTACH syscall command (Yauheni Kaliuta) [1944799]
- bpf: Document BPF_PROG_PIN syscall command (Yauheni Kaliuta) [1944799]
- bpf: Document BPF_F_LOCK in syscall commands (Yauheni Kaliuta) [1944799]
- bpf: Add minimal bpf() command documentation (Yauheni Kaliuta) [1944799]
- bpf: Import syscall arg documentation (Yauheni Kaliuta) [1944799]
- libbpf: Fix whitespace in btf_add_composite() comment (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add a verifier scale test with unknown bounded loop (Yauheni Kaliuta) [1944799]
- tools, bpf_asm: Exit non-zero on errors (Yauheni Kaliuta) [1944799]
- tools, bpf_asm: Hard error on out of range jumps (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add arraymap test for bpf_for_each_map_elem() helper (Yauheni Kaliuta) [1944799]
- selftests/bpf: Add hashmap test for bpf_for_each_map_elem() helper (Yauheni Kaliuta) [1944799]
- bpftool: Print subprog address properly (Yauheni Kaliuta) [1944799]
- libbpf: Support subprog address relocation (Yauheni Kaliuta) [1944799]
- libbpf: Move function is_ldimm64() earlier in libbpf.c (Yauheni Kaliuta) [1944799]
- bpf: Add arraymap support for bpf_for_each_map_elem() helper (Yauheni Kaliuta) [1944799]
- bpf: Add hashtab support for bpf_for_each_map_elem() helper (Yauheni Kaliuta) [1944799]
- bpf: Add bpf_for_each_map_elem() helper (Yauheni Kaliuta) [1944799]
- bpf: Change return value of verifier function add_subprog() (Yauheni Kaliuta) [1944799]
- bpf: Refactor check_func_call() to allow callback function (Yauheni Kaliuta) [1944799]
- bpf: Factor out verbose_invalid_scalar() (Yauheni Kaliuta) [1944799]
- bpf: Factor out visit_func_call_insn() in check_cfg() (Yauheni Kaliuta) [1944799]
- selftests/bpf: Copy extras in out-of-srctree builds (Yauheni Kaliuta) [1944799]
- selftests/bpf: Propagate error code of the command to vmtest.sh (Yauheni Kaliuta) [1944799]
- selftests/bpf: Introduce xsk statistics tests (Yauheni Kaliuta) [1944799]
- selftests/bpf: Restructure xsk selftests (Yauheni Kaliuta) [1944799]
- selftests/bpf: Expose and rename debug argument (Yauheni Kaliuta) [1944799]
- selftest/bpf: Make xsk tests less verbose (Yauheni Kaliuta) [1944799]
- bpf: Rename fixup_bpf_calls and add some comments (Yauheni Kaliuta) [1944799]
- bpf: Use MAX_BPF_FUNC_REG_ARGS macro (Yauheni Kaliuta) [1944799]
- bpf: runqslower: Prefer using local vmlimux to generate vmlinux.h (Yauheni Kaliuta) [1944799]
- bpf: Add kernel/modules BTF presence checks to bpftool feature command (Yauheni Kaliuta) [1944799]

* Mon Dec 06 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-354.el8]
- netfilter: log: work around missing softdep backend module (Florian Westphal) [2017794]
- netfilter: nft_ct: protect nft_ct_pcpu_template_refcnt with mutex (Florian Westphal) [2017794]
- netfilter: Fix fall-through warnings for Clang (Florian Westphal) [2017794]
- netfilter: nft_nat: allow to specify layer 4 protocol NAT only (Florian Westphal) [2017794]
- netfilter: conntrack: adjust stop timestamp to real expiry value (Florian Westphal) [2017794]
- netfilter: ipvs: make global sysctl readonly in non-init netns (Florian Westphal) [2017794]
- ipvs: fix possible memory leak in ip_vs_control_net_init (Florian Westphal) [2017794]
- ipvs: fix the connection sync failed in some cases (Florian Westphal) [2017794]
- net: Fix offloading indirect devices dependency on qdisc order creation (Davide Caratti) [1997381]
- net/core: Remove unused field from struct flow_indr_dev (Davide Caratti) [1997381]
- Drivers: hv: balloon: Use VMBUS_RING_SIZE() wrapper for dm_ring_size (Vitaly Kuznetsov) [2019101]
- hv_balloon: Remove redundant assignment to region_start (Vitaly Kuznetsov) [2019101]
- hv_balloon: disable warning when floor reached (Vitaly Kuznetsov) [2019101]
- net/tls: Fix flipped sign in async_wait.err assignment (Sabrina Dubroca) [2019176]
- net/tls: Fix flipped sign in tls_err_abort() calls (Sabrina Dubroca) [2019176]
- tls: prevent oversized sendfile() hangs by ignoring MSG_MORE (Sabrina Dubroca) [2019176]
- tls splice: remove inappropriate flags checking for MSG_PEEK (Sabrina Dubroca) [2019176]
- net/tls: Fix use-after-free after the TLS device goes down and up (Sabrina Dubroca) [2019176]
- net/tls: Replace TLS_RX_SYNC_RUNNING with RCU (Sabrina Dubroca) [2019176]
- tls splice: check SPLICE_F_NONBLOCK instead of MSG_DONTWAIT (Sabrina Dubroca) [2019176]
- net/tls: Remove redundant initialization of record (Sabrina Dubroca) [2019176]
- ibmvnic: don't stop queue in xmit (Diego Domingos) [2011995]
- selftests: net: switch to socat in the GSO GRE test (Hangbin Liu) [2018059]
- selftests: net: properly support IPv6 in GSO GRE test (Hangbin Liu) [2018059]
- kselftests/net: add missed setup_loopback.sh/setup_veth.sh to Makefile (Hangbin Liu) [2018059]
- selftests: add simple GSO GRE test (Hangbin Liu) [2018059]
- selftests/net: allow GRO coalesce test on veth (Hangbin Liu) [2018059]
- selftests/net: GRO coalesce test (Hangbin Liu) [2018059]
- perf/x86: Reset destroy callback on event init failure (Michael Petlan) [2003982]
- x86/msr: Define new bits in TSX_FORCE_ABORT MSR (Michael Petlan) [2003982]
- perf script: Fix --list-dlfilters documentation (Michael Petlan) [2003982]
- perf/x86/intel/uncore: Fix IIO cleanup mapping procedure for SNR/ICX (Michael Petlan) [2003982]
- Revert "perf map: Fix dso->nsinfo refcounting" (Michael Petlan) [2003982]
- perf pmu: Fix alias matching (Michael Petlan) [2003982]
- perf cs-etm: Split --dump-raw-trace by AUX records (Michael Petlan) [2003982]
- perf sched: Fix record failure when CONFIG_SCHEDSTATS is not set (Michael Petlan) [2003982]
- perf probe: Fix add event failure when running 32-bit perf in a 64-bit kernel (Michael Petlan) [2003982]
- perf data: Close all files in close_dir() (Michael Petlan) [2003982]
- perf probe-file: Delete namelist in del_events() on the error path (Michael Petlan) [2003982]
- perf test bpf: Free obj_buf (Michael Petlan) [2003982]
- perf trace: Free strings in trace__parse_events_option() (Michael Petlan) [2003982]
- perf trace: Free syscall tp fields in evsel->priv (Michael Petlan) [2003982]
- perf trace: Free syscall->arg_fmt (Michael Petlan) [2003982]
- perf trace: Free malloc'd trace fields on exit (Michael Petlan) [2003982]
- perf lzma: Close lzma stream on exit (Michael Petlan) [2003982]
- perf script: Fix memory 'threads' and 'cpus' leaks on exit (Michael Petlan) [2003982]
- perf script: Release zstd data (Michael Petlan) [2003982]
- perf session: Cleanup trace_event (Michael Petlan) [2003982]
- perf inject: Close inject.output on exit (Michael Petlan) [2003982]
- perf report: Free generated help strings for sort option (Michael Petlan) [2003982]
- perf env: Fix memory leak of cpu_pmu_caps (Michael Petlan) [2003982]
- perf test maps__merge_in: Fix memory leak of maps (Michael Petlan) [2003982]
- perf dso: Fix memory leak in dso__new_map() (Michael Petlan) [2003982]
- perf test event_update: Fix memory leak of unit (Michael Petlan) [2003982]
- perf test event_update: Fix memory leak of evlist (Michael Petlan) [2003982]
- perf test session_topology: Delete session->evlist (Michael Petlan) [2003982]
- perf env: Fix sibling_dies memory leak (Michael Petlan) [2003982]
- perf probe: Fix dso->nsinfo refcounting (Michael Petlan) [2003982]
- perf map: Fix dso->nsinfo refcounting (Michael Petlan) [2003982]
- perf inject: Fix dso->nsinfo refcounting (Michael Petlan) [2003982]
- perf cs-etm: Split Coresight decode by aux records (Michael Petlan) [2003982]
- perf sched: Cast PTHREAD_STACK_MIN to int as it may turn into sysconf(__SC_THREAD_STACK_MIN_VALUE) (Michael Petlan) [2003982]
- libperf: Fix build error with LIBPFM4=1 (Michael Petlan) [2003982]
- perf stat: Merge uncore events by default for hybrid platform (Michael Petlan) [2003982]
- perf tests: Fix 'Convert perf time to TSC' on core-only system (Michael Petlan) [2003982]
- perf tests: Fix 'Roundtrip evsel->name' on core-only system (Michael Petlan) [2003982]
- perf tests: Fix 'Parse event definition strings' on core-only system (Michael Petlan) [2003982]
- perf pmu: Skip invalid hybrid pmu (Michael Petlan) [2003982]
- perf test: Add free() calls for scandir() returned dirent entries (Michael Petlan) [2003982]
- libperf: Add tests for perf_evlist__set_leader() (Michael Petlan) [2003982]
- libperf: Remove BUG_ON() from library code in get_group_fd() (Michael Petlan) [2003982]
- libperf: Add group support to perf_evsel__open() (Michael Petlan) [2003982]
- perf tools: Fix pattern matching for same substring in different PMU type (Michael Petlan) [2003982]
- perf record: Add a dummy event on hybrid systems to collect metadata records (Michael Petlan) [2003982]
- perf stat: Add Topdown metrics L2 events as default events (Michael Petlan) [2003982]
- libperf: Adopt evlist__set_leader() from tools/perf as perf_evlist__set_leader() (Michael Petlan) [2003982]
- libperf: Move 'nr_groups' from tools/perf to evlist::nr_groups (Michael Petlan) [2003982]
- libperf: Move 'leader' from tools/perf to perf_evsel::leader (Michael Petlan) [2003982]
- libperf: Move 'idx' from tools/perf to perf_evsel::idx (Michael Petlan) [2003982]
- libperf: Change tests to single static and shared binaries (Michael Petlan) [2003982]
- perf intel-pt: Add a config for max loops without consuming a packet (Michael Petlan) [2003982]
- perf stat: Disable the NMI watchdog message on hybrid (Michael Petlan) [2003982]
- perf trace: Fix the perf trace link location (Michael Petlan) [2003982]
- perf top: Fix overflow in elf_sec__is_text() (Michael Petlan) [2003982]
- perf annotate: Fix 's' on source line when disasm is empty (Michael Petlan) [2003982]
- perf probe: Do not show @plt function by default (Michael Petlan) [2003982]
- perf symbol-elf: Decode dynsym even if symtab exists (Michael Petlan) [2003982]
- perf probe: Fix debuginfo__new() to enable build-id based debuginfo (Michael Petlan) [2003982]
- perf stat: Enable BPF counter with --for-each-cgroup (Michael Petlan) [2003982]
- perf report: Fix --task and --stat with pipe input (Michael Petlan) [2003982]
- perf session: Add missing evlist__delete when deleting a session (Michael Petlan) [2003982]
- perf annotate: Allow 's' on source code lines (Michael Petlan) [2003982]
- perf dlfilter: Add object_code() to perf_dlfilter_fns (Michael Petlan) [2003982]
- perf dlfilter: Add attr() to perf_dlfilter_fns (Michael Petlan) [2003982]
- perf dlfilter: Add srcline() to perf_dlfilter_fns (Michael Petlan) [2003982]
- perf dlfilter: Add insn() to perf_dlfilter_fns (Michael Petlan) [2003982]
- perf dlfilter: Add resolve_address() to perf_dlfilter_fns (Michael Petlan) [2003982]
- perf build: Install perf_dlfilter.h (Michael Petlan) [2003982]
- perf script: Add option to pass arguments to dlfilters (Michael Petlan) [2003982]
- perf script: Add option to list dlfilters (Michael Petlan) [2003982]
- perf script: Add dlfilter__filter_event_early() (Michael Petlan) [2003982]
- perf script: Add API for filtering via dynamically loaded shared object (Michael Petlan) [2003982]
- perf llvm: Return -ENOMEM when asprintf() fails (Michael Petlan) [2003982]
- perf cs-etm: Delay decode of non-timeless data until cs_etm__flush_events() (Michael Petlan) [2003982]
- perf arm-spe: Don't wait for PERF_RECORD_EXIT event (Michael Petlan) [2003982]
- perf arm-spe: Bail out if the trace is later than perf event (Michael Petlan) [2003982]
- perf arm-spe: Assign kernel time to synthesized event (Michael Petlan) [2003982]
- perf arm-spe: Convert event kernel time to counter value (Michael Petlan) [2003982]
- perf arm-spe: Save clock parameters from TIME_CONV event (Michael Petlan) [2003982]
- perf cs-etm: Remove callback cs_etm_find_snapshot() (Michael Petlan) [2003982]
- perf bpf_counter: Move common functions to bpf_counter.h (Michael Petlan) [2003982]
- perf tools: Add cgroup_is_v2() helper (Michael Petlan) [2003982]
- perf tools: Add read_cgroup_id() function (Michael Petlan) [2003982]
- tools lib: Adopt bitmap_intersects() operation from the kernel sources (Michael Petlan) [2003982]
- perf top: Add cgroup support for perf top (-G) (Michael Petlan) [2003982]
- perf script: Share addr_al between functions (Michael Petlan) [2003982]
- perf script: Move filtering before scripting (Michael Petlan) [2003982]
- perf script: Move filter_cpu() earlier (Michael Petlan) [2003982]
- perf test: Pass the verbose option to shell tests (Michael Petlan) [2003982]
- perf probe: Add --bootconfig to output definition in bootconfig format (Michael Petlan) [2003982]
- perf probe: Cleanup synthesize_probe_trace_command() (Michael Petlan) [2003982]
- perf probe: Support probes on init functions for offline kernel (Michael Petlan) [2003982]
- perf test: Make stat bpf counters test more robust (Michael Petlan) [2003982]
- perf test: Add verbose skip output for bpf counters (Michael Petlan) [2003982]
- perf annotate: Add itrace options support (Michael Petlan) [2003982]
- perf mem-events: Remove duplicate #undef (Michael Petlan) [2003982]
- perf evsel: Adjust hybrid event and global event mixed group (Michael Petlan) [2003982]
- perf probe: Provide clearer message permission error for tracefs access (Michael Petlan) [2003982]
- perf auxtrace: Change to use SMP memory barriers (Michael Petlan) [2003982]
- perf srccode: Use list_move() instead of equivalent list_del() + list_add() sequence (Michael Petlan) [2003982]
- perf probe: Report possible permission error for map__load() failure (Michael Petlan) [2003982]
- perf probe: Add permission and sysctl notice to man page (Michael Petlan) [2003982]
- perf c2c: Support record for hybrid platform (Michael Petlan) [2003982]
- perf mem: Disable 'mem-loads-aux' group before reporting (Michael Petlan) [2003982]
- perf mem: Fix wrong verbose output for recording events (Michael Petlan) [2003982]
- perf mem: Support record for hybrid platform (Michael Petlan) [2003982]
- perf tools: Check if mem_events is supported for hybrid platform (Michael Petlan) [2003982]
- perf tools: Support pmu prefix for mem-store event (Michael Petlan) [2003982]
- perf tools: Support pmu prefix for mem-load event (Michael Petlan) [2003982]
- perf tools: Check mem-loads auxiliary event (Michael Petlan) [2003982]
- perf scripting python: intel-pt-events.py: Add --insn-trace and --src-trace (Michael Petlan) [2003982]
- perf scripting python: exported-sql-viewer.py: Factor out libxed.py (Michael Petlan) [2003982]
- perf scripting python: Update documentation for srcline etc (Michael Petlan) [2003982]
- perf scripting python: Add perf_sample_srcline() and perf_sample_srccode() (Michael Petlan) [2003982]
- perf scripting python: Add perf_set_itrace_options() (Michael Petlan) [2003982]
- perf auxtrace: Factor out itrace_do_parse_synth_opts() (Michael Petlan) [2003982]
- perf scripting python: Add perf_sample_insn() (Michael Petlan) [2003982]
- perf script: Factor out script_fetch_insn() (Michael Petlan) [2003982]
- perf scripting python: Assign perf_script_context (Michael Petlan) [2003982]
- perf scripting: Add perf_session to scripting_context (Michael Petlan) [2003982]
- perf scripting: Add scripting_context__update() (Michael Petlan) [2003982]
- perf scripting python: Simplify perf-trace-context module functions (Michael Petlan) [2003982]
- perf scripting python: Remove unnecessary 'static' (Michael Petlan) [2003982]
- perf test: Test 2 libpfm4 error cases (Michael Petlan) [2003982]
- perf test: Iterate over shell tests in alphabetical order (Michael Petlan) [2003982]
- perf probe: Provide more detail with relocation warning (Michael Petlan) [2003982]
- perf parse-events: Add bison --file-prefix-map option (Michael Petlan) [2003982]
- perf inject: Do not inject BUILD_ID record if MMAP2 has it (Michael Petlan) [2003982]
- perf inject: Call dso__put() even if dso->hit is set (Michael Petlan) [2003982]
- perf scripts python: intel-pt-events.py: Add branches to script (Michael Petlan) [2003982]
- perf scripting python: Add auxtrace error (Michael Petlan) [2003982]
- perf scripting python: Add context switch (Michael Petlan) [2003982]
- perf scripting python: Add cpumode (Michael Petlan) [2003982]
- perf scripting python: Add IPC (Michael Petlan) [2003982]
- perf scripting python: Add sample flags (Michael Petlan) [2003982]
- perf script: Factor out perf_sample__sprintf_flags() (Michael Petlan) [2003982]
- perf scripting python: Add 'addr_location' for 'addr' (Michael Petlan) [2003982]
- perf scripting python: Factor out set_sym_in_dict() (Michael Petlan) [2003982]
- perf scripting python: Fix tuple_set_u64() (Michael Petlan) [2003982]
- perf auxtrace: Make perf_event__process_auxtrace*() callable (Michael Petlan) [2003982]
- perf script: Find script file relative to exec path (Michael Petlan) [2003982]
- perf arm-spe: Remove redundant checking for "full_auxtrace" (Michael Petlan) [2003982]
- perf arm-spe: Enable timestamp for per-cpu mode (Michael Petlan) [2003982]
- perf arm-spe: Correct sample flags for dummy event (Michael Petlan) [2003982]
- perf arm-spe: Correct sample flags for SPE event (Michael Petlan) [2003982]
- perf vendor events intel: Update event list for Icelake Client (Michael Petlan) [2003982]
- perf vendor events intel: Add uncore event list for Icelake Server (Michael Petlan) [2003982]
- perf vendor events intel: Add core event list for Icelake Server (Michael Petlan) [2003982]
- perf tests: Drop __maybe_unused on x86 test declarations (Michael Petlan) [2003982]
- perf tests: Consolidate test__arch_unwind_sample declaration (Michael Petlan) [2003982]
- perf build: Improve error message for old/missing clang (Michael Petlan) [2003982]
- perf tools: Test build with libbpf/LIBBPF_DYNAMIC=1 (Michael Petlan) [2003982]
- perf tools: Test build with libopencsd/CORESIGHT=1 (Michael Petlan) [2003982]
- perf cs-etm: Prevent and warn on underflows during timestamp calculation. (Michael Petlan) [2003982]
- perf cs-etm: Start reading 'Z' --itrace option (Michael Petlan) [2003982]
- perf cs-etm: Move synth_opts initialisation (Michael Petlan) [2003982]
- perf header: Support HYBRID_CPU_PMU_CAPS feature (Michael Petlan) [2003982]
- perf header: Support HYBRID_TOPOLOGY feature (Michael Petlan) [2003982]
- perf cs-etm: Set time on synthesised samples to preserve ordering (Michael Petlan) [2003982]
- perf cs-etm: Refactor timestamp variable names (Michael Petlan) [2003982]
- perf x86 kvm-stat: Support to analyze kvm MSR (Michael Petlan) [2003982]
- perf stat: Use aggregated counts directly (Michael Petlan) [2003982]
- perf record: Set timestamp boundary for AUX area events (Michael Petlan) [2003982]
- perf intel-pt: Parse VM Time Correlation options and set up decoding (Michael Petlan) [2003982]
- perf intel-pt: Add VM Time Correlation to decoder (Michael Petlan) [2003982]
- perf intel-pt: Better 7-byte timestamp wraparound logic (Michael Petlan) [2003982]
- perf intel-pt: Pass the first timestamp to the decoder (Michael Petlan) [2003982]
- perf intel-pt: Add a tree for VMCS information (Michael Petlan) [2003982]
- perf intel-pt: Let overlap detection handle VM timestamps (Michael Petlan) [2003982]
- perf auxtrace: Allow buffers to be mapped read / write (Michael Petlan) [2003982]
- perf inject: Add --vm-time-correlation option (Michael Petlan) [2003982]
- perf inject: Add facility to do in place update (Michael Petlan) [2003982]
- perf intel-pt: Support Z itrace option for timeless decoding (Michael Petlan) [2003982]
- perf intel-pt: Move synth_opts initialization earlier (Michael Petlan) [2003982]
- perf auxtrace: Add Z itrace option for timeless decoding (Michael Petlan) [2003982]
- perf/x86/amd/power: Assign pmu.module (Michael Petlan) [2003982]
- perf/x86/amd/ibs: Extend PERF_PMU_CAP_NO_EXCLUDE to IBS Op (Michael Petlan) [2003982]
- perf/x86/amd/ibs: Work around erratum #1197 (Michael Petlan) [2003982]
- perf/x86/intel/uncore: Fix integer overflow on 23 bit left shift of a u32 (Michael Petlan) [2003982]
- perf/x86/intel/pt: Fix mask of num_address_ranges (Michael Petlan) [2003982]
- perf/x86: Fix out of bound MSR access (Michael Petlan) [2003982]
- perf/x86/cstate: Add ICELAKE_X and ICELAKE_D support (Michael Petlan) [2003982]
- perf: MAP_EXECUTABLE does not indicate VM_MAYEXEC (Michael Petlan) [2003982]
- arm64: perf: Simplify EVENT ATTR macro in perf_event.c (Michael Petlan) [2003982]
- arm64: perf: Simplify the ARMv8 PMUv3 event attributes (Michael Petlan) [2003982]
- arm64: perf: Remove unused macro (Michael Petlan) [2003982]
- drivers/perf: Simplify EVENT ATTR macro in qcom_l2_pmu.c (Michael Petlan) [2003982]
- drivers/perf: Simplify EVENT ATTR macro in qcom_l3_pmu.c (Michael Petlan) [2003982]
- drivers/perf: Simplify EVENT ATTR macro in xgene_pmu.c (Michael Petlan) [2003982]
- drivers/perf: convert sysfs sprintf family to sysfs_emit (Michael Petlan) [2003982]
- drivers/perf: convert sysfs scnprintf family to sysfs_emit_at() and sysfs_emit() (Michael Petlan) [2003982]
- perf: arm-ccn: Use scnprintf() for robustness (Michael Petlan) [2003982]
- drivers/perf: convert sysfs snprintf family to sysfs_emit (Michael Petlan) [2003982]
- perf: Add EVENT_ATTR_ID to simplify event attributes (Michael Petlan) [2003982]
- perf/x86/intel: Fix instructions:ppp support in Sapphire Rapids (Michael Petlan) [2003982]
- perf/x86/intel: Add more events requires FRONTEND MSR on Sapphire Rapids (Michael Petlan) [2003982]
- perf/x86: Reset the dirty counter to prevent the leak for an RDPMC task (Michael Petlan) [2003982]
- uprobes: Update uprobe_write_opcode() kernel-doc comment (Michael Petlan) [2003982]
- perf/hw_breakpoint: Fix DocBook warnings in perf hw_breakpoint (Michael Petlan) [2003982]
- perf/core: Fix DocBook warnings (Michael Petlan) [2003982]
- perf/core: Make local function perf_pmu_snapshot_aux() static (Michael Petlan) [2003982]
- perf/x86/intel/uncore: Enable I/O stacks to IIO PMON mapping on ICX (Michael Petlan) [2003982]
- perf/x86/intel/uncore: Enable I/O stacks to IIO PMON mapping on SNR (Michael Petlan) [2003982]
- perf/x86/intel/uncore: Generalize I/O stacks to PMON mapping procedure (Michael Petlan) [2003982]
- perf/x86/intel/uncore: Drop unnecessary NULL checks after container_of() (Michael Petlan) [2003982]
- x86/events/intel: Do not deploy TSX force abort workaround when TSX is deprecated (Michael Petlan) [2003982]
- netpoll: don't require irqs disabled in rt kernels (Wander Lairson Costa) [1905440]
- net/netif_receive_skb_core: Use migrate_disable() (Luis Claudio R. Goncalves) [2024168]
- RDMA/qedr: Fix NULL deref for query_qp on the GSI QP (Kamal Heib) [2006260 1984280]
- RDMA/core: Always release restrack object (Kamal Heib) [2006260]
- RDMA/core: Fix incorrect print format specifier (Kamal Heib) [2006260]
- RDMA: Remove rdma_set_device_sysfs_group() (Kamal Heib) [2006260]
- RDMA/core: Allow port_groups to be used with namespaces (Kamal Heib) [2006260]
- RDMA: Change ops->init_port to ops->port_groups (Kamal Heib) [2006260]
- RDMA/hfi1: Use attributes for the port sysfs (Kamal Heib) [2006260 1989164]
- RDMA/cm: Use an attribute_group on the ib_port_attribute intead of kobj's (Kamal Heib) [2006260]
- RDMA/core: Expose the ib port sysfs attribute machinery (Kamal Heib) [2006260]
- RDMA/core: Remove the kobject_uevent() NOP (Kamal Heib) [2006260]
- RDMA/core: Create the device hw_counters through the normal groups mechanism (Kamal Heib) [2006260]
- RDMA/core: Simplify how the port sysfs is created (Kamal Heib) [2006260]
- RDMA/core: Simplify how the gid_attrs sysfs is created (Kamal Heib) [2006260]
- RDMA/core: Split gid_attrs related sysfs from add_port() (Kamal Heib) [2006260]
- RDMA/core: Split port and device counter sysfs attributes (Kamal Heib) [2006260]
- RDMA/core: Replace the ib_port_data hw_stats pointers with a ib_port pointer (Kamal Heib) [2006260]
- RDMA: Split the alloc_hw_stats() ops to port and device variants (Kamal Heib) [2006260]
- RDMA/rxe: Zero out index member of struct rxe_queue (Kamal Heib) [2006260]
- RDMA/efa: Free IRQ vectors on error flow (Kamal Heib) [2006260]
- RDMA/rxe: Fix memory allocation while in a spin lock (Kamal Heib) [2006260]
- IB/hfi1: Fix possible null-pointer dereference in _extend_sdma_tx_descs() (Kamal Heib) [2006260 1989164]
- RDMA/rxe: Restore setting tot_len in the IPv4 header (Kamal Heib) [2006260]
- RDMA/rxe: Use the correct size of wqe when processing SRQ (Kamal Heib) [2006260]
- RDMA/cma: Revert INIT-INIT patch (Kamal Heib) [2006260]
- RDMA/rxe: Fix memory leak in error path code (Kamal Heib) [2006260]
- RDMA/rxe: Missing unlock on error in get_srq_wqe() (Kamal Heib) [2006260]
- RDMA/cma: Fix rdma_resolve_route() memory leak (Kamal Heib) [2006260]
- RDMA/core/sa_query: Remove unused argument (Kamal Heib) [2006260]
- RDMA/cma: Fix incorrect Packet Lifetime calculation (Kamal Heib) [2006260]
- RDMA/cma: Protect RMW with qp_mutex (Kamal Heib) [2006260]
- RDMA/cma: Remove unnecessary INIT->INIT transition (Kamal Heib) [2006260]
- RDMA/rxe: Fix redundant skb_put_zero (Kamal Heib) [2006260]
- RDMA/rxe: Fix extra copy in prepare_ack_packet (Kamal Heib) [2006260]
- RDMA/rxe: Fix over copying in get_srq_wqe (Kamal Heib) [2006260]
- RDMA/rxe: Fix extra copies in build_rdma_network_hdr (Kamal Heib) [2006260]
- RDMA/rxe: Fix redundant call to ip_send_check (Kamal Heib) [2006260]
- RDMA/rxe: Fix useless copy in send_atomic_ack (Kamal Heib) [2006260]
- RDMA/core: Use flexible array for mad data (Kamal Heib) [2006260]
- RDMA/rxe: Don't overwrite errno from ib_umem_get() (Kamal Heib) [2006260]
- IB/core: Shuffle locks in ib_port_data to save memory (Kamal Heib) [2006260]
- IB/core: Removed port validity check from ib_get_cached_subnet_prefix (Kamal Heib) [2006260]
- RDMA: Fix kernel-doc warnings about wrong comment (Kamal Heib) [2006260]
- RDMA/rxe: Disallow MR dereg and invalidate when bound (Kamal Heib) [2006260]
- RDMA/rxe: Implement memory access through MWs (Kamal Heib) [2006260]
- RDMA/rxe: Implement invalidate MW operations (Kamal Heib) [2006260]
- RDMA/rxe: Add support for bind MW work requests (Kamal Heib) [2006260]
- RDMA/rxe: Move local ops to subroutine (Kamal Heib) [2006260]
- RDMA/rxe: Replace WR_REG_MASK by WR_LOCAL_OP_MASK (Kamal Heib) [2006260]
- RDMA/rxe: Add ib_alloc_mw and ib_dealloc_mw verbs (Kamal Heib) [2006260]
- RDMA/rxe: Enable MW object pool (Kamal Heib) [2006260]
- RDMA/rxe: Return errors for add index and key (Kamal Heib) [2006260]
- RDMA/rxe: Add bind MW fields to rxe_send_wr (Kamal Heib) [2006260]
- RDMA/rxe: Fix qp reference counting for atomic ops (Kamal Heib) [2006260]
- IB/cm: Remove dgid from the cm_id_priv av (Kamal Heib) [2006260]
- RDMA/core: Use refcount_t instead of atomic_t on refcount of ib_uverbs_device (Kamal Heib) [2006260]
- RDMA/ipoib: Use refcount_t instead of atomic_t for reference counting (Kamal Heib) [2006260]
- RDMA/core: Use refcount_t instead of atomic_t on refcount of mcast_port (Kamal Heib) [2006260]
- RDMA/core: Use refcount_t instead of atomic_t on refcount of mcast_member (Kamal Heib) [2006260]
- RDMA/core: Remove refcount from struct ib_mad_snoop_private (Kamal Heib) [2006260]
- RDMA/core: Use refcount_t instead of atomic_t on refcount of iwpm_admin_data (Kamal Heib) [2006260]
- RDMA/core: Use refcount_t instead of atomic_t on refcount of iwcm_id_private (Kamal Heib) [2006260]
- RDMA/rxe: Protext kernel index from user space (Kamal Heib) [2006260]
- RDMA/rxe: Protect user space index loads/stores (Kamal Heib) [2006260]
- RDMA/rxe: Add a type flag to rxe_queue structs (Kamal Heib) [2006260]
- IB/cm: Protect cm_dev, cm_ports and mad_agent with kref and lock (Kamal Heib) [2006260]
- IB/cm: Improve the calling of cm_init_av_for_lap and cm_init_av_by_path (Kamal Heib) [2006260]
- IB/cm: Simplify ib_cancel_mad() and ib_modify_mad() calls (Kamal Heib) [2006260]
- Revert "IB/cm: Mark stale CM id's whenever the mad agent was unregistered" (Kamal Heib) [2006260]
- IB/cm: Tidy remaining cm_msg free paths (Kamal Heib) [2006260]
- IB/cm: Call the correct message free functions in cm_send_handler() (Kamal Heib) [2006260]
- IB/cm: Split cm_alloc_msg() (Kamal Heib) [2006260]
- IB/cm: Pair cm_alloc_response_msg() with a cm_free_response_msg() (Kamal Heib) [2006260]
- RDMA/core: Sanitize WQ state received from the userspace (Kamal Heib) [2006260]
- RDMA/srp: Use DEVICE_ATTR_*() macros (Kamal Heib) [2006260]
- RDMA/core: Use the DEVICE_ATTR_RO macro (Kamal Heib) [2006260]
- IB/ipoib: Use DEVICE_ATTR_*() macros (Kamal Heib) [2006260]
- IB/core: Only update PKEY and GID caches on respective events (Kamal Heib) [2006260]
- RDMA/srp: Fix a recently introduced memory leak (Kamal Heib) [2006260]
- RDMA/srp: Add more structure size checks (Kamal Heib) [2006260]
- IB/hfi1: Move a function from a header file into a .c file (Kamal Heib) [2006260 1989164]
- IB/hfi1: Remove the repeated declaration (Kamal Heib) [2006260 1989164]
- IB/hfi1: Delete an unneeded bool conversion (Kamal Heib) [2006260 1989164]
- RDMA: Remove unnecessary struct declaration (Kamal Heib) [2006260]
- RDMA/core: Remove never used ib_modify_wq function call (Kamal Heib) [2006260]
- IB/srpt: Remove redundant assignment to ret (Kamal Heib) [2006260]
- RDMA/ucma: Cleanup to reduce duplicate code (Kamal Heib) [2006260]
- RDMA/umem: batch page unpin in __ib_umem_release() (Kamal Heib) [2006259]
- RDMA/rxe: Return CQE error if invalid lkey was supplied (Kamal Heib) [2006259]
- RDMA/nldev: Add copy-on-fork attribute to get sys command (Kamal Heib) [2006259]
- IB/hfi1: Remove redundant variable rcd (Kamal Heib) [2006259 1989164]
- RDMA/nldev: Add QP numbers to SRQ information (Kamal Heib) [2006259]
- RDMA/nldev: Return SRQ information (Kamal Heib) [2006259]
- RDMA/restrack: Add support to get resource tracking for SRQ (Kamal Heib) [2006259]
- RDMA/nldev: Return context information (Kamal Heib) [2006259]
- RDMA/cma: Skip device which doesn't support CM (Kamal Heib) [2006259 1957239]
- IB/ipoib: Remove unnecessary struct declaration (Kamal Heib) [2006259]
- IB/ipoib: Improve latency in ipoib/cm connection formation (Kamal Heib) [2006259]
- RDMA/ipoib: Print a message if only child interface is UP (Kamal Heib) [2006259]
- RDMA/uverbs: Make UVERBS_OBJECT_METHODS to consider line number (Kamal Heib) [2006259]
- IB/hfi1: Rework AIP and VNIC dummy netdev usage (Kamal Heib) [2006259 1989164]
- IB/cma: Introduce rdma_set_min_rnr_timer() (Kamal Heib) [2006259]
- RDMA/core: Correct format of block comments (Kamal Heib) [2006259]
- RDMA/core: Correct format of braces (Kamal Heib) [2006259]
- RDMA/core: Remove redundant spaces (Kamal Heib) [2006259]
- RDMA/core: Add necessary spaces (Kamal Heib) [2006259]
- RDMA/core: Remove the redundant return statements (Kamal Heib) [2006259]
- RDMA/core: Print the function name by __func__ instead of an fixed string (Kamal Heib) [2006259]
- RDMA/rxe: Fix missing acks from responder (Kamal Heib) [2006259]
- RDMA/core: Make the wc status prompt message clearer (Kamal Heib) [2006259]
- IB/hfi1: Remove indirect call to hfi1_ipoib_send_dma() (Kamal Heib) [2006259 1989164]
- IB/hfi1: Use napi_schedule_irqoff() for tx napi (Kamal Heib) [2006259 1989164]
- IB/hfi1: Correct oversized ring allocation (Kamal Heib) [2006259 1989164]
- IB/{ipoib,hfi1}: Add a timeout handler for rdma_netdev (Kamal Heib) [2006259 1989164]
- IB/hfi1: Add AIP tx traces (Kamal Heib) [2006259 1989164]
- RDMA/uverbs: Fix -Wunused-function warning (Kamal Heib) [2006259]
- RDMA/iser: struct iscsi_iser_task is declared twice (Kamal Heib) [2006259]
- RDMA/rxe: Split MEM into MR and MW (Kamal Heib) [2006259]
- RDMA/efa: Use strscpy instead of strlcpy (Kamal Heib) [2006259]
- RDMA: Fix a typo (Kamal Heib) [2006259]
- IB/hfi1: Fix a typo (Kamal Heib) [2006259 1989164]
- RDMA/core: Correct misspellings of two words in comments (Kamal Heib) [2006259]
- RDMA/uverbs: Refactor rdma_counter_set_auto_mode and __counter_set_mode (Kamal Heib) [2006259]
- RDMA: Support more than 255 rdma ports (Kamal Heib) [2006259 1957239]
- RDMA/include: Mundane typo fixes throughout the file (Kamal Heib) [2006259]
- RDMA/cma: Remove unused leftovers in cma code (Kamal Heib) [2006259]
- RDMA: Fix kernel-doc compilation warnings (Kamal Heib) [2006259]
- RDMA/hw/i40iw/i40iw_virtchnl: Fix a bunch of kernel-doc issues (Kamal Heib) [2006259]
- RDMA/hw/i40iw/i40iw_utils: Fix some misspellings and missing param descriptions (Kamal Heib) [2006259]
- IB/core: Split uverbs_get_const/default to consider target type (Kamal Heib) [2006259]
- IB/core: Drop WARN_ON() from ib_umem_find_best_pgsz() (Kamal Heib) [2006259]
- RDMA/core: Remove unused req_ncomp_notif device operation (Kamal Heib) [2006259]
- RDMA/iwcm: Allow AFONLY binding for IPv6 addresses (Kamal Heib) [2006259]
- IB/hfi1: switch to core handling of rx/tx byte/packet counters (Kamal Heib) [2006259 1989164]
- RDMA: Convert various random sprintf sysfs _show uses to sysfs_emit (Kamal Heib) [2006259]
- RDMA: Manual changes for sysfs_emit and neatening (Kamal Heib) [2006259]
- RDMA: Convert sysfs device * show functions to use sysfs_emit() (Kamal Heib) [2006259]
- IB/hfi1: use new function dev_fetch_sw_netstats (Kamal Heib) [2006259 1989164]
- RDMA/ipoib: Convert to use DEFINE_SEQ_ATTRIBUTE macro (Kamal Heib) [2006259]
- include/linux/seq_file.h: introduce DEFINE_SEQ_ATTRIBUTE() helper macro (Kamal Heib) [2006259]
- ibmvnic: delay complete() (Diego Domingos) [2019210]
- ibmvnic: Process crqs after enabling interrupts (Diego Domingos) [2019210]
- Documentation: sysrq: update description about sysrq crash (Chris von Recklinghausen) [2019943]
- sysrq: Use panic() to force a crash (Chris von Recklinghausen) [2019943]
- ethtool: extend coalesce setting uAPI with CQE mode (Ivan Vecera) [2006829]
- ethtool: add two coalesce attributes for CQE mode (Ivan Vecera) [2006829]
- ice: Add support for VF rate limiting (Jonathan Toppins) [1973187]
- net: Prevent infinite while loop in skb_tx_hash() (Paolo Abeni) [2018437]
- napi: fix race inside napi_enable (Paolo Abeni) [2018437]
- net/af_unix: fix a data-race in unix_dgram_poll (Paolo Abeni) [2018437]
- devlink: Clear whole devlink_flash_notify struct (Paolo Abeni) [2018437]
- net: linkwatch: fix failure to restore device state across suspend/resume (Paolo Abeni) [2018437]
- gro: fix napi_gro_frags() Fast GRO breakage due to IP alignment check (Paolo Abeni) [2018437]
- gro: ensure frag0 meets IP header alignment (Paolo Abeni) [2018437]
- net: core: allow fast GRO for skbs with Ethernet header in head (Paolo Abeni) [2018437]
- udp: fix skb_copy_and_csum_datagram with odd segment sizes (Paolo Abeni) [2018437]
- skbuff: back tiny skbs with kmalloc() in __netdev_alloc_skb() too (Paolo Abeni) [2018437]
- selftests/net: remove min gso test in packet_snd (Paolo Abeni) [2018437]
- net: be more gentle about silly gso requests coming from user (Paolo Abeni) [2018437]
- virtio_net: Do not pull payload in skb->head (Paolo Abeni) [2018437]
- net: check untrusted gso_size at kernel entry (Paolo Abeni) [2018437]
- net: stricter validation of untrusted gso packets$ (Paolo Abeni) [2018437]
- net: avoid 32 x truesize under-estimation for tiny skbs (Paolo Abeni) [2018437]
- ionic: no devlink_unregister if not registered (Jonathan Toppins) [2016705]
- ionic: tame the filter no space message (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: allow adminq requests to override default error message (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: handle vlan id overflow (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: generic filter delete (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: generic filter add (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: add generic filter search (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: remove mac overflow flags (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: move lif mac address functions (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: add filterlist to debugfs (Jonathan Toppins) [2016705 1959512 2002943]
- ionic: don't remove netdev->dev_addr when syncing uc list (Jonathan Toppins) [2016705 2012030]
- ionic: move filter sync_needed bit set (Jonathan Toppins) [2016705]
- ionic: add lif param to ionic_qcq_disable (Jonathan Toppins) [2016705]
- ionic: have ionic_qcq_disable decide on sending to hardware (Jonathan Toppins) [2016705]
- ionic: add polling to adminq wait (Jonathan Toppins) [2016705]
- ionic: widen queue_lock use around lif init and deinit (Jonathan Toppins) [2016705]
- ionic: move lif mutex setup and delete (Jonathan Toppins) [2016705]
- ionic: check for binary values in FW ver string (Jonathan Toppins) [2016705]
- ionic: remove debug stats (Jonathan Toppins) [2016705]
- ionic: fix gathering of debug stats (Jonathan Toppins) [2016705]
- ionic: fix a sleeping in atomic bug (Jonathan Toppins) [2016705]
- ionic: fix double use of queue-lock (Jonathan Toppins) [2016705]
- ionic: recreate hwstamp queues on ifup (Jonathan Toppins) [2016705 1981590]
- ionic: pull hwstamp queue_lock up a level (Jonathan Toppins) [2016705 1981590]
- ionic: add queue lock around open and stop (Jonathan Toppins) [2016705 1981590]
- ionic: fill mac addr earlier in add_addr (Jonathan Toppins) [2016705 1981590]
- ionic: squelch unnecessary fw halted message (Jonathan Toppins) [2016705 1981590]
- ionic: fire watchdog again after fw_down (Jonathan Toppins) [2016705 1981590]
- ionic: handle mac filter overflow (Jonathan Toppins) [2016705 1981590]
- ionic: refactor ionic_lif_addr to remove a layer (Jonathan Toppins) [2016705 1981590]
- ionic: sync the filters in the work task (Jonathan Toppins) [2016705 1981590]
- ionic: flatten calls to set-rx-mode (Jonathan Toppins) [2016705 1981590]
- ionic: remove old work task types (Jonathan Toppins) [2016705 1981590]
- ionic: add function tag to debug string (Jonathan Toppins) [2016705]
- ionic: enable rxhash only with multiple queues (Jonathan Toppins) [2016705]
- ionic: block some ethtool operations when fw in reset (Jonathan Toppins) [2016705]
- ionic: remove unneeded comp union fields (Jonathan Toppins) [2016705]
- ionic: increment num-vfs before configure (Jonathan Toppins) [2016705]
- ionic: use fewer inits on the buf_info struct (Jonathan Toppins) [2016705]
- ionic: init reconfig err to 0 (Jonathan Toppins) [2016705]
- ionic: print firmware version on identify (Jonathan Toppins) [2016705]
- ionic: monitor fw status generation (Jonathan Toppins) [2016705]
- ionic: minimize resources when under kdump (Jonathan Toppins) [2016705]
- ionic: cleanly release devlink instance (Jonathan Toppins) [2016705]
- ionic: drop useless check of PCI driver data validity (Jonathan Toppins) [2016705]
- ionic: Remove unused function pointer typedef ionic_reset_cb (Jonathan Toppins) [2016705]
- ACPI: Use fwnode_init() to set up fwnode (Mark Langsdorf) [1982374]
- device property: Add missed header in fwnode.h (Mark Langsdorf) [1982374]
- regmap: set debugfs_name to NULL after it is freed (Mark Langsdorf) [1982374]
- mfd: cpcap: Fix interrupt regression with regmap clear_ack (Mark Langsdorf) [1982374]
- driver core: Fix device link device name collision (Mark Langsdorf) [1982374]
- driver core: Extend device_is_dependent() (Mark Langsdorf) [1982374]
- device property: add description of fwnode cases (Mark Langsdorf) [1982374]
- Revert "device property: Keep secondary firmware node secondary by type" (Mark Langsdorf) [1982374]
- regmap: debugfs: Fix a reversed if statement in regmap_debugfs_init() (Mark Langsdorf) [1982374]
- regmap: debugfs: Fix a memory leak when calling regmap_attach_dev (Mark Langsdorf) [1982374]
- driver core: platform: Add extra error check in devm_platform_get_irqs_affinity() (Mark Langsdorf) [1982374]
- driver core: platform: don't oops in platform_shutdown() on unbound devices (Mark Langsdorf) [1982374]
- PM: domains: create debugfs nodes when adding power domains (Mark Langsdorf) [1982374]
- driver core: platform: Add devm_platform_get_irqs_affinity() (Mark Langsdorf) [1982374]
- platform-msi: Track shared domain allocation (Mark Langsdorf) [1982374]
- driver core: platform: Introduce platform_get_mem_or_io() (Mark Langsdorf) [1982374]
- soc: fix comment for freeing soc_dev_attr (Mark Langsdorf) [1982374]
- driver core: platform: use bus_type functions (Mark Langsdorf) [1982374]
- driver core: platform: change logic implementing platform_driver_probe (Mark Langsdorf) [1982374]
- driver core: platform: reorder functions (Mark Langsdorf) [1982374]
- driver core: make driver_probe_device() static (Mark Langsdorf) [1982374]
- driver core: Fix a couple of typos (Mark Langsdorf) [1982374]
- driver core: Refactor fw_devlink feature (Mark Langsdorf) [1982374]
- efi: Update implementation of add_links() to create fwnode links (Mark Langsdorf) [1982374]
- of: property: Update implementation of add_links() to create fwnode links (Mark Langsdorf) [1982374]
- driver core: Use device's fwnode to check if it is waiting for suppliers (Mark Langsdorf) [1982374]
- driver core: Add fw_devlink_parse_fwtree() (Mark Langsdorf) [1982374]
- driver core: Redefine the meaning of fwnode_operations.add_links() (Mark Langsdorf) [1982374]
- device property: Add fwnode_is_ancestor_of() and fwnode_get_next_parent_dev() (Mark Langsdorf) [1982374]
- driver core: Allow only unprobed consumers for SYNC_STATE_ONLY device links (Mark Langsdorf) [1982374]
- driver core: Add fwnode link support (Mark Langsdorf) [1982374]
- driver core: Add fwnode_init() (Mark Langsdorf) [1982374]
- Revert "[base] driver core: fw_devlink: Add support for batching fwnode parsing" (Mark Langsdorf) [1982374]
- Revert "[base] driver core: Remove check in driver_deferred_probe_force_trigger()" (Mark Langsdorf) [1982374]
- Revert "[base] driver core: Don't do deferred probe in parallel with kernel_init thread" (Mark Langsdorf) [1982374]
- Revert "[base] driver core: Rename dev_links_info.defer_sync to defer_hook" (Mark Langsdorf) [1982374]
- Revert "[base] driver core: Avoid deferred probe due to fw_devlink_pause/resume()" (Mark Langsdorf) [1982374]
- regmap: Remove duplicate `type` field from regmap `regcache_sync` trace event (Mark Langsdorf) [1982374]
- PM: sleep: Add dev_wakeup_path() helper (Mark Langsdorf) [1982374]
- regmap: Fix order of regmap write log (Mark Langsdorf) [1982374]
- regmap: use less #ifdef for LOG_DEVICE (Mark Langsdorf) [1982374]
- PM: domains: Enable dev_pm_genpd_suspend|resume() for suspend-to-idle (Mark Langsdorf) [1982374]
- PM: domains: Rename pm_genpd_syscore_poweroff|poweron() (Mark Langsdorf) [1982374]
- PM: sleep: Print driver flags for all devices during suspend/resume (Mark Langsdorf) [1982374]
- driver core: Fix lockdep warning on wfs_lock (Mark Langsdorf) [1982374]
- regmap: irq: Convert to use irq_domain_create_legacy() (Mark Langsdorf) [1982374]
- irqdomain: Introduce irq_domain_create_legacy() API (Mark Langsdorf) [1982374]
- irqdomain: Replace open coded of_node_to_fwnode() (Mark Langsdorf) [1982374]
- irqdomain: Add forward declaration of fwnode_handle (Mark Langsdorf) [1982374]
- irqdomain: Remove unused of_device_id forward declaration (Mark Langsdorf) [1982374]
- regmap-irq: use fwnode instead of device node in add_irq_chip() (Mark Langsdorf) [1982374]
- regmap: mmio: add config option to allow relaxed MMIO accesses (Mark Langsdorf) [1982374]
- PM: sleep: remove unreachable break (Mark Langsdorf) [1982374]
- PM: domains: enable domain idle state accounting (Mark Langsdorf) [1982374]
- PM: domains: Add curly braces to delimit comment + statement block (Mark Langsdorf) [1982374]
- PM: domains: Add support for PM domain on/off notifiers for genpd (Mark Langsdorf) [1982374]
- PM / Domains: Simplify genpd_lookup_dev() (Mark Langsdorf) [1982374]
- regmap: irq: Add support to clear ack registers (Mark Langsdorf) [1982374]
- PM: domains: Allow to abort power off when no ->power_off() callback (Mark Langsdorf) [1982374]
- PM: domains: Rename power state enums for genpd (Mark Langsdorf) [1982374]
- regmap: debugfs: use semicolons rather than commas to separate statements (Mark Langsdorf) [1982374]
- drivers core: node: Use a more typical macro definition style for ACCESS_ATTR (Mark Langsdorf) [1982374]
- drivers core: Use sysfs_emit for shared_cpu_map_show and shared_cpu_list_show (Mark Langsdorf) [1982374]
- efi: Rename arm-init to efi-init common for all arch (Mark Langsdorf) [1982374]
- efi/arm: Defer probe of PCIe backed efifb on DT systems (Mark Langsdorf) [1982374]
- net/smc: improved fix wait on already cleared link (Sumanth Korikkar) [1984991]
- net/smc: fix 'workqueue leaked lock' in smc_conn_abort_work (Sumanth Korikkar) [1984991]
- net/smc: add missing error check in smc_clc_prfx_set() (Sumanth Korikkar) [1984991]
- net/smc: Correct smc link connection counter in case of smc client (Sumanth Korikkar) [1984991]
- net/smc: fix wait on already cleared link (Sumanth Korikkar) [1984991]
- KVM: s390: Fix handle_sske page fault handling (Thomas Huth) [2022731]
- KVM: s390: Simplify SIGP Set Arch handling (Thomas Huth) [2022731]
- KVM: s390: pv: avoid stalls when making pages secure (Thomas Huth) [2022731]
- KVM: s390: pv: avoid stalls for kvm_s390_pv_init_vm (Thomas Huth) [2022731]
- KVM: s390: pv: avoid double free of sida page (Thomas Huth) [2022731]
- KVM: s390: pv: add macros for UVC CC values (Thomas Huth) [2022731]
- s390/uv: fully validate the VMA before calling follow_page() (Thomas Huth) [2022731]
- s390/gmap: don't unconditionally call pte_unmap_unlock() in __gmap_zap() (Thomas Huth) [2022731]
- s390/gmap: validate VMA in __gmap_zap() (Thomas Huth) [2022731]
- KVM: s390: preserve deliverable_mask in __airqs_kick_single_vcpu (Thomas Huth) [2022731]
- KVM: s390: clear kicked_mask before sleeping again (Thomas Huth) [2022731]
- KVM: s390: Function documentation fixes (Thomas Huth) [2022731]
- s390/mm: fix kernel doc comments (Thomas Huth) [2022731]
- KVM: s390: index kvm->arch.idle_mask by vcpu_idx (Thomas Huth) [2022731]
- KVM: s390: generate kvm hypercall functions (Thomas Huth) [2022731]
- KVM: Rename lru_slot to last_used_slot (Thomas Huth) [2022731]
- s390: mm: Fix secure storage access exception handling (Thomas Huth) [2022731]
- virtio/s390: get rid of open-coded kvm hypercall (Thomas Huth) [2022731]
- KVM: s390: get rid of register asm usage (Thomas Huth) [2022731]
- powerpc/vas: Fix potential NULL pointer dereference (Steve Best) [1907522]
- powerpc/pseries/vas: Declare pseries_vas_fault_thread_fn() as static (Steve Best) [1907522]
- crypto/nx: Register and unregister VAS interface on PowerVM (Steve Best) [1907522]
- crypto/nx: Add sysfs interface to export NX capabilities (Steve Best) [1907522]
- crypto/nx: Get NX capabilities for GZIP coprocessor type (Steve Best) [1907522]
- crypto/nx: Rename nx-842-pseries file name to nx-common-pseries (Steve Best) [1907522]
- powerpc/pseries/vas: Setup IRQ and fault handling (Steve Best) [1907522]
- powerpc/pseries/vas: Integrate API with open/close windows (Steve Best) [1907522]
- powerpc/pseries/vas: Implement getting capabilities from hypervisor (Steve Best) [1907522]
- powerpc/pseries/vas: Add hcall wrappers for VAS handling (Steve Best) [1907522]
- powerpc/vas: Define QoS credit flag to allocate window (Steve Best) [1907522]
- powerpc/pseries/vas: Define VAS/NXGZIP hcalls and structs (Steve Best) [1907522]
- powerpc/vas: Define and use common vas_window struct (Steve Best) [1907522]
- powerpc/powernv: no need to check return value of debugfs_create functions (Steve Best) [1907522]
- powerpc/vas: Move update_csb/dump_crb to common book3s platform (Steve Best) [1907522]
- powerpc/vas: Create take/drop pid and mm reference functions (Steve Best) [1907522]
- powerpc/vas: Add platform specific user window operations (Steve Best) [1907522]
- powerpc/powernv/vas: Rename register/unregister functions (Steve Best) [1907522]
- powerpc/vas: Move VAS API to book3s common platform (Steve Best) [1907522]
- powerpc/powernv/vas: Release reference to tgid during window close (Steve Best) [1907522]
- powerpc/pseries: Prevent free CPU ids being reused on another node (Desnes A. Nunes do Rosario) [2004808]
- powerpc/numa: Consider the max NUMA node for migratable LPAR (Desnes A. Nunes do Rosario) [2004808]

* Thu Nov 25 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-353.el8]
- zram: replace fsync_bdev with sync_blockdev (Ming Lei) [2015755]
- zram: avoid race between zram_remove and disksize_store (Ming Lei) [2015755]
- zram: don't fail to remove zram during unloading module (Ming Lei) [2015755]
- zram: fix race between zram_reset_device() and disksize_store() (Ming Lei) [2015755]
- zram: register default groups with device_add_disk() (Ming Lei) [2015755]
- hyperv/vmbus: include linux/bitops.h (Mohammed Gamal) [2008565]
- hv: vmbus: Avoid -Werror=maybe-uninitialized error (Mohammed Gamal) [2008565]
- Drivers: hv: vmbus: Fix kernel crash upon unbinding a device from uio_hv_generic driver (Mohammed Gamal) [2008565]
- Drivers: hv: vmbus: Fix duplicate CPU assignments within a device (Mohammed Gamal) [2008565]
- drivers: hv: Fix missing error code in vmbus_connect() (Mohammed Gamal) [2008565]
- hv_utils: Fix passing zero to 'PTR_ERR' warning (Mohammed Gamal) [2008565]
- ice: Fix VF true promiscuous mode (Jonathan Toppins) [1970643]
- ice: Remove toggling of antispoof for VF trusted promiscuous mode (Jonathan Toppins) [1970643]
- ice: Fix replacing VF hardware MAC to existing MAC filter (Jonathan Toppins) [1970643]
- ice: Fix not stopping Tx queues for VFs (Jonathan Toppins) [1970643]
- ice: Fix race conditions between virtchnl handling and VF ndo ops (Jonathan Toppins) [1970643]
- ice: move ice_container_type onto ice_ring_container (Jonathan Toppins) [1970643]
- ice: remove ring_active from ice_ring (Jonathan Toppins) [1970643]
- ice: Print the api_patch as part of the fw.mgmt.api (Jonathan Toppins) [1970643]
- ice: Avoid crash from unnecessary IDA free (Jonathan Toppins) [1970643]
- ice: Fix failure to re-add LAN/RDMA Tx queues (Jonathan Toppins) [1970643]
- ice: Add missing E810 device ids (Jonathan Toppins) [1970643]
- ice: fix locking for Tx timestamp tracking flush (Jonathan Toppins) [1970643]
- ice: Delete always true check of PF pointer (Jonathan Toppins) [1970643]
- ice: Correctly deal with PFs that do not support RDMA (Jonathan Toppins) [1970643]
- ice: add lock around Tx timestamp tracker flush (Jonathan Toppins) [1970643]
- ice: remove dead code for allocating pin_config (Jonathan Toppins) [1970643]
- ice: do not abort devlink info if board identifier can't be found (Jonathan Toppins) [1970643]
- ice: Fix a memory leak in an error handling path in 'ice_pf_dcb_cfg()' (Jonathan Toppins) [1970643]
- ice: remove unnecessary VSI assignment (Jonathan Toppins) [1970643]
- ice: remove the VSI info from previous agg (Jonathan Toppins) [1970643]
- ice: add tracepoints (Jonathan Toppins) [1970643]
- ice: report hash type such as L2/L3/L4 (Jonathan Toppins) [1970643]
- ice: remove redundant continue statement in a for-loop (Jonathan Toppins) [1970643]
- net: ice: ptp: fix compilation warning if PTP_1588_CLOCK is disabled (Jonathan Toppins) [1970643]
- ice: remove unnecessary NULL checks before ptp_read_system_* (Jonathan Toppins) [1970643]
- ice: Remove the repeated declaration (Jonathan Toppins) [1970643]
- ice: remove local variable (Jonathan Toppins) [1970643]
- ice: reduce scope of variables (Jonathan Toppins) [1970643]
- ice: mark PTYPE 2 as reserved (Jonathan Toppins) [1970643]
- ice: fix incorrect payload indicator on PTYPE (Jonathan Toppins) [1970643]
- ice: parameterize functions responsible for Tx ring management (Jonathan Toppins) [1970643]
- ice: add ndo_bpf callback for safe mode netdev ops (Jonathan Toppins) [1970643]
- ice: fix clang warning regarding deadcode.DeadStores (Jonathan Toppins) [1970643]
- ice: downgrade error print to debug print (Jonathan Toppins) [1970643]
- ice: Detect and report unsupported module power levels (Jonathan Toppins) [1970643]
- ice: (re)initialize NVM fields when rebuilding (Jonathan Toppins) [1970643]
- ice: wait for reset before reporting devlink info (Jonathan Toppins) [1970643]
- ice: add error message when pldmfw_flash_image fails (Jonathan Toppins) [1970643]
- ice: add extack when unable to read device caps (Jonathan Toppins) [1970643]
- ice: use static inline for dummy functions (Jonathan Toppins) [1970643]
- ice: Re-organizes reqstd/avail {R, T}XQ check/code for efficiency (Jonathan Toppins) [1970643]
- ice: set the value of global config lock timeout longer (Jonathan Toppins) [1970643]
- ice: Refactor VIRTCHNL_OP_CONFIG_VSI_QUEUES handling (Jonathan Toppins) [1970643]
- ice: Refactor ice_setup_rx_ctx (Jonathan Toppins) [1970643]
- ice: Save VF's MAC across reboot (Jonathan Toppins) [1970643]
- ice: Manage VF's MAC address for both legacy and new cases (Jonathan Toppins) [1970643]
- ice: Register auxiliary device to provide RDMA (Jonathan Toppins) [1970643]
- ice: Implement iidc operations (Jonathan Toppins) [1970643]
- virtchnl: Use pad byte in virtchnl_ether_addr to specify MAC type (Jonathan Toppins) [1970643]
- iidc: Introduce iidc.h (Jonathan Toppins) [1970643]
- ice: Initialize RDMA support (Jonathan Toppins) [1970643]
- ice: Respond to a NETDEV_UNREGISTER event for LAG (Jonathan Toppins) [1970643]
- Revert "Revert "ice: Add initial support framework for LAG"" (Jonathan Toppins) [1970643]
- ice: reduce scope of variable (Jonathan Toppins) [1970643]
- ice: remove return variable (Jonathan Toppins) [1970643]
- ice: suppress false cppcheck issues (Jonathan Toppins) [1970643]
- ice: Set vsi->vf_id as ICE_INVAL_VFID for non VF VSI types (Jonathan Toppins) [1970643]
- ice: remove unused struct member (Jonathan Toppins) [1970643]
- ice: use local for consistency (Jonathan Toppins) [1970643]
- ice: print name in /proc/iomem (Jonathan Toppins) [1970643]
- ice: Reimplement module reads used by ethtool (Jonathan Toppins) [1970643]
- ice: refactor ITR data structures (Jonathan Toppins) [1970643]
- ice: manage interrupts during poll exit (Jonathan Toppins) [1970643]
- ice: replace custom AIM algorithm with kernel's DIM library (Jonathan Toppins) [1970643]
- ice: refactor interrupt moderation writes (Jonathan Toppins) [1970643]
- ice: Add new VSI states to track netdev alloc/registration (Jonathan Toppins) [1970643]
- ice: Drop leading underscores in enum ice_pf_state (Jonathan Toppins) [1970643]
- ice: use kernel definitions for IANA protocol ports and ether-types (Jonathan Toppins) [1970643]
- ice: Remove unnecessary blank line (Jonathan Toppins) [1970643]
- ice: Remove unnecessary checks in add/kill_vid ndo ops (Jonathan Toppins) [1970643]
- ice: Remove rx_gro_dropped stat (Jonathan Toppins) [1970643]
- ice: Use local variable instead of pointer derefs (Jonathan Toppins) [1970643]
- ice: Remove unnecessary variable (Jonathan Toppins) [1970643]
- ice: Limit forced overrides based on FW version (Jonathan Toppins) [1970643]
- ice: Use default configuration mode for PHY configuration (Jonathan Toppins) [1970643]
- ice: Replace some memsets and memcpys with assignment (Jonathan Toppins) [1970643]
- ice: Fix error return codes in ice_set_link_ksettings (Jonathan Toppins) [1970643]
- ice: Rename a couple of variables (Jonathan Toppins) [1970643]
- ice: Remove unnecessary checker loop (Jonathan Toppins) [1970643]
- ice: Ignore EMODE return for opcode 0x0605 (Jonathan Toppins) [1970643]
- ice: Align macro names to the specification (Jonathan Toppins) [1970643]
- ice: Modify recursive way of adding nodes (Jonathan Toppins) [1970643]
- ice: Re-send some AQ commands, as result of EBUSY AQ error (Jonathan Toppins) [1970643]
- ice: Correct comment block style (Jonathan Toppins) [1970643]
- ice: cleanup style issues (Jonathan Toppins) [1970643]
- ice: rename ptype bitmap (Jonathan Toppins) [1970643]
- ice: correct memory allocation call (Jonathan Toppins) [1970643]
- ice: Check for bail out condition early (Jonathan Toppins) [1970643]
- ice: remove unnecessary duplicated AQ command flag setting (Jonathan Toppins) [1970643]
- ice: change link misconfiguration message (Jonathan Toppins) [1970643]
- ice: Update to use package info from ice segment (Jonathan Toppins) [1970643]
- ice: Delay netdev registration (Jonathan Toppins) [1970643]
- ice: Add Support for XPS (Jonathan Toppins) [1970643]
- ice: Fix fall-through warnings for Clang (Jonathan Toppins) [1970643]
- ice: Fix prototype warnings (Jonathan Toppins) [1970643]
- ice: move headroom initialization to ice_setup_rx_ctx (Jonathan Toppins) [1970643]
- ice: store the result of ice_rx_offset() onto ice_ring (Jonathan Toppins) [1970643]
- sched/core: Mitigate race cpus_share_cache()/update_top_cache_domain() (Phil Auld) [2011436]
- sched/fair: Prevent dead task groups from regaining cfs_rq's (Phil Auld) [2011436]
- sched/fair: Removed useless update of p->recent_used_cpu (Phil Auld) [2011436]
- sched: Always inline is_percpu_thread() (Phil Auld) [2011436]
- sched/fair: Add ancestors of unthrottled undecayed cfs_rq (Phil Auld) [2011436]
- sched: Remove unused inline function __rq_clock_broken() (Phil Auld) [2011436]
- sched: Prevent balance_push() on remote runqueues (Phil Auld) [2011436]
- cpumask/hotplug: Fix cpu_dying() state tracking (Phil Auld) [2011436]
- sched: Use cpu_dying() to fix balance_push vs hotplug-rollback (Phil Auld) [2011436]
- cpumask: Introduce DYING mask (Phil Auld) [2011436]
- cpumask: Make cpu_{online,possible,present,active}() inline (Phil Auld) [2011436]
- cpu/hotplug: Cache number of online CPUs (Phil Auld) [2011436]
- sched: Switch wait_task_inactive to HRTIMER_MODE_REL_HARD (Phil Auld) [2011436]
- psi: Fix race between psi_trigger_create/destroy (Phil Auld) [2011436]
- sctp: add vtag check in sctp_sf_ootb (Xin Long) [2001767]
- sctp: add vtag check in sctp_sf_do_8_5_1_E_sa (Xin Long) [2001767]
- sctp: add vtag check in sctp_sf_violation (Xin Long) [2001767]
- sctp: fix the processing for COOKIE_ECHO chunk (Xin Long) [2001767]
- sctp: fix the processing for INIT_ACK chunk (Xin Long) [2001767]
- sctp: fix the processing for INIT chunk (Xin Long) [2001767]
- sctp: use init_tag from inithdr for ABORT chunk (Xin Long) [2001767]

* Mon Nov 22 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-352.el8]
- KVM: arm64: Extract ESR_ELx.EC only (Gavin Shan) [2008070]
- KVM: arm64: vgic-v3: Align emulated cpuif LPI state machine with the pseudocode (Gavin Shan) [2008070]
- KVM: arm64: vgic-v3: Don't advertise ICC_CTLR_EL1.SEIS (Gavin Shan) [2008070]
- KVM: arm64: Fix reporting of endianess when the access originates at EL0 (Gavin Shan) [2008070]
- KVM: arm64: Trim guest debug exception handling (Gavin Shan) [2008070]
- KVM: arm64: Upgrade VMID accesses to {READ,WRITE}_ONCE (Gavin Shan) [2008070]
- KVM: arm64: vgic: Drop WARN from vgic_get_irq (Gavin Shan) [2008070]
- KVM: arm64: Enforce reserved bits for PSCI target affinities (Gavin Shan) [2008070]
- KVM: arm64: Handle PSCI resets before userspace touches vCPU state (Gavin Shan) [2008070]
- KVM: arm64: Fix read-side race on updates to vcpu reset state (Gavin Shan) [2008070]
- KVM: arm64: Restore PMU configuration on first run (Gavin Shan) [2008070]
- KVM: arm64: Don't zero the cycle count register when PMCR_EL0.P is set (Gavin Shan) [2008070]
- KVM: arm64: Prevent mixed-width VM creation (Gavin Shan) [2008070]
- KVM: arm64: Fix debug register indexing (Gavin Shan) [2008070]
- KVM: arm64: Reject VM creation when the default IPA size is unsupported (Gavin Shan) [2008070]
- KVM: arm64: Limit the debug architecture to ARMv8.0 (Gavin Shan) [2008070]
- KVM: arm64: Handle SCXTNUM_ELx traps (Gavin Shan) [2008070]
- arm64: kvm: mte: Hide the MTE CPUID information from the guests (Gavin Shan) [2008070]
- arm64: mte: Fix typo in macro definition (Gavin Shan) [2008070]
- arm64/cpufeature: Add remaining feature bits in ID_AA64PFR1 register (Gavin Shan) [2008070]
- arm64: mte: system register definitions (Gavin Shan) [2008070]
- arm64: sysreg: Clean up instructions for modifying PSTATE fields (Gavin Shan) [2008070]
- KVM: arm64: Only reschedule if MMU_NOTIFIER_RANGE_BLOCKABLE is not set (Gavin Shan) [2008070]
- arm64: kvm: Fix IDMAP overlap with HYP VA (Gavin Shan) [2008070]
- packet: rework packet_pick_tx_queue() to use common code selection (Petr Oros) [2016477]
- net: dev: rename queue selection helpers. (Petr Oros) [2016477]
- Revert "cpuset: Make cpuset hotplug synchronous" (Waiman Long) [2023783]
- tcp: fix TLP timer not set when CA_STATE changes from DISORDER to OPEN (Paolo Abeni) [2018546]
- net: Only allow init netns to set default tcp cong to a restricted algo (Paolo Abeni) [2018546]
- ipv6: tcp: drop silly ICMPv6 packet too big messages (Paolo Abeni) [2018546]
- tcp: annotate data races around tp->mtu_info (Paolo Abeni) [2018546]
- net: send SYNACK packet with accepted fwmark (Paolo Abeni) [2018546]
- tcp: call sk_wmem_schedule before sk_mem_charge in zerocopy path (Paolo Abeni) [2018546]
- net/tcp_fastopen: fix data races around tfo_active_disable_stamp (Paolo Abeni) [2018546]
- net/tcp_fastopen: remove obsolete extern (Paolo Abeni) [2018546]
- net, gro: Set inner transport header offset in tcp/udp GRO hook (Paolo Abeni) [2018546]
- tcp_bbr: fix u32 wrap bug in round logic if bbr_init() called after 2B packets (Paolo Abeni) [2018546]
- tcp: seq_file: Avoid skipping sk during tcp_seek_last_pos (Paolo Abeni) [2018546]
- tcp: fix tp->undo_retrans accounting in tcp_sacktag_one() (Paolo Abeni) [2018546]
- evm: mark evm_fixmode as __ro_after_init (Bruno Meneguele) [2017155]
- IMA: remove -Wmissing-prototypes warning (Bruno Meneguele) [2017155]
- ima: Set correct casting types (Bruno Meneguele) [2017155]
- evm: Don't return an error in evm_write_xattrs() if audit is not enabled (Bruno Meneguele) [2017155]
- evm: fix writing <securityfs>/evm overflow (Bruno Meneguele) [2017155]
- ima: Fix function name error in comment. (Bruno Meneguele) [2017155]
- ima: Fix the error code for restoring the PCR value (Bruno Meneguele) [2017155]
- integrity: double check iint_cache was initialized (Bruno Meneguele) [2017155]
- certs: Fix blacklist flag type confusion (Bruno Meneguele) [2017155]
- integrity: Make function integrity_add_key() static (Bruno Meneguele) [2017155]
- ima: Free IMA measurement buffer after kexec syscall (Bruno Meneguele) [2017155]
- ima: Free IMA measurement buffer on error (Bruno Meneguele) [2017155]
- evm: Fix memleak in init_desc (Bruno Meneguele) [2017155]
- crypto: shash - remove shash_desc::flags (Bruno Meneguele) [2017155]
- ima: Don't modify file descriptor mode on the fly (Bruno Meneguele) [2017155]
- evm: Check size of security.evm before using it (Bruno Meneguele) [2017155]
- ima: Remove semicolon at the end of ima_get_binary_runtime_size() (Bruno Meneguele) [2017155]
- ima: Don't ignore errors from crypto_shash_update() (Bruno Meneguele) [2017155]
- integrity: remove redundant initialization of variable ret (Bruno Meneguele) [2017155]
- ima: Fail rule parsing when appraise_flag=blacklist is unsupportable (Bruno Meneguele) [2017155]
- ima: Fail rule parsing when the KEXEC_CMDLINE hook is combined with an invalid cond (Bruno Meneguele) [2017155]
- ima: Fail rule parsing when buffer hook functions have an invalid action (Bruno Meneguele) [2017155]
- ima: Free the entire rule if it fails to parse (Bruno Meneguele) [2017155]
- ima: Free the entire rule when deleting a list of rules (Bruno Meneguele) [2017155]
- evm: Fix possible memory leak in evm_calc_hmac_or_hash() (Bruno Meneguele) [2017155]
- ima: Fix ima digest hash table key calculation (Bruno Meneguele) [2017155]
- ima: Fix return value of ima_write_policy() (Bruno Meneguele) [2017155]
- evm: Fix a small race in init_desc() (Bruno Meneguele) [2017155]
- crypto: drop mask=CRYPTO_ALG_ASYNC from 'shash' tfm allocations (Bruno Meneguele) [2017155]
- evm: Don't deadlock if a crypto algorithm is unavailable (Bruno Meneguele) [2017155]
- evm: Check also if *tfm is an error pointer in init_desc() (Bruno Meneguele) [2017155]
- ima: avoid appraise error for hash calc interrupt (Bruno Meneguele) [2017155]
- integrity: remove pointless subdir-$(CONFIG_...) (Bruno Meneguele) [2017155]
- integrity: remove unneeded, broken attempt to add -fshort-wchar (Bruno Meneguele) [2017155]
- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL (Vitaly Kuznetsov) [2016961]
- fs/xfs: convert comma to semicolon (Bill O'Donnell) [2009521]
- xfs: remove xfs_buf_t typedef (Bill O'Donnell) [2009521]
- xfs: open code updating i_mode in xfs_set_acl (Bill O'Donnell) [2009521]
- xfs: remove xfs_vn_setattr_nonsize (Bill O'Donnell) [2009521]
- xfs: remove unneeded return value check for *init_cursor() (Bill O'Donnell) [2009521]
- xfs: introduce xfs_validate_stripe_geometry() (Bill O'Donnell) [2009521]
- xfs: show the proper user quota options (Bill O'Donnell) [2009521]
- xfs: remove the unused XFS_B_FSB_OFFSET macro (Bill O'Donnell) [2009521]
- xfs: remove unnecessary null check in xfs_generic_create (Bill O'Donnell) [2009521]
- xfs: directly return if the delta equal to zero (Bill O'Donnell) [2009521]
- xfs: delete duplicated tp->t_dqinfo null check and allocation (Bill O'Donnell) [2009521]
- xfs: rename xfs_fc_* back to xfs_fs_* (Bill O'Donnell) [2009521]
- xfs: refactor file range validation (Bill O'Donnell) [2009521]
- xfs: refactor realtime volume extent validation (Bill O'Donnell) [2009521]
- xfs: refactor data device extent validation (Bill O'Donnell) [2009521]
- xfs: scrub should mark a directory corrupt if any entries cannot be iget'd (Bill O'Donnell) [2009521]
- xfs: detect overflows in bmbt records (Bill O'Donnell) [2009521]
- xfs: trace log intent item recovery failures (Bill O'Donnell) [2009521]
- xfs: validate feature support when recovering rmap/refcount intents (Bill O'Donnell) [2009521]
- xfs: improve the code that checks recovered extent-free intent items (Bill O'Donnell) [2009521]
- xfs: hoist recovered extent-free intent checks out of xfs_efi_item_recover (Bill O'Donnell) [2009521]
- xfs: improve the code that checks recovered refcount intent items (Bill O'Donnell) [2009521]
- xfs: hoist recovered refcount intent checks out of xfs_cui_item_recover (Bill O'Donnell) [2009521]
- xfs: improve the code that checks recovered rmap intent items (Bill O'Donnell) [2009521]
- xfs: hoist recovered rmap intent checks out of xfs_rui_item_recover (Bill O'Donnell) [2009521]
- xfs: improve the code that checks recovered bmap intent items (Bill O'Donnell) [2009521]
- xfs: hoist recovered bmap intent checks out of xfs_bui_item_recover (Bill O'Donnell) [2009521]
- xfs: move kernel-specific superblock validation out of libxfs (Bill O'Donnell) [2009521]
- platform/x86: amd-pmc: Increase the response register timeout (David Arcari) [2005064]
- ARM: 9093/1: drivers: firmwapsci: Register with kernel restart handler (Mark Salter) [1996748]
- arm64/kernel: Remove needless Call Frame Information annotations (Mark Salter) [1996748]
- arm64: smccc: Add support for SMCCCv1.2 extended input/output registers (Mark Salter) [1996748]
- psci: Remove unneeded semicolon (Mark Salter) [1996748]
- firmware: smccc: Add SMCCC TRNG function call IDs (Mark Salter) [1996748]
- arm64: Add support for SMCCC TRNG entropy source (Mark Salter) [1996748]
- firmware: smccc: Introduce SMCCC TRNG framework (Mark Salter) [1996748]
- arm64: random: Remove no longer needed prototypes (Mark Salter) [1996748]
- arm64: kaslr: Use standard early random function (Mark Salter) [1996748]
- random: random.h should include archrandom.h, not the other way around (Mark Salter) [1996748]
- arm64: add credited/trusted RNG support (Mark Salter) [1996748]
- arm64: Use v8.5-RNG entropy for KASLR seed (Mark Salter) [1996748]
- arm64: kaslr: Check command line before looking for a seed (Mark Salter) [1996748]
- arm64: kaslr: Announce KASLR status on boot (Mark Salter) [1996748]
- psci: Add accessor for psci_0_1_function_ids (Mark Salter) [1996748]
- psci: Replace psci_function_id array with a struct (Mark Salter) [1996748]
- psci: Split functions to v0.1 and v0.2+ variants (Mark Salter) [1996748]
- psci: Support psci_ops.get_version for v0.1 (Mark Salter) [1996748]
- arm64: psci: Avoid printing in cpu_psci_cpu_die() (Mark Salter) [1996748]
- firmware: psci: Extend psci_set_osi_mode() to allow reset to PC mode (Mark Salter) [1996748]
- smccc: Use separate variables for args and results (Mark Salter) [1996748]
- smccc: Define vendor hyp owned service call region (Mark Salter) [1996748]
- firmware: smccc: Export both smccc functions (Mark Salter) [1996748]
- sched,psci: Convert to sched_set_fifo*() (Mark Salter) [1996748]
- firmware: smccc: Add ARCH_SOC_ID support (Mark Salter) [1996748]
- base: soc: Add serial_number attribute to soc (Mark Salter) [1996748]
- drivers/firmware/psci: Assign @err directly in hotplug_tests() (Mark Salter) [1996748]
- drivers/firmware/psci: Fix memory leakage in alloc_init_cpu_groups() (Mark Salter) [1996748]
- firmware: smccc: Fix missing prototype warning for arm_smccc_version_init (Mark Salter) [1996748]
- firmware: smccc: Add function to fetch SMCCC version (Mark Salter) [1996748]
- firmware: smccc: Refactor SMCCC specific bits into separate file (Mark Salter) [1996748]
- firmware: smccc: Drop smccc_version enum and use ARM_SMCCC_VERSION_1_x instead (Mark Salter) [1996748]
- firmware: smccc: Add HAVE_ARM_SMCCC_DISCOVERY to identify SMCCC v1.1 and above (Mark Salter) [1996748]
- firmware: psci: Replace cpu_up/down() with add/remove_cpu() (Mark Salter) [1996748]
- firmware: psci: Export functions to manage the OSI mode (Mark Salter) [1996748]
- arm64: psci: Reduce the waiting time for cpu_psci_cpu_kill() (Mark Salter) [1996748]
- firmware/psci: use common SMCCC_CONDUIT_* (Mark Salter) [1996748]
- arm64: smp: disable hotplug on trusted OS resident CPU (Mark Salter) [1996748]
- PSCI: cpuidle: Refactor CPU suspend power_state parameter handling (Mark Salter) [1996748]
- ARM: psci: cpuidle: Enable PSCI CPUidle driver (Mark Salter) [1996748]
- drivers: firmware: psci: Decouple checker from generic ARM CPUidle (Mark Salter) [1996748]
- firmware/psci: psci_checker: Park kthreads before stopping them (Mark Salter) [1996748]
- firmware/psci: add support for SYSTEM_RESET2 (Mark Salter) [1996748]
- drivers: firmware: psci: Announce support for OS initiated suspend mode (Mark Salter) [1996748]
- drivers: firmware: psci: Simplify error path of psci_dt_init() (Mark Salter) [1996748]
- drivers: firmware: psci: Split psci_dt_cpu_init_idle() (Mark Salter) [1996748]
- drivers: firmware: psci: Move psci to separate directory (Mark Salter) [1996748]
- arm64: remove unused asm/compiler.h header file (Mark Salter) [1996748]
- ppc64: Adding read_lock definition to nvme (Gopal Tiwari) [1990475]
- nvme: fix per-namespace chardev deletion (Gopal Tiwari) [1990475]
- nvme: set the PRACT bit when using Write Zeroes with T10 PI (Gopal Tiwari) [1990475]
- nvme: fix nvme_setup_command metadata trace event (Gopal Tiwari) [1990475]
- nvme-pci: don't WARN_ON in nvme_reset_work if ctrl.state is not RESETTING (Gopal Tiwari) [1990475]
- nvme: fix refcounting imbalance when all paths are down (Gopal Tiwari) [1990475]
- nvme-pci: do not call nvme_dev_remove_admin from nvme_remove (Gopal Tiwari) [1990475]
- nvme-pci: fix multiple races in nvme_setup_io_queues (Gopal Tiwari) [1990475]
- nvme-tcp: use __dev_get_by_name instead dev_get_by_name for OPT_HOST_IFACE (Gopal Tiwari) [1990475]
- nvme-tcp: can't set sk_user_data without write_lock (Gopal Tiwari) [1990475]
- nvme: use blk_execute_rq() for passthrough commands (Gopal Tiwari) [1990475]
- nvmet: use NVMET_MAX_NAMESPACES to set nn value (Gopal Tiwari) [1990475]
- nvme-pci: remove zeroout memset call for struct (Gopal Tiwari) [1990475]
- nvme: remove zeroout memset call for struct (Gopal Tiwari) [1990475]
- nvmet: add ZBD over ZNS backend support (Gopal Tiwari) [1990475]
- nvmet: remove zeroout memset call for struct (Gopal Tiwari) [1990475]
- nvmet: use req->cmd directly in file-ns fast path (Gopal Tiwari) [1990475]
- nvmet: add Command Set Identifier support (Gopal Tiwari) [1990475]
- nvmet: add nvmet_req_bio put helper for backends (Gopal Tiwari) [1990475]
- nvmet: use nvme status value directly (Gopal Tiwari) [1990475]
- nvmet: use u32 for nvmet_subsys max_nsid (Gopal Tiwari) [1990475]
- nvmet: remove local variable (Gopal Tiwari) [1990475]
- nvmet: add req cns error complete helper (Gopal Tiwari) [1990475]
- nvmet: use req->cmd directly in bdev-ns fast path (Gopal Tiwari) [1990475]
- nvmet: use u32 type for the local variable nsid (Gopal Tiwari) [1990475]
- nvme-fabrics: remove memset in connect io q (Gopal Tiwari) [1990475]
- nvme-fabrics: remove memset in nvmf_reg_write32() (Gopal Tiwari) [1990475]
- nvme-fabrics: remove memset in connect admin q (Gopal Tiwari) [1990475]
- nvmet: make ver stable once connection established (Gopal Tiwari) [1990475]
- nvmet: make sn stable once connection was established (Gopal Tiwari) [1990475]
- nvmet: change sn size and check validity (Gopal Tiwari) [1990475]
- nvme-tcp: use ctrl sgl check helper (Gopal Tiwari) [1990475]
- nvmet-fc: do not check for invalid target port in nvmet_fc_handle_fcp_rqst() (Gopal Tiwari) [1990475]
- nvme-fabrics: remove memset in nvmf_reg_read64() (Gopal Tiwari) [1990475]
- nvmet: allow mn change if subsys not discovered (Gopal Tiwari) [1990475]
- nvme-fc: use ctrl sgl check helper (Gopal Tiwari) [1990475]
- nvme-pci: fix var. type for increasing cq_head (Gopal Tiwari) [1990475]
- nvme: add a helper to check ctrl sgl support (Gopal Tiwari) [1990475]
- nvme: factor out a nvme_validate_passthru_nsid helper (Gopal Tiwari) [1990475]
- nvme-tcp: fix error codes in nvme_tcp_setup_ctrl() (Gopal Tiwari) [1990475]
- nvme: fix grammar in the CONFIG_NVME_MULTIPATH kconfig help text (Gopal Tiwari) [1990475]
- nvme: verify MNAN value if ANA is enabled (Gopal Tiwari) [1990475]
- ACPI: Check StorageD3Enable _DSD property in ACPI code (Gopal Tiwari) [1990475]
- nvmet: move ka_work initialization to nvmet_alloc_ctrl (Gopal Tiwari) [1990475]
- nvme: remove nvme_{get,put}_ns_from_disk (Gopal Tiwari) [1990475]
- nvme: split nvme_report_zones (Gopal Tiwari) [1990475]
- nvmet: remove a superfluous variable (Gopal Tiwari) [1990475]
- nvme: open code nvme_put_ns_from_disk in nvme_ns_head_chr_ioctl (Gopal Tiwari) [1990475]
- nvme: move the CSI sanity check into nvme_ns_report_zones (Gopal Tiwari) [1990475]
- nvme-fabrics: remove extra braces (Gopal Tiwari) [1990475]
- nvme: open code nvme_{get,put}_ns_from_disk in nvme_ns_head_ioctl (Gopal Tiwari) [1990475]
- nvme: add a sparse annotation to nvme_ns_head_ctrl_ioctl (Gopal Tiwari) [1990475]
- nvme-fabrics: remove an extra comment (Gopal Tiwari) [1990475]
- nvme-fabrics: remove extra new lines in the switch (Gopal Tiwari) [1990475]
- nvme: open code nvme_put_ns_from_disk in nvme_ns_head_ctrl_ioctl (Gopal Tiwari) [1990475]
- nvme: extend and modify the APST configuration algorithm (Gopal Tiwari) [1990475]
- nvme-tcp: allow selecting the network interface for connections (Gopal Tiwari) [1990475]
- nvme-fabrics: fix the kerneldco comment for nvmf_log_connect_error() (Gopal Tiwari) [1990475]
- nvme: remove redundant initialization of variable ret (Gopal Tiwari) [1990475]
- nvmet: fix freeing unallocated p2pmem (Gopal Tiwari) [1990475]
- nvme-loop: reset queue count to 1 in nvme_loop_destroy_io_queues() (Gopal Tiwari) [1990475]
- nvme-loop: do not warn for deleted controllers during reset (Gopal Tiwari) [1990475]
- nvme-loop: check for NVME_LOOP_Q_LIVE in nvme_loop_destroy_admin_queue() (Gopal Tiwari) [1990475]
- nvme-loop: clear NVME_LOOP_Q_LIVE when nvme_loop_configure_admin_queue() fails (Gopal Tiwari) [1990475]
- nvme-rdma: fix in-casule data send for chained sgls (Gopal Tiwari) [1990475]
- nvmet: fix false keep-alive timeout when a controller is torn down (Gopal Tiwari) [1990475]
- nvmet-tcp: fix inline data size comparison in nvmet_tcp_queue_response (Gopal Tiwari) [1990475]
- nvme-tcp: remove incorrect Kconfig dep in BLK_DEV_NVME (Gopal Tiwari) [1990475]
- nvme-fabrics: decode host pathing error for connect (Gopal Tiwari) [1990475]
- nvme-fc: short-circuit reconnect retries (Gopal Tiwari) [1990475]
- nvme: fix potential memory leaks in nvme_cdev_add (Gopal Tiwari) [1990475]
- nvme-fc: clear q_live at beginning of association teardown (Gopal Tiwari) [1990475]
- nvme-tcp: rerun io_work if req_list is not empty (Gopal Tiwari) [1990475]
- nvme-tcp: fix possible use-after-completion (Gopal Tiwari) [1990475]
- nvme-loop: fix memory leak in nvme_loop_create_ctrl() (Gopal Tiwari) [1990475]
- nvmet: fix memory leak in nvmet_alloc_ctrl() (Gopal Tiwari) [1990475]
- nvmet: seset ns->file when open fails (Gopal Tiwari) [1990475]
- nvmet: demote fabrics cmd parse err msg to debug (Gopal Tiwari) [1990475]
- nvmet: fix inline bio check for passthru (Gopal Tiwari) [1990475]
- nvmet: fix inline bio check for bdev-ns (Gopal Tiwari) [1990475]
- nvmet: use helper to remove the duplicate code (Gopal Tiwari) [1990475]
- nvmet: demote discovery cmd parse err msg to debug (Gopal Tiwari) [1990475]
- nvmet: remove unsupported command noise (Gopal Tiwari) [1990475]
- nvme-pci: fix controller reset hang when racing with nvme_timeout (Gopal Tiwari) [1990475]
- nvme: move the fabrics queue ready check routines to core (Gopal Tiwari) [1990475]
- nvme: avoid memset for passthrough requests (Gopal Tiwari) [1990475]
- nvme: add nvme_get_ns helper (Gopal Tiwari) [1990475]
- nvme: fix controller ioctl through ns_head (Gopal Tiwari) [1990475]
- nvme: introduce generic per-namespace chardev (Gopal Tiwari) [1990475]
- nvme: cleanup nvme_configure_apst (Gopal Tiwari) [1990475]
- nvme: do not try to reconfigure APST when the controller is not live (Gopal Tiwari) [1990475]
- nvme: sanitize KATO setting (Gopal Tiwari) [1990475]
- nvmet: avoid queuing keep-alive timer if it is disabled (Gopal Tiwari) [1990475]
- nvme: fix NULL derefence in nvme_ctrl_fast_io_fail_tmo_show/store (Gopal Tiwari) [1990475]
- nvme: let namespace probing continue for unsupported features (Gopal Tiwari) [1990475]
- nvme: factor out nvme_ns_open and nvme_ns_release helpers (Gopal Tiwari) [1990475]
- nvme: move nvme_ns_head_ops to multipath.c (Gopal Tiwari) [1990475]
- nvme: factor out a nvme_tryget_ns_head helper (Gopal Tiwari) [1990475]
- nvme: move the ioctl code to a separate file (Gopal Tiwari) [1990475]
- nvme: don't bother to look up a namespace for controller ioctls (Gopal Tiwari) [1990475]
- nvme: simplify block device ioctl handling for the !multipath case (Gopal Tiwari) [1990475]
- nvme: simplify the compat ioctl handling (Gopal Tiwari) [1990475]
- nvme-multipath: remove single trailing whitespace (Gopal Tiwari) [1990475]
- nvme: pass a user pointer to nvme_nvm_ioctl (Gopal Tiwari) [1990475]
- nvme: factor out a nvme_ns_ioctl helper (Gopal Tiwari) [1990475]
- nvme: cleanup setting the disk name (Gopal Tiwari) [1990475]
- nvme: remove single trailing whitespace (Gopal Tiwari) [1990475]
- nvme-pci: remove single trailing whitespace (Gopal Tiwari) [1990475]
- nvme: add a nvme_ns_head_multipath helper (Gopal Tiwari) [1990475]
- nvmet: fix a spelling mistake "nubmer" -> "number" (Gopal Tiwari) [1990475]
- nvmet-fc: simplify nvmet_fc_alloc_hostport (Gopal Tiwari) [1990475]
- nvmet-tcp: fix a segmentation fault during io parsing error (Gopal Tiwari) [1990475]
- lightnvm: use kobj_to_dev() (Gopal Tiwari) [1990475]
- nvme: fix handling of large MDTS values (Gopal Tiwari) [1990475]
- nvme: implement non-mdts command limits (Gopal Tiwari) [1990475]
- nvme: disallow passthru cmd from targeting a nsid != nsid of the block dev (Gopal Tiwari) [1990475]
- nvme: use sysfs_emit instead of sprintf (Gopal Tiwari) [1990475]
- nvme-fc: check sgl supported by target (Gopal Tiwari) [1990475]
- nvme: remove superfluous else in nvme_ctrl_loss_tmo_store (Gopal Tiwari) [1990475]
- nvme: warn of unhandled effects only once (Gopal Tiwari) [1990475]
- nvmet-tcp: enable optional queue idle period tracking (Gopal Tiwari) [1990475]
- nvmet-tcp: fix incorrect locking in state_change sk callback (Gopal Tiwari) [1990475]
- nvme-tcp: block BH in sk state_change sk callback (Gopal Tiwari) [1990475]
- nvmet: return proper error code from discovery ctrl (Gopal Tiwari) [1990475]
- nvme-tcp: check sgl supported by target (Gopal Tiwari) [1990475]
- nvme: use driver pdu command for passthrough (Gopal Tiwari) [1990475]
- nvmet: remove unnecessary ctrl parameter (Gopal Tiwari) [1990475]
- nvmet-fc: update function documentation (Gopal Tiwari) [1990475]
- nvme-pci: allocate nvme_command within driver pdu (Gopal Tiwari) [1990475]
- nvmet: do not allow model_number exceed 40 bytes (Gopal Tiwari) [1990475]
- nvme-fc: fix the function documentation comment (Gopal Tiwari) [1990475]
- nvme: add new line after variable declatation (Gopal Tiwari) [1990475]
- nvme: don't check nvme_req flags for new req (Gopal Tiwari) [1990475]
- nvme: mark nvme_setup_passsthru() inline (Gopal Tiwari) [1990475]
- nvme: split init identify into helper (Gopal Tiwari) [1990475]
- nvme: rename nvme_init_identify() (Gopal Tiwari) [1990475]
- nvme: reduce checks for zero command effects (Gopal Tiwari) [1990475]
- nvmet: update error log page in nvmet_alloc_ctrl() (Gopal Tiwari) [1990475]
- nvmet: remove an unnecessary function parameter to nvmet_check_ctrl_status (Gopal Tiwari) [1990475]
- nvmet: remove a duplicate status assignment in nvmet_alloc_ctrl (Gopal Tiwari) [1990475]
- nvmet: replace white spaces with tabs (Gopal Tiwari) [1990475]
- nvme: use NVME_CTRL_CMIC_ANA macro (Gopal Tiwari) [1990475]
- nvme-pci: cleanup nvme_irq() (Gopal Tiwari) [1990475]
- nvme-pci: remove the barriers in nvme_irq() (Gopal Tiwari) [1990475]
- nvmet-tcp: fix kmap leak when data digest in use (Gopal Tiwari) [1990475]
- nvmet: don't check iosqes,iocqes for discovery controllers (Gopal Tiwari) [1990475]
- nvme-tcp: fix a NULL deref when receiving a 0-length r2t PDU (Gopal Tiwari) [1990475]
- nvme-rdma: fix possible hang when failing to set io queues (Gopal Tiwari) [1990475]
- nvme-tcp: fix possible hang when failing to set io queues (Gopal Tiwari) [1990475]
- nvme-fabrics: only reserve a single tag (Gopal Tiwari) [1990475]
- nvme: allocate the keep alive request using BLK_MQ_REQ_NOWAIT (Gopal Tiwari) [1990475]
- nvme: merge nvme_keep_alive into nvme_keep_alive_work (Gopal Tiwari) [1990475]
- nvme-hwmon: Return error code when registration fails (Gopal Tiwari) [1990475]
- nvme: update enumerations for status codes (Gopal Tiwari) [1990475]

* Sat Nov 20 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-351.el8]
- scsi: mpt3sas: Fix incorrectly assigned error return and check (Tomas Henzl) [1990535]
- scsi: mpt3sas: Introduce sas_ncq_prio_supported sysfs sttribute (Tomas Henzl) [1990535]
- scsi: mpt3sas: Update driver version to 39.100.00.00 (Tomas Henzl) [1990535]
- scsi: mpt3sas: Use firmware recommended queue depth (Tomas Henzl) [1990535]
- scsi: mpt3sas: Bump driver version to 38.100.00.00 (Tomas Henzl) [1990535]
- scsi: mpt3sas: Transition IOC to Ready state during shutdown (Tomas Henzl) [1990535]
- scsi: mpt3sas: Fix error return value in _scsih_expander_add() (Tomas Henzl) [1990535]
- scsi: mpt3sas: Fix Coverity reported issue (Tomas Henzl) [1990535]
- scsi: mpt3sas: Fix fall-through warnings for Clang (Tomas Henzl) [1990535]
- scsi: mpt3sas: Handle firmware faults during second half of IOC init (Tomas Henzl) [1990535]
- scsi: mpt3sas: Handle firmware faults during first half of IOC init (Tomas Henzl) [1990535]
- scsi: mpt3sas: Fix deadlock while cancelling the running firmware event (Tomas Henzl) [1990535]
- scsi: mpt3sas: Documentation cleanup (Tomas Henzl) [1990535]
- scsi: mpt3sas: Fix two kernel-doc headers (Tomas Henzl) [1990535]
- scsi: mpt3sas: Fix out-of-bounds warnings in _ctl_addnl_diag_query (Tomas Henzl) [1990535]
- scsi: megaraid_sas: Driver version update to 07.719.03.00-rc1 (Tomas Henzl) [1989643]
- scsi: megaraid_sas: Add helper functions for irq_context (Tomas Henzl) [1989643]
- scsi: megaraid: Clean up some inconsistent indenting (Tomas Henzl) [1989643]
- scsi: megaraid: Fix Coccinelle warning (Tomas Henzl) [1989643]
- IB/cma: Do not send IGMP leaves for sendonly Multicast groups (Kamal Heib) [2007269]
- hv_netvsc: Add comment of netvsc_xdp_xmit() (Mohammed Gamal) [2008560]
- hv_netvsc: use netif_is_bond_master() instead of open code (Mohammed Gamal) [2008560]
- hv_netvsc: Avoid field-overflowing memcpy() (Mohammed Gamal) [2008560]
- hv_netvsc: Set needed_headroom according to VF (Mohammed Gamal) [2008560]
- netfilter: conntrack: fix error path in nf_conntrack_pernet_init() (Florian Westphal) [1922568]
- netfilter: nf_conntrack: provide modparam to always register conntrack hooks (Florian Westphal) [1922568]
- sctp: return true only for pathmtu update in sctp_transport_pl_toobig (Xin Long) [1890383]
- sctp: subtract sctphdr len in sctp_transport_pl_hlen (Xin Long) [1890383]
- sctp: reset probe_timer in sctp_transport_pl_update (Xin Long) [1890383]
- sctp: allow IP fragmentation when PLPMTUD enters Error state (Xin Long) [1890383]
- sctp: send pmtu probe only if packet loss in Search Complete state (Xin Long) [1890383]
- sctp: improve the code for pmtu probe send and recv update (Xin Long) [1890383]
- sctp: prevent info leak in sctp_make_heartbeat() (Xin Long) [1890383]
- sctp: check pl.raise_count separately from its increment (Xin Long) [1890383]
- sctp: send the next probe immediately once the last one is acked (Xin Long) [1890383]
- sctp: do black hole detection in search complete state (Xin Long) [1890383]
- sctp: process sctp over udp icmp err on sctp side (Xin Long) [1890383]
- sctp: extract sctp_v4_err_handle function from sctp_v4_err (Xin Long) [1890383]
- sctp: extract sctp_v6_err_handle function from sctp_v6_err (Xin Long) [1890383]
- sctp: remove the unessessary hold for idev in sctp_v6_err (Xin Long) [1890383]
- sctp: enable PLPMTUD when the transport is ready (Xin Long) [1890383]
- sctp: do state transition when receiving an icmp TOOBIG packet (Xin Long) [1890383]
- sctp: do state transition when a probe succeeds on HB ACK recv path (Xin Long) [1890383]
- sctp: do state transition when PROBE_COUNT == MAX_PROBES on HB send path (Xin Long) [1890383]
- sctp: do the basic send and recv for PLPMTUD probe (Xin Long) [1890383]
- sctp: add the probe timer in transport for PLPMTUD (Xin Long) [1890383]
- sctp: add the constants/variables and states and some APIs for transport (Xin Long) [1890383]
- sctp: add SCTP_PLPMTUD_PROBE_INTERVAL sockopt for sock/asoc/transport (Xin Long) [1890383]
- sctp: add probe_interval in sysctl and sock/asoc/transport (Xin Long) [1890383]
- sctp: add pad chunk and its make function and event table (Xin Long) [1890383]
- blk-mq: still set q->make_request_fn for blk-mq (Ming Lei) [1999728]
- PCI: Add AMD RS690 quirk to enable 64-bit DMA (Myron Stowe) [1993279]
- PCI: Add ACS quirk for Broadcom BCM57414 NIC (Myron Stowe) [1993279]
- PCI: Mark some NVIDIA GPUs to avoid bus reset (Myron Stowe) [1993279]
- PCI: of: Clear 64-bit flag for non-prefetchable memory below 4GB (Myron Stowe) [1993279]
- x86/PCI: Remove unused alloc_pci_root_info() return value (Myron Stowe) [1993279]
- PCI: Delay after FLR of Intel DC P4510 NVMe (Myron Stowe) [1993279]
- PCI: Delay after FLR of Intel DC P3700 NVMe (Myron Stowe) [1993279]
- PCI: Disable Samsung SM961/PM961 NVMe before FLR (Myron Stowe) [1993279]
- PCI/sysfs: Use sysfs_emit() and sysfs_emit_at() in "show" functions (Myron Stowe) [1993279]
- PCI/sysfs: Rearrange smbios_attr_group and acpi_attr_group (Myron Stowe) [1993279]
- PCI/sysfs: Tidy SMBIOS & ACPI label attributes (Myron Stowe) [1993279]
- PCI/sysfs: Convert "index", "acpi_index", "label" to static attributes (Myron Stowe) [1993279]
- PCI/sysfs: Define SMBIOS label attributes with DEVICE_ATTR*() (Myron Stowe) [1993279]
- PCI/sysfs: Define ACPI label attributes with DEVICE_ATTR*() (Myron Stowe) [1993279]
- PCI/sysfs: Rename device_has_dsm() to device_has_acpi_name() (Myron Stowe) [1993279]
- PCI/sysfs: Convert "vpd" to static attribute (Myron Stowe) [1993279]
- PCI/sysfs: Rename "vpd" attribute accessors (Myron Stowe) [1993279]
- PCI/sysfs: Convert "reset" to static attribute (Myron Stowe) [1993279]
- PCI/sysfs: Convert "rom" to static attribute (Myron Stowe) [1993279]
- PCI/sysfs: Convert "config" to static attribute (Myron Stowe) [1993279]
- PCI: Allow VPD access for QLogic ISP2722 (Myron Stowe) [1993279]
- PCI/VPD: Add helper pci_get_func0_dev() (Myron Stowe) [1993279]
- PCI/VPD: Remove pci_vpd_find_tag() SRDT handling (Myron Stowe) [1993279]
- PCI/VPD: Remove pci_vpd_find_tag() 'offset' argument (Myron Stowe) [1993279]
- PCI/VPD: Change pci_vpd_init() return type to void (Myron Stowe) [1993279]
- PCI/VPD: Make missing VPD message less alarming (Myron Stowe) [1993279]
- PCI/VPD: Remove pci_set_vpd_size() (Myron Stowe) [1993279]
- PCI/VPD: Remove sysfs accessor size checking dead code (Myron Stowe) [1993279]
- PCI/VPD: Remove obsolete Broadcom NIC quirk (Myron Stowe) [1993279]
- PCI/ACPI: Fix acpi_pci_set_power_state() debug message (Myron Stowe) [1993279]
- PCI: acpiphp: Fix whitespace issue (Myron Stowe) [1993279]
- PCI: shpchp: Remove unused shpc_writeb() (Myron Stowe) [1993279]
- PCI: cpqphp: Use DEFINE_SPINLOCK() for int15_lock (Myron Stowe) [1993279]
- ACPI / hotplug / PCI: Fix reference count leak in enable_slot() (Myron Stowe) [1993279]
- PCI: Add pci_disable_parity() (Myron Stowe) [1993279]
- PCI: Release OF node in pci_scan_device()'s error path (Myron Stowe) [1993279]
- fs: dlm: fix check for multi-homed hosts (Alexander Aring) [1889887]
- iommu: remove iommu_domain_{get,set}_attr (Jerry Snitselaar) [2004349]
- iommu/fsl_pamu: enable the liodn when attaching a device (Jerry Snitselaar) [2004349]
- iommu/fsl_pamu: replace DOMAIN_ATTR_FSL_PAMU_STASH with a direct call (Jerry Snitselaar) [2004349]
- iommu/fsl_pamu: remove ->domain_window_enable (Jerry Snitselaar) [2004349]
- iommu/fsl_pamu: remove support for multiple windows (Jerry Snitselaar) [2004349]
- iommu/fsl_pamu: remove fsl_pamu_get_domain_attr (Jerry Snitselaar) [2004349]
- iommu: remove the unused domain_window_disable method (Jerry Snitselaar) [2004349]
- iommu: Remove .domain_{get,set}_windows (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Decrease the queue size of evtq and priq (Jerry Snitselaar) [2004349]
- iommu/vt-d: Use pasid_pte_is_present() helper function (Jerry Snitselaar) [2004349]
- iommu/vt-d: Update the virtual command related registers (Jerry Snitselaar) [2004349]
- ACPI: IORT: Handle device properties with software node API (Jerry Snitselaar) [2004349]
- iommu: Update "iommu.strict" documentation (Jerry Snitselaar) [2004349]
- iommu/dma: Remove redundant "!dev" checks (Jerry Snitselaar) [2004349]
- iommu/virtio: Drop IOVA cookie management (Jerry Snitselaar) [2004349]
- iommu/vt-d: Drop IOVA cookie management (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Drop IOVA cookie management (Jerry Snitselaar) [2004349]
- iommu/amd: Drop IOVA cookie management (Jerry Snitselaar) [2004349]
- iommu: Pull IOVA cookie management into the core (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Extract reusable function __arm_smmu_cmdq_skip_err() (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_get_cmdq() (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Remove some unneeded init in arm_smmu_cmdq_issue_cmdlist() (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_cmdq_issue_cmd_with_sync() (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Use command queue batching helpers to improve performance (Jerry Snitselaar) [2004349]
- iommu/amd: Use only natural aligned flushes in a VM (Jerry Snitselaar) [2004349]
- iommu/amd: Sync once for scatter-gather operations (Jerry Snitselaar) [2004349]
- iommu/amd: Tailored gather logic for AMD (Jerry Snitselaar) [2004349]
- iommu: Factor iommu_iotlb_gather_is_disjoint() out (Jerry Snitselaar) [2004349]
- iommu: Improve iommu_iotlb_gather helpers (Jerry Snitselaar) [2004349]
- iommu/amd: Do not use flush-queue when NpCache is on (Jerry Snitselaar) [2004349]
- iommu/amd: Selective flush on unmap (Jerry Snitselaar) [2004349]
- iommu/amd: Convert from atomic_t to refcount_t on pasid_state->count (Jerry Snitselaar) [2004349]
- iommu: Streamline iommu_iova_to_phys() (Jerry Snitselaar) [2004349]
- iommu/vt-d: Allow devices to have more than 32 outstanding PRs (Jerry Snitselaar) [1920744]
- iommu/vt-d: Drop "0x" prefix from PCI bus & device addresses (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix a deadlock in intel_svm_drain_prq() (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix PASID leak in intel_svm_unbind_mm() (Jerry Snitselaar) [2004349]
- iommu/amd: Fix printing of IOMMU events when rate limiting kicks in (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Fix missing unlock on error in arm_smmu_device_group() (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Fix race condition during iommu_group creation (Jerry Snitselaar) [2004349]
- iommu: Fix race condition during default domain allocation (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971977]
- iommu/arm-smmu-v3: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971977]
- iommu/vt-d: Move clflush'es from iotlb_sync_map() to map_pages() (Jerry Snitselaar) [1971977]
- iommu/vt-d: Implement map/unmap_pages() iommu_ops callback (Jerry Snitselaar) [1971977]
- iommu/vt-d: Report real pgsize bitmap to iommu core (Jerry Snitselaar) [1971977]
- iommu/arm-smmu: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971977]
- iommu/arm-smmu: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971977]
- iommu/io-pgtable-arm: Implement arm_lpae_map_pages() (Jerry Snitselaar) [1971977]
- iommu/io-pgtable-arm: Implement arm_lpae_unmap_pages() (Jerry Snitselaar) [1971977]
- iommu/io-pgtable-arm: Prepare PTE methods for handling multiple entries (Jerry Snitselaar) [1971977]
- iommu: Add support for the map_pages() callback (Jerry Snitselaar) [1971977]
- iommu: Hook up '->unmap_pages' driver callback (Jerry Snitselaar) [1971977]
- iommu: Split 'addr_merge' argument to iommu_pgsize() into separate parts (Jerry Snitselaar) [1971977]
- iommu: Use bitmap to calculate page size in iommu_pgsize() (Jerry Snitselaar) [1971977]
- iommu: Add a map_pages() op for IOMMU drivers (Jerry Snitselaar) [1971977]
- iommu/io-pgtable: Introduce map_pages() as a page table op (Jerry Snitselaar) [1971977]
- iommu: Add an unmap_pages() op for IOMMU drivers (Jerry Snitselaar) [1971977]
- iommu/io-pgtable: Introduce unmap_pages() as a page table op (Jerry Snitselaar) [1971977]
- iommu/vt-d: Fix incomplete cache flush in intel_pasid_tear_down_entry() (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix PASID reference leak (Jerry Snitselaar) [2004349]
- iommu: Check if group is NULL before remove device (Jerry Snitselaar) [2004349]
- iommu/dma: Fix leak in non-contiguous API (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Fix fall-through warning for Clang (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix clearing real DMA device's scalable-mode context entries (Jerry Snitselaar) [2004349]
- iommu/vt-d: Global devTLB flush when present context entry changed (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Use Tegra implementation on Tegra186 (Jerry Snitselaar) [2004349]
- iommu: Delete a duplicate check in iommu_change_dev_def_domain() (Jerry Snitselaar) [2004349]
- iommu/dma: Fix compile warning in 32-bit builds (Jerry Snitselaar) [2004349]
- iommu: Drop unnecessary of_iommu.h includes (Jerry Snitselaar) [2004349]
- iommu: Remove unused of_get_dma_window() (Jerry Snitselaar) [2004349]
- iommu/iova: Put free_iova_mem() outside of spinlock iova_rbtree_lock (Jerry Snitselaar) [2004349]
- iommu/dma: Fix IOVA reserve dma ranges (Jerry Snitselaar) [2004349]
- iommu/virtio: Enable x86 support (Jerry Snitselaar) [2004349]
- iommu/dma: Pass address limit rather than size to iommu_setup_dma_ops() (Jerry Snitselaar) [2004349]
- iommu/amd: Fix section mismatch warning for detect_ivrs() (Jerry Snitselaar) [2004349]
- iommu/amd: Add amd_iommu=force_enable option (Jerry Snitselaar) [2004349]
- iommu/amd: Fix extended features logging (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix dereference of pointer info before it is null checked (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix linker error on 32-bit (Jerry Snitselaar) [2004349]
- iommu/vt-d: No need to typecast (Jerry Snitselaar) [2004349]
- iommu/vt-d: Define counter explicitly as unsigned int (Jerry Snitselaar) [2004349]
- iommu/vt-d: Remove unnecessary braces (Jerry Snitselaar) [2004349]
- iommu/vt-d: Removed unused iommu_count in dmar domain (Jerry Snitselaar) [2004349]
- iommu/vt-d: Use bitfields for DMAR capabilities (Jerry Snitselaar) [2004349]
- iommu/vt-d: Use DEVICE_ATTR_RO macro (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix out-bounds-warning in intel/svm.c (Jerry Snitselaar) [2004349]
- iommu/vt-d: Add PRQ handling latency sampling (Jerry Snitselaar) [1971935]
- iommu/vt-d: Add cache invalidation latency sampling (Jerry Snitselaar) [1971935]
- iommu/vt-d: Expose latency monitor data through debugfs (Jerry Snitselaar) [1971935]
- iommu/vt-d: Add common code for dmar latency performance monitors (Jerry Snitselaar) [1971935]
- iommu/vt-d: Add prq_report trace event (Jerry Snitselaar) [1971973]
- iommu/vt-d: Report prq to io-pgfault framework (Jerry Snitselaar) [1971971]
- iommu/vt-d: Allocate/register iopf queue for sva devices (Jerry Snitselaar) [1971971]
- iommu/vt-d: Refactor prq_event_thread() (Jerry Snitselaar) [1971971]
- iommu/vt-d: Use common helper to lookup svm devices (Jerry Snitselaar) [1971971]
- iommu/vt-d: Use iommu_sva_alloc(free)_pasid() helpers (Jerry Snitselaar) [1971971]
- iommu/vt-d: Add pasid private data helpers (Jerry Snitselaar) [1971971]
- iommu/vt-d: Support asynchronous IOMMU nested capabilities (Jerry Snitselaar) [2004349]
- iommu/vt-d: Select PCI_ATS explicitly (Jerry Snitselaar) [2004349]
- iommu/vt-d: Tweak the description of a DMA fault (Jerry Snitselaar) [1971975]
- iommu/vt-d: Fix kernel-doc syntax in file header (Jerry Snitselaar) [2004349]
- iommu/vt-d: Remove redundant assignment to variable agaw (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Check smmu->impl pointer before dereferencing (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Implement ->probe_finalize() (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Remove unnecessary oom message (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Fix arm_smmu_device refcount leak in address translation (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Fix arm_smmu_device refcount leak when arm_smmu_rpm_get fails (Jerry Snitselaar) [2004349]
- PM: runtime: Add documentation for pm_runtime_resume_and_get() (Jerry Snitselaar) [2004349]
- PM: runtime: Add pm_runtime_resume_and_get to deal with usage counter (Jerry Snitselaar) [2004349]
- iommu/arm: Cleanup resources in case of probe error path (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Ratelimit event dump (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Add stall support for platform devices (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Change *array into *const array (Jerry Snitselaar) [2004349]
- iommu/amd: Remove redundant assignment of err (Jerry Snitselaar) [2004349]
- iommu/amd: Tidy up DMA ops init (Jerry Snitselaar) [2004349]
- iommu/arm-smmu: Add support for driver IOMMU fault handlers (Jerry Snitselaar) [2004349]
- iommu/virtio: Add missing MODULE_DEVICE_TABLE (Jerry Snitselaar) [2004349]
- iommu/amd: Fix wrong parentheses on page-specific invalidations (Jerry Snitselaar) [2004349]
- iommu: Streamline registration interface (Jerry Snitselaar) [2004349]
- iommu: Statically set module owner (Jerry Snitselaar) [2004349]
- iommu: remove DOMAIN_ATTR_IO_PGTABLE_CFG (Jerry Snitselaar) [2004349]
- iommu: remove DOMAIN_ATTR_DMA_USE_FLUSH_QUEUE (Jerry Snitselaar) [2004349]
- iommu: remove iommu_set_cmd_line_dma_api and iommu_cmd_line_dma_api (Jerry Snitselaar) [2004349]
- iommu: remove DOMAIN_ATTR_NESTING (Jerry Snitselaar) [2004349]
- iommu: remove DOMAIN_ATTR_GEOMETRY (Jerry Snitselaar) [2004349]
- iommu: remove DOMAIN_ATTR_PAGING (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Maintain a SID->device structure (Jerry Snitselaar) [2004349]
- iommu: Add a page fault handler (Jerry Snitselaar) [2004349]
- iommu/vt-d: Support IOMMU_DEV_FEAT_IOPF (Jerry Snitselaar) [2004349]
- iommu: Separate IOMMU_DEV_FEAT_IOPF from IOMMU_DEV_FEAT_SVA (Jerry Snitselaar) [2004349]
- iommu/arm-smmu-v3: Use device properties for pasid-num-bits (Jerry Snitselaar) [2004349]
- of/device: Add input id to of_dma_configure() (Jerry Snitselaar) [2004349]
- of/iommu: Make of_map_rid() PCI agnostic (Jerry Snitselaar) [2004349]
- iommu: Fix comment for struct iommu_fwspec (Jerry Snitselaar) [2004349]
- iommu/amd: Remove duplicate check of devid (Jerry Snitselaar) [2004349]
- iommu/amd: Page-specific invalidations for more than one page (Jerry Snitselaar) [2004349]
- iommu/amd: Move a few prototypes to include/linux/amd-iommu.h (Jerry Snitselaar) [2004349]
- iommu/amd: Remove a few unused exports (Jerry Snitselaar) [2004349]
- iommu/amd: Remove the unused amd_iommu_get_v2_domain function (Jerry Snitselaar) [2004349]
- iommu/amd: Remove the unused device errata code (Jerry Snitselaar) [2004349]
- iommu/amd: Remove duplicate check of pasids (Jerry Snitselaar) [2004349]
- iommu/vt-d: Fix lockdep splat in intel_pasid_get_entry() (Jerry Snitselaar) [2004349]
- iommu/amd: Remove iommu_init_ga() (Jerry Snitselaar) [1998265]
- iommu/amd: Relocate GAMSup check to early_enable_iommus (Jerry Snitselaar) [1998265]
- x86/Kconfig: Do not enable AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT automatically (Prarit Bhargava) [2021219]
- hyper-v: Replace uuid.h with types.h (Mohammed Gamal) [2008563]
- x86/hyperv: Avoid erroneously sending IPI to 'self' (Mohammed Gamal) [2008563]
- asm-generic/hyperv: provide cpumask_to_vpset_noself (Mohammed Gamal) [2008563]
- asm-generic/hyperv: Add missing function prototypes per -W1 warnings (Mohammed Gamal) [2008563]
- hv: hyperv.h: Remove unused inline functions (Mohammed Gamal) [2008563]
- hv: hyperv.h: a few mundane typo fixes (Mohammed Gamal) [2008563]
- hv: hyperv.h: Replace one-element array with flexible-array in struct icmsg_negotiate (Mohammed Gamal) [2008563]
- x86/hyperv: add comment describing TSC_INVARIANT_CONTROL MSR setting bit 0 (Mohammed Gamal) [2008563]
- x86/hyperv: fix for unwanted manipulation of sched_clock when TSC marked unstable (Mohammed Gamal) [2008563]
- hyperv: Detect Nested virtualization support for SVM (Mohammed Gamal) [2008563]
- hyperv: SVM enlightened TLB flush support flag (Mohammed Gamal) [2008563]
- x86/hyperv: remove on-stack cpumask from hv_send_ipi_mask_allbutself (Mohammed Gamal) [2008563]
- drivers: hv: Create a consistent pattern for checking Hyper-V hypercall status (Mohammed Gamal) [2008563]
- x86/hyperv: remove unused linux/version.h header (Mohammed Gamal) [2008563]
- x86/hyperv: Fix unused variable 'hi' warning in hv_apic_read (Mohammed Gamal) [2008563]
- x86/hyperv: Fix unused variable 'msr_val' warning in hv_qlock_wait (Mohammed Gamal) [2008563]
- PCI: hv: Fix sleep while in non-sleep context when removing child devices from the bus (Mohammed Gamal) [2008562]
- PCI: hv: Add check for hyperv_initialized in init_hv_pci_drv() (Mohammed Gamal) [2008562]
- PCI: hv: Drop msi_controller structure (Mohammed Gamal) [2008562]
- PCI/IOV: Add sysfs MSI-X vector assignment interface (Myron Stowe) [2019087]
- x86: ACPI: cstate: Optimize C3 entry on AMD CPUs (David Arcari) [1998529]
- Bluetooth: Move shutdown callback before flushing tx and rx queue (Gopal Tiwari) [1990477]
- Bluetooth: btusb: check conditions before enabling USB ALT 3 for WBS (Gopal Tiwari) [1990477]
- Bluetooth: Fix VIRTIO_ID_BT assigned number (Gopal Tiwari) [1990477]
- Bluetooth: mgmt: Fix wrong opcode in the response for add_adv cmd (Gopal Tiwari) [1990477]
- Bluetooth: defer cleanup of resources in hci_unregister_dev() (Gopal Tiwari) [1990477]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [1990477]
- Bluetooth: Fix handling of HCI_LE_Advertising_Set_Terminated event (Gopal Tiwari) [1990477]
- Bluetooth: Fix Set Extended (Scan Response) Data (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language when filtering devices (Gopal Tiwari) [1990477]
- Bluetooth: smp: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language in HCI role comments (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language when tracking connections (Gopal Tiwari) [1990477]
- Bluetooth: sco: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: a2mp: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: 6lowpan: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: amp: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: cmtp: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: bnep: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: hidp: Use the correct print format (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language in comments (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language in SMP (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language in HCI LE features (Gopal Tiwari) [1990477]
- Bluetooth: use inclusive language to describe CPB (Gopal Tiwari) [1990477]
- Bluetooth: mgmt: Fix slab-out-of-bounds in tlv_data_is_valid (Gopal Tiwari) [1990477]
- Bluetooth: disable filter dup when scan for adv monitor (Gopal Tiwari) [1990477]
- Bluetooth: mgmt: Fix the command returns garbage parameter value (Gopal Tiwari) [1990477]
- Bluetooth: RFCOMM: Use DEVICE_ATTR_RO macro (Gopal Tiwari) [1990477]
- Bluetooth: Translate additional address type during le_conn_comp (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Fix invalid access on ECRED Connection response (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Fix invalid access if ECRED Reconfigure fails (Gopal Tiwari) [1990477]
- Bluetooth: Remove spurious error message (Gopal Tiwari) [1990477]
- Bluetooth: Shutdown controller after workqueues are flushed or cancelled (Gopal Tiwari) [1990477]
- Bluetooth: Add ncmd=0 recovery handling (Gopal Tiwari) [1990477]
- Bluetooth: 6lowpan: remove unused function (Gopal Tiwari) [1990477]
- Bluetooth: Fix alt settings for incoming SCO with transparent coding format (Gopal Tiwari) [1990477]
- Bluetooth: Fix the HCI to MGMT status conversion table (Gopal Tiwari) [1990477]
- Bluetooth: cmtp: fix file refcount when cmtp_attach_device fails (Gopal Tiwari) [1990477]
- Bluetooth: 6lowpan: delete unneeded variable initialization (Gopal Tiwari) [1990477]
- Bluetooth: Return whether a connection is outbound (Gopal Tiwari) [1990477]
- Bluetooth: SMP: Fix crash when receiving new connection when debug is enabled (Gopal Tiwari) [1990477]
- Bluetooth: Fix spelling mistakes (Gopal Tiwari) [1990477]
- Bluetooth: Set defaults for le_scan_{int,window}_adv_monitor (Gopal Tiwari) [1990477]
- Bluetooth: Allow Microsoft extension to indicate curve validation (Gopal Tiwari) [1990477]
- Bluetooth: Add support for reading AOSP vendor capabilities (Gopal Tiwari) [1990477]
- Bluetooth: LL privacy allow RPA (Gopal Tiwari) [1990477]
- Bluetooth: Handle own address type change with HCI_ENABLE_LL_PRIVACY (Gopal Tiwari) [1990477]
- Bluetooth: Do not set cur_adv_instance in adv param MGMT request (Gopal Tiwari) [1990477]
- Bluetooth: Use ext adv handle from requests in CCs (Gopal Tiwari) [1990477]
- Bluetooth: use the correct print format for L2CAP debug statements (Gopal Tiwari) [1990477]
- Bluetooth: SMP: Fix variable dereferenced before check 'conn' (Gopal Tiwari) [1990477]
- Bluetooth: Check inquiry status before sending one (Gopal Tiwari) [1990477]
- Bluetooth: Coding style fix (Gopal Tiwari) [1990477]
- Bluetooth: Remove 'return' in void function (Gopal Tiwari) [1990477]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [1990477]
- Bluetooth: Move the advertisement monitor events to correct list (Gopal Tiwari) [1990477]
- Bluetooth: Add missing entries for PHY configuration commands (Gopal Tiwari) [1990477]
- Bluetooth: Fix mgmt status for LL Privacy experimental feature (Gopal Tiwari) [1990477]
- Bluetooth: Fix wrong opcode error for read advertising features (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Rudimentary typo fixes (Gopal Tiwari) [1990477]
- Bluetooth: Remove trailing semicolon in macros (Gopal Tiwari) [1990477]
- Bluetooth: check for zapped sk before connecting (Gopal Tiwari) [1990477]
- Bluetooth: fix set_ecdh_privkey() prototype (Gopal Tiwari) [1990477]
- Bluetooth: initialize skb_queue_head at l2cap_chan_create() (Gopal Tiwari) [1990477]
- Bluetooth: Set CONF_NOT_COMPLETE as l2cap_chan default (Gopal Tiwari) [1990477]
- Bluetooth: Fix incorrect status handling in LE PHY UPDATE event (Gopal Tiwari) [1990477]
- Bluetooth: avoid deadlock between hci_dev->lock and socket lock (Gopal Tiwari) [1990477]
- Bluetooth: SMP: Convert BT_ERR/BT_DBG to bt_dev_err/bt_dev_dbg (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Fix not checking for maximum number of DCID (Gopal Tiwari) [1990477]
- Bluetooth: Cancel le_scan_restart work when stopping discovery (Gopal Tiwari) [1990477]
- Bluetooth: SMP: Fail if remote and local public keys are identical (Gopal Tiwari) [1990477]
- Bluetooth: Allow scannable adv with extended MGMT APIs (Gopal Tiwari) [1990477]
- Bluetooth: Remove unneeded commands for suspend (Gopal Tiwari) [1990477]
- Bluetooth: Notify suspend on le conn failed (Gopal Tiwari) [1990477]
- Bluetooth: hci_uart: Remove redundant assignment to fw_ptr (Gopal Tiwari) [1990477]
- Bluetooth: btmrvl: remove redundant continue statement (Gopal Tiwari) [1990477]
- Bluetooth: btusb: use default nvm if boardID is 0 for wcn6855. (Gopal Tiwari) [1990477]
- Bluetooth: btusb: fix bt fiwmare downloading failure issue for qca btsoc. (Gopal Tiwari) [1990477]
- Bluetooth: btmtkuart: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Gopal Tiwari) [1990477]
- Bluetooth: btrtl: rename USB fw for RTL8761 (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Add 0x0b05:0x190e Realtek 8761BU (ASUS BT500) device. (Gopal Tiwari) [1990477]
- Bluetooth: hci_h5: Add RTL8822CS capabilities (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Add support USB ALT 3 for WBS (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Add a new QCA_ROME device (0cf3:e500) (Gopal Tiwari) [1990477]
- Bluetooth: btqca: Don't modify firmware contents in-place (Gopal Tiwari) [1990477]
- Bluetooth: btbcm: Add entry for BCM43430B0 UART Bluetooth (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: fix potential GPF (Gopal Tiwari) [1990477]
- Bluetooth: btusb: fix memory leak (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Fixed too many in-token issue for Mediatek Chip. (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Add support for Lite-On Mediatek Chip (Gopal Tiwari) [1990477]
- Bluetooth: virtio_bt: add missing null pointer check on alloc_skb call return (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Fix failing to init controllers with operation firmware (Gopal Tiwari) [1990477]
- Bluetooth: Add a new USB ID for RTL8822CE (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Revert Fix the autosuspend enable and disable (Gopal Tiwari) [1990477]
- Bluetooth: Add support for virtio transport driver (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Enable quirk boolean flag for Mediatek Chip. (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Skip reading firmware file version while in bootloader mode (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Collect tlv based active firmware build info in FW mode (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Reorganized bootloader mode tlv checks in intel_version_tlv parsing (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Consolidate code for waiting firmware to boot (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Consolidate code for waiting firmware download (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Consolidate intel_version parsing (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Consolidate intel_version_tlv parsing (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Move operational checks after version check (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Check firmware version before download (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: Mundane typo fix (Gopal Tiwari) [1990477]
- Bluetooth: btbcm: Add BCM4330 and BCM4334 compatibles (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: Add device_may_wakeup support (Gopal Tiwari) [1990477]
- Bluetooth: btintel: Fix offset calculation boot address parameter (Gopal Tiwari) [1990477]
- Bluetooth: btusb: print firmware file name on error loading firmware (Gopal Tiwari) [1990477]
- Bluetooth: btbcm: Obtain and handle reset GPIO (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Fix incorrect type in assignment and uninitialized symbol (Gopal Tiwari) [1990477]
- Bluetooth: btusb: support 0cb5:c547 Realtek 8822CE device (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: Fixed issue during suspend (Gopal Tiwari) [1990477]
- Bluetooth: btusb: fix excessive stack usage (Gopal Tiwari) [1990477]
- Bluetooth: btusb: remove set but not used variable in btusb_mtk_setup_firmware_79xx (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Fix typo and correct the log print (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Fix memory leak in btusb_mtk_wmt_recv (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Add protocol support for MediaTek MT7921U USB devices (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Fine-tune mt7663 mechanism. (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: check for SSR triggered flag while suspend (Gopal Tiwari) [1990477]
- Bluetooth: btrtl: Enable WBS for the specific Realtek devices (Gopal Tiwari) [1990477]
- Bluetooth: hci_h5: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for btrtl (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: Wait for SSR completion during suspend (Gopal Tiwari) [1990477]
- Bluetooth: hci_qca: Fix memleak in qca_controller_memdump (Gopal Tiwari) [1990477]
- Bluetooth: hci_h5: Add support for binding RTL8723DS with device tree (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Add support for GarfieldPeak controller (Gopal Tiwari) [1990477]
- Bluetooth: btrtl: Add null check in setup (Gopal Tiwari) [1990477]
- Bluetooth: btrtl: Enable central-peripheral role (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Remove duplicate newlines from logging (Gopal Tiwari) [1990477]
- Bluetooth: btmtksdio: Fixed switch and case should be at the same indent (Gopal Tiwari) [1990477]
- Revert "Bluetooth: btintel: Fix endianness issue for TLV version information" (Gopal Tiwari) [1990477]
- Bluetooth: hci_bcm: Add support for ISO packets (Gopal Tiwari) [1990477]
- Bluetooth: btusb: add shutdown function for wcn6855 (Gopal Tiwari) [1990477]
- Bluetooth: hci_uart: Fix a race for write_work scheduling (Gopal Tiwari) [1990477]
- Bluetooth: btqca: Add support to read FW build version for WCN3991 BTSoC (Gopal Tiwari) [1990477]
- Bluetooth: btusb: Always fallback to alt 1 for WBS (Gopal Tiwari) [1990477]
- Bluetooth: btqcomsmd: Fix a resource leak in error handling paths in the probe function (Gopal Tiwari) [1990477]
- Bluetooth: Fix null pointer dereference in amp_read_loc_assoc_final_data (Gopal Tiwari) [1990477]
- Bluetooth: Skip eSCO 2M params when not supported (Gopal Tiwari) [1990477]
- Bluetooth: fix indentation and alignment reported by checkpatch (Gopal Tiwari) [1990477]
- Bluetooth: fix coccicheck warnings debugfs (Gopal Tiwari) [1990477]
- Bluetooth: Add new HCI_QUIRK_NO_SUSPEND_NOTIFIER quirk (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Try harder to accept device not knowing options (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Fix handling fragmented length (Gopal Tiwari) [1990477]
- Bluetooth: btusb: fix memory leak on suspend and resume (Gopal Tiwari) [1990477]
- Bluetooth: Put HCI device if inquiry procedure interrupts (Gopal Tiwari) [1990477]
- Bluetooth: drop HCI device reference before return (Gopal Tiwari) [1990477]
- Bluetooth: avoid u128_xor() on potentially misaligned inputs (Gopal Tiwari) [1990477]
- Bluetooth: Fix initializing response id after clearing struct (Gopal Tiwari) [1990477]
- Bluetooth: Cancel Inquiry before Create Connection (Gopal Tiwari) [1990477]
- Bluetooth: Pause service discovery for suspend (Gopal Tiwari) [1990477]
- Bluetooth: Remove hci_req_le_suspend_config (Gopal Tiwari) [1990477]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [1990477]
- Bluetooth: Set missing suspend task bits (Gopal Tiwari) [1990477]
- Bluetooth: Change MGMT security info CMD to be more generic (Gopal Tiwari) [1990477]
- Bluetooth: Query LE tx power on startup (Gopal Tiwari) [1990477]
- Bluetooth: Use intervals and tx power from mgmt cmds (Gopal Tiwari) [1990477]
- Bluetooth: Break add adv into two mgmt commands (Gopal Tiwari) [1990477]
- Bluetooth: Add helper to set adv data (Gopal Tiwari) [1990477]
- Bluetooth: Add toggle to switch off interleave scan (Gopal Tiwari) [1990477]
- Bluetooth: Refactor read default sys config for various types (Gopal Tiwari) [1990477]
- Bluetooth: Handle active scan case (Gopal Tiwari) [1990477]
- Bluetooth: Handle system suspend resume case (Gopal Tiwari) [1990477]
- Bluetooth: Interleave with allowlist scan (Gopal Tiwari) [1990477]
- Bluetooth: Fix attempting to set RPA timeout when unsupported (Gopal Tiwari) [1990477]
- Bluetooth: Rename get_adv_instance_scan_rsp (Gopal Tiwari) [1990477]
- Bluetooth: Fix not sending Set Extended Scan Response (Gopal Tiwari) [1990477]
- Bluetooth: Fix for Bluetooth SIG test L2CAP/COS/CFD/BV-14-C (Gopal Tiwari) [1990477]
- Bluetooth: sco: Fix crash when using BT_SNDMTU/BT_RCVMTU option (Gopal Tiwari) [1990477]
- Bluetooth: Replace BT_DBG with bt_dev_dbg in HCI request (Gopal Tiwari) [1990477]
- Bluetooth: consolidate error paths in hci_phy_link_complete_evt() (Gopal Tiwari) [1990477]
- Bluetooth: Enforce key size of 16 bytes on FIPS level (Gopal Tiwari) [1990477]
- Bluetooth: hidp: use correct wait queue when removing ctrl_wait (Gopal Tiwari) [1990477]
- Bluetooth: Move force_bredr_smp debugfs into hci_debugfs_create_bredr (Gopal Tiwari) [1990477]
- Bluetooth: Fix: LL PRivacy BLE device fails to connect (Gopal Tiwari) [1990477]
- Bluetooth: Resume advertising after LE connection (Gopal Tiwari) [1990477]
- Bluetooth: Fix slab-out-of-bounds read in hci_le_direct_adv_report_evt() (Gopal Tiwari) [1990477]
- Bluetooth: Replace zero-length array with flexible-array member (Gopal Tiwari) [1990477]
- Bluetooth: MGMT: Fix not checking if BT_HS is enabled (Gopal Tiwari) [1990477]
- Bluetooth: Disable High Speed by default (Gopal Tiwari) [1990477]
- Bluetooth: Fix update of own_addr_type if ll_privacy supported (Gopal Tiwari) [1990477]
- Bluetooth: Fix auto-creation of hci_conn at Conn Complete event (Gopal Tiwari) [1990477]
- Bluetooth: Set scan parameters for ADV Monitor (Gopal Tiwari) [1990477]
- Bluetooth: Update Adv monitor count upon removal (Gopal Tiwari) [1990477]
- net: bluetooth: delete duplicated words (Gopal Tiwari) [1990477]
- Bluetooth: pause/resume advertising around suspend (Gopal Tiwari) [1990477]
- Bluetooth: Emit controller suspend and resume events (Gopal Tiwari) [1990477]
- Bluetooth: Add suspend reason for device disconnect (Gopal Tiwari) [1990477]
- Bluetooth: Add mgmt suspend and resume events (Gopal Tiwari) [1990477]
- Bluetooth: Set ext scan response only when it exists (Gopal Tiwari) [1990477]
- Bluetooth: Only mark socket zapped after unlocking (Gopal Tiwari) [1990477]
- Bluetooth: Add MGMT capability flags for tx power and ext advertising (Gopal Tiwari) [1990477]
- Bluetooth: Report num supported adv instances for hw offloading (Gopal Tiwari) [1990477]
- Bluetooth: sco: new getsockopt options BT_SNDMTU/BT_RCVMTU (Gopal Tiwari) [1990477]
- Bluetooth: Re-order clearing suspend tasks (Gopal Tiwari) [1990477]
- Bluetooth: Fix memory leak in read_adv_mon_features() (Gopal Tiwari) [1990477]
- Bluetooth: Clear suspend tasks on unregister (Gopal Tiwari) [1990477]
- Bluetooth: Remove CRYPTO_ALG_INTERNAL flag (Gopal Tiwari) [1990477]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [1990477]
- Bluetooth: use the proper scan params when conn is pending (Gopal Tiwari) [1990477]
- Bluetooth: Enable controller RPA resolution using Experimental feature (Gopal Tiwari) [1990477]
- Bluetooth: Let controller creates RPA during le create conn (Gopal Tiwari) [1990477]
- Bluetooth: Translate additional address type during le_conn (Gopal Tiwari) [1990477]
- Bluetooth: Enable RPA Timeout (Gopal Tiwari) [1990477]
- Bluetooth: Enable/Disable address resolution during le create conn (Gopal Tiwari) [1990477]
- Bluetooth: Configure controller address resolution if available (Gopal Tiwari) [1990477]
- Bluetooth: Translate additional address type correctly (Gopal Tiwari) [1990477]
- Bluetooth: Update resolving list when updating whitelist (Gopal Tiwari) [1990477]
- Bluetooth: Fix suspend notifier race (Gopal Tiwari) [1990477]
- Bluetooth: Return NOTIFY_DONE for hci_suspend_notifier (Gopal Tiwari) [1990477]
- Bluetooth: Add per-instance adv disable/remove (Gopal Tiwari) [1990477]
- Replace HTTP links with HTTPS ones: BLUETOOTH SUBSYSTEM (Gopal Tiwari) [1990477]
- Bluetooth: RFCOMM: Use fallthrough pseudo-keyword (Gopal Tiwari) [1990477]
- Bluetooth: core: Use fallthrough pseudo-keyword (Gopal Tiwari) [1990477]
- Bluetooth: Use whitelist for scan policy when suspending (Gopal Tiwari) [1990477]
- Bluetooth: le_simult_central_peripheral experimental feature (Gopal Tiwari) [1990477]
- Bluetooth: Fix kernel oops triggered by hci_adv_monitors_clear() (Gopal Tiwari) [1990477]
- Bluetooth: use configured default params for active scans (Gopal Tiwari) [1990477]
- Bluetooth: Adding a configurable autoconnect timeout (Gopal Tiwari) [1990477]
- Bluetooth: Don't restart scanning if paused (Gopal Tiwari) [1990477]
- Bluetooth: add a mutex lock to avoid UAF in do_enale_set (Gopal Tiwari) [1990477]
- Bluetooth: use configured params for ext adv (Gopal Tiwari) [1990477]
- Bluetooth: Add hci_dev_lock to get/set device flags (Gopal Tiwari) [1990477]
- Bluetooth: mgmt: Use command complete on success for set system config (Gopal Tiwari) [1990477]
- Bluetooth: Terminate the link if pairing is cancelled (Gopal Tiwari) [1990477]
- Bluetooth: Update background scan and report device based on advertisement monitors (Gopal Tiwari) [1990477]
- Bluetooth: Notify adv monitor removed event (Gopal Tiwari) [1990477]
- Bluetooth: Notify adv monitor added event (Gopal Tiwari) [1990477]
- Bluetooth: Add handler of MGMT_OP_REMOVE_ADV_MONITOR (Gopal Tiwari) [1990477]
- Bluetooth: Add handler of MGMT_OP_ADD_ADV_PATTERNS_MONITOR (Gopal Tiwari) [1990477]
- Bluetooth: Add handler of MGMT_OP_READ_ADV_MONITOR_FEATURES (Gopal Tiwari) [1990477]
- Bluetooth: Add definitions for advertisement monitor features (Gopal Tiwari) [1990477]
- Bluetooth: Add get/set device flags mgmt op (Gopal Tiwari) [1990477]
- Bluetooth: Replace wakeable in hci_conn_params (Gopal Tiwari) [1990477]
- Bluetooth: Replace wakeable list with flag (Gopal Tiwari) [1990477]
- Bluetooth: Add bdaddr_list_with_flags for classic whitelist (Gopal Tiwari) [1990477]
- Bluetooth: mgmt: Add commands for runtime configuration (Gopal Tiwari) [1990477]
- Bluetooth: implement read/set default system parameters mgmt (Gopal Tiwari) [1990477]
- Bluetooth: mgmt: read/set system parameter definitions (Gopal Tiwari) [1990477]
- Bluetooth: centralize default value initialization. (Gopal Tiwari) [1990477]
- Bluetooth: Use only 8 bits for the HCI CMSG state flags (Gopal Tiwari) [1990477]
- Bluetooth: Add support for BT_PKT_STATUS CMSG data for SCO connections (Gopal Tiwari) [1990477]
- Bluetooth: Removing noisy dbg message (Gopal Tiwari) [1990477]
- Bluetooth: Fix update of connection state in `hci_encrypt_cfm` (Gopal Tiwari) [1990477]
- Bluetooth: Fix assuming EIR flags can result in SSP authentication (Gopal Tiwari) [1990477]
- Bluetooth: Consolidate encryption handling in hci_encrypt_cfm (Gopal Tiwari) [1990477]
- Bluetooth: Add SCO fallback for invalid LMP parameters error (Gopal Tiwari) [1990477]
- Bluetooth: Fix for GAP/SEC/SEM/BI-10-C (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: add support for waiting disconnection resp (Gopal Tiwari) [1990477]
- Bluetooth: Handle Inquiry Cancel error after Inquiry Complete (Gopal Tiwari) [1990477]
- Bluetooth: Rename BT_SUSPEND_COMPLETE (Gopal Tiwari) [1990477]
- Bluetooth: Introduce debug feature when dynamic debug is disabled (Gopal Tiwari) [1990477]
- Bluetooth: Fix advertising handle is set to 0 (Gopal Tiwari) [1990477]
- Bluetooth: Introduce HCI_MGMT_HDEV_OPTIONAL option (Gopal Tiwari) [1990477]
- Bluetooth: Add support for experimental features configuration (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Fix errors during L2CAP_CREDIT_BASED_CONNECTION_REQ (0x17) (Gopal Tiwari) [1990477]
- Bluetooth: Add MGMT_EV_PHY_CONFIGURATION_CHANGED to supported list (Gopal Tiwari) [1990477]
- Bluetooth: use crypto_shash_tfm_digest() (Gopal Tiwari) [1990477]
- Bluetooth: allow scatternet connections if supported. (Gopal Tiwari) [1990477]
- Bluetooth: Enhanced Connection Complete event belongs to LL Privacy (Gopal Tiwari) [1990477]
- Bluetooth: Enable LE Enhanced Connection Complete event. (Gopal Tiwari) [1990477]
- Bluetooth: Use extra variable to make code more readable (Gopal Tiwari) [1990477]
- Bluetooth: log advertisement packet length if it gets corrected (Gopal Tiwari) [1990477]
- Bluetooth: Always request for user confirmation for Just Works (LE SC) (Gopal Tiwari) [1990477]
- Bluetooth: Simplify / fix return values from tk_request (Gopal Tiwari) [1990477]
- Bluetooth: debugfs option to unset MITM flag (Gopal Tiwari) [1990477]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [1990477]
- Bluetooth: replace zero-length array with flexible-array member (Gopal Tiwari) [1990477]
- Bluetooth: Add support for reading security information (Gopal Tiwari) [1990477]
- Bluetooth: Add support for Read Local Simple Pairing Options (Gopal Tiwari) [1990477]
- Bluetooth: Add framework for Microsoft vendor extension (Gopal Tiwari) [1990477]
- Bluetooth: Move debugfs configuration above the selftests (Gopal Tiwari) [1990477]
- Bluetooth: fixing minor typo in comment (Gopal Tiwari) [1990477]
- Bluetooth: Prioritize SCO traffic (Gopal Tiwari) [1990477]
- Bluetooth: L2CAP: Fix handling LE modes by L2CAP_OPTIONS (Gopal Tiwari) [1990477]
- Bluetooth: Always request for user confirmation for Just Works (Gopal Tiwari) [1990477]
- Bluetooth: Add BT_MODE socket option (Gopal Tiwari) [1990477]
- crypto: shash - remove shash_desc::flags (Gopal Tiwari) [1990477]
- cifs: On cifs_reconnect, resolve the hostname again. (Ronnie Sahlberg) [2018046]
- cifs: Handle witness client move notification (Ronnie Sahlberg) [2018046]
- cifs: Send witness register messages to userspace daemon in echo task (Ronnie Sahlberg) [2018046]
- cifs: Add witness information to debug data dump (Ronnie Sahlberg) [2018046]
- cifs: Set witness notification handler for messages from userspace daemon (Ronnie Sahlberg) [2018046]
- cifs: Send witness register and unregister commands to userspace daemon (Ronnie Sahlberg) [2018046]
- cifs: Register generic netlink family (Ronnie Sahlberg) [2018046]
- cifs: add witness mount option and data structs (Ronnie Sahlberg) [2018046]
- cifs: Simplify reconnect code when dfs upcall is enabled (Ronnie Sahlberg) [2018046]
- file: fix close_range() for unshare+cloexec (Pavel Reichl) [1950248]
- scsi: lpfc: Update lpfc version to 14.0.0.3 (Dick Kennedy) [1989265]
- scsi: lpfc: Allow fabric node recovery if recovery is in progress before devloss (Dick Kennedy) [1989265]
- scsi: lpfc: Fix link down processing to address NULL pointer dereference (Dick Kennedy) [1989265]
- scsi: lpfc: Allow PLOGI retry if previous PLOGI was aborted (Dick Kennedy) [1989265]
- scsi: lpfc: Fix use-after-free in lpfc_unreg_rpi() routine (Dick Kennedy) [1989265]
- scsi: lpfc: Correct sysfs reporting of loop support after SFP status change (Dick Kennedy) [1989265]
- scsi: lpfc: Wait for successful restart of SLI3 adapter during host sg_reset (Dick Kennedy) [1989265]
- scsi: lpfc: Revert LOG_TRACE_EVENT back to LOG_INIT prior to driver_resource_setup() (Dick Kennedy) [1989265]
- scsi: lpfc: Fix memory overwrite during FC-GS I/O abort handling (Dick Kennedy) [1989265]
- scsi: lpfc: Add support for optional PLDV handling (Dick Kennedy) [1989265]
- scsi: lpfc: Return NULL rather than a plain 0 integer (Dick Kennedy) [1989265]
- scsi: lpfc: Fix a function name in comments (Dick Kennedy) [1989265]
- scsi: lpfc: Fix mailbox command failure during driver initialization (Dick Kennedy) [1989265]
- scsi: lpfc: Fix gcc -Wstringop-overread warning, again (Dick Kennedy) [1989265]
- scsi: lpfc: Use correct scnprintf() limit (Dick Kennedy) [1989265]
- scsi: lpfc: Fix sprintf() overflow in lpfc_display_fpin_wwpn() (Dick Kennedy) [1989265]
- scsi: lpfc: Update lpfc version to 14.0.0.2 (Dick Kennedy) [1989265]
- scsi: lpfc: Improve PBDE checks during SGL processing (Dick Kennedy) [1989265]
- scsi: lpfc: Zero CGN stats only during initial driver load and stat reset (Dick Kennedy) [1989265]
- scsi: lpfc: Fix I/O block after enabling managed congestion mode (Dick Kennedy) [1989265]
- scsi: lpfc: Adjust bytes received vales during cmf timer interval (Dick Kennedy) [1989265]
- scsi: fc: Add EDC ELS definition (Dick Kennedy) [1989265]
- scsi: lpfc: Fix EEH support for NVMe I/O (Dick Kennedy) [1989265]
- scsi: lpfc: Fix FCP I/O flush functionality for TMF routines (Dick Kennedy) [1989265]
- scsi: lpfc: Fix NVMe I/O failover to non-optimized path (Dick Kennedy) [1989265]
- scsi: lpfc: Don't remove ndlp on PRLI errors in P2P mode (Dick Kennedy) [1989265]
- scsi: lpfc: Fix rediscovery of tape device after LIP (Dick Kennedy) [1989265]
- scsi: lpfc: Fix hang on unload due to stuck fport node (Dick Kennedy) [1989265]
- scsi: lpfc: Fix premature rpi release for unsolicited TPLS and LS_RJT (Dick Kennedy) [1989265]
- scsi: lpfc: Don't release final kref on Fport node while ABTS outstanding (Dick Kennedy) [1989265]
- scsi: lpfc: Fix list_add() corruption in lpfc_drain_txq() (Dick Kennedy) [1989265]
- scsi: lpfc: Remove unneeded variable (Dick Kennedy) [1989265]
- scsi: lpfc: Fix compilation errors on kernels with no CONFIG_DEBUG_FS (Dick Kennedy) [1989265]
- scsi: lpfc: Fix CPU to/from endian warnings introduced by ELS processing (Dick Kennedy) [1989265]
- scsi: lpfc: Copyright updates for 14.0.0.1 patches (Dick Kennedy) [1989265]
- scsi: lpfc: Update lpfc version to 14.0.0.1 (Dick Kennedy) [1989265]
- scsi: lpfc: Add bsg support for retrieving adapter cmf data (Dick Kennedy) [1989265]
- scsi: lpfc: Add cmf_info sysfs entry (Dick Kennedy) [1989265]
- scsi: lpfc: Add debugfs support for cm framework buffers (Dick Kennedy) [1989265]
- scsi: lpfc: Add support for maintaining the cm statistics buffer (Dick Kennedy) [1989265]
- scsi: lpfc: Add rx monitoring statistics (Dick Kennedy) [1989265]
- scsi: lpfc: Add support for the CM framework (Dick Kennedy) [1989265]
- scsi: lpfc: Add cmfsync WQE support (Dick Kennedy) [1989265]
- scsi: lpfc: Add support for cm enablement buffer (Dick Kennedy) [1989265]
- scsi: lpfc: Add cm statistics buffer support (Dick Kennedy) [1989265]
- scsi: lpfc: Add EDC ELS support (Dick Kennedy) [1989265]
- scsi: lpfc: Expand FPIN and RDF receive logging (Dick Kennedy) [1989265]
- scsi: lpfc: Add MIB feature enablement support (Dick Kennedy) [1989265]
- scsi: lpfc: Add SET_HOST_DATA mbox cmd to pass date/time info to firmware (Dick Kennedy) [1989265]
- scsi: lpfc: Fix possible ABBA deadlock in nvmet_xri_aborted() (Dick Kennedy) [1989265]
- scsi: lpfc: Remove redundant assignment to pointer pcmd (Dick Kennedy) [1989265]
- scsi: lpfc: Copyright updates for 14.0.0.0 patches (Dick Kennedy) [1989265]
- scsi: lpfc: Update lpfc version to 14.0.0.0 (Dick Kennedy) [1989265]
- scsi: lpfc: Add 256 Gb link speed support (Dick Kennedy) [1989265]
- scsi: lpfc: Revise Topology and RAS support checks for new adapters (Dick Kennedy) [1989265]
- scsi: lpfc: Fix cq_id truncation in rq create (Dick Kennedy) [1989265]
- scsi: lpfc: Add PCI ID support for LPe37000/LPe38000 series adapters (Dick Kennedy) [1989265]
- scsi: lpfc: Copyright updates for 12.8.0.11 patches (Dick Kennedy) [1989265]
- scsi: lpfc: Update lpfc version to 12.8.0.11 (Dick Kennedy) [1989265]
- scsi: lpfc: Skip issuing ADISC when node is in NPR state (Dick Kennedy) [1989265]
- scsi: lpfc: Skip reg_vpi when link is down for SLI3 in ADISC cmpl path (Dick Kennedy) [1989265]
- scsi: lpfc: Call discovery state machine when handling PLOGI/ADISC completions (Dick Kennedy) [1989265]
- scsi: lpfc: Delay unregistering from transport until GIDFT or ADISC completes (Dick Kennedy) [1989265]
- scsi: lpfc: Enable adisc discovery after RSCN by default (Dick Kennedy) [1989265]
- scsi: lpfc: Use PBDE feature enabled bit to determine PBDE support (Dick Kennedy) [1989265]
- scsi: lpfc: Clear outstanding active mailbox during PCI function reset (Dick Kennedy) [1989265]
- scsi: lpfc: Fix KASAN slab-out-of-bounds in lpfc_unreg_rpi() routine (Dick Kennedy) [1989265]
- scsi: lpfc: Remove REG_LOGIN check requirement to issue an ELS RDF (Dick Kennedy) [1989265]
- scsi: lpfc: Fix NULL ptr dereference with NPIV ports for RDF handling (Dick Kennedy) [1989265]
- scsi: lpfc: Fix target reset handler from falsely returning FAILURE (Dick Kennedy) [1989265]
- scsi: lpfc: Discovery state machine fixes for LOGO handling (Dick Kennedy) [1989265]
- scsi: lpfc: Fix function description comments for vmid routines (Dick Kennedy) [1989265]
- scsi: lpfc: Improve firmware download logging (Dick Kennedy) [1989265]
- scsi: lpfc: Remove use of kmalloc() in trace event logging (Dick Kennedy) [1989265]
- scsi: lpfc: Fix NVMe support reporting in log message (Dick Kennedy) [1989265]
- scsi: lpfc: Fix build error in lpfc_scsi.c (Dick Kennedy) [1989265]
- scsi: lpfc: Use list_move_tail() instead of list_del()/list_add_tail() (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Introduce VMID in I/O path (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Add QFPA and VMID timeout check in worker thread (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Timeout implementation for VMID (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Append the VMID to the wqe before sending (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Implement CT commands for appid (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Functions to manage VMIDs (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Implement ELS commands for appid (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Add support for VMID in mailbox command (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: VMID parameter initialization (Dick Kennedy) [1989265]
- scsi: lpfc: vmid: Add datastructure for supporting VMID in lpfc (Dick Kennedy) [1989265]
- redhat/config: Rename CONFIG_DEBUG_KMEMLEAK_EARLY_LOG_SIZE to CONFIG_DEBUG_KMEMLEAK_MEM_POOL_SIZE (Waiman Long) [2018425]
- kasan, kmemleak: reset tags when scanning block (Waiman Long) [2018425]
- mm/kmemleak: rely on rcu for task stack scanning (Waiman Long) [2018425]
- mm/kmemleak: silence KCSAN splats in checksum (Waiman Long) [2018425]
- mm/kmemleak: turn kmemleak_lock and object->lock to raw_spinlock_t (Waiman Long) [2018425]
- kmemleak: Do not corrupt the object_list during clean-up (Waiman Long) [2018425]
- mm: kmemleak: use the memory pool for early allocations (Waiman Long) [2018425]
- mm: kmemleak: simple memory allocation pool for kmemleak objects (Waiman Long) [2018425]
- mm: kmemleak: make the tool tolerant to struct scan_area allocation failures (Waiman Long) [2018425]
- kmemleak: increase DEBUG_KMEMLEAK_EARLY_LOG_SIZE default to 16K (Waiman Long) [2018425]
- mm: kmemleak: disable early logging in case of error (Waiman Long) [2018425]
- mm/kmemleak.c: fix unused-function warning (Waiman Long) [2018425]
- kmemleak: powerpc: skip scanning holes in the .bss section (Waiman Long) [2018425]
- mm: kmemleak: no need to check return value of debugfs_create functions (Waiman Long) [2018425]

* Wed Nov 17 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-350.el8]
- powerpc/smp: Use existing L2 cache_map cpumask to find L3 cache siblings (Desnes A. Nunes do Rosario) [2013537]
- powerpc/cacheinfo: Remove the redundant get_shared_cpu_map() (Desnes A. Nunes do Rosario) [2013537]
- powerpc/cacheinfo: Lookup cache by dt node and thread-group id (Desnes A. Nunes do Rosario) [2013537]
- Revert "thunderbolt: Hide authorized attribute if router does not support PCIe tunnels" (Torez Smith) [1969444]
- thunderbolt: Add quirk for Intel Goshen Ridge DP credits (Torez Smith) [1969444]
- thunderbolt: Update port credits after bonding is enabled/disabled (Torez Smith) [1969444]
- thunderbolt: Wait for the lanes to actually bond (Torez Smith) [1969444]
- thunderbolt: Read router preferred credit allocation information (Torez Smith) [1969444]
- thunderbolt: Make tb_port_type() take const parameter (Torez Smith) [1969444]
- thunderbolt: Move nfc_credits field to struct tb_path_hop (Torez Smith) [1969444]
- thunderbolt: Align USB4 router wakes configuration with the CM guide (Torez Smith) [1969444]
- thunderbolt: Add wake from DisplayPort (Torez Smith) [1969444]
- thunderbolt: Use generic tb_nvm_[read|write]_data() for Thunderbolt 2/3 devices (Torez Smith) [1969444]
- thunderbolt: Split NVM read/write generic functions out from usb4.c (Torez Smith) [1969444]
- thunderbolt: Add self-authenticate support for new dock (Torez Smith) [1969444]
- thunderbolt: usb4: Fix NVM read buffer bounds and offset issue (Torez Smith) [1969444]
- thunderbolt: dma_port: Fix NVM read buffer bounds and offset issue (Torez Smith) [1969444]
- thunderbolt: Hide authorized attribute if router does not support PCIe tunnels (Torez Smith) [1969444]
- x86/mce: Avoid infinite loop for copy from user recovery (Prarit Bhargava) [1999550]
- x86/mce: Rename kill_it to kill_current_task (Prarit Bhargava) [1999550]
- x86/mce: Recover from poison found while copying from user space (Prarit Bhargava) [1999550]
- x86/mce: Delay clearing IA32_MCG_STATUS to the end of do_machine_check() (Prarit Bhargava) [1999550]
- x86/mce: Send #MC singal from task work (Prarit Bhargava) [1999550]
- redhat/config: Enable Nitro Enclaves on aarch64 (Vitaly Kuznetsov) [2001581]
- nitro_enclaves: Add fixes for checkpatch match open parenthesis reports (Vitaly Kuznetsov) [2001581]
- nitro_enclaves: Update copyright statement to include 2021 (Vitaly Kuznetsov) [2001581]
- nitro_enclaves: Add fix for the kernel-doc report (Vitaly Kuznetsov) [2001581]
- nitro_enclaves: Enable Arm64 support (Vitaly Kuznetsov) [2001581]
- nitro_enclaves: Set Bus Master for the NE PCI device (Vitaly Kuznetsov) [2001581]
- nitro_enclaves: Fixup type and simplify logic of the poll mask setup (Vitaly Kuznetsov) [2001581]
- mptcp: Make mptcp_pm_nl_mp_prio_send_ack() static (Davide Caratti) [2020198]
- mptcp: fix possible stall on recvmsg() (Davide Caratti) [2020198]
- mptcp: don't clear MPTCP_DATA_READY in sk_wait_event() (Davide Caratti) [2020198]
- net: introduce and use lock_sock_fast_nested() (Davide Caratti) [2020198]
- net: add annotation for sock_{lock,unlock}_fast (Davide Caratti) [2020198]
- mptcp: allow changing the 'backup' bit when no sockets are open (Davide Caratti) [2020198]
- mptcp: don't return sockets in foreign netns (Davide Caratti) [2020198]
- mptcp: ensure tx skbs always have the MPTCP ext (Davide Caratti) [2020198]
- mptcp: full fully established support after ADD_ADDR (Davide Caratti) [2020198]
- redhat/configs: Move Hyper-V configs to 'generic' (Vitaly Kuznetsov) [1949614]
- redhat/configs: enable CONFIG_INPUT_KEYBOARD on Aarch64 (Vitaly Kuznetsov) [1949614]
- efi/libstub/random: Align allocate size to EFI_ALLOC_ALIGN (Vitaly Kuznetsov) [1949614]
- efi/libstub: arm64: Double check image alignment at entry (Vitaly Kuznetsov) [1949614]
- efi/arm64: Update debug prints to reflect other entropy sources (Vitaly Kuznetsov) [1949614]
- efi/arm64: libstub: Deal gracefully with EFI_RNG_PROTOCOL failure (Vitaly Kuznetsov) [1949614]
- Drivers: hv: Enable Hyper-V code to be built on ARM64 (Vitaly Kuznetsov) [1949614]
- x86/Kconfig: Add new X86_HV_CALLBACK_VECTOR config symbol (Vitaly Kuznetsov) [1949614]
- arm64: efi: Export screen_info (Vitaly Kuznetsov) [1949614]
- arm64: hyperv: Initialize hypervisor on boot (Vitaly Kuznetsov) [1949614]
- arm64: hyperv: Add panic handler (Vitaly Kuznetsov) [1949614]
- arm64: hyperv: Add Hyper-V hypercall and register access utilities (Vitaly Kuznetsov) [1949614]
- arm64: add arch/arm64/Kbuild (Vitaly Kuznetsov) [1949614]
- PCI: hv: Turn on the host bridge probing on ARM64 (Vitaly Kuznetsov) [1949614]
- PCI: hv: Set up MSI domain at bridge probing time (Vitaly Kuznetsov) [1949614]
- PCI: hv: Set ->domain_nr of pci_host_bridge at probing time (Vitaly Kuznetsov) [1949614]
- PCI: hv: Generify PCI probing (Vitaly Kuznetsov) [1949614]
- arm64: PCI: Support root bridge preparation for Hyper-V (Vitaly Kuznetsov) [1949614]
- arm64: PCI: Restructure pcibios_root_bridge_prepare() (Vitaly Kuznetsov) [1949614]
- PCI: Support populating MSI domains of root buses via bridges (Vitaly Kuznetsov) [1949614]
- PCI: Introduce domain_nr in pci_host_bridge (Vitaly Kuznetsov) [1949614]
- drivers: hv: Decouple Hyper-V clock/timer code from VMbus drivers (Vitaly Kuznetsov) [1949614]
- Drivers: hv: Move Hyper-V misc functionality to arch-neutral code (Vitaly Kuznetsov) [1949614]
- x86/hyperv: handling hypercall page setup for root (Vitaly Kuznetsov) [1949614]
- Drivers: hv: Add arch independent default functions for some Hyper-V handlers (Vitaly Kuznetsov) [1949614]
- Drivers: hv: Make portions of Hyper-V init code be arch neutral (Vitaly Kuznetsov) [1949614]
- asm-generic/hyperv: Add missing #include of nmi.h (Vitaly Kuznetsov) [1949614]
- PCI: hv: Support for create interrupt v3 (Vitaly Kuznetsov) [1949614]
- Drivers: hv: Move Hyper-V extended capability check to arch neutral code (Vitaly Kuznetsov) [1949614]
- clocksource/drivers/hyper-v: Re-enable VDSO_CLOCKMODE_HVCLOCK on X86 (Vitaly Kuznetsov) [1949614]
- clocksource/drivers/hyper-v: Handle vDSO differences inline (Vitaly Kuznetsov) [1949614]
- arm64: smccc: Add support for SMCCCv1.2 extended input/output registers (Vitaly Kuznetsov) [1949614]
- smccc: Define vendor hyp owned service call region (Vitaly Kuznetsov) [1949614]
- scsi: smartpqi: Update version to 2.1.12-055 (Don Brace) [2018317]
- scsi: smartpqi: Add 3252-8i PCI id (Don Brace) [2018317]
- scsi: smartpqi: Fix duplicate device nodes for tape changers (Don Brace) [2018317]
- scsi: smartpqi: Fix boot failure during LUN rebuild (Don Brace) [2018317]
- scsi: smartpqi: Add extended report physical LUNs (Don Brace) [2018317]
- scsi: smartpqi: Avoid failing I/Os for offline devices (Don Brace) [2018317]
- scsi: smartpqi: Add TEST UNIT READY check for SANITIZE operation (Don Brace) [2018317]
- scsi: smartpqi: Update LUN reset handler (Don Brace) [2018317]
- scsi: smartpqi: Capture controller reason codes (Don Brace) [2018317]
- scsi: smartpqi: Add controller handshake during kdump (Don Brace) [2018317]
- scsi: smartpqi: Update device removal management (Don Brace) [2018317]
- KVM: PPC: Tick accounting should defer vtime accounting 'til after IRQ handling (Laurent Vivier) [2009312]
- vhost_net: fix OoB on sendmsg() failure. (Paolo Abeni) [1922828]
- scsi: qla2xxx: Update version to 10.02.06.200-k (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Fix returnvar.cocci warnings (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix NVMe session down detection (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix NVMe retry (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix hang on NVMe command timeouts (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix NVMe | FCP personality change (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Do secure PLOGI when auth app is present (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add N2N support for EDIF (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix hang during NVMe session tear down (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Fix EDIF enable flag (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Reject AUTH ELS on session down (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Fix stale session (Nilesh Javali) [1983874]
- scsi: qla2xxx: Update version to 10.02.06.100-k (Nilesh Javali) [1983874]
- scsi: qla2xxx: Sync queue idx with queue_pair_map idx (Nilesh Javali) [1983874]
- scsi: qla2xxx: Changes to support kdump kernel for NVMe BFS (Nilesh Javali) [1983874]
- scsi: qla2xxx: Changes to support kdump kernel (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix NPIV create erroneous error (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix unsafe removal from linked list (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix port type info (Nilesh Javali) [1983874]
- scsi: qla2xxx: Add debug print of 64G link speed (Nilesh Javali) [1983874]
- scsi: qla2xxx: Show OS name and version in FDMI-1 (Nilesh Javali) [1983874]
- scsi: qla2xxx: Changes to support FCP2 Target (Nilesh Javali) [1983874]
- scsi: qla2xxx: Adjust request/response queue size for 28xx (Nilesh Javali) [1983874]
- scsi: qla2xxx: Add host attribute to trigger MPI hang (Nilesh Javali) [1983874]
- scsi: qla2xxx: Remove redundant initialization of variable num_cnt (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix use after free in debug code (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix spelling mistakes "allloc" -> "alloc" (Nilesh Javali) [1983874]
- scsi: qla2xxx: Update version to 10.02.00.107-k (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Increment command and completion counts (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add encryption to I/O path (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add doorbell notification for app (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add detection of secure device (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add authentication pass + fail bsgs (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add key update (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add extraction of auth_els from the wire (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add send, receive, and accept for auth_els (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add getfcinfo and statistic bsgs (Nilesh Javali) [1983874]
- scsi: qla2xxx: edif: Add start + stop bsgs (Nilesh Javali) [1983874]
- scsi: qla2xxx: Remove unused variable 'status' (Nilesh Javali) [1983874]
- scsi: qla2xxx: Remove redundant continue statement in a for-loop (Nilesh Javali) [1983874]
- scsi: qla2xxx: Add heartbeat check (Nilesh Javali) [1983874]
- scsi: qla2xxx: Use list_move_tail() instead of list_del()/list_add_tail() (Nilesh Javali) [1983874]
- scsi: qla2xxx: Remove duplicate declarations (Nilesh Javali) [1983874]
- scsi: qla2xxx: Log PCI address in qla_nvme_unregister_remote_port() (Nilesh Javali) [1983874]
- scsi: target: qla2xxx: Wait for stop_phase1 at WWN removal (Nilesh Javali) [1983874]
- scsi: qla2xxx: Remove redundant assignment to rval (Nilesh Javali) [1983874]
- scsi: qla2xxx: Fix error return code in qla82xx_write_flash_dword() (Nilesh Javali) [1983874]
- scsi: qla2xxx: Prevent PRLI in target mode (Nilesh Javali) [1983874]
- scsi: qla2xxx: Reuse existing error handling path (Nilesh Javali) [1983874]
- scsi: qla2xxx: Remove unneeded if-null-free check (Nilesh Javali) [1983874]
- thermal/drivers/int340x: Do not set a wrong tcc offset on resume (David Arcari) [1997757]
- thermal: core: Add new event for sending keep alive notifications (David Arcari) [1997757]
- thermal/drivers/int340x/processor_thermal: Fix tcc setting (David Arcari) [1997757]
- thermal/drivers/int340x/processor_thermal: Fix warning for return value (David Arcari) [1997757]
- thermal/drivers/int340x/processor_thermal: Add PCI MMIO based thermal driver (David Arcari) [1997757]
- thermal/drivers/int340x/processor_thermal: Split enumeration and processing part (David Arcari) [1997757]
- thermal/drivers/int340x: processor_thermal: Export additional attributes (David Arcari) [1997757]
- thermal/drivers/int340x: processor_thermal: Export mailbox interface (David Arcari) [1997757]
- thermal/drivers/intel: Initialize RW trip to THERMAL_TEMP_INVALID (David Arcari) [1997757]
- thermal: int340x: Fix unexpected shutdown at critical temperature (David Arcari) [1997757]
- thermal: int340x: Support Alder Lake (David Arcari) [1997757]
- thermal: int340x: processor_thermal: Correct workload type name (David Arcari) [1997757]
- thermal: int340x: processor_thermal: Add mailbox driver (David Arcari) [1997757]
- thermal: int340x: processor_thermal: Add RFIM driver (David Arcari) [1997757]
- thermal: int340x: processor_thermal: Add AlderLake PCI device id (David Arcari) [1997757]
- thermal: int340x: processor_thermal: Refactor MMIO interface (David Arcari) [1997757]
- thermal: int340x: Add keep alive response method (David Arcari) [1997757]
- thermal: int340x: Provide notification for OEM variable change (David Arcari) [1997757]
- treewide: Add SPDX license identifier - Makefile/Kconfig (David Arcari) [1997757]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (David Arcari) [1997757]
- intel_idle: Adjust the SKX C6 parameters if PC6 is disabled (David Arcari) [2003731]
- intel_idle: update ICX C6 data (David Arcari) [2003731]
- nbd: provide a way for userspace processes to identify device backends (Ming Lei) [1997338]
- Revert "block, bfq: honor already-setup queue merges" (Ming Lei) [1997338]
- blk-cgroup: fix UAF by grabbing blkcg lock before destroying blkg pd (Ming Lei) [1997338]
- blkcg: fix memory leak in blk_iolatency_init (Ming Lei) [1997338]
- blk-mq: avoid to iterate over stale request (Ming Lei) [1997338]
- blk-mq: allow 4x BLK_MAX_REQUEST_COUNT at blk_plug for multiple_queues (Ming Lei) [1997338]
- block, bfq: honor already-setup queue merges (Ming Lei) [1997338]
- block/mq-deadline: Move dd_queued() to fix defined but not used warning (Ming Lei) [1997338]
- cryptoloop: add a deprecation warning (Ming Lei) [1997338]
- Revert "block/mq-deadline: Prioritize high-priority requests" (Ming Lei) [1997338]
- mq-deadline: Fix request accounting (Ming Lei) [1997338]
- nbd: Aovid double completion of a request (Ming Lei) [1997338]
- blk-mq: clear active_queues before clearing BLK_MQ_F_TAG_QUEUE_SHARED (Ming Lei) [1997338]
- Revert "block/mq-deadline: Add cgroup support" (Ming Lei) [1997338]
- kyber: make trace_block_rq call consistent with documentation (Ming Lei) [1997338]
- blk-iolatency: error out if blk_get_queue() failed in iolatency_set_limit() (Ming Lei) [1997338]
- blk-mq-sched: Fix blk_mq_sched_alloc_tags() error handling (Ming Lei) [1997338]
- loop: reintroduce global lock for safe loop_validate_file() traversal (Ming Lei) [1997338]
- blk-cgroup: prevent rcu_sched detected stalls warnings while iterating blkgs (Ming Lei) [1997338]
- block: fix the problem of io_ticks becoming smaller (Ming Lei) [1997338]
- block: return errors from blk_execute_rq() (Ming Lei) [1997338]
- block: support polling through blk_execute_rq (Ming Lei) [1997338]
- loop: rewrite loop_exit using idr_for_each_entry (Ming Lei) [1997338]
- loop: split loop_lookup (Ming Lei) [1997338]
- loop: don't allow deleting an unspecified loop device (Ming Lei) [1997338]
- loop: move loop_ctl_mutex locking into loop_add (Ming Lei) [1997338]
- loop: split loop_control_ioctl (Ming Lei) [1997338]
- loop: don't call loop_lookup before adding a loop device (Ming Lei) [1997338]
- loop: remove the l argument to loop_add (Ming Lei) [1997338]
- loop: reduce loop_ctl_mutex coverage in loop_exit (Ming Lei) [1997338]
- loop: reorder loop_exit (Ming Lei) [1997338]
- loop: Fix missing discard support when using LOOP_CONFIGURE (Ming Lei) [1997338]
- block: export blk_next_bio() (Ming Lei) [1997338]
- rsxx: Use struct_size() in vmalloc() (Ming Lei) [1997338]
- block/mq-deadline: Remove a WARN_ON_ONCE() call (Ming Lei) [1997338]
- blk: Fix lock inversion between ioc lock and bfqd lock (Ming Lei) [1997338]
- bfq: Remove merged request already in bfq_requests_merged() (Ming Lei) [1997338]
- block: fix trace completion for chained bio (Ming Lei) [1997338]
- block/partitions/msdos: Fix typo inidicator -> indicator (Ming Lei) [1997338]
- block, bfq: reset waker pointer with shared queues (Ming Lei) [1997338]
- block, bfq: check waker only for queues with no in-flight I/O (Ming Lei) [1997338]
- block, bfq: avoid delayed merge of async queues (Ming Lei) [1997338]
- block, bfq: boost throughput by extending queue-merging times (Ming Lei) [1997338]
- block, bfq: consider also creation time in delayed stable merge (Ming Lei) [1997338]
- block, bfq: fix delayed stable merge check (Ming Lei) [1997338]
- block, bfq: let also stably merged queues enjoy weight raising (Ming Lei) [1997338]
- blk-wbt: make sure throttle is enabled properly (Ming Lei) [1997338]
- blk-wbt: introduce a new disable state to prevent false positive by rwb_enabled() (Ming Lei) [1997338]
- block/mq-deadline: Prioritize high-priority requests (Ming Lei) [1997338]
- block/mq-deadline: Add cgroup support (Ming Lei) [1997338]
- block/mq-deadline: Track I/O statistics (Ming Lei) [1997338]
- block/mq-deadline: Add I/O priority support (Ming Lei) [1997338]
- block/mq-deadline: Micro-optimize the batching algorithm (Ming Lei) [1997338]
- block/mq-deadline: Reserve 25 of scheduler tags for synchronous requests (Ming Lei) [1997338]
- block/mq-deadline: Improve the sysfs show and store macros (Ming Lei) [1997338]
- block/mq-deadline: Improve compile-time argument checking (Ming Lei) [1997338]
- block: mq-deadline: Fix queue restart handling (Ming Lei) [1997338]
- block/mq-deadline: Rename dd_init_queue() and dd_exit_queue() (Ming Lei) [1997338]
- block/mq-deadline: Remove two local variables (Ming Lei) [1997338]
- block/mq-deadline: Add two lockdep_assert_held() statements (Ming Lei) [1997338]
- block/mq-deadline: Add several comments (Ming Lei) [1997338]
- block: Introduce the ioprio rq-qos policy (Ming Lei) [1997338]
- block/blk-rq-qos: Move a function from a header file into a C file (Ming Lei) [1997338]
- block/blk-cgroup: Swap the blk_throtl_init() and blk_iolatency_init() calls (Ming Lei) [1997338]
- blkcg: fix memleak for iolatency (Ming Lei) [1997338]
- blk-wbt: remove outdated comment (Ming Lei) [1997338]
- block: Remove unnecessary elevator operation checks (Ming Lei) [1997338]
- blk-mq: factor out a blk_mq_alloc_sq_tag_set helper (Ming Lei) [1997338]
- block: Update blk_update_request() documentation (Ming Lei) [1997338]
- blkcg: drop CLONE_IO check in blkcg_can_attach() (Ming Lei) [1997338]
- aoe: remove unnecessary mutex_init() (Ming Lei) [1997338]
- block: loop: fix deadlock between open and remove (Ming Lei) [1997338]
- loop: scale loop device by introducing per device lock (Ming Lei) [1997338]
- block/partitions/efi.c: Fix the efi_partition() kernel-doc header (Ming Lei) [1997338]
- nbd: share nbd_put and return by goto put_nbd (Ming Lei) [1997338]
- nbd: Fix NULL pointer in flush_workqueue (Ming Lei) [1997338]
- blkdev.h: remove unused codes blk_account_rq (Ming Lei) [1997338]
- block, bfq: avoid circular stable merges (Ming Lei) [1997338]
- block: uapi: fix comment about block device ioctl (Ming Lei) [1997338]
- block: reexpand iov_iter after read/write (Ming Lei) [1997338]
- bfq/mq-deadline: remove redundant check for passthrough request (Ming Lei) [1997338]
- blk-mq: bypass IO scheduler's limit_depth for passthrough request (Ming Lei) [1997338]
- block: Fix sys_ioprio_set(.which=IOPRIO_WHO_PGRP) task iteration (Ming Lei) [1997338]
- blk-mq: Always use blk_mq_is_sbitmap_shared (Ming Lei) [1997338]
- block: add sysfs entry for virt boundary mask (Ming Lei) [1997338]
- block, bfq: merge bursts of newly-created queues (Ming Lei) [1997338]
- block, bfq: keep shared queues out of the waker mechanism (Ming Lei) [1997338]
- block, bfq: fix weight-raising resume with !low_latency (Ming Lei) [1997338]
- block, bfq: make shared queues inherit wakers (Ming Lei) [1997338]
- block, bfq: put reqs of waker and woken in dispatch list (Ming Lei) [1997338]
- block, bfq: always inject I/O of queues blocked by wakers (Ming Lei) [1997338]
- blk-mq: Sentence reconstruct for better readability (Ming Lei) [1997338]
- block: update a few comments in uapi/linux/blkpg.h (Ming Lei) [1997338]
- block: don't ignore REQ_NOWAIT for direct IO (Ming Lei) [1997338]
- block: clear GD_NEED_PART_SCAN later in bdev_disk_changed (Ming Lei) [1997338]
- block: Discard page cache of zone reset target range (Ming Lei) [1997338]
- block: Suppress uevent for hidden device when removed (Ming Lei) [1997338]
- block: rsxx: fix error return code of rsxx_pci_probe() (Ming Lei) [1997338]
- block: Fix REQ_OP_ZONE_RESET_ALL handling (Ming Lei) [1997338]
- blk-cgroup: Fix the recursive blkg rwstat (Ming Lei) [1997338]
- rsxx: Return -EFAULT if copy_to_user() fails (Ming Lei) [1997338]
- block/bfq: update comments and default value in docs for fifo_expire (Ming Lei) [1997338]
- block: Drop leftover references to RQF_SORTED (Ming Lei) [1997338]
- blktrace: fix documentation for blk_fill_rw() (Ming Lei) [1997338]
- blktrace: remove debugfs file dentries from struct blk_trace (Ming Lei) [1997338]
- block: get rid of the trace rq insert wrapper (Ming Lei) [1997338]
- blktrace: fix blk_rq_merge documentation (Ming Lei) [1997338]
- blktrace: fix blk_rq_issue documentation (Ming Lei) [1997338]
- blktrace: add blk_fill_rwbs documentation comment (Ming Lei) [1997338]
- block: remove superfluous param in blk_fill_rwbs() (Ming Lei) [1997338]
- block: Remove unused blk_pm_*() function definitions (Ming Lei) [1997338]
- blk-mq: Use llist_head for blk_cpu_done (Ming Lei) [1997338]
- blk-mq: Always complete remote completions requests in softirq (Ming Lei) [1997338]
- block: use bi_max_vecs to find the bvec pool (Ming Lei) [1997338]
- md/raid10: remove dead code in reshape_request (Ming Lei) [1997338]
- block: remove the 1 and 4 vec bvec_slabs entries (Ming Lei) [1997338]
- block: streamline bvec_alloc (Ming Lei) [1997338]
- block: factor out a bvec_alloc_gfp helper (Ming Lei) [1997338]
- block: move struct biovec_slab to bio.c (Ming Lei) [1997338]
- block: reuse BIO_INLINE_VECS for integrity bvecs (Ming Lei) [1997338]
- block: move three bvec helpers declaration into private helper (Ming Lei) [1997338]
- blk-cgroup: Remove obsolete macro (Ming Lei) [1997338]
- block: use an on-stack bio in blkdev_issue_flush (Ming Lei) [1997338]
- blkcg: delete redundant get/put operations for queue (Ming Lei) [1997338]
- block: unexport truncate_bdev_range (Ming Lei) [1997338]
- blk: wbt: remove unused parameter from wbt_should_throttle (Ming Lei) [1997338]
- bdev: Do not return EBUSY if bdev discard races with write (Ming Lei) [1997338]
- bfq: don't duplicate code for different paths (Ming Lei) [1997338]
- block: remove the request_queue to argument request based tracepoints (Ming Lei) [1997338]
- virtio_net: disable cb aggressively (Stefan Hajnoczi) [1965914]
- virtio: fix up virtio_disable_cb (Stefan Hajnoczi) [1965914]
- virtio_net: move txq wakeups under tx q lock (Stefan Hajnoczi) [1965914]
- virtio_net: move tx vq operation under tx queue lock (Stefan Hajnoczi) [1965914]
- virtio_net: bulk free tx skbs (Stefan Hajnoczi) [1965914]
- [s390] s390/qdio: propagate error when cancelling a ccw fails (Mete Durlu) [1984989]
- [s390] s390/qdio: improve roll-back after error on ESTABLISH ccw (Mete Durlu) [1984989]
- [s390] s390/qdio: cancel the ESTABLISH ccw after timeout (Mete Durlu) [1984989]
- [s390] scsi: zfcp: Lift Request Queue tasklet & timer from qdio (Mete Durlu) [1984989]
- [s390] scsi: zfcp: Move the position of put_device() (Mete Durlu) [1984989]
- [s390] scsi: zfcp: Clean up sysfs code for SFP diagnostics (Mete Durlu) [1984989]
- [s390] scsi: zfcp: Fix sysfs roll-back on error in zfcp_adapter_enqueue() (Mete Durlu) [1984989]
- [s390] scsi: zfcp: Fix indentation coding style issue (Mete Durlu) [1984989]
- [s390] scsi: zfcp: Remove unneeded INIT_LIST_HEAD() for FSF requests (Mete Durlu) [1984989]
- x86/fpu/xstate: Clear xstate header in copy_xstate_to_uabi_buf() again (Prarit Bhargava) [1981448]
- x86/fpu/signal: Let xrstor handle the features to init (Prarit Bhargava) [1981448]
- x86/fpu/signal: Handle #PF in the direct restore path (Prarit Bhargava) [1981448]
- x86/fpu: Return proper error codes from user access functions (Prarit Bhargava) [1981448]
- x86/fpu/signal: Split out the direct restore code (Prarit Bhargava) [1981448]
- x86/fpu/signal: Sanitize copy_user_to_fpregs_zeroing() (Prarit Bhargava) [1981448]
- x86/fpu/signal: Sanitize the xstate check on sigframe (Prarit Bhargava) [1981448]
- x86/fpu/signal: Remove the legacy alignment check (Prarit Bhargava) [1981448]
- x86/fpu/signal: Move initial checks into fpu__restore_sig() (Prarit Bhargava) [1981448]
- x86/fpu: Mark init_fpstate __ro_after_init (Prarit Bhargava) [1981448]
- x86/pkru: Remove xstate fiddling from write_pkru() (Prarit Bhargava) [1981448]
- x86/fpu: Don't store PKRU in xstate in fpu_reset_fpstate() (Prarit Bhargava) [1981448]
- x86/fpu: Remove PKRU handling from switch_fpu_finish() (Prarit Bhargava) [1981448]
- x86/fpu: Mask PKRU from kernel XRSTOR[S] operations (Prarit Bhargava) [1981448]
- x86/fpu: Hook up PKRU into ptrace() (Prarit Bhargava) [1981448]
- x86/fpu: Add PKRU storage outside of task XSAVE buffer (Prarit Bhargava) [1981448]
- x86/fpu: Dont restore PKRU in fpregs_restore_userspace() (Prarit Bhargava) [1981448]
- x86/fpu: Rename xfeatures_mask_user() to xfeatures_mask_uabi() (Prarit Bhargava) [1981448]
- x86/fpu: Move FXSAVE_LEAK quirk info __copy_kernel_to_fpregs() (Prarit Bhargava) [1981448]
- x86/fpu: Rename copy_kernel_to_fpregs() to restore_fpregs_from_fpstate() (Prarit Bhargava) [1981448]
- x86/fpu: Rename __fpregs_load_activate() to fpregs_restore_userregs() (Prarit Bhargava) [1981448]
- x86/fpu: Clean up the fpu__clear() variants (Prarit Bhargava) [1981448]
- x86/fpu: Rename fpu__clear_all() to fpu_flush_thread() (Prarit Bhargava) [1981448]
- x86/fpu: Use pkru_write_default() in copy_init_fpstate_to_fpregs() (Prarit Bhargava) [1981448]
- x86/cpu: Write the default PKRU value when enabling PKE (Prarit Bhargava) [1981448]
- x86/pkru: Provide pkru_write_default() (Prarit Bhargava) [1981448]
- x86/pkru: Provide pkru_get_init_value() (Prarit Bhargava) [1981448]
- x86/cpu: Sanitize X86_FEATURE_OSPKE (Prarit Bhargava) [1981448]
- x86/pkeys: Move read_pkru() and write_pkru() (Prarit Bhargava) [1981448]
- x86/fpu: Rename and sanitize fpu__save/copy() (Prarit Bhargava) [1981448]
- x86/fpu/xstate: Sanitize handling of independent features (Prarit Bhargava) [1981448]
- x86/fpu: Rename "dynamic" XSTATEs to "independent" (Prarit Bhargava) [1981448]
- x86/fpu: Rename initstate copy functions (Prarit Bhargava) [1981448]
- x86/fpu: Get rid of the FNSAVE optimization (Prarit Bhargava) [1981448]
- x86/fpu: Rename copy_fpregs_to_fpstate() to save_fpregs_to_fpstate() (Prarit Bhargava) [1981448]
- x86/fpu: Deduplicate copy_uabi_from_user/kernel_to_xstate() (Prarit Bhargava) [1981448]
- x86/fpu: Rename xstate copy functions which are related to UABI (Prarit Bhargava) [1981448]
- x86/fpu: Rename fregs-related copy functions (Prarit Bhargava) [1981448]
- x86/math-emu: Rename frstor() (Prarit Bhargava) [1981448]
- x86/fpu: Rename fxregs-related copy functions (Prarit Bhargava) [1981448]
- x86/fpu: Get rid of CONFIG_AS_FXSAVEQ (Prarit Bhargava) [1981448]
- x86/fpu: Rename copy_user_to_xregs() and copy_xregs_to_user() (Prarit Bhargava) [1981448]
- x86/fpu: Rename copy_xregs_to_kernel() and copy_kernel_to_xregs() (Prarit Bhargava) [1981448]
- x86/fpu: Get rid of copy_supervisor_to_kernel() (Prarit Bhargava) [1981448]
- x86/fpu: Cleanup arch_set_user_pkey_access() (Prarit Bhargava) [1981448]
- x86/kvm: Avoid looking up PKRU in XSAVE buffer (Prarit Bhargava) [1981448]
- x86/fpu: Get rid of using_compacted_format() (Prarit Bhargava) [1981448]
- x86/fpu: Move fpu__write_begin() to regset (Prarit Bhargava) [1981448]
- x86/fpu/regset: Move fpu__read_begin() into regset (Prarit Bhargava) [1981448]
- x86/fpu: Remove fpstate_sanitize_xstate() (Prarit Bhargava) [1981448]
- x86/fpu: Use copy_xstate_to_uabi_buf() in fpregs_get() (Prarit Bhargava) [1981448]
- x86/fpu: Use copy_xstate_to_uabi_buf() in xfpregs_get() (Prarit Bhargava) [1981448]
- x86/fpu: Make copy_xstate_to_kernel() usable for [x]fpregs_get() (Prarit Bhargava) [1981448]
- x86/fpu: Clean up fpregs_set() (Prarit Bhargava) [1981448]
- x86/fpu: Fail ptrace() requests that try to set invalid MXCSR values (Prarit Bhargava) [1981448]
- x86/fpu: Rewrite xfpregs_set() (Prarit Bhargava) [1981448]
- x86/fpu: Simplify PTRACE_GETREGS code (Prarit Bhargava) [1981448]
- x86/fpu: Reject invalid MXCSR values in copy_kernel_to_xstate() (Prarit Bhargava) [1981448]
- x86/fpu: Sanitize xstateregs_set() (Prarit Bhargava) [1981448]
- x86/fpu: Move inlines where they belong (Prarit Bhargava) [1981448]
- x86/fpu: Get rid of fpu__get_supported_xfeatures_mask() (Prarit Bhargava) [1981448]
- x86/fpu: Make xfeatures_mask_all __ro_after_init (Prarit Bhargava) [1981448]
- x86/fpu: Mark various FPU state variables __ro_after_init (Prarit Bhargava) [1981448]
- x86/pkeys: Revert a5eff7259790 ("x86/pkeys: Add PKRU value to init_fpstate") (Prarit Bhargava) [1981448]
- x86/fpu: Fix copy_xstate_to_kernel() gap handling (Prarit Bhargava) [1981448]
- x86/fpu: Limit xstate copy size in xstateregs_set() (Prarit Bhargava) [1981448]
- x86/fpu: Make init_fpstate correct with optimized XSAVE (Prarit Bhargava) [1981448]
- x86/fpu: Preserve supervisor states in sanitize_restored_user_xstate() (Prarit Bhargava) [1981448]
- x86/fpu: Reset state for all signal restore failures (Prarit Bhargava) [1981448]
- x86/signal: Introduce helpers to get the maximum signal frame size (Prarit Bhargava) [1981448]
- x86/fpu: Fix various typos in comments (Prarit Bhargava) [1981448]
- x86/fpu/xstate: Use sizeof() instead of a constant (Prarit Bhargava) [1981448]
- x86/fpu: Handle FPU-related and clearcpuid command line arguments earlier (Prarit Bhargava) [1981448]
- x86/fpu: Allow multiple bits in clearcpuid= parameter (Prarit Bhargava) [1981448]
- x86: switch to ->regset_get() (Prarit Bhargava) [1981448]
- regset: new method and helpers for it (Prarit Bhargava) [1981448]
- copy_regset_to_user(): do all copyout at once. (Prarit Bhargava) [1981448]
- introduction of regset ->get() wrappers, switching ELF coredumps to those (Prarit Bhargava) [1981448]
- user_regset_copyout_zero(): use clear_user() (Prarit Bhargava) [1981448]
- x86: kill dump_fpu() (Prarit Bhargava) [1981448]
- x86: copy_fpstate_to_sigframe(): have fpregs_soft_get() use kernel buffer (Prarit Bhargava) [1981448]
- x86/pkeys: Add check for pkey "overflow" (Prarit Bhargava) [1981448]
- x86/fpu: Deactivate FPU state after failure during state load (Prarit Bhargava) [1981448]
- x86/fpu: Use sizeof_field() macro (Prarit Bhargava) [1981448]
- x86/fpu: Inline fpu__xstate_clear_all_cpu_caps() (Prarit Bhargava) [1981448]
- x86/fpu: Make 'no387' and 'nofxsr' command line options useful (Prarit Bhargava) [1981448]
- x86/fpu: Remove the fpu__save() export (Prarit Bhargava) [1981448]
- x86/process: Add AVX-512 usage elapsed time to /proc/pid/arch_status (Prarit Bhargava) [1981448]
- x86/fpu: Add SPDX license identifier - Makefile/Kconfig (Prarit Bhargava) [1981448]
- x86/fpu: Add SPDX license identifier for missed files (Prarit Bhargava) [1981448]
- x86/fpu: Fix __user annotations (Prarit Bhargava) [1981448]
- x86/fpu: Move init_xstate_size() to __init section (Prarit Bhargava) [1981448]
- x86/fpu: Update comment for __raw_xsave_addr() (Prarit Bhargava) [1981448]
- scsi: qla2xxx: Fix kernel crash when accessing port_speed sysfs file (Nilesh Javali) [1981433]
- scsi: core: Put LLD module refcnt after SCSI device is released (Ming Lei) [1996509]
- scsi: iscsi: Fix set_param() handling (Chris Leech) [2011470]
- scsi: iscsi: Fix iscsi_task use after free (Chris Leech) [2011470]
- scsi: iscsi: Adjust iface sysfs attr detection (Chris Leech) [2011470]
- scsi: iscsi: Fix iface sysfs attr detection (Chris Leech) [2011470]
- scsi: iscsi: Move pool freeing (Chris Leech) [2011470]
- scsi: iscsi: Hold task ref during TMF timeout handling (Chris Leech) [2011470]
- scsi: iscsi: Flush block work before unblock (Chris Leech) [2011470]
- scsi: iscsi: Fix completion check during abort races (Chris Leech) [2011470]
- scsi: iscsi: Fix shost->max_id use (Chris Leech) [2011470]
- scsi: iscsi: Fix conn use after free during resets (Chris Leech) [2011470]
- scsi: iscsi: Get ref to conn during reset handling (Chris Leech) [2011470]
- scsi: iscsi: Have abort handler get ref to conn (Chris Leech) [2011470]
- scsi: iscsi: Add iscsi_cls_conn refcount helpers (Chris Leech) [2011470]
- scsi: iscsi: iscsi_tcp: Start socket shutdown during conn stop (Chris Leech) [2011470]
- scsi: iscsi: iscsi_tcp: Set no linger (Chris Leech) [2011470]
- scsi: iscsi: Fix in-kernel conn failure handling (Chris Leech) [2011470]
- scsi: iscsi: Rel ref after iscsi_lookup_endpoint() (Chris Leech) [2011470]
- scsi: iscsi: Use system_unbound_wq for destroy_work (Chris Leech) [2011470]
- scsi: iscsi: Force immediate failure during shutdown (Chris Leech) [2011470]
- scsi: iscsi: Drop suspend calls from ep_disconnect (Chris Leech) [2011470]
- scsi: iscsi: Stop queueing during ep_disconnect (Chris Leech) [2011470]
- scsi: iscsi: Add task completion helper (Chris Leech) [2011470]
- scsi: iscsi: Fix iSCSI cls conn state (Chris Leech) [2011470]
- scsi: iscsi: Fix race condition between login and sync thread (Chris Leech) [2011470]
- scsi: iscsi: Drop session lock in iscsi_session_chkready() (Chris Leech) [2011470]
- scsi: libiscsi: Reset max/exp cmdsn during recovery (Chris Leech) [2011470]
- scsi: iscsi_tcp: Fix shost can_queue initialization (Chris Leech) [2011470]
- scsi: libiscsi: Add helper to calculate max SCSI cmds per session (Chris Leech) [2011470]
- scsi: libiscsi: Fix iSCSI host workq destruction (Chris Leech) [2011470]
- scsi: libiscsi: Fix iscsi_task use after free() (Chris Leech) [2011470]
- scsi: libiscsi: Drop taskqueuelock (Chris Leech) [2011470]
- scsi: libiscsi: Fix iscsi_prep_scsi_cmd_pdu() error handling (Chris Leech) [2011470]
- scsi: iscsi: Fix inappropriate use of put_device() (Chris Leech) [2011470]
- scsi: iscsi: Fail session and connection on transport registration failure (Chris Leech) [2011470]
- scsi: drivers: base: Propagate errors through the transport component (Chris Leech) [2011470]
- scsi: drivers: base: Support atomic version of attribute_container_device_trigger (Chris Leech) [2011470]
- scsi: libiscsi: Fix NOP race condition (Chris Leech) [2011470]
- scsi: libiscsi: use sendpage_ok() in iscsi_tcp_segment_map() (Chris Leech) [2011470]
- scsi: iscsi: iscsi_tcp: Avoid holding spinlock while calling getpeername() (Chris Leech) [2011470]
- scsi: iscsi: Do not put host in iscsi_set_flashnode_param() (Chris Leech) [2011470]
- scsi: iscsi: Register sysfs for workqueue iscsi_destroy (Chris Leech) [2011470]
- scsi: iscsi: Remove sessdestroylist (Chris Leech) [2011470]
- scsi: iscsi: Optimize work queue flush use (Chris Leech) [2011470]
- scsi: iscsi: Delay freeing target_id (Chris Leech) [2011470]
- scsi: iscsi: Change iSCSI workqueue max_active back to 1 (Chris Leech) [2011470]
- scsi: iscsi: Fix reference count leak in iscsi_boot_create_kobj (Chris Leech) [2011470]

* Fri Nov 12 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-349.el8]
- scsi: qedf: Fix error codes in qedf_alloc_global_queues() (Nilesh Javali) [1983908]
- scsi: qedf: Add check to synchronize abort and flush (Nilesh Javali) [1983908]
- scsi: qedf: Use DEVICE_ATTR_RO() macro (Nilesh Javali) [1983908]
- scsi: qedf: Use vzalloc() instead of vmalloc()/memset(0) (Nilesh Javali) [1983908]
- scsi: qedf: Drop unnecessary NULL checks after container_of() (Nilesh Javali) [1983908]
- scsi: qedf: Use devlink to report errors and recovery (Nilesh Javali) [1983908]
- scsi: qedf: Enable devlink support (Nilesh Javali) [1983908]
- scsi: qedf: Remove unused include of linux/version.h (Nilesh Javali) [1983908]
- qed: implement devlink dump (Nilesh Javali) [1983908]
- qed*: make use of devlink recovery infrastructure (Nilesh Javali) [1983908]
- qed: use devlink logic to report errors (Nilesh Javali) [1983908]
- qed: health reporter init deinit seq (Nilesh Javali) [1983908]
- qed: implement devlink info request (Nilesh Javali) [1983908]
- qed/qede: make devlink survive recovery (Nilesh Javali) [1983908]
- qed: move out devlink logic into a new file (Nilesh Javali) [1983908]
- i40e: fix endless loop under rtnl (Stefan Assmann) [1903921]
- ovl: fix missing negative dentry check in ovl_rename() (Miklos Szeredi) [2010887] {CVE-2021-20321}
- [RHEL8.6 BZ 1849234] cifs: report error instead of invalid when revalidating a dentry fails (Ronnie Sahlberg) [1849234]
- mei: me: emmitsburg workstation DID (David Arcari) [2014195]
- redhat/configs: Add CONFIG_INTEL_QEP (Prarit Bhargava) [1783559]
- redhat/configs: Add CONFIG_COUNTER (Prarit Bhargava) [1783559]
- counter: Rename counter_count_function to counter_function (Prarit Bhargava) [1783559]
- counter: Rename counter_signal_value to counter_signal_level (Prarit Bhargava) [1783559]
- counter: Standardize to ERANGE for limit exceeded errors (Prarit Bhargava) [1783559]
- counter: intel-qep: Remove linux/bitops.h include (Prarit Bhargava) [1783559]
- counter: intel-qep: Use to_pci_dev() helper (Prarit Bhargava) [1783559]
- counter: intel-qep: Mark PM callbacks with __maybe_unused (Prarit Bhargava) [1783559]
- counter: Add support for Intel Quadrature Encoder Peripheral (Prarit Bhargava) [1783559]
- counter: Simplify the count_read and count_write callbacks (Prarit Bhargava) [1783559]
- drivers/counter: Add SPDX license identifier - Makefile/Kconfig (Prarit Bhargava) [1783559]
- counter: Introduce the Generic Counter interface (Prarit Bhargava) [1783559]
- bpf: Fix integer overflow in prealloc_elems_and_freelist() (Yauheni Kaliuta) [2010492] {CVE-2021-41864}
- audit: move put_tree() to avoid trim_trees refcount underflow and UAF (Richard Guy Briggs) [1978123]
- tpm: ibmvtpm: Avoid error message when process gets signal while waiting (Štěpán Horáček) [1981473]
- efi/tpm: Differentiate missing and invalid final event log table. (Štěpán Horáček) [1981473]
- tpm: Replace WARN_ONCE() with dev_err_once() in tpm_tis_status() (Štěpán Horáček) [1981473]
- tpm_tis: Use DEFINE_RES_MEM() to simplify code (Štěpán Horáček) [1981473]
- tpm: fix some doc warnings in tpm1-cmd.c (Štěpán Horáček) [1981473]
- tpm_tis_spi: add missing SPI device ID entries (Štěpán Horáček) [1981473]
- tpm: add longer timeout for TPM2_CC_VERIFY_SIGNATURE (Štěpán Horáček) [1981473]
- tpm_tis_spi: set default probe function if device id not match (Štěpán Horáček) [1981473]
- tpm_crb: Use IOMEM_ERR_PTR when function returns iomem (Štěpán Horáček) [1981473]
- tools/testing/scatterlist: Fix overflow of max segment size (Rafael Aquini) [2016426]
- drm: Remove SCATTERLIST_MAX_SEGMENT (Rafael Aquini) [2016426]
- lib/scatterlist: Fix wrong update of orig_nents (Rafael Aquini) [2016426]
- lib/scatterlist: Provide a dedicated function to support table append (Rafael Aquini) [2016426]
- tools/testing/scatterlist: Test dynamic __sg_alloc_table_from_pages (Rafael Aquini) [2016426]
- tools/testing/scatterlist: Fix test to compile and run (Rafael Aquini) [2016426]
- tools/testing/scatterlist: Show errors in human readable form (Rafael Aquini) [2016426]
- tools/testing/scatterlist: Rejuvenate bit-rotten test (Rafael Aquini) [2016426]
- Kconfig.debug: drop selecting non-existing HARDLOCKUP_DETECTOR_ARCH (Rafael Aquini) [2016426]
- buildid: only consider GNU notes for build ID parsing (Rafael Aquini) [2016426]
- lib/decompressors: remove set but not used variabled 'level' (Rafael Aquini) [2016426]
- lib/math/rational.c: fix divide by zero (Rafael Aquini) [2016426]
- lockdep/selftests: Fix selftests vs PROVE_RAW_LOCK_NESTING (Rafael Aquini) [2016426]
- kunit: Fix result propagation for parameterised tests (Rafael Aquini) [2016426]
- bug: Remove redundant condition check in report_bug (Rafael Aquini) [2016426]
- zlib: move EXPORT_SYMBOL() and MODULE_LICENSE() out of dfltcc_syms.c (Rafael Aquini) [2016426]
- zlib: export S390 symbols for zlib modules (Rafael Aquini) [2016426]
- lib/crc32test: remove extra local_irq_disable/enable (Rafael Aquini) [2016426]
- random32: add a selftest for the prandom32 code (Rafael Aquini) [2016426]
- random32: add noise from network and scheduling activity (Rafael Aquini) [2016426]
- random32: make prandom_u32() output unpredictable (Rafael Aquini) [2016426]
- lib: Correct comment of prandom_seed (Rafael Aquini) [2016426]
- lib/crc32.c: fix trivial typo in preprocessor condition (Rafael Aquini) [2016426]
- lib/crc: Use consistent naming for CRC-32 polynomials (Rafael Aquini) [2016426]
- lib/crc: Move polynomial definition to separate header (Rafael Aquini) [2016426]
- kstrto*: do not describe simple_strto*() as obsolete/replaced (Rafael Aquini) [2016426]
- kstrto*: correct documentation references to simple_strto*() (Rafael Aquini) [2016426]
- kernel.h: update comment about simple_strto<foo>() functions (Rafael Aquini) [2016426]
- lib/bitmap.c: fix bitmap_cut() for partial overlapping case (Rafael Aquini) [2016426]
- devres: keep both device name and resource name in pretty name (Rafael Aquini) [2016426]
- crc-t10dif: Fix potential crypto notify dead-lock (Rafael Aquini) [2016426]
- vsprintf: don't obfuscate NULL and error pointers (Rafael Aquini) [2016426]
- lib/stackdepot.c: fix global out-of-bounds in stack_slabs (Rafael Aquini) [2016426]
- lib/scatterlist.c: adjust indentation in __sg_alloc_table (Rafael Aquini) [2016426]
- lib/stackdepot: Fix outdated comments (Rafael Aquini) [2016426]
- lib/test_kasan.c: fix memory leak in kmalloc_oob_krealloc_more() (Rafael Aquini) [2016426]
- lib: Remove select of inexistant GENERIC_IO (Rafael Aquini) [2016426]
- lib: test_user_copy: style cleanup (Rafael Aquini) [2016426]
- usercopy: Add parentheses around assignment in test_copy_struct_from_user (Rafael Aquini) [2016426]
- lib: textsearch: fix escapes in example code (Rafael Aquini) [2016426]
- Partially revert "kfifo: fix kfifo_alloc() and kfifo_init()" (Rafael Aquini) [2016426]
- lib: logic_pio: Fix RCU usage (Rafael Aquini) [2016426]
- lib/test_overflow.c: avoid tainting the kernel and fix wrap size (Rafael Aquini) [2016426]
- lib/test_string.c: avoid masking memset16/32/64 failures (Rafael Aquini) [2016426]
- lib/scatterlist: Fix mapping iterator when sg->offset is greater than PAGE_SIZE (Rafael Aquini) [2016426]
- lib/mpi: Fix karactx leak in mpi_powm (Rafael Aquini) [2016426]
- sbitmap: fix improper use of smp_mb__before_atomic() (Rafael Aquini) [2016426]
- kobject: Don't trigger kobject_uevent(KOBJ_REMOVE) twice. (Rafael Aquini) [2016426]
- lib/div64.c: off by one in shift (Rafael Aquini) [2016426]
- assoc_array: Fix shortcut creation (Rafael Aquini) [2016426]
- lib/test_kmod.c: potential double free in error handling (Rafael Aquini) [2016426]
- devres: always use dev_name() in devm_ioremap_resource() (Rafael Aquini) [2016426]
- lib: fix build failure in CONFIG_DEBUG_VIRTUAL test (Rafael Aquini) [2016426]
- test_firmware: fix error return getting clobbered (Rafael Aquini) [2016426]
- lib: Fix ia64 bootloader linkage (Rafael Aquini) [2016426]
- lib/test_hexdump.c: fix failure on big endian cpu (Rafael Aquini) [2016426]
- hv_utils: Set the maximum packet size for VSS driver to the length of the receive buffer (Cathy Avery) [2012842]
- scsi: storvsc: Log TEST_UNIT_READY errors as warnings (Cathy Avery) [2012842]
- scsi: storvsc: Correctly handle multiple flags in srb_status (Cathy Avery) [2012842]
- scsi: storvsc: Update error logging (Cathy Avery) [2012842]
- scsi: storvsc: Miscellaneous code cleanups (Cathy Avery) [2012842]
- scsi: storvsc: Use blk_mq_unique_tag() to generate requestIDs (Cathy Avery) [2012842]
- Drivers: hv: vmbus: Copy packets sent by Hyper-V out of the ring buffer (Cathy Avery) [2012842]
- scsi: core: Fix hang of freezing queue between blocking and running device (Ewan D. Milne) [2012323]
- scsi: core: Fix capacity set to zero after offlinining device (Ewan D. Milne) [2012323]
- scsi: sr: Return correct event when media event code is 3 (Ewan D. Milne) [2012323]
- scsi: core: Avoid printing an error if target_alloc() returns -ENXIO (Ewan D. Milne) [2012323]
- scsi: scsi_dh_rdac: Avoid crash during rdac_bus_attach() (Ewan D. Milne) [2012323]
- scsi: core: Fix bad pointer dereference when ehandler kthread is invalid (Ewan D. Milne) [2012323]
- scsi: core: Fix the documentation of the scsi_execute() time parameter (Ewan D. Milne) [2012323]
- scsi: core: Retry I/O for Notify (Enable Spinup) Required error (Ewan D. Milne) [2012323]
- scsi: sd: Call sd_revalidate_disk() for ioctl(BLKRRPART) (Ewan D. Milne) [2012323]
- scsi: core: Inline scsi_mq_alloc_queue() (Ewan D. Milne) [2012323]
- scsi: sr: Return appropriate error code when disk is ejected (Ewan D. Milne) [2012323]
- scsi: core: Only put parent device if host state differs from SHOST_CREATED (Ewan D. Milne) [2012323]
- scsi: core: Put .shost_dev in failure path if host state changes to RUNNING (Ewan D. Milne) [2012323]
- scsi: core: Fix failure handling of scsi_add_host_with_dma() (Ewan D. Milne) [2012323]
- scsi: core: Fix error handling of scsi_host_alloc() (Ewan D. Milne) [2012323]
- scsi: st: Return error code in st_scsi_execute() (Ewan D. Milne) [2012323]
- scsi: scsi_dh_alua: Retry RTPG on a different path after failure (Ewan D. Milne) [2012323]
- scsi: scsi_transport_fc: Remove double FC_FPORT_DELETED in mask creation (Ewan D. Milne) [2012323]
- scsi: core: Fix a comment in function scsi_host_dev_release() (Ewan D. Milne) [2012323]
- scsi: scsi_debug: Drop if with an always false condition (Ewan D. Milne) [2012323]
- scsi: scsi_debug: Fix cmd_per_lun, set to max_queue (Ewan D. Milne) [2012323]
- scsi: sd: Introduce a new local variable in sd_check_events() (Ewan D. Milne) [2012323]
- scsi: core: Modify the scsi_send_eh_cmnd() return value for the SDEV_BLOCK case (Ewan D. Milne) [2012323]
- scsi: core: Rename scsi_softirq_done() into scsi_complete() (Ewan D. Milne) [2012323]
- scsi: core: Remove an incorrect comment (Ewan D. Milne) [2012323]
- scsi: core: Make the scsi_alloc_sgtables() documentation more accurate (Ewan D. Milne) [2012323]
- scsi: scsi_dh_alua: Prevent duplicate pg info print in alua_rtpg() (Ewan D. Milne) [2012323]
- scsi: core: scsi_host_cmd_pool is declared twice (Ewan D. Milne) [2012323]
- scsi: core: Remove duplicate declarations (Ewan D. Milne) [2012323]
- scsi: core: Fix comment typo (Ewan D. Milne) [2012323]
- scsi: scsi_dh: Fix a typo (Ewan D. Milne) [2012323]
- scsi: sd: Fix function name in header (Ewan D. Milne) [2012323]
- scsi: sd_zbc: Place function name into header (Ewan D. Milne) [2012323]
- scsi: sd_zbc: Update write pointer offset cache (Ewan D. Milne) [2012323]
- scsi: st: Fix a use after free in st_open() (Ewan D. Milne) [2012323]
- scsi: scsi_debug: Fix cmd duration calculation (Ewan D. Milne) [2012323]
- scsi: core: Set shost as hctx driver_data (Ewan D. Milne) [2012323]
- scsi: scsi_debug: Add new defer type for mq_poll (Ewan D. Milne) [2012323]
- scsi: scsi_debug: mq_poll support (Ewan D. Milne) [2012323]
- scsi: core: Add mq_poll support to SCSI layer (Ewan D. Milne) [2012323]
- scsi: sd: Remove obsolete variable in sd_remove() (Ewan D. Milne) [2012323]
- scsi: handle zone resources errors (Ewan D. Milne) [2012323]
- scsi: scsi_debug: Fix scp is NULL errors (Ewan D. Milne) [2012323]
- scsi: scsi_debug: Improve command duration calculation (Ewan D. Milne) [2012323]
- x86/platform: Increase maximum GPIO number for X86_64 (David Arcari) [2016796]
- pinctrl: pinconf-generic: Add function parameter description 'pctldev' (David Arcari) [2016796]
- pinctrl: core: Remove duplicated word from devm_pinctrl_unregister() (David Arcari) [2016796]
- pinctrl: tigerlake: Fix GPIO mapping for newer version of software (David Arcari) [2016796]
- pinctrl: tigerlake: Add Alder Lake-M ACPI ID (David Arcari) [2016796]
- docs: update pin-control.rst references (David Arcari) [2016796]
- pinctrl: Keep enum pin_config_param ordered by name (part 2) (David Arcari) [2016796]
- pinctrl: core: Show pin numbers for the controllers with base = 0 (David Arcari) [2016796]
- pinctrl: Add PIN_CONFIG_MODE_PWM to enum pin_config_param (David Arcari) [2016796]
- pinctrl: Introduce MODE group in enum pin_config_param (David Arcari) [2016796]
- pinctrl: Keep enum pin_config_param ordered by name (David Arcari) [2016796]
- pinctrl: core: Fix kernel doc string for pin_get_name() (David Arcari) [2016796]
- pinctrl: intel: check REVID register value for device presence (David Arcari) [2016796]
- pinctrl: intel: No need to disable IRQs in the handler (David Arcari) [2016796]
- pinctrl: core: Set ret to 0 when group is skipped (David Arcari) [2016796]
- pinctrl: core: Handling pinmux and pinconf separately (David Arcari) [2016796]
- Documentation: rename pinctl to pin-control (David Arcari) [2016796]
- pinctrl: pinmux: Add pinmux-select debugfs file (David Arcari) [2016796]
- pinctrl: use to octal permissions for debugfs files (David Arcari) [2016796]
- pinctrl: intel: Show the GPIO base calculation explicitly (David Arcari) [2016796]
- pinctrl: pinmux: add function selector to pinmux-functions (David Arcari) [2016796]
- pinctrl: intel: Convert capability list to features (David Arcari) [2016796]
- pinctrl: intel: Drop unnecessary check for predefined features (David Arcari) [2016796]
- pinctrl: intel: Split intel_pinctrl_add_padgroups() for better maintenance (David Arcari) [2016796]
- pinctrl: remove empty lines in pinctrl subsystem (David Arcari) [2016796]
- pinctrl: intel: Actually disable Tx and Rx buffers on GPIO request (David Arcari) [2016796]
- pinctrl: Remove hole in pinctrl_gpio_range (David Arcari) [2016796]
- pinctrl: core: Add missing #ifdef CONFIG_GPIOLIB (David Arcari) [2016796]
- pinctrl: intel: Set default bias in case no particular value given (David Arcari) [2016796]
- pinctrl: intel: Fix 2 kOhm bias which is 833 Ohm (David Arcari) [2016796]
- pinctrl: core: print gpio in pins debugfs file (David Arcari) [2016796]
- pinctrl: pinmux: Add some missing parameter descriptions (David Arcari) [2016796]
- pinctrl: core: Fix a bunch of kerneldoc issues (David Arcari) [2016796]
- pinctrl: Define of_pinctrl_get() dummy for !PINCTRL (David Arcari) [2016796]
- pinctrl: core: Remove extra kref_get which blocks hogs being freed (David Arcari) [2016796]
- pinctrl: Export some needed symbols at module load time (David Arcari) [2016796]
- pinctrl: core: Add pinctrl_select_default_state() and export it (David Arcari) [2016796]
- pinctrl: make pinconf.h self-contained (David Arcari) [2016796]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 194 (David Arcari) [2016796]
- pinctrl: remove pinctrl/machine.h inclusion from pinctrl/pinconf.h (David Arcari) [2016796]
- pinctrl: Document pin_config_group_get() return codes like pin_config_get() (David Arcari) [2016796]
- pinctrl: intel: Convert to use SPDX identifier (David Arcari) [2016796]
- mm/swapfile: fix an integer overflow in swap_show() (Rafael Aquini) [2008812]
- mm: swapfile: fix /proc/swaps heading and Size/Used/Priority alignment (Rafael Aquini) [2008812]
- Makefile: update early devel phase flag (Augusto Caringi) [2000679]
- KVM: s390: Enable specification exception interpretation (Thomas Huth) [1984894]
- KVM: x86: Update vCPU's hv_clock before back to guest when tsc_offset is adjusted (Marcelo Tosatti) [2007928]
- ibmvnic: Remove the proper scrq flush (Desnes A. Nunes do Rosario) [2014097]
- selftests/net/ipsec: Add test for xfrm_spdattr_type_t (Hangbin Liu) [2018056]
- selftest/net/ipsec.c: Remove unneeded semicolon (Hangbin Liu) [2018056]
- selftest/net/xfrm: Add test for ipsec tunnel (Hangbin Liu) [2018056]
- ipv6: add ip6_sock_set_v6only (Josef Oskera) [2008908]
- ipv6: When forwarding count rx stats on the orig netdev (Hangbin Liu) [2017704]
- ipv6: make exception cache less predictible (Hangbin Liu) [2017704]
- ipv6: use siphash in rt6_exception_hash() (Hangbin Liu) [2017704]
- ipv6: use jhash2() in rt6_exception_hash() (Hangbin Liu) [2017704]
- net/l2tp: Fix reference count leak in l2tp_udp_recv_core (Guillaume Nault) [2020380]
- netfilter: nft_flow_offload: fix underflow in flowtable reference counter (Phil Sutter) [2008551]
- net: xfrm: Fix end of loop tests for list_for_each_entry (Sabrina Dubroca) [2019168]
- xfrm: Fix error reporting in xfrm_state_construct. (Sabrina Dubroca) [2019168]

* Fri Nov 05 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-348.6.el8]
- nvme-mpath: replace direct_make_request with generic_make_request (Gopal Tiwari) [2013505]
- net-sysfs: try not to restart the syscall if it will fail eventually (Antoine Tenart) [2016005]
- net: mana: Fix error handling in mana_create_rxq() (Mohammed Gamal) [2011886]
- net: mana: Prefer struct_size over open coded arithmetic (Mohammed Gamal) [2011886]
- net: mana: Add WARN_ON_ONCE in case of CQE read overflow (Mohammed Gamal) [2011886]
- net: mana: Add support for EQ sharing (Mohammed Gamal) [2011886]
- net: mana: Move NAPI from EQ to CQ (Mohammed Gamal) [2011886]
- net: mana: Fix a memory leak in an error handling path in 'mana_create_txq()' (Mohammed Gamal) [2011886]
- net: mana: Use struct_size() in kzalloc() (Mohammed Gamal) [2011886]
- vmxnet3: switch from 'pci_' to 'dma_' API (Kamal Heib) [2013202]
- vmxnet3: update to version 6 (Kamal Heib) [2013202]
- vmxnet3: increase maximum configurable mtu to 9190 (Kamal Heib) [2013202]
- vmxnet3: set correct hash type based on rss information (Kamal Heib) [2013202]
- vmxnet3: add support for ESP IPv6 RSS (Kamal Heib) [2013202]
- vmxnet3: remove power of 2 limitation on the queues (Kamal Heib) [2013202]
- vmxnet3: add support for 32 Tx/Rx queues (Kamal Heib) [2013202]
- vmxnet3: prepare for version 6 changes (Kamal Heib) [2013202]
- vmxnet3: fix cksum offload issues for tunnels with non-default udp ports (Kamal Heib) [2013202]
- treewide: Use fallthrough pseudo-keyword (Kamal Heib) [2013202]
- net: Use skb_frag_off accessors (Kamal Heib) [2013202]
- net: Use skb accessors in network drivers (Kamal Heib) [2013202]
- vmxnet3: Remove call to memset after dma_alloc_coherent (Kamal Heib) [2013202]
- cgroup/debug: Fix lockdep splat with "pK" format specifier (Waiman Long) [2007919]
- configs: Enable FC_APPID (Ewan D. Milne) [1643346]
- configs: Enable BLK_CGROUP_FC_APPID (Ewan D. Milne) [1643346]
- scsi: nvme: Added a new sysfs attribute appid_store (Ewan D. Milne) [1643346]
- scsi: blkcg: Add app identifier support for blkcg (Ewan D. Milne) [1643346]
- scsi: cgroup: Add cgroup_get_from_id() (Ewan D. Milne) [1643346]
- perf iostat: Fix Segmentation fault from NULL 'struct perf_counts_values *' (Michael Petlan) [2003981]
- perf iostat: Use system-wide mode if the target cpu_list is unspecified (Michael Petlan) [2003981]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2003981]
- perf test: Fix non-bash issue with stat bpf counters (Michael Petlan) [2003981]
- perf machine: Fix refcount usage when processing PERF_RECORD_KSYMBOL (Michael Petlan) [2003981]
- perf metricgroup: Return error code from metricgroup__add_metric_sys_event_iter() (Michael Petlan) [2003981]
- perf metricgroup: Fix find_evsel_group() event selector (Michael Petlan) [2003981]
- perf session: Correct buffer copying when peeking events (Michael Petlan) [2003981]
- perf env: Fix memory leak of bpf_prog_info_linear member (Michael Petlan) [2003981]
- perf symbol-elf: Fix memory leak by freeing sdt_note.args (Michael Petlan) [2003981]
- perf stat: Honor event config name on --no-merge (Michael Petlan) [2003981]
- perf test: Test 17 fails with make LIBPFM4=1 on s390 z/VM (Michael Petlan) [2003981]
- perf stat: Fix error return code in bperf__load() (Michael Petlan) [2003981]
- perf record: Move probing cgroup sampling support (Michael Petlan) [2003981]
- perf probe: Fix NULL pointer dereference in convert_variable_location() (Michael Petlan) [2003981]
- perf tools: Copy uapi/asm/perf_regs.h from the kernel for MIPS (Michael Petlan) [2003981]
- perf stat: Fix error check for bpf_program__attach (Michael Petlan) [2003981]
- perf jevents: Fix getting maximum number of fds (Michael Petlan) [2003981]
- perf stat: Skip evlist__[enable|disable] when all events uses BPF (Michael Petlan) [2003981]
- perf script: Add missing PERF_IP_FLAG_CHARS for VM-Entry and VM-Exit (Michael Petlan) [2003981]
- perf scripts python: exported-sql-viewer.py: Fix warning display (Michael Petlan) [2003981]
- perf scripts python: exported-sql-viewer.py: Fix Array TypeError (Michael Petlan) [2003981]
- perf scripts python: exported-sql-viewer.py: Fix copy to clipboard from Top Calls by elapsed Time report (Michael Petlan) [2003981]
- perf parse-events: Check if the software events array slots are populated (Michael Petlan) [2003981]
- perf tools: Add 'cgroup-switches' software event (Michael Petlan) [2003981]
- perf intel-pt: Remove redundant setting of ptq->insn_len (Michael Petlan) [2003981]
- perf intel-pt: Fix sample instruction bytes (Michael Petlan) [2003981]
- perf intel-pt: Fix transaction abort handling (Michael Petlan) [2003981]
- perf test: Fix libpfm4 support (63) test error for nested event groups (Michael Petlan) [2003981]
- perf buildid-list: Initialize zstd_data (Michael Petlan) [2003981]
- tools build: Fix quiet cmd indentation (Michael Petlan) [2003981]
- perf tools: Fix a build error on arm64 with clang (Michael Petlan) [2003981]
- perf tools: Fix dynamic libbpf link (Michael Petlan) [2003981]
- perf session: Fix swapping of cpu_map and stat_config records (Michael Petlan) [2003981]
- perf jevents: Silence warning for ArchStd files (Michael Petlan) [2003981]
- perf build: Defer printing detected features to the end of all feature checks (Michael Petlan) [2003981]
- tools build: Allow deferring printing the results of feature detection (Michael Petlan) [2003981]
- perf build: Regenerate the FEATURE_DUMP file after extra feature checks (Michael Petlan) [2003981]
- perf session: Dump PERF_RECORD_TIME_CONV event (Michael Petlan) [2003981]
- perf session: Add swap operation for event TIME_CONV (Michael Petlan) [2003981]
- perf jit: Let convert_timestamp() to be backwards-compatible (Michael Petlan) [2003981]
- perf tools: Change fields type in perf_record_time_conv (Michael Petlan) [2003981]
- perf tools: Enable libtraceevent dynamic linking (Michael Petlan) [2003981]
- perf report: Print percentage of each event statistics (Michael Petlan) [2003981]
- perf report: Make --skip-empty as default (Michael Petlan) [2003981]
- perf report: Add --skip-empty option to suppress 0 event stat (Michael Petlan) [2003981]
- perf report: Show event sample counts in --stat output (Michael Petlan) [2003981]
- perf hists: Split hists_stats from events_stats (Michael Petlan) [2003981]
- perf top: Use evlist->events_stat to count events (Michael Petlan) [2003981]
- perf data: Add JSON export (Michael Petlan) [2003981]
- perf stat: Introduce bpf_counter_ops->disable() (Michael Petlan) [2003981]
- perf stat: Introduce ':b' modifier (Michael Petlan) [2003981]
- perf stat: Introduce config stat.bpf-counter-events (Michael Petlan) [2003981]
- perf bpf: check perf_attr_map is compatible with the perf binary (Michael Petlan) [2003981]
- perf util: Move bpf_perf definitions to a libperf header (Michael Petlan) [2003981]
- perf tools: Update topdown documentation to permit rdpmc calls (Michael Petlan) [2003981]
- perf tools: Add a build-test variant to use in builds from a tarball (Michael Petlan) [2003981]
- perf arm64: Fix off-by-one directory paths. (Michael Petlan) [2003981]
- perf: Update .gitignore file (Michael Petlan) [2003981]
- perf stat: Enable iostat mode for x86 platforms (Michael Petlan) [2003981]
- perf stat: Helper functions for PCIe root ports list in iostat mode (Michael Petlan) [2003981]
- perf stat: Basic support for iostat in perf (Michael Petlan) [2003981]
- libperf xyarray: Add bounds checks to xyarray__entry() (Michael Petlan) [2003981]
- libperf: Add support for user space counter access (Michael Petlan) [2003981]
- libperf tests: Add support for verbose printing (Michael Petlan) [2003981]
- libperf: Add evsel mmap support (Michael Petlan) [2003981]
- tools include: Add an initial math64.h (Michael Petlan) [2003981]
- perf beauty: Fix fsconfig generator (Michael Petlan) [2003981]
- perf record: Improve 'Workload failed' message printing events + what was exec'ed (Michael Petlan) [2003981]
- perf evlist: Add a method to return the list of evsels as a string (Michael Petlan) [2003981]
- perf annotate: Fix sample events lost in stdio mode (Michael Petlan) [2003981]
- perf vendor events amd: Add Zen3 events (Michael Petlan) [2003981]
- perf vendor events amd: Use 0x02x format for event code and umask (Michael Petlan) [2003981]
- perf vendor events amd: Use lowercases for all the eventcodes and umasks (Michael Petlan) [2003981]
- perf vendor events amd: Fix broken L2 Cache Hits from L2 HWPF metric (Michael Petlan) [2003981]
- perf vendor events arm64: Add Hisi hip08 L3 metrics (Michael Petlan) [2003981]
- perf vendor events arm64: Add Hisi hip08 L2 metrics (Michael Petlan) [2003981]
- perf vendor events arm64: Add Hisi hip08 L1 metrics (Michael Petlan) [2003981]
- perf pmu: Add pmu_events_map__find() function to find the common PMU map for the system (Michael Petlan) [2003981]
- perf test: Handle metric reuse in pmu-events parsing test (Michael Petlan) [2003981]
- perf metricgroup: Make find_metric() public with name change (Michael Petlan) [2003981]
- perf mem-events: Remove unnecessary 'struct mem_info' forward declaration (Michael Petlan) [2003981]
- perf evsel: Remove duplicate 'struct target' forward declaration (Michael Petlan) [2003981]
- perf annotate: Add --demangle and --demangle-kernel (Michael Petlan) [2003981]
- perf tools: Preserve identifier id in OCaml demangler (Michael Petlan) [2003981]
- perf daemon: Remove duplicate includes (Michael Petlan) [2003981]
- perf tools: Remove duplicate struct forward declarations (Michael Petlan) [2003981]
- perf test: Add CSV summary test (Michael Petlan) [2003981]
- perf stat: Align CSV output for summary mode (Michael Petlan) [2003981]
- perf test: Add a shell test for 'perf stat --bpf-counters' new option (Michael Petlan) [2003981]
- perf stat: Measure 't0' and 'ref_time' after enable_counters() (Michael Petlan) [2003981]
- perf stat: Introduce 'bperf' to share hardware PMCs with BPF (Michael Petlan) [2003981]
- perf tools: Fix various typos in comments (Michael Petlan) [2003981]
- perf test: Add 30s timeout for wait for daemon start. (Michael Petlan) [2003981]
- perf test: Cleanup daemon if test is interrupted. (Michael Petlan) [2003981]
- perf test: Remove unused argument (Michael Petlan) [2003981]
- perf stat: Improve readability of shadow stats (Michael Petlan) [2003981]
- perf stat: Elaborate use cases for the -n/--null command line option (Michael Petlan) [2003981]
- perf evlist: Change the COMM when preparing the workload (Michael Petlan) [2003981]
- perf machine: Assign boolean values to a bool variable (Michael Petlan) [2003981]
- perf tools: use ARRAY_SIZE (Michael Petlan) [2003981]
- perf stat: Fixup __perf_stat_evsel__is() prefix (Michael Petlan) [2003981]
- perf script: Fixup 'struct evsel_script' method prefix (Michael Petlan) [2003981]
- perf symbols: Fix dso__fprintf_symbols_by_name() to return the number of printed chars (Michael Petlan) [2003981]
- tools include: Add __sum16 and __wsum definitions. (Michael Petlan) [2003981]
- perf annotate: Show full source location with 'l' hotkey (Michael Petlan) [2003981]
- perf bench: Fix misspellings using codespell (Michael Petlan) [2003981]
- perf config: Add annotate.demangle{,_kernel} (Michael Petlan) [2003981]
- perf bpf: Minor whitespace cleanup. (Michael Petlan) [2003981]
- perf tools: Enable warnings when compiling BPF programs (Michael Petlan) [2003981]
- perf skel: Remove some unused variables. (Michael Petlan) [2003981]
- perf report: Create option to disable raw event ordering (Michael Petlan) [2003981]
- perf metric: Remove unneeded semicolon (Michael Petlan) [2003981]
- perf cs-etm: Detect pid in VMID for kernel running at EL2 (Michael Petlan) [2003981]
- perf cs-etm: Add helper cs_etm__get_pid_fmt() (Michael Petlan) [2003981]
- perf cs-etm: Support PID tracing in config (Michael Petlan) [2003981]
- perf cs-etm: Fix bitmap for option (Michael Petlan) [2003981]
- perf cs-etm: Update ETM metadata format (Michael Petlan) [2003981]
- perf vendor events power9: Remove unsupported metrics (Michael Petlan) [2003981]
- perf buildid-cache: Add test for PE executable (Michael Petlan) [2003981]
- perf docs: Add man pages to see also (Michael Petlan) [2003981]
- perf tools: Generate mips syscalls_n64.c syscall table (Michael Petlan) [2003981]
- perf s390: Move syscall.tbl check into check-headers.sh (Michael Petlan) [2003981]
- perf tools: Support MIPS unwinding and dwarf-regs (Michael Petlan) [2003981]
- tools: do not include scripts/Kbuild.include (Michael Petlan) [2003981]
- tools: Allow proper CC/CXX/... override with LLVM=1 in Makefile.include (Michael Petlan) [2003981]
- perf intel-pt: Use aux_watermark (Michael Petlan) [2003981]
- perf/x86/intel/uncore: Fix M2M event umask for Ice Lake server (Michael Petlan) [2003981]
- perf/x86/intel/uncore: Fix a kernel WARNING triggered by maxcpus=1 (Michael Petlan) [2003981]
- perf: Fix data race between pin_count increment/decrement (Michael Petlan) [2003981]
- perf/x86: Avoid touching LBR_TOS MSR for Arch LBR (Michael Petlan) [2003981]
- perf/x86: Allow for 8<num_fixed_counters<16 (Michael Petlan) [2003981]
- perf/amd/uncore: Fix sysfs type mismatch (Michael Petlan) [2003981]
- x86/events/amd/iommu: Fix sysfs type mismatch (Michael Petlan) [2003981]
- perf core: Add PERF_COUNT_SW_CGROUP_SWITCHES event (Michael Petlan) [2003981]
- perf core: Factor out __perf_sw_event_sched (Michael Petlan) [2003981]
- perf/x86: Move cpuc->running into P4 specific code (Michael Petlan) [2003981]
- perf: Add support for event removal on exec (Michael Petlan) [2003981]
- perf: Support only inheriting events if cloned with CLONE_THREAD (Michael Petlan) [2003981]
- perf: Apply PERF_EVENT_IOC_MODIFY_ATTRIBUTES to children (Michael Petlan) [2003981]
- perf: Rework perf_event_exit_event() (Michael Petlan) [2003981]
- perf: Cap allocation order at aux_watermark (Michael Petlan) [2003981]
- perf/x86/intel/uncore: Enable IIO stacks to PMON mapping for multi-segment SKX (Michael Petlan) [2003981]
- perf core: Allocate perf_event in the target node memory (Michael Petlan) [2003981]
- perf core: Add a kmem_cache for struct perf_event (Michael Petlan) [2003981]
- perf core: Allocate perf_buffer in the target node memory (Michael Petlan) [2003981]
- x86: Remove unusual Unicode characters from comments (Michael Petlan) [2003981]
- redhat/configs: Add CONFIG_TIMERLAT_TRACER (Jerome Marchand) [1979382]
- redhat/configs: Add CONFIG_OSNOISE_TRACER (Jerome Marchand) [1979382]
- tracing/osnoise: Fix missed cpus_read_unlock() in start_per_cpu_kthreads() (Jerome Marchand) [1979382]
- tracing: Replace deprecated CPU-hotplug functions. (Jerome Marchand) [1979382]
- trace/osnoise: Print a stop tracing message (Jerome Marchand) [1979382]
- trace/timerlat: Add a header with PREEMPT_RT additional fields (Jerome Marchand) [1979382]
- trace/osnoise: Add a header with PREEMPT_RT additional fields (Jerome Marchand) [1979382]
- tracing: Quiet smp_processor_id() use in preemptable warning in hwlat (Jerome Marchand) [1979382]
- trace/timerlat: Fix indentation on timerlat_main() (Jerome Marchand) [1979382]
- trace/osnoise: Make 'noise' variable s64 in run_osnoise() (Jerome Marchand) [1979382]
- tracing: Fix spelling in osnoise tracer "interferences" -> "interference" (Jerome Marchand) [1979382]
- Documentation: Fix a typo on trace/osnoise-tracer (Jerome Marchand) [1979382]
- trace/osnoise: Fix return value on osnoise_init_hotplug_support (Jerome Marchand) [1979382]
- trace/osnoise: Make interval u64 on osnoise_main (Jerome Marchand) [1979382]
- trace/osnoise: Fix 'no previous prototype' warnings (Jerome Marchand) [1979382]
- tracing: Have osnoise_main() add a quiescent state for task rcu (Jerome Marchand) [1979382]
- trace/osnoise: Support hotplug operations (Jerome Marchand) [1979382]
- trace/hwlat: Support hotplug operations (Jerome Marchand) [1979382]
- trace/hwlat: Protect kdata->kthread with get/put_online_cpus (Jerome Marchand) [1979382]
- trace: Add timerlat tracer (Jerome Marchand) [1979382]
- trace: Add osnoise tracer (Jerome Marchand) [1979382]
- trace: Add __print_ns_to_secs() and __print_ns_without_secs() helpers (Jerome Marchand) [1979382]
- trace/hwlat: Remove printk from sampling loop (Jerome Marchand) [1979382]
- trace/hwlat: Use trace_min_max_param for width and window params (Jerome Marchand) [1979382]
- trace: Add a generic function to read/write u64 values from tracefs (Jerome Marchand) [1979382]
- trace/hwlat: Implement the per-cpu mode (Jerome Marchand) [1979382]
- trace/hwlat: Switch disable_migrate to mode none (Jerome Marchand) [1979382]
- trace/hwlat: Implement the mode config option (Jerome Marchand) [1979382]
- uio_hv_generic: Fix another memory leak in error handling paths (Mohammed Gamal) [2008561]
- uio_hv_generic: Fix a memory leak in error handling paths (Mohammed Gamal) [2008561]
- mfd: intel-lpss: Add Intel Alder Lake-M PCI IDs (David Arcari) [1929498]
- xfs: fix up non-directory creation in SGID directories (Brian Foster) [2004810]
- xfs: kill ialloced in xfs_dialloc() (Brian Foster) [2004810]
- xfs: spilt xfs_dialloc() into 2 functions (Brian Foster) [2004810]
- xfs: move xfs_dialloc_roll() into xfs_dialloc() (Brian Foster) [2004810]
- xfs: move on-disk inode allocation out of xfs_ialloc() (Brian Foster) [2004810]
- xfs: introduce xfs_dialloc_roll() (Brian Foster) [2004810]
- xfs: convert noroom, okalloc in xfs_dialloc() to bool (Brian Foster) [2004810]
- xfs: check tp->t_dqinfo value instead of the XFS_TRANS_DQ_DIRTY flag (Brian Foster) [2004810]
- scsi: vmw_pvscsi: Set correct residual data length (Cathy Avery) [2012237]
- scsi: vmw_pvscsi: MAINTAINERS: Update maintainer (Cathy Avery) [2012237]
- treewide: Use fallthrough pseudo-keyword (Cathy Avery) [2012237]
- scsi: be2iscsi: Fix use-after-free during IP updates (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix some missing space in some messages (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix an error handling path in beiscsi_dev_probe() (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Remove redundant initialization (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Demote incomplete/non-conformant kernel-doc header (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Ensure function follows directly after its header (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix beiscsi_phys_port()'s name in header (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Provide missing function name in header (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix incorrect naming of beiscsi_iface_config_vlan() (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Mark beiscsi_attrs with static keyword (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Revert "Fix a theoretical leak in beiscsi_create_eqs()" (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix a theoretical leak in beiscsi_create_eqs() (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Correct misdocumentation of function param 'ep' (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Add missing function parameter description (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix misdocumentation of 'pcontext' (Maurizio Lombardi) [1984347]
- scsi: be2iscsi: Fix API/documentation slip (Maurizio Lombardi) [1984347]
- powerpc/spinlock: Properly define pv_spinlocks_init() (Waiman Long) [2014363]
- ACPI: Pass the same capabilities to the _OSC regardless of the query flag (Mark Langsdorf) [1982319]
- Revert "[acpi] ACPI: sleep: Put the FACS table after using it" (Mark Langsdorf) [1982319]
- ACPICA: Clean up context mutex during object deletion (Mark Langsdorf) [1982319]
- ACPI: power: Refine turning off unused power resources (Mark Langsdorf) [1982319]
- ACPI: NFIT: Fix support for variable 'SPA' structure size (Mark Langsdorf) [1982319]
- ACPI: custom_method: fix a possible memory leak (Mark Langsdorf) [1982319]
- ACPI: custom_method: fix potential use-after-free issue (Mark Langsdorf) [1982319]
- ACPI: irq: Prevent unregistering of GIC SGIs (Mark Langsdorf) [1982319]
- ACPI: GTDT: Don't corrupt interrupt mappings on watchdow probe failure (Mark Langsdorf) [1982319]
- ACPI: video: use native backlight for GA401/GA502/GA503 (Mark Langsdorf) [1982319]
- ACPI: APEI: remove redundant assignment to variable rc (Mark Langsdorf) [1982319]
- ACPI: utils: Capitalize abbreviations in the comments (Mark Langsdorf) [1982319]
- ACPI: utils: Document for_each_acpi_dev_match() macro (Mark Langsdorf) [1982319]
- ACPI: bus: Introduce acpi_dev_get() and reuse it in ACPI code (Mark Langsdorf) [1982319]
- ACPI: scan: Utilize match_string() API (Mark Langsdorf) [1982319]
- ACPI: CPPC: Replace cppc_attr with kobj_attribute (Mark Langsdorf) [1982319]
- ACPI: scan: Call acpi_get_object_info() from acpi_set_pnp_ids() (Mark Langsdorf) [1982319]
- ACPI: scan: Drop sta argument from acpi_init_device_object() (Mark Langsdorf) [1982319]
- ACPI: scan: Drop sta argument from acpi_add_single_object() (Mark Langsdorf) [1982319]
- ACPI: scan: Rearrange checks in acpi_bus_check_add() (Mark Langsdorf) [1982319]
- ACPI: scan: Fold acpi_bus_type_and_status() into its caller (Mark Langsdorf) [1982319]
- ACPI: video: Check LCD flag on ACPI-reduced-hardware devices (Hans de Goede) [1982319]
- ACPI: utils: Add acpi_reduced_hardware() helper (Mark Langsdorf) [1982319]
- ACPI: dock: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPI: sysfs: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPI: PM: add a missed blank line after declarations (Mark Langsdorf) [1982319]
- ACPI: custom_method: fix a coding style issue (Mark Langsdorf) [1982319]
- ACPI: CPPC: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPI: button: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPI: battery: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPI: acpi_pad: add a missed blank line after declarations (Mark Langsdorf) [1982319]
- ACPI: LPSS: add a missed blank line after declarations (Mark Langsdorf) [1982319]
- ACPI: ipmi: remove useless return statement for void function (Mark Langsdorf) [1982319]
- ACPI: processor: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPI: APD: fix a block comment align issue (Mark Langsdorf) [1982319]
- ACPI: AC: fix some coding style issues (Mark Langsdorf) [1982319]
- ACPICA: Update version to 20210331 (Mark Langsdorf) [1982319]
- ACPICA: IORT: Updates for revision E.b (Mark Langsdorf) [1982319]
- ACPICA: iASL: Decode subtable type field for VIOT (Mark Langsdorf) [1982319]
- ACPICA: iASL: Add support for CEDT table (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: add support for PHAT table (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: add CSI2Bus resource template (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: PMTT: add new fields/structures (Mark Langsdorf) [1982319]
- ACPICA: CXL 2.0: CEDT: Add new CEDT table (Mark Langsdorf) [1982319]
- ACPICA: acpisrc: Add missing conversion for VIOT support (Mark Langsdorf) [1982319]
- ACPICA: iASL: Add definitions for the VIOT table (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: add SDEV secure access components (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: Add new flags in SRAT (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: HMAT: add new fields/flags (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: NFIT: add Location Cookie field (Mark Langsdorf) [1982319]
- ACPICA: Tree-wide: fix various typos and spelling mistakes (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: PPTT: add new version of subtable type 1 (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: PCCT: add support for subtable type 5 (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: MADT: add Multiprocessor Wakeup Structure (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: add CXL ACPI device ID and _CBR object (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: add USB4 capabilities UUID (Mark Langsdorf) [1982319]
- ACPICA: ACPI 6.4: Add new predefined objects _BPC, _BPS, and _BPT (Mark Langsdorf) [1982319]
- ACPICA: Add parsing for IVRS IVHD 40h and device entry F0h (Mark Langsdorf) [1982319]
- ACPI: CPPC: Add emtpy stubs of functions for CONFIG_ACPI_CPPC_LIB unset (Mark Langsdorf) [1982319]
- ACPI: scan: Turn off unused power resources during initialization (Mark Langsdorf) [1982319]
- ACPI: power: Turn off unused power resources unconditionally (Mark Langsdorf) [1982319]
- ACPI: fix various typos in comments (Mark Langsdorf) [1982319]
- ACPI: utils: Introduce acpi_evaluation_failure_warn() (Mark Langsdorf) [1982319]
- ACPI: processor: perflib: Eliminate redundant status check (Mark Langsdorf) [1982319]
- ACPI: Drop unused ACPI_*_COMPONENT definitions and update documentation (Mark Langsdorf) [1982319]
- ACPI: sysfs: Get rid of ACPICA message printing (Mark Langsdorf) [1982319]
- ACPI: HED: Drop unused ACPI_MODULE_NAME() definition (Mark Langsdorf) [1982319]
- ACPI: processor: Get rid of ACPICA message printing (Mark Langsdorf) [1982319]
- ACPI: processor: idle: Drop extra prefix from pr_notice() (Mark Langsdorf) [1982319]
- ACPI: processor: Remove initialization of static variable (Mark Langsdorf) [1982319]
- ACPI: PCI: Replace direct printk() invocations in pci_link.c (Mark Langsdorf) [1982319]
- ACPI: PCI: Drop ACPI_PCI_COMPONENT that is not used any more (Mark Langsdorf) [1982319]
- ACPI: PCI: Replace ACPI_DEBUG_PRINT() and ACPI_EXCEPTION() (Mark Langsdorf) [1982319]
- ACPI: PCI: IRQ: Consolidate printing diagnostic messages (Mark Langsdorf) [1982319]
- arm64: compat: Poison the compat sigpage (C. Erastus Toe) [1983849] {CVE-2021-21781}
- ARM: ensure the signal page contains defined contents (C. Erastus Toe) [1983849] {CVE-2021-21781}
- powerpc/pseries: Fix update of LPAR security flavor after LPM (Steve Best) [1997294]
- s390/qeth: Update MACs of LEARNING_SYNC device (Robin Dapp) [1919227]
- s390/qeth: Switchdev event handler (Robin Dapp) [1919227]
- s390/qeth: Register switchdev event handler (Robin Dapp) [1919227]
- PCI: Add pcie_ptm_enabled() (Petr Oros) [2006834]
- Revert "PCI: Make pci_enable_ptm() private" (Petr Oros) [2006834]
- x86/cpufeatures: Force disable X86_FEATURE_ENQCMD and remove update_pasid() (Jerry Snitselaar) [2004577]
- s390: report more CPU capabilities (Robin Dapp) [1984839]
- s390/disassembler: add instructions (Robin Dapp) [1984839]
- s390/opcodes: rename selhhhr to selfhr (Robin Dapp) [1984839]
- s390/disassembler: update opcode table (Robin Dapp) [1984839]
- s390/opcodes: add missing instructions to the disassembler (Robin Dapp) [1984839]
- CI: Add template for baseline gcov build (Israel Santana Aleman)
- futex: Remove unused variable 'vpid' in futex_proxy_trylock_atomic() (Waiman Long) [2000293]
- futex: Prevent inconsistent state and exit race (Waiman Long) [2000293]
- locking/ww_mutex: Initialize waiter.ww_ctx properly (Waiman Long) [2000293]
- futex: Return error code instead of assigning it without effect (Waiman Long) [2000293]
- Documentation: seqlock: s/LOCKTYPE/LOCKNAME/g (Waiman Long) [2000293]
- lib/test_lockup.c: fix return value of test_lockup_init() (Waiman Long) [2000293]
- locking/rwbase: Take care of ordering guarantee for fastpath reader (Waiman Long) [2000293]
- locking/rwbase: Extract __rwbase_write_trylock() (Waiman Long) [2000293]
- locking/rwbase: Properly match set_and_save_state() to restore_state() (Waiman Long) [2000293]
- locking/rtmutex: Fix ww_mutex deadlock check (Waiman Long) [2000293]
- locking/rwsem: Add missing __init_rwsem() for PREEMPT_RT (Waiman Long) [2000293]
- locking/rtmutex: Return success on deadlock for ww_mutex waiters (Waiman Long) [2000293]
- locking/rtmutex: Prevent spurious EDEADLK return caused by ww_mutexes (Waiman Long) [2000293]
- locking/rtmutex: Dequeue waiter on ww_mutex deadlock (Waiman Long) [2000293]
- locking/rtmutex: Dont dereference waiter lockless (Waiman Long) [2000293]
- locking/local_lock: Add PREEMPT_RT support (Waiman Long) [2000293]
- locking/spinlock/rt: Prepare for RT local_lock (Waiman Long) [2000293]
- locking/rtmutex: Add adaptive spinwait mechanism (Waiman Long) [2000293]
- locking/rtmutex: Implement equal priority lock stealing (Waiman Long) [2000293]
- preempt: Adjust PREEMPT_LOCK_OFFSET for RT (Waiman Long) [2000293]
- locking/rtmutex: Prevent lockdep false positive with PI futexes (Waiman Long) [2000293]
- futex: Prevent requeue_pi() lock nesting issue on RT (Waiman Long) [2000293]
- futex: Simplify handle_early_requeue_pi_wakeup() (Waiman Long) [2000293]
- futex: Reorder sanity checks in futex_requeue() (Waiman Long) [2000293]
- futex: Clarify comment in futex_requeue() (Waiman Long) [2000293]
- futex: Restructure futex_requeue() (Waiman Long) [2000293]
- futex: Correct the number of requeued waiters for PI (Waiman Long) [2000293]
- futex: Remove bogus condition for requeue PI (Waiman Long) [2000293]
- futex: Clarify futex_requeue() PI handling (Waiman Long) [2000293]
- futex: Clean up stale comments (Waiman Long) [2000293]
- futex: Validate waiter correctly in futex_proxy_trylock_atomic() (Waiman Long) [2000293]
- lib/test_lockup: Adapt to changed variables (Waiman Long) [2000293]
- locking/rtmutex: Add mutex variant for RT (Waiman Long) [2000293]
- locking/ww_mutex: Implement rtmutex based ww_mutex API functions (Waiman Long) [2000293]
- locking/rtmutex: Extend the rtmutex core to support ww_mutex (Waiman Long) [2000293]
- locking/ww_mutex: Add rt_mutex based lock type and accessors (Waiman Long) [2000293]
- locking/ww_mutex: Add RT priority to W/W order (Waiman Long) [2000293]
- locking/ww_mutex: Implement rt_mutex accessors (Waiman Long) [2000293]
- locking/ww_mutex: Abstract out internal lock accesses (Waiman Long) [2000293]
- locking/ww_mutex: Abstract out mutex types (Waiman Long) [2000293]
- locking/ww_mutex: Abstract out mutex accessors (Waiman Long) [2000293]
- locking/ww_mutex: Abstract out waiter enqueueing (Waiman Long) [2000293]
- locking/ww_mutex: Abstract out the waiter iteration (Waiman Long) [2000293]
- locking/ww_mutex: Remove the __sched annotation from ww_mutex APIs (Waiman Long) [2000293]
- locking/ww_mutex: Split out the W/W implementation logic into kernel/locking/ww_mutex.h (Waiman Long) [2000293]
- locking/ww_mutex: Split up ww_mutex_unlock() (Waiman Long) [2000293]
- locking/ww_mutex: Gather mutex_waiter initialization (Waiman Long) [2000293]
- locking/ww_mutex: Simplify lockdep annotations (Waiman Long) [2000293]
- locking/mutex: Make mutex::wait_lock raw (Waiman Long) [2000293]
- locking/ww_mutex: Move the ww_mutex definitions from <linux/mutex.h> into <linux/ww_mutex.h> (Waiman Long) [2000293]
- locking/mutex: Move the 'struct mutex_waiter' definition from <linux/mutex.h> to the internal header (Waiman Long) [2000293]
- locking/mutex: Consolidate core headers, remove kernel/locking/mutex-debug.h (Waiman Long) [2000293]
- locking/rtmutex: Squash !RT tasks to DEFAULT_PRIO (Waiman Long) [2000293]
- locking/rwlock: Provide RT variant (Waiman Long) [2000293]
- locking/spinlock: Provide RT variant (Waiman Long) [2000293]
- locking/rtmutex: Provide the spin/rwlock core lock function (Waiman Long) [2000293]
- locking/spinlock: Provide RT variant header: <linux/spinlock_rt.h> (Waiman Long) [2000293]
- locking/spinlock: Provide RT specific spinlock_t (Waiman Long) [2000293]
- locking/rtmutex: Reduce <linux/rtmutex.h> header dependencies, only include <linux/rbtree_types.h> (Waiman Long) [2000293]
- rbtree: Split out the rbtree type definitions into <linux/rbtree_types.h> (Waiman Long) [2000293]
- locking/lockdep: Reduce header dependencies in <linux/debug_locks.h> (Waiman Long) [2000293]
- locking/rtmutex: Prevent future include recursion hell (Waiman Long) [2000293]
- locking/spinlock: Split the lock types header, and move the raw types into <linux/spinlock_types_raw.h> (Waiman Long) [2000293]
- locking/rtmutex: Guard regular sleeping locks specific functions (Waiman Long) [2000293]
- locking/rtmutex: Prepare RT rt_mutex_wake_q for RT locks (Waiman Long) [2000293]
- locking/rtmutex: Use rt_mutex_wake_q_head (Waiman Long) [2000293]
- locking/rtmutex: Provide rt_wake_q_head and helpers (Waiman Long) [2000293]
- locking/rtmutex: Add wake_state to rt_mutex_waiter (Waiman Long) [2000293]
- locking/rwsem: Add rtmutex based R/W semaphore implementation (Waiman Long) [2000293]
- locking/rt: Add base code for RT rw_semaphore and rwlock (Waiman Long) [2000293]
- locking/rtmutex: Provide rt_mutex_base_is_locked() (Waiman Long) [2000293]
- locking/rtmutex: Provide rt_mutex_slowlock_locked() (Waiman Long) [2000293]
- locking/rtmutex: Split out the inner parts of 'struct rtmutex' (Waiman Long) [2000293]
- locking/rtmutex: Split API from implementation (Waiman Long) [2000293]
- locking/rtmutex: Convert macros to inlines (Waiman Long) [2000293]
- locking/rtmutex: Remove rt_mutex_is_locked() (Waiman Long) [2000293]
- sched/wake_q: Provide WAKE_Q_HEAD_INITIALIZER() (Waiman Long) [2000293]
- sched/core: Provide a scheduling point for RT locks (Waiman Long) [2000293]
- sched/core: Rework the __schedule() preempt argument (Waiman Long) [2000293]
- sched/wakeup: Prepare for RT sleeping spin/rwlocks (Waiman Long) [2000293]
- sched/wakeup: Reorganize the current::__state helpers (Waiman Long) [2000293]
- sched/wakeup: Introduce the TASK_RTLOCK_WAIT state bit (Waiman Long) [2000293]
- sched/wakeup: Split out the wakeup ->__state check (Waiman Long) [2000293]
- locking/rtmutex: Set proper wait context for lockdep (Waiman Long) [2000293]
- locking/local_lock: Add missing owner initialization (Waiman Long) [2000293]
- locking/rtmutex: Use the correct rtmutex debugging config option (Waiman Long) [2000293]
- tools/runqslower: Use __state instead of state (Waiman Long) [2000293]
- locking/rwsem: Remove an unused parameter of rwsem_wake() (Waiman Long) [2000293]
- locking/mutex: Add MUTEX_WARN_ON (Waiman Long) [2000293]
- locking/mutex: Introduce __mutex_trylock_or_handoff() (Waiman Long) [2000293]
- locking/mutex: Fix HANDOFF condition (Waiman Long) [2000293]
- locking/mutex: Use try_cmpxchg() (Waiman Long) [2000293]
- sched: Change task_struct::state (Waiman Long) [2000293]
- isdn/hisax: Use get_current_state() (Waiman Long) [2000293]
- sched,timer: Use __set_current_state() (Waiman Long) [2000293]
- sched: Add get_current_state() (Waiman Long) [2000293]
- sched,perf,kvm: Fix preemption condition (Waiman Long) [2000293]
- sched: Introduce task_is_running() (Waiman Long) [2000293]
- sched: Unbreak wakeups (Waiman Long) [2000293]
- seqlock: Remove trailing semicolon in macros (Waiman Long) [2000293]
- locking/mutex: clear MUTEX_FLAGS if wait_list is empty due to signal (Waiman Long) [2000293]
- ptrace: make ptrace() fail if the tracee changed its pid unexpectedly (Waiman Long) [2000293]
- sched: Rename sched_info_{queued,dequeued} (Waiman Long) [2000293]
- locking/rwsem: Fix comment typo (Waiman Long) [2000293]
- bpf: runqslower: Use task local storage (Waiman Long) [2000293]
- lib/test_lockup.c: minimum fix to get it compiled on PREEMPT_RT (Waiman Long) [2000293]
- seqlock: kernel-doc: Specify when preemption is automatically altered (Waiman Long) [2000293]
- seqlock: Prefix internal seqcount_t-only macros with a "do_" (Waiman Long) [2000293]
- rcu: Check and report missed fqs timer wakeup on RCU stall (Waiman Long) [2000293]
- softirq: Move related code into one section (Waiman Long) [2000293]
- seqlock: Rename __seqprop() users (Waiman Long) [2000293]
- seqlock: avoid -Wshadow warnings (Waiman Long) [2000293]
- locking/seqlocks: Fix kernel-doc warnings (Waiman Long) [2000293]
- locking/seqlock: Tweak DEFINE_SEQLOCK() kernel doc (Waiman Long) [2000293]
- seqlock: Unbreak lockdep (Waiman Long) [2000293]
- seqlock: PREEMPT_RT: Do not starve seqlock_t writers (Waiman Long) [2000293]
- seqlock: seqcount_LOCKNAME_t: Introduce PREEMPT_RT support (Waiman Long) [2000293]
- seqlock: seqcount_t: Implement all read APIs as statement expressions (Waiman Long) [2000293]
- seqlock: Use unique prefix for seqcount_t property accessors (Waiman Long) [2000293]
- seqlock: seqcount_LOCKNAME_t: Standardize naming convention (Waiman Long) [2000293]
- seqlock: seqcount latch APIs: Only allow seqcount_latch_t (Waiman Long) [2000293]
- rbtree_latch: Use seqcount_latch_t (Waiman Long) [2000293]
- x86/tsc: Use seqcount_latch_t (Waiman Long) [2000293]
- timekeeping: Use seqcount_latch_t (Waiman Long) [2000293]
- time/sched_clock: Mark sched_clock_read_begin/retry() as notrace (Waiman Long) [2000293]
- time/sched_clock: Use raw_read_seqcount_latch() (Waiman Long) [2000293]
- time/sched_clock: Use raw_read_seqcount_latch() during suspend (Waiman Long) [2000293]
- time/sched_clock: Use seqcount_latch_t (Waiman Long) [2000293]
- sched_clock: Expose struct clock_read_data (Waiman Long) [2000293]
- timers/sched_clock: Include local timekeeping.h for missing declarations (Waiman Long) [2000293]
- sched/clock: Move sched clock initialization and merge with generic clock (Waiman Long) [2000293]
- userfaultfd: simplify fault handling (Waiman Long) [2000293]
- rwsem: fix commas in initialisation (Waiman Long) [2000293]
- lib/test_lockup.c: make test_inode static (Waiman Long) [2000293]
- genirq: Provide irq_enter/exit_rcu() (Waiman Long) [2000293]
- lib/test_lockup.c: add parameters for locking generic vfs locks (Waiman Long) [2000293]
- lib/test_lockup.c: fix spelling mistake "iteraions" -> "iterations" (Waiman Long) [2000293]
- lib/test_lockup: test module to generate lockups (Waiman Long) [2000293]
- x86/tsc: Move inline keyword to the beginning of function declarations (Waiman Long) [2000293]
- softirq: Don't skip softirq execution when softirq thread is parking (Waiman Long) [2000293]
- sched/core: Convert task_struct.stack_refcount to refcount_t (Waiman Long) [2000293]
- kernel/hung_task.c: break RCU locks based on jiffies (Waiman Long) [2000293]
- x86/process: Avoid unnecessary NULL check in get_wchan() (Waiman Long) [2000293]
- kernel/rwsem: Remove ifdef __init_rwsem code from rwsem.c (Waiman Long) [2000293]
- misc: hpilo: map iLO shared memory by PCI revision id (Joseph Szczypek) [1985076]
- misc: hpilo: MAINTAINERS: add entry for hpilo (Joseph Szczypek) [1985076]
- misc: hpilo: avoid a useless memset (Joseph Szczypek) [1985076]
- misc: hpilo: switch from 'pci_' to 'dma_' API (Joseph Szczypek) [1985076]
- hpilo: Replace one-element array with flexible-array member (Joseph Szczypek) [1985076]
- perf flamegraph: flamegraph.py script improvements (Michael Petlan) [2010269]

* Wed Nov 03 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-348.5.el8]
- ceph: skip existing superblocks that are blocklisted or shut down when mounting (Jeffrey Layton) [2011462]
- cpufreq: intel_pstate: Combine ->stop_cpu() and ->offline() (David Arcari) [2003695]
- cpufreq: intel_pstate: Add Cometlake support in no-HWP mode (David Arcari) [2003695]
- cpufreq: intel_pstate: Add Icelake servers support in no-HWP mode (David Arcari) [2003695]
- i2c: i801: Add support for Intel Alder Lake PCH-M (David Arcari) [1929497]
- i2c: i801: Add Block Write-Block Read Process Call support (David Arcari) [1929497]
- pinctrl: tigerlake: Add Alder Lake-M ACPI ID (David Arcari) [1929501]
- x86/microcode: Check for offline CPUs before requesting new microcode (Puneet Sethi) [1971878]
- x86/resctrl: Fix a maybe-uninitialized build warning treated as error (Terry Bowman) [1994090]
- x86/resctrl: Fix default monitoring groups reporting (Terry Bowman) [1994090]
- PCI: Remove WARN_ON(in_interrupt()) (Myron Stowe) [1993262]
- PCI: Apply CONFIG_PCI_DEBUG to entire drivers/pci hierarchy (Myron Stowe) [1993262]
- PCI: Add Silicom Denmark vendor ID (Myron Stowe) [1993262]
- PCI: Align checking of syscall user config accessors (Myron Stowe) [1993262]
- PCI: Decline to resize resources if boot config must be preserved (Myron Stowe) [1993262]
- PCI/LINK: Remove bandwidth notification (Myron Stowe) [1993262]
- PCI: acpiphp: Remove unused acpiphp_callback typedef (Myron Stowe) [1993262]
- PCI: Fix pci_register_io_range() memory leak (Myron Stowe) [1993262]
- EDAC/amd64: Add AMD family 17h model 60h PCI IDs (Aristeu Rozanski) [1930489]
- EDAC/amd64: Add PCI device IDs for family 17h, model 70h (Aristeu Rozanski) [1930489]
- scsi: bnx2fc: Remove meaningless bnx2fc_abts_cleanup() return value assignment (Nilesh Javali) [1983956]
- scsi: bnx2fc: Return failure if io_req is already in ABTS processing (Nilesh Javali) [1983956]
- scsi: target: ibmvscsi_tgt: Convert to new submission API (Maurizio Lombardi) [2004470]
- scsi: target: Fix sense key for invalid EXTENDED COPY request (Maurizio Lombardi) [2004470]
- scsi: target: Allows backend drivers to fail with specific sense codes (Maurizio Lombardi) [2004470]
- scsi: target: pscsi: Fix possible null-pointer dereference in pscsi_complete_cmd() (Maurizio Lombardi) [2004470]
- scsi: target: core: Drop unnecessary se_cmd ASC/ASCQ members (Maurizio Lombardi) [2004470]
- scsi: target: sbp: Drop incorrect ASC/ASCQ usage (Maurizio Lombardi) [2004470]
- scsi: target: core: Avoid using lun_tg_pt_gp after unlock (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Add new feature KEEP_BUF (Maurizio Lombardi) [2004470]
- scsi: target: Remove redundant assignment to variable ret (Maurizio Lombardi) [2004470]
- scsi: target: Fix NULL dereference on XCOPY completion (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Remove redundant continue statement (Maurizio Lombardi) [2004470]
- scsi: target: Use standard SAM status types (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Fix boolreturn.cocci warnings (Maurizio Lombardi) [2004470]
- scsi: target: core: Add the VERSION DESCRIPTOR fields to the INQUIRY data (Maurizio Lombardi) [2004470]
- scsi: target: core: Bump INQUIRY VERSION to SPC-4 (Maurizio Lombardi) [2004470]
- scsi: target: core: Add configurable IEEE Company ID attribute (Maurizio Lombardi) [2004470]
- scsi: target: core: Unify NAA identifier generation (Maurizio Lombardi) [2004470]
- scsi: target: sbp_target: Remove redundant assignment to pg_size (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Rename TCM_DEV_BIT_PLUGGED to TCMU_DEV_BIT_PLUGGED (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Drop unnecessary container_of() (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Switch to kmemdup_nul() (Maurizio Lombardi) [2004470]
- scsi: target: iblock: Fix smp_processor_id() BUG messages (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Fix xarray RCU warning (Maurizio Lombardi) [2004470]
- scsi: target: core: Avoid smp_processor_id() in preemptible code (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Return from tcmu_handle_completions() if cmd_id not found (Maurizio Lombardi) [2004470]
- scsi: target: tcm_fc: Fix a kernel-doc header (Maurizio Lombardi) [2004470]
- scsi: target: Shorten ALUA error messages (Maurizio Lombardi) [2004470]
- scsi: target: Fix two format specifiers (Maurizio Lombardi) [2004470]
- scsi: target: Compare explicitly with SAM_STAT_GOOD (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Make data_pages_per_blk changeable via configfs (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Replace block size definitions with new udev members (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Remove function tcmu_get_block_page() (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Support DATA_BLOCK_SIZE = N * PAGE_SIZE (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Prepare for PAGE_SIZE != DATA_BLOCK_SIZE (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Adjust names of variables and definitions (Maurizio Lombardi) [2004470]
- scsi: target: Make the virtual LUN 0 device (Maurizio Lombardi) [2004470]
- scsi: target: Add the DUMMY flag to rd_mcp (Maurizio Lombardi) [2004470]
- scsi: target: Fix htmldocs warning in target_submit_prep() (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Adjust parameter in call to tcmu_blocks_release() (Maurizio Lombardi) [2004470]
- scsi: target: core: file: Don't duplicate memset(0xff) (Maurizio Lombardi) [2004470]
- scsi: target: core: pr: Initialize arrays at declaration time (Maurizio Lombardi) [2004470]
- scsi: target: configfs: Initialize arrays at declaration time (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Initialize arrays at declaration time (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Remove unused macro PRINT_BUF (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Remove unused macro TEXT_LEN (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Remove unused macro ISCSI_INST_LAST_FAILURE_TYPE (Maurizio Lombardi) [2004470]
- scsi: target: core: Remove unused macros NONE and ISPRINT (Maurizio Lombardi) [2004470]
- scsi: target: core: Get rid of warning in compare_and_write_do_cmp() (Maurizio Lombardi) [2004470]
- scsi: target: pscsi: Remove unused macro ISPRINT (Maurizio Lombardi) [2004470]
- scsi: target: pscsi: Fix warning in pscsi_complete_cmd() (Maurizio Lombardi) [2004470]
- scsi: target: iblock: Fix type of logs_per_phys (Maurizio Lombardi) [2004470]
- scsi: target: iblock: Trim line longer than 80 characters (Maurizio Lombardi) [2004470]
- scsi: target: iblock: Remove an extra argument (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Use GFP_NOIO while handling cmds or holding cmdr_lock (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Replace radix_tree with XArray (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Replace IDR by XArray (Maurizio Lombardi) [2004470]
- scsi: target: core: Make completion affinity configurable (Maurizio Lombardi) [2004470]
- scsi: target: core: Flush submission work during TMR processing (Maurizio Lombardi) [2004470]
- scsi: target: tcmu: Add backend plug/unplug callouts (Maurizio Lombardi) [2004470]
- scsi: target: iblock: Add backend plug/unplug callouts (Maurizio Lombardi) [2004470]
- scsi: target: core: Fix backend plugging (Maurizio Lombardi) [2004470]
- scsi: target: tcm_loop: Use LIO wq cmd submission helper (Maurizio Lombardi) [2004470]
- scsi: target: tcm_loop: Use block cmd allocator for se_cmds (Maurizio Lombardi) [2004470]
- scsi: target: core: Add workqueue based cmd submission (Maurizio Lombardi) [2004470]
- scsi: target: core: Add gfp_t arg to target_cmd_init_cdb() (Maurizio Lombardi) [2004470]
- scsi: target: core: Remove target_submit_cmd_map_sgls() (Maurizio Lombardi) [2004470]
- scsi: target: srpt: Convert to new submission API (Maurizio Lombardi) [2004470]
- scsi: target: qla2xxx: Convert to new submission API (Maurizio Lombardi) [2004470]
- scsi: target: tcm_qla2xxx: Remove BUG_ON(in_interrupt()) (Maurizio Lombardi) [2004470]
- scsi: qla2xxx: Move sess cmd list/lock to driver (Maurizio Lombardi) [2004470]
- scsi: qla2xxx: Drop TARGET_SCF_LOOKUP_LUN_FROM_TAG (Maurizio Lombardi) [2004470]
- scsi: target: tcm_fc: Convert to new submission API (Maurizio Lombardi) [2004470]
- scsi: target: sbp_target: Convert to new submission API (Maurizio Lombardi) [2004470]
- scsi: target: tcm_loop: Convert to new submission API (Maurizio Lombardi) [2004470]
- scsi: target: core: Break up target_submit_cmd_map_sgls() (Maurizio Lombardi) [2004470]
- scsi: target: core: Rename transport_init_se_cmd() (Maurizio Lombardi) [2004470]
- scsi: target: core: Drop kref_get_unless_zero() in target_get_sess_cmd() (Maurizio Lombardi) [2004470]
- scsi: target: core: Move t_task_cdb initialization (Maurizio Lombardi) [2004470]
- scsi: target: iscsi: Fix zero tag inside a trace event (Maurizio Lombardi) [2004470]
- nfsd: move fsnotify on client creation outside spinlock (Steve Dickson) [1719330]
- nfsd: report client confirmation status in "info" file (Steve Dickson) [1719330]
- nfsd: fsnotify on rmdir under nfsd/clients/ (Steve Dickson) [1719330]

* Mon Oct 25 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-348.4.el8]
- mm: gup: fix potential pgmap refcnt leak in __gup_device_huge() (Waiman Long) [2009258]
- mm/gup: check for isolation errors (Waiman Long) [2009258]
- mm/gup: return an error on migration failure (Waiman Long) [2009258]
- mm/gup: check every subpage of a compound page during isolation (Waiman Long) [2009258]
- mm/gup: don't pin migrated cma pages in movable zone (Waiman Long) [2009258]
- mm/gup: add a range variant of unpin_user_pages_dirty_lock() (Waiman Long) [2009258]
- mm/gup: decrement head page once for group of subpages (Waiman Long) [2009258]
- mm/gup: add compound page list iterator (Waiman Long) [2009258]
- mm/gup: protect unpin_user_pages() against npages==-ERRNO (Waiman Long) [2009258]
- mm, memcg: remove unused functions (Waiman Long) [2008341]
- mm,vmscan: fix divide by zero in get_scan_count (Waiman Long) [2008341]
- mm: memcontrol: fix occasional OOMs due to proportional memory.low reclaim (Waiman Long) [2008341]
- mm/memcg: fix incorrect flushing of lruvec data in obj_stock (Waiman Long) [2008341]
- mm/memcg: fix NULL pointer dereference in memcg_slab_free_hook() (Waiman Long) [2008341]
- mm: memcontrol: fix blocking rstat function called from atomic cgroup1 thresholding code (Waiman Long) [2008341]
- cgroup: rstat: fix A-A deadlock on 32bit around u64_stats_sync (Waiman Long) [2008341]
- percpu: flush tlb in pcpu_reclaim_populated() (Waiman Long) [2008341]
- mm/memcontrol.c: fix kerneldoc comment for mem_cgroup_calculate_protection (Waiman Long) [2008341]
- memcontrol: use flexible-array member (Waiman Long) [2008341]
- mm: vmscan: remove noinline_for_stack (Waiman Long) [2008341]
- mm: memcontrol: move obj_cgroup_uncharge_pages() out of css_set_lock (Waiman Long) [2008341]
- mm: memcontrol: simplify the logic of objcg pinning memcg (Waiman Long) [2008341]
- mm: memcontrol: rename lruvec_holds_page_lru_lock to page_matches_lruvec (Waiman Long) [2008341]
- mm: memcontrol: simplify lruvec_holds_page_lru_lock (Waiman Long) [2008341]
- mm: memcontrol: remove the pgdata parameter of mem_cgroup_page_lruvec (Waiman Long) [2008341]
- mm: memcontrol: bail out early when !mm in get_mem_cgroup_from_mm (Waiman Long) [2008341]
- mm: memcontrol: fix page charging in page replacement (Waiman Long) [2008341]
- percpu: optimize locking in pcpu_balance_workfn() (Waiman Long) [2008341]
- percpu: initialize best_upa variable (Waiman Long) [2008341]
- percpu: rework memcg accounting (Waiman Long) [2008341]
- mm, memcg: introduce mem_cgroup_kmem_disabled() (Waiman Long) [2008341]
- mm, memcg: mark cgroup_memory_nosocket, nokmem and noswap as __ro_after_init (Waiman Long) [2008341]
- mm: vmscan: shrink deferred objects proportional to priority (Waiman Long) [2008341]
- mm: memcontrol: reparent nr_deferred when memcg offline (Waiman Long) [2008341]
- mm: vmscan: don't need allocate shrinker->nr_deferred for memcg aware shrinkers (Waiman Long) [2008341]
- mm: vmscan: use per memcg nr_deferred of shrinker (Waiman Long) [2008341]
- mm: vmscan: add per memcg shrinker nr_deferred (Waiman Long) [2008341]
- mm: vmscan: use a new flag to indicate shrinker is registered (Waiman Long) [2008341]
- mm: vmscan: add shrinker_info_protected() helper (Waiman Long) [2008341]
- mm: memcontrol: rename shrinker_map to shrinker_info (Waiman Long) [2008341]
- mm: vmscan: use kvfree_rcu instead of call_rcu (Waiman Long) [2008341]
- mm: vmscan: remove memcg_shrinker_map_size (Waiman Long) [2008341]
- mm: vmscan: use shrinker_rwsem to protect shrinker_maps allocation (Waiman Long) [2008341]
- mm: vmscan: consolidate shrinker_maps handling code (Waiman Long) [2008341]
- mm: vmscan: use nid from shrink_control for tracepoint (Waiman Long) [2008341]
- linux/memcontrol.h: remove duplicate struct declaration (Waiman Long) [2008341]
- memcg: charge before adding to swapcache on swapin (Waiman Long) [2008341]
- kselftests: cgroup: update kmem test for new vmstat implementation (Waiman Long) [2008341]
- mm: memcontrol: consolidate lruvec stat flushing (Waiman Long) [2008341]
- mm: memcontrol: switch to rstat (Waiman Long) [2008341]
- cgroup: rstat: punt root-level optimization to individual controllers (Waiman Long) [2008341]
- cgroup: rstat: support cgroup1 (Waiman Long) [2008341]
- mm: memcontrol: privatize memcg_page_state query functions (Waiman Long) [2008341]
- mm: memcontrol: kill mem_cgroup_nodeinfo() (Waiman Long) [2008341]
- memcg: enable memcg oom-kill for __GFP_NOFAIL (Waiman Long) [2008341]
- memcg: cleanup root memcg checks (Waiman Long) [2008341]
- mm: memcontrol: fix kernel stack account (Waiman Long) [2008341]
- mm: page-writeback: simplify memcg handling in test_clear_page_writeback() (Waiman Long) [2008341]
- percpu: implement partial chunk depopulation (Waiman Long) [2008341]
- percpu: use pcpu_free_slot instead of pcpu_nr_slots - 1 (Waiman Long) [2008341]
- percpu: factor out pcpu_check_block_hint() (Waiman Long) [2008341]
- percpu: split __pcpu_balance_workfn() (Waiman Long) [2008341]
- percpu: fix a comment about the chunks ordering (Waiman Long) [2008341]
- mm/compaction: remove rcu_read_lock during page compaction (Waiman Long) [2008341]
- mm/vmscan.c: make lruvec_lru_size() static (Waiman Long) [2008341]
- include/linux/mm_inline.h: fold __update_lru_size() into its sole caller (Waiman Long) [2008341]
- include/linux/mm_inline.h: fold page_lru_base_type() into its sole caller (Waiman Long) [2008341]
- mm: VM_BUG_ON lru page flags (Waiman Long) [2008341]
- mm: add __clear_page_lru_flags() to replace page_off_lru() (Waiman Long) [2008341]
- mm/swap.c: don't pass "enum lru_list" to del_page_from_lru_list() (Waiman Long) [2008341]
- mm/swap.c: don't pass "enum lru_list" to trace_mm_lru_insertion() (Waiman Long) [2008341]
- mm: don't pass "enum lru_list" to lru list addition functions (Waiman Long) [2008341]
- include/linux/mm_inline.h: shuffle lru list addition and deletion functions (Waiman Long) [2008341]
- mm/vmscan.c: use add_page_to_lru_list() (Waiman Long) [2008341]
- mm: fix VM_BUG_ON(PageTail) and BUG_ON(PageWriteback) (Waiman Long) [2008341]
- mm: remove superfluous __ClearPageActive() (Waiman Long) [2008341]
- mm, memcg: decouple e{low,min} state mutations from protection checks (Waiman Long) [2008341]
- Revert "cgroup: Add memory barriers to plug cgroup_rstat_updated() race window" (Waiman Long) [2008341]
- mm/memcontrol.c: allocate shrinker_map on appropriate NUMA node (Waiman Long) [2008341]
- include/bitmap.h: add new functions to documentation (Waiman Long) [2008341]
- include/bitmap.h: add missing parameter in docs (Waiman Long) [2008341]
- bitmap: genericize percpu bitmap region iterators (Waiman Long) [2008341]
- cgroup, rstat: Don't flush subtree root unless necessary (Waiman Long) [2008341]
- mm/memcg: Move mem_cgroup kABI compatibility structure into rh_kabi_memcg.h (Waiman Long) [2008341]
- mm/swap: consider max pages in iomap_swapfile_add_extent (Brian Foster) [1969326]
- mm/slub: Fix backtrace of objects to handle redzone adjustment (Waiman Long) [2008340]
- powerpc/powernv: Fix CPU idle to be called with IRQs disabled (Waiman Long) [2008340]
- torture: Fix grace-period rate output (Waiman Long) [2008340]
- rcu: Fix kfree_rcu() docbook errors (Waiman Long) [2008340]
- rcu/nocb: Perform deferred wake up before last idle's need_resched() check (Waiman Long) [2008340]
- rcu: Pull deferred rcuog wake up to rcu_eqs_enter() callers (Waiman Long) [2008340]
- idle: Prevent late-arriving interrupts from disrupting offline (Waiman Long) [2008340]
- torture: Maintain torture-specific set of CPUs-online books (Waiman Long) [2008340]
- torture: Clean up after torture-test CPU hotplugging (Waiman Long) [2008340]
- rcutorture: Make object_debug also double call_rcu() heap object (Waiman Long) [2008340]
- torture: Throttle VERBOSE_TOROUT_*() output (Waiman Long) [2008340]
- torture: Make refscale throttle high-rate printk()s (Waiman Long) [2008340]
- rcutorture: Use hrtimers for reader and writer delays (Waiman Long) [2008340]
- torture: Make stutter use torture_hrtimeout_*() functions (Waiman Long) [2008340]
- rcutorture: Use torture_hrtimeout_jiffies() to avoid busy-waits (Waiman Long) [2008340]
- torture: Add fuzzed hrtimer-based sleep functions (Waiman Long) [2008340]
- rcutorture: Make rcu_torture_fakewriter() use blocking wait primitives (Waiman Long) [2008340]
- rcutorture: Make synctype[] and nsynctype be static global (Waiman Long) [2008340]
- rcutorture: Require entire stutter period be post-boot (Waiman Long) [2008340]
- refscale: Allow summarization of verbose output (Waiman Long) [2008340]
- torture: Allow standalone kvm-recheck.sh run detect --trust-make (Waiman Long) [2008340]
- torture: Simplify exit-code plumbing for kvm-recheck.sh and kvm-find-errors.sh (Waiman Long) [2008340]
- torture: s/STOP/STOP.1/ to avoid scenario collision (Waiman Long) [2008340]
- torture: Add --dryrun batches to help schedule a distributed run (Waiman Long) [2008340]
- torture: Stop hanging on panic (Waiman Long) [2008340]
- torture: Add kvm.sh test summary to end of log file (Waiman Long) [2008340]
- torture: Make kvm.sh include --kconfig arguments in CPU calculation (Waiman Long) [2008340]
- torture: Make kvm.sh return failure upon build failure (Waiman Long) [2008340]
- torture: Print run duration at end of kvm.sh execution (Waiman Long) [2008340]
- torture: Make kvm.sh arguments accumulate (Waiman Long) [2008340]
- torture: Make kvm.sh "Test Summary" date be end of test (Waiman Long) [2008340]
- tools/rcutorture: Make identify_qemu_vcpus() independent of local language (Waiman Long) [2008340]
- torture: Add config2csv.sh script to compare torture scenarios (Waiman Long) [2008340]
- torture: Prepare for splitting qemu execution from kvm-test-1-run.sh (Waiman Long) [2008340]
- torture: Allow kvm.sh --datestamp to specify subdirectories (Waiman Long) [2008340]
- torture: Make kvm.sh "--dryrun sched" summarize number of builds (Waiman Long) [2008340]
- torture: Make kvm.sh "--dryrun sched" summarize number of batches (Waiman Long) [2008340]
- torture: Make --kcsan specify lockdep (Waiman Long) [2008340]
- rcu: Do not NMI offline CPUs (Waiman Long) [2008340]
- rcu: For RCU grace-period kthread starvation, dump last CPU it ran on (Waiman Long) [2008340]
- rcu: Mark obtuse portion of stall warning as internal debug (Waiman Long) [2008340]
- scftorture: Add debug output for wrong-CPU warning (Waiman Long) [2008340]
- rcutorture: Add testing for RCU's global memory ordering (Waiman Long) [2008340]
- rcutorture: Add reader-side tests of polling grace-period API (Waiman Long) [2008340]
- rcutorture: Add writer-side tests of polling grace-period API (Waiman Long) [2008340]
- rcutorture: Prepare for ->start_gp_poll and ->poll_gp_state (Waiman Long) [2008340]
- srcu: Add comment explaining cookie overflow/wrap (Waiman Long) [2008340]
- srcu: Document polling interfaces for Tree SRCU grace periods (Waiman Long) [2008340]
- srcu: Provide polling interfaces for Tree SRCU grace periods (Waiman Long) [2008340]
- srcu: Provide polling interfaces for Tiny SRCU grace periods (Waiman Long) [2008340]
- srcu: Provide internal interface to start a Tree SRCU grace period (Waiman Long) [2008340]
- srcu: Provide internal interface to start a Tiny SRCU grace period (Waiman Long) [2008340]
- srcu: Make Tiny SRCU use multi-bit grace-period counter (Waiman Long) [2008340]
- rcu: Enable rcu_normal_after_boot unconditionally for RT (Waiman Long) [2008340]
- rcu: Unconditionally use rcuc threads on PREEMPT_RT (Waiman Long) [2008340]
- rcu: Make RCU_BOOST default on CONFIG_PREEMPT_RT (Waiman Long) [2008340]
- rcu: Eliminate the __kvfree_rcu() macro (Waiman Long) [2008340]
- rcu: Introduce kfree_rcu() single-argument macro (Waiman Long) [2008340]
- rcu: Record kvfree_call_rcu() call stack for KASAN (Waiman Long) [2008340]
- rcu: Do any deferred nocb wakeups at CPU offline time (Waiman Long) [2008340]
- rcu/nocb: Code-style nits in callback-offloading toggling (Waiman Long) [2008340]
- rcu/nocb: Add nocb CB kthread list to show_rcu_nocb_state() output (Waiman Long) [2008340]
- rcu/nocb: Add grace period and task state to show_rcu_nocb_state() output (Waiman Long) [2008340]
- tools/rcutorture: Support nocb toggle in TREE01 (Waiman Long) [2008340]
- rcutorture: Test runtime toggling of CPUs' callback offloading (Waiman Long) [2008340]
- cpu/hotplug: Add lockdep_is_cpus_held() (Waiman Long) [2008340]
- rcu/nocb: Locally accelerate callbacks as long as offloading isn't complete (Waiman Long) [2008340]
- rcu/nocb: Process batch locally as long as offloading isn't complete (Waiman Long) [2008340]
- rcu/nocb: Only cond_resched() from actual offloaded batch processing (Waiman Long) [2008340]
- rcu/nocb: Set SEGCBLIST_SOFTIRQ_ONLY at the very last stage of de-offloading (Waiman Long) [2008340]
- rcu/nocb: Flush bypass before setting SEGCBLIST_SOFTIRQ_ONLY (Waiman Long) [2008340]
- rcu/nocb: Shutdown nocb timer on de-offloading (Waiman Long) [2008340]
- rcu/nocb: Re-offload support (Waiman Long) [2008340]
- rcu/nocb: De-offloading GP kthread (Waiman Long) [2008340]
- rcu/nocb: Don't deoffload an offline CPU with pending work (Waiman Long) [2008340]
- rcu/nocb: De-offloading CB kthread (Waiman Long) [2008340]
- rcu/nocb: Always init segcblist on CPU up (Waiman Long) [2008340]
- rcu/nocb: Provide basic callback offloading state machine bits (Waiman Long) [2008340]
- rcu/nocb: Turn enabled/offload states into a common flag (Waiman Long) [2008340]
- rcu/segcblist: Add debug checks for segment lengths (Waiman Long) [2008340]
- rcu/trace: Add tracing for how segcb list changes (Waiman Long) [2008340]
- rcu/tree: segcblist: Remove redundant smp_mb()s (Waiman Long) [2008340]
- rcu/segcblist: Add counters to segcblist datastructure (Waiman Long) [2008340]
- rcu/segcblist: Add additional comments to explain smp_mb() (Waiman Long) [2008340]
- rcu/tree: Make rcu_do_batch count how many callbacks were executed (Waiman Long) [2008340]
- rcu: Make call_rcu() print mem_dump_obj() info for double-freed callback (Waiman Long) [2008340]
- mm: Make mem_obj_dump() vmalloc() dumps include start and length (Waiman Long) [2008340]
- mm: Make mem_dump_obj() handle vmalloc() memory (Waiman Long) [2008340]
- mm: Make mem_dump_obj() handle NULL and zero-sized pointers (Waiman Long) [2008340]
- mm: Add mem_dump_obj() to print source of memory block (Waiman Long) [2008340]
- rcu: Make TASKS_TRACE_RCU select IRQ_WORK (Waiman Long) [2008340]
- rcu-tasks: Add RCU-tasks self tests (Waiman Long) [2008340]
- rcu-tasks: Move RCU-tasks initialization to before early_initcall() (Waiman Long) [2008340]
- rcu: Add lockdep_assert_irqs_disabled() to raw_spin_unlock_rcu_node() macros (Waiman Long) [2008340]
- rcu: Add lockdep_assert_irqs_disabled() to rcu_sched_clock_irq() and callees (Waiman Long) [2008340]
- rcutorture: Don't do need_resched() testing if ->sync is NULL (Waiman Long) [2008340]
- scftorture: Add full-test stutter capability (Waiman Long) [2008340]
- torture: Allow alternative forms of kvm.sh command-line arguments (Waiman Long) [2008340]
- rcutorture: Small code cleanups (Waiman Long) [2008340]
- torture: Accept time units on kvm.sh --duration argument (Waiman Long) [2008340]
- rcutorture:  Make stutter_wait() caller restore priority (Waiman Long) [2008340]
- torture: Force weak-hashed pointers on console log (Waiman Long) [2008340]
- rcutorture: Prevent hangs for invalid arguments (Waiman Long) [2008340]
- torture: Prevent jitter processes from delaying failed run (Waiman Long) [2008340]
- rcutorture: Adjust scenarios SRCU-t and SRCU-u to make kconfig happy (Waiman Long) [2008340]
- refscale: Prevent hangs for invalid arguments (Waiman Long) [2008340]
- rcuscale: Prevent hangs for invalid arguments (Waiman Long) [2008340]
- torture: Exclude "NOHZ tick-stop error" from fatal errors (Waiman Long) [2008340]
- rcuscale: Avoid divide by zero (Waiman Long) [2008340]
- rcuscale: Add RCU Tasks Trace (Waiman Long) [2008340]
- scftorture: Add an alternative IPI vector (Waiman Long) [2008340]
- torture: Make torture_stutter() use hrtimer (Waiman Long) [2008340]
- torture: Periodically pause in stutter_wait() (Waiman Long) [2008340]
- torture: Don't kill gdb sessions (Waiman Long) [2008340]
- refscale: Bounds-check module parameters (Waiman Long) [2008340]
- rcu-tasks: Make the units of ->init_fract be jiffies (Waiman Long) [2008340]
- rcutorture: Make grace-period kthread report match RCU flavor being tested (Waiman Long) [2008340]
- rcu-tasks: Convert rcu_tasks_wait_gp() for-loop to while-loop (Waiman Long) [2008340]
- rcutorture: Make preemptible TRACE02 enable lockdep (Waiman Long) [2008340]
- srcu: Use a more appropriate lockdep helper (Waiman Long) [2008340]
- srcu: Take early exit on memory-allocation failure (Waiman Long) [2008340]
- rcu: Fix a typo in rcu_blocking_is_gp() header comment (Waiman Long) [2008340]
- rcu: Prevent lockdep-RCU splats on lock acquisition/release (Waiman Long) [2008340]
- rcu/tree: nocb: Avoid raising softirq for offloaded ready-to-execute CBs (Waiman Long) [2008340]
- rcu/tree: Make struct kernel_param_ops definitions const (Waiman Long) [2008340]
- rcu/tree: Add a warning if CPU being onlined did not report QS already (Waiman Long) [2008340]
- rcu: Clarify nocb kthreads naming in RCU_NOCB_CPU config (Waiman Long) [2008340]
- rcu: Fix single-CPU check in rcu_blocking_is_gp() (Waiman Long) [2008340]
- rcu: Implement rcu_segcblist_is_offloaded() config dependent (Waiman Long) [2008340]
- list.h: Update comment to explicitly note circular lists (Waiman Long) [2008340]
- rcu: Panic after fixed number of stalls (Waiman Long) [2008340]
- x86/smpboot:  Move rcu_cpu_starting() earlier (Waiman Long) [2008340]
- torture: Replace cpu_up/down() with add/remove_cpu() (Waiman Long) [2008340]
- PCI/PTM: Remove error message at boot (Myron Stowe) [1993252]
- PCI: Mark AMD Navi14 GPU ATS as broken (Myron Stowe) [1993252]
- PCI: vmd: Update type of the __iomem pointers (Myron Stowe) [1993252]
- PCI: Unify ECAM constants in native PCI Express drivers (Myron Stowe) [1993252]
- PCI: Add function 1 DMA alias quirk for Marvell 9215 SATA controller (Myron Stowe) [1993252]
- PCI: Mark AMD Raven iGPU ATS as broken in some platforms (Myron Stowe) [1993252]
- PCI: Disable PTM during suspend to save power (Myron Stowe) [1993252]
- PCI/PTM: Save/restore Precision Time Measurement Capability for suspend/resume (Myron Stowe) [1993252]
- PCI: Add sysfs attribute for device power state (Myron Stowe) [1993252]
- PCI/MSI: Set device flag indicating only 32-bit MSI support (Myron Stowe) [1993252]
- PCI/MSI: Move MSI/MSI-X flags updaters to msi.c (Myron Stowe) [1993252]
- PCI/MSI: Move MSI/MSI-X init to msi.c (Myron Stowe) [1993252]
- PCI: Use predefined Pericom Vendor ID (Myron Stowe) [1993252]
- PCI: Disable MSI for Pericom PCIe-USB adapter (Myron Stowe) [1993252]
- PCI: Reduce pci_set_cacheline_size() message to debug level (Myron Stowe) [1993252]
- PCI: Remove unused HAVE_PCI_SET_MWI (Myron Stowe) [1993252]
- PCI: Fix overflow in command-line resource alignment requests (Myron Stowe) [1993252]
- PCI: Bounds-check command-line resource alignment requests (Myron Stowe) [1993252]
- PCI: Fix kernel-doc markup (Myron Stowe) [1993252]
- PCI: ibmphp: Remove unneeded break (Myron Stowe) [1993252]
- PCI/ACPI: Fix companion lookup for device 0 on the root bus (Myron Stowe) [1993252]
- PCI: Keep both device and resource name for config space remaps (Myron Stowe) [1993252]
- PCI: Return u16 from pci_find_ext_capability() and similar (Myron Stowe) [1993252]
- PCI: Return u8 from pci_find_capability() and similar (Myron Stowe) [1993252]
- PCI: Avoid duplicate IDs in driver dynamic IDs list (Myron Stowe) [1993252]
- PCI: Move pci_match_device() ahead of new_id_store() (Myron Stowe) [1993252]
- PCI: Decode PCIe 64 GT/s link speed (Myron Stowe) [1993252]
- PCI: host-generic: Support building as modules (Myron Stowe) [1993252]
- ata: sata_nv: Fix retrieving of active qcs (Tomas Henzl) [1921465]
- ata: pata_ns87415.c: Document support on parisc with superio chip (Tomas Henzl) [1921465]
- ata: fix some kernel-doc markups (Tomas Henzl) [1921465]
- sata, highbank: simplify the return expression of ahci_highbank_suspend (Tomas Henzl) [1921465]
- libata: implement ATA_HORKAGE_MAX_TRIM_128M and apply to Sandisks (Tomas Henzl) [1921465]
- ata: ahci: use ata_link_info() instead of ata_link_printk() (Tomas Henzl) [1921465]
- libata: Use per port sync for detach (Tomas Henzl) [1921465]
- ata/libata: Fix usage of page address by page_address in ata_scsi_mode_select_xlat function (Tomas Henzl) [1921465]
- sata_rcar: handle pm_runtime_get_sync failure cases (Tomas Henzl) [1921465]
- ata: sata_inic162x fix a spelling issue (Tomas Henzl) [1921465]
- ata: libata-core: fix a doc warning (Tomas Henzl) [1921465]
- ata: ahci: Add sysfs attribute to show remapped NVMe device count (Tomas Henzl) [1921465]
- ata: ahci-imx: remove redundant assignment to ret (Tomas Henzl) [1921465]
- libata: Return correct status in sata_pmp_eh_recover_pm() when ATA_DFLAG_DETACH is set (Tomas Henzl) [1921465]
- ata: move ata_eh_analyze_ncq_error() & co. to libata-sata.c (Tomas Henzl) [1921465]
- ata: start separating SATA specific code from libata-eh.c (Tomas Henzl) [1921465]
- ata: move ata_sas_*() to libata-sata.c (Tomas Henzl) [1921465]
- ata: start separating SATA specific code from libata-scsi.c (Tomas Henzl) [1921465]
- ata: move sata_deb_timing_*() to libata-sata.c (Tomas Henzl) [1921465]
- ata: move ata_qc_complete_multiple() to libata-sata.c (Tomas Henzl) [1921465]
- ata: move sata_link_hardreset() to libata-sata.c (Tomas Henzl) [1921465]
- ata: move sata_link_{debounce,resume}() to libata-sata.c (Tomas Henzl) [1921465]
- ata: move *sata_set_spd*() to libata-sata.c (Tomas Henzl) [1921465]
- ata: move sata_scr_*() to libata-sata.c (Tomas Henzl) [1921465]
- ata: start separating SATA specific code from libata-core.c (Tomas Henzl) [1921465]
- ata: fix CodingStyle issues in PATA timings code (Tomas Henzl) [1921465]
- ata: remove EXPORT_SYMBOL_GPL()s not used by modules (Tomas Henzl) [1921465]
- ata: move EXPORT_SYMBOL_GPL()s close to exported code (Tomas Henzl) [1921465]
- ata: optimize ata_scsi_rbuf[] size (Tomas Henzl) [1921465]
- ata: optimize struct ata_force_param size (Tomas Henzl) [1921465]
- ata: use COMMAND_LINE_SIZE for ata_force_param_buf[] size (Tomas Henzl) [1921465]
- ata: simplify ata_scsiop_inq_89() (Tomas Henzl) [1921465]
- sata_promise: use ata_cable_sata() (Tomas Henzl) [1921465]
- ata: make SATA_PMP option selectable only if any SATA host driver is enabled (Tomas Henzl) [1921465]
- ata: expose ncq_enable_prio sysfs attribute only on NCQ capable hosts (Tomas Henzl) [1921465]
- ata: remove stale maintainership information from core code (Tomas Henzl) [1921465]
- libata: Assign OF node to the SCSI device (Tomas Henzl) [1921465]
- libata: Remove extra scsi_host_put() in ata_scsi_add_hosts() (Tomas Henzl) [1921465]
- libata: transport: Use scnprintf() for avoiding potential buffer overflow (Tomas Henzl) [1921465]
- ata/acard_ahci: remove unused variable n_elem (Tomas Henzl) [1921465]
- ata: ahci_brcm: BCM7216 reset is self de-asserting (Tomas Henzl) [1921465]
- ata: ahci_brcm: Perform reset after obtaining resources (Tomas Henzl) [1921465]
- ata: brcm: fix reset controller API usage (Tomas Henzl) [1921465]
- ata: brcm: mark PM functions as __maybe_unused (Tomas Henzl) [1921465]
- ata: ahci_brcm: Support BCM7216 reset controller name (Tomas Henzl) [1921465]
- ata: ahci_brcm: Add a shutdown callback (Tomas Henzl) [1921465]
- ata: ahci_brcm: Manage reset line during suspend/resume (Tomas Henzl) [1921465]
- ata: ahci_brcm: Add missing clock management during recovery (Tomas Henzl) [1921465]
- ata: ahci_brcm: BCM7425 AHCI requires AHCI_HFLAG_DELAY_ENGINE (Tomas Henzl) [1921465]
- ata: ahci_brcm: Fix AHCI resources management (Tomas Henzl) [1921465]
- ata: libahci_platform: Export again ahci_platform_<en/dis>able_phys() (Tomas Henzl) [1921465]
- libata: Fix retrieving of active qcs (Tomas Henzl) [1921465]
- ata: pata_artop: make arrays static const, makes object smaller (Tomas Henzl) [1921465]
- ata_piix: remove open-coded dmi_match(DMI_OEM_STRING) (Tomas Henzl) [1921465]
- ata: sata_mv, avoid trigerrable BUG_ON (Tomas Henzl) [1921465]
- ata: make qc_prep return ata_completion_errors (Tomas Henzl) [1921465]
- ata: define AC_ERR_OK (Tomas Henzl) [1921465]
- libata: Ensure ata_port probe has completed before detach (Tomas Henzl) [1921465]
- ahci: tegra: use regulator_bulk_set_supply_names() (Tomas Henzl) [1921465]
- ahci: Add support for Amazon's Annapurna Labs SATA controller (Tomas Henzl) [1921465]
- ata: libahci_platform: Fix regulator_get_optional() misuse (Tomas Henzl) [1921465]
- ata: ahci-imx: Covert to use GPIO descriptor (Tomas Henzl) [1921465]
- libata/ahci: Fix PCS quirk application (Tomas Henzl) [1921465]
- libata/ahci: Drop PCS quirk for Denverton and beyond (Tomas Henzl) [1921465]
- libata: switch remaining drivers to use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- sata_sil24: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- sata_qstor: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- sata_nv: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- sata_mv: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- pdc_adma: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- ahci: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- acard_ahci: use dma_set_mask_and_coherent (Tomas Henzl) [1921465]
- libata: add SG safety checks in SFF pio transfers (Tomas Henzl) [1921465]
- libata: have ata_scsi_rw_xlat() fail invalid passthrough requests (Tomas Henzl) [1921465]
- ata: rb532_cf: Fix unused variable warning in rb532_pata_driver_probe (Tomas Henzl) [1921465]
- ata: libahci: do not complain in case of deferred probe (Tomas Henzl) [1921465]
- libata: zpodd: Fix small read overflow in zpodd_get_mech_type() (Tomas Henzl) [1921465]
- ata: libahci_platform: remove redundant dev_err message (Tomas Henzl) [1921465]
- drivers: ata: ahci_sunxi: Increased SATA/AHCI DMA TX/RX FIFOs (Tomas Henzl) [1921465]
- libata: Drop firmware version check from the ST1000LM024 quirk (Tomas Henzl) [1921465]
- ata: sata_sil24: Remove call to memset after dmam_alloc_coherent (Tomas Henzl) [1921465]
- ata:sata_qstor: Remove call to memset after dmam_alloc_coherent (Tomas Henzl) [1921465]
- ata: sata_nv: Remove call to memset after dmam_alloc_coherent (Tomas Henzl) [1921465]
- ata: pdc_adma: Remove call to memset after dmam_alloc_coherent (Tomas Henzl) [1921465]
- ata: libahci: Remove call to memset after dmam_alloc_coherent (Tomas Henzl) [1921465]
- ata: acard-ahci: Remove call to memset after dmam_alloc_coherent (Tomas Henzl) [1921465]
- libata: don't request sense data on !ZAC ATA devices (Tomas Henzl) [1921465]
- libata: Extend quirks for the ST1000LM024 drives with NOLPM quirk (Tomas Henzl) [1921465]
- sata_rcar: Remove ata_host_alloc() error printing (Tomas Henzl) [1921465]
- libata: fix using DMA buffers on stack (Tomas Henzl) [1921465]
- ata: libahci: Only warn for AHCI_HFLAG_MULTI_MSI set when genuine custom irq handler implemented (Tomas Henzl) [1921465]
- libata: fix a typo in comment (Tomas Henzl) [1921465]
- sata_rcar: fix deferred probing (Tomas Henzl) [1921465]
- ata: sata_highbank: Convert to use GPIO descriptors (Tomas Henzl) [1921465]
- sata_rcar: convert to SPDX identifiers (Tomas Henzl) [1921465]
- ata: ep93xx: Use proper enums for directions (Tomas Henzl) [1921465]
- ata: ahci_brcm: Allow using driver or DSL SoCs (Tomas Henzl) [1921465]
- ata: ahci_brcm: Match BCM63138 compatible strings (Tomas Henzl) [1921465]
- ata: ahci_brcm: Allow optional reset controller to be used (Tomas Henzl) [1921465]
- libata: mask swap internal and hardware tag (Tomas Henzl) [1921465]
- pata_atiixp: Remove unnecessary parentheses (Tomas Henzl) [1921465]
- ata: ahci_sunxi: add support for r40 (Tomas Henzl) [1921465]
- ata: ahci_platform: add support for PHY controller regulator (Tomas Henzl) [1921465]
- ata: ahci_platform: add support for AHCI controller regulator (Tomas Henzl) [1921465]
- libata: Use SMART LBAM/LBAH password defines (Tomas Henzl) [1921465]
- ata: ahci: Convert to using pOFn instead of device_node.name (Tomas Henzl) [1921465]
- ata: ftide010: Add a quirk for SQ201 (Tomas Henzl) [1921465]
- ata: ahci_platform: enable to get and control reset (Tomas Henzl) [1921465]
- ata: libahci_platform: add reset control support (Tomas Henzl) [1921465]
- ata: add an extra argument to ahci_platform_get_resources() (Tomas Henzl) [1921465]
- ata: sata_rcar: exclude setting of PHY registers in Gen3 (Tomas Henzl) [1921465]
- ata: sata_rcar: really mask all interrupts on Gen2 and later (Tomas Henzl) [1921465]
- ata: libahci: Allow reconfigure of DEVSLP register (Tomas Henzl) [1921465]
- ata: libahci: Correct setting of DEVSLP register (Tomas Henzl) [1921465]
- ata: ahci: Enable DEVSLP by default on x86 with SLP_S0 (Tomas Henzl) [1921465]
- ata: ahci: Support state with min power but Partial low power state (Tomas Henzl) [1921465]
- Revert "ata: ahci_platform: convert kcalloc to devm_kcalloc" (Tomas Henzl) [1921465]
- ata: sata_rcar: Add rudimentary Runtime PM support (Tomas Henzl) [1921465]
- ata: sata_rcar: Provide a short-hand for &pdev->dev (Tomas Henzl) [1921465]
- ata: Only output sg element mapped number in verbose debug (Tomas Henzl) [1921465]
- ata: Guard ata_scsi_dump_cdb() by ATA_VERBOSE_DEBUG (Tomas Henzl) [1921465]
- ata: ahci_platform: convert kcalloc to devm_kcalloc (Tomas Henzl) [1921465]
- ata: ahci_platform: convert kzallloc to kcalloc (Tomas Henzl) [1921465]
- ata: ahci_platform: correct parameter documentation for ahci_platform_shutdown (Tomas Henzl) [1921465]
- libata: remove ata_sff_data_xfer_noirq() (Tomas Henzl) [1921465]
- scsi: target: Fix the pgr/alua_support_store functions (Maurizio Lombardi) [1995935]
- sched/deadline: Fix missing clock update in migrate_task_rq_dl() (Phil Auld) [1992254]
- sched/fair: Avoid a second scan of target in select_idle_cpu (Phil Auld) [1992254]
- sched/fair: Use prev instead of new target as recent_used_cpu (Phil Auld) [1992254]
- sched: Replace deprecated CPU-hotplug functions. (Phil Auld) [1992254]
- sched/deadline: Fix reset_on_fork reporting of DL tasks (Phil Auld) [1992254]
- sched/numa: Fix is_core_idle() (Phil Auld) [1992254]
- sched/fair: Sync load_sum with load_avg after dequeue (Phil Auld) [1992254]
- sched/fair: Fix CFS bandwidth hrtimer expiry type (Phil Auld) [1992254]
- sched/fair: Ensure _sum and _avg values stay consistent (Phil Auld) [1992254]
- sched/fair: Ensure that the CFS parent is added after unthrottling (Phil Auld) [1992254]
- sched/rt: Fix Deadline utilization tracking during policy change (Phil Auld) [1992254]
- sched/rt: Fix RT utilization tracking during policy change (Phil Auld) [1992254]
- sched/fair: Age the average idle time (Phil Auld) [1992254]
- wait: use LIST_HEAD_INIT() to initialize wait_queue_head (Phil Auld) [1992254]
- sched: Optimize housekeeping_cpumask() in for_each_cpu_and() (Phil Auld) [1992254]
- sched/fair: Fix util_est UTIL_AVG_UNCHANGED handling (Phil Auld) [1992254]
- sched/pelt: Check that *_avg are null when *_sum are (Phil Auld) [1992254]
- sched/fair: Correctly insert cfs_rq's to list on unthrottle (Phil Auld) [1992254]
- sched/pelt: Ensure that *_sum is always synced with *_avg (Phil Auld) [1992254]
- sched/fair: Return early from update_tg_cfs_load() if delta == 0 (Phil Auld) [1992254]
- sched/fair: Make sure to update tg contrib for blocked load (Phil Auld) [1992254]
- sched/fair: Keep load_avg and load_sum synced (Phil Auld) [1992254]
- sched: Stop PF_NO_SETAFFINITY from being inherited by various init system threads (Phil Auld) [1992254]
- sched: Fix a stale comment in pick_next_task() (Phil Auld) [1992254]
- sched/fair: Fix ascii art by relpacing tabs (Phil Auld) [1992254]
- tick/nohz: Call tick_nohz_task_switch() with interrupts disabled (Phil Auld) [1992254]
- sched/fair: Fix clearing of has_idle_cores flag in select_idle_cpu() (Phil Auld) [1992254]
- sched/core: Remove the pointless BUG_ON(!task) from wake_up_q() (Phil Auld) [1992254]
- sched: Make the idle task quack like a per-CPU kthread (Phil Auld) [1992254]
- sched/fair: Fix unfairness caused by missing load decay (Phil Auld) [1992254]
- sched: Make nr_iowait_cpu() return 32-bit value (Phil Auld) [1992254]
- sched: Make nr_iowait() return 32-bit value (Phil Auld) [1992254]
- sched: Make nr_running() return 32-bit value (Phil Auld) [1992254]
- sched/isolation: Reconcile rcu_nocbs= and nohz_full= (Phil Auld) [1992254]
- sched/fair: Introduce a CPU capacity comparison helper (Phil Auld) [1992254]
- sched/fair: Clean up active balance nr_balance_failed trickery (Phil Auld) [1992254]
- sched/fair: Move update_nohz_stats() to the CONFIG_NO_HZ_COMMON block to simplify the code & fix an unused function warning (Phil Auld) [1992254]
- sched/fair: Bring back select_idle_smt(), but differently (Phil Auld) [1992254]
- sched,fair: Alternative sched_slice() (Phil Auld) [1992254]
- sched/topology: Remove redundant cpumask_and() in init_overlap_sched_group() (Phil Auld) [1992254]
- sched/numa: Allow runtime enabling/disabling of NUMA balance without SCHED_DEBUG (Phil Auld) [1992254]
- sched/fair: Optimize test_idle_cores() for !SMT (Phil Auld) [1992254]
- sched: Fix various typos (Phil Auld) [1992254]
- sched: Remove unnecessary variable from schedule_tail() (Phil Auld) [1992254]
- sched: Optimize __calc_delta() (Phil Auld) [1992254]
- sched: Provide raw_spin_rq_*lock*() helpers (Phil Auld) [1992254]
- sched/pelt: Fix task util_est update filtering (Phil Auld) [1992254]
- sched/fair: use lsub_positive in cpu_util_next() (Phil Auld) [1992254]
- sched/fair: Reduce the window for duplicated update (Phil Auld) [1992254]
- sched/fair: Reorder newidle_balance pulled_task tests (Phil Auld) [1992254]
- sched/fair: Remove unused parameter of update_nohz_stats (Phil Auld) [1992254]
- sched/fair: Remove unused return of _nohz_idle_balance (Phil Auld) [1992254]
- sched/fair: Remove update of blocked load from newidle_balance (Phil Auld) [1992254]
- sched/topology: fix the issue groups don't span domain->span for NUMA diameter > 2 (Phil Auld) [1992254]
- sched/fair: Merge select_idle_core/cpu() (Phil Auld) [1992254]
- sched/fair: Remove select_idle_smt() (Phil Auld) [1992254]
- sched/fair: Move avg_scan_cost calculations under SIS_PROP (Phil Auld) [1992254]
- sched/fair: Remove SIS_AVG_CPU (Phil Auld) [1992254]
- sched/eas: Don't update misfit status if the task is pinned (Phil Auld) [1992254]
- sched/fair: Avoid stale CPU util_est value for schedutil in task dequeue (Phil Auld) [1992254]
- sched/fair: Add a few assertions (Phil Auld) [1992254]
- cpufreq: schedutil: Simplify sugov_update_next_freq() (Phil Auld) [1992254]
- sched/topology: Warn when NUMA diameter > 2 (Phil Auld) [1992254]
- sched: Use task_current() instead of 'rq->curr == p' (Phil Auld) [1992254]
- sched/core: Allow try_invoke_on_locked_down_task() with irqs disabled (Phil Auld) [1992254]
- sched/fair: Exclude the current CPU from find_new_ilb() (Phil Auld) [1992254]
- rbtree, sched/deadline: Use rb_add_cached() (Phil Auld) [1992254]
- rbtree, sched/fair: Use rb_add_cached() (Phil Auld) [1992254]
- sched/isolation: Prefer housekeeping CPU in local node (Phil Auld) [1992254]
- sched: Fix various typos in comments (Phil Auld) [1992254]
- s390/qeth: fix deadlock during failing recovery (Sumanth Korikkar) [1984990]
- s390/qeth: Fix deadlock in remove_discipline (Sumanth Korikkar) [1984990]
- s390/qeth: fix NULL deref in qeth_clear_working_pool_list() (Sumanth Korikkar) [1984990]
- s390/qdio: fix roll-back after timeout on ESTABLISH ccw (Sumanth Korikkar) [1984990]
- s390/qdio: get rid of register asm (Sumanth Korikkar) [1984990]
- s390/netiuvc: get rid of forward declarations (Sumanth Korikkar) [1984990]
- s390/qeth: Consider dependency on SWITCHDEV module (Sumanth Korikkar) [1984990]
- s390/qeth: shrink TX buffer struct (Sumanth Korikkar) [1984990]
- s390/qeth: remove TX buffer's pointer to its queue (Sumanth Korikkar) [1984990]
- s390/qeth: remove QAOB's pointer to its TX buffer (Sumanth Korikkar) [1984990]
- s390/qeth: consolidate completion of pending TX buffers (Sumanth Korikkar) [1984990]
- s390/qeth: use ethtool_sprintf() (Sumanth Korikkar) [1984990]
- s390/qeth: unify the tracking of active cmds on ccw device (Sumanth Korikkar) [1984990]
- s390/qeth: also use TX NAPI for non-IQD devices (Sumanth Korikkar) [1984990]
- s390/qeth: count TX completion interrupts (Sumanth Korikkar) [1984990]
- powerpc/stacktrace: Include linux/delay.h (Steve Best) [2010674]
- powerpc/stacktrace: Fix spurious "stale" traces in raise_backtrace_ipi() (Steve Best) [2010674]
- powerpc/xmon: Reset RCU and soft lockup watchdogs (Steve Best) [2010674]
- bpf, sockmap: Fix sk->prot unhash op reset (Jiri Benc) [1947006]
- xdp: fix xdp_return_frame() kernel BUG throw for page_pool memory model (Jiri Benc) [1947006]
- selftests/bpf: Tests using bpf_check_mtu BPF-helper input mtu_len param (Jiri Benc) [1947006]
- bpf: BPF-helper for MTU checking add length input (Jiri Benc) [1947006]
- xsk: Remove dangling function declaration from header file (Jiri Benc) [1947006]
- bpf: Remove blank line in bpf helper description comment (Jiri Benc) [1947006]
- libbpf: Use AF_LOCAL instead of AF_INET in xsk.c (Jiri Benc) [1947006]
- selftests/bpf: Tests using bpf_check_mtu BPF-helper (Jiri Benc) [1947006]
- selftests/bpf: Use bpf_check_mtu in selftest test_cls_redirect (Jiri Benc) [1947006]
- bpf: Drop MTU check when doing TC-BPF redirect to ingress (Jiri Benc) [1947006]
- bpf: Add BPF-helper for MTU checking (Jiri Benc) [1947006]
- bpf: bpf_fib_lookup return MTU value as output when looked up (Jiri Benc) [1947006]
- bpf: Fix bpf_fib_lookup helper MTU check for SKB ctx (Jiri Benc) [1947006]
- bpf: Remove MTU check in __bpf_skb_max_len (Jiri Benc) [1947006]
- net, veth: Alloc skb in bulk for ndo_xdp_xmit (Jiri Benc) [1947006]
- bpf: Enable bpf_{g,s}etsockopt in BPF_CGROUP_UDP{4,6}_RECVMSG (Jiri Benc) [1947006]
- selftests/bpf: Rewrite recvmsg{4,6} asm progs to c in test_sock_addr (Jiri Benc) [1947006]
- bpf: Enable bpf_{g,s}etsockopt in BPF_CGROUP_INET{4,6}_GET{PEER,SOCK}NAME (Jiri Benc) [1947006]
- bpf: Enable bpf_{g,s}etsockopt in BPF_CGROUP_UDP{4,6}_SENDMSG (Jiri Benc) [1947006]
- selftests/bpf: Verify that rebinding to port < 1024 from BPF works (Jiri Benc) [1947006]
- bpf: Allow rewriting to ports under ip_unprivileged_port_start (Jiri Benc) [1947006]
- net: port < inet_prot_sock(net) --> inet_port_requires_bind_service(net, port) (Jiri Benc) [1947006]
- net: inet_is_local_reserved_port() should return bool not int (Jiri Benc) [1947006]
- libbpf, xsk: Select AF_XDP BPF program based on kernel version (Jiri Benc) [1947006]
- xsk: Fold xp_assign_dev and __xp_assign_dev (Jiri Benc) [1947006]
- xsk: Remove explicit_free parameter from __xsk_rcv() (Jiri Benc) [1947006]
- bpf: Split cgroup_bpf_enabled per attach type (Jiri Benc) [1947006]
- bpf: Remove extra lock_sock for TCP_ZEROCOPY_RECEIVE (Jiri Benc) [1947006]
- net, xdp: Introduce xdp_build_skb_from_frame utility routine (Jiri Benc) [1947006]
- net, xdp: Introduce __xdp_build_skb_from_frame utility routine (Jiri Benc) [1947006]
- bpf: Extend bind v4/v6 selftests for mark/prio/bindtoifindex (Jiri Benc) [1947006]
- bpf: Allow to retrieve sol_socket opts from sock_addr progs (Jiri Benc) [1947006]
- bpf: Replace fput with sockfd_put in sock map (Jiri Benc) [1947006]
- tools: bpf: add SO_BINDTOIFINDEX to socket.h in tools (Jiri Benc) [1947006]
- media: firewire: firedtv-avc: fix a buffer overflow in avc_ca_pmt() (Lucas Zampieri) [1956472] {CVE-2021-3542}

* Mon Oct 18 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-348.3.el8]
- mm/hmm: make HMM_MIRROR an implicit option (Rafael Aquini) [1998534]
- mm/hmm: allow HMM_MIRROR on all architectures with MMU (Rafael Aquini) [1998534]
- mm: don't select MIGRATE_VMA_HELPER from HMM_MIRROR (Rafael Aquini) [1998534]
- mm: sort out the DEVICE_PRIVATE Kconfig mess (Rafael Aquini) [1998534]
- s390/ap/zcrypt: notify userspace with online, config and mode info (Stefan Schulze Frielinghaus) [1984895]
- docs: livepatch: Fix a typo and remove the unnecessary gaps in a sentence (C. Erastus Toe) [1995447]
- Documentation: livepatch: document reliable stacktrace (C. Erastus Toe) [1995447]
- Documentation: livepatch: Convert to automatically generated contents (C. Erastus Toe) [1995447]
- scsi: ibmvfc: Reinitialize sub-CRQs and perform channel enquiry after LPM (Desnes A. Nunes do Rosario) [1932217]
- scsi: ibmvfc: Store return code of H_FREE_SUB_CRQ during cleanup (Desnes A. Nunes do Rosario) [1932217]
- scsi: ibmvfc: Treat H_CLOSED as success during sub-CRQ registration (Desnes A. Nunes do Rosario) [1932217]
- scsi: ibmvfc: Fix invalid sub-CRQ handles after hard reset (Desnes A. Nunes do Rosario) [1932217]
- scsi: ibmvfc: Simplify handling of sub-CRQ initialization (Desnes A. Nunes do Rosario) [1932217]
- exec: Transform exec_update_mutex into a rw_semaphore (Chris von Recklinghausen) [1993665]
- perf: Break deadlock involving exec_update_mutex (Chris von Recklinghausen) [1993665]
- pidfd: Add missing sock updates for pidfd_getfd() (Chris von Recklinghausen) [1993665]
- exec: Move the call of prepare_binprm into search_binary_handler (Chris von Recklinghausen) [1993665]
- exec: Allow load_misc_binary to call prepare_binprm unconditionally (Chris von Recklinghausen) [1993665]
- exec: Convert security_bprm_set_creds into security_bprm_repopulate_creds (Chris von Recklinghausen) [1993665]
- exec: Factor security_bprm_creds_for_exec out of security_bprm_set_creds (Chris von Recklinghausen) [1993665]
- exec: Move would_dump into flush_old_exec (Chris von Recklinghausen) [1993665]
- exec: Rename flush_old_exec begin_new_exec (Chris von Recklinghausen) [1993665]
- exec: Move most of setup_new_exec into flush_old_exec (Chris von Recklinghausen) [1993665]
- exec: In setup_new_exec cache current in the local variable me (Chris von Recklinghausen) [1993665]
- exec: Merge install_exec_creds into setup_new_exec (Chris von Recklinghausen) [1993665]
- exec: Rename the flag called_exec_mmap point_of_no_return (Chris von Recklinghausen) [1993665]
- exec: Make unlocking exec_update_mutex explict (Chris von Recklinghausen) [1993665]
- binfmt: Move install_exec_creds after setup_new_exec to match binfmt_elf (Chris von Recklinghausen) [1993665]
- pidfd: Use new infrastructure to fix deadlocks in execve (Chris von Recklinghausen) [1993665]
- perf: Use new infrastructure to fix deadlocks in execve (Chris von Recklinghausen) [1993665]
- proc: io_accounting: Use new infrastructure to fix deadlocks in execve (Chris von Recklinghausen) [1993665]
- proc: Use new infrastructure to fix deadlocks in execve (Chris von Recklinghausen) [1993665]
- kernel/kcmp.c: Use new infrastructure to fix deadlocks in execve (Chris von Recklinghausen) [1993665]
- kernel: doc: remove outdated comment cred.c (Chris von Recklinghausen) [1993665]
- mm: docs: Fix a comment in process_vm_rw_core (Chris von Recklinghausen) [1993665]
- selftests/ptrace: add test cases for dead-locks (Chris von Recklinghausen) [1993665]
- exec: Fix a deadlock in strace (Chris von Recklinghausen) [1993665]
- exec: Add exec_update_mutex to replace cred_guard_mutex (Chris von Recklinghausen) [1993665]
- exec: Move exec_mmap right after de_thread in flush_old_exec (Chris von Recklinghausen) [1993665]
- exec: Move cleanup of posix timers on exec out of de_thread (Chris von Recklinghausen) [1993665]
- exec: Factor unshare_sighand out of de_thread and call it separately (Chris von Recklinghausen) [1993665]
- exec: Only compute current once in flush_old_exec (Chris von Recklinghausen) [1993665]
- pid: Implement pidfd_getfd syscall (Chris von Recklinghausen) [1993665]
- pidfd: add P_PIDFD to waitid() (Chris von Recklinghausen) [1993665]
- fork: return proper negative error code (Chris von Recklinghausen) [1993665]
- copy_process(): don't use ksys_close() on cleanups (Chris von Recklinghausen) [1993665]
- fork: don't check parent_tidptr with CLONE_PIDFD (Chris von Recklinghausen) [1993665]
- fs/exec.c: move ->recursion_depth out of critical sections (Chris von Recklinghausen) [1993665]
- clone: add CLONE_PIDFD (Chris von Recklinghausen) [1993665]
- signal: support CLONE_PIDFD with pidfd_send_signal (Chris von Recklinghausen) [1993665]
- arch: add pidfd and io_uring syscalls everywhere (Chris von Recklinghausen) [1993665]
- signal: don't silently convert SI_USER signals to non-current pidfd (Chris von Recklinghausen) [1993665]
- signal: add pidfd_send_signal() syscall (Chris von Recklinghausen) [1993665]
- sched/core: Convert signal_struct.sigcnt to refcount_t (Chris von Recklinghausen) [1993665]
- sched/core: Convert sighand_struct.count to refcount_t (Chris von Recklinghausen) [1993665]
- exec: make prepare_bprm_creds static (Chris von Recklinghausen) [1993665]
- fork: don't copy inconsistent signal handler state to child (Chris von Recklinghausen) [1993665]
- Revert "perf: Break deadlock involving exec_update_mutex" (Chris von Recklinghausen) [1993665]
- powerpc/mm/highmem: use __set_pte_at() for kmap_local() (Nico Pache) [2001854]
- mm: extract might_alloc() debug check (Nico Pache) [2001854]
- mm/mempolicy: use vma_lookup() in __access_remote_vm() (Nico Pache) [2001854]
- mm/memory.c: use vma_lookup() in __access_remote_vm() (Nico Pache) [2001854]
- mm/mremap: use vma_lookup() in vma_to_resize() (Nico Pache) [2001854]
- mm/migrate: use vma_lookup() in do_pages_stat_array() (Nico Pache) [2001854]
- mm/ksm: use vma_lookup() in find_mergeable_vma() (Nico Pache) [2001854]
- kernel/events/uprobes: use vma_lookup() in find_active_uprobe() (Nico Pache) [2001854]
- misc/sgi-gru/grufault: use vma_lookup() in gru_find_vma() (Nico Pache) [2001854]
- media: videobuf2: use vma_lookup() in get_vaddr_frames() (Nico Pache) [2001854]
- drm/amdgpu: use vma_lookup() in amdgpu_ttm_tt_get_user_pages() (Nico Pache) [2001854]
- net/ipv5/tcp: use vma_lookup() in tcp_zerocopy_receive() (Nico Pache) [2001854]
- vfio: use vma_lookup() instead of find_vma_intersection() (Nico Pache) [2001854]
- virt/kvm: use vma_lookup() instead of find_vma_intersection() (Nico Pache) [2001854]
- x86/sgx: use vma_lookup() in sgx_encl_find() (Nico Pache) [2001854]
- arch/powerpc/kvm/book3s: use vma_lookup() in kvmppc_hv_setup_htab_rma() (Nico Pache) [2001854]
- arch/powerpc/kvm/book3s_hv_uvmem: use vma_lookup() instead of find_vma_intersection() (Nico Pache) [2001854]
- arch/arm64/kvm: use vma_lookup() instead of find_vma_intersection() (Nico Pache) [2001854]
- drm/i915/selftests: use vma_lookup() in __igt_mmap() (Nico Pache) [2001854]
- mm: add vma_lookup(), update find_vma_intersection() comments (Nico Pache) [2001854]
- i915_vma: Rename vma_lookup to i915_vma_lookup (Nico Pache) [2001854]
- media: videobuf2: Move frame_vector into media subsystem (Nico Pache) [2001854]
- mm/frame-vector: Use FOLL_LONGTERM (Nico Pache) [2001854]
- vhost: convert get_user_pages() --> pin_user_pages() (Nico Pache) [2001854]
- docs: mm/gup: pin_user_pages.rst: add a "case 5" (Nico Pache) [2001854]
- mm/gup: documentation fix for pin_user_pages*() APIs (Nico Pache) [2001854]
- mm/gup: frame_vector: convert get_user_pages() --> pin_user_pages() (Nico Pache) [2001854]
- mm/gup: update pin_user_pages.rst for "case 3" (mmu notifiers) (Nico Pache) [2001854]
- mm: untag user pointers in get_vaddr_frames (Nico Pache) [2001854]
- media: videobuf2-vmalloc: get_userptr: buffers are always writable (Nico Pache) [2001854]
- net: expand textsearch ts_state to fit skb_seq_state (Nico Pache) [2001854]
- esp: avoid unneeded kmap_atomic call (Nico Pache) [2001854]
- net: compound page support in skb_seq_read (Nico Pache) [2001854]
- net: support kmap_local forced debugging in skb_frag_foreach (Nico Pache) [2001854]
- mm/highmem: fix CONFIG_DEBUG_KMAP_LOCAL_FORCE_MAP (Nico Pache) [2001854]
- x86/crashdump/32: Simplify copy_oldmem_page() (Nico Pache) [2001854]
- io-mapping: Provide iomap_local variant (Nico Pache) [2001854]
- mm/highmem: Provide kmap_local* (Nico Pache) [2001854]
- sched: highmem: Store local kmaps in task struct (Nico Pache) [2001854]
- x86: Support kmap_local() forced debugging (Nico Pache) [2001854]
- mm/highmem: Provide CONFIG_DEBUG_KMAP_LOCAL_FORCE_MAP (Nico Pache) [2001854]
- mm/highmem: Provide and use CONFIG_DEBUG_KMAP_LOCAL (Nico Pache) [2001854]
- mm/highmem: Take kmap_high_get() properly into account (Nico Pache) [2001854]
- highmem: High implementation details and document API (Nico Pache) [2001854]
- Documentation/io-mapping: Remove outdated blurb (Nico Pache) [2001854]
- io-mapping: Cleanup atomic iomap (Nico Pache) [2001854]
- mm/highmem: Remove the old kmap_atomic cruft (Nico Pache) [2001854]
- highmem: Get rid of kmap_types.h (Nico Pache) [2001854]
- powerpc/mm/highmem: Switch to generic kmap atomic (Nico Pache) [2001854]
- x86/mm/highmem: Use generic kmap atomic implementation (Nico Pache) [2001854]
- highmem: Make DEBUG_HIGHMEM functional (Nico Pache) [2001854]
- highmem: Provide generic variant of kmap_atomic* (Nico Pache) [2001854]
- asm-generic: Provide kmap_size.h (Nico Pache) [2001854]
- fs: Remove asm/kmap_types.h includes (Nico Pache) [2001854]
- highmem: Remove unused functions (Nico Pache) [2001854]
- mm/highmem: Un-EXPORT __kmap_atomic_idx() (Nico Pache) [2001854]
- kmap: consolidate kmap_prot definitions (Nico Pache) [2001854]
- parisc/kmap: remove duplicate kmap code (Nico Pache) [2001854]
- arch/kmap: define kmap_atomic_prot() for all arch's (Nico Pache) [2001854]
- arch/kmap: ensure kmap_prot visibility (Nico Pache) [2001854]
- arch/kunmap_atomic: consolidate duplicate code (Nico Pache) [2001854]
- arch/kmap_atomic: consolidate duplicate code (Nico Pache) [2001854]
- {x86,powerpc,microblaze}/kmap: move preempt disable (Nico Pache) [2001854]
- arch/kunmap: remove duplicate kunmap implementations (Nico Pache) [2001854]
- arch/kmap: remove redundant arch specific kmaps (Nico Pache) [2001854]
- arch/kmap: remove BUG_ON() (Nico Pache) [2001854]
- ipc: remove memcg accounting for sops objects in do_semtimedop() (Rafael Aquini) [1999705] {CVE-2021-3759}
- memcg: enable accounting of ipc resources (Rafael Aquini) [1999705] {CVE-2021-3759}
- ipc: use kmalloc for msg_queue and shmid_kernel (Rafael Aquini) [1999705] {CVE-2021-3759}
- ipc sem: use kvmalloc for sem_undo allocation (Rafael Aquini) [1999705] {CVE-2021-3759}
- ipc/sem.c: replace kvmalloc/memset with kvzalloc and use struct_size (Rafael Aquini) [1999705] {CVE-2021-3759}
- x86: sev-es: Restore SEV-ES-specific version of copy_from_kernel_nofault() (Vitaly Kuznetsov) [2010082]
- perf machine: Initialize srcline string member in add_location struct (Michael Petlan) [1981880]
- ipmi: kcs_bmc_aspeed: Fix less than zero comparison of a unsigned int (Tony Camuso) [2003186]
- ipmi: kcs_bmc_aspeed: Optionally apply status address (Tony Camuso) [2003186]
- ipmi: kcs_bmc_aspeed: Fix IBFIE typo from datasheet (Tony Camuso) [2003186]
- ipmi: kcs_bmc_aspeed: Implement KCS SerIRQ configuration (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Add serio adaptor (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Enable IBF on open (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Allow clients to control KCS IRQ state (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Decouple the IPMI chardev from the core (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Strip private client data from struct kcs_bmc (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Split headers into device and client (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Turn the driver data-structures inside-out (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Split out kcs_bmc_cdev_ipmi (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Rename {read,write}_{status,data}() functions (Tony Camuso) [2003186]
- ipmi: kcs_bmc: Make status update atomic (Tony Camuso) [2003186]
- ipmi: kcs_bmc_aspeed: Use of match data to extract KCS properties (Tony Camuso) [2003186]
- ipmi/watchdog: Stop watchdog timer when the current action is 'none' (Tony Camuso) [2003186]
- ipmi: kcs: aspeed: Adapt to new LPC DTS layout (Tony Camuso) [2003186]
- ipmi_si: Join string literals back (Tony Camuso) [2003186]
- ipmi_si: Drop redundant check before calling put_device() (Tony Camuso) [2003186]
- ipmi_si: Use strstrip() to remove surrounding spaces (Tony Camuso) [2003186]
- ipmi_si: Get rid of ->addr_source_cleanup() (Tony Camuso) [2003186]
- ipmi_si: Reuse si_to_str[] array in ipmi_hardcode_init_one() (Tony Camuso) [2003186]
- ipmi_si: Introduce ipmi_panic_event_str[] array (Tony Camuso) [2003186]
- ipmi_si: Use proper ACPI macros to check error code for failures (Tony Camuso) [2003186]
- ipmi_si: Utilize temporary variable to hold device pointer (Tony Camuso) [2003186]
- ipmi_si: Remove bogus err_free label (Tony Camuso) [2003186]
- ipmi: Handle device properties with software node API (Tony Camuso) [2003186]
- ipmi:ssif: make ssif_i2c_send() void (Tony Camuso) [2003186]
- ipmi: Refine retry conditions for getting device id (Tony Camuso) [2003186]
- redhat/configs: enable CONFIG_IMA_WRITE_POLICY (Bruno Meneguele) [2010530]
- Disable CONFIG_CRYPTO_SM4 on aarch64 (Vladis Dronov) [2008943]
- powerpc/iommu: Report the correct most efficient DMA mask for PCI devices (Steve Best) [2007425]
- powerpc/dma: Fix dma_map_ops::get_required_mask (Steve Best) [2007425]
- ibmvnic: Reuse tx pools when possible (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Reuse rx pools when possible (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Reuse LTB when possible (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Use bitmap for LTB map_ids (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: init_tx_pools move loop-invariant code (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Use/rename local vars in init_tx_pools (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Use/rename local vars in init_rx_pools (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Fix up some comments and messages (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Consolidate code in replenish_rx_pool() (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: check failover_pending in login response (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: retry reset if there are no other resets (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: parenthesize a check (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: free tx_pool if tso_pool alloc fails (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: set ltb->buff to NULL after freeing (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: account for bufs already saved in indir_buf (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: clean pending indirect buffs during reset (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Use strscpy() instead of strncpy() (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: fix send_request_map incompatible argument (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: fix kernel build warnings in build_hdr_descs_arr (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: fix kernel build warning (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: fix kernel build warning in strncpy (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Allow device probe if the device is not ready at boot (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: Use list_for_each_entry() to simplify code in ibmvnic.c (Desnes A. Nunes do Rosario) [1998677]
- ibmvnic: remove default label from to_string switch (Desnes A. Nunes do Rosario) [1998677]
- intel_th: pci: Add Alder Lake-M support (Jiri Olsa) [1929502]
- i2c: designware: Fix indentation in the header (David Arcari) [2004468]
- i2c: designware: Use DIV_ROUND_CLOSEST() macro (David Arcari) [2004468]
- math64: New DIV_S64_ROUND_CLOSEST helper (David Arcari) [2004468]
- units: Add SI metric prefix definitions (David Arcari) [2004468]
- i2c: busses: i2c-designware-master: Fix misnaming of 'i2c_dw_init_master()' (David Arcari) [2004468]
- MAINTAINERS: adjust to removing i2c designware platform data (David Arcari) [2004468]
- i2c: designware: Get rid of legacy platform data (David Arcari) [2004468]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (David Arcari) [2004468]
- i2c: designware: Switch over to i2c_freq_mode_string() (David Arcari) [2004468]
- i2c: core: add api to provide frequency mode strings (David Arcari) [2004468]
- i2c: designware: Fix return value check in navi_amd_register_client() (David Arcari) [2004468]
- i2c: drivers: Use generic definitions for bus frequencies (part 2) (David Arcari) [2004468]
- i2c: designware: Add driver support for AMD NAVI GPU (David Arcari) [2004468]
- i2c: designware: Adjust bus_freq_hz when refuse high speed mode set (David Arcari) [2004468]
- i2c: designware: Get right data length (David Arcari) [2004468]
- i2c: designware: Make register offsets all of the same width (David Arcari) [2004468]
- i2c: designware: Switch header to use BIT() and GENMASK() (David Arcari) [2004468]
- i2c: designware: slave should do WRITE_REQUESTED before WRITE_RECEIVED (David Arcari) [2004468]
- i2c: designware: call i2c_dw_read_clear_intrbits_slave() once (David Arcari) [2004468]
- i2c: busses: Use fallthrough pseudo-keyword (David Arcari) [2004468]
- i2c: designware: platdrv: Set class based on DMI (David Arcari) [2004468]
- i2c: designware: Adjust bus speed independently of ACPI (David Arcari) [2004468]
- i2c: designware: Add Baikal-T1 System I2C support (David Arcari) [2004468]
- i2c: designware: Move reg-space remapping into a dedicated function (David Arcari) [2004468]
- i2c: designware: Retrieve quirk flags as early as possible (David Arcari) [2004468]
- i2c: designware: Convert driver to using regmap API (David Arcari) [2004468]
- i2c: designware: Discard Cherry Trail model flag (David Arcari) [2004468]
- i2c: designware: Drop hard coded FIFO depth assignment (David Arcari) [2004468]
- i2c: designware: Read counters from ACPI for PCI driver (David Arcari) [2004468]
- i2c: designware: Move ACPI parts into common module (David Arcari) [2004468]
- i2c: designware: Drop unneeded condition in i2c_dw_validate_speed() (David Arcari) [2004468]
- i2c: designware: Move i2c_dw_validate_speed() helper to a common code (David Arcari) [2004468]
- i2c: designware: Include proper headers in i2c-desingware-core.h (David Arcari) [2004468]
- i2c: designware: Get rid of PCI driver specifics in common code (David Arcari) [2004468]
- i2c: designware: Allow slave mode for PCI enumerated devices (David Arcari) [2004468]
- i2c: designware: Rename i2c_dw_probe() to i2c_dw_probe_master() (David Arcari) [2004468]
- i2c: designware: Switch PCI driver to use i2c_dw_configure_master() (David Arcari) [2004468]
- i2c: designware: Move configuration routines to respective modules (David Arcari) [2004468]
- i2c: designware: Use devm_platform_ioremap_resource() to simplify code (David Arcari) [2004468]
- i2c: designware: Calculate SCL timing parameter for High Speed Mode (David Arcari) [2004468]
- i2c: designware: Calculate SCL timing parameter for Fast Mode Plus (David Arcari) [2004468]
- i2c: designware: platdrv: Remove DPM_FLAG_SMART_SUSPEND flag on BYT and CHT (David Arcari) [2004468]
- i2c: drivers: Use generic definitions for bus frequencies (David Arcari) [2004468]
- i2c: core: Provide generic definitions for bus frequencies (David Arcari) [2004468]
- i2c: designware: Fix spelling typos in the comments (David Arcari) [2004468]
- i2c: designware: Discard i2c_dw_read_comp_param() function (David Arcari) [2004468]
- i2c: designware: Detect the FIFO size in the common code (David Arcari) [2004468]
- i2c: designware: Add ACPI HID for Hisilicon Hip08-Lite I2C controller (David Arcari) [2004468]
- i2c: designware: Fix optional reset error handling (David Arcari) [2004468]
- i2c: designware: assert reset when error happen at ->probe() (David Arcari) [2004468]
- i2c: designware: Synchronize IRQs when unregistering slave client (David Arcari) [2004468]
- i2c: designware: Fix unused variable warning (David Arcari) [2004468]
- i2c: designware: make use of devm_gpiod_get_optional (David Arcari) [2004468]
- i2c: busses: Use dev_get_drvdata where possible (David Arcari) [2004468]
- i2c: designware: ratelimit 'transfer when suspended' errors (David Arcari) [2004468]
- i2c: designware: Add support for an interface clock (David Arcari) [2004468]
- i2c: i2c-designware-platdrv: Always use a dynamic adapter number (David Arcari) [2004468]
- i2c: i2c-designware-platdrv: Cleanup setting of the adapter number (David Arcari) [2004468]
- i2c: designware: Do not allow i2c_dw_xfer() calls while suspended (David Arcari) [2004468]
- i2c: designware: Cleanup bus lock handling (David Arcari) [2004468]
- i2c: designware: Set IRQF_NO_SUSPEND flag for all BYT and CHT controllers (David Arcari) [2004468]
- i2c: designware: Call i2c_dw_clk_rate() only when calculating timings (David Arcari) [2004468]
- i2c: designware: Remove Cherry Trail PMIC I2C bus pm_disabled workaround (David Arcari) [2004468]
- i2c: designware: add MSCC Ocelot support (David Arcari) [2004468]
- i2c: designware: allow IP specific sda_hold_time (David Arcari) [2004468]
- i2c: designware: move #ifdef CONFIG_OF to the top (David Arcari) [2004468]
- i2c: designware: use generic table matching (David Arcari) [2004468]
- i2c: designware: Add SPDX license tag (David Arcari) [2004468]
- i2c: designware: Convert to use struct i2c_timings (David Arcari) [2004468]
- i2c: designware-pcidrv: Mark expected switch fall-through (David Arcari) [2004468]
- i2c: designware-master: use core to detect 'no zero length' quirk (David Arcari) [2004468]
- i2c: designware: Add debug print for bus speed (David Arcari) [2004468]
- i2c: designware: Add debug print for SDA hold time value (David Arcari) [2004468]
- i2c: designware: Separate timing parameter setting from HW initalization (David Arcari) [2004468]
- i2c: designware: Move SDA hold time configuration to common code (David Arcari) [2004468]
- i2c: designware: Call i2c_dw_clk_rate() only once in i2c_dw_init_master() (David Arcari) [2004468]
- i2c: designware: Don't use internal ___constant_swab32 (David Arcari) [2004468]
- i2c: designware: Move register access detection to common code (David Arcari) [2004468]
- i2c: designware: Remove needless variable from i2c_dw_init_slave() (David Arcari) [2004468]

* Wed Oct 13 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-348.2.el8]
- x86/amd_nb: Add AMD family 17h model 60h PCI IDs (David Arcari) [1987067]
- x86/amd_nb: Check vendor in AMD-only functions (David Arcari) [1987067]
- hwmon: (k10temp) Add support for yellow carp (David Arcari) [1987067]
- x86/amd_nb: Add AMD family 19h model 50h PCI ids (David Arcari) [1987067]
- x86: Fix various typos in comments, take #2 (David Arcari) [1987067]
- x86/amd_nb, char/amd64-agp: Use amd_nb_num() accessor (David Arcari) [1987067]
- x86/amd_nb: Add PCI device IDs for family 17h, model 70h (David Arcari) [1987067]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 477 (David Arcari) [1987067]
- x86/amd_nb: Make hygon_nb_misc_ids static (David Arcari) [1987067]
- x86/pci, x86/amd_nb: Add Hygon Dhyana support to PCI and northbridge (David Arcari) [1987067]
- x86/cpu: Create Hygon Dhyana architecture support file (David Arcari) [1987067]
- hwmon: (k10temp) Rework the temperature offset calculation (David Arcari) [1987067]
- hwmon: (k10temp) Don't show Tdie for all Zen/Zen2/Zen3 CPU/APU (David Arcari) [1987067]
- hwmon: (k10temp) Add additional missing Zen2 and Zen3 APUs (David Arcari) [1987067]
- hwmon: (k10temp) support Zen3 APUs (David Arcari) [1987067]
- CI: Fix RT branch name (Veronika Kabatova)
- platform/x86/intel: pmc/core: Add GBE Package C10 fix for Alder Lake PCH (David Arcari) [1962965]
- platform/x86/intel: pmc/core: Add Alder Lake low power mode support for pmc core (David Arcari) [1962965]
- platform/x86/intel: pmc/core: Add Latency Tolerance Reporting (LTR) support to Alder Lake (David Arcari) [1962965]
- platform/x86/intel: pmc/core: Add Alderlake support to pmc core driver (David Arcari) [1962965]
- redhat/configs: Add CONFIG_X86_PLATFORM_DRIVERS_INTEL (David Arcari) [1962965]
- platform/x86: intel_pmc_core: Move to intel sub-directory (David Arcari) [1962965]
- platform/x86: intel_skl_int3472: Move to intel/ subfolder (David Arcari) [1962965]
- platform/x86: intel_pmc_core: Prevent possibile overflow (David Arcari) [1962965]
- ipvs: check that ip_vs_conn_tab_bits is between 8 and 20 (Andrea Claudi) [1816769]
- KVM: nVMX: Filter out all unsupported controls when eVMCS was activated (Vitaly Kuznetsov) [2001915]
- pinctrl: amd: Handle wake-up interrupt (David Arcari) [2000228]
- pinctrl: amd: Add irq field data (David Arcari) [2000228]
- pinctrl: amd: Fix an issue with shutdown when system set to s0ix (David Arcari) [2000228]
- pinctrl/amd: Add device HID for new AMD GPIO controller (David Arcari) [2000228]
- pinctrl: amd: Implement irq_set_wake (David Arcari) [2000228]
- genirq/PM: Introduce IRQCHIP_ENABLE_WAKEUP_ON_SUSPEND flag (David Arcari) [2000228]
- pinctrl: amd: remove debounce filter setting in IRQ type setting (David Arcari) [2000228]
- pinctrl: amd: print debounce filter info in debugfs (David Arcari) [2000228]
- pinctrl: amd: use higher precision for 512 RtcClk (David Arcari) [2000228]
- pinctrl: amd: fix incorrect way to disable debounce filter (David Arcari) [2000228]
- pinctrl: amd: Use irqchip template (David Arcari) [2000228]
- pinctrl: pinctrl-amd: Do not define 'struct acpi_device_id' when !CONFIG_ACPI (David Arcari) [2000228]
- pinctrl: amd: Honor IRQ trigger type requested by the caller (David Arcari) [2000228]
- pinctrl: Use new GPIO_LINE_DIRECTION (David Arcari) [2000228]
- remove ioremap_nocache and devm_ioremap_nocache (David Arcari) [2000228]
- pinctrl: amd: fix __iomem annotation in amd_gpio_irq_handler() (David Arcari) [2000228]
- pinctrl: amd: disable spurious-firing GPIO IRQs (David Arcari) [2000228]
- pinctrl: Remove dev_err() usage after platform_get_irq() (David Arcari) [2000228]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 422 (David Arcari) [2000228]
- pinctrl/amd: fix typo (David Arcari) [2000228]
- pinctrl: pinctrl-amd: simplify getting .driver_data (David Arcari) [2000228]
- pinctrl/amd: poll InterruptEnable bits in amd_gpio_irq_set_type (David Arcari) [2000228]
- pinctrl: Include <linux/gpio/driver.h> nothing else (David Arcari) [2000228]
- pinctrl/amd: only handle irq if it is pending and unmasked (David Arcari) [2000228]
- pinctrl/amd: fix gpio irq level in debugfs (David Arcari) [2000228]
- smartpqi: Update version to 2.1.10-025 (Don Brace) [1980106]
- scsi: smartpqi: Replace one-element array with flexible-array member (Don Brace) [1980106]
- scsi: smartpqi: Fix an error code in pqi_get_raid_map() (Don Brace) [1980106]
- scsi: smartpqi: Update version to 2.1.10-020 (Don Brace) [1980106]
- scsi: smartpqi: Fix ISR accessing uninitialized data (Don Brace) [1980106]
- scsi: smartpqi: Add PCI IDs for new ZTE controllers (Don Brace) [1980106]
- scsi: smartpqi: Add PCI ID for new ntcom controller (Don Brace) [1980106]
- scsi: smartpqi: Add SCSI cmd info for resets (Don Brace) [1980106]
- scsi: smartpqi: Change Kconfig menu entry to Microchip (Don Brace) [1980106]
- scsi: smartpqi: Change driver module macros to Microchip (Don Brace) [1980106]
- scsi: smartpqi: Update copyright notices (Don Brace) [1980106]
- scsi: smartpqi: Add PCI IDs for H3C P4408 controllers (Don Brace) [1980106]

* Wed Oct 06 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-348.1.el8]
- lib/linear_ranges: fix repeated words & one typo (Nico Pache) [2006475]
- lib: linear_ranges: Add missing MODULE_LICENSE() (Nico Pache) [2006475]
- bpf: Fix regression on BPF_OBJ_GET with non-O_RDWR flags (Jiri Olsa) [1944798]
- bpf, x86: Fix extable offset calculation (Jiri Olsa) [1944798]
- bpftool: Add Makefile target bootstrap (Jiri Olsa) [1944798]
- bpf: Avoid warning when re-casting __bpf_call_base into __bpf_call_base_args (Jiri Olsa) [1944798]
- docs, bpf: Add minimal markup to address doc warning (Jiri Olsa) [1944798]
- test_bpf: Remove EXPECTED_FAIL flag from bpf_fill_maxinsns11 (Jiri Olsa) [1944798]
- trace: bpf: Allow bpf to attach to bare tracepoints (Jiri Olsa) [1944798]
- docs: bpf: Clarify -mcpu=v3 requirement for atomic ops (Jiri Olsa) [1944798]
- tools, headers: Sync struct bpf_perf_event_data (Jiri Olsa) [1944798]
- selftests/bpf: Add missing cleanup in atomic_bounds test (Jiri Olsa) [1944798]
- docs: bpf: Clarify BPF_CMPXCHG wording (Jiri Olsa) [1944798]
- docs: bpf: Fixup atomics markup (Jiri Olsa) [1944798]
- bpf: Document new atomic instructions (Jiri Olsa) [1944798]
- kbuild: Do not clean resolve_btfids if the output does not exist (Jiri Olsa) [1944798]
- kbuild: Add resolve_btfids clean to root clean target (Jiri Olsa) [1944798]
- bpf: Introduce task_vma bpf_iter (Jiri Olsa) [1944798]
- bpf: Allow bpf_d_path in bpf_iter program (Jiri Olsa) [1944798]
- selftests/bpf: Add test for bpf_iter_task_vma (Jiri Olsa) [1944798]
- bpf: Don't do bpf_cgroup_storage_set() for kuprobe/tp programs (Jiri Olsa) [1944798]
- libbpf: Use SOCK_CLOEXEC when opening the netlink socket (Jiri Olsa) [1944798]
- bpf: Update selftests to reflect new error states (Jiri Olsa) [1944798]
- bpf, x86: Validate computation of branch displacements for x86-32 (Jiri Olsa) [1944798]
- bpf, x86: Validate computation of branch displacements for x86-64 (Jiri Olsa) [1944798]
- bpf: program: Refuse non-O_RDWR flags in BPF_OBJ_GET (Jiri Olsa) [1944798]
- bpf: Take module reference for trampoline in module (Jiri Olsa) [1944798]
- bpf/selftests: Test that kernel rejects a TCP CC with an invalid license (Jiri Olsa) [1944798]
- bpf: Enforce that struct_ops programs be GPL-only (Jiri Olsa) [1944798]
- libbpf: Fix bail out from 'ringbuf_process_ring()' on error (Jiri Olsa) [1944798]
- selftests/bpf: Add selftest for pointer-to-array-of-struct BTF dump (Jiri Olsa) [1944798]
- libbpf: Fix BTF dump of pointer-to-array-of-struct (Jiri Olsa) [1944798]
- bpf, selftests: Fix up some test_verifier cases for unprivileged (Jiri Olsa) [1944798]
- bpf, x86: Use kvmalloc_array instead kmalloc_array in bpf_jit_comp (Jiri Olsa) [1944798]
- libbpf: Fix INSTALL flag order (Jiri Olsa) [1944798]
- libbpf: Clear map_info before each bpf_obj_get_info_by_fd (Jiri Olsa) [1944798]
- samples, bpf: Add missing munmap in xdpsock (Jiri Olsa) [1944798]
- tools/resolve_btfids: Fix build error with older host toolchains (Jiri Olsa) [1944798]
- selftests/bpf: Fix a compiler warning in global func test (Jiri Olsa) [1944798]
- bpf: Drop imprecise log message (Jiri Olsa) [1944798]
- bpf: Clear percpu pointers in bpf_prog_clone_free() (Jiri Olsa) [1944798]
- bpf: Fix a warning message in mark_ptr_not_null_reg() (Jiri Olsa) [1944798]
- selftests/bpf: Add unit tests for pointers in global functions (Jiri Olsa) [1944798]
- bpf: Support pointers in global func args (Jiri Olsa) [1944798]
- bpf: Extract nullable reg type conversion into a helper function (Jiri Olsa) [1944798]
- bpf: Rename bpf_reg_state variables (Jiri Olsa) [1944798]
- tools/resolve_btfids: Add /libbpf to .gitignore (Jiri Olsa) [1944798]
- bpf: selftests: Add non function pointer test to struct_ops (Jiri Olsa) [1944798]
- libbpf: Ignore non function pointer member in struct_ops (Jiri Olsa) [1944798]
- bpf: Clear per_cpu pointers during bpf_prog_realloc (Jiri Olsa) [1944798]
- selftests/bpf: Add a selftest for the tracing bpf_get_socket_cookie (Jiri Olsa) [1944798]
- selftests/bpf: Use vmlinux.h in socket_cookie_prog.c (Jiri Olsa) [1944798]
- selftests/bpf: Integrate the socket_cookie test to test_progs (Jiri Olsa) [1944798]
- bpf: Expose bpf_get_socket_cookie to tracing programs (Jiri Olsa) [1944798]
- selftests/bpf: Convert test_xdp_redirect.sh to bash (Jiri Olsa) [1944798]
- selftests/bpf: Add a test for map-in-map and per-cpu maps in sleepable progs (Jiri Olsa) [1944798]
- bpf: Allows per-cpu maps and map-in-map in sleepable programs (Jiri Olsa) [1944798]
- selftests/bpf: Improve recursion selftest (Jiri Olsa) [1944798]
- selftest/bpf: Add a recursion test (Jiri Olsa) [1944798]
- bpf: Count the number of times recursion was prevented (Jiri Olsa) [1944798]
- bpf: Add per-program recursion prevention mechanism (Jiri Olsa) [1944798]
- bpf: Compute program stats for sleepable programs (Jiri Olsa) [1944798]
- bpf: Run sleepable programs with migration disabled (Jiri Olsa) [1944798]
- bpf: Optimize program stats (Jiri Olsa) [1944798]
- selftests/bpf: Simplify the calculation of variables (Jiri Olsa) [1944798]
- selftest/bpf: Add test for var-offset stack access (Jiri Olsa) [1944798]
- tools/resolve_btfids: Set srctree variable unconditionally (Jiri Olsa) [1944798]
- tools/resolve_btfids: Check objects before removing (Jiri Olsa) [1944798]
- tools/resolve_btfids: Build libbpf and libsubcmd in separate directories (Jiri Olsa) [1944798]
- bpf: Simplify bool comparison (Jiri Olsa) [1944798]
- selftests/bpf: Remove unneeded semicolon (Jiri Olsa) [1944798]
- bpf/benchs/bench_ringbufs: Remove unneeded semicolon (Jiri Olsa) [1944798]
- bpf: Refactor BPF_PSEUDO_CALL checking as a helper function (Jiri Olsa) [1944798]
- bpf/selftests: Update the IMA test to use BPF ring buffer (Jiri Olsa) [1944798]
- bpf: Allow usage of BPF ringbuffer in sleepable programs (Jiri Olsa) [1944798]
- bpf/selftests: Add a short note about vmtest.sh in README.rst (Jiri Olsa) [1944798]
- bpf: Helper script for running BPF presubmit tests (Jiri Olsa) [1944798]
- bpf: Emit explicit NULL pointer checks for PROBE_LDX instructions. (Jiri Olsa) [1944798]
- libbpf: Stop using feature-detection Makefiles (Jiri Olsa) [1944798]
- selftest/bpf: Testing for multiple logs on REJECT (Jiri Olsa) [1944798]
- samples: bpf: Remove unneeded semicolon (Jiri Olsa) [1944798]
- bpf: Propagate stack bounds to registers in atomics w/ BPF_FETCH (Jiri Olsa) [1944798]
- samples/bpf: Add include dir for MIPS Loongson64 to fix build errors (Jiri Olsa) [1944798]
- bpf: Simplify cases in bpf_base_func_proto (Jiri Olsa) [1944798]
- samples/bpf: Set flag __SANE_USERSPACE_TYPES__ for MIPS to fix build warnings (Jiri Olsa) [1944798]
- selftests/bpf: Avoid useless void *-casts (Jiri Olsa) [1944798]
- selftests/bpf: Consistent malloc/calloc usage (Jiri Olsa) [1944798]
- selftests/bpf: Avoid heap allocation (Jiri Olsa) [1944798]
- selftests/bpf: Define local variables at the beginning of a block (Jiri Olsa) [1944798]
- selftests/bpf: Change type from void * to struct generic_data * (Jiri Olsa) [1944798]
- selftests/bpf: Change type from void * to struct ifaceconfigobj * (Jiri Olsa) [1944798]
- selftests/bpf: Remove casting by introduce local variable (Jiri Olsa) [1944798]
- selftests/bpf: Improve readability of xdpxceiver/worker_pkt_validate() (Jiri Olsa) [1944798]
- selftests/bpf: Remove memory leak (Jiri Olsa) [1944798]
- selftests/bpf: Fix style warnings (Jiri Olsa) [1944798]
- selftests/bpf: Remove unused enums (Jiri Olsa) [1944798]
- selftests/bpf: Remove a lot of ifobject casting (Jiri Olsa) [1944798]
- samples/bpf: Add xdp program on egress for xdp_redirect_map (Jiri Olsa) [1944798]
- bpf: Fix typo in scalar{,32}_min_max_rsh comments (Jiri Olsa) [1944798]
- bpf, docs: Update build procedure for manually compiling LLVM and Clang (Jiri Olsa) [1944798]
- selftest/bpf: Fix typo (Jiri Olsa) [1944798]
- libbpf: Use string table index from index table if needed (Jiri Olsa) [1944798]
- bpf: Try to avoid kzalloc in cgroup/{s,g}etsockopt (Jiri Olsa) [1944798]
- bpf: Permit size-0 datasec (Jiri Olsa) [1944798]
- selftests: bpf: Add a new test for bare tracepoints (Jiri Olsa) [1944798]
- selftests/bpf: Add verifier tests for x64 jit jump padding (Jiri Olsa) [1944798]
- bpf,x64: Pad NOPs to make images converge more easily (Jiri Olsa) [1944798]
- tools/bpftool: Add -Wall when building BPF programs (Jiri Olsa) [1944798]
- bpf: Declare __bpf_free_used_maps() unconditionally (Jiri Olsa) [1944798]
- bpf: Add bpf_patch_call_args prototype to include/linux/bpf.h (Jiri Olsa) [1944798]
- kernel.spec: Add support to use vmlinux.h (Jiri Olsa) [1989087]
- spec: Add vmlinux.h to kernel-devel package (Jiri Olsa) [1989087]
- lib/test_scanf: Handle n_bits == 0 in random tests (Chris von Recklinghausen) [1985062]
- printk/console: Check consistent sequence number when handling race in console_unlock() (Chris von Recklinghausen) [1985062]
- printk: fix cpu lock ordering (Chris von Recklinghausen) [1985062]
- lib/dump_stack: move cpu lock to printk.c (Chris von Recklinghausen) [1985062]
- random32: Fix implicit truncation warning in prandom_seed_state() (Chris von Recklinghausen) [1985062]
- lib: test_scanf: Remove pointless use of type_min() with unsigned types (Chris von Recklinghausen) [1985062]
- selftests: lib: Add wrapper script for test_scanf (Chris von Recklinghausen) [1985062]
- lib: test_scanf: Add tests for sscanf number conversion (Chris von Recklinghausen) [1985062]
- lib: vsprintf: Fix handling of number field widths in vsscanf (Chris von Recklinghausen) [1985062]
- lib: vsprintf: scanf: Negative number must have field width > 1 (Chris von Recklinghausen) [1985062]
- usb: host: xhci-tegra: Switch to use ptTs (Chris von Recklinghausen) [1985062]
- nilfs2: Switch to use ptTs (Chris von Recklinghausen) [1985062]
- kdb: Switch to use ptTs (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Allow to override ISO 8601 date and time separator (Chris von Recklinghausen) [1985062]
- printk: Remove trailing semicolon in macros (Chris von Recklinghausen) [1985062]
- printk: Move EXPORT_SYMBOL() closer to vprintk definition (Chris von Recklinghausen) [1985062]
- kernel/printk.c: Fixed mundane typos (Chris von Recklinghausen) [1985062]
- printk: rename vprintk_func to vprintk (Chris von Recklinghausen) [1985062]
- printk: console: remove unnecessary safe buffer usage (Chris von Recklinghausen) [1985062]
- printk: kmsg_dump: remove _nolock() variants (Chris von Recklinghausen) [1985062]
- printk: remove logbuf_lock (Chris von Recklinghausen) [1985062]
- printk: introduce a kmsg_dump iterator (Chris von Recklinghausen) [1985062]
- printk: kmsg_dumper: remove @active field (Chris von Recklinghausen) [1985062]
- printk: add syslog_lock (Chris von Recklinghausen) [1985062]
- printk: use atomic64_t for devkmsg_user.seq (Chris von Recklinghausen) [1985062]
- printk: use seqcount_latch for clear_seq (Chris von Recklinghausen) [1985062]
- printk: introduce CONSOLE_LOG_MAX (Chris von Recklinghausen) [1985062]
- printk: consolidate kmsg_dump_get_buffer/syslog_print_all code (Chris von Recklinghausen) [1985062]
- printk: refactor kmsg_dump_get_buffer() (Chris von Recklinghausen) [1985062]
- printk: kmsg_dump: remove unused fields (Chris von Recklinghausen) [1985062]
- printk: limit second loop of syslog_print_all (Chris von Recklinghausen) [1985062]
- mtd: mtdoops: synchronize kmsg_dumper (Chris von Recklinghausen) [1985062]
- vsprintf: dump full information of page flags in pGp (Chris von Recklinghausen) [1985062]
- mm, slub: don't combine pr_err with INFO (Chris von Recklinghausen) [1985062]
- mm, slub: use pGp to print page flags (Chris von Recklinghausen) [1985062]
- lib/vsprintf.c: remove leftover 'f' and 'F' cases from bstr_printf() (Chris von Recklinghausen) [1985062]
- printk: clarify the documentation for plain pointer printing (Chris von Recklinghausen) [1985062]
- lib/vsprintf: do not show no_hash_pointers message multiple times (Chris von Recklinghausen) [1985062]
- kdb: Refactor env variables get/set code (Chris von Recklinghausen) [1985062]
- kernel: debug: Ordinary typo fixes in the file gdbstub.c (Chris von Recklinghausen) [1985062]
- kdb: Simplify kdb commands registration (Chris von Recklinghausen) [1985062]
- seqlock,lockdep: Fix seqcount_latch_init() (Chris von Recklinghausen) [1985062]
- printk: avoid prb_first_valid_seq() where possible (Chris von Recklinghausen) [1985062]
- printk: rectify kernel-doc for prb_rec_init_wr() (Chris von Recklinghausen) [1985062]
- lib/vsprintf: no_hash_pointers prints all addresses as unhashed (Chris von Recklinghausen) [1985062]
- kselftest: add support for skipped tests (Chris von Recklinghausen) [1985062]
- lib: use KSTM_MODULE_GLOBALS macro in kselftest drivers (Chris von Recklinghausen) [1985062]
- printk: fix deadlock when kernel panic (Chris von Recklinghausen) [1985062]
- torture: Remove "Failed to add ttynull console" false positive (Chris von Recklinghausen) [1985062]
- printk: fix string termination for record_print_text() (Chris von Recklinghausen) [1985062]
- printk: fix buffer overflow potential for print_text() (Chris von Recklinghausen) [1985062]
- printk: fix kmsg_dump_get_buffer length calulations (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: fix line counting (Chris von Recklinghausen) [1985062]
- Revert "init/console: Use ttynull as a fallback when there is no console" (Chris von Recklinghausen) [1985062]
- printk: remove obsolete dead assignment (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: Reference text_data_ring directly in callees. (Chris von Recklinghausen) [1985062]
- printk/console: Allow to disable console output by using console="" or console=null (Chris von Recklinghausen) [1985062]
- init/console: Use ttynull as a fallback when there is no console (Chris von Recklinghausen) [1985062]
- printk: remove logbuf_lock writer-protection of ringbuffer (Chris von Recklinghausen) [1985062]
- printk: inline log_output(),log_store() in vprintk_store() (Chris von Recklinghausen) [1985062]
- printk: remove unneeded dead-store assignment (Chris von Recklinghausen) [1985062]
- printk: finalize records with trailing newlines (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: Wrong data pointer when appending small string (Chris von Recklinghausen) [1985062]
- printk: reduce setup_text_buf size to LOG_LINE_MAX (Chris von Recklinghausen) [1985062]
- printk: avoid and/or handle record truncation (Chris von Recklinghausen) [1985062]
- printk: remove dict ring (Chris von Recklinghausen) [1985062]
- printk: move dictionary keys to dev_printk_info (Chris von Recklinghausen) [1985062]
- printk: move printk_info into separate array (Chris von Recklinghausen) [1985062]
- printk: reimplement log_cont using record extension (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: add finalization/extension support (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: change representation of states (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: clear initial reserved fields (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: add BLK_DATALESS() macro (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: relocate get_data() (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: avoid memcpy() on state_var (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: fix setting state in desc_read() (Chris von Recklinghausen) [1985062]
- seqlock: Introduce seqcount_latch_t (Chris von Recklinghausen) [1985062]
- scripts/gdb: update for lockless printk ringbuffer (Chris von Recklinghausen) [1985062]
- scripts/gdb: add utils.read_ulong() (Chris von Recklinghausen) [1985062]
- printk: reduce LOG_BUF_SHIFT range for H8300 (Chris von Recklinghausen) [1985062]
- printk: ringbuffer: support dataless records (Chris von Recklinghausen) [1985062]
- MAINTAIERS: Add John Ogness as printk reviewer (Chris von Recklinghausen) [1985062]
- printk: use the lockless ringbuffer (Chris von Recklinghausen) [1985062]
- Revert "printk: lock/unlock console only for new logbuf entries" (Chris von Recklinghausen) [1985062]
- printk: add lockless ringbuffer (Chris von Recklinghausen) [1985062]
- crash: add VMCOREINFO macro to define offset in a struct declared by typedef (Chris von Recklinghausen) [1985062]
- printk: Use fallthrough pseudo-keyword (Chris von Recklinghausen) [1985062]
- kernel.h: Move oops_in_progress to printk.h (Chris von Recklinghausen) [1985062]
- serial: 8250: change lock order in serial8250_do_startup() (Chris von Recklinghausen) [1985062]
- kernel: printk: delete repeated words in comments (Chris von Recklinghausen) [1985062]
- random32: Restore __latent_entropy attribute on net_rand_state (Chris von Recklinghausen) [1985062]
- random32: add a tracepoint for prandom_u32() (Chris von Recklinghausen) [1985062]
- init: open code setting up stdin/stdout/stderr (Chris von Recklinghausen) [1985062]
- hvc: unify console setup naming (Chris von Recklinghausen) [1985062]
- console: Fix trivia typo 'change' -> 'chance' (Chris von Recklinghausen) [1985062]
- console: Propagate error code from console ->setup() (Chris von Recklinghausen) [1985062]
- tty: hvc: Return proper error code from console ->setup() hook (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Force type of flags value for gfp_t (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Replace custom spec to print decimals with generic one (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Replace hidden BUILD_BUG_ON() with static_assert() (Chris von Recklinghausen) [1985062]
- printk: Make linux/printk.h self-contained (Chris von Recklinghausen) [1985062]
- doc:kmsg: explicitly state the return value in case of SEEK_CUR (Chris von Recklinghausen) [1985062]
- Replace HTTP links with HTTPS ones: vsprintf (Chris von Recklinghausen) [1985062]
- Revert "kernel/printk: add kmsg SEEK_CUR handling" (Chris von Recklinghausen) [1985062]
- random32: move the pseudo-random 32-bit definitions to prandom.h (Chris von Recklinghausen) [1985062]
- printk/kdb: Redirect printk messages into kdb in any context (Chris von Recklinghausen) [1985062]
- usb: pulse8-cec: Switch to use ptT (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Print time64_t in human readable format (Chris von Recklinghausen) [1985062]
- printk: Remove pr_cont_once() (Chris von Recklinghausen) [1985062]
- printk: handle blank console arguments passed in. (Chris von Recklinghausen) [1985062]
- kernel/printk: add kmsg SEEK_CUR handling (Chris von Recklinghausen) [1985062]
- printk: Fix a typo in comment "interator"->"iterator" (Chris von Recklinghausen) [1985062]
- printk: Correctly set CON_CONSDEV even when preferred console was not registered (Chris von Recklinghausen) [1985062]
- printk: Fix preferred console selection with multiple matches (Chris von Recklinghausen) [1985062]
- printk: Move console matching logic into a separate function (Chris von Recklinghausen) [1985062]
- lib/vsprintf: update comment about simple_strto<foo>() functions (Chris von Recklinghausen) [1985062]
- printk: Convert a use of sprintf to snprintf in console_unlock (Chris von Recklinghausen) [1985062]
- lib/dynamic_debug.c: use address-of operator on section symbols (Chris von Recklinghausen) [1985062]
- printk: fix exclusive_console replaying (Chris von Recklinghausen) [1985062]
- Revert "fs: remove ksys_dup()" (Chris von Recklinghausen) [1985062]
- early init: fix error handling when opening /dev/console (Chris von Recklinghausen) [1985062]
- device.h: move dev_printk()-like functions to dev_printk.h (Chris von Recklinghausen) [1985062]
- docs: printk-formats: add ptrdiff_t type to printk-formats (Chris von Recklinghausen) [1985062]
- fs: remove ksys_dup() (Chris von Recklinghausen) [1985062]
- MAINTAINERS: Add VSPRINTF (Chris von Recklinghausen) [1985062]
- tools lib api: Renaming pr_warning to pr_warn (Chris von Recklinghausen) [1985062]
- lib: cpu_rmap: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- trace: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- vgacon: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- scsi: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- platform/x86: intel_oaktrail: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- platform/x86: asus-laptop: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- platform/x86: eeepc-laptop: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- oprofile: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- of: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- macintosh: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- idsn: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- ide: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- crypto: n2: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- clocksource: samsung_pwm_timer: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- gdrom: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- drbd: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- x86: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- arm64: Use pr_warn instead of pr_warning (Chris von Recklinghausen) [1985062]
- dump_stack: avoid the livelock of the dump_lock (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Add pfw conversion specifier for printing fwnode names (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Make use of fwnode API to obtain node names and separators (Chris von Recklinghausen) [1985062]
- ABI: Update dev-kmsg documentation to match current kernel behaviour (Chris von Recklinghausen) [1985062]
- printk: Replace strncmp() with str_has_prefix() (Chris von Recklinghausen) [1985062]
- lib/test_printf: Remove obvious comments from pd and pD tests (Chris von Recklinghausen) [1985062]
- lib/test_printf: Add test of null/invalid pointer dereference for dentry (Chris von Recklinghausen) [1985062]
- vsprintf: Prevent crash when dereferencing invalid pointers for pD (Chris von Recklinghausen) [1985062]
- printk: Do not lose last line in kmsg buffer dump (Chris von Recklinghausen) [1985062]
- scripts/gdb: fix lx-dmesg when CONFIG_PRINTK_CALLER is set (Chris von Recklinghausen) [1985062]
- lib/vsprintf: Remove support for pF and pf in favour of pS and ps (Chris von Recklinghausen) [1985062]
- tracing: kdb: Allow ftdump to skip all but the last few entries (Chris von Recklinghausen) [1985062]
- tracing: kdb: The skip_lines parameter should have been skip_entries (Chris von Recklinghausen) [1985062]
- tracing: Add trace_total_entries() / trace_total_entries_cpu() (Chris von Recklinghausen) [1985062]
- tty: Add NULL TTY driver (Chris von Recklinghausen) [1985062]
- treewide: Switch printk users from pf and pF to ps and pS, respectively (Chris von Recklinghausen) [1985062]
- iio: adc: fix warning in Qualcomm PM8xxx HK/XOADC driver (Chris von Recklinghausen) [1985062]
- device.h: Add __cold to dev_<level> logging functions (Chris von Recklinghausen) [1985062]
- dynamic_debug: move pr_err from module.c to ddebug_add_module (Chris von Recklinghausen) [1985062]
- dynamic_debug: don't duplicate modname in ddebug_add_module (Chris von Recklinghausen) [1985062]
- kdb: use bool for binary state indicators (Chris von Recklinghausen) [1985062]
- panic: avoid deadlocks in re-entrant console drivers (Chris von Recklinghausen) [1985062]
- x86/apic: Trivial coding style fixes (Chris von Recklinghausen) [1985062]
- video/console/vgacon: Print big fat warning with nomodeset (Chris von Recklinghausen) [1985062]
- device: Add #define dev_fmt similar to #define pr_fmt (Chris von Recklinghausen) [1985062]
- bcache: replace 'pF' by 'pS' in seq_printf() (Chris von Recklinghausen) [1985062]
- Revert "Merge: redhat: switch secureboot kernel image signing to release keys" (Augusto Caringi)
- drm/nouveau/fifo/ga102: initialise chid on return from channel creation (Ben Skeggs) [1997878]
- drm/nouveau/ga102-: support ttm buffer moves via copy engine (Ben Skeggs) [1997878]
- drm/nouveau/kms/tu102-: delay enabling cursor until after assign_windows (Ben Skeggs) [1997878]
- drm/nouveau/kms/nv50: workaround EFI GOP window channel format differences (Ben Skeggs) [1997878]
- drm/nouveau/disp: power down unused DP links during init (Ben Skeggs) [1997878]
- drm/nouveau: recognise GA107 (Ben Skeggs) [1997878]
- PCI: Mark TI C667X to avoid bus reset (Alex Williamson) [1975768]
- redhat: switch secureboot kernel image signing to release keys (Bruno Meneguele)
- CI: handle RT branches in a single config (Veronika Kabatova)
- CI: Fix RT check branch name (Veronika Kabatova)
- CI: Drop private CI config (Veronika Kabatova)
- CI: extend template use (Veronika Kabatova)
- Revert "Merge: mt7921e: enable new Mediatek wireless hardware" (Bruno Meneguele) [2009501]
- megaraid_sas: fix concurrent access to ISR between IRQ polling and real interrupt (Tomas Henzl) [2009022]
- scsi: megaraid_sas: mq_poll support (Tomas Henzl) [2009022]
- [PATCH v2] scsi: qla2xxx: Suppress unnecessary log messages during login (Nilesh Javali) [1982186]
- scsi: qla2xxx: Fix excessive messages during device logout (Nilesh Javali) [1982186]
- PCI: pciehp: Ignore Link Down/Up caused by DPC (Myron Stowe) [1981741]
- arm64: kpti: Fix "kpti=off" when KASLR is enabled (Mark Salter) [1979731]
- arm64: Fix CONFIG_ARCH_RANDOM=n build (Mark Salter) [1979731]
- redhat/configs: aarch64: add CONFIG_ARCH_RANDOM (Mark Salter) [1979731]
- arm64: Implement archrandom.h for ARMv8.5-RNG (Mark Salter) [1979731]
- arm64: kconfig: Fix alignment of E0PD help text (Mark Salter) [1979731]
- arm64: Use register field helper in kaslr_requires_kpti() (Mark Salter) [1979731]
- arm64: Simplify early check for broken TX1 when KASLR is enabled (Mark Salter) [1979731]
- arm64: Use a variable to store non-global mappings decision (Mark Salter) [1979731]
- arm64: Don't use KPTI where we have E0PD (Mark Salter) [1979731]
- arm64: Factor out checks for KASLR in KPTI code into separate function (Mark Salter) [1979731]
- redhat/configs: Add CONFIG_ARM64_E0PD (Mark Salter) [1979731]
- arm64: Add initial support for E0PD (Mark Salter) [1979731]
- arm64: cpufeature: Export matrix and other features to userspace (Mark Salter) [1980098]
- arm64: docs: cpu-feature-registers: Document ID_AA64PFR1_EL1 (Mark Salter) [1980098]
- docs/arm64: cpu-feature-registers: Rewrite bitfields that don't follow [e, s] (Mark Salter) [1980098]
- docs/arm64: cpu-feature-registers: Documents missing visible fields (Mark Salter) [1980098]
- arm64: Introduce system_capabilities_finalized() marker (Mark Salter) [1980098]
- arm64: entry.S: Do not preempt from IRQ before all cpufeatures are enabled (Mark Salter) [1980098]
- docs/arm64: elf_hwcaps: Document HWCAP_SB (Mark Salter) [1980098]
- docs/arm64: elf_hwcaps: sort the HWCAP{, 2} documentation by ascending value (Mark Salter) [1980098]
- arm64: cpufeature: Treat ID_AA64ZFR0_EL1 as RAZ when SVE is not enabled (Mark Salter) [1980098]
- arm64: cpufeature: Effectively expose FRINT capability to userspace (Mark Salter) [1980098]
- arm64: cpufeature: Fix feature comparison for CTR_EL0.{CWG,ERG} (Mark Salter) [1980098]
- arm64: Expose FRINT capabilities to userspace (Mark Salter) [1980098]
- arm64: Expose ARMv8.5 CondM capability to userspace (Mark Salter) [1980098]
- docs: arm64: convert perf.txt to ReST format (Mark Salter) [1980098]
- docs: arm64: convert docs to ReST and rename to .rst (Mark Salter) [1980098]
- Documentation/arm64: HugeTLB page implementation (Mark Salter) [1980098]
- Documentation/arm64/sve: Couple of improvements and typos (Mark Salter) [1980098]
- arm64: cpufeature: Fix missing ZFR0 in __read_sysreg_by_encoding() (Mark Salter) [1980098]
- arm64: Expose SVE2 features for userspace (Mark Salter) [1980098]
- arm64: Advertise ARM64_HAS_DCPODP cpu feature (Mark Salter) [1980098]
- arm64: add CVADP support to the cache maintenance helper (Mark Salter) [1980098]
- arm64: Fix minor issues with the dcache_by_line_op macro (Mark Salter) [1980098]
- arm64: Expose DC CVADP to userspace (Mark Salter) [1980098]
- arm64: Handle trapped DC CVADP (Mark Salter) [1980098]
- arm64: HWCAP: encapsulate elf_hwcap (Mark Salter) [1980098]
- arm64: HWCAP: add support for AT_HWCAP2 (Mark Salter) [1980098]
- x86/MCE/AMD, EDAC/mce_amd: Add new SMCA bank types (Aristeu Rozanski) [1965331]
- x86/MCE/AMD, EDAC/mce_amd: Remove struct smca_hwid.xec_bitmap (Aristeu Rozanski) [1965331]
- EDAC, mce_amd: Print ExtErrorCode and description on a single line (Aristeu Rozanski) [1965331]

* Mon Sep 27 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-345.1.el8]
- scsi: ibmvfc: Fix command state accounting and stale response detection (Steve Best) [1988157]
- tasklist_lock, ppc64: Convert tasklist_lock to use qrwlock for ppc64 (Waiman Long) [1978377]
- tasklist_lock, ppc64: Provide infrastructure to support specific use of qrwlock (Waiman Long) [1978377]
- redhat/configs: Disable CONFIG_PPC_QUEUED_SPINLOCKS (Waiman Long) [1978377]
- qspinlock: use signed temporaries for cmpxchg (Waiman Long) [1978377]
- powerpc/qspinlock: Optimised atomic_try_cmpxchg_lock() that adds the lock hint (Waiman Long) [1978377]
- powerpc/pseries: Implement paravirt qspinlocks for SPLPAR (Waiman Long) [1978377]
- powerpc/64s: Implement queued spinlocks and rwlocks (Waiman Long) [1978377]
- powerpc: Move spinlock implementation to simple_spinlock (Waiman Long) [1978377]
- locking/spinlocks: Remove an instruction from spin and write locks (Waiman Long) [1978377]
- net: Fix skb->csum update in inet_proto_csum_replace16(). (Balazs Nemeth) [1975193]
- [s390] s390/dasd: fix use after free in dasd path handling (Claudio Imbrenda) [1996764]
- powerpc/bpf: Fix detecting BPF atomic instructions (Viktor Malik) [1931483]
- selftests/bpf: ringbuf_multi: Test bpf_map__set_inner_map_fd (Viktor Malik) [1931483]
- selftests/bpf: ringbuf_multi: Use runtime page size (Viktor Malik) [1931483]
- libbpf: Add bpf_map__inner_map API (Viktor Malik) [1931483]
- selftests/bpf: ringbuf: Use runtime page size (Viktor Malik) [1931483]
- selftests/bpf: mmap: Use runtime page size (Viktor Malik) [1931483]
- selftests/bpf: Pass page size from userspace in map_ptr (Viktor Malik) [1931483]
- selftests/bpf: Pass page size from userspace in sockopt_sk (Viktor Malik) [1931483]
- selftests/bpf: test_progs/sockopt_sk: Convert to use BPF skeleton (Viktor Malik) [1931483]
- selftests/bpf: test_progs/sockopt_sk: Remove version (Viktor Malik) [1931483]
- powerpc/64s: Fix crashes when toggling entry flush barrier (Diego Domingos) [1894804]
- powerpc/64s: flush L1D after user accesses (Diego Domingos) [1894804]
- powerpc/uaccess: Evaluate macro arguments once, before user access is allowed (Diego Domingos) [1894804]
- powerpc: Fix __clear_user() with KUAP enabled (Diego Domingos) [1894804]
- powerpc: Implement user_access_begin and friends (Diego Domingos) [1894804]
- powerpc: Add a framework for user access tracking (Diego Domingos) [1894804]
- powerpc/64s: flush L1D on kernel entry (Diego Domingos) [1894804]
- redhat: enable CONFIG_SLAB_FREELIST_HARDENED (Rafael Aquini) [1862283]
- include/uapi/linux/swab.h: fix userspace breakage, use __BITS_PER_LONG for swap (Rafael Aquini) [1862283]
- uapi: rename ext2_swab() to swab() and share globally in swab.h (Rafael Aquini) [1862283]
- lib/timerqueue: Rely on rbtree semantics for next timer (Phil Auld) [1984798]
- e1000e: Do not take care about recovery NVM checksum (Ken Cox) [1984558]
- qrtr: disable CONFIG_QRTR for non x86_64 archs (Íñigo Huguet) [1999642]
- ceph: fix possible null-pointer dereference in ceph_mdsmap_decode() (Jeff Layton) [1989999]
- ceph: fix dereference of null pointer cf (Jeff Layton) [1989999]
- ceph: correctly handle releasing an embedded cap flush (Jeff Layton) [1989999]
- ceph: take snap_empty_lock atomically with snaprealm refcount change (Jeff Layton) [1989999]
- ceph: don't WARN if we're still opening a session to an MDS (Jeff Layton) [1989999]
- rbd: don't hold lock_rwsem while running_list is being drained (Jeff Layton) [1989999]
- rbd: always kick acquire on "acquired" and "released" notifications (Jeff Layton) [1989999]
- ceph: take reference to req->r_parent at point of assignment (Jeff Layton) [1989999]
- ceph: eliminate ceph_async_iput() (Jeff Layton) [1989999]
- ceph: don't take s_mutex in ceph_flush_snaps (Jeff Layton) [1989999]
- ceph: don't take s_mutex in try_flush_caps (Jeff Layton) [1989999]
- ceph: don't take s_mutex or snap_rwsem in ceph_check_caps (Jeff Layton) [1989999]
- ceph: eliminate session->s_gen_ttl_lock (Jeff Layton) [1989999]
- ceph: allow ceph_put_mds_session to take NULL or ERR_PTR (Jeff Layton) [1989999]
- ceph: clean up locking annotation for ceph_get_snap_realm and __lookup_snap_realm (Jeff Layton) [1989999]
- ceph: add some lockdep assertions around snaprealm handling (Jeff Layton) [1989999]
- ceph: decoding error in ceph_update_snap_realm should return -EIO (Jeff Layton) [1989999]
- ceph: add IO size metrics support (Jeff Layton) [1989999]
- ceph: update and rename __update_latency helper to __update_stdev (Jeff Layton) [1989999]
- ceph: simplify the metrics struct (Jeff Layton) [1989999]
- libceph: fix doc warnings in cls_lock_client.c (Jeff Layton) [1989999]
- libceph: remove unnecessary ret variable in ceph_auth_init() (Jeff Layton) [1989999]
- libceph: kill ceph_none_authorizer::reply_buf (Jeff Layton) [1989999]
- ceph: make ceph_queue_cap_snap static (Jeff Layton) [1989999]
- ceph: remove bogus checks and WARN_ONs from ceph_set_page_dirty (Jeff Layton) [1989999]
- libceph: set global_id as soon as we get an auth ticket (Jeff Layton) [1989999]
- libceph: don't pass result into ac->ops->handle_reply() (Jeff Layton) [1989999]
- ceph: fix error handling in ceph_atomic_open and ceph_lookup (Jeff Layton) [1989999]
- ceph: must hold snap_rwsem when filling inode for async create (Jeff Layton) [1989999]
- libceph: Fix spelling mistakes (Jeff Layton) [1989999]
- libceph: don't set global_id until we get an auth ticket (Jeff Layton) [1989999]
- libceph: bump CephXAuthenticate encoding version (Jeff Layton) [1989999]
- ceph: don't allow access to MDS-private inodes (Jeff Layton) [1989999]
- ceph: fix up some bare fetches of i_size (Jeff Layton) [1989999]
- ceph: support getting ceph.dir.rsnaps vxattr (Jeff Layton) [1989999]
- ceph: drop pinned_page parameter from ceph_get_caps (Jeff Layton) [1989999]
- ceph: fix inode leak on getattr error in __fh_to_dentry (Jeff Layton) [1989999]
- ceph: only check pool permissions for regular files (Jeff Layton) [1989999]
- ceph: send opened files/pinned caps/opened inodes metrics to MDS daemon (Jeff Layton) [1989999]
- ceph: avoid counting the same request twice or more (Jeff Layton) [1989999]
- ceph: rename the metric helpers (Jeff Layton) [1989999]
- ceph: fix kerneldoc copypasta over ceph_start_io_direct (Jeff Layton) [1989999]
- ceph: don't use d_add in ceph_handle_snapdir (Jeff Layton) [1989999]
- ceph: don't clobber i_snap_caps on non-I_NEW inode (Jeff Layton) [1989999]
- ceph: fix fall-through warnings for Clang (Jeff Layton) [1989999]
- net: ceph: Fix a typo in osdmap.c (Jeff Layton) [1989999]
- ceph: don't allow type or device number to change on non-I_NEW inodes (Jeff Layton) [1989999]
- ceph: defer flushing the capsnap if the Fb is used (Jeff Layton) [1989999]
- ceph: allow queueing cap/snap handling after putting cap references (Jeff Layton) [1989999]
- ceph: clean up inode work queueing (Jeff Layton) [1989999]
- ceph: fix flush_snap logic after putting caps (Jeff Layton) [1989999]
- libceph: fix "Boolean result is used in bitwise operation" warning (Jeff Layton) [1989999]
- new helper: inode_wrong_type() (Jeff Layton) [1989999]
- kabi: Adding symbol single_release (fs/seq_file.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol single_open (fs/seq_file.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol seq_read (fs/seq_file.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol seq_printf (fs/seq_file.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol seq_lseek (fs/seq_file.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol unregister_chrdev_region (fs/char_dev.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol cdev_init (fs/char_dev.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol cdev_del (fs/char_dev.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol cdev_alloc (fs/char_dev.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol cdev_add (fs/char_dev.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol alloc_chrdev_region (fs/char_dev.c) (Čestmír Kalina) [1945486]
- kabi: Adding symbol pcie_capability_read_word (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pcie_capability_read_dword (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pcie_capability_clear_and_set_word (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_write_config_dword (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_write_config_byte (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_set_power_state (drivers/pci/pci.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_read_config_dword (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_read_config_byte (drivers/pci/access.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_irq_vector (drivers/pci/msi.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_get_device (drivers/pci/search.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_free_irq_vectors (drivers/pci/msi.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol pci_alloc_irq_vectors_affinity (drivers/pci/msi.c) (Čestmír Kalina) [1945485]
- kabi: Adding symbol kexec_crash_loaded (kernel/kexec_core.c) (Čestmír Kalina) [1945491]
- perf/x86/intel: Fix PEBS-via-PT reload base value for Extended PEBS (Michael Petlan) [1998051]
- perf/x86/intel/uncore: Fix Add BW copypasta (Michael Petlan) [1998051]
- perf/x86/intel/uncore: Add BW counters for GT, IA and IO breakdown (Michael Petlan) [1998051]
- Revert "ice: Add initial support framework for LAG" (Michal Schmidt) [1999016]
- net: re-initialize slow_gro flag at gro_list_prepare time (Paolo Abeni) [2002367]
- cxgb4: dont touch blocked freelist bitmap after free (Rahul Lakkireddy) [1998148]
- cxgb4vf: configure ports accessible by the VF (Rahul Lakkireddy) [1961329]
- scsi: lpfc: Fix memory leaks in error paths while issuing ELS RDF/SCR request (Dick Kennedy) [1976332]
- scsi: lpfc: Keep NDLP reference until after freeing the IOCB after ELS handling (Dick Kennedy) [1976332]
- scsi: lpfc: Move initialization of phba->poll_list earlier to avoid crash (Dick Kennedy) [1976332]

* Thu Sep 23 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-343.1.el8]
- md/raid10: properly indicate failure when ending a failed write request (Nigel Croxon) [1983859]
- md: Constify attribute_group structs (Nigel Croxon) [1983859]
- md: mark some personalities as deprecated (Nigel Croxon) [1983859]
- md/raid1: rename print_msg with r1bio_existed (Nigel Croxon) [1983859]
- async_xor: check src_offs is not NULL before updating it (Nigel Croxon) [1983859]
- async_xor: increase src_offs when dropping destination page (Nigel Croxon) [1983859]
- md/raid5: reallocate page array after setting new stripe_size (Nigel Croxon) [1983859]
- md/raid5: resize stripe_head when reshape array (Nigel Croxon) [1983859]
- md/raid5: let multiple devices of stripe_head share page (Nigel Croxon) [1983859]
- md/raid6: let async recovery function support different page offset (Nigel Croxon) [1983859]
- md/raid6: let syndrome computor support different page offset (Nigel Croxon) [1983859]
- md/raid5: convert to new xor compution interface (Nigel Croxon) [1983859]
- md/raid5: add new xor function to support different page offset (Nigel Croxon) [1983859]
- md/raid5: make async_copy_data() to support different page offset (Nigel Croxon) [1983859]
- md/raid5: add a new member of offset into r5dev (Nigel Croxon) [1983859]
- x86/cpu: Update cached HLE state on write to TSX_CTRL_CPUID_CLEAR (Jay Shin) [1994421]
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [1987094]
- crypto: ccp - shutdown SEV firmware on kexec (Vladis Dronov) [1987094]
- crypto: ccp - Use list_move_tail instead of list_del/list_add_tail in ccp-dmaengine.c (Vladis Dronov) [1987094]
- crypto: ccp: ccp-dev: Fix a little doc-rot (Vladis Dronov) [1987094]
- crypto: ccp - Fix a resource leak in an error handling path (Vladis Dronov) [1987094]
- crypto: ccp - Annotate SEV Firmware file names (Vladis Dronov) [1987094]
- crypto: ccp - Make ccp_dev_suspend and ccp_dev_resume void functions (Vladis Dronov) [1987094]
- crypto: ccp - Use DEFINE_SPINLOCK() for spinlock (Vladis Dronov) [1987094]
- crypto: ccp - A value assigned to a variable is never used (Vladis Dronov) [1987094]
- crypto: ccp - Don't initialize SEV support without the SEV feature (Vladis Dronov) [1987094]
- crypto: ccp - fix error handling (Vladis Dronov) [1987094]
- crypto: ccp - use generic power management (Vladis Dronov) [1987094]
- crypto: drivers - set the flag CRYPTO_ALG_ALLOCATES_MEMORY (Vladis Dronov) [1987094]
- crypto: ahash - remove useless setting of type flags (Vladis Dronov) [1987094]
- crypto: ccp - Silence strncpy warning (Vladis Dronov) [1987094]
- crypto: ccp - permit asynchronous skcipher as fallback (Vladis Dronov) [1987094]
- crypto: ccp - Fix sparse warnings (Vladis Dronov) [1987094]
- crypto: ccp - Update CCP driver maintainer information (Vladis Dronov) [1987094]
- crypto: ccp - Fix use of merged scatterlists (Vladis Dronov) [1987094]
- crypto: ccp - remove redundant assignment to variable ret (Vladis Dronov) [1987094]
- crypto: ccp - use crypto_shash_tfm_digest() (Vladis Dronov) [1987094]
- crypto: hash - introduce crypto_shash_tfm_digest() (Vladis Dronov) [1987094]
- crypto: ccp -- don't "select" CONFIG_DMADEVICES (Vladis Dronov) [1987094]
- crypto: ccp - Update MAINTAINERS for CCP driver (Vladis Dronov) [1987094]
- crypto: ccp - switch from ablkcipher to skcipher (Vladis Dronov) [1987094]
- ipc: replace costly bailout check in sysvipc_find_ipc() (Rafael Aquini) [1980619 1987128] {CVE-2021-3669}
- ipc/util.c: sysvipc_find_ipc() incorrectly updates position index (Rafael Aquini) [1980619 1987128] {CVE-2021-3669}
- ipc/util.c: sysvipc_find_ipc() should increase position index (Rafael Aquini) [1980619 1987128] {CVE-2021-3669}
- psi: Fix psi state corruption when schedule() races with cgroup move (Waiman Long) [2002025]
- psi: Optimize task switch inside shared cgroups (Waiman Long) [2002025]
- kthread: Fix PF_KTHREAD vs to_kthread() race (Waiman Long) [2002025]
- sched/fair: Ignore percpu threads for imbalance pulls (Waiman Long) [2002025]
- sched: Fix get_push_task() vs migrate_disable() (Waiman Long) [2002025]
- sched: Don't defer CPU pick to migration_cpu_stop() (Waiman Long) [2002025]
- sched: Simplify migration_cpu_stop() (Waiman Long) [2002025]
- sched: Simplify set_affinity_pending refcounts (Waiman Long) [2002025]
- sched: Fix affine_move_task() self-concurrency (Waiman Long) [2002025]
- sched: Optimize migration_cpu_stop() (Waiman Long) [2002025]
- sched: Collate affine_move_task() stoppers (Waiman Long) [2002025]
- sched: Simplify migration_cpu_stop() (Waiman Long) [2002025]
- sched: Fix migration_cpu_stop() requeueing (Waiman Long) [2002025]
- sched: Relax the set_cpus_allowed_ptr() semantics (Waiman Long) [2002025]
- sched: Fix CPU hotplug / tighten is_per_cpu_kthread() (Waiman Long) [2002025]
- sched: Prepare to use balance_push in ttwu() (Waiman Long) [2002025]
- workqueue: Restrict affinity change to rescuer (Waiman Long) [2002025]
- workqueue: Tag bound workers with KTHREAD_IS_PER_CPU (Waiman Long) [2002025]
- kthread: Extract KTHREAD_IS_PER_CPU (Waiman Long) [2002025]
- sched: Don't run cpu-online with balance_push() enabled (Waiman Long) [2002025]
- workqueue: Use cpu_possible_mask instead of cpu_active_mask to break affinity (Waiman Long) [2002025]
- sched/core: Print out straggler tasks in sched_cpu_dying() (Waiman Long) [2002025]
- sched: Optimize finish_lock_switch() (Waiman Long) [2002025]
- sched: Fix migration_cpu_stop() WARN (Waiman Long) [2002025]
- sched/core: Add missing completion for affine_move_task() waiters (Waiman Long) [2002025]
- stop_machine, rcu: Mark functions as notrace (Waiman Long) [2002025]
- sched: Comment affine_move_task() (Waiman Long) [2002025]
- sched: Deny self-issued __set_cpus_allowed_ptr() when migrate_disable() (Waiman Long) [2002025]
- sched/proc: Print accurate cpumask vs migrate_disable() (Waiman Long) [2002025]
- sched: Make migrate_disable/enable() independent of RT (Waiman Long) [2002025]
- sched: Fix migrate_disable() vs rt/dl balancing (Waiman Long) [2002025]
- sched, lockdep: Annotate ->pi_lock recursion (Waiman Long) [2002025]
- sched,rt: Use the full cpumask for balancing (Waiman Long) [2002025]
- sched,rt: Use cpumask_any*_distribute() (Waiman Long) [2002025]
- sched/core: Make migrate disable and CPU hotplug cooperative (Waiman Long) [2002025]
- sched: Fix migrate_disable() vs set_cpus_allowed_ptr() (Waiman Long) [2002025]
- sched: Add migrate_disable() (Waiman Long) [2002025]
- sched: Massage set_cpus_allowed() (Waiman Long) [2002025]
- sched: Fix hotplug vs CPU bandwidth control (Waiman Long) [2002025]
- sched/hotplug: Consolidate task migration on CPU unplug (Waiman Long) [2002025]
- workqueue: Manually break affinity on hotplug (Waiman Long) [2002025]
- sched/core: Wait for tasks being pushed away on hotplug (Waiman Long) [2002025]
- sched/hotplug: Ensure only per-cpu kthreads run during hotplug (Waiman Long) [2002025]
- sched: Fix balance_callback() (Waiman Long) [2002025]
- maccess: rename probe_kernel_{read,write} to copy_{from,to}_kernel_nofault (Waiman Long) [2002025]
- s390/ftrace: fix potential crashes when switching tracers (Waiman Long) [2002025]
- psi: Move PF_MEMSTALL out of task->flags (Waiman Long) [2002025]
- psi: Optimize switching tasks inside shared cgroups (Waiman Long) [2002025]
- psi: Fix cpu.pressure for cpu.max and competing cgroups (Waiman Long) [2002025]
- stop_machine: Make stop_cpus() static (Waiman Long) [2002025]
- stop_machine: remove try_stop_cpus helper (Waiman Long) [2002025]
- kernel.h: Add non_block_start/end() (Waiman Long) [2002025]
- processor: get rid of cpu_relax_yield (Waiman Long) [2002025]
- processor: remove spin_cpu_yield (Waiman Long) [2002025]
- s390: improve wait logic of stop_machine (Waiman Long) [2002025]
- sched/core: Fix typo in comment (Waiman Long) [2002025]
- ia64/tlb: Eradicate tlb_migrate_finish() callback (Waiman Long) [2002025]
- sched/core: Remove unnecessary unlikely() in push_*_task() (Waiman Long) [2002025]
- sched/fair: Reduce long-tail newly idle balance cost (Phil Auld) [1971918]
- hwmon: (acpi_power_meter) Fix lockdep splat (Waiman Long) [1997807]
- redhat: open the RHEL-8.6 development (Augusto Caringi) [2000679]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1997500]
- mt76: connac: do not schedule mac_work if the device is not running (Íñigo Huguet) [1956419 1972045]
- mt7921e: enable module in config (Íñigo Huguet) [1956419 1972045]
- Revert tools/power/cpupower: Read energy_perf_bias from sysfs (Steve Best) [1999926]
- libnvdimm/namespace: Differentiate between probe mapping and runtime mapping (Jeff Moyer) [1795719]
- libnvdimm/pfn_dev: Don't clear device memmap area during generic namespace probe (Jeff Moyer) [1795719]
- perf/x86/intel/uncore: Clean up error handling path of iio mapping (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Fix for iio mapping on Skylake Server (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Generic support for the MMIO type of uncore blocks (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Generic support for the PCI type of uncore blocks (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Rename uncore_notifier to uncore_pci_sub_notifier (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Generic support for the MSR type of uncore blocks (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Parse uncore discovery tables (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Expose an Uncore unit to IIO PMON mapping (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Wrap the max dies calculation into an accessor (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Expose an Uncore unit to PMON mapping (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Validate MMIO address before accessing (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Record the size of mapped area (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Fix oops when counting IMC uncore events on some TGL (Michael Petlan) [1837330]
- crypto: qat - remove unused macro in FW loader (Vladis Dronov) [1920086]
- crypto: qat - check return code of qat_hal_rd_rel_reg() (Vladis Dronov) [1920086]
- crypto: qat - report an error if MMP file size is too large (Vladis Dronov) [1920086]
- crypto: qat - check MMP size before writing to the SRAM (Vladis Dronov) [1920086]
- crypto: qat - return error when failing to map FW (Vladis Dronov) [1920086]
- crypto: qat - enable detection of accelerators hang (Vladis Dronov) [1920086]
- crypto: qat - Fix a double free in adf_create_ring (Vladis Dronov) [1920086]
- crypto: qat - fix error path in adf_isr_resource_alloc() (Vladis Dronov) [1920086]
- crypto: qat - ADF_STATUS_PF_RUNNING should be set after adf_dev_init (Vladis Dronov) [1920086]
- crypto: qat - don't release uninitialized resources (Vladis Dronov) [1920086]
- crypto: qat - fix use of 'dma_map_single' (Vladis Dronov) [1920086]
- crypto: qat - fix unmap invalid dma address (Vladis Dronov) [1920086]
- crypto: qat - fix spelling mistake: "messge" -> "message" (Vladis Dronov) [1920086]
- crypto: qat - reduce size of mapped region (Vladis Dronov) [1920086]
- crypto: qat - change format string and cast ring size (Vladis Dronov) [1920086]
- crypto: qat - fix potential spectre issue (Vladis Dronov) [1920086]
- crypto: qat - configure arbiter mapping based on engines enabled (Vladis Dronov) [1920086]
- selftest: netfilter: add test case for unreplied tcp connections (Florian Westphal) [1991523]
- netfilter: conntrack: do not renew entry stuck in tcp SYN_SENT state (Florian Westphal) [1991523]
- net/sched: store the last executed chain also for clsact egress (Davide Caratti) [1980537]
- ice: fix Tx queue iteration for Tx timestamp enablement (Ken Cox) [1999743]
- perf evsel: Add missing cloning of evsel->use_config_name (Michael Petlan) [1838635]
- perf Documentation: Document intel-hybrid support (Michael Petlan) [1838635]
- perf tests: Skip 'perf stat metrics (shadow stat) test' for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Convert perf time to TSC' test for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Session topology' test for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Parse and process metrics' test for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Track with sched_switch' test for hybrid (Michael Petlan) [1838635]
- perf tests: Skip 'Setup struct perf_event_attr' test for hybrid (Michael Petlan) [1838635]
- perf tests: Add hybrid cases for 'Roundtrip evsel->name' test (Michael Petlan) [1838635]
- perf tests: Add hybrid cases for 'Parse event definition strings' test (Michael Petlan) [1838635]
- perf record: Uniquify hybrid event name (Michael Petlan) [1838635]
- perf stat: Warn group events from different hybrid PMU (Michael Petlan) [1838635]
- perf stat: Filter out unmatched aggregation for hybrid event (Michael Petlan) [1838635]
- perf stat: Add default hybrid events (Michael Petlan) [1838635]
- perf record: Create two hybrid 'cycles' events by default (Michael Petlan) [1838635]
- perf parse-events: Support event inside hybrid pmu (Michael Petlan) [1838635]
- perf parse-events: Compare with hybrid pmu name (Michael Petlan) [1838635]
- perf parse-events: Create two hybrid raw events (Michael Petlan) [1838635]
- perf parse-events: Create two hybrid cache events (Michael Petlan) [1838635]
- perf parse-events: Create two hybrid hardware events (Michael Petlan) [1838635]
- perf stat: Uniquify hybrid event name (Michael Petlan) [1838635]
- perf pmu: Add hybrid helper functions (Michael Petlan) [1838635]
- perf pmu: Save detected hybrid pmus to a global pmu list (Michael Petlan) [1838635]
- perf pmu: Save pmu name (Michael Petlan) [1838635]
- perf pmu: Simplify arguments of __perf_pmu__new_alias (Michael Petlan) [1838635]
- perf jevents: Support unit value "cpu_core" and "cpu_atom" (Michael Petlan) [1838635]
- tools headers uapi: Update tools's copy of linux/perf_event.h (Michael Petlan) [1838635]

* Thu Sep 16 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-343.el8]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1997500]
- mt76: connac: do not schedule mac_work if the device is not running (Íñigo Huguet) [1956419 1972045]
- mt7921e: enable module in config (Íñigo Huguet) [1956419 1972045]
- Revert tools/power/cpupower: Read energy_perf_bias from sysfs (Steve Best) [1999926]
- libnvdimm/namespace: Differentiate between probe mapping and runtime mapping (Jeff Moyer) [1795719]
- libnvdimm/pfn_dev: Don't clear device memmap area during generic namespace probe (Jeff Moyer) [1795719]
- perf/x86/intel/uncore: Clean up error handling path of iio mapping (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Fix for iio mapping on Skylake Server (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Generic support for the MMIO type of uncore blocks (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Generic support for the PCI type of uncore blocks (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Rename uncore_notifier to uncore_pci_sub_notifier (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Generic support for the MSR type of uncore blocks (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Parse uncore discovery tables (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Expose an Uncore unit to IIO PMON mapping (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Wrap the max dies calculation into an accessor (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Expose an Uncore unit to PMON mapping (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Validate MMIO address before accessing (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Record the size of mapped area (Michael Petlan) [1837330]
- perf/x86/intel/uncore: Fix oops when counting IMC uncore events on some TGL (Michael Petlan) [1837330]
- crypto: qat - remove unused macro in FW loader (Vladis Dronov) [1920086]
- crypto: qat - check return code of qat_hal_rd_rel_reg() (Vladis Dronov) [1920086]
- crypto: qat - report an error if MMP file size is too large (Vladis Dronov) [1920086]
- crypto: qat - check MMP size before writing to the SRAM (Vladis Dronov) [1920086]
- crypto: qat - return error when failing to map FW (Vladis Dronov) [1920086]
- crypto: qat - enable detection of accelerators hang (Vladis Dronov) [1920086]
- crypto: qat - Fix a double free in adf_create_ring (Vladis Dronov) [1920086]
- crypto: qat - fix error path in adf_isr_resource_alloc() (Vladis Dronov) [1920086]
- crypto: qat - ADF_STATUS_PF_RUNNING should be set after adf_dev_init (Vladis Dronov) [1920086]
- crypto: qat - don't release uninitialized resources (Vladis Dronov) [1920086]
- crypto: qat - fix use of 'dma_map_single' (Vladis Dronov) [1920086]
- crypto: qat - fix unmap invalid dma address (Vladis Dronov) [1920086]
- crypto: qat - fix spelling mistake: "messge" -> "message" (Vladis Dronov) [1920086]
- crypto: qat - reduce size of mapped region (Vladis Dronov) [1920086]
- crypto: qat - change format string and cast ring size (Vladis Dronov) [1920086]
- crypto: qat - fix potential spectre issue (Vladis Dronov) [1920086]
- crypto: qat - configure arbiter mapping based on engines enabled (Vladis Dronov) [1920086]

* Tue Sep 14 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-342.el8]
- selftest: netfilter: add test case for unreplied tcp connections (Florian Westphal) [1991523]
- netfilter: conntrack: do not renew entry stuck in tcp SYN_SENT state (Florian Westphal) [1991523]
- net/sched: store the last executed chain also for clsact egress (Davide Caratti) [1980537]
- ice: fix Tx queue iteration for Tx timestamp enablement (Ken Cox) [1999743]
- perf evsel: Add missing cloning of evsel->use_config_name (Michael Petlan) [1838635]
- perf Documentation: Document intel-hybrid support (Michael Petlan) [1838635]
- perf tests: Skip 'perf stat metrics (shadow stat) test' for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Convert perf time to TSC' test for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Session topology' test for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Parse and process metrics' test for hybrid (Michael Petlan) [1838635]
- perf tests: Support 'Track with sched_switch' test for hybrid (Michael Petlan) [1838635]
- perf tests: Skip 'Setup struct perf_event_attr' test for hybrid (Michael Petlan) [1838635]
- perf tests: Add hybrid cases for 'Roundtrip evsel->name' test (Michael Petlan) [1838635]
- perf tests: Add hybrid cases for 'Parse event definition strings' test (Michael Petlan) [1838635]
- perf record: Uniquify hybrid event name (Michael Petlan) [1838635]
- perf stat: Warn group events from different hybrid PMU (Michael Petlan) [1838635]
- perf stat: Filter out unmatched aggregation for hybrid event (Michael Petlan) [1838635]
- perf stat: Add default hybrid events (Michael Petlan) [1838635]
- perf record: Create two hybrid 'cycles' events by default (Michael Petlan) [1838635]
- perf parse-events: Support event inside hybrid pmu (Michael Petlan) [1838635]
- perf parse-events: Compare with hybrid pmu name (Michael Petlan) [1838635]
- perf parse-events: Create two hybrid raw events (Michael Petlan) [1838635]
- perf parse-events: Create two hybrid cache events (Michael Petlan) [1838635]
- perf parse-events: Create two hybrid hardware events (Michael Petlan) [1838635]
- perf stat: Uniquify hybrid event name (Michael Petlan) [1838635]
- perf pmu: Add hybrid helper functions (Michael Petlan) [1838635]
- perf pmu: Save detected hybrid pmus to a global pmu list (Michael Petlan) [1838635]
- perf pmu: Save pmu name (Michael Petlan) [1838635]
- perf pmu: Simplify arguments of __perf_pmu__new_alias (Michael Petlan) [1838635]
- perf jevents: Support unit value "cpu_core" and "cpu_atom" (Michael Petlan) [1838635]
- tools headers uapi: Update tools's copy of linux/perf_event.h (Michael Petlan) [1838635]

* Fri Sep 10 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-341.el8]
- mptcp: Only send extra TCP acks in eligible socket states (Paolo Abeni) [1997178]
- mptcp: fix possible divide by zero (Paolo Abeni) [1997178]
- mptcp: drop tx skb cache (Paolo Abeni) [1997178]
- mptcp: fix memory leak on address flush (Paolo Abeni) [1997178]
- ice: Only lock to update netdev dev_addr (Michal Schmidt) [1995868]
- ice: restart periodic outputs around time changes (Ken Cox) [1992750]
- ice: Fix perout start time rounding (Ken Cox) [1992750]
- net/sched: ets: fix crash when flipping from 'strict' to 'quantum' (Davide Caratti) [1981184]
- ovl: prevent private clone if bind mount is not allowed (Miklos Szeredi) [1993131] {CVE-2021-3732}
- gfs2: Don't call dlm after protocol is unmounted (Bob Peterson) [1997193]
- gfs2: don't stop reads while withdraw in progress (Bob Peterson) [1997193]
- gfs2: Mark journal inodes as "don't cache" (Bob Peterson) [1997193]
- bpf: bpftool: Add -fno-asynchronous-unwind-tables to BPF Clang invocation (Yauheni Kaliuta) [1997124]
- perf/x86/intel: Apply mid ACK for small core (Michael Petlan) [1838573]
- perf/x86/intel/lbr: Zero the xstate buffer on allocation (Michael Petlan) [1838573]
- perf: Fix task context PMU for Hetero (Michael Petlan) [1838573]
- perf/x86/intel: Fix fixed counter check warning for some Alder Lake (Michael Petlan) [1838573]
- perf/x86/lbr: Remove cpuc->lbr_xsave allocation from atomic context (Michael Petlan) [1838573]
- x86/fpu/xstate: Fix an xstate size check warning with architectural LBRs (Michael Petlan) [1838573]
- perf/x86/rapl: Add support for Intel Alder Lake (Michael Petlan) [1838573]
- perf/x86/cstate: Add Alder Lake CPU support (Michael Petlan) [1838573]
- perf/x86/msr: Add Alder Lake CPU support (Michael Petlan) [1838573]
- perf/x86/intel/uncore: Add Alder Lake support (Michael Petlan) [1838573]
- perf: Extend PERF_TYPE_HARDWARE and PERF_TYPE_HW_CACHE (Michael Petlan) [1838573]
- perf/x86/intel: Add Alder Lake Hybrid support (Michael Petlan) [1838573]
- perf/x86: Support filter_match callback (Michael Petlan) [1838573]
- perf/x86/intel: Add attr_update for Hybrid PMUs (Michael Petlan) [1838573]
- perf/x86: Add structures for the attributes of Hybrid PMUs (Michael Petlan) [1838573]
- perf/x86: Register hybrid PMUs (Michael Petlan) [1838573]
- perf/x86: Factor out x86_pmu_show_pmu_cap (Michael Petlan) [1838573]
- perf/x86: Remove temporary pmu assignment in event_init (Michael Petlan) [1838573]
- perf/x86/intel: Factor out intel_pmu_check_extra_regs (Michael Petlan) [1838573]
- perf/x86/intel: Factor out intel_pmu_check_event_constraints (Michael Petlan) [1838573]
- perf/x86/intel: Factor out intel_pmu_check_num_counters (Michael Petlan) [1838573]
- perf/x86: Hybrid PMU support for extra_regs (Michael Petlan) [1838573]
- perf/x86: Hybrid PMU support for event constraints (Michael Petlan) [1838573]
- perf/x86: Hybrid PMU support for hardware cache event (Michael Petlan) [1838573]
- perf/x86: Hybrid PMU support for unconstrained (Michael Petlan) [1838573]
- perf/x86: Hybrid PMU support for counters (Michael Petlan) [1838573]
- perf/x86: Hybrid PMU support for intel_ctrl (Michael Petlan) [1838573]
- perf/x86/intel: Hybrid PMU support for perf capabilities (Michael Petlan) [1838573]
- perf/x86: Track pmu in per-CPU cpu_hw_events (Michael Petlan) [1838573]
- perf/x86/intel/lbr: Support XSAVES for arch LBR read (Michael Petlan) [1838573]
- perf/x86/intel/lbr: Support XSAVES/XRSTORS for LBR context switch (Michael Petlan) [1838573]
- x86/fpu/xstate: Add helpers for LBR dynamic supervisor feature (Michael Petlan) [1838573]
- x86/fpu/xstate: Support dynamic supervisor feature for LBR (Michael Petlan) [1838573]
- x86/fpu: Use proper mask to replace full instruction mask (Michael Petlan) [1838573]
- x86/cpu: Add helper function to get the type of the current hybrid CPU (Michael Petlan) [1838573]
- x86/cpufeatures: Enumerate Intel Hybrid Technology feature bit (Michael Petlan) [1838573]
- HID: make arrays usage and value to be the same (Benjamin Tissoires) [1974942]
- ACPI: PM: s2idle: Invert Microsoft UUID entry and exit (David Arcari) [1960440]
- platform/x86: amd-pmc: Fix undefined reference to __udivdi3 (David Arcari) [1960440]
- platform/x86: amd-pmc: Fix missing unlock on error in amd_pmc_send_cmd() (David Arcari) [1960440]
- platform/x86: amd-pmc: Use return code on suspend (David Arcari) [1960440]
- platform/x86: amd-pmc: Add new acpi id for future PMC controllers (David Arcari) [1960440]
- platform/x86: amd-pmc: Add support for ACPI ID AMDI0006 (David Arcari) [1960440]
- platform/x86: amd-pmc: Add support for logging s0ix counters (David Arcari) [1960440]
- platform/x86: amd-pmc: Add support for logging SMU metrics (David Arcari) [1960440]
- platform/x86: amd-pmc: call dump registers only once (David Arcari) [1960440]
- platform/x86: amd-pmc: Fix SMU firmware reporting mechanism (David Arcari) [1960440]
- platform/x86: amd-pmc: Fix command completion code (David Arcari) [1960440]
- usb: pci-quirks: disable D3cold on xhci suspend for s2idle on AMD Renoir (David Arcari) [1960440]
- ACPI: PM: Only mark EC GPE for wakeup on Intel systems (David Arcari) [1960440]
- ACPI: PM: Adjust behavior for field problems on AMD systems (David Arcari) [1960440]
- ACPI: PM: s2idle: Add support for new Microsoft UUID (David Arcari) [1960440]
- ACPI: PM: s2idle: Add support for multiple func mask (David Arcari) [1960440]
- ACPI: PM: s2idle: Refactor common code (David Arcari) [1960440]
- ACPI: PM: s2idle: Use correct revision id (David Arcari) [1960440]
- ACPI: PM: s2idle: Add missing LPS0 functions for AMD (David Arcari) [1960440]
- lockd: Fix invalid lockowner cast after vfs_test_lock (Benjamin Coddington) [1986138]

* Thu Sep 02 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-340.el8]
- blk-mq: fix is_flush_rq (Ming Lei) [1992700]
- blk-mq: fix kernel panic during iterating over flush request (Ming Lei) [1992700]

* Fri Aug 27 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-339.el8]
- smb2: fix use-after-free in smb2_ioctl_query_info() (Ronnie Sahlberg) [1952781]
- dm crypt: Avoid percpu_counter spinlock contention in crypt_page_alloc() (Mike Snitzer) [1996854]
- md/raid10: Remove rcu_dereference when it doesn't need rcu lock to protect (Nigel Croxon) [1978115]
- scsi: csiostor: Mark known unused variable as __always_unused (Raju Rangoju) [1961333]
- scsi: csiostor: Fix wrong return value in csio_hw_prep_fw() (Raju Rangoju) [1961333]
- scsi: csiostor: Remove set but not used variable 'rln' (Raju Rangoju) [1961333]
- scsi: csiostor: Return value not required for csio_dfs_destroy (Raju Rangoju) [1961333]
- scsi: csiostor: Fix NULL check before debugfs_remove_recursive (Raju Rangoju) [1961333]
- scsi: csiostor: Don't enable IRQs too early (Raju Rangoju) [1961333]
- scsi: csiostor: Fix spelling typos (Raju Rangoju) [1961333]
- scsi: csiostor: Prefer pcie_capability_read_word() (Raju Rangoju) [1961333]
- scsi: target: cxgbit: Unmap DMA buffer before calling target_execute_cmd() (Raju Rangoju) [1961394]
- net: Use skb_frag_off accessors (Raju Rangoju) [1961394]
- net: Use skb accessors in network drivers (Raju Rangoju) [1961394]
- cxgb4/chtls/cxgbit: Keeping the max ofld immediate data size same in cxgb4 and ulds (Raju Rangoju) [1961394]
- scsi: libcxgbi: Fix a use after free in cxgbi_conn_xmit_pdu() (Raju Rangoju) [1961394]
- scsi: libcxgbi: Use kvzalloc instead of opencoded kzalloc/vzalloc (Raju Rangoju) [1961394]
- scsi: libcxgbi: Remove unnecessary NULL checks for 'tdata' pointer (Raju Rangoju) [1961394]
- scsi: cxgb4i: Remove an unnecessary NULL check for 'cconn' pointer (Raju Rangoju) [1961394]
- scsi: cxgb4i: Clean up a debug printk (Raju Rangoju) [1961394]
- scsi: cxgb4i: Fix dereference of pointer tdata before it is null checked (Raju Rangoju) [1961394]
- scsi: libcxgbi: fix NULL pointer dereference in cxgbi_device_destroy() (Raju Rangoju) [1961394]
- scsi: libcxgbi: remove unused function to stop warning (Raju Rangoju) [1961394]
- scsi: libcxgbi: add a check for NULL pointer in cxgbi_check_route() (Raju Rangoju) [1961394]
- net/chelsio: Delete drive and module versions (Raju Rangoju) [1961394]
- chelsio: Replace zero-length array with flexible-array member (Raju Rangoju) [1961394]
- [netdrv] treewide: prefix header search paths with $(srctree)/ (Raju Rangoju) [1961394]
- libcxgb: fix incorrect ppmax calculation (Raju Rangoju) [1961394]
- scsi: cxgb4i: Fix TLS dependency (Raju Rangoju) [1961394]
- [target] treewide: Use fallthrough pseudo-keyword (Raju Rangoju) [1961394]
- scsi: cxgb4i: Add support for iSCSI segmentation offload (Raju Rangoju) [1961394]
- [target] treewide: Use sizeof_field() macro (Raju Rangoju) [1961394]
- [target] treewide: replace '---help---' in Kconfig files with 'help' (Raju Rangoju) [1961394]
- scsi: cxgb4i: Remove superfluous null check (Raju Rangoju) [1961394]

* Thu Aug 26 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-338.el8]
- KVM: nSVM: avoid picking up unsupported bits from L2 in int_ctl (CVE-2021-3653) (Jon Maloy) [1985413] {CVE-2021-3653}
- KVM: nSVM: always intercept VMLOAD/VMSAVE when nested (CVE-2021-3656) (Jon Maloy) [1985430] {CVE-2021-3656}
- drm/i915/rkl: Remove require_force_probe protection (Lyude Paul) [1985159]
- drm/i915/display: support ddr5 mem types (Lyude Paul) [1992233]
- drm/i915/adl_s: Update ddi buf translation tables (Lyude Paul) [1992233]
- drm/i915/adl_s: Wa_14011765242 is also needed on A1 display stepping (Lyude Paul) [1992233]
- drm/i915/adl_s: Extend Wa_1406941453 (Lyude Paul) [1992233]
- drm/i915: Implement Wa_1508744258 (Lyude Paul) [1992233]
- drm/i915/adl_s: Fix dma_mask_size to 39 bit (Lyude Paul) [1992233]
- drm/i915: Add the missing adls vswing tables (Lyude Paul) [1992233]
- drm/i915: Add Wa_14011060649 (Lyude Paul) [1992233]
- drm/i915/adl_s: Add Interrupt Support (Lyude Paul) [1992233]
- drm/amdgpu: add another Renoir DID (Lyude Paul) [1980900]

* Wed Aug 25 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-337.el8]
- net/mlx5: Fix flow table chaining (Amir Tzin) [1987139]
- openvswitch: fix sparse warning incorrect type (Mark Gray) [1992773]
- openvswitch: fix alignment issues (Mark Gray) [1992773]
- openvswitch: update kdoc OVS_DP_ATTR_PER_CPU_PIDS (Mark Gray) [1992773]
- openvswitch: Introduce per-cpu upcall dispatch (Mark Gray) [1992773]
- KVM: X86: Expose bus lock debug exception to guest (Paul Lai) [1842322]
- KVM: X86: Add support for the emulation of DR6_BUS_LOCK bit (Paul Lai) [1842322]
- scsi: libfc: Fix array index out of bound exception (Chris Leech) [1972643]
- scsi: libfc: FDMI enhancements (Chris Leech) [1972643]
- scsi: libfc: Add FDMI-2 attributes (Chris Leech) [1972643]
- scsi: qedf: Add vendor identifier attribute (Chris Leech) [1972643]
- scsi: libfc: Initialisation of RHBA and RPA attributes (Chris Leech) [1972643]
- scsi: libfc: Correct the condition check and invalid argument passed (Chris Leech) [1972643]
- scsi: libfc: Work around -Warray-bounds warning (Chris Leech) [1972643]
- scsi: fc: FDMI enhancement (Chris Leech) [1972643]
- scsi: libfc: Move scsi/fc_encode.h to libfc (Chris Leech) [1972643]
- scsi: fc: Correct RHBA attributes length (Chris Leech) [1972643]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [1991976]
- x86/fpu: Prevent state corruption in __fpu__restore_sig() (Terry Bowman) [1970086]
- x86/fpu: Invalidate FPU state after a failed XRSTOR from a user buffer (Terry Bowman) [1970086]
- x86/pkru: Write hardware init value to PKRU when xstate is init (Terry Bowman) [1970086]
- x86/process: Check PF_KTHREAD and not current->mm for kernel threads (Terry Bowman) [1970086]
- x86/fpu: Add address range checks to copy_user_to_xstate() (Terry Bowman) [1970086]
- selftests/x86: Test signal frame XSTATE header corruption handling (Terry Bowman) [1970086]
- Bump DRM backport version to 5.12.14 (Lyude Paul) [1944405]
- drm/i915: Use the correct max source link rate for MST (Lyude Paul) [1944405 1966599]
- drm/dp_mst: Use Extended Base Receiver Capability DPCD space (Lyude Paul) [1944405 1966599]
- drm/i915/display: Defeature PSR2 for RKL and ADL-S (Lyude Paul) [1944405]
- drm/i915/adl_s: ADL-S platform Update PCI ids for Mobile BGA (Lyude Paul) [1944405]
- drm/amdgpu: wait for moving fence after pinning (Lyude Paul) [1944405]
- drm/radeon: wait for moving fence after pinning (Lyude Paul) [1944405]
- drm/nouveau: wait for moving fence after pinning v2 (Lyude Paul) [1944405]
- radeon: use memcpy_to/fromio for UVD fw upload (Lyude Paul) [1944405]
- drm/amd/amdgpu:save psp ring wptr to avoid attack (Lyude Paul) [1944405]
- drm/amd/display: Fix potential memory leak in DMUB hw_init (Lyude Paul) [1944405]
- drm/amdgpu: refine amdgpu_fru_get_product_info (Lyude Paul) [1944405]
- drm/amd/display: Allow bandwidth validation for 0 streams. (Lyude Paul) [1944405]
- drm: Lock pointer access in drm_master_release() (Lyude Paul) [1944405]
- drm: Fix use-after-free read in drm_getunique() (Lyude Paul) [1944405]
- drm/amdgpu: make sure we unpin the UVD BO (Lyude Paul) [1944405]
- drm/amdgpu: Don't query CE and UE errors (Lyude Paul) [1944405]
- drm/amdgpu/jpeg3: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- drm/amdgpu/jpeg2.5: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- drm/amdgpu/vcn3: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- amdgpu: fix GEM obj leak in amdgpu_display_user_framebuffer_create (Lyude Paul) [1944405]
- drm/i915/selftests: Fix return value check in live_breadcrumbs_smoketest() (Lyude Paul) [1944405]
- drm/amdgpu: stop touching sched.ready in the backend (Lyude Paul) [1944405]
- drm/amd/amdgpu: fix a potential deadlock in gpu reset (Lyude Paul) [1944405]
- drm/amdgpu: Fix a use-after-free (Lyude Paul) [1944405]
- drm/amd/amdgpu: fix refcount leak (Lyude Paul) [1944405]
- drm/amd/display: Disconnect non-DP with no EDID (Lyude Paul) [1944405]
- drm/amdgpu/jpeg2.0: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- drm/amdgpu/vcn2.5: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- drm/amdgpu/vcn2.0: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- drm/amdkfd: correct sienna_cichlid SDMA RLC register offset error (Lyude Paul) [1944405]
- drm/amdgpu/vcn1: add cancel_delayed_work_sync before power gate (Lyude Paul) [1944405]
- drm/amd/pm: correct MGpuFanBoost setting (Lyude Paul) [1944405]
- drm/i915: Reenable LTTPR non-transparent LT mode for DPCD_REV<1.4 (Lyude Paul) [1944405]
- drm/i915/gt: Disable HiZ Raw Stall Optimization on broken gen7 (Lyude Paul) [1944405]
- dma-buf: fix unintended pin/unpin warnings (Lyude Paul) [1944405]
- drm/amdgpu: update sdma golden setting for Navi12 (Lyude Paul) [1944405]
- drm/amdgpu: update gc golden setting for Navi12 (Lyude Paul) [1944405]
- drm/amdgpu: disable 3DCGCG on picasso/raven1 to avoid compute hang (Lyude Paul) [1944405]
- drm/amdgpu: Fix GPU TLB update error when PAGE_SIZE > AMDGPU_PAGE_SIZE (Lyude Paul) [1944405]
- drm/radeon: use the dummy page for GART if needed (Lyude Paul) [1944405]
- drm/amd/display: Use the correct max downscaling value for DCN3.x family (Lyude Paul) [1944405]
- drm/i915/gem: Pin the L-shape quirked object as unshrinkable (Lyude Paul) [1944405]
- drm/ttm: Do not add non-system domain BO into swap list (Lyude Paul) [1944405]
- drm/amd/display: Fix two cursor duplication when using overlay (Lyude Paul) [1944405]
- amdgpu/pm: Prevent force of DCEFCLK on NAVI10 and SIENNA_CICHLID (Lyude Paul) [1944405]
- drm/i915/display: fix compiler warning about array overrun (Lyude Paul) [1944405]
- drm/i915: Fix crash in auto_retire (Lyude Paul) [1944405]
- drm/i915/overlay: Fix active retire callback alignment (Lyude Paul) [1944405]
- drm/i915: Read C0DRB3/C1DRB3 as 16 bits again (Lyude Paul) [1944405]
- drm/i915/gt: Fix a double free in gen8_preallocate_top_level_pdp (Lyude Paul) [1944405]
- drm/i915/dp: Use slow and wide link training for everything (Lyude Paul) [1944405]
- drm/i915: Avoid div-by-zero on gen2 (Lyude Paul) [1944405]
- drm/amd/display: Initialize attribute for hdcp_srm sysfs file (Lyude Paul) [1944405]
- drm/radeon/dpm: Disable sclk switching on Oland when two 4K 60Hz monitors are connected (Lyude Paul) [1944405]
- drm/radeon: Avoid power table parsing memory leaks (Lyude Paul) [1944405]
- drm/radeon: Fix off-by-one power_state index heap overwrite (Lyude Paul) [1944405]
- drm/amdgpu: Add mem sync flag for IB allocated by SA (Lyude Paul) [1944405]
- drm/amd/display: add handling for hdcp2 rx id list validation (Lyude Paul) [1944405]
- drm/amd/display: fixed divide by zero kernel crash during dsc enablement (Lyude Paul) [1944405]
- drm/amd/display: Force vsync flip when reconfiguring MPCC (Lyude Paul) [1944405]
- arm64: enable tlbi range instructions (Jeremy Linton) [1861872]
- arm64: tlb: Use the TLBI RANGE feature in arm64 (Jeremy Linton) [1861872]
- arm64: tlb: Detect the ARMv8.4 TLBI RANGE feature (Jeremy Linton) [1861872]
- arm64/cpufeature: Add remaining feature bits in ID_AA64ISAR0 register (Jeremy Linton) [1861872]
- arm64: tlbflush: Ensure start/end of address range are aligned to stride (Jeremy Linton) [1861872]
- arm64: Detect the ARMv8.4 TTL feature (Jeremy Linton) [1861872]
- arm64: tlbi: Set MAX_TLBI_OPS to PTRS_PER_PTE (Jeremy Linton) [1861872]

* Tue Aug 24 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-336.el8]
- bpf: Fix integer overflow involving bucket_size (Jiri Olsa) [1992588]
- bpf: Fix leakage due to insufficient speculative store bypass mitigation (Jiri Olsa) [1992588]
- bpf: Introduce BPF nospec instruction for mitigating Spectre v4 (Jiri Olsa) [1992588]
- bpf: Fix OOB read when printing XDP link fdinfo (Jiri Olsa) [1992588]
- bpf, test: fix NULL pointer dereference on invalid expected_attach_type (Jiri Olsa) [1992588]
- bpf: Fix tail_call_reachable rejection for interpreter when jit failed (Jiri Olsa) [1992588]
- bpf: Track subprog poke descriptors correctly and fix use-after-free (Jiri Olsa) [1992588]
- bpf: Fix null ptr deref with mixed tail calls and subprogs (Jiri Olsa) [1992588]
- bpf: Fix leakage under speculation on mispredicted branches (Jiri Olsa) [1992588]
- bpf: Set mac_len in bpf_skb_change_head (Jiri Olsa) [1992588]
- bpf: Prevent writable memory-mapping of read-only ringbuf pages (Jiri Olsa) [1992588]
- bpf: Fix alu32 const subreg bound tracking on bitwise operations (Jiri Olsa) [1992588]
- xsk: Fix broken Tx ring validation (Jiri Olsa) [1992588]
- xsk: Fix for xp_aligned_validate_desc() when len == chunk_size (Jiri Olsa) [1992588]
- bpf: link: Refuse non-O_RDWR flags in BPF_OBJ_GET (Jiri Olsa) [1992588]
- bpf: Refcount task stack in bpf_get_task_stack (Jiri Olsa) [1992588]
- bpf: Use NOP_ATOMIC5 instead of emit_nops(&prog, 5) for BPF_TRAMP_F_CALL_ORIG (Jiri Olsa) [1992588]
- selftest/bpf: Add a test to check trampoline freeing logic. (Jiri Olsa) [1992588]
- bpf: Fix fexit trampoline. (Jiri Olsa) [1992588]
- ftrace: Fix modify_ftrace_direct. (Jiri Olsa) [1992588]
- ftrace: Add a helper function to modify_ftrace_direct() to allow arch optimization (Jiri Olsa) [1992588]
- ftrace: Add helper find_direct_entry() to consolidate code (Jiri Olsa) [1992588]
- bpf: Fix truncation handling for mod32 dst reg wrt zero (Jiri Olsa) [1992588]
- bpf: Fix an unitialized value in bpf_iter (Jiri Olsa) [1992588]
- bpf_lru_list: Read double-checked variable once without lock (Jiri Olsa) [1992588]
- mt76: validate rx A-MSDU subframes (Íñigo Huguet) [1991459] {CVE-2020-24588 CVE-2020-26144}
- ath11k: Drop multicast fragments (Íñigo Huguet) [1991459] {CVE-2020-26145}
- ath11k: Clear the fragment cache during key install (Íñigo Huguet) [1991459] {CVE-2020-24587}
- ath10k: Validate first subframe of A-MSDU before processing the list (Íñigo Huguet) [1991459] {CVE-2020-24588 CVE-2020-26144}
- ath10k: Fix TKIP Michael MIC verification for PCIe (Íñigo Huguet) [1991459] {CVE-2020-26141}
- ath10k: drop MPDU which has discard flag set by firmware for SDIO (Íñigo Huguet) [1991459] {CVE-2020-24588}
- ath10k: drop fragments with multicast DA for SDIO (Íñigo Huguet) [1991459] {CVE-2020-26145}
- ath10k: drop fragments with multicast DA for PCIe (Íñigo Huguet) [1991459] {CVE-2020-26145}
- ath10k: add CCMP PN replay protection for fragmented frames for PCIe (Íñigo Huguet) [1991459]
- mac80211: extend protection against mixed key and fragment cache attacks (Íñigo Huguet) [1991459] {CVE-2020-24586 CVE-2020-24587}
- mac80211: do not accept/forward invalid EAPOL frames (Íñigo Huguet) [1991459] {CVE-2020-26139}
- mac80211: prevent attacks on TKIP/WEP as well (Íñigo Huguet) [1991459] {CVE-2020-26141}
- mac80211: check defrag PN against current frame (Íñigo Huguet) [1991459]
- mac80211: add fragment cache to sta_info (Íñigo Huguet) [1991459] {CVE-2020-24586 CVE-2020-24587}
- mac80211: drop A-MSDUs on old ciphers (Íñigo Huguet) [1991459] {CVE-2020-24588}
- cfg80211: mitigate A-MSDU aggregation attacks (Íñigo Huguet) [1991459] {CVE-2020-24588 CVE-2020-26144}
- mac80211: properly handle A-MSDUs that start with an RFC 1042 header (Íñigo Huguet) [1991459]
- mac80211: prevent mixed key and fragment cache attacks (Íñigo Huguet) [1991459] {CVE-2020-24586 CVE-2020-24587}
- mac80211: assure all fragments are encrypted (Íñigo Huguet) [1991459] {CVE-2020-26147}
- tipc: call tipc_wait_for_connect only when dlen is not 0 (Xin Long) [1989361]
- mptcp: remove tech preview warning (Florian Westphal) [1985120]
- tcp: consistently disable header prediction for mptcp (Florian Westphal) [1985120]
- selftests: mptcp: fix case multiple subflows limited by server (Florian Westphal) [1985120]
- selftests: mptcp: turn rp_filter off on each NIC (Florian Westphal) [1985120]
- selftests: mptcp: display proper reason to abort tests (Florian Westphal) [1985120]
- mptcp: properly account bulk freed memory (Florian Westphal) [1985120]
- mptcp: fix 'masking a bool' warning (Florian Westphal) [1985120]
- mptcp: refine mptcp_cleanup_rbuf (Florian Westphal) [1985120]
- mptcp: use fast lock for subflows when possible (Florian Westphal) [1985120]
- mptcp: avoid processing packet if a subflow reset (Florian Westphal) [1985120]
- mptcp: add sk parameter for mptcp_get_options (Florian Westphal) [1985120]
- mptcp: fix syncookie process if mptcp can not_accept new subflow (Florian Westphal) [1985120]
- mptcp: fix warning in __skb_flow_dissect() when do syn cookie for subflow join (Florian Westphal) [1985120]
- mptcp: avoid race on msk state changes (Florian Westphal) [1985120]
- mptcp: fix 32 bit DSN expansion (Florian Westphal) [1985120]
- mptcp: fix bad handling of 32 bit ack wrap-around (Florian Westphal) [1985120]
- tcp: parse mptcp options contained in reset packets (Florian Westphal) [1985120]
- ionic: count csum_none when offload enabled (Jonathan Toppins) [1991646]
- ionic: fix up dim accounting for tx and rx (Jonathan Toppins) [1991646]
- ionic: remove intr coalesce update from napi (Jonathan Toppins) [1991646]
- ionic: catch no ptp support earlier (Jonathan Toppins) [1991646]
- ionic: make all rx_mode work threadsafe (Jonathan Toppins) [1991646]
- dmaengine: idxd: Fix missing error code in idxd_cdev_open() (Jerry Snitselaar) [1990637]
- dmaengine: idxd: add missing dsa driver unregister (Jerry Snitselaar) [1990637]
- dmaengine: idxd: add engine 'struct device' missing bus type assignment (Jerry Snitselaar) [1990637]
- dmaengine: idxd: remove MSIX masking for interrupt handlers (Jerry Snitselaar) [1990637]
- dmaengine: idxd: Use cpu_feature_enabled() (Jerry Snitselaar) [1990637]
- dmaengine: idxd: enable SVA feature for IOMMU (Jerry Snitselaar) [1990637]
- dmagenine: idxd: Don't add portal offset in idxd_submit_desc (Jerry Snitselaar) [1990637]
- ethtool: strset: fix message length calculation (Balazs Nemeth) [1989003]
- net: add strict checks in netdev_name_node_alt_destroy() (Andrea Claudi) [1859038]
- net: rtnetlink: fix bugs in rtnl_alt_ifname() (Andrea Claudi) [1859038]
- net: rtnetlink: add linkprop commands to add and delete alternative ifnames (Andrea Claudi) [1859038]
- net: check all name nodes in __dev_alloc_name (Andrea Claudi) [1859038]
- net: fix a leak in register_netdevice() (Andrea Claudi) [1859038]
- tun: fix memory leak in error path (Andrea Claudi) [1859038]
- net: propagate errors correctly in register_netdevice() (Andrea Claudi) [1859038]
- net: introduce name_node struct to be used in hashlist (Andrea Claudi) [1859038]
- net: procfs: use index hashlist instead of name hashlist (Andrea Claudi) [1859038]
- configs: Enable CONFIG_CHELSIO_INLINE_CRYPTO (Raju Rangoju) [1961368]
- cxgb4/ch_ktls: Clear resources when pf4 device is removed (Raju Rangoju) [1961374]
- ch_ktls: Remove redundant variable result (Raju Rangoju) [1961374]
- ch_ktls: do not send snd_una update to TCB in middle (Raju Rangoju) [1961374]
- ch_ktls: tcb close causes tls connection failure (Raju Rangoju) [1961374]
- ch_ktls: fix device connection close (Raju Rangoju) [1961374]
- ch_ktls: Fix kernel panic (Raju Rangoju) [1961374]
- ch_ktls: fix enum-conversion warning (Raju Rangoju) [1961374]
- net: ethernet: chelsio: inline_crypto: Mundane typos fixed throughout the file chcr_ktls.c (Raju Rangoju) [1961374]
- ch_ipsec: Remove initialization of rxq related data (Raju Rangoju) [1961388]
- ch_ktls: fix build warning for ipv4-only config (Raju Rangoju) [1961374]
- ch_ktls: lock is not freed (Raju Rangoju) [1961374]
- ch_ktls: stop the txq if reaches threshold (Raju Rangoju) [1961374]
- ch_ktls: tcb update fails sometimes (Raju Rangoju) [1961374]
- ch_ktls/cxgb4: handle partial tag alone SKBs (Raju Rangoju) [1961374]
- ch_ktls: don't free skb before sending FIN (Raju Rangoju) [1961374]
- ch_ktls: packet handling prior to start marker (Raju Rangoju) [1961374]
- ch_ktls: Correction in middle record handling (Raju Rangoju) [1961374]
- ch_ktls: missing handling of header alone (Raju Rangoju) [1961374]
- ch_ktls: Correction in trimmed_len calculation (Raju Rangoju) [1961374]
- cxgb4/ch_ktls: creating skbs causes panic (Raju Rangoju) [1961374]
- ch_ktls: Update cheksum information (Raju Rangoju) [1961374]
- ch_ktls: Correction in finding correct length (Raju Rangoju) [1961374]
- cxgb4/ch_ktls: decrypted bit is not enough (Raju Rangoju) [1961374]
- cxgb4/ch_ipsec: Replace the module name to ch_ipsec from chcr (Raju Rangoju) [1961388]
- cxgb4/ch_ktls: ktls stats are added at port level (Raju Rangoju) [1961374]
- ch_ktls: Issue if connection offload fails (Raju Rangoju) [1961374]
- chelsio/chtls: Re-add dependencies on CHELSIO_T4 to fix modular CHELSIO_T4 (Raju Rangoju) [1961388]
- chelsio/chtls: CHELSIO_INLINE_CRYPTO should depend on CHELSIO_T4 (Raju Rangoju) [1961388]
- crypto: chelsio - fix minor indentation issue (Raju Rangoju) [1961368]
- crypto/chcr: move nic TLS functionality to drivers/net (Raju Rangoju) [1961368]
- cxgb4/ch_ipsec: Registering xfrmdev_ops with cxgb4 (Raju Rangoju) [1961388]
- crypto/chcr: Moving chelsio's inline ipsec functionality to /drivers/net (Raju Rangoju) [1961368]
- chelsio/chtls: separate chelsio tls driver from crypto driver (Raju Rangoju) [1961368]
- crypto: chelsio - Fix some pr_xxx messages (Raju Rangoju) [1961368]
- crypto: chelsio - Avoid some code duplication (Raju Rangoju) [1961368]
- crypto: drivers - set the flag CRYPTO_ALG_ALLOCATES_MEMORY (Raju Rangoju) [1961368]
- crypto: aead - remove useless setting of type flags (Raju Rangoju) [1961368]
- crypto: Replace zero-length array with flexible-array (Raju Rangoju) [1961368]
- [Crypto] treewide: replace '---help---' in Kconfig files with 'help' (Raju Rangoju) [1961368]
- Crypto/chcr: Checking cra_refcnt before unregistering the algorithms (Raju Rangoju) [1961368]
- Crypto/chcr: Calculate src and dst sg lengths separately for dma map (Raju Rangoju) [1961368]
- Crypto/chcr: Fixes a coccinile check error (Raju Rangoju) [1961368]
- Crypto/chcr: Fixes compilations warnings (Raju Rangoju) [1961368]
- crypto/chcr: IPV6 code needs to be in CONFIG_IPV6 (Raju Rangoju) [1961368]
- crypto: lib/sha1 - remove unnecessary includes of linux/cryptohash.h (Raju Rangoju) [1961368]
- Crypto/chcr: fix for hmac(sha) test fails (Raju Rangoju) [1961368]
- Crypto/chcr: fix for ccm(aes) failed test (Raju Rangoju) [1961368]
- Crypto/chcr: fix ctr, cbc, xts and rfc3686-ctr failed tests (Raju Rangoju) [1961368]
- crypto: chelsio - remove redundant assignment to variable error (Raju Rangoju) [1961368]
- chcr: Fix CPU hard lockup (Raju Rangoju) [1961368]
- crypto: remove CRYPTO_TFM_RES_BAD_KEY_LEN (Raju Rangoju) [1961368]
- crypto: chelsio - switch to skcipher API (Raju Rangoju) [1961368]
- crypto: chelsio - Remove VLA usage of skcipher (Raju Rangoju) [1961368]

* Mon Aug 23 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-335.el8]
- tracing: Fix bug in rb_per_cpu_empty() that might cause deadloop. (Chris von Recklinghausen) [1989485] {CVE-2021-3679}
- vmlinux.lds.h: Keep .ctors.* with .ctors (Jan Stancek) [1993208]
- spi: pxa2xx: Add support for Intel Alder Lake PCH-P (Steve Best) [1978463]
- bnxt_en: allow promiscuous mode for trusted VFs (Jonathan Toppins) [1730616]
- arm64: memory: Add missing brackets to untagged_addr() macro (Chris von Recklinghausen) [1955809]
- arm64: tags: Preserve tags for addresses translated via TTBR1 (Chris von Recklinghausen) [1955809]
- arm64: entry: Move ct_user_exit before any other exception (Chris von Recklinghausen) [1955809]
- arm64: memory: Implement __tag_set() as common function (Chris von Recklinghausen) [1955809]
- arm64: mm: Really fix sparse warning in untagged_addr() (Chris von Recklinghausen) [1955809]
- arm64: untag user pointers in access_ok and __uaccess_mask_ptr (Chris von Recklinghausen) [1955809]
- arm64/mm: fix variable 'tag' set but not used (Chris von Recklinghausen) [1955809]
- arm64: entry: SP Alignment Fault doesn't write to FAR_EL1 (Chris von Recklinghausen) [1955809]
- arm64: compat: Add separate CP15 trapping hook (Chris von Recklinghausen) [1955809]
- arm64: don't restore GPRs when context tracking (Chris von Recklinghausen) [1955809]

* Fri Aug 20 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-334.el8]
- bareudp: Fix invalid read beyond skb's linear data (Guillaume Nault) [1990938]
- perf/x86/amd: Don't touch the AMD64_EVENTSEL_HOSTONLY bit inside the guest (Michael Petlan) [1990695]
- net: dcb: Accept RTM_GETDCB messages carrying set-like DCB commands (Balazs Nemeth) [1956825]
- net: dcb: Validate netlink message in DCB handler (Balazs Nemeth) [1956825]
- xfrm: Fix RCU vs hash_resize_mutex lock inversion (Sabrina Dubroca) [1988405]
- Revert "xfrm: policy: Read seqcount outside of rcu-read side in xfrm_policy_lookup_bytype" (Sabrina Dubroca) [1988405]
- xfrm: policy: Read seqcount outside of rcu-read side in xfrm_policy_lookup_bytype (Sabrina Dubroca) [1988405]
- [s390] s390/AP: support new dynamic AP bus size limit (Claudio Imbrenda) [1974581]
- net: sched: act_mirred: Reset ct info when mirror/redirect skb (Hangbin Liu) [1980532]
- ucounts: Move max_time_namespace according to ucount_type (Alex Gladkov) [1982954]
- perf vendor events power10: Adds 24x7 nest metric events for power10 platform (Diego Domingos) [1946650]
- perf/core: fix backport of PERF_SAMPLE_WEIGHT_STRUCT (Diego Domingos) [1946650]
- perf/core: Add support for PERF_SAMPLE_CODE_PAGE_SIZE (Diego Domingos) [1946650]
- perf vendor events powerpc: Fix eventcode of power10 JSON events (Diego Domingos) [1946650]
- perf vendor events: Initial JSON/events list for power10 platform (Diego Domingos) [1946650]
- powerpc/perf: Fix sampled instruction type for larx/stcx (Diego Domingos) [1946650]
- powerpc/perf: Fix the threshold event selection for memory events in power10 (Diego Domingos) [1946650]
- perf sort: Display sort dimension p_stage_cyc only on supported archs (Diego Domingos) [1946650]
- perf tools: Support pipeline stage cycles for powerpc (Diego Domingos) [1946650]
- perf powerpc: Add support for PERF_SAMPLE_WEIGHT_STRUCT (Diego Domingos) [1946650]
- perf sort: Add dynamic headers for perf report columns (Diego Domingos) [1946650]
- powerpc/perf: Expose processor pipeline stage cycles using PERF_SAMPLE_WEIGHT_STRUCT (Diego Domingos) [1946650]
- Documentation/admin-guide: kernel-parameters: fix "disable_ddw" wording (Diego Domingos) [1946650]
- powerpc/perf: Support PERF_SAMPLE_DATA_PAGE_SIZE (Diego Domingos) [1946650]
- perf/core: Add PERF_SAMPLE_DATA_PAGE_SIZE (Diego Domingos) [1946650]
- powerpc/perf: Infrastructure to support checking of attr.config* (Diego Domingos) [1946650]
- powerpc/perf: Add platform specific check_attr_config (Diego Domingos) [1946650]
- ice: add support for auxiliary input/output pins (Jonathan Toppins) [1956913]
- ice: enable transmit timestamps for E810 devices (Jonathan Toppins) [1944818]
- ice: enable receive hardware timestamping (Jonathan Toppins) [1944818]
- ice: report the PTP clock index in ethtool .get_ts_info (Jonathan Toppins) [1944818]
- ice: register 1588 PTP clock device object for E810 devices (Jonathan Toppins) [1944818]
- ice: add low level PTP clock access functions (Jonathan Toppins) [1944818]
- ice: add support for set/get of driver-stored firmware parameters (Jonathan Toppins) [1944818]
- ice: process 1588 PTP capabilities during initialization (Jonathan Toppins) [1944818]
- ice: add support for sideband messages (Jonathan Toppins) [1944818]

* Wed Aug 18 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-333.el8]
- bnxt_en: Fix static checker warning in bnxt_fw_reset_task() (Jonathan Toppins) [1989274]
- bnxt_en: Check abort error state in bnxt_half_open_nic() (Jonathan Toppins) [1989274]
- bnxt_en: fix error path of FW reset (Jonathan Toppins) [1989274]
- bnxt_en: Add missing check for BNXT_STATE_ABORT_ERR in bnxt_fw_rset_task() (Jonathan Toppins) [1989274]
- bnxt_en: Refresh RoCE capabilities in bnxt_ulp_probe() (Jonathan Toppins) [1989274]
- bnxt_en: reject ETS settings that will starve a TC (Jonathan Toppins) [1989274]
- bnxt_en: don't disable an already disabled PCI device (Jonathan Toppins) [1989274]
- bnxt_en: Remove the read of BNXT_FW_RESET_INPROG_REG after firmware reset. (Jonathan Toppins) [1989274]
- i40e: Fix log TC creation failure when max num of queues is exceeded (Stefan Assmann) [1920274]
- i40e: Fix queue-to-TC mapping on Tx (Stefan Assmann) [1920274]
- i40e: Add additional info to PHY type error (Stefan Assmann) [1920274]
- i40e: Fix firmware LLDP agent related warning (Stefan Assmann) [1920274]
- i40e: Fix logic of disabling queues (Stefan Assmann) [1920274]
- i40e: add support for PTP external synchronization clock (Stefan Assmann) [1920274]
- i40e: improve locking of mac_filter_hash (Stefan Assmann) [1920274]
- i40e: Fix missing rtnl locking when setting up pf switch (Stefan Assmann) [1920274]
- i40e: fix PTP on 5Gb links (Stefan Assmann) [1920274]
- i40e: Fix autoneg disabling for non-10GBaseT links (Stefan Assmann) [1920274]
- i40e: Fix error handling in i40e_vsi_open (Stefan Assmann) [1920274]
- intel: Remove rcu_read_lock() around XDP program invocation (Stefan Assmann) [1920274]
- i40e: clean up packet type lookup table (Stefan Assmann) [1920274]
- i40e: add correct exception tracing for XDP (Stefan Assmann) [1920274]
- i40e: Remove LLDP frame filters (Stefan Assmann) [1920274]
- i40e: Fix PHY type identifiers for 2.5G and 5G adapters (Stefan Assmann) [1920274]
- i40e: Fix use-after-free in i40e_client_subtask() (Stefan Assmann) [1920274]
- i40e: fix broken XDP support (Stefan Assmann) [1920274]
- i40e: refactor repeated link state reporting code (Stefan Assmann) [1920274]
- i40e: optimize for XDP_REDIRECT in xsk path (Stefan Assmann) [1920274]
- i40e: fix the panic when running bpf in xdpdrv mode (Stefan Assmann) [1920274]
- i40e: Fix sparse warning: missing error code 'err' (Stefan Assmann) [1920274]
- i40e: Fix sparse error: 'vsi->netdev' could be null (Stefan Assmann) [1920274]
- i40e: Fix sparse error: uninitialized symbol 'ring' (Stefan Assmann) [1920274]
- i40e: Fix sparse errors in i40e_txrx.c (Stefan Assmann) [1920274]
- i40e: Fix display statistics for veb_tc (Stefan Assmann) [1920274]
- i40e: fix receiving of single packets in xsk zero-copy mode (Stefan Assmann) [1920274]
- i40e: Fix inconsistent indenting (Stefan Assmann) [1920274]
- i40e: Fix oops at i40e_rebuild() (Stefan Assmann) [1920274]
- i40e: Fix kernel oops when i40e driver removes VF's (Stefan Assmann) [1920274]
- i40e: Added Asym_Pause to supported link modes (Stefan Assmann) [1920274]
- net: i40e: remove repeated words (Stefan Assmann) [1920274]
- bpf, devmap: Move drop error path to devmap for XDP_REDIRECT (Stefan Assmann) [1920274]
- intel: clean up mismatched header comments (Stefan Assmann) [1920274]
- intel: Update drivers to use ethtool_sprintf (Stefan Assmann) [1920274]
- i40e: move headroom initialization to i40e_configure_rx_ring (Stefan Assmann) [1920274]
- i40e: Fix endianness conversions (Stefan Assmann) [1920274]
- i40e: Fix add TC filter for IPv6 (Stefan Assmann) [1920274]
- i40e: Fix addition of RX filters after enabling FW LLDP agent (Stefan Assmann) [1920274]
- i40e: Fix overwriting flow control settings during driver loading (Stefan Assmann) [1920274]
- i40e: Add zero-initialization of AQ command structures (Stefan Assmann) [1920274]
- i40e: Fix memory leak in i40e_probe (Stefan Assmann) [1920274]
- i40e: Fix flow for IPv6 next header (extension header) (Stefan Assmann) [1920274]
- i40e: Fix incorrect argument in call to ipv6_addr_any() (Stefan Assmann) [1920274]
- i40e: store the result of i40e_rx_offset() onto i40e_ring (Stefan Assmann) [1920274]
- i40e: Simplify the do-while allocation loop (Stefan Assmann) [1920274]
- i40e: adjust i40e_is_non_eop (Stefan Assmann) [1920274]
- i40e: drop misleading function comments (Stefan Assmann) [1920274]
- i40e: drop redundant check when setting xdp prog (Stefan Assmann) [1920274]
- i40e: remove the useless value assignment in i40e_clean_adminq_subtask (Stefan Assmann) [1920274]
- i40e: VLAN field for flow director (Stefan Assmann) [1920274]
- i40e: Add flow director support for IPv6 (Stefan Assmann) [1920274]
- i40e: Add EEE status getting & setting implementation (Stefan Assmann) [1920274]
- i40e: Fix uninitialized variable mfs_max (Stefan Assmann) [1920274]
- i40e: Add netlink callbacks support for software based DCB (Stefan Assmann) [1920274]
- i40e: Add init and default config of software based DCB (Stefan Assmann) [1920274]
- i40e: Add hardware configuration for software based DCB (Stefan Assmann) [1920274]
- i40e: Log error for oversized MTU on device (Stefan Assmann) [1920274]
- i40e: consolidate handling of XDP program actions (Stefan Assmann) [1920274]
- i40e: remove the redundant buffer info updates (Stefan Assmann) [1920274]
- i40e: remove unnecessary cleaned_count updates (Stefan Assmann) [1920274]
- i40e: remove unnecessary memory writes of the next to clean pointer (Stefan Assmann) [1920274]
- i40e: Use batched xsk Tx interfaces to increase performance (Stefan Assmann) [1920274]
- i40e: convert to new udp_tunnel infrastructure (Stefan Assmann) [1920274]
- netfilter: nf_tables: skip module reference count bump on object updates (Fernando Fernandez Mancera) [1944487]
- netfilter: nf_tables: fix unexpected EOPNOTSUPP error (Fernando Fernandez Mancera) [1944487]
- netfilter: nf_tables: Fix an Oops in nf_tables_updobj() error handling (Fernando Fernandez Mancera) [1944487]
- netfilter: nf_tables: fix possible null-pointer dereference in object update (Fernando Fernandez Mancera) [1944487]
- netfilter: nft_quota: add quota object update support (Fernando Fernandez Mancera) [1944487]
- netfilter: nf_tables: Introduce stateful object update operation (Fernando Fernandez Mancera) [1944487]
- cifs: retry lookup and readdir when EAGAIN is returned. (Ronnie Sahlberg) [1972411]
- netfilter: nf_tables: Fix dereference of null pointer flow (Florian Westphal) [1985087]
- netfilter: nf_tables: memleak in hw offload abort path (Florian Westphal) [1985087]
- netfilter: nft_tproxy: restrict support to TCP and UDP transport protocols (Florian Westphal) [1985087]
- netfilter: synproxy: Fix out of bounds when parsing TCP options (Florian Westphal) [1985087]
- netfilter: nfnetlink_cthelper: hit EBUSY on updates if size mismatches (Florian Westphal) [1985087]
- ipvs: ignore IP_VS_SVC_F_HASHED flag when adding service (Florian Westphal) [1985087]
- netfilter: nftables: avoid overflows in nft_hash_buckets() (Florian Westphal) [1985087]
- netfilter: nfnetlink_osf: Fix a missing skb_header_pointer() NULL check (Florian Westphal) [1985087]
- netfilter: nf_tables_offload: check FLOW_DISSECTOR_KEY_BASIC in VLAN transfer logic (Florian Westphal) [1985087]
- netfilter: nftables_offload: special ethertype handling for VLAN (Florian Westphal) [1985087]
- netfilter: nftables_offload: VLAN id needs host byteorder in flow dissector (Florian Westphal) [1985087]
- netfilter: nft_payload: fix C-VLAN offload support (Florian Westphal) [1985087]
- ipvs: allow connection reuse for unconfirmed conntrack (Florian Westphal) [1985087]
- net: fix GRO skb truesize update (Paolo Abeni) [1987391]
- sk_buff: avoid potentially clearing 'slow_gro' field (Paolo Abeni) [1987391]
- veth: use skb_prepare_for_gro() (Paolo Abeni) [1987391]
- skbuff: allow 'slow_gro' for skb carring sock reference (Paolo Abeni) [1987391]
- net: optimize GRO for the common case. (Paolo Abeni) [1987391]
- sk_buff: track extension status in slow_gro (Paolo Abeni) [1987391]
- sk_buff: track dst status in slow_gro (Paolo Abeni) [1987391]
- sk_buff: introduce 'slow_gro' flags (Paolo Abeni) [1987391]
- skbuff: Fix build with SKB extensions disabled (Paolo Abeni) [1987391]
- skbuff: Release nfct refcount on napi stolen or re-used skbs (Paolo Abeni) [1987391]
- selftests: net: veth: add tests for set_channel (Paolo Abeni) [1987391]
- veth: create by default nr_possible_cpus queues (Paolo Abeni) [1987391]
- veth: implement support for set_channel ethtool op (Paolo Abeni) [1987391]
- veth: factor out initialization helper (Paolo Abeni) [1987391]
- veth: always report zero combined channels (Paolo Abeni) [1987391]
- veth: Implement ethtool's get_channelis() callback (Paolo Abeni) [1987391]
- net: add GSO UDP L4 and GSO fraglists to the list of software-backed types (Paolo Abeni) [1987391]
- ice: Support RSS configure removal for AVF (Jonathan Toppins) [1946726]
- ice: Enable RSS configure for AVF (Jonathan Toppins) [1946726]
- ice: Add helper function to get the VF's VSI (Jonathan Toppins) [1946726]
- ice: remove redundant assignment to pointer vsi (Jonathan Toppins) [1946726]
- ice: Advertise virtchnl UDP segmentation offload capability (Jonathan Toppins) [1946726]
- ice: Allow ignoring opcodes on specific VF (Jonathan Toppins) [1946726]
- ice: warn about potentially malicious VFs (Jonathan Toppins) [1946726]
- ice: Consolidate VSI state and flags (Jonathan Toppins) [1946726]
- ice: Refactor ice_set/get_rss into LUT and key specific functions (Jonathan Toppins) [1946726]
- ice: Refactor get/set RSS LUT to use struct parameter (Jonathan Toppins) [1946726]
- ice: Change ice_vsi_setup_q_map() to not depend on RSS (Jonathan Toppins) [1946726]
- ice: Check FDIR program status for AVF (Jonathan Toppins) [1946726]
- ice: Add more FDIR filter type for AVF (Jonathan Toppins) [1946726]
- ice: Add GTPU FDIR filter for AVF (Jonathan Toppins) [1946726]
- ice: Add non-IP Layer2 protocol FDIR filter for AVF (Jonathan Toppins) [1946726]
- ice: Add new actions support for VF FDIR (Jonathan Toppins) [1946726]
- ice: Add FDIR pattern action parser for VF (Jonathan Toppins) [1946726]
- ice: Enable FDIR Configure for AVF (Jonathan Toppins) [1946726]
- ice: Add support for per VF ctrl VSI enabling (Jonathan Toppins) [1946726]
- ice: Enhanced IPv4 and IPv6 flow filter (Jonathan Toppins) [1946726]
- ice: Support to separate GTP-U uplink and downlink (Jonathan Toppins) [1946726]
- ice: Add more advanced protocol support in flow filter (Jonathan Toppins) [1946726]
- ice: Support non word aligned input set field (Jonathan Toppins) [1946726]
- ice: Add more basic protocol support for flow filter (Jonathan Toppins) [1946726]
- sctp: move the active_key update after sh_keys is added (Xin Long) [1986966]
- sctp: fix return value check in __sctp_rcv_asconf_lookup (Xin Long) [1986966]
- sctp: delete addr based on sin6_scope_id (Xin Long) [1986966]
- sctp: update active_key for asoc when old key is being replaced (Xin Long) [1986966]
- sctp: move 198 addresses from unusable to private scope (Xin Long) [1986966]
- sctp: add param size validation for SCTP_PARAM_SET_PRIMARY (Xin Long) [1986966]
- sctp: validate chunk size in __rcv_asconf_lookup (Xin Long) [1986966]
- sctp: add size validation when walking chunks (Xin Long) [1986966]
- sctp: validate from_addr_param return (Xin Long) [1986966]
- sctp: fix the proc_handler for sysctl encap_port (Xin Long) [1986966]
- sctp: add the missing setting for asoc encap_port (Xin Long) [1986966]
- sctp: fix a SCTP_MIB_CURRESTAB leak in sctp_sf_do_dupcook_b (Xin Long) [1986966]
- sctp: Fix out-of-bounds warning in sctp_process_asconf_param() (Xin Long) [1986966]
- sctp: Fix COMM_LOST/CANT_STR_ASSOC err reporting on big-endian platforms (Xin Long) [1986966]
- bonding: allow nesting of bonding device (Antoine Tenart) [1989099]
- bonding: avoid adding slave device with IFF_MASTER flag (Antoine Tenart) [1989099]
- ice: don't remove netdev->dev_addr from uc sync list (Ken Cox) [1873969 1961018]
- ice: Stop processing VF messages during teardown (Ken Cox) [1986451]
- ice: Prevent probing virtual functions (Ken Cox) [1952810]
- ima: extend boot_aggregate with kernel measurements (Bruno Meneguele) [1977422]
- selftest/bpf: Verifier tests for var-off access (Jiri Olsa) [1960944] {CVE-2021-29155}
- selftest/bpf: Adjust expected verifier errors (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: No need to simulate speculative domain for immediates (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Fix mask direction swap upon off reg sign change (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Wrap aux data inside bpf_sanitize_info container (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Fix pointer arithmetic mask tightening under state pruning (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Fix leakage of uninitialized bpf stack under speculation (Jiri Olsa) [1960944 1958070] {CVE-2021-29155 CVE-2021-31829}
- bpf: Fix masking negation logic upon negative dst register (Jiri Olsa) [1960944 1958070] {CVE-2021-29155 CVE-2021-31829}
- bpf: verifier: Allocate idmap scratch in verifier env (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Tighten speculative pointer arithmetic mask (Jiri Olsa) [1960944 1972496] {CVE-2021-29155 CVE-2021-33200}
- bpf: Move sanitize_val_alu out of op switch (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Refactor and streamline bounds check into helper (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Allow variable-offset stack access (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Improve verifier error messages for users (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Rework ptr_limit into alu_limit and add common error path (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Ensure off_reg has no mixed signed bounds for all types (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Move off_reg into sanitize_ptr_alu (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Use correct permission flag for mixed signed bounds arithmetic (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Add sanity check for upper ptr_limit (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Simplify alu_limit masking for pointer arithmetic (Jiri Olsa) [1960944] {CVE-2021-29155}
- bpf: Fix off-by-one for area size in creating mask to left (Jiri Olsa) [1960944] {CVE-2021-29155}
- Documentation/x86: Add ratelimit in buslock.rst (Prarit Bhargava) [1948048]
- Documentation/admin-guide: Add bus lock ratelimit (Prarit Bhargava) [1948048]
- x86/bus_lock: Set rate limit for bus lock (Prarit Bhargava) [1948048]
- Documentation/x86: Add buslock.rst (Prarit Bhargava) [1948048]
- [s390] net/smc: Ensure correct state of the socket in send path (Claudio Imbrenda) [1731026]
- [s390] net/smc: Fix ENODATA tests in smc_nl_get_fback_stats() (Claudio Imbrenda) [1731026]
- [s390] net/smc: Make SMC statistics network namespace aware (Claudio Imbrenda) [1731026]
- [s390] net/smc: Add netlink support for SMC fallback statistics (Claudio Imbrenda) [1731026]
- [s390] net/smc: Add netlink support for SMC statistics (Claudio Imbrenda) [1731026]
- [s390] net/smc: Add SMC statistics support (Claudio Imbrenda) [1731026]
- [s390] s390/ap: Fix hanging ioctl caused by wrong msg counter (Claudio Imbrenda) [1984762]
- KVM: PPC: Book3S: Fix H_RTAS rets buffer overflow (Jon Maloy) [1988226] {CVE-2021-37576}
- NFSv4: Fix an Oops in pnfs_mark_request_commit() when doing O_DIRECT (Benjamin Coddington) [1983793]
- selftests/powerpc: EBB selftest for MMCR0 control for PMU SPRs in ISA v3.1 (Desnes A. Nunes do Rosario) [1991753]
- selftests/powerpc: Fix "no_handler" EBB selftest (Desnes A. Nunes do Rosario) [1991753]
- powerpc/perf: Fix crash in perf_instruction_pointer() when ppmu is not set (Desnes A. Nunes do Rosario) [1991753]
- powerpc/pmu: Make the generic compat PMU use the architected events (Desnes A. Nunes do Rosario) [1991753]
- perf script python: Fix buffer size to report iregs in perf script (Desnes A. Nunes do Rosario) [1991753]
- ceph: reduce contention in ceph_check_delayed_caps() (Jeff Layton) [1953430]

* Mon Aug 16 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-332.el8]
- net: mac802154: Fix general protection fault (Chris von Recklinghausen) [1984571] {CVE-2021-3659}
- Bluetooth: fix the erroneous flush_work() order (Chris von Recklinghausen) [1964559] {CVE-2021-3564}
- Bluetooth: use correct lock to prevent UAF of hdev object (Chris von Recklinghausen) [1968214] {CVE-2021-3573}
- usb: ehci: Prevent missed ehci interrupts with edge-triggered MSI (Torez Smith) [1972139]
- usb: ehci: do not initialise static variables (Torez Smith) [1972139]
- usb: host: move EH SINGLE_STEP_SET_FEATURE implementation to core (Torez Smith) [1972139]
- USB: ehci: drop workaround for forced irq threading (Torez Smith) [1972139]
- usb: ehci: add spurious flag to disable overcurrent checking (Torez Smith) [1972139]
- perf test: Handle fd gaps in test__dso_data_reopen (Michael Petlan) [1871785]
- tty: vt: always invoke vc->vc_sw->con_resize callback (Maxim Levitsky) [1957611]
- iavf: fix locking of critical sections (Stefan Assmann) [1975245]
- iavf: do not override the adapter state in the watchdog task (Stefan Assmann) [1975245]
- ixgbe: Fix packet corruption due to missing DMA sync (Ken Cox) [1920269]
- ixgbe: Fix an error handling path in 'ixgbe_probe()' (Ken Cox) [1920269]
- intel: Remove rcu_read_lock() around XDP program invocation (Ken Cox) [1920269]
- ixgbe: add correct exception tracing for XDP (Ken Cox) [1920269]
- ixgbe: Fix out-bounds warning in ixgbe_host_interface_command() (Ken Cox) [1920269]
- ixgbe: reduce checker warnings (Ken Cox) [1920269]
- ixgbe: use checker safe conversions (Ken Cox) [1920269]
- ixgbe: fix large MTU request from VF (Ken Cox) [1920269]
- net: ethernet: intel: Fix a typo in the file ixgbe_dcb_nl.c (Ken Cox) [1920269]
- net: intel: Remove unused function pointer typedef ixgbe_mc_addr_itr (Ken Cox) [1920269]
- ixgbe: Support external GBE SerDes PHY BCM54616s (Ken Cox) [1920269]
- ixgbe: fix unbalanced device enable/disable in suspend/resume (Ken Cox) [1920269]
- ixgbe: Fix NULL pointer dereference in ethtool loopback test (Ken Cox) [1920269]
- ixgbe: Fix fall-through warnings for Clang (Ken Cox) [1920269]
- intel: clean up mismatched header comments (Ken Cox) [1920269]
- bpf, devmap: Move drop error path to devmap for XDP_REDIRECT (Ken Cox) [1920269]
- intel: Update drivers to use ethtool_sprintf (Ken Cox) [1920269]
- ixgbe: optimize for XDP_REDIRECT in xsk path (Ken Cox) [1920269]
- ixgbe: move headroom initialization to ixgbe_configure_rx_ring (Ken Cox) [1920269]
- ixgbe: Fix memleak in ixgbe_configure_clsu32 (Ken Cox) [1920269]
- ixgbe: fail to create xfrm offload of IPsec tunnel mode SA (Ken Cox) [1920269]
- ixgbe: store the result of ixgbe_rx_offset() onto ixgbe_ring (Ken Cox) [1920269]
- net: ixgbe: use skb_csum_is_sctp instead of protocol check (Ken Cox) [1920269]
- ixgbe: avoid premature Rx buffer reuse (Ken Cox) [1920269]
- net: remove unneeded break (Ken Cox) [1920269]
- ixgbe: add pause frame stats (Ken Cox) [1920269]
- iavf: Set RSS LUT and key in reset handle path (Ken Cox) [1910853]
- [netdrv] chelsio: Replace zero-length array with flexible-array member (Raju Rangoju) [1955208]
- cxgb4: avoid collecting SGE_QBASE regs during traffic (Raju Rangoju) [1955208]
- cxgb4: collect serial config version from register (Raju Rangoju) [1955208]
- cxgb4: remove unused vpd_cap_addr (Raju Rangoju) [1955208]
- cxgb4: remove bogus CHELSIO_VPD_UNIQUE_ID constant (Raju Rangoju) [1955208]
- cxgb4: Assign boolean values to a bool variable (Raju Rangoju) [1955208]
- cxgb4: enable interrupt based Tx completions for T5 (Raju Rangoju) [1955208]
- cxgb4: fix the panic caused by non smac rewrite (Raju Rangoju) [1955208]
- cxgb4: Fix the -Wmisleading-indentation warning (Raju Rangoju) [1955208]
- cxgb4: set up filter action after rewrites (Raju Rangoju) [1955208]
- cxgb4: handle 4-tuple PEDIT to NAT mode translation (Raju Rangoju) [1955208]
- [netdrv] net: rename flow_action_hw_stats_types* -> flow_action_hw_stats* (Raju Rangoju) [1955208]
- net: cxbg4: Remove pointless in_interrupt() check (Raju Rangoju) [1955208]
- cxgb4: Avoid log flood (Raju Rangoju) [1955208]
- cxgb4: fix memory leak during module unload (Raju Rangoju) [1955208]
- cxgb4: Fix offset when clearing filter byte counters (Raju Rangoju) [1955208]
- cxgb4: add error handlers to LE intr_handler (Raju Rangoju) [1955208]
- cxgb4: insert IPv6 filter rules in next free region (Raju Rangoju) [1955208]
- cxgb4: Fix race between loopback and normal Tx path (Raju Rangoju) [1955208]
- cxgb4: Fix work request size calculation for loopback test (Raju Rangoju) [1955208]
- cxgb4: add TC-MATCHALL IPv6 support (Raju Rangoju) [1955208]
- cxgb4: fix extracting IP addresses in TC-FLOWER rules (Raju Rangoju) [1955208]
- cxgb4: fix check for running offline ethtool selftest (Raju Rangoju) [1955208]
- cxgb4: add loopback ethtool self-test (Raju Rangoju) [1955208]
- net: cxgb4: reject unsupported coalescing params (Raju Rangoju) [1955208]
- cxgb4: use eth_zero_addr() to clear mac address (Raju Rangoju) [1955208]
- cxgb4: add missing release on skb in uld_send() (Raju Rangoju) [1955208]
- cxgb4: convert to new udp_tunnel_nic infra (Raju Rangoju) [1955208]
- cxgb4: fix all-mask IP address comparison (Raju Rangoju) [1955208]
- cxgb4: add main VI to mirror VI config replication (Raju Rangoju) [1955208]
- cxgb4: add support for mirror Rxqs (Raju Rangoju) [1955208]
- cxgb4: add mirror action to TC-MATCHALL offload (Raju Rangoju) [1955208]
- net: cxgb4: fix return error value in t4_prep_fw (Raju Rangoju) [1955208]
- cxgb4: move device dump arrays in header to C file (Raju Rangoju) [1955208]
- cxgb4: always sync access when flashing PHY firmware (Raju Rangoju) [1955208]
- cxgb4: update kernel-doc line comments (Raju Rangoju) [1955208]
- cxgb4: fix set but unused variable when DCB is disabled (Raju Rangoju) [1955208]
- cxgb4: move DCB version extern to header file (Raju Rangoju) [1955208]
- cxgb4: remove cast when saving IPv4 partial checksum (Raju Rangoju) [1955208]
- cxgb4: fix SGE queue dump destination buffer context (Raju Rangoju) [1955208]
- cxgb4: use correct type for all-mask IP address comparison (Raju Rangoju) [1955208]
- cxgb4: fix endian conversions for L4 ports in filters (Raju Rangoju) [1955208]
- cxgb4: parse TC-U32 key values and masks natively (Raju Rangoju) [1955208]
- cxgb4: use unaligned conversion for fetching timestamp (Raju Rangoju) [1955208]
- cxgb4: move PTP lock and unlock to caller in Tx path (Raju Rangoju) [1955208]
- cxgb4: move handling L2T ARP failures to caller (Raju Rangoju) [1955208]
- cxgb4: Use struct_size() helper (Raju Rangoju) [1955208]
- cxgb4: add action to steer flows to specific Rxq (Raju Rangoju) [1955208]
- cxgb4: add support to fetch ethtool n-tuple filters (Raju Rangoju) [1955208]
- cxgb4: add ethtool n-tuple filter deletion (Raju Rangoju) [1955208]
- cxgb4: add ethtool n-tuple filter insertion (Raju Rangoju) [1955208]
- [netdrv] flow_offload: check for basic action hw stats type (Raju Rangoju) [1955208]
- cxgb4: add skeleton for ethtool n-tuple filters (Raju Rangoju) [1955208]
- cxgb4: add support to read serial flash (Raju Rangoju) [1955208]
- cxgb4: add support to flash boot cfg image (Raju Rangoju) [1955208]
- cxgb4: add support to flash boot image (Raju Rangoju) [1955208]
- cxgb4: add support to flash PHY image (Raju Rangoju) [1955208]
- cxgb4: update set_flash to flash different images (Raju Rangoju) [1955208]
- cxgb4: Use kfree() instead kvfree() where appropriate (Raju Rangoju) [1955208]
- cxgb4: Use pM format specifier for MAC addresses (Raju Rangoju) [1955208]
- net: sock: fix in-kernel mark setting (Alexander Aring) [1509204]
- sock: Reset dst when changing sk_mark via setsockopt (Alexander Aring) [1509204]
- fs: dlm: fix mark setting deadlock (Alexander Aring) [1509204]
- fs: dlm: fix mark per nodeid setting (Alexander Aring) [1509204]
- fs: dlm: remove lock dependency warning (Alexander Aring) [1509204]
- fs: dlm: set skb mark per peer socket (Alexander Aring) [1509204]
- fs: dlm: set skb mark for listen socket (Alexander Aring) [1509204]
- net: sock: add sock_set_mark (Alexander Aring) [1509204]
- Bluetooth: btusb: Add support for GarfieldPeak controller (Gopal Tiwari) [1959110]
- can: gw: synchronize rcu operations before removing gw job entry (Balazs Nemeth) [1986334]
- can: bcm: fix infoleak in struct bcm_msg_head (Balazs Nemeth) [1986334]
- can: af_can: prevent potential access of uninitialized member in canfd_rcv() (Balazs Nemeth) [1956730]
- can: af_can: prevent potential access of uninitialized member in can_rcv() (Balazs Nemeth) [1956730]
- can: proc: can_remove_proc(): silence remove_proc_entry warning (Balazs Nemeth) [1956730]
- cifs: add missing parsing of backupuid (Ronnie Sahlberg) [1987126]
- cifs: use helpers when parsing uid/gid mount options and validate them (Ronnie Sahlberg) [1987126]
- kernfs: dont call d_splice_alias() under kernfs node lock (Ian Kent) [1939133]
- kernfs: use i_lock to protect concurrent inode updates (Ian Kent) [1939133]
- kernfs: switch kernfs to use an rwsem (Ian Kent) [1939133]
- kernfs: use VFS negative dentry caching (Ian Kent) [1939133]
- kernfs: add a revision to identify directory node changes (Ian Kent) [1939133]
- kernfs: move revalidate to be near lookup (Ian Kent) [1939133]

* Thu Aug 12 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-331.el8]
- mlxsw: spectrum_mr: Update egress RIF list before route's action (Ivan Vecera) [1941938]
- selftests: mlxsw: Fix mausezahn invocation in ERSPAN scale test (Ivan Vecera) [1941938]
- selftests: mlxsw: Increase the tolerance of backlog buildup (Ivan Vecera) [1941938]
- selftests: mlxsw: Return correct error code in resource scale tests (Ivan Vecera) [1941938]
- selftests: mlxsw: Remove a redundant if statement in tc_flower_scale test (Ivan Vecera) [1941938]
- selftests: mlxsw: Remove a redundant if statement in port_scale test (Ivan Vecera) [1941938]
- selftests: mlxsw: sch_red_ets: Test proper counter cleaning in ETS (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Index future FIFOs by band number (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Allocate child qdiscs dynamically (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Guard all qdisc accesses with a lock (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Track children per qdisc (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Promote backlog reduction to mlxsw_sp_qdisc_destroy() (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Track tclass_num as int, not u8 (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Drop an always-true condition (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Simplify mlxsw_sp_qdisc_compare() (Ivan Vecera) [1941938]
- mlxsw: spectrum_qdisc: Drop one argument from check_params callback (Ivan Vecera) [1941938]
- mlxsw: core: Remove critical trip points from thermal zones (Ivan Vecera) [1941938]
- selftests: mlxsw: Test vetoing of double sampling (Ivan Vecera) [1941938]
- mlxsw: spectrum: Veto sampling if already enabled on port (Ivan Vecera) [1941938]
- selftests: mlxsw: Test matchall failure with protocol match (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Perform priority checks earlier (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Convert if statements to a switch statement (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Perform protocol check earlier (Ivan Vecera) [1941938]
- selftests: forwarding: vxlan_bridge_1d: Add more ECN decap test cases (Ivan Vecera) [1941938]
- mlxsw: spectrum: Fix ECN marking in tunnel decapsulation (Ivan Vecera) [1941938]
- selftests: net: forwarding: Fix a typo (Ivan Vecera) [1941938]
- selftests: mlxsw: spectrum-2: Remove q_in_vni_veto test (Ivan Vecera) [1941938]
- selftests: forwarding: Add test for dual VxLAN bridge (Ivan Vecera) [1941938]
- mlxsw: Allow 802.1d and .1ad VxLAN bridges to coexist on Spectrum>=2 (Ivan Vecera) [1941938]
- mlxsw: Add struct mlxsw_sp_switchdev_ops per ASIC (Ivan Vecera) [1941938]
- mlxsw: spectrum: Add mlxsw_sp_port_egress_ethtype_set() (Ivan Vecera) [1941938]
- mlxsw: reg: Add Switch Port Egress VLAN EtherType Register (Ivan Vecera) [1941938]
- mlxsw: reg: Add egr_et_set field to SPVID (Ivan Vecera) [1941938]
- selftests: mlxsw: Test egress sampling limitation on Spectrum-1 only (Ivan Vecera) [1941938]
- selftests: mlxsw: Add tc sample tests for new triggers (Ivan Vecera) [1941938]
- mlxsw: spectrum_acl: Offload FLOW_ACTION_SAMPLE (Ivan Vecera) [1941938]
- mlxsw: core_acl_flex_actions: Add mirror sampler action (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Add support for egress sampling (Ivan Vecera) [1941938]
- mlxsw: spectrum: Start using sampling triggers hash table (Ivan Vecera) [1941938]
- mlxsw: spectrum: Track sampling triggers in a hash table (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Pass matchall entry to sampling operations (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Push sampling checks to per-ASIC operations (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Propagate extack further (Ivan Vecera) [1941938]
- selftests: mlxsw: Add tc sample tests (Ivan Vecera) [1941938]
- mlxsw: spectrum: Report extra metadata to psample module (Ivan Vecera) [1941938]
- mlxsw: spectrum: Remove mlxsw_sp_sample_receive() (Ivan Vecera) [1941938]
- mlxsw: spectrum: Remove unnecessary RCU read-side critical section (Ivan Vecera) [1941938]
- mlxsw: pci: Set extra metadata in skb control block (Ivan Vecera) [1941938]
- mlxsw: Create dedicated field for Rx metadata in skb control block (Ivan Vecera) [1941938]
- mlxsw: pci: Add more metadata fields to CQEv2 (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Implement sampling using mirroring (Ivan Vecera) [1941938]
- mlxsw: spectrum_trap: Split sampling traps between ASICs (Ivan Vecera) [1941938]
- mlxsw: spectrum_matchall: Split sampling support between ASICs (Ivan Vecera) [1941938]
- mlxsw: spectrum_span: Add SPAN probability rate support (Ivan Vecera) [1941938]
- mlxsw: reg: Extend mirroring registers with probability rate field (Ivan Vecera) [1941938]
- mlxsw: spectrum_span: Add SPAN session identifier support (Ivan Vecera) [1941938]
- mlxsw: Adjust some MFDE fields shift and size to fw implementation (Ivan Vecera) [1941938]
- mlxsw: core: Expose MFDE.log_ip to devlink health (Ivan Vecera) [1941938]
- mlxsw: reg: Extend MFDE register with new log_ip field (Ivan Vecera) [1941938]
- mlxsw: spectrum: Bump minimum FW version to xx.2008.2406 (Ivan Vecera) [1941938]
- mlxsw: reg: Fix comment about slot_index field in PMAOS register (Ivan Vecera) [1941938]
- mlxsw: spectrum: Reword an error message for Q-in-Q veto (Ivan Vecera) [1941938]
- mlxsw: spectrum_ethtool: Add an external speed to PTYS register (Ivan Vecera) [1941938]
- mlxsw: spectrum_span: Do not overwrite policer configuration (Ivan Vecera) [1941938]
- selftests: forwarding: Specify interface when invoking mausezahn (Ivan Vecera) [1941938]
- selftests: mlxsw: Add a scale test for physical ports (Ivan Vecera) [1941938]
- mlxsw: Register physical ports as a devlink resource (Ivan Vecera) [1941938]
- mlxsw: pci: switch from 'pci_' to 'dma_' API (Ivan Vecera) [1941938]
- mlxsw: core: Increase critical threshold for ASIC thermal zone (Ivan Vecera) [1941938]
- mlxsw: core: Add validation of transceiver temperature thresholds (Ivan Vecera) [1941938]
- selftests: mlxsw: Set headroom size of correct port (Ivan Vecera) [1941938]
- net/mlxfw: Use kzalloc for allocating only one thing (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Use eXtended mezzanine to offload IPv4 router (Ivan Vecera) [1941938]
- mlxsw: spectrum: Set KVH XLT cache mode for Spectrum2/3 (Ivan Vecera) [1941938]
- mlxsw: spectrum_router_xm: Introduce basic XM cache flushing (Ivan Vecera) [1941938]
- mlxsw: reg: Add Router LPM Cache Enable Register (Ivan Vecera) [1941938]
- mlxsw: reg: Add Router LPM Cache ML Delete Register (Ivan Vecera) [1941938]
- mlxsw: spectrum_router_xm: Implement L-value tracking for M-index (Ivan Vecera) [1941938]
- mlxsw: reg: Add XM Router M Table Register (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Introduce per-ASIC XM initialization (Ivan Vecera) [1941938]
- mlxsw: reg: Add XM Lookup Table Query Register (Ivan Vecera) [1941938]
- mlxsw: reg: Add Router XLT M select Register (Ivan Vecera) [1941938]
- mlxsw: Ignore ports that are connected to eXtended mezanine (Ivan Vecera) [1941938]
- mlxsw: pci: Obtain info about ports used by eXtended mezanine (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Introduce XM implementation of router low-level ops (Ivan Vecera) [1941938]
- mlxsw: reg: Add Router XLT Enable Register (Ivan Vecera) [1941938]
- mlxsw: reg: Add XM Direct Register (Ivan Vecera) [1941938]
- selftests: mlxsw: Add Q-in-VNI veto tests (Ivan Vecera) [1941938]
- selftests: forwarding: Add Q-in-VNI test (Ivan Vecera) [1941938]
- mlxsw: spectrum_switchdev: Allow joining VxLAN to 802.1ad bridge (Ivan Vecera) [1941938]
- mlxsw: Veto Q-in-VNI for Spectrum-1 ASIC (Ivan Vecera) [1941938]
- mlxsw: spectrum_switchdev: Use ops->vxlan_join() when adding VLAN to VxLAN device (Ivan Vecera) [1941938]
- mlxsw: spectrum_nve_vxlan: Add support for Q-in-VNI for Spectrum-2 ASIC (Ivan Vecera) [1941938]
- mlxsw: spectrum: Publish mlxsw_sp_ethtype_to_sver_type() (Ivan Vecera) [1941938]
- mlxsw: Save EtherType as part of mlxsw_sp_nve_config (Ivan Vecera) [1941938]
- mlxsw: Save EtherType as part of mlxsw_sp_nve_params (Ivan Vecera) [1941938]
- mlxsw: spectrum_switchdev: Create common function for joining VxLAN to VLAN-aware bridge (Ivan Vecera) [1941938]
- mlxsw: reg: Add support for tunnel port in SPVID register (Ivan Vecera) [1941938]
- mlxsw: reg: Add Switch Port VLAN Stacking Register (Ivan Vecera) [1941938]
- mlxsw: Use one enum for all registers that contain tunnel_port field (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Reduce mlxsw_sp_ipip_fib_entry_op_gre4() (Ivan Vecera) [1941938]
- mlxsw: spectrum: Bump minimum FW version to xx.2008.2018 (Ivan Vecera) [1941938]
- mlxsw: core_acl: Use an array instead of a struct with a zero-length array (Ivan Vecera) [1941938]
- mlxsw: spectrum_mr: Use flexible-array member instead of zero-length array (Ivan Vecera) [1941938]
- mlxsw: core: Trace EMAD events (Ivan Vecera) [1941938]
- selftests: mlxsw: Test RIF's reference count when joining a LAG (Ivan Vecera) [1941938]
- mlxsw: spectrum: Apply RIF configuration when joining a LAG (Ivan Vecera) [1941938]
- selftests: forwarding: Add QinQ veto testing (Ivan Vecera) [1941938]
- mlxsw: Add QinQ configuration vetoes (Ivan Vecera) [1941938]
- mlxsw: spectrum_switchdev: Add support of QinQ traffic (Ivan Vecera) [1941938]
- mlxsw: spectrum_switchdev: Create common functions for VLAN-aware bridge (Ivan Vecera) [1941938]
- mlxsw: Make EtherType configurable when pushing VLAN at ingress (Ivan Vecera) [1941938]
- mlxsw: spectrum: Only treat 802.1q packets as tagged packets (Ivan Vecera) [1941938]
- mlxsw: reg: Add et_vlan field to SPVID register (Ivan Vecera) [1941938]
- mlxsw: reg: Add Switch Port VLAN Classification Register (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Update adjacency index more efficiently (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Track nexthop group virtual router membership (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Rollback virtual router adjacency pointer update (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Pass virtual router parameters directly instead of pointer (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Fix error handling issue (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Resolve RIF from nexthop struct instead of neighbour (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Use loopback RIF for unresolved nexthops (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Use different trap identifier for unresolved nexthops (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Create loopback RIF during initialization (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Allow returning errors from mlxsw_sp_nexthop_group_refresh() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Add an indication if a nexthop group can be destroyed (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Re-order mlxsw_sp_nexthop6_group_get() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Set FIB entry's type based on nexthop group (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Set FIB entry's type after creating nexthop group (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Pass ifindex to mlxsw_sp_ipip_entry_find_by_decap() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Set ifindex for IPv4 nexthops (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Fix wrong kfree() in error path (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Remove outdated comment (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Consolidate mlxsw_sp_nexthop{4, 6}_type_fini() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Consolidate mlxsw_sp_nexthop{4, 6}_type_init() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Remove unused argument from mlxsw_sp_nexthop6_type_init() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Pass nexthop netdev to mlxsw_sp_nexthop4_type_init() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Pass nexthop netdev to mlxsw_sp_nexthop6_type_init() (Ivan Vecera) [1941938]
- mlxsw: spectrum_ipip: Remove overlay protocol from can_offload() callback (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Split nexthop group configuration to a different struct (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Move IPv4 FIB info into a union in nexthop group struct (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Remove unused field 'prio' from IPv4 FIB entry struct (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Store FIB info in route (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Associate neighbour table with nexthop instead of group (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Use nexthop group type in hash table key (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Add nexthop group type field (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Compare key with correct object type (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Introduce FIB entry update op (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Track FIB entry committed state and skip uncommitted on delete (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Introduce fib_entry priv for low-level ops (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Have FIB entry op context allocated for the instance (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Prepare work context for possible bulking (Ivan Vecera) [1941938]
- mlxsw: spectrum: Push RALUE packing and writing into low-level router ops (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Use RALUE pack helper from abort function (Ivan Vecera) [1941938]
- mlxsw: reg: Allow to pass NULL pointer to mlxsw_reg_ralue_pack4/6() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Pass destination IP as a pointer to mlxsw_reg_ralue_pack4() (Ivan Vecera) [1941938]
- mlxsw: spectrum: Export RALUE pack helper and use it from IPIP (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Push out RALUE pack into separate helper (Ivan Vecera) [1941938]
- mlxsw: spectrum: Propagate context from work handler containing RALUE payload (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Introduce FIB event queue instead of separate works (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Use RALUE-independent op arg (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Pass non-register proto enum to __mlxsw_sp_router_set_abort_trap() (Ivan Vecera) [1941938]
- mlxsw: spectrum_router: Introduce low-level ops and implement them for RALXX regs (Ivan Vecera) [1941938]
- mlxsw: reg: Add XRALXX Registers (Ivan Vecera) [1941938]
- hwmon: (mlxreg-fan) Add support for fan drawers capability and present registers (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Add callback to notify mux creation completion (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Extend supported mux number (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Extend driver to support word address space devices (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Get rid of adapter numbers enforcement (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Prepare mux selection infrastructure for two-byte support (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Convert driver to platform driver (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Move header file out of x86 realm (Ivan Vecera) [1941938]
- platform/x86: mlxcpld: Update module license (Ivan Vecera) [1941938]
- i2c: mux: mlxcpld: Update module license (Ivan Vecera) [1941938]
- i2c: mlxcpld: Add support for I2C bus frequency setting (Ivan Vecera) [1941938]
- i2c: mlxcpld: Decrease polling time for performance improvement (Ivan Vecera) [1941938]
- i2c: mlxcpld: Update module license (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Fix item counter assignment for MSN2700/ComEx system (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Fix item counter assignment for MSN2700, MSN24xx systems (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: remove an unused variable (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Remove PSU EEPROM from MSN274x platform configuration (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Remove PSU EEPROM from default platform configuration (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Add capability field to platform FAN description (Ivan Vecera) [1941938]
- platform_data/mlxreg: Extend core platform structure (Ivan Vecera) [1941938]
- platform_data/mlxreg: Update module license (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Fix extended topology configuration for power supply units (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Remove PSU EEPROM configuration (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Extend FAN platform data description (Ivan Vecera) [1941938]
- platform_data/mlxreg: Add presence register field for FAN devices (Ivan Vecera) [1941938]
- Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1941938]
- platform/mellanox: mlxreg-io: Add support for complex attributes (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: Add more definitions for system attributes (Ivan Vecera) [1941938]
- platform_data/mlxreg: Add support for complex attributes (Ivan Vecera) [1941938]
- platform/mellanox: mlxreg-hotplug: Add environmental data to uevent (Ivan Vecera) [1941938]
- platform/mellanox: mlxreg-hotplug: Use capability register for attribute creation (Ivan Vecera) [1941938]
- platform/mellanox: mlxreg-hotplug: Modify module license (Ivan Vecera) [1941938]
- lib/string_helpers: Introduce string_upper() and string_lower() helpers (Ivan Vecera) [1941938]
- i2c: mlxcpld: check correct size of maximum RECV_LEN packet (Ivan Vecera) [1941938]
- docs: watchdog: mlx-wdt: Add description of new watchdog type 3 (Ivan Vecera) [1941938]
- watchdog: mlx-wdt: support new watchdog type with longer timeout period (Ivan Vecera) [1941938]
- platform/x86: mlx-platform: support new watchdog type with longer timeout (Ivan Vecera) [1941938]
- platform_data/mlxreg: support new watchdog type with longer timeout period (Ivan Vecera) [1941938]
- platform/mellanox: mlxreg-hotplug: convert to use i2c_new_client_device() (Ivan Vecera) [1941938]
- selftests: icmp_redirect: IPv6 PMTU info should be cleared after redirect (Hangbin Liu) [1986227]
- selftests: icmp_redirect: remove from checking for IPv6 route get (Hangbin Liu) [1986227]
- selftests: icmp_redirect: support expected failures (Hangbin Liu) [1986227]
- selftests: disable rp_filter for icmp_redirect.sh (Hangbin Liu) [1986227]
- selftests: icmp_redirect: Add support for routing via nexthop objects (Hangbin Liu) [1986227]
- selftest: Fixes for icmp_redirect test (Hangbin Liu) [1986227]
- selftests: Add redirect tests (Hangbin Liu) [1986227]
- redhat: enable vdpa_sim_net vdpa_sim_block vp_vdpa (Cindy Lu) [1975173]
- virtio/vdpa: clear the virtqueue state during probe (Cindy Lu) [1975173]
- vp_vdpa: allow set vq state to initial state after reset (Cindy Lu) [1975173]
- virtio-pci library: introduce vp_modern_get_driver_features() (Cindy Lu) [1975173]
- vdpa: support packed virtqueue for set/get_vq_state() (Cindy Lu) [1975173]
- vdpa/mlx5: Clear vq ready indication upon device reset (Cindy Lu) [1975173]
- vdpa/mlx5: Add support for doorbell bypassing (Cindy Lu) [1975173]
- vdpa/mlx5: Add support for running with virtio_vdpa (Cindy Lu) [1975173]
- vdp/mlx5: Fix setting the correct dma_device (Cindy Lu) [1975173]
- vdpa/mlx5: Support creating resources with uid == 0 (Cindy Lu) [1975173]
- vdpa/mlx5: Fix possible failure in umem size calculation (Cindy Lu) [1975173]
- vdpa/mlx5: Fix umem sizes assignments on VQ create (Cindy Lu) [1975173]
- vp_vdpa: correct the return value when fail to map notification (Cindy Lu) [1975173]
- virtio_net: Fix error handling in virtnet_restore() (Cindy Lu) [1975173]
- virtio-blk: Fix memory leak among suspend/resume procedure (Cindy Lu) [1975173]
- vDPA/ifcvf: reuse pre-defined macros for device ids and vendor ids (Cindy Lu) [1975173]
- virtio: update virtio id table, add transitional ids (Cindy Lu) [1975173]
- vDPA/ifcvf: implement doorbell mapping for ifcvf (Cindy Lu) [1975173]
- vDPA/ifcvf: record virtio notify base (Cindy Lu) [1975173]
- vdpa_sim_blk: remove duplicate include of linux/blkdev.h (Cindy Lu) [1975173]
- {net,vdpa}/mlx5: Configure interface MAC into mpfs L2 table (Cindy Lu) [1975173]
- virtio_pci_modern: correct sparse tags for notify (Cindy Lu) [1975173]
- virtio_pci_modern: __force cast the notify mapping (Cindy Lu) [1975173]
- vDPA/ifcvf: get_config_size should return dev specific config size (Cindy Lu) [1975173]
- vDPA/ifcvf: enable Intel C5000X-PL virtio-block for vDPA (Cindy Lu) [1975173]
- vDPA/ifcvf: deduce VIRTIO device ID when probe (Cindy Lu) [1975173]
- vdpa_sim_blk: add support for vdpa management tool (Cindy Lu) [1975173]
- vdpa_sim_blk: handle VIRTIO_BLK_T_GET_ID (Cindy Lu) [1975173]
- vdpa_sim_blk: implement ramdisk behaviour (Cindy Lu) [1975173]
- vdpa: add vdpa simulator for block device (Cindy Lu) [1975173]
- vhost/vdpa: Remove the restriction that only supports virtio-net devices (Cindy Lu) [1975173]
- vhost/vdpa: use get_config_size callback in vhost_vdpa_config_validate() (Cindy Lu) [1975173]
- vdpa: add get_config_size callback in vdpa_config_ops (Cindy Lu) [1975173]
- vdpa_sim: cleanup kiovs in vdpasim_free() (Cindy Lu) [1975173]
- vringh: add vringh_kiov_length() helper (Cindy Lu) [1975173]
- vringh: implement vringh_kiov_advance() (Cindy Lu) [1975173]
- vringh: explain more about cleaning riov and wiov (Cindy Lu) [1975173]
- vringh: reset kiov 'consumed' field in __vringh_iov() (Cindy Lu) [1975173]
- vringh: add 'iotlb_lock' to synchronize iotlb accesses (Cindy Lu) [1975173]
- vdpa_sim: use iova module to allocate IOVA addresses (Cindy Lu) [1975173]
- vDPA/ifcvf: deduce VIRTIO device ID from pdev ids (Cindy Lu) [1975173]
- vDPA/ifcvf: verify mandatory feature bits for vDPA (Cindy Lu) [1975173]
- vDPA/ifcvf: fetch device feature bits when probe (Cindy Lu) [1975173]
- vDPA/ifcvf: remove the version number string (Cindy Lu) [1975173]
- vDPA/ifcvf: rename original IFCVF dev ids to N3000 ids (Cindy Lu) [1975173]
- vDPA/ifcvf: enable Intel C5000X-PL virtio-net for vDPA (Cindy Lu) [1975173]
- vDPA/ifcvf: get_vendor_id returns a device specific vendor id (Cindy Lu) [1975173]
- vhost-vdpa: fix vm_flags for virtqueue doorbell mapping (Cindy Lu) [1975173]
- vp_vdpa: report doorbell address (Cindy Lu) [1975173]
- virtio-pci library: report resource address (Cindy Lu) [1975173]
- virito_pci libray: hide vp_modern_map_capability() (Cindy Lu) [1975173]
- virtio_pci_modern: hide vp_modern_get_queue_notify_off() (Cindy Lu) [1975173]
- vp_vdpa: switch to use vp_modern_map_vq_notify() (Cindy Lu) [1975173]
- virtio-pci library: switch to use vp_modern_map_vq_notify() (Cindy Lu) [1975173]
- virtio_pci_modern: introduce helper to map vq notify area (Cindy Lu) [1975173]
- virtio-net: don't allocate control_buf if not supported (Cindy Lu) [1975173]
- vdpa: Follow kdoc comment style (Cindy Lu) [1975173]
- vdpa: Follow kdoc comment style (Cindy Lu) [1975173]
- vdpa/mlx5: Enable user to add/delete vdpa device (Cindy Lu) [1975173]
- vdpa: introduce virtio pci driver (Cindy Lu) [1975173]
- vdpa/mlx5: Set err = -ENOMEM in case dma_map_sg_attrs fails (Cindy Lu) [1975173]
- vhost-vdpa: protect concurrent access to vhost device iotlb (Cindy Lu) [1975173]
- vdpa/mlx5: Fix suspend/resume index restoration (Cindy Lu) [1975173]
- vdpa/mlx5: Fix wrong use of bit numbers (Cindy Lu) [1975173]
- vdpa/mlx5: should exclude header length and fcs from mtu (Cindy Lu) [1975173]
- vhost-vdpa: set v->config_ctx to NULL if eventfd_ctx_fdget() fails (Cindy Lu) [1975173]
- vhost-vdpa: fix use-after-free of v->config_ctx (Cindy Lu) [1975173]
- vhost_vdpa: fix the missing irq_bypass_unregister_producer() invocation (Cindy Lu) [1975173]
- vdpa_sim: Skip typecasting from void* (Cindy Lu) [1975173]
- vdpa: set the virtqueue num during register (Cindy Lu) [1975173]
- vdpa/mlx5: fix param validation in mlx5_vdpa_get_config() (Cindy Lu) [1975173]
- virtio_vdpa: don't warn when fail to disable vq (Cindy Lu) [1975173]
- virtio-pci: introduce modern device module (Cindy Lu) [1975173]
- virito-pci-modern: rename map_capability() to vp_modern_map_capability() (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helper to get notification offset (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helper for getting queue nums (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helper for setting/geting queue size (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helper to set/get queue_enable (Cindy Lu) [1975173]
- virtio-pci-modern: introduce vp_modern_queue_address() (Cindy Lu) [1975173]
- virtio-pci-modern: introduce vp_modern_set_queue_vector() (Cindy Lu) [1975173]
- virtio-pci-modern: introduce vp_modern_generation() (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helpers for setting and getting features (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helpers for setting and getting status (Cindy Lu) [1975173]
- virtio-pci-modern: introduce helper to set config vector (Cindy Lu) [1975173]
- virtio-pci-modern: introduce vp_modern_remove() (Cindy Lu) [1975173]
- virtio-pci-modern: factor out modern device initialization logic (Cindy Lu) [1975173]
- virtio-pci: split out modern device (Cindy Lu) [1975173]
- virtio-pci: do not access iomem via struct virtio_pci_device directly (Cindy Lu) [1975173]
- vdpa_sim_net: Add support for user supported devices (Cindy Lu) [1975173]
- vdpa: Enable user to query vdpa device info (Cindy Lu) [1975173]
- vdpa: Enable a user to add and delete a vdpa device (Cindy Lu) [1975173]
- vdpa: Define vdpa mgmt device, ops and a netlink interface (Cindy Lu) [1975173]
- vdpa: Extend routine to accept vdpa device name (Cindy Lu) [1975173]
- vdpa_sim_net: Make mac address array static (Cindy Lu) [1975173]
- vdpa/mlx5: Restore the hardware used index after change map (Cindy Lu) [1975173]
- vdpa/mlx5: Fix memory key MTT population (Cindy Lu) [1975173]
- vdpa: Use simpler version of ida allocation (Cindy Lu) [1975173]
- vdpa: Add missing comment for virtqueue count (Cindy Lu) [1975173]
- vdpa: split vdpasim to core and net modules (Cindy Lu) [1975173]
- vdpa_sim: split vdpasim_virtqueue's iov field in out_iov and in_iov (Cindy Lu) [1975173]
- vdpa_sim: make vdpasim->buffer size configurable (Cindy Lu) [1975173]
- vdpa_sim: use kvmalloc to allocate vdpasim->buffer (Cindy Lu) [1975173]
- vdpa_sim: set vringh notify callback (Cindy Lu) [1975173]
- vdpa_sim: add set_config callback in vdpasim_dev_attr (Cindy Lu) [1975173]
- vdpa_sim: add get_config callback in vdpasim_dev_attr (Cindy Lu) [1975173]
- vdpa_sim: make 'config' generic and usable for any device type (Cindy Lu) [1975173]
- vdpa_sim: store parsed MAC address in a buffer (Cindy Lu) [1975173]
- vdpa_sim: add work_fn in vdpasim_dev_attr (Cindy Lu) [1975173]
- vdpa_sim: add supported_features field in vdpasim_dev_attr (Cindy Lu) [1975173]
- vdpa_sim: add device id field in vdpasim_dev_attr (Cindy Lu) [1975173]
- vdpa_sim: add struct vdpasim_dev_attr for device attributes (Cindy Lu) [1975173]
- vdpa_sim: rename vdpasim_config_ops variables (Cindy Lu) [1975173]
- vdpa_sim: make IOTLB entries limit configurable (Cindy Lu) [1975173]
- vdpa_sim: remove hard-coded virtq count (Cindy Lu) [1975173]
- vdpa_sim: remove unnecessary headers inclusion (Cindy Lu) [1975173]
- vdpa: remove unnecessary 'default n' in Kconfig entries (Cindy Lu) [1975173]
- vdpa: ifcvf: Use dma_set_mask_and_coherent to simplify code (Cindy Lu) [1975173]
- vhost_vdpa: switch to vmemdup_user() (Cindy Lu) [1975173]
- vhost: vringh: use krealloc_array() (Cindy Lu) [1975173]
- vringh: fix vringh_iov_push_*() documentation (Cindy Lu) [1975173]
- vringh: fix __vringh_iov() when riov and wiov are different (Cindy Lu) [1975173]
- net: sched: fix memory leak in tcindex_partial_destroy_work (Davide Caratti) [1987042]
- net/sched: act_ct: remove and free nf_table callbacks (Davide Caratti) [1987042]
- net: sched: fix warning in tcindex_alloc_perfect_hash (Davide Caratti) [1987042]
- pkt_sched: sch_qfq: fix qfq_change_class() error path (Davide Caratti) [1987042]
- sch_htb: fix refcount leak in htb_parent_to_leaf_offload (Davide Caratti) [1987042]
- sch_dsmark: fix a NULL deref in qdisc_reset() (Davide Caratti) [1987042]
- sch_red: fix off-by-one checks in red_check_params() (Davide Caratti) [1987042]
- ipv6: fix 'disable_policy' for fwd packets (Hangbin Liu) [1985837]
- net: ipv6: fix return value of ip6_skb_dst_mtu (Hangbin Liu) [1985837]
- ipv6: fix out-of-bound access in ip6_parse_tlv() (Hangbin Liu) [1985837]
- ipv6: exthdrs: do not blindly use init_net (Hangbin Liu) [1985837]
- ipv6: record frag_max_size in atomic fragments in input path (Hangbin Liu) [1985837]
- selftests: net: devlink_port_split.py: skip the test if no devlink device (Hangbin Liu) [1985836]
- selftests/net: bump timeout to 5 minutes (Hangbin Liu) [1985836]
- selftests: net: forwarding: Fix a typo (Hangbin Liu) [1985836]
- selftests/net: so_txtime: remove unneeded semicolon (Hangbin Liu) [1985836]
- tools: selftests: add test for changing routes with PTMU exceptions (Hangbin Liu) [1985836]
- selftests: fix the return value for UDP GRO test (Hangbin Liu) [1985836]
- selftests: pmtu.sh: improve the test result processing (Hangbin Liu) [1985836]
- selftests: pmtu.sh: use $ksft_skip for skipped return code (Hangbin Liu) [1985836]
- selftests/net: timestamping: add ptp v2 support (Hangbin Liu) [1985836]
- ixgbevf: add correct exception tracing for XDP (Ken Cox) [1920268]
- intel: call csum functions with well formatted arguments (Ken Cox) [1920268]
- net: intel: Remove unused function pointer typedef ixgbe_mc_addr_itr (Ken Cox) [1920268]
- ixgbevf: Fix fall-through warnings for Clang (Ken Cox) [1920268]
- intel: clean up mismatched header comments (Ken Cox) [1920268]
- ixgbe: fail to create xfrm offload of IPsec tunnel mode SA (Ken Cox) [1920268]
- net: ixgbevf: use skb_csum_is_sctp instead of protocol check (Ken Cox) [1920268]
- treewide: Use sizeof_field() macro (Ken Cox) [1920268]
- selftests: net: add ESP-in-UDP PMTU test (Xin Long) [1986599]
- udp: check encap socket in __udp_lib_err (Xin Long) [1986599]
- udp: fix possible user after free in error handler (Xin Long) [1986599]
- udpv6: fix possible user after free in error handler (Xin Long) [1986599]
- udp: Support for error handlers of tunnels with arbitrary destination port (Xin Long) [1986599]
- bpf, sockmap, udp: sk_prot needs inuse_idx set for proc stats (Xin Long) [1986599]
- udp: properly flush normal packet at GRO time (Xin Long) [1986599]
- udp: annotate data races around unix_sk(sk)->gso_size (Xin Long) [1986599]
- udp: fix race between close() and udp_abort() (Xin Long) [1986599]
- netfilter: conntrack: remove offload_pickup sysctl again (Florian Westphal) [1987101]
- bpf, samples: Add -fno-asynchronous-unwind-tables to BPF Clang invocation (Yauheni Kaliuta) [1977162]
- net/af_unix: fix a data-race in unix_dgram_sendmsg / unix_release_sock (Balazs Nemeth) [1986845]
- netfilter: nf_tables: fix flowtable list del corruption (Jay Shin) [1977137]
- net: qrtr: fix memory leaks (Íñigo Huguet) [1981236]
- net: qrtr: fix OOB Read in qrtr_endpoint_post (Íñigo Huguet) [1981236]
- net: qrtr: ns: Fix error return code in qrtr_ns_init() (Íñigo Huguet) [1981236]
- net: qrtr: Avoid potential use after free in MHI send (Íñigo Huguet) [1981236]
- qrtr: Convert qrtr_ports from IDR to XArray (Íñigo Huguet) [1981236]
- net: qrtr: Fix memory leak on qrtr_tx_wait failure (Íñigo Huguet) [1981236]
- net: qrtr: fix a kernel-infoleak in qrtr_recvmsg() (Íñigo Huguet) [1981236]
- net: qrtr: fix error return code of qrtr_sendmsg() (Íñigo Huguet) [1981236]
- net/qrtr: fix __netdev_alloc_skb call (Íñigo Huguet) [1981236]
- net: qrtr: Fix memory leak in qrtr_tun_open (Íñigo Huguet) [1981236]
- net/qrtr: restrict user-controlled length in qrtr_tun_write_iter() (Íñigo Huguet) [1981236]
- net: qrtr: fix null-ptr-deref in qrtr_ns_remove (Íñigo Huguet) [1981236]
- net: qrtr: Unprepare MHI channels during remove (Íñigo Huguet) [1981236]
- net: qrtr: Start MHI channels during init (Íñigo Huguet) [1981236]
- net: qrtr: Release distant nodes along the bridge node (Íñigo Huguet) [1981236]
- net: qrtr: Add GFP flags parameter to qrtr_alloc_ctrl_packet (Íñigo Huguet) [1981236]
- net: qrtr: Allow non-immediate node routing (Íñigo Huguet) [1981236]
- net: qrtr: Allow forwarded services (Íñigo Huguet) [1981236]
- net: qrtr: Fix port ID for control messages (Íñigo Huguet) [1981236]
- net: qrtr: ns: Fix the incorrect usage of rcu_read_lock() (Íñigo Huguet) [1981236]
- net: qrtr: ns: Protect radix_tree_deref_slot() using rcu read locks (Íñigo Huguet) [1981236]
- net: qrtr: check skb_put_padto() return value (Íñigo Huguet) [1981236]
- net: qrtr: fix usage of idr in port assignment to socket (Íñigo Huguet) [1981236]
- qrtr: orphan socket in qrtr_release() (Íñigo Huguet) [1981236]
- net: qrtr: Fix an out of bounds read qrtr_endpoint_post() (Íñigo Huguet) [1981236]
- net: qrtr: free flow in __qrtr_node_release (Íñigo Huguet) [1981236]
- treewide: replace '---help---' in Kconfig files with 'help' (Íñigo Huguet) [1981236]
- net: qrtr: Allocate workqueue before kernel_bind (Íñigo Huguet) [1981236]
- net: qrtr: Fix passing invalid reference to qrtr_local_enqueue() (Íñigo Huguet) [1981236]
- net: qrtr: Add MHI transport layer (Íñigo Huguet) [1981236]
- net: qrtr: Add tracepoint support (Íñigo Huguet) [1981236]
- net: qrtr: send msgs from local of same id as broadcast (Íñigo Huguet) [1981236]
- net: qrtr: Fix FIXME related to qrtr_ns_init() (Íñigo Huguet) [1981236]
- net: qrtr: Respond to HELLO message (Íñigo Huguet) [1981236]
- net: qrtr: Fix error pointer vs NULL bugs (Íñigo Huguet) [1981236]
- net: qrtr: fix spelling mistake "serivce" -> "service" (Íñigo Huguet) [1981236]
- net: qrtr: Fix the local node ID as 1 (Íñigo Huguet) [1981236]
- net: qrtr: Migrate nameservice to kernel from userspace (Íñigo Huguet) [1981236]
- net: qrtr: Remove receive worker (Íñigo Huguet) [1981236]
- net: qrtr: Make qrtr_port_lookup() use RCU (Íñigo Huguet) [1981236]
- net: qrtr: Migrate node lookup tree to spinlock (Íñigo Huguet) [1981236]
- net: qrtr: Implement outgoing flow control (Íñigo Huguet) [1981236]
- net: qrtr: Move resume-tx transmission to recvmsg (Íñigo Huguet) [1981236]
- net: qrtr: fix len of skb_put_padto in qrtr_node_enqueue (Íñigo Huguet) [1981236]
- net: qrtr: Simplify 'qrtr_tun_release()' (Íñigo Huguet) [1981236]
- net: qrtr: Stop rx_worker before freeing node (Íñigo Huguet) [1981236]
- net: qrtr: fix memort leak in qrtr_tun_write_iter (Íñigo Huguet) [1981236]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 284 (Íñigo Huguet) [1981236]
- treewide: Add SPDX license identifier - Makefile/Kconfig (Íñigo Huguet) [1981236]
- net: qrtr: Fix message type of outgoing packets (Íñigo Huguet) [1981236]
- net: qrtr: use protocol endiannes variable (Íñigo Huguet) [1981236]
- net: fix hangup on napi_disable for threaded napi (Paolo Abeni) [1949546]
- net: fix race between napi kthread mode and busy poll (Paolo Abeni) [1949546]
- net: add sysfs attribute to control napi threaded mode (Paolo Abeni) [1949546]
- net: implement threaded-able napi poll loop support (Paolo Abeni) [1949546]
- net: extract napi poll functionality to __napi_poll() (Paolo Abeni) [1949546]
- mfd: intel-lpss: Use devm_ioremap_uc for MMIO (Steve Best) [1986715]
- lib: devres: add a helper function for ioremap_uc (Steve Best) [1986715]
- sched/rt: Fix double enqueue caused by rt_effective_prio (Juri Lelli) [1990566]
- x86/crash: Remove crash_reserve_low_1M() (Lianbo Jiang) [1904318]
- x86/setup: Remove CONFIG_X86_RESERVE_LOW and reservelow= options (Lianbo Jiang) [1904318]
- x86/setup: Always reserve the first 1M of RAM (Lianbo Jiang) [1904318]
- powerpc/kexec: blacklist functions called in real mode for kprobe (Desnes A. Nunes do Rosario) [1987281]
- [s390] scsi: zfcp: Report port fc_security as unknown early during remote cable pull (Claudio Imbrenda) [1989910]
- x86/boot: Use common BUILD_BUG_ON (Prarit Bhargava) [1979940]
- net: phy: icplus: call phy_restore_page() when phy_select_page() fails (Petr Oros) [1955165]
- net: phy: ti: take into account all possible interrupt sources (Petr Oros) [1955165]
- net: phy: smsc: add missed clk_disable_unprepare in smsc_phy_probe() (Petr Oros) [1955165]
- net: phy: Expose phydev::dev_flags through sysfs (Petr Oros) [1955165]
- net: phy: fix save wrong speed and duplex problem if autoneg is on (Petr Oros) [1955165]
- net: phy: micrel: set soft_reset callback to genphy_soft_reset for KSZ8081 (Petr Oros) [1955165]
- net: phy: icplus: add MDI/MDIX support for IP101A/G (Petr Oros) [1955165]
- net: phy: icplus: add PHY counter for IP101G (Petr Oros) [1955165]
- net: phy: icplus: fix paged register access (Petr Oros) [1955165]
- net: phy: icplus: don't set APS_EN bit on IP101G (Petr Oros) [1955165]
- net: phy: icplus: split IP101A/G driver (Petr Oros) [1955165]
- net: phy: icplus: use the .soft_reset() of the phy-core (Petr Oros) [1955165]
- net: phy: icplus: drop address operator for functions (Petr Oros) [1955165]
- net: phy: icplus: use PHY_ID_MATCH_EXACT() for IP101A/G (Petr Oros) [1955165]
- net: phy: icplus: use PHY_ID_MATCH_MODEL() macro (Petr Oros) [1955165]
- net: phy: drop explicit genphy_read_status() op (Petr Oros) [1955165]
- net: phy: broadcom: remove BCM5482 1000Base-BX support (Petr Oros) [1955165]
- net: mdiobus: Prevent spike on MDIO bus reset signal (Petr Oros) [1955165]
- net: phy: realtek: Add support for RTL9000AA/AN (Petr Oros) [1955165]
- mdio, phy: fix -Wshadow warnings triggered by nested container_of() (Petr Oros) [1955165]
- net: phy: national: remove definition of DEBUG (Petr Oros) [1955165]
- net: phy: ar803x: disable extended next page bit (Petr Oros) [1955165]
- net: phy: smsc: fix clk error handling (Petr Oros) [1955165]
- net: phy: at803x: use phy_modify_mmd() (Petr Oros) [1955165]
- net: phy: replace mutex_is_locked with lockdep_assert_held in phylib (Petr Oros) [1955165]
- net: phy: micrel: Add KS8851 PHY support (Petr Oros) [1955165]
- net: phy: marvell: replace phy_modify() (Petr Oros) [1955165]
- net: phy: micrel: fix interrupt handling (Petr Oros) [1955165]
- net: phy: remove the .did_interrupt() and .ack_interrupt() callback (Petr Oros) [1955165]
- net: phy: qsemi: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: qsemi: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: ti: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: ti: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: national: remove the use of the .ack_interrupt() (Petr Oros) [1955165]
- net: phy: national: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: micrel: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: micrel: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: icplus: remove the use .ack_interrupt() (Petr Oros) [1955165]
- net: phy: icplus: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: intel-xway: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: intel-xway: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- mdio_bus: suppress err message for reset gpio EPROBE_DEFER (Petr Oros) [1955165]
- net: phy: don't duplicate driver name in phy_attached_print (Petr Oros) [1955165]
- net: phy: ste10Xp: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: ste10Xp: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: smsc: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: smsc: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: amd: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: amd: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: lxt: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: lxt: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: marvell: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: marvell: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: microchip: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: microchip: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: vitesse: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: vitesse: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: aquantia: do not return an error on clearing pending IRQs (Petr Oros) [1955165]
- net: phy: microchip_t1: Don't set .config_aneg (Petr Oros) [1955165]
- docs: networking: phy: s/2.5 times faster/2.5 times as fast/ (Petr Oros) [1955165]
- net: phy: realtek: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: realtek: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: add genphy_handle_interrupt_no_ack() (Petr Oros) [1955165]
- net: phy: davicom: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: davicom: implement generic .handle_interrupt() calback (Petr Oros) [1955165]
- net: phy: cicada: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: cicada: implement the generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: broadcom: remove use of ack_interrupt() (Petr Oros) [1955165]
- net: phy: broadcom: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: aquantia: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: aquantia: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: mscc: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: mscc: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: at803x: remove the use of .ack_interrupt() (Petr Oros) [1955165]
- net: phy: at803x: implement generic .handle_interrupt() callback (Petr Oros) [1955165]
- net: phy: make .ack_interrupt() optional (Petr Oros) [1955165]
- net: phy: add a shutdown procedure (Petr Oros) [1955165]
- net: phy: export phy_error and phy_trigger_machine (Petr Oros) [1955165]
- drivers: net: phy: Fix spelling in comment defalut to default (Petr Oros) [1955165]
- net: phy: marvell: add special handling of Finisar modules with 88E1111 (Petr Oros) [1955165]
- net: phylink: disable BMCR_ISOLATE in phylink_mii_c22_pcs_config (Petr Oros) [1955165]
- gpiolib: Extract gpiod_not_found() helper (Petr Oros) [1955165]
- net: phy: marvell: Use phy_read_paged() instead of open coding it (Petr Oros) [1955165]
- net: phy: dp83869: fix unsigned comparisons against less than zero values (Petr Oros) [1955165]
- net: phy: dp83869: Add speed optimization feature (Petr Oros) [1955165]
- net: phy: dp83869: support Wake on LAN (Petr Oros) [1955165]
- net: phy: dp83822: Update the fiber advertisement for speed (Petr Oros) [1955165]
- net: dp83869: Add ability to advertise Fiber connection (Petr Oros) [1955165]
- net: phy: Do not warn in phy_stop() on PHY_DOWN (Petr Oros) [1955165]
- net: phy: Avoid NPD upon phy_detach() when driver is unbound (Petr Oros) [1955165]
- net: phy: bcm7xxx: request and manage GPHY clock (Petr Oros) [1955165]
- net: phy: smsc: LAN8710/20: add phy refclk in support (Petr Oros) [1955165]
- net: phy: smsc: simplify config_init callback (Petr Oros) [1955165]
- net: phy: smsc: skip ENERGYON interrupt if disabled (Petr Oros) [1955165]
- net: phy: dp83867: Fix various styling and space issues (Petr Oros) [1955165]
- net: mdiobus: add clause 45 mdiobus write accessor (Petr Oros) [1955165]
- net: phylink: consider QSGMII interface mode in phylink_mii_c22_pcs_get_state (Petr Oros) [1955165]
- net: phylink: add helper function to decode USXGMII word (Petr Oros) [1955165]
- net: phy: DP83822: Add ability to advertise Fiber connection (Petr Oros) [1955165]
- net: dp83869: Fix RGMII internal delay configuration (Petr Oros) [1955165]
- net: mdio-mux-gpio: use devm_gpiod_get_array() (Petr Oros) [1955165]
- net: phy: add USXGMII link partner ability constants (Petr Oros) [1955165]
- net: phy: mdio-octeon: Cleanup module loading dependencies (Petr Oros) [1955165]
- net: phy: cavium: Improve __iomem mess (Petr Oros) [1955165]
- net: phy: Add a helper to return the index for of the internal delay (Petr Oros) [1955165]
- dt-bindings: net: Add RGMII internal delay for DP83869 (Petr Oros) [1955165]
- net: dp83869: Add RGMII internal delay configuration (Petr Oros) [1955165]
- net: phy: DP83822: Add setting the fixed internal delay (Petr Oros) [1955165]
- net: dp83869: Fix OF_MDIO config check (Petr Oros) [1955165]
- net: dp83867: Fix OF_MDIO config check (Petr Oros) [1955165]
- net: marvell: Fix OF_MDIO config check (Petr Oros) [1955165]
- net: phy: mscc: use mdiobus_get_phy() (Petr Oros) [1955165]
- net: phy: improve phy_driver callback handle_interrupt (Petr Oros) [1955165]

* Mon Aug 09 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-330.el8]
- net/mlx5e: Add IPsec support to uplink representor (Alaa Hleihel) [1980171 1926098]
- net/mlx5e: TC: Reserved bit 31 of REG_C1 for IPsec offload (Alaa Hleihel) [1980171 1926098]
- net/mlx5e: TC: Use bit counts for register mapping (Alaa Hleihel) [1980171 1926098]
- RDMA/mlx5: Don't access NULL-cleared mpi pointer (Alaa Hleihel) [1980171]
- RDMA/mlx5: Split mlx5_ib_update_xlt() into ODP and non-ODP cases (Alaa Hleihel) [1980171]
- ip6_tunnel: allow redirecting ip6gre and ipxip6 packets to eth devices (Guillaume Nault) [1921539]
- gre: let mac_header point to outer header only when necessary (Guillaume Nault) [1921539]
- sit: allow redirecting ip6ip, ipip and mplsip packets to eth devices (Guillaume Nault) [1921539]
- ipip: allow redirecting ipip and mplsip packets to eth devices (Guillaume Nault) [1921539]
- bareudp: allow redirecting bareudp packets to eth devices (Guillaume Nault) [1921539]
- net: handle ARPHRD_IP6GRE in dev_is_mac_header_xmit() (Guillaume Nault) [1921539]
- net: ipv4: fix memory leak in ip_mc_add1_src (Guillaume Nault) [1987605]
- net: ipv4: fix memory leak in netlbl_cipsov4_add_std (Guillaume Nault) [1987605]
- ixgbe: fix probing of multi-port devices with one MDIO (Ken Cox) [1968696]
- [s390] s390/qdio: let driver manage the QAOB (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: remove RX VLAN filter stubs in L3 driver (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: enable napi_consume_skb() for pending TX buffers (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: allocate initial TX Buffer structs with GFP_KERNEL (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix notification for pending buffers during teardown (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: schedule TX NAPI on QAOB completion (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: improve completion of pending TX buffers (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix memory leak after failed TX Buffer allocation (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: don't fake a TX completion interrupt after TX error (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: make cast type selection for af_iucv skbs robust (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: pass proto to qeth_l3_get_cast_type() (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: remove qeth_get_ip_version() (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: clean up load/remove code for disciplines (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix L2 header access in qeth_l3_osa_features_check() (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix locking for discipline setup / removal (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix deadlock during recovery (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: make qeth_qdio_handle_aob() more robust (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: remove QETH_QDIO_BUF_HANDLED_DELAYED state (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: don't replace a fully completed async TX buffer (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: use dev->groups for common sysfs attributes (Claudio Imbrenda) [1919250]
- [s390] s390/ccwgroup: use bus->dev_groups for bus-based sysfs attributes (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: don't call INIT_LIST_HEAD() on iob's list entry (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix tear down of async TX buffers (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: fix af_iucv notification race (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: improve selection of ethtool link modes (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: use QUERY OAT for initial link info (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: clean up default cases for ethtool link mode (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: set static link info during initialization (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: improve QUERY CARD INFO processing (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: tolerate error when querying card info (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: remove useless if/else (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: reduce rtnl locking for switchdev events (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: static checker cleanups (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: use netdev_name() (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: constify the disciplines (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: allow configuration of TX queues for OSA devices (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: de-magic the QIB parm area (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: keep track of wanted TX queues (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: remove forward declarations in L2 code (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: consolidate teardown code (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: consolidate online code (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: cancel cmds earlier during teardown (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: tighten ucast IP locking (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: replace deprecated simple_stroul() (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: clean up string ops in qeth_l3_parse_ipatoe() (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: relax locking for ipato config data (Claudio Imbrenda) [1919250]
- [s390] s390/qeth: don't init refcount twice for mcast IPs (Claudio Imbrenda) [1919250]
- mm, page_alloc: check for max order in hot path (Jay Shin) [1982466]
- be2net: Fix an error handling path in 'be_probe()' (Petr Oros) [1980665]
- net: emulex: benet: simplify the return expression of be_if_create() (Petr Oros) [1980665]
- treewide: Use fallthrough pseudo-keyword (Petr Oros) [1980665]
- be2net: convert to new udp_tunnel_nic infra (Petr Oros) [1980665]
- benet: use generic power management (Petr Oros) [1980665]
- treewide: replace '---help---' in Kconfig files with 'help' (Petr Oros) [1980665]
- hwmon: (k10temp) Zen3 Ryzen Desktop CPUs support (David Arcari) [1980072]
- hwmon: (k10temp) Remove support for displaying voltage and current on Zen CPUs (David Arcari) [1980072]
- hwmon: (k10temp) Add support for Zen3 CPUs (David Arcari) [1980072]
- hwmon: (k10temp) Take out debugfs code (David Arcari) [1980072]
- hwmon: (k10temp) Define SVI telemetry and current factors for Zen2 CPUs (David Arcari) [1980072]
- hwmon: (k10temp) Create common functions and macros for Zen CPU families (David Arcari) [1980072]
- hwmon: (k10temp) Add AMD family 17h model 60h PCI match (David Arcari) [1980072]
- hwmon: (k10temp) make some symbols static (David Arcari) [1980072]
- hwmon: (k10temp) Reorganize and simplify temperature support detection (David Arcari) [1980072]
- hwmon: (k10temp) Swap Tdie and Tctl on Family 17h CPUs (David Arcari) [1980072]
- hwmon: (k10temp) Display up to eight sets of CCD temperatures (David Arcari) [1980072]
- hwmon: (k10temp) Add debugfs support (David Arcari) [1980072]
- hwmon: (k10temp) Don't show temperature limits on Ryzen (Zen) CPUs (David Arcari) [1980072]
- hwmon: (k10temp) Show core and SoC current and voltages on Ryzen CPUs (David Arcari) [1980072]
- hwmon: (k10temp) Report temperatures per CPU die (David Arcari) [1980072]
- hmon: (k10temp) Convert to use devm_hwmon_device_register_with_info (David Arcari) [1980072]
- hwmon: (k10temp) Use bitops (David Arcari) [1980072]
- hwmon: (k10temp) Add support for AMD family 17h, model 70h CPUs (David Arcari) [1980072]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 56 (David Arcari) [1980072]
- hwmon: (k10temp) Add Hygon Dhyana support (David Arcari) [1980072]
- hwmon: (k10temp) Auto-convert to use SENSOR_DEVICE_ATTR_{RO, RW, WO} (David Arcari) [1980072]
- hwmon: (k10temp) Support all Family 15h Model 6xh and Model 7xh processors (David Arcari) [1980072]
- hwmon: k10temp: Support Threadripper 2920X, 2970WX; simplify offset table (David Arcari) [1980072]
- hwmon: (k10temp) 27C Offset needed for Threadripper2 (David Arcari) [1980072]
- x86/amd_nb: Add AMD family 17h model 60h PCI IDs (David Arcari) [1980072]
- x86/amd_nb: Add PCI device IDs for family 17h, model 70h (David Arcari) [1980072]
- x86/pci, x86/amd_nb: Add Hygon Dhyana support to PCI and northbridge (David Arcari) [1980072]
- Revert "[hwmon] hwmon: (k10temp) Add support for Zen3 CPUs" (David Arcari) [1980072]
- serial: 8250: Process sysrq at port unlock time (Prarit Bhargava) [1982016]
- serial: core: Include console.h from serial_core.h (Prarit Bhargava) [1982016]
- serial: core: Allow processing sysrq at port unlock time (Prarit Bhargava) [1982016]
- [s390] s390/dasd: add missing discipline function (Claudio Imbrenda) [1981804]
- bnxt_en: Validate vlan protocol ID on RX packets (Jonathan Toppins) [1960961]
- KVM: do not allow mapping valid but non-reference-counted pages (Jon Maloy) [1975515]
- gfs2: Fix error handling in init_statfs (Andreas Gruenbacher) [1872440]
- gfs2: Fix underflow in gfs2_page_mkwrite (Andreas Gruenbacher) [1872440]
- gfs2: Pass glock holder to gfs2_file_direct_{read,write} (Andreas Gruenbacher) [1872440]
- gfs2: Prevent direct-I/O write fallback errors from getting lost (Andreas Gruenbacher) [1872440]
- gfs2: Improve mmap write vs. truncate consistency (Andreas Gruenbacher) [1872440]
- iomap: Permit pages without an iop to enter writeback (Andreas Gruenbacher) [1872440]
- iomap: Don't create iomap_page objects for inline files (Andreas Gruenbacher) [1872440]
- gfs2: Clean up gfs2_unstuff_dinode (Andreas Gruenbacher) [1872440]
- gfs2: Unstuff before locking page in gfs2_page_mkwrite (Andreas Gruenbacher) [1872440]
- gfs2: Clean up the error handling in gfs2_page_mkwrite (Andreas Gruenbacher) [1872440]
- gfs2: Fix end-of-file handling in gfs2_page_mkwrite (Andreas Gruenbacher) [1872440]
- gfs2: Use resource group glock sharing (Andreas Gruenbacher) [1442151]
- gfs2: Allow node-wide exclusive glock sharing (Andreas Gruenbacher) [1442151]
- gfs2: Add local resource group locking (Andreas Gruenbacher) [1442151]
- gfs2: Add per-reservation reserved block accounting (Andreas Gruenbacher) [1442151]
- gfs2: Rename rs_{free -> requested} and rd_{reserved -> requested} (Andreas Gruenbacher) [1442151]
- gfs2: Check for active reservation in gfs2_release (Andreas Gruenbacher) [1442151]
- gfs2: Don't search for unreserved space twice (Andreas Gruenbacher) [1442151]
- gfs2: Only pass reservation down to gfs2_rbm_find (Andreas Gruenbacher) [1442151]
- gfs2: Also reflect single-block allocations in rgd->rd_extfail_pt (Andreas Gruenbacher) [1442151]
- gfs2: Set GBF_FULL flags when reading resource group (Andreas Gruenbacher) [1442151]
- gfs2: Don't clear GBF_FULL flags in rs_deltree (Andreas Gruenbacher) [1442151]
- Revert "gfs2: Don't reject a supposedly full bitmap if we have blocks reserved" (Andreas Gruenbacher) [1442151]
- gfs2: Minor gfs2_inplace_reserve cleanup (Andreas Gruenbacher) [1442151]
- gfs2: Get rid of unnecessary variable in gfs2_alloc_blocks (Andreas Gruenbacher) [1442151]
- gfs2: Only use struct gfs2_rbm for bitmap manipulations (Andreas Gruenbacher) [1442151]
- gfs2: Turn gfs2_rbm_incr into gfs2_rbm_add (Andreas Gruenbacher) [1872440]
- gfs2: Replace gfs2_lblk_to_dblk with gfs2_get_extent (Andreas Gruenbacher) [1872440]
- gfs2: Turn gfs2_extent_map into gfs2_{get,alloc}_extent (Andreas Gruenbacher) [1872440]
- gfs2: Add new gfs2_iomap_get helper (Andreas Gruenbacher) [1872440]
- gfs2: Make inode operations static (Andreas Gruenbacher) [1872440]
- gfs2: use iomap for buffered I/O in ordered and writeback mode (Andreas Gruenbacher) [1872440]
- gfs2: Never call gfs2_block_zero_range with an open transaction (Andreas Gruenbacher) [1872440]
- gfs2: Upgrade shared glocks for atime updates (Andreas Gruenbacher) [1872440]
- gfs2: Rework read and page fault locking (Andreas Gruenbacher) [1872440]
- fs: Add IOCB_NOIO flag for generic_file_read_iter (Andreas Gruenbacher) [1872440]
- gfs2: Remove duplicate call from gfs2_create_inode (Andreas Gruenbacher) [1872440]
- gfs2: Multi-block allocations in gfs2_page_mkwrite (Andreas Gruenbacher) [1872440]
- gfs2: implement gfs2_block_zero_range using iomap_zero_range (Andreas Gruenbacher) [1872440]
- gfs2: Add support for IOMAP_ZERO (Andreas Gruenbacher) [1872440]
- gfs2: gfs2_iomap_begin cleanup (Andreas Gruenbacher) [1872440]
- gfs2: Remove unused gfs2_iomap_alloc argument (Andreas Gruenbacher) [1872440]
- gfs2: don't use buffer_heads in gfs2_allocate_page_backing (Andreas Gruenbacher) [1872440]
- gfs2: use iomap_bmap instead of generic_block_bmap (Andreas Gruenbacher) [1872440]
- gfs2: mark stuffed_readpage static (Andreas Gruenbacher) [1872440]
- gfs2: merge gfs2_writepage_common into gfs2_writepage (Andreas Gruenbacher) [1872440]
- gfs2: merge gfs2_writeback_aops and gfs2_ordered_aops (Andreas Gruenbacher) [1872440]
- gfs2: remove the unused gfs2_stuffed_write_end function (Andreas Gruenbacher) [1872440]
- gfs2: use page_offset in gfs2_page_mkwrite (Andreas Gruenbacher) [1442151]
- gfs2: Add new sysfs file for gfs2 status (Andreas Gruenbacher) [1442151]
- gfs2: Per-revoke accounting in transactions (Andreas Gruenbacher) [1442151]
- gfs2: Rework the log space allocation logic (Andreas Gruenbacher) [1442151]
- gfs2: Minor calc_reserved cleanup (Andreas Gruenbacher) [1442151]
- gfs2: Move function gfs2_ail_empty_tr (Andreas Gruenbacher) [1442151]
- gfs2: Get rid of current_tail() (Andreas Gruenbacher) [1442151]
- gfs2: Use a tighter bound in gfs2_trans_begin (Andreas Gruenbacher) [1442151]
- gfs2: Clean up gfs2_log_reserve (Andreas Gruenbacher) [1442151]
- gfs2: Don't wait for journal flush in clean_journal (Andreas Gruenbacher) [1442151]
- gfs2: Move lock flush locking to gfs2_trans_{begin,end} (Andreas Gruenbacher) [1442151]
- gfs2: Get rid of sd_reserving_log (Andreas Gruenbacher) [1442151]
- gfs2: Clean up on-stack transactions (Andreas Gruenbacher) [1442151]
- gfs2: Use sb_start_intwrite in gfs2_ail_empty_gl (Andreas Gruenbacher) [1442151]
- gfs2: Clean up ail2_empty (Andreas Gruenbacher) [1442151]
- gfs2: Rename gfs2_{write => flush}_revokes (Andreas Gruenbacher) [1442151]
- gfs2: Minor debugging improvement (Andreas Gruenbacher) [1442151]
- gfs2: Some documentation updates (Andreas Gruenbacher) [1442151]
- gfs2: Minor gfs2_write_revokes cleanups (Andreas Gruenbacher) [1442151]
- gfs2: Simplify the buf_limit and databuf_limit definitions (Andreas Gruenbacher) [1442151]
- gfs2: Un-obfuscate function jdesc_find_i (Andreas Gruenbacher) [1442151]
- gfs2: Fix fall-through warnings for Clang (Andreas Gruenbacher) [1442151]
- gfs2: Make gfs2_setattr_simple static (Andreas Gruenbacher) [1442151]
- gfs2: Turn gfs2_meta_indirect_buffer into gfs2_meta_buffer (Andreas Gruenbacher) [1442151]
- gfs2: Remove unused variable sb_format (Andreas Gruenbacher) [1442151]
- gfs2: Fix dir.c function parameter descriptions (Andreas Gruenbacher) [1442151]
- gfs2: Eliminate gh parameter from go_xmote_bh func (Andreas Gruenbacher) [1442151]
- gfs2: don't create empty buffers for NO_CREATE (Andreas Gruenbacher) [1442151]
- gfs2: Flag a withdraw if init_threads() fails (Andreas Gruenbacher) [1442151]
- gfs2: bypass log flush if the journal is not live (Andreas Gruenbacher) [1442151]
- gfs2: bypass signal_our_withdraw if no journal (Andreas Gruenbacher) [1442151]
- gfs2: fix use-after-free in trans_drain (Andreas Gruenbacher) [1442151]
- gfs2: make function gfs2_make_fs_ro() to void type (Andreas Gruenbacher) [1442151]
- whack-a-mole: don't open-code iminor/imajor (Andreas Gruenbacher) [1442151]
- gfs2: amend SLAB_RECLAIM_ACCOUNT on gfs2 related slab cache (Andreas Gruenbacher) [1442151]
- gfs2: Remove sb_start_write from gfs2_statfs_sync (Andreas Gruenbacher) [1442151]
- gfs2: check for empty rgrp tree in gfs2_ri_update (Andreas Gruenbacher) [1442151]
- gfs2: set lockdep subclass for iopen glocks (Andreas Gruenbacher) [1442151]
- gfs2: Fix deadlock dumping resource group glocks (Andreas Gruenbacher) [1442151]
- gfs2: Wake up when sd_glock_disposal becomes zero (Andreas Gruenbacher) [1442151]
- gfs2: Split up gfs2_meta_sync into inode and rgrp versions (Andreas Gruenbacher) [1442151]
- gfs2: Don't ignore inode write errors during inode_go_sync (Andreas Gruenbacher) [1442151]
- gfs2: Ignore subsequent errors after withdraw in rgrp_go_sync (Andreas Gruenbacher) [1442151]
- gfs2: Eliminate gl_vm (Andreas Gruenbacher) [1442151]
- gfs2: Fix comments to glock_hash_walk (Andreas Gruenbacher) [1442151]
- gfs2: eliminate GLF_QUEUED flag in favor of list_empty(gl_holders) (Andreas Gruenbacher) [1442151]
- gfs2: Fix invalid block size message (Andreas Gruenbacher) [1442151]
- gfs2: add validation checks for size of superblock (Andreas Gruenbacher) [1442151]
- gfs2: use-after-free in sysfs deregistration (Andreas Gruenbacher) [1442151]
- Revert "GFS2: Prevent delete work from occurring on glocks used for create" (Andreas Gruenbacher) [1442151]
- gfs2: Don't skip dlm unlock if glock has an lvb (Andreas Gruenbacher) [1442151]
- gfs2: Lock imbalance on error path in gfs2_recover_one (Andreas Gruenbacher) [1442151]
- gfs2: keep bios separate for each journal (Bob Peterson) [1442151]
- gfs2: change from write to read lock for sd_log_flush_lock in journal replay (Bob Peterson) [1442151]
- gfs2: don't lock sd_log_flush_lock in try_rgrp_unlink (Bob Peterson) [1442151]
- gfs2: fix glock confusion in function signal_our_withdraw (Bob Peterson) [1442151]
- gfs2: Don't write log headers after file system withdraw (Andreas Gruenbacher) [1442151]
- gfs2: make gfs2_log_write_page static (Andreas Gruenbacher) [1442151]
- gfs2: fix possible reference leak in gfs2_check_blk_type (Andreas Gruenbacher) [1442151]
- gfs2: Fix NULL pointer dereference in gfs2_rgrp_dump (Andreas Gruenbacher) [1442151]
- gfs2: remove unused LBIT macros (Andreas Gruenbacher) [1925121]
- gfs2: add missing log_blocks trace points in gfs2_write_revokes (Andreas Gruenbacher) [1925121]
- gfs2: print details on transactions that aren't properly ended (Andreas Gruenbacher) [1925121]
- gfs2: fix use-after-free on transaction ail lists (Andreas Gruenbacher) [1925121]
- gfs2: new slab for transactions (Andreas Gruenbacher) [1925121]
- gfs2: initialize transaction tr_ailX_lists earlier (Andreas Gruenbacher) [1925121]
- gfs2: eliminate ssize parameter from gfs2_struct2blk (Andreas Gruenbacher) [1925121]
- gfs2: Fix error path kobject memory leak (Andreas Gruenbacher) [1925121]
- gfs2: Rename gfs2_trans_{add_unrevoke => remove_revoke} (Andreas Gruenbacher) [1925121]
- gfs2: Remove unnecessary extern declarations (Andreas Gruenbacher) [1925121]
- gfs2: Fix sign extension bug in gfs2_update_stats (Andreas Gruenbacher) [1925121]
- gfs2: Fix an incorrect gfs2_assert() (Bob Peterson) [1925121]
- gfs2: Remove vestigial bd_ops (Andreas Gruenbacher) [1925121]
- gfs2: Fix the gfs2_invalidatepage description (Andreas Gruenbacher) [1925121]
- gfs2: Clean up gfs2_is_{ordered,writeback} (Andreas Gruenbacher) [1925121]
- gfs2: Pass resource group to rgblk_free (Andreas Gruenbacher) [1925121]
- gfs2: Remove unnecessary gfs2_rlist_alloc parameter (Andreas Gruenbacher) [1925121]
- gfs2: Fix some minor typos (Andreas Gruenbacher) [1925121]
- gfs2: Remove unused RGRP_RSRV_MINBYTES definition (Andreas Gruenbacher) [1925121]
- gfs2: Move rs_{sizehint, rgd_gh} fields into the inode (Andreas Gruenbacher) [1925121]
- gfs2: Clean up out-of-bounds check in gfs2_rbm_from_block (Andreas Gruenbacher) [1925121]
- gfs2: Always check the result of gfs2_rbm_from_block (Andreas Gruenbacher) [1925121]
- gfs: no need to check return value of debugfs_create functions (Andreas Gruenbacher) [1925121]
- serial_core: switch to ->[sg]et_serial() (Artem Savkov) [1952415]

* Thu Aug 05 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-329.el8]
- tipc: fix sleeping in tipc accept routine (Xin Long) [1986549]
- tipc: fix implicit-connect for SYN+ (Xin Long) [1986549]
- net: tipc: fix FB_MTU eat two pages (Xin Long) [1986549]
- tipc: Return the correct errno code (Xin Long) [1986549]
- net/mlx5: Fix checksum issue of VXLAN and IPsec crypto offload (Alaa Hleihel) [1979901]
- net/mlx5: Optimize mlx5e_feature_checks for non IPsec packet (Alaa Hleihel) [1979901]
- bpf, selftests: Fold test_current_pid_tgid_new_ns into test_progs. (Jiri Olsa) [1869447]
- libbpf: Support BTF_KIND_FLOAT during type compatibility checks in CO-RE (Jiri Olsa) [1984486]
- bpf: Generate BTF_KIND_FLOAT when linking vmlinux (Jiri Olsa) [1984486]
- selftests/bpf: Add BTF_KIND_FLOAT to btf_dump_test_case_syntax (Jiri Olsa) [1984486]
- selftests/bpf: Add BTF_KIND_FLOAT to test_core_reloc_size (Jiri Olsa) [1984486]
- bpf: Document BTF_KIND_FLOAT in btf.rst (Jiri Olsa) [1984486]
- selftests/bpf: Add BTF_KIND_FLOAT to the existing deduplication tests (Jiri Olsa) [1984486]
- selftest/bpf: Add BTF_KIND_FLOAT tests (Jiri Olsa) [1984486]
- bpf: Add BTF_KIND_FLOAT support (Jiri Olsa) [1984486]
- selftests/bpf: Use the 25th bit in the "invalid BTF_INFO" test (Jiri Olsa) [1984486]
- tools/bpftool: Add BTF_KIND_FLOAT support (Jiri Olsa) [1984486]
- libbpf: Add BTF_KIND_FLOAT support (Jiri Olsa) [1984486]
- bpf: Add BTF_KIND_FLOAT to uapi (Jiri Olsa) [1984486]
- libbpf: Add explicit padding to btf_dump_emit_type_decl_opts (Jiri Olsa) [1984486]
- selftests/bpf: Fix test_attach_probe for powerpc uprobes (Jiri Olsa) [1931531]
- selftests/bpf: Mask bpf_csum_diff() return value to 16 bits in test_verifier (Jiri Olsa) [1942513]
- openvswitch: add trace points (Aaron Conole) [1979680]
- vxlan: add missing rcu_read_lock() in neigh_reduce() (Guillaume Nault) [1987310]
- net: ip6_tunnel: Unregister catch-all devices (Guillaume Nault) [1987310]
- net: sit: Unregister catch-all devices (Guillaume Nault) [1987310]
- cpuidle: pseries: Do not cap the CEDE0 latency in fixup_cede0_latency() (Diego Domingos) [1952809]
- cpuidle: pseries: Fixup CEDE0 latency only for POWER10 onwards (Diego Domingos) [1952809]
- mm/swap: fix for "mm: workingset: age nonresident information alongside anonymous pages" (Rafael Aquini) [1984173]
- mm/thp: remap_page() is only needed on anonymous THP (Rafael Aquini) [1984173]
- mm/compaction: fix 'limit' in fast_isolate_freepages (Rafael Aquini) [1984173]
- mm/huge_memory.c: don't discard hugepage if other processes are mapping it (Rafael Aquini) [1984173]
- slub: restore slub_debug=- behavior (Rafael Aquini) [1984173]
- mm/gup: fix try_grab_compound_head() race with split_huge_page() (Rafael Aquini) [1984173]
- mm, futex: fix shared futex pgoff on shmem huge page (Rafael Aquini) [1984173]
- x86/mm: Avoid truncating memblocks for SGX memory (Rafael Aquini) [1984173]
- mm/thp: fix vma_address() if virtual address below file offset (Rafael Aquini) [1984173]
- mm, thp: use head page in __migration_entry_wait() (Rafael Aquini) [1984173]
- mm/slub.c: include swab.h (Rafael Aquini) [1984173]
- mm/memory-failure: make sure wait for page writeback in memory_failure (Rafael Aquini) [1984173]
- mm/slub: fix redzoning for small allocations (Rafael Aquini) [1984173]
- mm, hugetlb: fix simple resv_huge_pages underflow on UFFDIO_COPY (Rafael Aquini) [1984173]
- mm/page_alloc: fix counting of free pages after take off from buddy (Rafael Aquini) [1984173]
- userfaultfd: release page in error path to avoid BUG_ON (Rafael Aquini) [1984173]
- ksm: fix potential missing rmap_item for stable_node (Rafael Aquini) [1984173]
- mm/migrate.c: fix potential indeterminate pte entry in migrate_vma_insert_page() (Rafael Aquini) [1984173]
- mm/hugeltb: handle the error case in hugetlb_fix_reserve_counts() (Rafael Aquini) [1984173]
- khugepaged: fix wrong result value for trace_mm_collapse_huge_page_isolate() (Rafael Aquini) [1984173]
- mm/memory-failure: unnecessary amount of unmapping (Rafael Aquini) [1984173]
- mm: page_alloc: ignore init_on_free=1 for debug_pagealloc=1 (Rafael Aquini) [1984173]
- mm/sparse: add the missing sparse_buffer_fini() in error branch (Rafael Aquini) [1984173]
- mm: memcontrol: fix cpuhotplug statistics flushing (Rafael Aquini) [1984173]
- x86/mem_encrypt: Correct physical address calculation in __set_clr_pte_enc() (Rafael Aquini) [1984173]
- zsmalloc: account the number of compacted pages correctly (Rafael Aquini) [1984173]
- mm/compaction: fix misbehaviors of fast_find_migrateblock() (Rafael Aquini) [1984173]
- hugetlb: fix update_and_free_page contig page struct assumption (Rafael Aquini) [1984173]
- mm/hugetlb: fix potential double free in hugetlb_register_node() error path (Rafael Aquini) [1984173]
- mm/memory.c: fix potential pte_unmap_unlock pte error (Rafael Aquini) [1984173]
- mm/memory.c: fix potential pte_unmap_unlock pte error (Rafael Aquini) [1984173]
- mm/hugetlb: fix potential missing huge page size info (Rafael Aquini) [1984173]
- x86/mm: Fix leak of pmd ptlock (Rafael Aquini) [1984173]
- mm/zswap: fix passing zero to 'PTR_ERR' warning (Rafael Aquini) [1984173]
- mm/page_isolation: do not isolate the max order page (Rafael Aquini) [1984173]
- mm,memory_failure: always pin the page in madvise_inject_error (Rafael Aquini) [1984173]
- mm/page_alloc: speed up the iteration of max_order (Rafael Aquini) [1984173]
- x86/mm/mem_encrypt: Fix definition of PMD_FLAGS_DEC_WP (Rafael Aquini) [1984173]
- x86/mm/ident_map: Check for errors from ident_pud_init() (Rafael Aquini) [1984173]
- mm, oom_adj: don't loop through tasks in __set_oom_adj when not necessary (Rafael Aquini) [1984173]
- mm/page_alloc.c: fix freeing non-compound pages (Rafael Aquini) [1984173]
- mm: khugepaged: recalculate min_free_kbytes after memory hotplug as expected by khugepaged (Rafael Aquini) [1984173]
- percpu: fix first chunk size calculation for populated bitmap (Rafael Aquini) [1984173]
- x86, fakenuma: Fix invalid starting node ID (Rafael Aquini) [1984173]
- mm: include CMA pages in lowmem_reserve at boot (Rafael Aquini) [1984173]
- mm/rodata_test.c: fix missing function declaration (Rafael Aquini) [1984173]
- mm/page_counter: fix various data races at memsw (Rafael Aquini) [1984173]
- khugepaged: retract_page_tables() remember to test exit (Rafael Aquini) [1984173]
- mm/page_counter.c: fix protection usage propagation (Rafael Aquini) [1984173]
- x86/mm/numa: Remove uninitialized_var() usage (Rafael Aquini) [1984173]
- shmem: fix possible deadlocks on shmlock_user_lock (Rafael Aquini) [1984173]
- mm: swap: use smp_mb__after_atomic() to order LRU bit set (Rafael Aquini) [1984173]
- cgroup: memcg: net: do not associate sock with unrelated cgroup (Rafael Aquini) [1984173]
- mm: fix gup_pud_range (Rafael Aquini) [1984173]
- x86/mm: Fix NX bit clearing issue in kernel_map_pages_in_pgd (Rafael Aquini) [1984173]
- mm/shmem.c: thp, shmem: fix conflict of above-47bit hint address and PMD alignment (Rafael Aquini) [1984173]
- mm: Implement no-MMU variant of vmalloc_user_node_flags (Rafael Aquini) [1984173]
- usercopy: Avoid HIGHMEM pfn warning (Rafael Aquini) [1984173]
- x86/mm: Don't exceed the valid physical address space (Rafael Aquini) [1984173]
- x86/mm/mem_encrypt: Fix erroneous sizeof() (Rafael Aquini) [1984173]
- s390/mm: fix addressing exception after suspend/resume (Rafael Aquini) [1984173]
- blk-mq: fix use-after-free in blk_mq_exit_sched (Ming Lei) [1969726]
- nvmet: use new ana_log_size instead the old one (Maurizio Lombardi) [1949777]
- nvme-multipath: fix double initialization of ANA state (Maurizio Lombardi) [1949777]
- configs: enable CONFIG_LEDS_BRIGHTNESS_HW_CHANGED (Benjamin Tissoires) [1922973]

* Tue Aug 03 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-328.el8]
- Revert "xfs: enable new inode btree counters feature" (Bill O'Donnell) [1976969]
- Revert "xfs: enable big timestamps" (Bill O'Donnell) [1976969]
- Revert "xfs: remove kmem_realloc()" (Bill O'Donnell) [1976969]
- xfs: prevent metadata files from being inactivated (Bill O'Donnell) [1976969]
- quota: widen timestamps for the fs_disk_quota structure (Bill O'Donnell) [1976969]
- cifs: fix fallocate when trying to allocate a hole. (Ronnie Sahlberg) [1866684]
- cifs: only write 64kb at a time when fallocating a small region of a file (Ronnie Sahlberg) [1866684]
- cifs: improve fallocate emulation (Ronnie Sahlberg) [1866684]
- cifs: Do not use the original cruid when following DFS links for multiuser mounts (Ronnie Sahlberg) [1812436]
- cifs: ignore relatime in smb3_fs_context_parse_monolithic() (Ronnie Sahlberg) [1812436]
- cifs: fix regression when mounting shares with prefix paths (Ronnie Sahlberg) [1812436]
- cifs: fix leak in cifs_smb3_do_mount() ctx (Ronnie Sahlberg) [1812436]
- cifs: add fs_context param to parsing helpers (Ronnie Sahlberg) [1812436]
- cifs: make fs_context error logging wrapper (Ronnie Sahlberg) [1812436]
- cifs: warn and fail if trying to use rootfs without the config option (Ronnie Sahlberg) [1812436]
- cifs: fix nodfs mount option (Ronnie Sahlberg) [1812436]
- cifs: fix handling of escaped ',' in the password mount argument (Ronnie Sahlberg) [1812436]
- cifs: Add new parameter "acregmax" for distinct file and directory metadata timeout (Ronnie Sahlberg) [1812436]
- cifs: convert revalidate of directories to using directory metadata cache timeout (Ronnie Sahlberg) [1812436]
- cifs: Add new mount parameter "acdirmax" to allow caching directory metadata (Ronnie Sahlberg) [1812436]
- cifs: fix trivial typo (Ronnie Sahlberg) [1812436]
- cifs: Set CIFS_MOUNT_USE_PREFIX_PATH flag on setting cifs_sb->prepath. (Ronnie Sahlberg) [1812436]
- cifs: In the new mount api we get the full devname as source= (Ronnie Sahlberg) [1812436]
- cifs: do not disable noperm if multiuser mount option is not provided (Ronnie Sahlberg) [1812436]
- cifs: fix dfs-links (Ronnie Sahlberg) [1812436]
- cifs: fix dfs domain referrals (Ronnie Sahlberg) [1812436]
- cifs: returning mount parm processing errors correctly (Ronnie Sahlberg) [1812436]
- cifs: fix mounts to subdirectories of target (Ronnie Sahlberg) [1812436]
- cifs: ignore auto and noauto options if given (Ronnie Sahlberg) [1812436]
- cifs: connect: style: Simplify bool comparison (Ronnie Sahlberg) [1812436]
- fs: cifs: remove unneeded variable in smb3_fs_context_dup (Ronnie Sahlberg) [1812436]
- cifs: Fix support for remount when not changing rsize/wsize (Ronnie Sahlberg) [1812436]
- cifs: handle "guest" mount parameter (Ronnie Sahlberg) [1812436]
- cifs: correct four aliased mount parms to allow use of previous names (Ronnie Sahlberg) [1812436]
- cifs: fix use after free in cifs_smb3_do_mount() (Ronnie Sahlberg) [1812436]
- cifs: fix rsize/wsize to be negotiated values (Ronnie Sahlberg) [1812436]
- cifs: update super_operations to show_devname (Ronnie Sahlberg) [1812436]
- cifs: fix uninitialized variable in smb3_fs_context_parse_param (Ronnie Sahlberg) [1812436]
- cifs: update mnt_cifs_flags during reconfigure (Ronnie Sahlberg) [1812436]
- cifs: move update of flags into a separate function (Ronnie Sahlberg) [1812436]
- cifs: remove ctx argument from cifs_setup_cifs_sb (Ronnie Sahlberg) [1812436]
- cifs: do not allow changing posix_paths during remount (Ronnie Sahlberg) [1812436]
- cifs: uncomplicate printing the iocharset parameter (Ronnie Sahlberg) [1812436]
- cifs: don't create a temp nls in cifs_setup_ipc (Ronnie Sahlberg) [1812436]
- cifs: simplify handling of cifs_sb/ctx->local_nls (Ronnie Sahlberg) [1812436]
- cifs: we do not allow changing username/password/unc/... during remount (Ronnie Sahlberg) [1812436]
- cifs: add initial reconfigure support (Ronnie Sahlberg) [1812436]
- cifs: move [brw]size from cifs_sb to cifs_sb->ctx (Ronnie Sahlberg) [1812436]
- cifs: move cifs_cleanup_volume_info[_content] to fs_context.c (Ronnie Sahlberg) [1812436]
- cifs: Add missing sentinel to smb3_fs_parameters (Ronnie Sahlberg) [1812436]
- cifs: remove actimeo from cifs_sb (Ronnie Sahlberg) [1812436]
- cifs: remove [gu]id/backup[gu]id/file_mode/dir_mode from cifs_sb (Ronnie Sahlberg) [1812436]
- cifs: minor kernel style fixes for comments (Ronnie Sahlberg) [1812436]
- linux/parser.h: add include guards (Ronnie Sahlberg) [1812436]
- cifs: Make extract_sharename function public (Ronnie Sahlberg) [1812436]
- cifs: Make extract_hostname function public (Ronnie Sahlberg) [1812436]
- cifs: get rid of cifs_sb->mountdata (Ronnie Sahlberg) [1812436]
- cifs: add an smb3_fs_context to cifs_sb (Ronnie Sahlberg) [1812436]
- cifs: remove the devname argument to cifs_compose_mount_options (Ronnie Sahlberg) [1812436]
- cifs: switch to new mount api (Ronnie Sahlberg) [1812436]
- cifs: move cifs_parse_devname to fs_context.c (Ronnie Sahlberg) [1812436]
- cifs: move the enum for cifs parameters into fs_context.h (Ronnie Sahlberg) [1812436]
- cifs: rename dup_vol to smb3_fs_context_dup and move it into fs_context.c (Ronnie Sahlberg) [1812436]
- cifs: rename smb_vol as smb3_fs_context and move it to fs_context.h (Ronnie Sahlberg) [1812436]
- cifs: Fix fall-through warnings for Clang (Ronnie Sahlberg) [1812436]
- cifs: refactor create_sd_buf() and and avoid corrupting the buffer (Ronnie Sahlberg) [1812436]
- scsi: lpfc: Fix failure to transmit ABTS on FC link (Dick Kennedy) [1964670]
- scsi: lpfc: Update lpfc version to 12.8.0.10 (Dick Kennedy) [1964670]
- scsi: lpfc: Reregister FPIN types if ELS_RDF is received from fabric controller (Dick Kennedy) [1964670]
- scsi: lpfc: Add a option to enable interlocked ABTS before job completion (Dick Kennedy) [1964670]
- scsi: lpfc: Fix crash when lpfc_sli4_hba_setup() fails to initialize the SGLs (Dick Kennedy) [1964670]
- scsi: lpfc: Ignore GID-FT response that may be received after a link flip (Dick Kennedy) [1964670]
- scsi: lpfc: Fix node handling for Fabric Controller and Domain Controller (Dick Kennedy) [1964670]
- scsi: lpfc: Fix Node recovery when driver is handling simultaneous PLOGIs (Dick Kennedy) [1964670]
- scsi: lpfc: Add ndlp kref accounting for resume RPI path (Dick Kennedy) [1964670]
- scsi: lpfc: Fix "Unexpected timeout" error in direct attach topology (Dick Kennedy) [1964670]
- scsi: lpfc: Fix non-optimized ERSP handling (Dick Kennedy) [1964670]
- scsi: lpfc: Fix unreleased RPIs when NPIV ports are created (Dick Kennedy) [1964670]
- scsi: lpfc: Remove redundant assignment to pointer temp_hdr (Dick Kennedy) [1964670]
- Documentation: add more details in tipc.rst (Xin Long) [1872308]
- net/tipc: add TIPC chapter to networking Documentation (Xin Long) [1872308]
- scsi: qla2xxx: Reserve extra IRQ vectors (Nilesh Javali) [1964834]
- tracing/hwlat: Honor the tracing_cpumask (Jerome Marchand) [1920595]
- tracing/hwlat: Drop the duplicate assignment in start_kthread() (Jerome Marchand) [1920595]
- sfc: add logs explaining XDP_TX/REDIRECT is not available (Íñigo Huguet) [1976756]
- sfc: ensure correct number of XDP queues (Íñigo Huguet) [1976756]
- sfc: fix lack of XDP TX queues - error XDP TX failed (-22) (Íñigo Huguet) [1976756]
- sfc: Remove rcu_read_lock() around XDP program invocation (Íñigo Huguet) [1976756]
- sfc: use DEVICE_ATTR_*() macro (Íñigo Huguet) [1976756]
- sfc: farch: fix compile warning in efx_farch_dimension_resources() (Íñigo Huguet) [1976756]
- sfc: don't use netif_info et al before net_device is registered (Íñigo Huguet) [1976756]
- net: stmmac: Do not enable RX FIFO overflow interrupts (Mark Salter) [1905243]
- net: stmmac: Clear receive all(RA) bit when promiscuous mode is off (Mark Salter) [1905243]
- net: stmmac: cleared __FPE_REMOVING bit in stmmac_fpe_start_wq() (Mark Salter) [1905243]
- stmmac: intel: Enable HW descriptor prefetch by default (Mark Salter) [1905243]
- net: stmmac: Add HW descriptor prefetch setting for DWMAC Core 5.20 onwards (Mark Salter) [1905243]
- net: stmmac: fix TSO and TBS feature enabling during driver open (Mark Salter) [1905243]
- stmmac: intel: set TSO/TBS TX Queues default settings (Mark Salter) [1905243]
- stmmac: intel: unlock on error path in intel_crosststamp() (Mark Salter) [1905243]
- net: stmmac: use __napi_schedule() for PREEMPT_RT (Mark Salter) [1905243]
- stmmac: intel: Enable SERDES PHY rx clk for PSE (Mark Salter) [1905243]
- stmmac: intel: Drop duplicate ID in the list of PCI device IDs (Mark Salter) [1905243]
- stmmac: intel: add cross time-stamping freq difference adjustment (Mark Salter) [1905243]
- net: stmmac: Add support for external trigger timestamping (Mark Salter) [1905243]
- net: stmmac: fix dma physical address of descriptor when display ring (Mark Salter) [1905243]
- net: stmmac: fix wrongly set buffer2 valid when sph unsupport (Mark Salter) [1905243]
- net: stmmac: arrange Tx tail pointer update to stmmac_flush_tx_descriptors (Mark Salter) [1905243]
- net: stmmac: make SPH enable/disable to be configurable (Mark Salter) [1905243]
- net: stmmac: set IRQ affinity hint for multi MSI vectors (Mark Salter) [1905243]
- net: stmmac: remove unnecessary pci_enable_msi() call (Mark Salter) [1905243]
- stmmac: intel: use managed PCI function on probe and resume (Mark Salter) [1905243]
- net: stmmac: enable MTL ECC Error Address Status Over-ride by default (Mark Salter) [1905243]
- net: ethernet: stmicro: Remove duplicate struct declaration (Mark Salter) [1905243]
- net: stmmac: fix missing unlock on error in stmmac_suspend() (Mark Salter) [1905243]
- net: stmmac: Fix kernel panic due to NULL pointer dereference of fpe_cfg (Mark Salter) [1905243]
- net: stmmac: use interrupt mode INTM=1 for multi-MSI (Mark Salter) [1905243]
- stmmac: intel: add support for multi-vector msi and msi-x (Mark Salter) [1905243]
- net: stmmac: introduce MSI Interrupt routines for mac, safety, RX & TX (Mark Salter) [1905243]
- net: stmmac: make stmmac_interrupt() function more friendly to MSI (Mark Salter) [1905243]
- net: stmmac: introduce DMA interrupt status masking per traffic direction (Mark Salter) [1905243]
- net: phy: marvell10g: Add PHY loopback support (Mark Salter) [1905243]
- net: phy: add genphy_c45_loopback (Mark Salter) [1905243]
- net: phylink: Fix phylink_err() function name error in phylink_major_config (Mark Salter) [1905243]
- net: stmmac: support FPE link partner hand-shaking procedure (Mark Salter) [1905243]
- net: stmmac: Add hardware supported cross-timestamp (Mark Salter) [1905243]
- net: stmmac: platform: fix build error with !CONFIG_PM_SLEEP (Mark Salter) [1905243]
- stmmac: intel: Add PSE and PCH PTP clock source selection (Mark Salter) [1905243]
- net: stmmac: Add EST errors into ethtool statistic (Mark Salter) [1905243]
- net: stmmac: EST interrupts handling and error reporting (Mark Salter) [1905243]
- net: stmmac: add RX frame steering based on VLAN priority in tc flower (Mark Salter) [1905243]
- net: stmmac: restructure tc implementation for RX VLAN Priority steering (Mark Salter) [1905243]
- net: stmmac: add per-queue TX & RX coalesce ethtool support (Mark Salter) [1905243]
- net: stmmac: Use hrtimer for TX coalescing (Mark Salter) [1905243]
- net: stmmac: add timestamp correction to rid CDC sync error (Mark Salter) [1905243]
- net: stmmac: add platform level clocks management (Mark Salter) [1905243]
- net: stmmac: add clocks management for gmac driver (Mark Salter) [1905243]
- stmmac: intel: add pcs-xpcs for Intel mGbE controller (Mark Salter) [1905243]
- net: stmmac: ensure phydev is attached to phylink for C37 AN (Mark Salter) [1905243]
- net: stmmac: make in-band AN mode parsing is supported for non-DT (Mark Salter) [1905243]
- net: phylink: make phylink_parse_mode() support non-DT platform (Mark Salter) [1905243]
- net: pcs: add C37 SGMII AN support for intel mGbE controller (Mark Salter) [1905243]
- net: pcs: rearrange C73 functions to prepare for C37 support later (Mark Salter) [1905243]
- net: phy: leds: Deduplicate link LED trigger registration (Mark Salter) [1905243]
- net: stmmac: Fix VLAN filter delete timeout issue in Intel mGBE SGMII (Mark Salter) [1905243]
- net: stmmac: fix incorrect DMA channel intr enable setting of EQoS v4.10 (Mark Salter) [1905243]
- net: stmmac: fix CBS idleslope and sendslope calculation (Mark Salter) [1905243]
- net: stmmac: set TxQ mode back to DCB after disabling CBS (Mark Salter) [1905243]
- net: stmmac: allow stmmac to probe for C45 PHY devices (Mark Salter) [1905243]
- net: stmmac: Enable EEE HW LPI timer with auto SW/HW switching (Mark Salter) [1905243]
- net: pcs-xpcs: depend on MDIO_BUS instead of selecting it (Mark Salter) [1905243]
- net: pcs: Move XPCS into new PCS subdirectory (Mark Salter) [1905243]
- net: stmmac: Add XLGMII support (Mark Salter) [1905243]
- net: phy: xpcs: Add XLGMII support (Mark Salter) [1905243]
- net: phy: xpcs: Restart AutoNeg if outcome was invalid (Mark Salter) [1905243]
- net: phy: xpcs: Set Link down if AutoNeg is enabled and did not finish (Mark Salter) [1905243]
- net: phy: xpcs: Reset XPCS upon probe (Mark Salter) [1905243]
- net: phy: xpcs: Return error when 10GKR link errors are found (Mark Salter) [1905243]
- stmmac/intel: mark driver as tech preview (Mark Salter) [1905243]
- redhat/configs: Add CONFIG_DWMAC_INTEL (Mark Salter) [1905243]
- stmmac: intel: Fixes clock registration error seen for multiple interfaces (Mark Salter) [1905243]
- stmmac: intel: Fix mdio bus registration issue for TGL-H/ADL-S (Mark Salter) [1905243]
- net: stmmac: Add PCI bus info to ethtool driver query output (Mark Salter) [1905243]
- stmmac: intel: Add ADL-S 1Gbps PCI IDs (Mark Salter) [1905243]
- stmmac: intel: Configure EHL PSE0 GbE and PSE1 GbE to 32 bits DMA addressing (Mark Salter) [1905243]
- stmmac: intel: Add PCI IDs for TGL-H platform (Mark Salter) [1905243]
- stmmac: intel: change all EHL/TGL to auto detect phy addr (Mark Salter) [1905243]
- net: stmmac: overwrite the dma_cap.addr64 according to HW design (Mark Salter) [1905243]
- stmmac: intel: Fix kernel panic on pci probe (Mark Salter) [1905243]
- stmmac: intel: Adding ref clock 1us tic for LPI cntr (Mark Salter) [1905243]
- net: stmmac: Add option for VLAN filter fail queue enable (Mark Salter) [1905243]
- net: stmmac: Fix clock handling on remove path (Mark Salter) [1905243]
- stmmac: intel: Place object in the Makefile according to the order (Mark Salter) [1905243]
- stmmac: intel: Fix indentation to put on one line affected code (Mark Salter) [1905243]
- stmmac: intel: Eliminate useless conditions and variables (Mark Salter) [1905243]
- stmmac: intel: Convert to use pci_alloc_irq_vectors() API (Mark Salter) [1905243]
- stmmac: intel: Remove unnecessary loop for PCI BARs (Mark Salter) [1905243]
- stmmac: intel: Fix clock handling on error and remove paths (Mark Salter) [1905243]
- net: stmmac: Enable SERDES power up/down sequence (Mark Salter) [1905243]
- net: stmmac: add EHL 2.5Gbps PCI info and PCI ID (Mark Salter) [1905243]
- net: stmmac: add EHL PSE0 & PSE1 1Gbps PCI info and PCI ID (Mark Salter) [1905243]
- net: stmmac: create dwmac-intel.c to contain all Intel platform (Mark Salter) [1905243]
- net: stmmac: Get rid of custom STMMAC_DEVICE() macro (Mark Salter) [1905243]
- net: stmmac: update pci platform data to use phy_interface (Mark Salter) [1905243]
- net: stmmac: pci: Enable TBS on GMAC5 IPK PCI entry (Mark Salter) [1905243]
- net: stmmac: pci: remove the duplicate code of set phy_mask (Mark Salter) [1905243]
- PCI: Add PCI_STD_NUM_BARS for the number of standard BARs (Mark Salter) [1905243]
- net: stmmac: pci: Add HAPS support using GMAC5 (Mark Salter) [1905243]
- net: stmmac: setup higher frequency clk support for EHL & TGL (Mark Salter) [1905243]
- net: stmmac: add EHL RGMII 1Gbps PCI info and PCI ID (Mark Salter) [1905243]
- net: stmmac: add TGL SGMII 1Gbps PCI info and PCI ID (Mark Salter) [1905243]
- net: stmmac: add EHL SGMII 1Gbps PCI info and PCI ID (Mark Salter) [1905243]
- net: stmmac: Make MDIO bus reset optional (Mark Salter) [1905243]
- stmmac: pci: Use pci_dev_id() helper (Mark Salter) [1905243]
- stmmac: pci: Fix typo in IOT2000 comment (Mark Salter) [1905243]
- stmmac: pci: Adjust IOT2000 matching (Mark Salter) [1905243]
- net: stmmac: Fix PCI module removal leak (Mark Salter) [1905243]
- net: stmmac: mark PM functions as __maybe_unused (Mark Salter) [1905243]
- ibmveth: Set CHECKSUM_PARTIAL if NULL TCP CSUM. (Diego Domingos) [1939996]
- IB/core: Add missing pin_user_pages*() usage (Waiman Long) [1972078]
- mm/gup/writeback: Fix incorrect inaccessible pages handling (Waiman Long) [1972078]
- netfilter: nf_tables: bogus EBUSY when deleting flowtable after flush (Phil Sutter) [1983245]
- ipv4: Fix device used for dst_alloc with local routes (Antoine Tenart) [1976789]
- vrf: fix a comment about loopback device (Antoine Tenart) [1976789]
- net: vrf: Fix operation not supported when set vrf mac (Antoine Tenart) [1976789]
- vrf: prevent adding upper devices (Antoine Tenart) [1976789]
- vrf: fix maximum MTU (Antoine Tenart) [1976789]
- net: vrf: Fix ping failed when vrf mtu is set to 0 (Antoine Tenart) [1976789]
- net: vrf: remove MTU limits for vrf device (Antoine Tenart) [1976789]

* Fri Jul 30 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-327.el8]
- block: fix discard request merge (Ming Lei) [1970316]
- blk-mq: update hctx->dispatch_busy in case of real scheduler (Ming Lei) [1976679]
- block: Do not pull requests from the scheduler when we cannot dispatch them (Ming Lei) [1976679]
- powerpc/pseries/mobility: handle premature return from H_JOIN (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: use struct for shared state (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: refactor node lookup during DT update (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: remove rtas_ibm_suspend_me_unsafe() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: dispatch partition migration requests to pseries (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: retry partition suspend after error (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: signal suspend cancellation to platform (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: use stop_machine for join/suspend (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: extract VASI session polling logic (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: use rtas_activate_firmware() on resume (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: error message improvements (Desnes A. Nunes do Rosario) [1979798]
- powerpc/hvcall: add token and codes for H_VASI_SIGNAL (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: add rtas_activate_firmware() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: add rtas_ibm_suspend_me() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: rtas_ibm_suspend_me -> rtas_ibm_suspend_me_unsafe (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: complete ibm,suspend-me status codes (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: Add pr_debug() for device tree changes (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries/mobility: Set pr_fmt() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries: remove obsolete memory hotplug DT notifier code (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries: remove dlpar_cpu_readd() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries: remove memory "re-add" implementation (Desnes A. Nunes do Rosario) [1979798]
- powerpc/pseries: remove prrn special case from DT update path (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove arch_update_cpu_topology (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove prrn_is_enabled() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtasd: simplify handle_rtas_event(), emit message on events (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove start/stop_topology_update() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove timed_topology_update() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: Handle extra hcall_vphn error cases (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: Suppress "VPHN is not supported" messages (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: stub out numa_update_cpu_topology() (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove vphn_enabled and prrn_enabled internal flags (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove unreachable topology workqueue code (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove unreachable topology timer code (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: make vphn_enabled, prrn_enabled flags const (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove unreachable topology update code (Desnes A. Nunes do Rosario) [1979798]
- powerpc/numa: remove ability to enable topology updates (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: don't online CPUs for partition suspend (Desnes A. Nunes do Rosario) [1979798]
- powerpc/rtas: Unexport rtas_online_cpus_mask, rtas_offline_cpus_mask (Desnes A. Nunes do Rosario) [1979798]
- mm/page_alloc: bail out on fatal signal during reclaim/compaction retry attempt (Aaron Tomlin) [1919765]
- RHEL: Revert "powerpc/kvm: Fix PR KVM with KUAP/MEM_KEYS enabled" (Paolo Bonzini) [1956950]
- KVM: selftests: smm_test: Test SMM enter from L2 (Paolo Bonzini) [1956950]
- KVM: nSVM: Restore nested control upon leaving SMM (Paolo Bonzini) [1956950]
- KVM: nSVM: Fix L1 state corruption upon return from SMM (Paolo Bonzini) [1956950]
- KVM: nSVM: Introduce svm_copy_vmrun_state() (Paolo Bonzini) [1956950]
- KVM: nSVM: Check that VM_HSAVE_PA MSR was set before VMRUN (Paolo Bonzini) [1956950]
- KVM: nVMX: nSVM: 'nested_run' should count guest-entry attempts that make it to guest code (Paolo Bonzini) [1956950]
- KVM: nSVM: Check the value written to MSR_VM_HSAVE_PA (Paolo Bonzini) [1956950]
- KVM: SVM: Fix sev_pin_memory() error checks in SEV migration utilities (Paolo Bonzini) [1956950]
- KVM: SVM: Return -EFAULT if copy_to_user() for SEV mig packet header fails (Paolo Bonzini) [1956950]
- KVM: SVM: add module param to control the #SMI interception (Paolo Bonzini) [1956950]
- KVM: SVM: remove INIT intercept handler (Paolo Bonzini) [1956950]
- KVM: SVM: #SMI interception must not skip the instruction (Paolo Bonzini) [1956950]
- KVM: VMX: Remove vmx_msr_index from vmx.h (Paolo Bonzini) [1956950]
- KVM: X86: Disable hardware breakpoints unconditionally before kvm_x86->run() (Paolo Bonzini) [1956950]
- KVM: x86/pmu: Clear anythread deprecated bit when 0xa leaf is unsupported on the SVM (Paolo Bonzini) [1956950]
- KVM: mmio: Fix use-after-free Read in kvm_vm_ioctl_unregister_coalesced_mmio (Paolo Bonzini) [1956950]
- KVM: SVM: Revert clearing of C-bit on GPA in #NPF handler (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Do not apply HPA (memory encryption) mask to GPAs (Paolo Bonzini) [1956950]
- KVM: x86: Use kernel's x86_phys_bits to handle reduced MAXPHYADDR (Paolo Bonzini) [1956950]
- KVM: x86: Use guest MAXPHYADDR from CPUID.0x8000_0008 iff TDP is enabled (Paolo Bonzini) [1956950]
- KVM: selftests: do not require 64GB in set_memory_region_test (Paolo Bonzini) [1956950]
- KVM: selftests: Fix mapping length truncation in m{,un}map() (Paolo Bonzini) [1956950]
- KVM: x86: Force all MMUs to reinitialize if guest CPUID is modified (Paolo Bonzini) [1956950]
- Revert "KVM: x86/mmu: Drop kvm_mmu_extended_role.cr4_la57 hack" (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Use MMU's role to detect CR4.SMEP value in nested NPT walk (Paolo Bonzini) [1956950]
- KVM: x86: Properly reset MMU context at vCPU RESET/INIT (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Treat NX as used (not reserved) for all !TDP shadow MMUs (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Remove broken WARN that fires on 32-bit KVM w/ nested EPT (Paolo Bonzini) [1956950]
- KVM: nVMX: Handle split-lock #AC exceptions that happen in L2 (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Calculate and check "full" mmu_role for nested MMU (Paolo Bonzini) [1956950]
- KVM: X86: Fix x86_emulator slab cache leak (Paolo Bonzini) [1956950]
- KVM: SVM: Call SEV Guest Decommission if ASID binding fails (Paolo Bonzini) [1956950]
- KVM: x86: Immediately reset the MMU context when the SMM flag is cleared (Paolo Bonzini) [1956950]
- KVM: x86: Fix fall-through warnings for Clang (Paolo Bonzini) [1956950]
- KVM: SVM: fix doc warnings (Paolo Bonzini) [1956950]
- kvm: LAPIC: Restore guard to prevent illegal APIC register access (Paolo Bonzini) [1956950]
- kvm: fix previous commit for 32-bit builds (Paolo Bonzini) [1956950]
- kvm: avoid speculation-based attacks from out-of-range memslot accesses (Paolo Bonzini) [1956950]
- KVM: x86: Ensure liveliness of nested VM-Enter fail tracepoint message (Paolo Bonzini) [1956950]
- KVM: x86: Ensure PV TLB flush tracepoint reflects KVM behavior (Paolo Bonzini) [1956950]
- KVM: X86: MMU: Use the correct inherited permissions to get shadow page (Paolo Bonzini) [1956950]
- KVM: LAPIC: Write 0 to TMICT should also cancel vmx-preemption timer (Paolo Bonzini) [1956950]
- KVM: SVM: Fix SEV SEND_START session length & SEND_UPDATE_DATA query length after commit 238eca821cee (Paolo Bonzini) [1956950]
- KVM: X86: Kill off ctxt->ud (Paolo Bonzini) [1956950]
- KVM: X86: Fix warning caused by stale emulation context (Paolo Bonzini) [1956950]
- KVM: X86: Use kvm_get_linear_rip() in single-step and #DB/#BP interception (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Fix comment mentioning skip_4k (Paolo Bonzini) [1956950]
- KVM: VMX: update vcpu posted-interrupt descriptor when assigning device (Paolo Bonzini) [1956950]
- KVM: rename KVM_REQ_PENDING_TIMER to KVM_REQ_UNBLOCK (Paolo Bonzini) [1956950]
- KVM: x86: add start_assignment hook to kvm_x86_ops (Paolo Bonzini) [1956950]
- KVM: LAPIC: Narrow the timer latency between wait_lapic_expire and world switch (Paolo Bonzini) [1956950]
- KVM: X86: Fix vCPU preempted state from guest's point of view (Paolo Bonzini) [1956950]
- KVM: X86: Bail out of direct yield in case of under-committed scenarios (Paolo Bonzini) [1956950]
- KVM: SVM: make the avic parameter a bool (Paolo Bonzini) [1956950]
- KVM: VMX: Drop unneeded CONFIG_X86_LOCAL_APIC check (Paolo Bonzini) [1956950]
- KVM: SVM: Drop unneeded CONFIG_X86_LOCAL_APIC check (Paolo Bonzini) [1956950]
- KVM: SVM: Move GHCB unmapping to fix RCU warning (Paolo Bonzini) [1956950]
- KVM: SVM: Invert user pointer casting in SEV {en,de}crypt helpers (Paolo Bonzini) [1956950]
- kvm: Cap halt polling at kvm->max_halt_poll_ns (Paolo Bonzini) [1956950]
- KVM: x86: Prevent deadlock against tk_core.seq (Paolo Bonzini) [1956950]
- KVM: x86: Cancel pvclock_gtod_work on module removal (Paolo Bonzini) [1956950]
- KVM: x86: Prevent KVM SVM from loading on kernels with 5-level paging (Paolo Bonzini) [1956950]
- KVM: SVM: Probe and load MSR_TSC_AUX regardless of RDTSCP support in host (Paolo Bonzini) [1956950]
- KVM: VMX: Disable preemption when probing user return MSRs (Paolo Bonzini) [1956950]
- KVM: x86: Move RDPID emulation intercept to its own enum (Paolo Bonzini) [1956950]
- KVM: SVM: Inject #UD on RDTSCP when it should be disabled in the guest (Paolo Bonzini) [1956950]
- KVM: x86: Emulate RDPID only if RDTSCP is supported (Paolo Bonzini) [1956950]
- KVM: VMX: Do not advertise RDPID if ENABLE_RDTSCP control is unsupported (Paolo Bonzini) [1956950]
- KVM: nSVM: always restore the L1's GIF on migration (Paolo Bonzini) [1956950]
- KVM: x86: Hoist input checks in kvm_add_msr_filter() (Paolo Bonzini) [1956950]
- KVM: nVMX: Properly pad 'struct kvm_vmx_nested_state_hdr' (Paolo Bonzini) [1956950]
- KVM/VMX: Invoke NMI non-IST entry instead of IST entry (Paolo Bonzini) [1956950]
- KVM: x86: Fix potential fput on a null source_kvm_file (Paolo Bonzini) [1956950]
- KVM: nSVM: leave the guest mode prior to loading a nested state (Paolo Bonzini) [1956950]
- KVM: nSVM: fix few bugs in the vmcb02 caching logic (Paolo Bonzini) [1956950]
- KVM: nSVM: fix a typo in svm_leave_nested (Paolo Bonzini) [1956950]
- KVM: PPC: exit halt polling on need_resched() (Paolo Bonzini) [1956950]
- kvm: exit halt polling on need_resched() as well (Paolo Bonzini) [1956950]
- KVM: LAPIC: Accurately guarantee busy wait for timer to expire when using hv_timer (Paolo Bonzini) [1956950]
- kvm/x86: Fix 'lpages' kvm stat for TDM MMU (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Avoid unnecessary page table allocation in kvm_tdp_mmu_map() (Paolo Bonzini) [1956950]
- KVM: selftests: Speed up set_memory_region_test (Paolo Bonzini) [1956950]
- selftests: kvm: Fix the check of return value (Paolo Bonzini) [1956950]
- KVM: x86: Take advantage of kvm_arch_dy_has_pending_interrupt() (Paolo Bonzini) [1956950]
- KVM: SVM: Skip SEV cache flush if no ASIDs have been used (Paolo Bonzini) [1956950]
- KVM: SVM: Remove an unnecessary prototype declaration of sev_flush_asids() (Paolo Bonzini) [1956950]
- KVM: SVM: Drop redundant svm_sev_enabled() helper (Paolo Bonzini) [1956950]
- KVM: SVM: Move SEV VMCB tracking allocation to sev.c (Paolo Bonzini) [1956950]
- KVM: SVM: Explicitly check max SEV ASID during sev_hardware_setup() (Paolo Bonzini) [1956950]
- KVM: SVM: Unconditionally invoke sev_hardware_teardown() (Paolo Bonzini) [1956950]
- KVM: SVM: Enable SEV/SEV-ES functionality by default (when supported) (Paolo Bonzini) [1956950]
- KVM: SVM: Condition sev_enabled and sev_es_enabled on CONFIG_KVM_AMD_SEV=y (Paolo Bonzini) [1956950]
- KVM: SVM: Append "_enabled" to module-scoped SEV/SEV-ES control variables (Paolo Bonzini) [1956950]
- KVM: SEV: Mask CPUID[0x8000001F].eax according to supported features (Paolo Bonzini) [1956950]
- KVM: SVM: Move SEV module params/variables to sev.c (Paolo Bonzini) [1956950]
- svm/sev: Register SEV and SEV-ES ASIDs to the misc controller (Paolo Bonzini) [1956950]
- KVM: SVM: Disable SEV/SEV-ES if NPT is disabled (Paolo Bonzini) [1956950]
- KVM: SVM: Free sev_asid_bitmap during init if SEV setup fails (Paolo Bonzini) [1956950]
- KVM: SVM: Zero out the VMCB array used to track SEV ASID association (Paolo Bonzini) [1956950]
- KVM: x86: Move reverse CPUID helpers to separate header file (Paolo Bonzini) [1956950]
- KVM: x86: Rename GPR accessors to make mode-aware variants the defaults (Paolo Bonzini) [1956950]
- KVM: SVM: Use default rAX size for INVLPGA emulation (Paolo Bonzini) [1956950]
- KVM: x86/xen: Drop RAX[63:32] when processing hypercall (Paolo Bonzini) [1956950]
- KVM: nVMX: Truncate base/index GPR value on address calc in !64-bit (Paolo Bonzini) [1956950]
- KVM: nVMX: Truncate bits 63:32 of VMCS field on nested check in !64-bit (Paolo Bonzini) [1956950]
- KVM: VMX: Truncate GPR value for DR and CR reads in !64-bit mode (Paolo Bonzini) [1956950]
- KVM: SVM: Truncate GPR value for DR and CR accesses in !64-bit mode (Paolo Bonzini) [1956950]
- KVM: x86: Check CR3 GPA for validity regardless of vCPU mode (Paolo Bonzini) [1956950]
- KVM: x86: Remove emulator's broken checks on CR0/CR3/CR4 loads (Paolo Bonzini) [1956950]
- KVM: VMX: Intercept FS/GS_BASE MSR accesses for 32-bit KVM (Paolo Bonzini) [1956950]
- KVM: SVM: Delay restoration of host MSR_TSC_AUX until return to userspace (Paolo Bonzini) [1956950]
- KVM: SVM: Clear MSR_TSC_AUX[63:32] on write (Paolo Bonzini) [1956950]
- KVM: SVM: Inject #GP on guest MSR_TSC_AUX accesses if RDTSCP unsupported (Paolo Bonzini) [1956950]
- KVM: VMX: Invert the inlining of MSR interception helpers (Paolo Bonzini) [1956950]
- KVM: X86: Fix failure to boost kernel lock holder candidate in SEV-ES guests (Paolo Bonzini) [1956950]
- KVM: x86: Properly handle APF vs disabled LAPIC situation (Paolo Bonzini) [1956950]
- KVM: VMX: use EPT_VIOLATION_GVA_TRANSLATED instead of 0x100 (Paolo Bonzini) [1956950]
- KVM: x86: Support KVM VMs sharing SEV context (Paolo Bonzini) [1956950]
- KVM: x86: Remove unused function declaration (Paolo Bonzini) [1956950]
- KVM: x86/mmu: Drop trace_kvm_age_page() tracepoint (Paolo Bonzini) [1956950]
- KVM: Move prototypes for MMU notifier callbacks to generic code (Paolo Bonzini) [1956950]
- KVM: Pass MMU notifier range flags to kvm_unmap_hva_range() (Paolo Bonzini) [1956950]
- KVM: x86/mmu: preserve pending TLB flush across calls to kvm_tdp_mmu_zap_sp (Paolo Bonzini) [1956950]
- KVM: x86: disable interrupts while pvclock_gtod_sync_lock is taken (Paolo Bonzini) [1956950]
- KVM: x86: reduce pvclock_gtod_sync_lock critical sections (Paolo Bonzini) [1956950]
- kvm: x86: annotate RCU pointers (Paolo Bonzini) [1956950]
- KVM: x86: remove misplaced comment on active_mmu_pages (Paolo Bonzini) [1956950]
- x86/sev: Drop redundant and potentially misleading 'sev_enabled' (Paolo Bonzini) [1956950]
- x86/cpufeatures: Assign dedicated feature word for CPUID_0x8000001F[EAX] (Paolo Bonzini) [1956950]
- cgroup: Add misc cgroup controller (Paolo Bonzini) [1956950]
- x86: Remove duplicate TSC DEADLINE MSR definitions (Paolo Bonzini) [1956950]
- KVM: s390: allow facility 192 (vector-packed-decimal-enhancement facility 2) (Thomas Huth) [1977289]
- KVM: s390: gen_facilities: allow facilities 165, 193, 194 and 196 (Thomas Huth) [1977289]
- mpi3mr: mark as tech preview (Tomas Henzl) [1858804]
- add the mpi3mr config (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix W=1 compilation warnings (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix warnings reported by smatch (Tomas Henzl) [1858804]
- scsi: mpi3mr: Make some symbols static (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix error return code in mpi3mr_init_ioc() (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix missing unlock on error (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix error handling in mpi3mr_setup_isr() (Tomas Henzl) [1858804]
- scsi: mpi3mr: Delete unnecessary NULL check (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix a double free (Tomas Henzl) [1858804]
- scsi: mpi3mr: Fix fall-through warning for Clang (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add event handling debug prints (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add EEDP DIF DIX support (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for DSN secure firmware check (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for PM suspend and resume (Tomas Henzl) [1858804]
- scsi: mpi3mr: Wait for pending I/O completions upon detection of VD I/O timeout (Tomas Henzl) [1858804]
- scsi: mpi3mr: Print pending host I/Os for debugging (Tomas Henzl) [1858804]
- scsi: mpi3mr: Complete support for soft reset (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for threaded ISR (Tomas Henzl) [1858804]
- scsi: mpi3mr: Hardware workaround for UNMAP commands to NVMe drives (Tomas Henzl) [1858804]
- scsi: mpi3mr: Allow certain commands during pci-remove hook (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add change queue depth support (Tomas Henzl) [1858804]
- scsi: mpi3mr: Implement SCSI error handler hooks (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add bios_param SCSI host template hook (Tomas Henzl) [1858804]
- scsi: mpi3mr: Print IOC info for debugging (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for timestamp sync with firmware (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for recovering controller (Tomas Henzl) [1858804]
- scsi: mpi3mr: Additional event handling (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for PCIe device event handling (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for device add/remove event handling (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for internal watchdog thread (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add support for queue command processing (Tomas Henzl) [1858804]
- scsi: mpi3mr: Create operational request and reply queue pair (Tomas Henzl) [1858804]
- scsi: mpi3mr: Base driver code (Tomas Henzl) [1858804]
- scsi: mpi3mr: Add mpi30 Rev-R headers and Kconfig (Tomas Henzl) [1858804]
- e1000e: Fix prototype warning (Ken Cox) [1920290]
- e1000e: Mark e1000e_pm_prepare() as __maybe_unused (Ken Cox) [1920290]
- e1000e: Fix duplicate include guard (Ken Cox) [1920290]
- e1000e: Remove the runtime suspend restriction on CNP+ (Ken Cox) [1920290]
- e1000e: Leverage direct_complete to speed up s2ram (Ken Cox) [1920290]
- e1000e: Fix error handling in e1000_set_d0_lplu_state_82571 (Ken Cox) [1920290]
- e1000e: add rtnl_lock() to e1000_reset_task (Ken Cox) [1920290]
- e1000e: remove the redundant value assignment in e1000_update_nvm_checksum_spt (Ken Cox) [1920290]
- e1000e: Export S0ix flags to ethtool (Ken Cox) [1920290]
- e1000e: bump up timeout to wait when ME un-configures ULP mode (Ken Cox) [1920290]
- e1000e: Only run S0ix flows if shutdown succeeded (Ken Cox) [1920290]
- scsi: ipr: System crashes when seeing type 20 error (Desnes A. Nunes do Rosario) [1977532]
- scsi: ipr: Use scnprintf() for avoiding potential buffer overflow (Desnes A. Nunes do Rosario) [1977532]
- tipc: do not write skb_shinfo frags when doing decrytion (Xin Long) [1974627]
- bnxt_en: Call bnxt_ethtool_free() in bnxt_init_one() error path (Jonathan Toppins) [1921449]
- bnxt_en: Fix TQM fastpath ring backing store computation (Jonathan Toppins) [1921449]
- bnxt_en: Rediscover PHY capabilities after firmware reset (Jonathan Toppins) [1921449]
- bnxt_en: Fix context memory setup for 64K page size. (Jonathan Toppins) [1921449]
- bnxt_en: Include new P5 HV definition in VF check. (Jonathan Toppins) [1921449]
- bnxt_en: Add PCI IDs for Hyper-V VF devices. (Jonathan Toppins) [1921449]
- bnxt_en: Fix RX consumer index logic in the error path. (Jonathan Toppins) [1921449]
- bnxt_en: fix ternary sign extension bug in bnxt_show_temp() (Jonathan Toppins) [1921449]
- bnxt_en: reliably allocate IRQ table on reset to avoid crash (Jonathan Toppins) [1921449]
- bnxt_en: Fix race between firmware reset and driver remove. (Jonathan Toppins) [1921449]
- bnxt_en: Improve logging of error recovery settings information. (Jonathan Toppins) [1921449]
- bnxt_en: Reply to firmware's echo request async message. (Jonathan Toppins) [1921449]
- bnxt_en: Initialize "context kind" field for context memory blocks. (Jonathan Toppins) [1921449]
- bnxt_en: Add context memory initialization infrastructure. (Jonathan Toppins) [1921449]
- bnxt_en: Implement faster recovery for firmware fatal error. (Jonathan Toppins) [1921449]
- bnxt_en: selectively allocate context memories (Jonathan Toppins) [1921449]
- bnxt_en: Update firmware interface spec to 1.10.2.16. (Jonathan Toppins) [1921449]
- bnxt_en: Fix devlink info's stored fw.psid version format. (Jonathan Toppins) [1921449]
- bnxt_en: reverse order of TX disable and carrier off (Jonathan Toppins) [1921449]
- bnxt_en: Convert to use netif_level() helpers. (Jonathan Toppins) [1921449]
- bnxt_en: Do not process completion entries after fatal condition detected. (Jonathan Toppins) [1921449]
- bnxt_en: Consolidate firmware reset event logging. (Jonathan Toppins) [1921449]
- bnxt_en: Improve firmware fatal error shutdown sequence. (Jonathan Toppins) [1921449]
- bnxt_en: Modify bnxt_disable_int_sync() to be called more than once. (Jonathan Toppins) [1921449]
- bnxt_en: Add a new BNXT_STATE_NAPI_DISABLED flag to keep track of NAPI state. (Jonathan Toppins) [1921449]
- bnxt_en: Add bnxt_fw_reset_timeout() helper. (Jonathan Toppins) [1921449]
- bnxt_en: Retry open if firmware is in reset. (Jonathan Toppins) [1921449]
- bnxt_en: attempt to reinitialize after aborted reset (Jonathan Toppins) [1921449]
- bnxt_en: log firmware debug notifications (Jonathan Toppins) [1921449]
- bnxt_en: Add an upper bound for all firmware command timeouts. (Jonathan Toppins) [1921449]
- bnxt_en: Move reading VPD info after successful handshake with fw. (Jonathan Toppins) [1921449]
- bnxt_en: Retry sending the first message to firmware if it is under reset. (Jonathan Toppins) [1921449]
- bnxt_en: handle CRASH_NO_MASTER during bnxt_open() (Jonathan Toppins) [1921449]
- bnxt_en: Define macros for the various health register states. (Jonathan Toppins) [1921449]
- bnxt_en: Update firmware interface to 1.10.2.11. (Jonathan Toppins) [1921449]
- bnxt_en: Clear DEFRAG flag in firmware message when retry flashing. (Jonathan Toppins) [1921449]
- bnxt_en: Improve stats context resource accounting with RDMA driver loaded. (Jonathan Toppins) [1921449]
- bnxt_en: Use kzalloc for allocating only one thing (Jonathan Toppins) [1921449]
- bnxt_en: Check TQM rings for maximum supported value. (Jonathan Toppins) [1921449]
- bnxt_en: Fix AER recovery. (Jonathan Toppins) [1921449]
- bnxt_en: Enable batch mode when using HWRM_NVM_MODIFY to flash packages. (Jonathan Toppins) [1921449]
- bnxt_en: Retry installing FW package under NO_SPACE error condition. (Jonathan Toppins) [1921449]
- bnxt_en: Restructure bnxt_flash_package_from_fw_obj() to execute in a loop. (Jonathan Toppins) [1921449]
- bnxt_en: Rearrange the logic in bnxt_flash_package_from_fw_obj(). (Jonathan Toppins) [1921449]
- bnxt_en: Refactor bnxt_flash_nvram. (Jonathan Toppins) [1921449]
- bnxt_en: Release PCI regions when DMA mask setup fails during probe. (Jonathan Toppins) [1921449]
- bnxt_en: fix error return code in bnxt_init_board() (Jonathan Toppins) [1921449]
- bnxt_en: fix error return code in bnxt_init_one() (Jonathan Toppins) [1921449]
- bnxt_en: Avoid unnecessary NVM_GET_DEV_INFO cmd error log on VFs. (Jonathan Toppins) [1921449]
- bnxt_en: Fix counter overflow logic. (Jonathan Toppins) [1921449]
- bnxt_en: Free port stats during firmware reset. (Jonathan Toppins) [1921449]
- bnxt_en: read EEPROM A2h address using page 0 (Jonathan Toppins) [1921449]
- bnxt_en: Send HWRM_FUNC_RESET fw command unconditionally. (Jonathan Toppins) [1921449]
- bnxt_en: Check abort error state in bnxt_open_nic(). (Jonathan Toppins) [1921449]
- bnxt_en: Re-write PCI BARs after PCI fatal error. (Jonathan Toppins) [1921449]
- bnxt_en: Invoke cancel_delayed_work_sync() for PFs also. (Jonathan Toppins) [1921449]
- bnxt_en: Fix regression in workqueue cleanup logic in bnxt_remove_one(). (Jonathan Toppins) [1921449]
- bnxt_en: Add stored FW version info to devlink info_get cb. (Jonathan Toppins) [1921449]
- bnxt_en: Refactor bnxt_dl_info_get(). (Jonathan Toppins) [1921449]
- bnxt_en: Add bnxt_hwrm_nvm_get_dev_info() to query NVM info. (Jonathan Toppins) [1921449]
- bnxt_en: Log unknown link speed appropriately. (Jonathan Toppins) [1921449]
- bnxt_en: Log event_data1 and event_data2 when handling RESET_NOTIFY event. (Jonathan Toppins) [1921449]
- bnxt_en: Simplify bnxt_async_event_process(). (Jonathan Toppins) [1921449]
- bnxt_en: Set driver default message level. (Jonathan Toppins) [1921449]
- bnxt_en: Enable online self tests for multi-host/NPAR mode. (Jonathan Toppins) [1921449]
- bnxt_en: Return -EROFS to user space, if NVM writes are not permitted. (Jonathan Toppins) [1921449]
- bnxt_en: Eliminate unnecessary RX resets. (Jonathan Toppins) [1921449]
- bnxt_en: Reduce unnecessary message log during RX errors. (Jonathan Toppins) [1921449]
- bnxt_en: Add a software counter for RX ring reset. (Jonathan Toppins) [1921449]
- bnxt_en: Implement RX ring reset in response to buffer errors. (Jonathan Toppins) [1921449]
- bnxt_en: Refactor bnxt_init_one_rx_ring(). (Jonathan Toppins) [1921449]
- bnxt_en: Refactor bnxt_free_rx_skbs(). (Jonathan Toppins) [1921449]
- bnxt_en: Log FW health status info, if reset is aborted. (Jonathan Toppins) [1921449]
- bnxt_en: perform no master recovery during startup (Jonathan Toppins) [1921449]
- bnxt_en: log firmware status on firmware init failure (Jonathan Toppins) [1921449]
- bnxt_en: refactor bnxt_alloc_fw_health() (Jonathan Toppins) [1921449]
- bnxt_en: Update firmware interface spec to 1.10.1.68. (Jonathan Toppins) [1921449]
- bnxt_en: Improve preset max value for ethtool -l. (Jonathan Toppins) [1921449]
- bnxt_en: Implement ethtool set_fec_param() method. (Jonathan Toppins) [1921449]
- bnxt_en: Report Active FEC encoding during link up. (Jonathan Toppins) [1921449]
- bnxt_en: Report FEC settings to ethtool. (Jonathan Toppins) [1921449]
- bnxt_en: avoid link reset if speed is not changed (Jonathan Toppins) [1921449]
- bnxt_en: Handle ethernet link being disabled by firmware. (Jonathan Toppins) [1921449]
- bnxt_en: ethtool: support PAM4 link speeds up to 200G (Jonathan Toppins) [1921449]
- bnxt_en: add basic infrastructure to support PAM4 link speeds (Jonathan Toppins) [1921449]
- bnxt_en: refactor bnxt_get_fw_speed() (Jonathan Toppins) [1921449]
- bnxt_en: refactor code to limit speed advertising (Jonathan Toppins) [1921449]
- bnxt_en: Update firmware interface spec to 1.10.1.65. (Jonathan Toppins) [1921449]
- bnxt: add pause frame stats (Jonathan Toppins) [1921449]
- xfrm: Fix xfrm offload fallback fail case (Andrea Claudi) [1976424]
- sctp: trim optlen when it's a huge value in sctp_setsockopt (Xin Long) [1983864]
- netfilter: flowtable: Set offload timeouts according to proto values (Phil Sutter) [1979184]
- netfilter: conntrack: Introduce udp offload timeout configuration (Phil Sutter) [1979184]
- netfilter: conntrack: Introduce tcp offload timeout configuration (Phil Sutter) [1979184]
- veth: check for NAPI instead of xdp_prog before xmit of XDP frame (Paolo Abeni) [1952835]
- self-tests: add veth tests (Paolo Abeni) [1952835]
- veth: refine napi usage (Paolo Abeni) [1952835]
- veth: allow enabling NAPI even without XDP (Paolo Abeni) [1952835]
- veth: use skb_orphan_partial instead of skb_orphan (Paolo Abeni) [1952835]
- net: really orphan skbs tied to closing sk (Paolo Abeni) [1952835]
- net: let skb_orphan_partial wake-up waiters. (Paolo Abeni) [1952835]
- veth: Store queue_mapping independently of XDP prog presence (Paolo Abeni) [1952835]
- net/xfrm: Add inner_ipproto into sec_path (Petr Oros) [1981429]
- net, xdp: Introduce xdp_prepare_buff utility routine (Jiri Benc) [1983730]
- net, xdp: Introduce xdp_init_buff utility routine (Jiri Benc) [1983730]
- bridge: switchdev: Notify about VLAN protocol changes (Ivan Vecera) [1981461]
- net: bridge: br_vlan_get_pvid_rcu() should dereference the VLAN group under RCU (Ivan Vecera) [1981461]
- bridge: add br_vlan_get_proto() (Ivan Vecera) [1981461]
- bridge: add br_vlan_get_pvid_rcu() (Ivan Vecera) [1981461]
- RDMA/bnxt_re: Fix a double free in bnxt_qplib_alloc_res (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Get rid of custom module reference counting (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Create direct symbol link between bnxt modules (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Depend on bnxt ethernet driver and not blindly select it (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Fix Kconfig indentation (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Fix error return code in bnxt_qplib_cq_process_terminal() (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Move device to error state upon device crash (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Allow bigger MR creation (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Code refactor while populating user MRs (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Fix max_qp_wrs reported (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Fix entry size during SRQ create (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Fix sizeof mismatch for allocation of pbl_tbl. (Selvin Xavier) [1921454 1923026]
- RDMA/bnxt_re: Use rdma_umem_for_each_dma_block() (Selvin Xavier) [1921454 1923026]
- [s390] tools/kvm_stat: Exempt time-based counters (Claudio Imbrenda) [1981802]
- Documentation/admin-guide: intel_pstate: drop doubled word (David Arcari) [1973225]
- Documentation: fix multiple typos found in the admin-guide subdirectory (David Arcari) [1973225]
- cpufreq: intel_pstate: Fix active mode setting from command line (David Arcari) [1973225]
- cpufreq: intel_pstate: Use passive mode by default without HWP (David Arcari) [1973225]
- cpufreq: intel_pstate: Use HWP if enabled by platform firmware (David Arcari) [1973225]
- cpufreq: intel_pstate: Simplify intel_pstate_update_perf_limits() (David Arcari) [1973225]
- cpufreq: intel_pstate: Clean up frequency computations (David Arcari) [1973225]
- cpufreq/intel_pstate: Fix wrong macro conversion (David Arcari) [1973225]
- cpufreq: Convert to new X86 CPU match macros (David Arcari) [1973225]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (David Arcari) [1973225]
- selftests/fpu: Fix debugfs_simple_attr.cocci warning (Vitaly Kuznetsov) [1919182]
- selftest/fpu: avoid clang warning (Vitaly Kuznetsov) [1919182]
- redhat/configs: Add Enable CONFIG_TEST_FPU (Vitaly Kuznetsov) [1919182]
- selftests/fpu: Add an FPU selftest (Vitaly Kuznetsov) [1919182]
- x86/fpu/64: Don't FNINIT in kernel_fpu_begin() (Vitaly Kuznetsov) [1919182]
- x86/fpu: Make the EFI FPU calling convention explicit (Vitaly Kuznetsov) [1919182]
- x86/mmx: Use KFPU_387 for MMX string operations (Vitaly Kuznetsov) [1919182]
- x86/fpu: Add kernel_fpu_begin_mask() to selectively initialize state (Vitaly Kuznetsov) [1919182]
- x86/fpu: Simplify kernel_fpu_begin() (Vitaly Kuznetsov) [1919182]
- x86/fpu: Simplify kernel_fpu_end() (Vitaly Kuznetsov) [1919182]
- x86/fpu: Don't use current->mm to check for a kthread (Vitaly Kuznetsov) [1919182]
- x86/fpu: Don't export __kernel_fpu_{begin,end}() (Vitaly Kuznetsov) [1919182]
- intel_th: pci: Add Alder Lake-P support (Tony Camuso) [1929493 1929494]

* Tue Jul 27 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-326.el8]
- can: bcm: delay release of struct bcm_op after synchronize_rcu() (Hangbin Liu) [1975059] {CVE-2021-3609}
- seq_file: Disallow extremely large seq buffer allocations (Ian Kent) [1975182]
- nvme-pci: look for StorageD3Enable on companion ACPI device instead (Gopal Tiwari) [1965660]
- prctl: exe link permission error changed from -EINVAL to -EPERM (Adrian Reber) [1960708]
- prctl: Allow local CAP_CHECKPOINT_RESTORE to change /proc/self/exe (Adrian Reber) [1960708]
- prctl_set_mm: refactor checks from validate_prctl_map (Adrian Reber) [1960708]
- proc: allow access in init userns for map_files with CAP_CHECKPOINT_RESTORE (Adrian Reber) [1960708]
- pid_namespace: use checkpoint_restore_ns_capable() for ns_last_pid (Adrian Reber) [1960708]
- capabilities: Introduce CAP_CHECKPOINT_RESTORE (Adrian Reber) [1960708]
- scripts: skip empty CAP_* strings (Adrian Reber) [1960708]
- VMCI: Release resource if the work is already queued (Cathy Avery) [1978518]
- perf vendor events arm64: Add Fujitsu A64FX pmu event (Michael Petlan) [1908109]
- perf vendor events arm64: Add more common and uarch events (Michael Petlan) [1908109]
- sunrpc: Avoid a KASAN slab-out-of-bounds bug in xdr_set_page_base() (Benjamin Coddington) [1969751]
- xfs: sync lazy sb accounting on quiesce of read-only mounts (Bill O'Donnell) [1917220]
- drm/dp_mst: Avoid to mess up payload table by ports in stale topology (Lyude Paul) [1944404]
- drm/dp_mst: Do not set proposed vcpi directly (Lyude Paul) [1944404]
- drm/qxl: add lock asserts to qxl_bo_vmap_locked + qxl_bo_vunmap_locked (Lyude Paul) [1944404 1907341]
- drm/qxl: rework cursor plane (Lyude Paul) [1944404 1907341]
- drm/qxl: move shadow handling to new qxl_prepare_shadow() (Lyude Paul) [1944404 1907341]
- drm/qxl: fix monitors object vmap (Lyude Paul) [1944404 1907341]
- drm/qxl: fix prime vmap (Lyude Paul) [1944404 1907341]
- drm/qxl: add qxl_bo_vmap/qxl_bo_vunmap (Lyude Paul) [1944404 1907341]
- drm/qxl: rename qxl_bo_kmap -> qxl_bo_vmap_locked (Lyude Paul) [1944404 1907341]
- drm/qxl: more fence wait rework (Lyude Paul) [1944404 1907341]
- drm/qxl: properly handle device init failures (Lyude Paul) [1944404 1907341]
- drm/qxl: allocate dumb buffers in ram (Lyude Paul) [1944404 1907341]
- drm/qxl: simplify qxl_fence_wait (Lyude Paul) [1944404 1907341]
- drm/qxl: properly free qxl releases (Lyude Paul) [1944404 1907341]
- drm/qxl: handle shadow in primary destroy (Lyude Paul) [1944404 1907341]
- drm/qxl: properly pin/unpin shadow (Lyude Paul) [1944404 1907341]
- drm/qxl: use drmm_mode_config_init (Lyude Paul) [1944404 1907341]
- drm/i915/icp+: Use icp_hpd_irq_setup() instead of spt_hpd_irq_setup() (Lyude Paul) [1944404]
- drm/i915/gen9_bc: Add W/A for missing STRAP config on TGP PCH + CML combos (Lyude Paul) [1944404]
- drm/i915/gen9_bc: Introduce HPD pin mappings for TGP PCH + CML combos (Lyude Paul) [1944404]
- drm/i915/gen9_bc: Introduce TGP PCH DDC pin mappings (Lyude Paul) [1944404]
- drm/i915/gen9_bc: Recognize TGP PCH + CML combos (Lyude Paul) [1944404]
- drm/i915: rename i915_rev_steppings->intel_step_info (Lyude Paul) [1944404]
- drm/i915: rename disp_stepping->display_step and gt_stepping->gt_step (Lyude Paul) [1944404]
- drm/i915: rename DISP_STEPPING->DISPLAY_STEP and GT_STEPPING->GT_STEP (Lyude Paul) [1944404]
- drm/i915: switch TGL and ADL to the new stepping scheme (Lyude Paul) [1944404]
- drm/i915: switch KBL to the new stepping scheme (Lyude Paul) [1944404]
- drm/i915: add new helpers for accessing stepping info (Lyude Paul) [1944404]
- drm/i915: split out stepping info to a new file (Lyude Paul) [1944404]
- drm/i915: Add DISPLAY_VER() and related macros (Lyude Paul) [1944404]
- drm/i915/display: Do not allow DC3CO if PSR SF is enabled (Lyude Paul) [1944404]
- drm/i915: s/dev_priv/i915/ for the remainder of DDI clock routing (Lyude Paul) [1944404]
- drm/i915: Relocate icl_sanitize_encoder_pll_mapping() (Lyude Paul) [1944404]
- drm/i915: Use .disable_clock() for pll sanitation (Lyude Paul) [1944404]
- drm/i915: Split adl-s/rkl from icl_ddi_combo_{enable,disable}_clock() (Lyude Paul) [1944404]
- drm/i915: Extract _cnl_ddi_{enable,disable}_clock() (Lyude Paul) [1944404]
- drm/i915: Sprinkle WARN(!pll) into icl/dg1 .clock_enable() (Lyude Paul) [1944404]
- drm/i915: Sprinkle a few missing locks around shared DDI clock registers (Lyude Paul) [1944404]
- drm/i915: Use intel_de_rmw() for DDI clock routing (Lyude Paul) [1944404]
- drm/i915: Extract icl+ .{enable,disable}_clock() vfuncs (Lyude Paul) [1944404]
- drm/i915: Convert DG1 over to .{enable,disable}_clock() (Lyude Paul) [1944404]
- drm/i195: Extract cnl_ddi_{enable,disable}_clock() (Lyude Paul) [1944404]
- drm/i915: Extract skl_ddi_{enable,disable}_clock() (Lyude Paul) [1944404]
- drm/i915: Extract hsw_ddi_{enable,disable}_clock() (Lyude Paul) [1944404]
- drm/i915: Introduce .{enable,disable}_clock() encoder vfuncs (Lyude Paul) [1944404]
- drm/i915: Use intel_ddi_clk_select() for FDI (Lyude Paul) [1944404]
- drm/i915/adl_s: Add GT and CTX WAs for ADL-S (Lyude Paul) [1944404]
- drm/i915/adl_s: Add display WAs for ADL-S (Lyude Paul) [1944404]
- drm/i915/display: Add HAS_D12_PLANE_MINIMIZATION (Lyude Paul) [1944404]
- drm/i915/adl_s: Re-use TGL GuC/HuC firmware (Lyude Paul) [1944404]
- drm/i915/adl_s: Add power wells (Lyude Paul) [1944404]
- drm/i915/adl_s: Update PHY_MISC programming (Lyude Paul) [1944404]
- drm/i915/adl_s: Update combo PHY master/slave relationships (Lyude Paul) [1944404]
- drm/i915/adl_s: Add vbt port and aux channel settings for adls (Lyude Paul) [1944404]
- drm/i915/adl_s: Add adl-s ddc pin mapping (Lyude Paul) [1944404]
- drm/i915/adl_s: Initialize display for ADL-S (Lyude Paul) [1944404]
- drm/i915/adl_s: Configure Port clock registers for ADL-S (Lyude Paul) [1944404]
- drm/i915/adl_s: Configure DPLL for ADL-S (Lyude Paul) [1944404]
- drm/i915/adl_s: Add PHYs for Alderlake S (Lyude Paul) [1944404]
- drm/i915/adl_s: Add PCH support (Lyude Paul) [1944404]
- drm/i915/adl_s: Add ADL-S platform info and PCI ids (Lyude Paul) [1944404]
- drm/i915/tgl: Use TGL stepping info for applying WAs (Lyude Paul) [1944404]
- redhat/configs: Update CONFIG_HSA_AMD (Lyude Paul)
- redhat/configs: Update CONFIG_DRM_AMDGPU_USERPTR (Lyude Paul)
- DRM Backport v5.11 -> v5.12.4 (Lyude Paul) [1944404]
- include/linux/kernel.h: add typeof_member() macro (Lyude Paul) [1944404]
- drm: Use USB controller's DMA mask when importing dmabufs (Lyude Paul) [1944404]
- PM: runtime: Add pm_runtime_get_if_active() (Lyude Paul) [1944404]
- PCI: Add pci_rebar_bytes_to_size() (Lyude Paul) [1944404]
- PCI: Export pci_rebar_get_possible_sizes() (Lyude Paul) [1944404]
- DRM backport v5.10->v5.11 (Lyude Paul) [1944404]
- dma-buf: Use struct dma_buf_map in dma_buf_vunmap() interfaces (Lyude Paul) [1944404]
- dma-buf: Use struct dma_buf_map in dma_buf_vmap() interfaces (Lyude Paul) [1944404]
- dma-buf: Add struct dma-buf-map for storing struct dma_buf.vaddr_ptr (Lyude Paul) [1944404]
- PCI/PM: Do not generate wakeup event when runtime resuming device (Lyude Paul) [1944404]
- PCI/PM: Rename pci_wakeup_bus() to pci_resume_bus() (Lyude Paul) [1944404]
- blktrace: make relay callbacks const (Lyude Paul) [1944404]
- drm/i915: make relay callbacks const (Lyude Paul) [1944404]
- relay: allow the use of const callback structs (Lyude Paul) [1944404]
- relay: make create_buf_file and remove_buf_file callbacks mandatory (Lyude Paul) [1944404]
- relay: require non-NULL callbacks in relay_open() (Lyude Paul) [1944404]
- relay: remove unused buf_mapped and buf_unmapped callbacks (Lyude Paul) [1944404]
- drm/edid: fix objtool warning in drm_cvt_modes() (Lyude Paul) [1944404]
- drm/edid: Fix uninitialized variable in drm_cvt_modes() (Lyude Paul) [1944404]
- DRM backport v5.9.y -> v5.10 (Lyude Paul) [1944404]
- time: Introduce jiffies64_to_msecs() (Lyude Paul) [1944404]
- virtio: add dma-buf support for exported objects (Lyude Paul) [1944404]
- objtool: Rename frame.h -> objtool.h (Lyude Paul) [1944404]
- moduleparams: Add hexint type parameter (Lyude Paul) [1944404]
- iommu/vt-d: Move intel_iommu_gfx_mapped to Intel IOMMU header (Lyude Paul) [1944404]

* Mon Jul 26 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-325.el8]
- [s390] s390/zcrypt/pkey: introduce zcrypt_wait_api_operational() function (Claudio Imbrenda) [1881833]
- [s390] s390/ap: ap bus userspace notifications for some bus conditions (Claudio Imbrenda) [1881833]
- [s390] s390/pkey: fix paes selftest failure with paes and pkey static build (Claudio Imbrenda) [1881833]
- KVM: nSVM: Avoid tainiting kernel by default (Vitaly Kuznetsov) [1982248]
- KVM: s390x: implement KVM_CAP_SET_GUEST_DEBUG2 (Thomas Huth) [1945752]
- KVM: s390: fix guarded storage control register handling (Thomas Huth) [1945752]
- s390/protvirt: fix error return code in uv_info_init() (Thomas Huth) [1945752]
- s390/uv: fix prot virt host indication compilation (Thomas Huth) [1945752]
- KVM: s390: VSIE: fix MVPG handling for prefixing and MSO (Thomas Huth) [1945752]
- KVM: s390: split kvm_s390_real_to_abs (Thomas Huth) [1945752]
- KVM: s390: VSIE: correctly handle MVPG when in VSIE (Thomas Huth) [1945752]
- KVM: s390: extend kvm_s390_shadow_fault to return entry pointer (Thomas Huth) [1945752]
- s390/uv: add prot virt guest/host indication files (Thomas Huth) [1945752]
- KVM: s390: split kvm_s390_logical_to_effective (Thomas Huth) [1945752]
- KVM: s390: Fix comment spelling in kvm_s390_vcpu_start() (Thomas Huth) [1945752]
- s390: uv: Fix sysfs max number of VCPUs reporting (Thomas Huth) [1945752]
- KVM: s390: track synchronous pfault events in kvm_stat (Thomas Huth) [1945752]
- s390/gmap: make gmap memcg aware (Thomas Huth) [1945752]
- KVM: s390: Add memcg accounting to KVM allocations (Thomas Huth) [1945752]
- s390/uv: handle destroy page legacy interface (Thomas Huth) [1945752]
- KVM: s390: pv: Mark mm as protected after the set secure parameters and improve cleanup (Thomas Huth) [1945752]
- virtio/s390: implement virtio-ccw revision 2 correctly (Thomas Huth) [1945752]
- sfc: deprecate SFC9020 family (Siena) (Íñigo Huguet) [1926379]
- NFS: Fix open coded versions of nfs_set_cache_invalid() in NFSv4 (Benjamin Coddington) [1936478]
- NFS: Fix open coded versions of nfs_set_cache_invalid() (Benjamin Coddington) [1936478]
- NFS: Clean up function nfs_mark_dir_for_revalidate() (Benjamin Coddington) [1936478]
- NFSD: Mark exports of NFS as tech-preview (Benjamin Coddington) [1972229]
- perf vendor events intel: Add missing skylake & icelake model numbers (Michael Petlan) [1971959]
- tc-testing: add test for ct DNAT tuple collision (Marcelo Ricardo Leitner) [1964578]
- tc-testing: add support for sending various scapy packets (Marcelo Ricardo Leitner) [1964578]
- tc-testing: fix list handling (Marcelo Ricardo Leitner) [1964578]
- net/sched: act_ct: handle DNAT tuple collision (Marcelo Ricardo Leitner) [1964578]
- net/packet: remove data races in fanout operations (Balazs Nemeth) [1957270]
- net/packet: remove locking from packet_rcv_has_room() (Balazs Nemeth) [1957270]
- net: packetmmap: fix only tx timestamp on request (Balazs Nemeth) [1970404]
- x86/sgx: Add TAINT_TECH_PREVIEW for virtual EPC (Bandan Das) [1977474]
- cxgb4: fix thermal zone device registration (Raju Rangoju) [1954012]
- powerpc/64s: Fix crashes when toggling stf barrier (Desnes A. Nunes do Rosario) [1964484]
- iavf: Fix an error handling path in 'iavf_probe()' (Stefan Assmann) [1920276]
- iavf: clean up packet type lookup table (Stefan Assmann) [1920276]
- iavf: redefine the magic number for FDIR GTP-U header fields (Stefan Assmann) [1920276]
- iavf: enhance the duplicated FDIR list scan handling (Stefan Assmann) [1920276]
- iavf: change the flex-byte support number to macro definition (Stefan Assmann) [1920276]
- iavf: remove duplicate free resources calls (Stefan Assmann) [1920276]
- iavf: Support for modifying SCTP RSS flow hashing (Stefan Assmann) [1920276]
- iavf: Support for modifying UDP RSS flow hashing (Stefan Assmann) [1920276]
- iavf: Support for modifying TCP RSS flow hashing (Stefan Assmann) [1920276]
- iavf: Add framework to enable ethtool RSS config (Stefan Assmann) [1920276]
- iavf: add support for UDP Segmentation Offload (Stefan Assmann) [1920276]
- intel: clean up mismatched header comments (Stefan Assmann) [1920276]
- iavf: Enable flex-bytes support (Stefan Assmann) [1920276]
- iavf: Support Ethernet Type Flow Director filters (Stefan Assmann) [1920276]
- iavf: Support IPv6 Flow Director filters (Stefan Assmann) [1920276]
- iavf: Support IPv4 Flow Director filters (Stefan Assmann) [1920276]
- iavf: Add framework to enable ethtool ntuple filters (Stefan Assmann) [1920276]
- net: intel: iavf: fix error return code of iavf_init_get_resources() (Stefan Assmann) [1920276]
- workqueue: Move the position of debug_work_activate() in __queue_work() (Waiman Long) [1977537]
- workqueue: remove useless unlock() and lock() in series (Waiman Long) [1977537]
- workqueue: Convert the pool::lock and wq_mayday_lock to raw_spinlock_t (Waiman Long) [1977537]
- workqueue: Use rcuwait for wq_manager_wait (Waiman Long) [1977537]
- workqueue: Remove unnecessary kfree() call in rcu_free_wq() (Waiman Long) [1977537]
- workqueue: Fix an use after free in init_rescuer() (Waiman Long) [1977537]
- workqueue: Use IS_ERR and PTR_ERR instead of PTR_ERR_OR_ZERO. (Waiman Long) [1977537]
- workqueue: don't use wq_select_unbound_cpu() for bound works (Waiman Long) [1977537]
- workqueue: Use pr_warn instead of pr_warning (Waiman Long) [1977537]
- workqueue: more destroy_workqueue() fixes (Waiman Long) [1977537]
- workqueue: Minor follow-ups to the rescuer destruction change (Waiman Long) [1977537]
- kernel/workqueue: Document wq_worker_last_func() argument (Waiman Long) [1977537]
- workqueue: Only unregister a registered lockdep key (Waiman Long) [1977537]
- kernel: workqueue: clarify wq_worker_last_func() caller requirements (Waiman Long) [1977537]
- workqueue: Fix spelling in source code comments (Waiman Long) [1977537]
- workqueue: fix typo in comment (Waiman Long) [1977537]
- ice: add correct exception tracing for XDP (Jonathan Toppins) [1920278]
- ice: optimize for XDP_REDIRECT in xsk path (Jonathan Toppins) [1920278]
- ice: Allow all LLDP packets from PF to Tx (Jonathan Toppins) [1920278]
- ice: report supported and advertised autoneg using PHY capabilities (Jonathan Toppins) [1920278]
- ice: handle the VF VSI rebuild failure (Jonathan Toppins) [1920278]
- ice: Fix VFR issues for AVF drivers that expect ATQLEN cleared (Jonathan Toppins) [1920278]
- ice: Fix allowing VF to request more/less queues via virtchnl (Jonathan Toppins) [1920278]
- ice: track AF_XDP ZC enabled queues in bitmap (Jonathan Toppins) [1920278]
- ice: handle increasing Tx or Rx ring sizes (Jonathan Toppins) [1920278]
- ice: Fix potential infinite loop when using u8 loop counter (Jonathan Toppins) [1920278]
- ice: fix memory leak of aRFS after resuming from suspend (Jonathan Toppins) [1920278]
- ice: Cleanup fltr list in case of allocation issues (Jonathan Toppins) [1920278]
- ice: Use port number instead of PF ID for WoL (Jonathan Toppins) [1920278]
- ice: Fix for dereference of NULL pointer (Jonathan Toppins) [1920278]
- ice: remove DCBNL_DEVRESET bit from PF state (Jonathan Toppins) [1920278]
- ice: fix memory allocation call (Jonathan Toppins) [1920278]
- ice: prevent ice_open and ice_stop during reset (Jonathan Toppins) [1920278]
- ice: Recognize 860 as iSCSI port in CEE mode (Jonathan Toppins) [1920278]
- ice: Increase control queue timeout (Jonathan Toppins) [1920278]
- ice: Continue probe on link/PHY errors (Jonathan Toppins) [1920278]
- ice: fix napi work done reporting in xsk path (Jonathan Toppins) [1920278]
- ice: update the number of available RSS queues (Jonathan Toppins) [1920278]
- ice: Fix state bits on LLDP mode switch (Jonathan Toppins) [1920278]
- ice: Account for port VLAN in VF max packet size calculation (Jonathan Toppins) [1920278]
- ice: Set trusted VF as default VSI when setting allmulti on (Jonathan Toppins) [1920278]
- ice: report correct max number of TCs (Jonathan Toppins) [1920278]
- ice: skip NULL check against XDP prog in ZC path (Jonathan Toppins) [1920278]
- ice: remove redundant checks in ice_change_mtu (Jonathan Toppins) [1920278]
- ice: move skb pointer from rx_buf to rx_ring (Jonathan Toppins) [1920278]
- ice: simplify ice_run_xdp (Jonathan Toppins) [1920278]
- ice: Improve MSI-X fallback logic (Jonathan Toppins) [1920278]
- ice: Fix trivial error message (Jonathan Toppins) [1920278]
- ice: remove unnecessary casts (Jonathan Toppins) [1920278]
- ice: Refactor DCB related variables out of the ice_port_info struct (Jonathan Toppins) [1920278]
- ice: fix writeback enable logic (Jonathan Toppins) [1920278]
- ice: Use PSM clock frequency to calculate RL profiles (Jonathan Toppins) [1920278]
- ice: create scheduler aggregator node config and move VSIs (Jonathan Toppins) [1920278 1940527 1940535 1940542] {CVE-2020-24504 CVE-2020-24503 CVE-2020-24502}
- ice: Add initial support framework for LAG (Jonathan Toppins) [1920278]
- ice: Remove xsk_buff_pool from VSI structure (Jonathan Toppins) [1920278]
- ice: implement new LLDP filter command (Jonathan Toppins) [1920278]
- ice: log message when trusted VF goes in/out of promisc mode (Jonathan Toppins) [1920278]
- ice: remove dead code (Jonathan Toppins) [1920278]
- ice: use flex_array_size where possible (Jonathan Toppins) [1920278]
- ice: Replace one-element array with flexible-array member (Jonathan Toppins) [1920278]
- ice: display stored UNDI firmware version via devlink info (Jonathan Toppins) [1920278]
- ice: display stored netlist versions via devlink info (Jonathan Toppins) [1920278]
- ice: display some stored NVM versions via devlink info (Jonathan Toppins) [1920278]
- ice: introduce function for reading from flash modules (Jonathan Toppins) [1920278]
- ice: cache NVM module bank information (Jonathan Toppins) [1920278]
- ice: introduce context struct for info report (Jonathan Toppins) [1920278]
- ice: create flash_info structure and separate NVM version (Jonathan Toppins) [1920278]
- ice: report timeout length for erasing during devlink flash (Jonathan Toppins) [1920278]
- ice: Implement flow for IPv6 next header (extension header) (Jonathan Toppins) [1920278]
- ice: fix FDir IPv6 flexbyte (Jonathan Toppins) [1920278]
- ice: drop dead code in ice_receive_skb() (Jonathan Toppins) [1920278]
- ice, xsk: Move Rx allocation out of while-loop (Jonathan Toppins) [1920278]
- ice: avoid premature Rx buffer reuse (Jonathan Toppins) [1920278]
- ice: Add space to unknown speed (Jonathan Toppins) [1920278]
- ice: join format strings to same line as ice_debug (Jonathan Toppins) [1920278]
- ice: silence static analysis warning (Jonathan Toppins) [1920278]
- ice: cleanup misleading comment (Jonathan Toppins) [1920278]
- ice: Remove vlan_ena from vsi structure (Jonathan Toppins) [1920278]
- ice: Remove gate to OROM init (Jonathan Toppins) [1920278]
- ice: Enable Support for FW Override (E82X) (Jonathan Toppins) [1920278]
- ice: don't always return an error for Get PHY Abilities AQ command (Jonathan Toppins) [1920278]
- ice: cleanup stack hog (Jonathan Toppins) [1920278]
- mm: migrate: fix missing update page_private to hugetlb_page_subpool (Chris von Recklinghausen) [1981661]
- mm,hugetlb: drop clearing of flag from prep_new_huge_page (Chris von Recklinghausen) [1981661]
- hugetlb: fix uninitialized subpool pointer (Chris von Recklinghausen) [1981661]
- include/linux/hugetlb.h: add synchronization information for new hugetlb specific flags (Chris von Recklinghausen) [1981661]
- hugetlb: convert PageHugeFreed to HPageFreed flag (Chris von Recklinghausen) [1981661]
- hugetlb: convert PageHugeTemporary() to HPageTemporary flag (Chris von Recklinghausen) [1981661]
- mm: hugetlb: fix a race between freeing and dissolving the page (Chris von Recklinghausen) [1981661]
- mm: don't let userspace spam allocations warnings (Xin Long) [1976699]
- dm writecache: make writeback pause configurable (Mike Snitzer) [1978369]
- dm writecache: pause writeback if cache full and origin being written directly (Mike Snitzer) [1978369]
- dm io tracker: factor out IO tracker (Mike Snitzer) [1978369]
- dm writecache: add optional "metadata_only" parameter (Mike Snitzer) [1978369]
- dm writecache: add "cleaner" and "max_age" to Documentation (Mike Snitzer) [1978369]
- dm writecache: write at least 4k when committing (Mike Snitzer) [1978369]
- dm writecache: have ssd writeback wait if the kcopyd workqueue is busy (Mike Snitzer) [1978369]
- dm writecache: use list_move instead of list_del_list_add in writecache_writeback() (Mike Snitzer) [1978369]
- dm writecache: commit just one block, not a full page (Mike Snitzer) [1978369]
- dm writecache: remove unused gfp_t argument from wc_add_block() (Mike Snitzer) [1978369]
- dm writecache: interrupt writeback if suspended (Mike Snitzer) [1978369]
- dm writecache: don't split bios when overwriting contiguous cache content (Mike Snitzer) [1978369]
- dm kcopyd: avoid spin_lock_irqsave from process context (Mike Snitzer) [1978369]
- dm kcopyd: avoid useless atomic operations (Mike Snitzer) [1978369]
- x86/asm: Optimize memcpy_flushcache() (Mike Snitzer) [1978369]
- IB/isert: Align target max I/O size to initiator size (Kamal Heib) [1930955]
- IB/isert: set rdma cm afonly flag (Kamal Heib) [1930955]

* Wed Jul 21 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-324.el8]
- xsk: Rollback reservation at NETDEV_TX_BUSY (Jiri Benc) [1882711]
- xsk: Fix race in SKB mode transmit with shared cq (Jiri Benc) [1882711]
- bpf: Only provide bpf_sock_from_file with CONFIG_NET (Jiri Benc) [1882711]
- xsk: Validate socket state in xsk_recvmsg, prior touching socket members (Jiri Benc) [1882711]
- samples/bpf: Fix spelling mistake "recieving" -> "receiving" (Jiri Benc) [1882711]
- samples/bpf: Sample application for eBPF load and socket creation split (Jiri Benc) [1882711]
- bpf: Adds support for setting window clamp (Jiri Benc) [1882711]
- tcp: declare tcp_mmap() only when CONFIG_MMU is set (Jiri Benc) [1882711]
- bpf: Remove trailing semicolon in macro definition (Jiri Benc) [1882711]
- bpf: Allow bpf_{s,g}etsockopt from cgroup bind{4,6} hooks (Jiri Benc) [1882711]
- bpf: Eliminate rlimit-based memory accounting infra for bpf maps (Jiri Benc) [1882711]
- bpf: Eliminate rlimit-based memory accounting for xskmap maps (Jiri Benc) [1882711]
- bpf: Eliminate rlimit-based memory accounting for sockmap and sockhash maps (Jiri Benc) [1882711]
- bpf: Refine memcg-based memory accounting for xskmap maps (Jiri Benc) [1882711]
- bpf: Refine memcg-based memory accounting for sockmap and sockhash maps (Jiri Benc) [1882711]
- net, xdp, xsk: fix __sk_mark_napi_id_once napi_id error (Jiri Benc) [1882711]
- samples/bpf: Add option to set the busy-poll budget (Jiri Benc) [1882711]
- samples/bpf: Add busy-poll support to xdpsock (Jiri Benc) [1882711]
- xsk: Propagate napi_id to XDP socket Rx path (Jiri Benc) [1882711]
- xsk: Add busy-poll support for {recv,send}msg() (Jiri Benc) [1882711]
- xsk: Check need wakeup flag in sendmsg() (Jiri Benc) [1882711]
- xsk: Add support for recvmsg() (Jiri Benc) [1882711]
- net: Add SO_BUSY_POLL_BUDGET socket option (Jiri Benc) [1882711]
- net: Introduce preferred busy-polling (Jiri Benc) [1882711]
- net: napi: use READ_ONCE()/WRITE_ONCE() (Jiri Benc) [1882711]
- net: napi: add hard irqs deferral feature (Jiri Benc) [1882711]
- fs/eventpoll.c: simply CONFIG_NET_RX_BUSY_POLL ifdefery (Jiri Benc) [1882711]
- xdp: Remove the functions xsk_map_inc and xsk_map_put (Jiri Benc) [1882711]
- xsk: Introduce batched Tx descriptor interfaces (Jiri Benc) [1882711]
- xsk: Introduce padding between more ring pointers (Jiri Benc) [1882711]
- net: page_pool: Add bulk support for ptr_ring (Jiri Benc) [1882711]
- net: xdp: Introduce bulking for xdp tx return path (Jiri Benc) [1882711]
- bpf: Rename some functions in bpf_sk_storage (Jiri Benc) [1882711]
- bpf: Folding omem_charge() into sk_storage_charge() (Jiri Benc) [1882711]
- net/smc: properly handle workqueue allocation failure (Andrea Claudi) [1955178]
- Revert "net/smc: fix a NULL pointer dereference" (Andrea Claudi) [1955178]
- KVM: selftests: evmcs_test: Test that KVM_STATE_NESTED_EVMCS is never lost (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Request to sync eVMCS from VMCS12 after migration (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Reset eVMCS clean fields data from prepare_vmcs02() (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Force enlightened VMCS sync from nested_vmx_failValid() (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Ignore 'hv_clean_fields' data when eVMCS data is copied in vmx_get_nested_state() (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Release enlightened VMCS on VMCLEAR (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Introduce 'EVMPTR_MAP_PENDING' post-migration state (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Make copy_vmcs12_to_enlightened()/copy_enlightened_to_vmcs12() return 'void' (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Release eVMCS when enlightened VMENTRY was disabled (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Don't set 'dirty_vmcs12' flag on enlightened VMPTRLD (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Use '-1' in 'hv_evmcs_vmptr' to indicate that eVMCS is not in use (Vitaly Kuznetsov) [1940837]
- KVM: selftests: evmcs_test: Check that VMCS12 is alway properly synced to eVMCS after restore (Vitaly Kuznetsov) [1940837]
- KVM: selftests: evmcs_test: Check that VMLAUNCH with bogus EVMPTR is causing #UD (Vitaly Kuznetsov) [1940837]
- KVM: nVMX: Always make an attempt to map eVMCS after migration (Vitaly Kuznetsov) [1940837]
- Bluetooth: btusb: Some Qualcomm Bluetooth adapters stop working (Gopal Tiwari) [1973909]
- KVM: x86: Unload MMU on guest TLB flush if TDP disabled to force MMU sync (Vitaly Kuznetsov) [1906634]
- scsi: sbitmap: Silence a debug kernel warning triggered by sbitmap_put() (Ewan D. Milne) [1761937]
- scsi: core: Replace sdev->device_busy with sbitmap (Ewan D. Milne) [1761937]
- scsi: core: Make sure sdev->queue_depth is <= max(shost->can_queue, 1024) (Ewan D. Milne) [1761937]
- scsi: core: Add scsi_device_busy() wrapper (Ewan D. Milne) [1761937]
- scsi: blk-mq: Return budget token from .get_budget callback (Ewan D. Milne) [1761937]
- scsi: blk-mq: Add callbacks for storing & retrieving budget token (Ewan D. Milne) [1761937]
- scsi: sbitmap: Add sbitmap_calculate_shift() helper (Ewan D. Milne) [1761937]
- scsi: sbitmap: Export sbitmap_weight (Ewan D. Milne) [1761937]
- scsi: sbitmap: Move allocation hint into sbitmap (Ewan D. Milne) [1761937]
- scsi: sbitmap: Add helpers for updating allocation hint (Ewan D. Milne) [1761937]
- scsi: sbitmap: Maintain allocation round_robin in sbitmap (Ewan D. Milne) [1761937]
- scsi: sbitmap: Remove sbitmap_clear_bit_unlock (Ewan D. Milne) [1761937]
- blk-mq: pass request queue into get/put budget callback (Ewan D. Milne) [1761937]
- dma-iommu: implement ->alloc_noncontiguous (Jerry Snitselaar) [1955767]
- dma-iommu: refactor iommu_dma_alloc_remap (Jerry Snitselaar) [1955767]
- dma-mapping: add a dma_alloc_noncontiguous API (Jerry Snitselaar) [1955767]
- dma-mapping: refactor dma_{alloc,free}_pages (Jerry Snitselaar) [1955767]
- dma-mapping: add a dma_mmap_pages helper (Jerry Snitselaar) [1955767]
- dma-mapping: remove the {alloc,free}_noncoherent methods (Jerry Snitselaar) [1955767]
- iommu/vt-d: Make unnecessarily global functions static (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove unused function declarations (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove SVM_FLAG_PRIVATE_PASID (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove svm_dev_ops (Jerry Snitselaar) [1955767]
- iommu/vt-d: Use Real PCI DMA device for IRTE (Jerry Snitselaar) [1955767]
- iommu/vt-d: Calculate and set flags for handle_mm_fault (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix build error of pasid_enable_wpe() with !X86 (Jerry Snitselaar) [1955767]
- iommu/vt-d: Avoid unnecessary cache flush in pasid entry teardown (Jerry Snitselaar) [1955767]
- iommu/vt-d: Enable write protect propagation from guest (Jerry Snitselaar) [1955767]
- iommu/vt-d: Enable write protect for supervisor SVM (Jerry Snitselaar) [1955767]
- iommu/vt-d: Report more information about invalidation errors (Jerry Snitselaar) [1955767]
- iommu/vt-d: Disable SVM when ATS/PRI/PASID are not enabled in the device (Jerry Snitselaar) [1955767]
- iommu: Stop exporting free_iova_fast() (Jerry Snitselaar) [1955767]
- iommu: Delete iommu_dma_free_cpu_cached_iovas() (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove IOVA domain rcache flushing for CPU offlining (Jerry Snitselaar) [1955767]
- iova: Add CPU hotplug handler to flush rcaches (Jerry Snitselaar) [1955767]
- iommu/iova: Improve restart logic (Jerry Snitselaar) [1955767]
- iommu/iova: Add rbtree entry helper (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Remove the unused fields for PREFETCH_CONFIG command (Jerry Snitselaar) [1955767]
- iommu/vt-d: Use user privilege for RID2PASID translation (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix sysfs leak in alloc_iommu() (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add a check to avoid invalid iotlb sync (Jerry Snitselaar) [1955767]
- x86/events/amd/iommu: Fix invalid Perf result due to IOMMU PMC power-gating (Jerry Snitselaar) [1955767]
- iommu: Fix a boundary issue to avoid performance drop (Jerry Snitselaar) [1955767]
- iommu/vt-d: Check for allocation failure in aux_detach_device() (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove unused dma map/unmap trace events (Jerry Snitselaar) [1955767]
- iommu/amd: Clear DMA ops when switching domain (Jerry Snitselaar) [1955767]
- iommu/amd: Remove performance counter pre-initialization test (Jerry Snitselaar) [1955767]
- Revert "iommu/amd: Fix performance counter initialization" (Jerry Snitselaar) [1955767]
- iommu/dma: Resurrect the "forcedac" option (Jerry Snitselaar) [1955767]
- iommu: Check dev->iommu in iommu_dev_xxx functions (Jerry Snitselaar) [1955767]
- iommu/amd: Put newline after closing bracket in warning (Jerry Snitselaar) [1955767]
- iommu/vt-d: Force to flush iotlb before creating superpage (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix an error handling path in 'intel_prepare_irq_remapping()' (Jerry Snitselaar) [1955767]
- iommu/vt-d: Invalidate PASID cache when root/context entry changed (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove WO permissions on second-level paging entries (Jerry Snitselaar) [1955767]
- iommu/vt-d: Report the right page fault address (Jerry Snitselaar) [1955767]
- iommu/vt-d: Report right snoop capability when using FL for IOVA (Jerry Snitselaar) [1955767]
- iommu/vt-d: Don't set then clear private data in prq_event_thread() (Jerry Snitselaar) [1955767]
- iommu/vt-d: Reject unsupported page request modes (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: add bit field SFM into GERROR_ERR_MASK (Jerry Snitselaar) [1955767]
- iommu/amd: Keep track of amd_iommu_irq_remap state (Jerry Snitselaar) [1955767]
- iommu/amd: Don't call early_amd_iommu_init() when AMD IOMMU is disabled (Jerry Snitselaar) [1955767]
- iommu/amd: Move Stoney Ridge check to detect_ivrs() (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix status code for Allocate/Free PASID command (Jerry Snitselaar) [1955767]
- iommu: Don't use lazy flush for untrusted device (Jerry Snitselaar) [1955767]
- iommu/amd: Fix sleeping in atomic in increase_address_space() (Jerry Snitselaar) [1955767]
- iommu: Delete iommu_dev_has_feature() (Jerry Snitselaar) [1955767]
- iommu: Delete iommu_domain_window_disable() (Jerry Snitselaar) [1955767]
- iommu: Stop exporting iommu_map_sg_atomic() (Jerry Snitselaar) [1955767]
- iova: Stop exporting some more functions (Jerry Snitselaar) [1955767]
- iova: Delete copy_reserved_iova() (Jerry Snitselaar) [1955767]
- iova: Make has_iova_flush_queue() private (Jerry Snitselaar) [1955767]
- iommu/vt-d: Add iotlb_sync_map callback (Jerry Snitselaar) [1955767]
- iommu/vt-d: Move capability check code to cap_audit files (Jerry Snitselaar) [1921289]
- iommu/vt-d: Audit IOMMU Capabilities and add helper functions (Jerry Snitselaar) [1921289]
- iommu/vt-d: Fix 'physical' typos (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix compile error [-Werror=implicit-function-declaration] (Jerry Snitselaar) [1955767]
- iommu/vt-d: Use INVALID response code instead of FAILURE (Jerry Snitselaar) [1920726]
- iommu/vt-d: Clear PRQ overflow only when PRQ is empty (Jerry Snitselaar) [1955767]
- iommu/vt-d: Preset Access/Dirty bits for IOVA over FL (Jerry Snitselaar) [1955767]
- iommu/vt-d: Add qi_submit trace event (Jerry Snitselaar) [1955767]
- iommu/vt-d: Consolidate duplicate cache invaliation code (Jerry Snitselaar) [1955767]
- iommu/amd: Adopt IO page table framework for AMD IOMMU v1 page table (Jerry Snitselaar) [1955767]
- iommu/amd: Introduce iommu_v1_map_page and iommu_v1_unmap_page (Jerry Snitselaar) [1955767]
- iommu/amd: Introduce iommu_v1_iova_to_phys (Jerry Snitselaar) [1955767]
- iommu/amd: Refactor fetch_pte to use struct amd_io_pgtable (Jerry Snitselaar) [1955767]
- iommu/amd: Rename variables to be consistent with struct io_pgtable_ops (Jerry Snitselaar) [1955767]
- iommu/amd: Remove amd_iommu_domain_get_pgtable (Jerry Snitselaar) [1955767]
- iommu/amd: Restructure code for freeing page table (Jerry Snitselaar) [1955767]
- iommu/amd: Move IO page table related functions (Jerry Snitselaar) [1955767]
- iommu/amd: Declare functions as extern (Jerry Snitselaar) [1955767]
- iommu/amd: Convert to using amd_io_pgtable (Jerry Snitselaar) [1955767]
- iommu/amd: Move pt_root to struct amd_io_pgtable (Jerry Snitselaar) [1955767]
- iommu/amd: Prepare for generic IO page table framework (Jerry Snitselaar) [1955767]
- iommu/amd: Re-define amd_iommu_domain_encode_pgtable as inline (Jerry Snitselaar) [1955767]
- iommu/amd: remove h from printk format specifier (Jerry Snitselaar) [1955767]
- iommu/amd: Use DEFINE_SPINLOCK() for spinlock (Jerry Snitselaar) [1955767]
- iommu/amd: Remove unnecessary assignment (Jerry Snitselaar) [1955767]
- iommu: Properly pass gfp_t in _iommu_map() to avoid atomic sleeping (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm-v7s: Add cfg as a param in some macros (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm-v7s: Clarify LVL_SHIFT/BITS macro (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm-v7s: Use ias to check the valid iova in unmap (Jerry Snitselaar) [1955767]
- iommu/io-pgtable: Remove TLBI_ON_MAP quirk (Jerry Snitselaar) [1955767]
- iommu/io-pgtable: Allow io_pgtable_tlb ops optional (Jerry Snitselaar) [1955767]
- iommu: Switch gather->end to the inclusive end (Jerry Snitselaar) [1955767]
- iommu: Add iova and size as parameters in iotlb_sync_map (Jerry Snitselaar) [1955767]
- iommu: Move iotlb_sync_map out from __iommu_map (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add support for VHE (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Make BTM optional for SVA (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Split arm_smmu_tlb_inv_range() (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Use DEFINE_RES_MEM() to simplify code (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Remove the page 1 fixup (Jerry Snitselaar) [1955767]
- x86,swiotlb: Adjust SWIOTLB bounce buffer size for SEV guests (Jerry Snitselaar) [1955767]
- iommu: Check dev->iommu in dev_iommu_priv_get() before dereferencing it (Jerry Snitselaar) [1955767]
- iommu/vt-d: Do not use flush-queue when caching-mode is on (Jerry Snitselaar) [1955767]
- iommu/vt-d: Correctly check addr alignment in qi_flush_dev_iotlb_pasid() (Jerry Snitselaar) [1955767]
- iommu/amd: Use IVHD EFR for early initialization of IOMMU features (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix unaligned addresses for intel_flush_svm_range_dev() (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix ineffective devTLB invalidation for subdevices (Jerry Snitselaar) [1920750 1920749]
- iommu/vt-d: Fix general protection fault in aux_detach_device() (Jerry Snitselaar) [1920748]
- iommu/vt-d: Move intel_iommu info from struct intel_svm to struct intel_svm_dev (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix lockdep splat in sva bind()/unbind() (Jerry Snitselaar) [1955767]
- Revert "iommu: Add quirk for Intel graphic devices in map_sg" (Jerry Snitselaar) [1955767]
- iommu/intel: Fix memleak in intel_irq_remapping_alloc (Jerry Snitselaar) [1955767]
- iommu/iova: fix 'domain' typos (Jerry Snitselaar) [1955767]
- dma-iommu: remove __iommu_dma_mmap (Jerry Snitselaar) [1955767]
- iommu/io-pgtable: Remove tlb_flush_leaf (Jerry Snitselaar) [1955767]
- iommu/vt-d: Avoid GFP_ATOMIC where it is not needed (Jerry Snitselaar) [1955767]
- iommu/vt-d: Remove set but not used variable (Jerry Snitselaar) [1955767]
- iommu/vt-d: Cleanup after converting to dma-iommu ops (Jerry Snitselaar) [1955767]
- iommu/vt-d: Convert intel iommu driver to the iommu ops (Jerry Snitselaar) [1955767]
- iommu/vt-d: Don't clear GFP_DMA and GFP_DMA32 flags (Jerry Snitselaar) [1955767]
- iommu/vt-d: Update domain geometry in iommu_ops.at(de)tach_dev (Jerry Snitselaar) [1955767]
- iommu: Add quirk for Intel graphic devices in map_sg (Jerry Snitselaar) [1955767]
- swiotlb: remove the tbl_dma_addr argument to swiotlb_tbl_map_single (Jerry Snitselaar) [1955767]
- swiotlb-xen: remove start_dma_addr (Jerry Snitselaar) [1955767]
- iommu: Allow the dma-iommu api to use bounce buffers (Jerry Snitselaar) [1955767]
- iommu: Add iommu_dma_free_cpu_cached_iovas() (Jerry Snitselaar) [1955767]
- iommu: Handle freelists when using deferred flushing in iommu drivers (Jerry Snitselaar) [1955767]
- iommu/sva: Add PASID helpers (Jerry Snitselaar) [1955767]
- iommu/ioasid: Add ioasid references (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm: Remove unused 'level' parameter from iopte_type() macro (Jerry Snitselaar) [1955767]
- iommu: Defer the early return in arm_(v7s/lpae)_map (Jerry Snitselaar) [1955767]
- iommu: Improve the performance for direct_mapping (Jerry Snitselaar) [1955767]
- iommu: return error code when it can't get group (Jerry Snitselaar) [1955767]
- iommu: Modify the description of iommu_sva_unbind_device (Jerry Snitselaar) [1955767]
- iommu: Stop exporting free_iova_mem() (Jerry Snitselaar) [1955767]
- iommu: Stop exporting alloc_iova_mem() (Jerry Snitselaar) [1955767]
- iommu: Delete split_and_remove_iova() (Jerry Snitselaar) [1955767]
- iommu: avoid taking iova_rbtree_lock twice (Jerry Snitselaar) [1955767]
- iommu/iova: Free global iova rcache on iova alloc failure (Jerry Snitselaar) [1955767]
- iommu/iova: Retry from last rb tree node if iova search fails (Jerry Snitselaar) [1955767]
- iommu: Fix htmldocs warnings in sysfs-kernel-iommu_groups (Jerry Snitselaar) [1955767]
- iommu: Document usage of "/sys/kernel/iommu_groups/<grp_id>/type" file (Jerry Snitselaar) [1838589]
- iommu: Take lock before reading iommu group default domain type (Jerry Snitselaar) [1838589]
- iommu: Add support to change default domain of an iommu group (Jerry Snitselaar) [1838589]
- iommu: Move def_domain type check for untrusted device into core (Jerry Snitselaar) [1838589]
- iommu/arm-smmu-v3: Hook up ATC invalidation to mm ops (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Implement iommu_sva_bind/unbind() (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Move non-strict mode to use io_pgtable_domain_attr (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Add support for pagetable config domain attribute (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Assign boolean values to a bool variable (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm: Add support to use system cache (Jerry Snitselaar) [1955767]
- iommu/io-pgtable: Add a domain attribute for pagetable configuration (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm: Support coherency for Mali LPAE (Jerry Snitselaar) [1955767]
- dma-mapping: document dma_{alloc,free}_pages (Jerry Snitselaar) [1955767]
- dma-direct: simplify the DMA_ATTR_NO_KERNEL_MAPPING handling (Jerry Snitselaar) [1955767]
- dma-direct: factor out a dma_direct_alloc_from_pool helper (Jerry Snitselaar) [1955767]
- dma-direct check for highmem pages in dma_direct_alloc_pages (Jerry Snitselaar) [1955767]
- firewire-ohci: use dma_alloc_pages (Jerry Snitselaar) [1955767]
- dma-iommu: implement ->alloc_noncoherent (Jerry Snitselaar) [1955767]
- dma-mapping: add new {alloc,free}_noncoherent dma_map_ops methods (Jerry Snitselaar) [1955767]
- dma-mapping: add a new dma_alloc_pages API (Jerry Snitselaar) [1955767]
- dma-mapping: add a new dma_alloc_noncoherent API (Jerry Snitselaar) [1955767]
- drm/nouveau/gk20a: stop setting DMA_ATTR_NON_CONSISTENT (Jerry Snitselaar) [1955767]
- mm: turn alloc_pages into an inline function (Jerry Snitselaar) [1955767]
- dma-mapping: better document dma_addr_t and DMA_MAPPING_ERROR (Jerry Snitselaar) [1955767]
- dma-mapping: move valid_dma_direction to dma-direction.h (Jerry Snitselaar) [1955767]
- dma-debug: convert comma to semicolon (Jerry Snitselaar) [1955767]
- dma-direct: Fix potential NULL pointer dereference (Jerry Snitselaar) [1955767]
- dma-mapping: move the dma_declare_coherent_memory documentation (Jerry Snitselaar) [1955767]
- dma-mapping: move dma_common_{mmap,get_sgtable} out of mapping.c (Jerry Snitselaar) [1955767]
- dma-mapping: make support for dma ops optional (Jerry Snitselaar) [1955767]
- dma-direct: rename and cleanup __phys_to_dma (Jerry Snitselaar) [1955767]
- dma-direct: remove __dma_to_phys (Jerry Snitselaar) [1955767]
- dma-direct: use phys_to_dma_direct in dma_direct_alloc (Jerry Snitselaar) [1955767]
- dma-direct: lift gfp_t manipulation out of__dma_direct_alloc_pages (Jerry Snitselaar) [1955767]
- dma-direct: remove dma_direct_{alloc,free}_pages (Jerry Snitselaar) [1955767]
- dma-debug: remove most exports (Jerry Snitselaar) [1955767]
- dma-mapping: remove the dma_dummy_ops export (Jerry Snitselaar) [1955767]
- dma-mapping: set default segment_boundary_mask to ULONG_MAX (Jerry Snitselaar) [1955767]
- dma-mapping: introduce dma_get_seg_boundary_nr_pages() (Jerry Snitselaar) [1955767]
- swiotlb: using SIZE_MAX needs limits.h included (Jerry Snitselaar) [1955767]
- swiotlb: fix "x86: Don't panic if can not alloc buffer for swiotlb" (Jerry Snitselaar) [1955767]
- swiotlb: Mark max_segment with static keyword (Jerry Snitselaar) [1955767]
- swiotlb: Declare swiotlb_late_init_with_default_size() in header (Jerry Snitselaar) [1955767]
- swiotlb: Use pa to print phys_addr_t variables (Jerry Snitselaar) [1955767]
- dma-debug: remove debug_dma_assert_idle() function (Jerry Snitselaar) [1955767]
- dma-mapping: move debug configuration options to kernel/dma (Jerry Snitselaar) [1955767]
- dma-debug: fix debug_dma_assert_idle(), use rcu_read_lock() (Jerry Snitselaar) [1955767]
- iommu: Check return of __iommu_attach_device() (Jerry Snitselaar) [1955767]
- iommu/amd: Enforce 4k mapping for certain IOMMU data structures (Jerry Snitselaar) [1955767]
- iommu: Fix a check in iommu_check_bind_data() (Jerry Snitselaar) [1955767]
- iommu/vt-d: Fix a bug for PDP check in prq_event_thread (Jerry Snitselaar) [1955767]
- iommu/vt-d: Check UAPI data processed by IOMMU core (Jerry Snitselaar) [1955767]
- iommu/uapi: Handle data and argsz filled by users (Jerry Snitselaar) [1955767]
- iommu/uapi: Rename uapi functions (Jerry Snitselaar) [1955767]
- iommu/uapi: Use named union for user data (Jerry Snitselaar) [1955767]
- iommu/uapi: Add argsz for user filled data (Jerry Snitselaar) [1955767]
- docs: IOMMU user API (Jerry Snitselaar) [1955767]
- iommu/dma: Handle init_iova_flush_queue() failure in dma-iommu path (Jerry Snitselaar) [1955767]
- iommu/iova: Replace cmpxchg with xchg in queue_iova (Jerry Snitselaar) [1955767]
- iommu/dma: Remove broken huge page handling (Jerry Snitselaar) [1955767]
- iommu: Rename iommu_tlb_* functions to iommu_iotlb_* (Jerry Snitselaar) [1955767]
- iommu/vt-d: Use device numa domain if RHSA is missing (Jerry Snitselaar) [1955767]
- iommu/vt-d: Drop kerneldoc marker from regular comment (Jerry Snitselaar) [1955767]
- iommu/amd: Re-purpose Exclusion range registers to support SNP CWWB (Jerry Snitselaar) [1955767]
- iommu/amd: Add support for RMP_PAGE_FAULT and RMP_HW_ERR (Jerry Snitselaar) [1955767]
- iommu/amd: Use 4K page for completion wait write-back semaphore (Jerry Snitselaar) [1955767]
- iommu/amd: Add missing function prototypes to fix -Wmissing-prototypes (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add SVA device feature (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Check for SVA features (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Seize private ASID (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Share process page tables (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Move definitions to a header (Jerry Snitselaar) [1955767]
- iommu/io-pgtable-arm: Move some definitions to a header (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Ensure queue is read after updating prod pointer (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Constify some helpers (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Prepare for the adreno-smmu implementation (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Add support for split pagetables (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Pass io-pgtable config to implementation specific function (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Fix endianness annotations (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: permit users to disable msi polling (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: replace module_param_named by module_param for disable_bypass (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: replace symbolic permissions by octal permissions for module parameter (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Fix l1 stream table size in the error message (Jerry Snitselaar) [1955767]
- ACPI: Do not create new NUMA domains from ACPI static tables that are not SRAT (Jerry Snitselaar) [1955767]
- iommu/amd: Prevent NULL pointer dereference (Jerry Snitselaar) [1955767]
- treewide: Use fallthrough pseudo-keyword (Jerry Snitselaar) [1955767]
- virtio-iommu: convert to LE accessors (Jerry Snitselaar) [1955767]
- virtio_iommu: correct tags for config space fields (Jerry Snitselaar) [1955767]
- mmap locking API: use coccinelle to convert mmap_sem rwsem call sites (Jerry Snitselaar) [1955767]
- iommu/iova: Unify format of the printed messages (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Move Arm SMMU drivers into their own subdirectory (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: move TLB timeout and spin count macros (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Call configuration impl hook before consuming features (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Manage ASIDs with xarray (Jerry Snitselaar) [1955767]
- redhat/configs: Add CONFIG_ARM_SMMU_DISABLE_BYPASS_BY_DEFAULT (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Break insecure users by disabling bypass by default (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Workaround for Marvell Armada-AP806 SoC erratum #582743 (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Allow client devices to select direct mapping (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Add global/context fault implementation hooks (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: add NVIDIA implementation for ARM MMU-500 usage (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Fix trivial typo (Jerry Snitselaar) [1955767]
- iommu/arm-smmu: Update impl quirks comment (Jerry Snitselaar) [1955767]
- iommu: arm-smmu-impl: Convert to a generic reset implementation (Jerry Snitselaar) [1955767]
- iommu: arm-smmu-impl: Add sdm845 implementation hook (Jerry Snitselaar) [1955767]
- firmware/qcom_scm: Add scm call to handle smmu errata (Jerry Snitselaar) [1955767]
- firmware: qcom_scm-64: Add atomic version of qcom_scm_call (Jerry Snitselaar) [1955767]
- firmware: qcom: scm: Ensure 'a0' status code is treated as signed (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Batch context descriptor invalidation (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Write level-1 descriptors atomically (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add support for PCI PASID (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add second level of context descriptor table (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Prepare for handling arm_smmu_write_ctx_desc() failure (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Propagate ssid_bits (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add support for Substream IDs (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Add context descriptor tables allocators (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Prepare arm_smmu_s1_cfg for SSID support (Jerry Snitselaar) [1955767]
- dt-bindings: document PASID property for IOMMU masters (Jerry Snitselaar) [1955767]
- iommu/arm-smmu-v3: Don't display an error when IRQ lines are missing (Jerry Snitselaar) [1955767]
- selftests: net: add UDP GRO forwarding self-tests (Paolo Abeni) [1948493]
- bareudp: allow UDP L4 GRO passthrou (Paolo Abeni) [1948493]
- geneve: allow UDP L4 GRO passthrou (Paolo Abeni) [1948493]
- vxlan: allow L4 GRO passthrough (Paolo Abeni) [1948493]
- udp: never accept GSO_FRAGLIST packets (Paolo Abeni) [1948493]
- udp: properly complete L4 GRO over UDP tunnel packet (Paolo Abeni) [1948493]
- udp: skip L4 aggregation for UDP tunnel packets (Paolo Abeni) [1948493]
- udp: fixup csum for GSO receive slow path (Paolo Abeni) [1948493]
- udp: allow forwarding of plain (non-fraglisted) UDP GRO packets (Paolo Abeni) [1948493]
- net: introduce a netdev feature for UDP GRO forwarding (Paolo Abeni) [1948493]
- [s390] s390/pkey: support CCA and EP11 secure ECC private keys (Claudio Imbrenda) [1780669]
- [s390] s390/zcrypt: Support for CCA APKA master keys (Claudio Imbrenda) [1780669]
- [s390] s390/zcrypt: remove set_fs() invocation in zcrypt device driver (Claudio Imbrenda) [1780669]
- [s390] s390/zcrypt: simplify cca_findcard2 loop code (Claudio Imbrenda) [1780669]
- cxgb4: Add new T6 PCI device id 0x6092 (Rahul Lakkireddy) [1950186]
- KVM: VMX: Don't use vcpu->run->internal.ndata as an array index (Jon Maloy) [1954219] {CVE-2021-3501}
- Bluetooth: Prevent out-of-bounds read in hci_inquiry_result_with_rssi_evt() (Gopal Tiwari) [1978598]
- Bluetooth: Prevent out-of-bounds read in hci_inquiry_result_evt() (Gopal Tiwari) [1978598]
- Bluetooth: Fix slab-out-of-bounds read in hci_extended_inquiry_result_evt() (Gopal Tiwari) [1978598]
- x86/cpu: Avoid cpuinfo-induced IPIing of idle CPUs (Waiman Long) [1970499]
- x86/cpu: Avoid cpuinfo-induced IPI pileups (Waiman Long) [1970499]
- x86/cpu: Disable frequency requests via aperfmperf IPI for nohz_full CPUs (Waiman Long) [1970499]
- x86: Convert some slow-path static_cpu_has() callers to boot_cpu_has() (Waiman Long) [1970499]
- x86/ldt: Enable LDT user-mapping for PAE (Waiman Long) [1970499]
- fanotify: fix merging marks masks with FAN_ONDIR (Miklos Szeredi) [1832099]
- sfc: avoid duplicated code in ef10_sriov (Íñigo Huguet) [1931779]
- sfc: explain that "attached" VFs only refer to Xen (Íñigo Huguet) [1931779]
- sfc: error code if SRIOV cannot be disabled (Íñigo Huguet) [1931779]
- sfc: avoid double pci_remove of VFs (Íñigo Huguet) [1931779]
- tpm: fix error return code in tpm2_get_cc_attrs_tbl() (Jerry Snitselaar) [1920812]
- tpm, tpm_tis: Reserve locality in tpm_tis_resume() (Jerry Snitselaar) [1920812]
- tpm, tpm_tis: Extend locality handling to TPM2 in tpm_tis_gen_interrupt() (Jerry Snitselaar) [1920812]
- tpm: vtpm_proxy: Avoid reading host log when using a virtual device (Jerry Snitselaar) [1920812]
- tpm: acpi: Check eventlog signature before using it (Jerry Snitselaar) [1920812]
- tpm: efi: Use local variable for calculating final log size (Jerry Snitselaar) [1920812]
- tpm: Remove unintentional dump_stack() call (Jerry Snitselaar) [1920812]
- tpm, tpm_tis: Decorate tpm_tis_gen_interrupt() with request_locality() (Jerry Snitselaar) [1920812]
- tpm, tpm_tis: Decorate tpm_get_timeouts() with request_locality() (Jerry Snitselaar) [1920812]
- KEYS: trusted: Reserve TPM for seal and unseal operations (Jerry Snitselaar) [1920812]
- tpm/ppi: Constify static struct attribute_group (Jerry Snitselaar) [1920812]
- tpm: add sysfs exports for all banks of PCR registers (Jerry Snitselaar) [1920812]
- tpm: Remove tpm_dev_wq_lock (Jerry Snitselaar) [1920812]
- tpm: Fix fall-through warnings for Clang (Jerry Snitselaar) [1920812]
- tpm_tis: Clean up locality release (Jerry Snitselaar) [1920812]
- tpm_tis: Disable interrupts on ThinkPad T490s (Jerry Snitselaar) [1920812]
- tpm_tis: Fix check_locality for correct locality acquisition (Jerry Snitselaar) [1920812]
- fuse: invalidate attrs when page writeback completes (Vivek Goyal) [1966424]
- net/sched: act_ct: remove rh_mark_used_feature mark (Marcelo Ricardo Leitner) [1973381]
- selftests: netfilter: Pass family parameter "-f" to conntrack tool (Hangbin Liu) [1979203]
- selftests: netfilter: remove unused cnt and simplify command testing (Hangbin Liu) [1979203]
- selftests: netfilter: fix nft_meta.sh error reporting (Hangbin Liu) [1979203]
- selftests: netfilter: add cpu counter check (Hangbin Liu) [1979203]
- selftests: netfilter: add meta iif/oif match test (Hangbin Liu) [1979203]
- NFS: Only change the cookie verifier if the directory page cache is empty (Benjamin Coddington) [1982825]
- NFS: Fix handling of cookie verifier in uncached_readdir() (Benjamin Coddington) [1982825]
- nfs: Subsequent READDIR calls should carry non-zero cookieverifier (Benjamin Coddington) [1982825]
- Revert "[netdrv] net/mlx5e: Rx, Update page pool numa node when changed" (Alaa Hleihel) [1915308]
- mlx5: net: zero-initialize tc skb extension on allocation (Alaa Hleihel) [1915308 1965418]
- RDMA/mlx5: Don't add slave port to unaffiliated list (Alaa Hleihel) [1915308]
- net/mlx5: Reset mkey index on creation (Alaa Hleihel) [1915308]
- net/mlx5e: Don't create devices during unload flow (Alaa Hleihel) [1915308]
- net/mlx5: DR, Fix STEv1 incorrect L3 decapsulation padding (Alaa Hleihel) [1915308]
- net/mlx5: SF_DEV, remove SF device on invalid state (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Allow setting GUID for host PF vport (Alaa Hleihel) [1915308 1967488]
- net/mlx5: E-Switch, Read PF mac address (Alaa Hleihel) [1915308 1967488]
- net/mlx5: Check that driver was probed prior attaching the device (Alaa Hleihel) [1915308]
- net/mlx5: Fix error path for set HCA defaults (Alaa Hleihel) [1915308]
- net/mlx5e: Disable TLS device offload in kdump mode (Alaa Hleihel) [1915308 1946647]
- net/mlx5e: Disable TX MPWQE in kdump mode (Alaa Hleihel) [1915308 1946647]
- net/mlx5e: kTLS, Add resiliency to RX resync failures (Alaa Hleihel) [1915308]
- net/mlx5e: TX, Inline function mlx5e_tls_handle_tx_wqe() (Alaa Hleihel) [1915308]
- net/mlx5e: TX, Inline TLS skb check (Alaa Hleihel) [1915308]
- net/mlx5e: Cleanup unused function parameter (Alaa Hleihel) [1915308]
- net/mlx5e: Remove non-essential TLS SQ state bit (Alaa Hleihel) [1915308]
- net/mlx5e: Restrict usage of mlx5e_priv in params logic functions (Alaa Hleihel) [1915308]
- net/mlx5e: Fix lost changes during code movements (Alaa Hleihel) [1915308]
- net/mlx5e: Move params logic into its dedicated file (Alaa Hleihel) [1915308]
- net/mlx5e: Pass q_counter indentifier as parameter to rq_param builders (Alaa Hleihel) [1915308]
- net/mlx5e: Block offload of outer header csum for GRE tunnel (Alaa Hleihel) [1915308]
- net/mlx5e: Block offload of outer header csum for UDP tunnels (Alaa Hleihel) [1915308]
- Revert "net/mlx5: Arm only EQs with EQEs" (Alaa Hleihel) [1915308]
- net/mlx5e: Verify dev is present in get devlink port ndo (Alaa Hleihel) [1915308]
- net/mlx5: DR, Don't use SW steering when RoCE is not supported (Alaa Hleihel) [1915308]
- net/mlx5: Consider RoCE cap before init RDMA resources (Alaa Hleihel) [1915308]
- net/mlx5e: Fix page reclaim for dead peer hairpin (Alaa Hleihel) [1915308]
- net/mlx5e: Remove dependency in IPsec initialization flows (Alaa Hleihel) [1915308]
- net/mlx5e: Fix use-after-free of encap entry in neigh update handler (Alaa Hleihel) [1915308]
- IB/mlx5: Fix initializing CQ fragments buffer (Alaa Hleihel) [1915308 1974263]
- RDMA/mlx5: Block FDB rules when not in switchdev mode (Alaa Hleihel) [1915308]
- RDMA/mlx5: Use different doorbell memory for different processes (Alaa Hleihel) [1915308]
- net/mlx5: Fix duplicate included vhca_event.h (Alaa Hleihel) [1915308]
- net/mlx5: Fix lag port remapping logic (Alaa Hleihel) [1915308]
- net/mlx5e: IPsec/rep_tc: Fix rep_tc_update_skb drops IPsec packet (Alaa Hleihel) [1915308]
- net/mlx5: DR, Create multi-destination flow table with level less than 64 (Alaa Hleihel) [1915308]
- net/mlx5e: Fix adding encap rules to slow path (Alaa Hleihel) [1915308]
- net/mlx5e: Check for needed capability for cvlan matching (Alaa Hleihel) [1915308]
- net/mlx5: Check firmware sync reset requested is set before trying to abort it (Alaa Hleihel) [1915308]
- net/mlx5e: Disable TLS offload for uplink representor (Alaa Hleihel) [1915308]
- net/mlx5e: Fix incompatible casting (Alaa Hleihel) [1915308]
- RDMA/mlx5: Fix query DCT via DEVX (Alaa Hleihel) [1915308]
- RDMA/mlx5: Recover from fatal event in dual port mode (Alaa Hleihel) [1915308]
- net/mlx5: Set term table as an unmanaged flow table (Alaa Hleihel) [1915308]
- net/mlx5e: Fix error path of updating netdev queues (Alaa Hleihel) [1915308]
- net/mlx5e: Reject mirroring on source port change encap rules (Alaa Hleihel) [1915308]
- net/mlx5e: Fix multipath lag activation (Alaa Hleihel) [1915308]
- net/mlx5e: reset XPS on error flow if netdev isn't registered yet (Alaa Hleihel) [1915308]
- net/mlx5e: Make sure fib dev exists in fib event (Alaa Hleihel) [1915308]
- net/mlx5e: Fix null deref accessing lag dev (Alaa Hleihel) [1915308]
- net/mlx5e: Fix nullptr in mlx5e_tc_add_fdb_flow() (Alaa Hleihel) [1915308]
- net/mlx5: SF, Fix show state inactive when its inactivated (Alaa Hleihel) [1915308]
- net/mlx5: Set reformat action when needed for termination rules (Alaa Hleihel) [1915308]
- net/mlx5e: Fix nullptr in add_vlan_push_action() (Alaa Hleihel) [1915308]
- {net, RDMA}/mlx5: Fix override of log_max_qp by other device (Alaa Hleihel) [1915308]
- net/mlx5: DR, Fix SQ/RQ in doorbell bitmask (Alaa Hleihel) [1915308]
- net/mlx5: Fix bit-wise and with zero (Alaa Hleihel) [1915308]
- RDMA/mlx5: Fix drop packet rule in egress table (Alaa Hleihel) [1915308]
- net/mlx5: Fix spelling mistakes in mlx5_core_info message (Alaa Hleihel) [1915308]
- net/mlx5: DR, Fixed typo in STE v0 (Alaa Hleihel) [1915308]
- RDMA/mlx5: Fix mlx5 rates to IB rates map (Alaa Hleihel) [1915308]
- RDMA/mlx5: Fix query RoCE port (Alaa Hleihel) [1915308]
- RDMA/mlx5: Zero out ODP related items in the mlx5_ib_mr (Alaa Hleihel) [1915308]
- net/mlx5e: Alloc flow spec using kvzalloc instead of kzalloc (Alaa Hleihel) [1915308]
- net/mlx5: Avoid unnecessary operation (Alaa Hleihel) [1915308]
- net/mlx5e: rep: Improve reg_cX conditions (Alaa Hleihel) [1915308]
- net/mlx5: SF, Fix return type (Alaa Hleihel) [1915308]
- net/mlx5e: mlx5_tc_ct_init does not fail (Alaa Hleihel) [1915308]
- net/mlx5: Fix indir stable stubs (Alaa Hleihel) [1915308]
- net/mlx5e: Add missing include (Alaa Hleihel) [1915308]
- net/mlx5e: fix mlx5e_tc_tun_update_header_ipv6 dummy definition (Alaa Hleihel) [1915308]
- net/mlx5e: CT, Avoid false lock dependency warning (Alaa Hleihel) [1915308]
- net/mlx5: Check returned value from health recover sequence (Alaa Hleihel) [1915308]
- net/mlx5: Don't rely on interface state bit (Alaa Hleihel) [1915308]
- net/mlx5: Remove second FW tracer check (Alaa Hleihel) [1915308]
- net/mlx5: Separate probe vs. reload flows (Alaa Hleihel) [1915308]
- net/mlx5: Remove impossible checks of interface state (Alaa Hleihel) [1915308]
- net/mlx5: Don't skip vport check (Alaa Hleihel) [1915308]
- net/mlx5e: Register nic devlink port for SF ports (Alaa Hleihel) [1915308]
- vdpa/mlx5: Retrieve BAR address suitable any function (Alaa Hleihel) [1915308]
- vdpa/mlx5: Use the correct dma device when registering memory (Alaa Hleihel) [1915308]
- net/mlx5: SF, Extend SF table for additional SF id range (Alaa Hleihel) [1915308]
- net/mlx5: SF, Split mlx5_sf_hw_table into two parts (Alaa Hleihel) [1915308]
- net/mlx5: SF, Use helpers for allocation and free (Alaa Hleihel) [1915308]
- net/mlx5: SF, Consider own vhca events of SF devices (Alaa Hleihel) [1915308]
- net/mlx5: SF, Store and use start function id (Alaa Hleihel) [1915308]
- net/mlx5: SF, Rely on hw table for SF devlink port allocation (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Consider SF ports of host PF (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Use xarray for vport number to vport and rep mapping (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Prepare to return total vports from eswitch struct (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Return eswitch max ports when eswitch is supported (Alaa Hleihel) [1915308]
- net/mlx5: SF, Reuse stored hardware function id (Alaa Hleihel) [1915308]
- net/mlx5: SF, Use device pointer directly (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Initialize eswitch acls ns when eswitch is enabled (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Move legacy code to a individual file (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Convert a macro to a helper routine (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch Make cleanup sequence mirror of init (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Make vport number u16 (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Skip querying SF enabled bits (Alaa Hleihel) [1915308]
- IB/mlx5: Set right RoCE l3 type and roce version while deleting GID (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, move QoS specific fields to existing qos struct (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, cut down mlx5_vport_info structure size by 8 bytes (Alaa Hleihel) [1915308]
- net/mlx5: Pair mutex_destory with mutex_init for rate limit table (Alaa Hleihel) [1915308]
- net/mlx5: Allocate rate limit table when rate is configured (Alaa Hleihel) [1915308]
- net/mlx5: Use helper to increment, decrement rate entry refcount (Alaa Hleihel) [1915308]
- net/mlx5: Use helpers to allocate and free rl table entries (Alaa Hleihel) [1915308]
- net/mlx5: Do not hold mutex while reading table constants (Alaa Hleihel) [1915308]
- net/mlx5: Pack mlx5_rl_entry structure (Alaa Hleihel) [1915308]
- net/mlx5: Use unsigned int for free_count (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, move QoS specific fields to existing qos struct (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, cut down mlx5_vport_info structure size by 8 bytes (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, let user to enable disable metadata (Alaa Hleihel) [1915308]
- net/mlx5e: TC, Add support to offload sample action (Alaa Hleihel) [1915308 1919649]
- net/mlx5e: TC, Handle sampled packets (Alaa Hleihel) [1915308 1919649]
- net/mlx5e: TC, Refactor tc update skb function (Alaa Hleihel) [1915308 1919649]
- net/mlx5e: TC, Add sampler restore handle API (Alaa Hleihel) [1915308 1919649]
- net/mlx5e: TC, Add sampler object API (Alaa Hleihel) [1915308 1919649]
- net/mlx5e: TC, Add sampler termination table API (Alaa Hleihel) [1915308 1919649]
- net/mlx5e: TC, Parse sample action (Alaa Hleihel) [1915308 1919649]
- net/mlx5: Instantiate separate mapping objects for FDB and NIC tables (Alaa Hleihel) [1915308 1919649]
- net/mlx5: Map register values to restore objects (Alaa Hleihel) [1915308 1919649]
- net/mlx5: E-switch, Set per vport table default group number (Alaa Hleihel) [1915308 1919649]
- net/mlx5: E-switch, Generalize per vport table API (Alaa Hleihel) [1915308 1919649]
- net/mlx5: E-switch, Rename functions to follow naming convention. (Alaa Hleihel) [1915308 1919649]
- net/mlx5: E-switch, Move vport table functions to a new file (Alaa Hleihel) [1915308 1919649]
- net/mlx5: CT: Add support for mirroring (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, Protect changing mode while adding rules (Alaa Hleihel) [1915308 1790457]
- net/mlx5: E-Switch, Change mode lock from mutex to rw semaphore (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Do not reload ethernet ports when changing eswitch mode (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Unregister eth-reps devices first (Alaa Hleihel) [1915308 1790457]
- net/mlx5: Move mlx5e hw resources into a sub object (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Register nic devlink port with switch id (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Verify dev is present in some ndos (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Use nic mode netdev ndos and ethtool ops for uplink representor (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Add offload stats ndos to nic netdev ops (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Distinguish nic and esw offload in tc setup block cb (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Allow legacy vf ndos only if in legacy mode (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: Same max num channels for both nic and uplink profiles (Alaa Hleihel) [1915308 1790457]
- net/mlx5e: fix ingress_ifindex check in mlx5e_flower_parse_meta (Alaa Hleihel) [1915308]
- net/mlx5e: Fix setting of RS FEC mode (Alaa Hleihel) [1915308]
- net/mlx5: Fix setting of devlink traps in switchdev mode (Alaa Hleihel) [1915308]
- net/mlx5: DR, Add missing vhca_id consume from STEv1 (Alaa Hleihel) [1915308]
- net/mlx5: fix kfree mismatch in indir_table.c (Alaa Hleihel) [1915308]
- net/mlx5: Fix PBMC register mapping (Alaa Hleihel) [1915308]
- net/mlx5: Fix PPLM register mapping (Alaa Hleihel) [1915308]
- net/mlx5: Fix placement of log_max_flow_counter (Alaa Hleihel) [1915308]
- net/mlx5: Fix HW spec violation configuring uplink (Alaa Hleihel) [1915308]
- net/mlx5e: Guarantee room for XSK wakeup NOP on async ICOSQ (Alaa Hleihel) [1915308]
- net/mlx5e: Consider geneve_opts for encap contexts (Alaa Hleihel) [1915308]
- net/mlx5: Don't request more than supported EQs (Alaa Hleihel) [1915308]
- net/mlx5e: kTLS, Fix RX counters atomicity (Alaa Hleihel) [1915308]
- net/mlx5e: kTLS, Fix TX counters atomicity (Alaa Hleihel) [1915308]
- net/mlx5: E-switch, Create vport miss group only if src rewrite is supported (Alaa Hleihel) [1915308 1915310]
- net/mlx5e: Fix ethtool indication of connector type (Alaa Hleihel) [1915308]
- net/mlx5: Delete auxiliary bus driver eth-rep first (Alaa Hleihel) [1915308]
- net/mlx5e: Fix mapping of ct_label zero (Alaa Hleihel) [1915308]
- net/mlx5: SF, do not use ecpu bit for vhca state processing (Alaa Hleihel) [1915308]
- net/mlx5e: Fix division by 0 in mlx5e_select_queue (Alaa Hleihel) [1915308]
- net/mlx5e: Fix error path for ethtool set-priv-flag (Alaa Hleihel) [1915308]
- net/mlx5e: Offload tuple rewrite for non-CT flows (Alaa Hleihel) [1915308]
- net/mlx5e: Allow to match on MPLS parameters only for MPLS over UDP (Alaa Hleihel) [1915308]
- net/mlx5: Add back multicast stats for uplink representor (Alaa Hleihel) [1915308]
- RDMA/mlx5: Fix typo in destroy_mkey inbox (Alaa Hleihel) [1915308]
- net/mlx5: DR, Fix potential shift wrapping of 32-bit value in STEv1 getter (Alaa Hleihel) [1915308]
- net/mlx5: SF: Fix error flow of SFs allocation flow (Alaa Hleihel) [1915308]
- net/mlx5: SF: Fix memory leak of work item (Alaa Hleihel) [1915308]
- net/mlx5: SF, Correct vhca context size (Alaa Hleihel) [1915308]
- net/mlx5e: E-switch, Fix rate calculation division (Alaa Hleihel) [1915308]
- RDMA/mlx5: Fix timestamp default mode (Alaa Hleihel) [1915308]
- net/mlx5: Set QP timestamp mode to default (Alaa Hleihel) [1915308]
- net/mlx5e: Fix error flow in change profile (Alaa Hleihel) [1915308]
- net/mlx5: Disable VF tunnel TX offload if ignore_flow_level isn't supported (Alaa Hleihel) [1915308 1915310]
- net/mlx5e: Check correct ip_version in decapsulation route resolution (Alaa Hleihel) [1915308]
- net/mlx5: Fix turn-off PPS command (Alaa Hleihel) [1915308]
- net/mlx5e: Don't match on Geneve options in case option masks are all zero (Alaa Hleihel) [1915308]
- net/mlx5e: Revert parameters on errors when changing PTP state without reset (Alaa Hleihel) [1915308]
- net/mlx5e: When changing XDP program without reset, take refs for XSK RQs (Alaa Hleihel) [1915308]
- net/mlx5e: Set PTP channel pointer explicitly to NULL (Alaa Hleihel) [1915308]
- net/mlx5e: Accumulate port PTP TX stats with other channels stats (Alaa Hleihel) [1915308]
- net/mlx5e: RX, Mind the MPWQE gaps when calculating offsets (Alaa Hleihel) [1915308]
- net/mlx5e: Enforce minimum value check for ICOSQ size (Alaa Hleihel) [1915308]
- RDMA/mlx5: Set correct kernel-doc identifier (Alaa Hleihel) [1915308]
- IB/mlx5: Add missing error code (Alaa Hleihel) [1915308]
- configs: Enable mlx5 subfunction device support (Alaa Hleihel) [1915308 1851717]
- net/mlx5: Add cyc2time HW translation mode support (Alaa Hleihel) [1915308 1919657]
- net/mlx5: Move some PPS logic into helper functions (Alaa Hleihel) [1915308 1919657]
- net/mlx5: Move all internal timer metadata into a dedicated struct (Alaa Hleihel) [1915308 1919657]
- net/mlx5: Refactor init clock function (Alaa Hleihel) [1915308 1919657]
- net/mlx5: Add register layout to support real-time time-stamp (Alaa Hleihel) [1915308 1919657]
- RDMA/mlx5: Fail QP creation if the device can not support the CQE TS (Alaa Hleihel) [1915308]
- RDMA/mlx5: Allow CQ creation without attached EQs (Alaa Hleihel) [1915308]
- net/mlx5: Add new timestamp mode bits (Alaa Hleihel) [1915308 1919657]
- net/mlx5: Remove TLS dependencies on XPS (Alaa Hleihel) [1915308]
- net/mlx5: SF, Fix error return code in mlx5_sf_dev_probe() (Alaa Hleihel) [1915308 1851717]
- net/mlx5e: Fix error return code in mlx5e_tc_esw_init() (Alaa Hleihel) [1915308 1919647]
- net/mlx5: Fix a NULL vs IS_ERR() check (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: Fix tc_tun.h to verify MLX5_ESWITCH config (Alaa Hleihel) [1915308 1919647]
- net/mlx5: Assign boolean values to a bool variable (Alaa Hleihel) [1915308]
- net/mlx5e: Fix spelling mistake "Unknouwn" -> "Unknown" (Alaa Hleihel) [1915308]
- net/mlx5e: Fix spelling mistake "channles" -> "channels" (Alaa Hleihel) [1915308]
- net/mlx5: Delete device list leftover (Alaa Hleihel) [1915308]
- net/mlx5_core: remove unused including <generated/utsrelease.h> (Alaa Hleihel) [1915308]
- net/mlx5: fix spelling mistake in Kconfig "accelaration" -> "acceleration" (Alaa Hleihel) [1915308]
- RDMA/mlx5: Support 400Gbps IB rate in mlx5 driver (Alaa Hleihel) [1915308]
- RDMA/mlx5: Cleanup the synchronize_srcu() from the ODP flow (Alaa Hleihel) [1915308]
- net/mlx5e: Handle FIB events to update tunnel endpoint device (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: Rename some encap-specific API to generic names (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: TC preparation refactoring for routing update event (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: Refactor neigh update infrastructure (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: Create route entry infrastructure (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: Extract tc tunnel encap/decap code to dedicated file (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: Match recirculated packet miss in slow table using reg_c1 (Alaa Hleihel) [1915308 1915310 1919647]
- net/mlx5e: Refactor reg_c1 usage (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: VF tunnel RX traffic offloading (Alaa Hleihel) [1915308 1915310 1919647]
- net/mlx5e: Remove redundant match on tunnel destination mac (Alaa Hleihel) [1915308 1919647]
- net/mlx5: E-Switch, Indirect table infrastructure (Alaa Hleihel) [1915308 1915310 1919647]
- net/mlx5e: Refactor tun routing helpers (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: VF tunnel TX traffic offloading (Alaa Hleihel) [1915308 1915310 1919647]
- net/mlx5: E-Switch, Refactor rule offload forward action processing (Alaa Hleihel) [1915308 1915310 1919647]
- net/mlx5e: Always set attr mdev pointer (Alaa Hleihel) [1915308 1919647]
- net/mlx5e: E-Switch, Maintain vhca_id to vport_num mapping (Alaa Hleihel) [1915308 1915310 1919647]
- net/mlx5: E-Switch, Refactor setting source port (Alaa Hleihel) [1915308 1915310 1919647]
- IB/mlx5: Use rdma_for_each_port for port iteration (Alaa Hleihel) [1915308]
- RDMA/core: Introduce and use API to read port immutable data (Alaa Hleihel) [1915308]
- IB/mlx5: Improve query port for representor port (Alaa Hleihel) [1915308]
- IB/mlx5: Avoid calling query device for reading pkey table length (Alaa Hleihel) [1915308]
- IB/mlx5: Move mlx5_port_caps from mlx5_core_dev to mlx5_ib_dev (Alaa Hleihel) [1915308]
- IB/mlx5: Support default partition key for representor port (Alaa Hleihel) [1915308]
- net/mlx5: DR, Avoid unnecessary csum recalculation on supporting devices (Alaa Hleihel) [1915308]
- net/mlx5e: CT: remove useless conversion to PTR_ERR then ERR_PTR (Alaa Hleihel) [1915308]
- net/mlx5e: accel, remove redundant space (Alaa Hleihel) [1915308]
- net/mlx5e: kTLS, Improve TLS RX workqueue scope (Alaa Hleihel) [1915308]
- net/mlx5e: remove h from printk format specifier (Alaa Hleihel) [1915308]
- net/mlx5e: Increase indirection RQ table size to 256 (Alaa Hleihel) [1915308]
- net/mlx5e: Enable napi in channel's activation stage (Alaa Hleihel) [1915308]
- net/mlx5e: Move representor neigh init into profile enable (Alaa Hleihel) [1915308]
- net/mlx5e: Avoid false lock depenency warning on tc_ht (Alaa Hleihel) [1915308]
- net/mlx5e: Move set vxlan nic info to profile init (Alaa Hleihel) [1915308]
- net/mlx5e: Move netif_carrier_off() out of mlx5e_priv_init() (Alaa Hleihel) [1915308]
- net/mlx5e: Refactor mlx5e_netdev_init/cleanup to mlx5e_priv_init/cleanup (Alaa Hleihel) [1915308]
- net/mxl5e: Add change profile method (Alaa Hleihel) [1915308]
- net/mlx5e: Separate between netdev objects and mlx5e profiles initialization (Alaa Hleihel) [1915308]
- net/mlx5: DR, Allow SW steering for sw_owner_v2 devices (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Copy all 64B whenever replacing STE in the head of miss-list (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Use HW specific logic API when writing STE (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Use the right size when writing partial STE into HW (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Add STEv1 modify header logic (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Add STEv1 action apply logic (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Add STEv1 setters and getters (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Allow native protocol support for HW STEv1 (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Add HW STEv1 match logic (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Add match STEv1 structs to ifc (Alaa Hleihel) [1915308 1851712]
- net/mlx5: DR, Fix potential shift wrapping of 32-bit value (Alaa Hleihel) [1915308 1851712]
- net/mlx5e: Enable traps according to link state (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Add listener to DMAC filter trap event (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Add listener to trap event (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Add trap entity to ETH driver (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Expose RX dma info helpers (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Add flow steering DMAC trap rule (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Add flow steering VLAN trap rule (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Optimize promiscuous mode (Alaa Hleihel) [1915308 1919652]
- net/mlx5: Notify on trap action by blocking event (Alaa Hleihel) [1915308 1919652]
- net/mlx5: Rename events notifier header (Alaa Hleihel) [1915308 1919652]
- net/mlx5: Register to devlink DMAC filter trap (Alaa Hleihel) [1915308 1919652]
- net/mlx5: Register to devlink ingress VLAN filter trap (Alaa Hleihel) [1915308 1919652]
- net/mlx5: Add support for devlink traps in mlx5 core driver (Alaa Hleihel) [1915308 1919652]
- net/mlx5e: Support HTB offload (Alaa Hleihel) [1915308]
- net/mlx5: SF, Port function state change support (Alaa Hleihel) [1915308 1851717]
- net/mlx5: SF, Add port add delete functionality (Alaa Hleihel) [1915308 1851717]
- net/mlx5: E-switch, Add eswitch helpers for SF vport (Alaa Hleihel) [1915308 1915310 1851717]
- net/mlx5: E-switch, Prepare eswitch to handle SF vport (Alaa Hleihel) [1915308 1915310 1851717]
- net/mlx5: SF, Add auxiliary device driver (Alaa Hleihel) [1915308 1851717]
- net/mlx5: SF, Add auxiliary device support (Alaa Hleihel) [1915308 1851717]
- net/mlx5: Introduce vhca state event notifier (Alaa Hleihel) [1915308 1851717]
- RDMA/hw/mlx5/qp: Demote non-conformant kernel-doc header (Alaa Hleihel) [1915308]
- RDMA/hw/mlx5/odp: Fix formatting and add missing descriptions in 'pagefault_data_segments()' (Alaa Hleihel) [1915308]
- IB/mlx5: Make function static (Alaa Hleihel) [1915308]
- net/mlx5e: IPsec, Remove unnecessary config flag usage (Alaa Hleihel) [1915308]
- net/mlx5e: IPsec, Inline feature_check fast-path function (Alaa Hleihel) [1915308]
- net/mlx5e: IPsec, Avoid unreachable return (Alaa Hleihel) [1915308]
- net/mlx5e: IPsec, Enclose csum logic under ipsec config (Alaa Hleihel) [1915308]
- net/mlx5e: CT: Remove redundant usage of zone mask (Alaa Hleihel) [1915308]
- net/mlx5e: Remove redundant initialization to null (Alaa Hleihel) [1915308]
- net/mlx5e: CT: Pass null instead of zero spec (Alaa Hleihel) [1915308]
- net/mlx5e: E-Switch, Offload all chain 0 priorities when modify header and forward action is not supported (Alaa Hleihel) [1915308]
- net/mlx5: E-Switch, use new cap as condition for mpls over udp (Alaa Hleihel) [1915308]
- net/mlx5e: Simplify condition on esw_vport_enable_qos() (Alaa Hleihel) [1915308]
- net/mlx5: Add HW definition of reg_c_preserve (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move STEv0 modify header logic (Alaa Hleihel) [1915308]
- net/mlx5: DR, Add STE modify header actions per-device API (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move STEv0 action apply logic (Alaa Hleihel) [1915308]
- net/mlx5: DR, Add STE tx/rx actions per-device API (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move STEv0 setters and getters (Alaa Hleihel) [1915308]
- net/mlx5: DR, Add STE setters and getters per-device API (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move action apply logic to dr_ste (Alaa Hleihel) [1915308]
- net/mlx5: DR, Refactor ICMP STE builder (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move STEv0 look up types from mlx5_ifc_dr header (Alaa Hleihel) [1915308]
- net/mlx5: DR, Merge similar DR STE SET macros (Alaa Hleihel) [1915308]
- net/mlx5: DR, Fix STEv0 source_eswitch_owner_vhca_id support (Alaa Hleihel) [1915308]
- net/mlx5: DR, Remove unused macro definition from dr_ste (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move HW STEv0 match logic to a separate file (Alaa Hleihel) [1915308]
- net/mlx5: DR, Use the new HW specific STE infrastructure (Alaa Hleihel) [1915308]
- net/mlx5: DR, Move macros from dr_ste.c to header (Alaa Hleihel) [1915308]
- net/mlx5: DR, Add infrastructure for supporting several steering formats (Alaa Hleihel) [1915308]
- ext4: handle read only external journal device (Lukas Czerner) [1860929]
- vfio/pci: Handle concurrent vma faults (Alex Williamson) [1976551]
- vfio-pci: Use io_remap_pfn_range() for PCI IO memory (Alex Williamson) [1976551]
- net: flow_dissector: Parse PTP L2 packet header (Ivan Vecera) [1971687]
- net: vlan: Add parse protocol header ops (Ivan Vecera) [1971687]
- PCI: hv: Remove bus device removal unused refcount/functions (Mohammed Gamal) [1982482]
- PCI: hv: Fix a race condition when removing the device (Mohammed Gamal) [1982482]
- RDMA/cxgb4: check for ipv6 address properly while destroying listener (Raju Rangoju) [1961313]
- RDMA/cxgb4: Fix adapter LE hash errors while destroying ipv6 listening server (Raju Rangoju) [1961313]
- RDMA: Convert sysfs device * show functions to use sysfs_emit() (Raju Rangoju) [1961313]
- RDMA/iw_cxgb4: Disable delayed ack by default (Raju Rangoju) [1961313]
- [infiniband] treewide: Remove uninitialized_var() usage (Raju Rangoju) [1961313]
- RDMA/iw_cxgb4: cleanup device debugfs entries on ULD remove (Raju Rangoju) [1961313]
- vfs: allow unprivileged whiteout creation (Miklos Szeredi) [1983608]
- Documentation: kdump: update kdump guide (Baoquan He) [1938067]
- docs: admin-guide: add kdump documentation into it (Baoquan He) [1938067]
- docs: kdump: convert docs to ReST and rename to *.rst (Baoquan He) [1938067]

* Wed Jul 14 2021 Augusto Caringi <acaringi@redhat.com> [4.18.0-323.el8]
- Revert "be2net: disable bh with spin_lock in be_process_mcc" (Petr Oros) [1973504]
- nvmet-rdma: Fix NULL deref when SEND is completed with error (Gopal Tiwari) [1959856]
- netfilter: nft_exthdr: Search chunks in SCTP packets only (Phil Sutter) [1868228]
- netfilter: nft_exthdr: Fix for unsafe packet data read (Phil Sutter) [1868228]
- netfilter: nft_exthdr: Support SCTP chunks (Phil Sutter) [1868228]
- xfs: fix deadlock retry tracepoint arguments (Bill O'Donnell) [1937116]
- xfs: fix xfs_reflink_unshare usage of filemap_write_and_wait_range (Bill O'Donnell) [1937116]
- xfs: fix return of uninitialized value in variable error (Bill O'Donnell) [1937116]
- xfs: fix scrub and remount-ro protection when running scrub (Bill O'Donnell) [1937116]
- xfs: fix xfs_trans slab cache name (Bill O'Donnell) [1937116]
- xfs: Fix a typo (Bill O'Donnell) [1937116]
- xfs: Rudimentary spelling fix (Bill O'Donnell) [1937116]
- xfs: Rudimentary typo fixes (Bill O'Donnell) [1937116]
- xfs: fix dquot scrub loop cancellation (Bill O'Donnell) [1937116]
- xfs: fix uninitialized variables in xrep_calc_ag_resblks (Bill O'Donnell) [1937116]
- xfs: fix incorrect root dquot corruption error when switching group/project quota types (Bill O'Donnell) [1937116]
- xfs: fix up build warnings when quotas are disabled (Bill O'Donnell) [1937116]
- xfs: fix chown leaking delalloc quota blocks when fssetxattr fails (Bill O'Donnell) [1937116]
- xfs: Fix assert failure in xfs_setattr_size() (Bill O'Donnell) [1937116]
- xfs: fix an ABBA deadlock in xfs_rename (Bill O'Donnell) [1937116 1966609]
- xfs: fix the forward progress assertion in xfs_iwalk_run_callbacks (Bill O'Donnell) [1937116]
- xfs: fix parent pointer scrubber bailing out on unallocated inodes (Bill O'Donnell) [1937116]
- xfs: revert "xfs: fix rmap key and record comparison functions" (Bill O'Donnell) [1937116]
- xfs: don't allow NOWAIT DIO across extent boundaries (Bill O'Donnell) [1937116]
- xfs: return corresponding errcode if xfs_initialize_perag() fail (Bill O'Donnell) [1937116]
- xfs: ensure inobt record walks always make forward progress (Bill O'Donnell) [1937116]
- xfs: fix forkoff miscalculation related to XFS_LITINO(mp) (Bill O'Donnell) [1937116]
- xfs: directory scrub should check the null bestfree entries too (Bill O'Donnell) [1937116]
- xfs: strengthen rmap record flags checking (Bill O'Donnell) [1937116]
- xfs: fix the minrecs logic when dealing with inode root child blocks (Bill O'Donnell) [1937116]
- xfs: fix a missing unlock on error in xfs_fs_map_blocks (Bill O'Donnell) [1937116]
- xfs: fix brainos in the refcount scrubber's rmap fragment processor (Bill O'Donnell) [1937116]
- xfs: fix rmap key and record comparison functions (Bill O'Donnell) [1937116]
- xfs: set the unwritten bit in rmap lookup flags in xchk_bmap_get_rmapextents (Bill O'Donnell) [1937116]
- xfs: fix flags argument to rmap lookup when converting shared file rmaps (Bill O'Donnell) [1937116]
- xfs: only flush the unshared range in xfs_reflink_unshare (Bill O'Donnell) [1937116]
- xfs: fix scrub flagging rtinherit even if there is no rt device (Bill O'Donnell) [1937116]
- xfs: fix missing CoW blocks writeback conversion retry (Bill O'Donnell) [1937116]
- xfs: set xefi_discard when creating a deferred agfl free log intent item (Bill O'Donnell) [1937116]
- xfs: cancel intents immediately if process_intents fails (Bill O'Donnell) [1937116]
- xfs: fix fallocate functions when rtextsize is larger than 1 (Bill O'Donnell) [1937116]
- xfs: fix high key handling in the rt allocator's query_range function (Bill O'Donnell) [1937116]
- xfs: annotate grabbing the realtime bitmap/summary locks in growfs (Bill O'Donnell) [1937116]
- xfs: make xfs_growfs_rt update secondary superblocks (Bill O'Donnell) [1937116]
- xfs: fix realtime bitmap/summary file truncation when growing rt volume (Bill O'Donnell) [1937116]
- xfs: fix the indent in xfs_trans_mod_dquot (Bill O'Donnell) [1937116]
- xfs: do the ASSERT for the arguments O_{u,g,p}dqpp (Bill O'Donnell) [1937116]
- xfs: fix deadlock and streamline xfs_getfsmap performance (Bill O'Donnell) [1937116]
- xfs: limit entries returned when counting fsmap records (Bill O'Donnell) [1937116]
- xfs: only relog deferred intent items if free space in the log gets low (Bill O'Donnell) [1937116]
- xfs: expose the log push threshold (Bill O'Donnell) [1937116]
- xfs: periodically relog deferred intent items (Bill O'Donnell) [1937116]
- xfs: change the order in which child and parent defer ops are finished (Bill O'Donnell) [1937116]
- xfs: fix an incore inode UAF in xfs_bui_recover (Bill O'Donnell) [1937116]
- xfs: clean up xfs_bui_item_recover iget/trans_alloc/ilock ordering (Bill O'Donnell) [1937116]
- xfs: clean up bmap intent item recovery checking (Bill O'Donnell) [1937116]
- xfs: xfs_defer_capture should absorb remaining transaction reservation (Bill O'Donnell) [1937116]
- xfs: xfs_defer_capture should absorb remaining block reservations (Bill O'Donnell) [1937116]
- xfs: proper replay of deferred ops queued during log recovery (Bill O'Donnell) [1937116]
- xfs: remove XFS_LI_RECOVERED (Bill O'Donnell) [1937116]
- xfs: remove xfs_defer_reset (Bill O'Donnell) [1937116]
- xfs: fix finobt btree block recovery ordering (Bill O'Donnell) [1937116]
- xfs: directly call xfs_generic_create() for ->create() and ->mkdir() (Bill O'Donnell) [1937116]
- xfs: avoid shared rmap operations for attr fork extents (Bill O'Donnell) [1937116]
- xfs: drop the obsolete comment on filestream locking (Bill O'Donnell) [1937116]
- xfs: code cleanup in xfs_attr_leaf_entsize_{remote,local} (Bill O'Donnell) [1937116]
- xfs: do the assert for all the log done items in xfs_trans_cancel (Bill O'Donnell) [1937116]
- xfs: remove the unused parameter id from xfs_qm_dqattach_one (Bill O'Donnell) [1937116]
- xfs: remove the redundant crc feature check in xfs_attr3_rmt_verify (Bill O'Donnell) [1937116]
- xfs: fix some comments (Bill O'Donnell) [1937116]
- xfs: remove the unnecessary xfs_dqid_t type cast (Bill O'Donnell) [1937116]
- xfs: use the existing type definition for di_projid (Bill O'Donnell) [1937116]
- xfs: remove the unused SYNCHRONIZE macro (Bill O'Donnell) [1937116]
- xfs: clean up calculation of LR header blocks (Bill O'Donnell) [1937116]
- xfs: avoid LR buffer overrun due to crafted h_len (Bill O'Donnell) [1937116]
- xfs: don't release log intent items when recovery fails (Bill O'Donnell) [1937116]
- xfs: attach inode to dquot in xfs_bui_item_recover (Bill O'Donnell) [1937116]
- xfs: log new intent items created as part of finishing recovered intent items (Bill O'Donnell) [1937116]
- xfs: check dabtree node hash values when loading child blocks (Bill O'Donnell) [1937116]
- xfs: don't free rt blocks when we're doing a REMAP bunmapi call (Bill O'Donnell) [1937116]
- xfs: Set xfs_buf's b_ops member when zeroing bitmap/summary files (Bill O'Donnell) [1937116]
- xfs: Set xfs_buf type flag when growing summary/bitmap files (Bill O'Donnell) [1937116]
- xfs: drop extra transaction roll from inode extent truncate (Bill O'Donnell) [1937116]
- xfs: don't propagate RTINHERIT -> REALTIME when there is no rtdev (Bill O'Donnell) [1937116]
- xfs: ensure that fpunch, fcollapse, and finsert operations are aligned to rt extent size (Bill O'Donnell) [1937116]
- xfs: refactor inode flags propagation code (Bill O'Donnell) [1937116]
- xfs: make sure the rt allocator doesn't run off the end (Bill O'Donnell) [1937116]
- xfs: Remove unneeded semicolon (Bill O'Donnell) [1937116]
- xfs: force the log after remapping a synchronous-writes file (Bill O'Donnell) [1937116]
- xfs: Convert xfs_attr_sf macros to inline functions (Bill O'Donnell) [1937116]
- xfs: Use variable-size array for nameval in xfs_attr_sf_entry (Bill O'Donnell) [1937116]
- xfs: Remove typedef xfs_attr_shortform_t (Bill O'Donnell) [1937116]
- xfs: remove typedef xfs_attr_sf_entry_t (Bill O'Donnell) [1937116]
- xfs: Remove kmem_zalloc_large() (Bill O'Donnell) [1937116]
- xfs: enable big timestamps (Bill O'Donnell) [1937116]
- xfs: trace timestamp limits (Bill O'Donnell) [1937116]
- xfs: widen ondisk quota expiration timestamps to handle y2038+ (Bill O'Donnell) [1937116]
- xfs: widen ondisk inode timestamps to deal with y2038+ (Bill O'Donnell) [1937116]
- xfs: redefine xfs_ictimestamp_t (Bill O'Donnell) [1937116]
- xfs: redefine xfs_timestamp_t (Bill O'Donnell) [1937116]
- xfs: move xfs_log_dinode_to_disk to the log recovery code (Bill O'Donnell) [1937116]
- xfs: refactor quota timestamp coding (Bill O'Donnell) [1937116]
- xfs: refactor default quota grace period setting code (Bill O'Donnell) [1937116]
- xfs: refactor quota expiration timer modification (Bill O'Donnell) [1937116]
- xfs: explicitly define inode timestamp range (Bill O'Donnell) [1937116]
- xfs: enable new inode btree counters feature (Bill O'Donnell) [1937116]
- xfs: support inode btree blockcounts in online repair (Bill O'Donnell) [1937116]
- xfs: support inode btree blockcounts in online scrub (Bill O'Donnell) [1937116]
- xfs: use the finobt block counts to speed up mount times (Bill O'Donnell) [1937116]
- xfs: store inode btree block counts in AGI header (Bill O'Donnell) [1937116]
- xfs: reuse _xfs_buf_read for re-reading the superblock (Bill O'Donnell) [1937116]
- xfs: remove xfs_getsb (Bill O'Donnell) [1937116]
- xfs: simplify xfs_trans_getsb (Bill O'Donnell) [1937116]
- xfs: remove xlog_recover_iodone (Bill O'Donnell) [1937116]
- xfs: clear the read/write flags later in xfs_buf_ioend (Bill O'Donnell) [1937116]
- xfs: use xfs_buf_item_relse in xfs_buf_item_done (Bill O'Donnell) [1937116]
- xfs: simplify the xfs_buf_ioend_disposition calling convention (Bill O'Donnell) [1937116]
- xfs: lift the XBF_IOEND_FAIL handling into xfs_buf_ioend_disposition (Bill O'Donnell) [1937116]
- xfs: remove xfs_buf_ioerror_retry (Bill O'Donnell) [1937116]
- xfs: refactor xfs_buf_ioerror_fail_without_retry (Bill O'Donnell) [1937116]
- xfs: fold xfs_buf_ioend_finish into xfs_ioend (Bill O'Donnell) [1937116]
- xfs: move the buffer retry logic to xfs_buf.c (Bill O'Donnell) [1937116]
- xfs: refactor xfs_buf_ioend (Bill O'Donnell) [1937116]
- xfs: mark xfs_buf_ioend static (Bill O'Donnell) [1937116]
- xfs: refactor the buf ioend disposition code (Bill O'Donnell) [1937116]
- xfs: xfs_iflock is no longer a completion (Bill O'Donnell) [1937116]
- xfs: remove kmem_realloc() (Bill O'Donnell) [1937116]
- xfs: don't update mtime on COW faults (Bill O'Donnell) [1937116]
- xfs: fix xfs_bmap_validate_extent_raw when checking attr fork of rt files (Bill O'Donnell) [1937116]
- xfs: initialize the shortform attr header padding entry (Bill O'Donnell) [1937116]
- xfs: fix off-by-one in inode alloc block reservation calculation (Bill O'Donnell) [1937116]
- xfs: finish dfops on every insert range shift iteration (Bill O'Donnell) [1937116]
- xfs: Fix UBSAN null-ptr-deref in xfs_sysfs_init (Bill O'Donnell) [1937116]
- xfs: delete duplicated words + other fixes (Bill O'Donnell) [1937116]
- xfs: Lift -ENOSPC handler from xfs_attr_leaf_addname (Bill O'Donnell) [1937116]
- xfs: Simplify xfs_attr_node_addname (Bill O'Donnell) [1937116]
- xfs: Simplify xfs_attr_leaf_addname (Bill O'Donnell) [1937116]
- xfs: Add helper function xfs_attr_node_removename_rmt (Bill O'Donnell) [1937116]
- xfs: Add helper function xfs_attr_node_removename_setup (Bill O'Donnell) [1937116]
- xfs: Add remote block helper functions (Bill O'Donnell) [1937116]
- xfs: Add helper function xfs_attr_leaf_mark_incomplete (Bill O'Donnell) [1937116]
- xfs: Add helpers xfs_attr_is_shortform and xfs_attr_set_shortform (Bill O'Donnell) [1937116]
- xfs: Remove xfs_trans_roll in xfs_attr_node_removename (Bill O'Donnell) [1937116]
- xfs: Remove unneeded xfs_trans_roll_inode calls (Bill O'Donnell) [1937116]
- xfs: Add helper function xfs_attr_node_shrink (Bill O'Donnell) [1937116]
- xfs: Pull up xfs_attr_rmtval_invalidate (Bill O'Donnell) [1937116]
- xfs: Refactor xfs_attr_rmtval_remove (Bill O'Donnell) [1937116]
- xfs: Pull up trans roll in xfs_attr3_leaf_clearflag (Bill O'Donnell) [1937116]
- xfs: Factor out xfs_attr_rmtval_invalidate (Bill O'Donnell) [1937116]
- xfs: Pull up trans roll from xfs_attr3_leaf_setflag (Bill O'Donnell) [1937116]
- xfs: Refactor xfs_attr_try_sf_addname (Bill O'Donnell) [1937116]
- xfs: Split apart xfs_attr_leaf_addname (Bill O'Donnell) [1937116]
- xfs: Pull up trans handling in xfs_attr3_leaf_flipflags (Bill O'Donnell) [1937116]
- xfs: Factor out new helper functions xfs_attr_rmtval_set (Bill O'Donnell) [1937116]
- xfs: Check for -ENOATTR or -EEXIST (Bill O'Donnell) [1937116]
- xfs: Add xfs_has_attr and subroutines (Bill O'Donnell) [1937116]
- xfs: Refactor xfs_da_state_alloc() helper (Bill O'Donnell) [1937116]
- xfs: remove xfs_zone_{alloc,zalloc} helpers (Bill O'Donnell) [1937116]
- xfs: Modify xlog_ticket_alloc() to use kernel's MM API (Bill O'Donnell) [1937116]
- xfs: Remove kmem_zone_zalloc() usage (Bill O'Donnell) [1937116]
- xfs: Remove kmem_zone_alloc() usage (Bill O'Donnell) [1937116]
- xfs: xfs_btree_staging.h: delete duplicated words (Bill O'Donnell) [1937116]
- xfs: rename the ondisk dquot d_flags to d_type (Bill O'Donnell) [1937116]
- xfs: improve ondisk dquot flags checking (Bill O'Donnell) [1937116]
- xfs: create xfs_dqtype_t to represent quota types (Bill O'Donnell) [1937116]
- xfs: replace a few open-coded XFS_DQTYPE_REC_MASK uses (Bill O'Donnell) [1937116]
- xfs: remove unnecessary quota type masking (Bill O'Donnell) [1937116]
- xfs: always use xfs_dquot_type when extracting type from a dquot (Bill O'Donnell) [1937116]
- xfs: refactor quota type testing (Bill O'Donnell) [1937116]
- xfs: remove the XFS_QM_IS[UGP]DQ macros (Bill O'Donnell) [1937116]
- xfs: refactor testing if a particular dquot is being enforced (Bill O'Donnell) [1937116]
- xfs: rename XFS_DQ_{USER,GROUP,PROJ} to XFS_DQTYPE_* (Bill O'Donnell) [1937116]
- xfs: drop the type parameter from xfs_dquot_verify (Bill O'Donnell) [1937116]
- xfs: add more dquot tracepoints (Bill O'Donnell) [1937116]
- xfs: actually bump warning counts when we send warnings (Bill O'Donnell) [1937116]
- xfs: assume the default quota limits are always set in xfs_qm_adjust_dqlimits (Bill O'Donnell) [1937116]
- xfs: refactor xfs_trans_apply_dquot_deltas (Bill O'Donnell) [1937116]
- xfs: refactor xfs_trans_dqresv (Bill O'Donnell) [1937116]
- xfs: refactor xfs_qm_scall_setqlim (Bill O'Donnell) [1937116]
- xfs: refactor quota exceeded test (Bill O'Donnell) [1937116]
- xfs: remove unnecessary arguments from quota adjust functions (Bill O'Donnell) [1937116]
- xfs: refactor default quota limits by resource (Bill O'Donnell) [1937116]
- xfs: remove qcore from incore dquots (Bill O'Donnell) [1937116]
- xfs: stop using q_core timers in the quota code (Bill O'Donnell) [1937116]
- xfs: stop using q_core warning counters in the quota code (Bill O'Donnell) [1937116]
- xfs: stop using q_core counters in the quota code (Bill O'Donnell) [1937116]
- xfs: stop using q_core limits in the quota code (Bill O'Donnell) [1937116]
- xfs: use a per-resource struct for incore dquot data (Bill O'Donnell) [1937116]
- xfs: stop using q_core.d_id in the quota code (Bill O'Donnell) [1937116]
- xfs: stop using q_core.d_flags in the quota code (Bill O'Donnell) [1937116]
- xfs: make XFS_DQUOT_CLUSTER_SIZE_FSB part of the ondisk format (Bill O'Donnell) [1937116]
- xfs: rename dquot incore state flags (Bill O'Donnell) [1937116]
- xfs: refactor quotacheck flags usage (Bill O'Donnell) [1937116]
- xfs: move the flags argument of xfs_qm_scall_trunc_qfiles to XFS_QMOPT_* (Bill O'Donnell) [1937116]
- xfs: validate ondisk/incore dquot flags (Bill O'Donnell) [1937116]
- xfs: fix inode quota reservation checks (Bill O'Donnell) [1937116]
- xfs: clear XFS_DQ_FREEING if we can't lock the dquot buffer to flush (Bill O'Donnell) [1937116]
- xfs: drain the buf delwri queue before xfsaild idles (Bill O'Donnell) [1937116]
- xfs: remove duplicated include from xfs_buf_item.c (Bill O'Donnell) [1937116]
- xfs: remove SYNC_WAIT and SYNC_TRYLOCK (Bill O'Donnell) [1937116]
- xfs: get rid of unnecessary xfs_perag_{get,put} pairs (Bill O'Donnell) [1937116]
- xfs: rtbitmap scrubber should check inode size (Bill O'Donnell) [1937116]
- xfs: rtbitmap scrubber should verify written extents (Bill O'Donnell) [1937116]
- xfs: remove xfs_inobp_check() (Bill O'Donnell) [1937116]
- xfs: factor xfs_iflush_done (Bill O'Donnell) [1937116]
- xfs: rework xfs_iflush_cluster() dirty inode iteration (Bill O'Donnell) [1937116]
- xfs: rename xfs_iflush_int() (Bill O'Donnell) [1937116]
- xfs: xfs_iflush() is no longer necessary (Bill O'Donnell) [1937116]
- xfs: attach inodes to the cluster buffer when dirtied (Bill O'Donnell) [1937116]
- xfs: rework stale inodes in xfs_ifree_cluster (Bill O'Donnell) [1937116]
- xfs: clean up inode reclaim comments (Bill O'Donnell) [1937116]
- xfs: remove SYNC_WAIT from xfs_reclaim_inodes() (Bill O'Donnell) [1937116]
- xfs: remove SYNC_TRYLOCK from inode reclaim (Bill O'Donnell) [1937116]
- xfs: don't block inode reclaim on the ILOCK (Bill O'Donnell) [1937116]
- xfs: allow multiple reclaimers per AG (Bill O'Donnell) [1937116]
- xfs: remove IO submission from xfs_reclaim_inode() (Bill O'Donnell) [1937116]
- xfs: make inode reclaim almost non-blocking (Bill O'Donnell) [1937116]
- xfs: pin inode backing buffer to the inode log item (Bill O'Donnell) [1937116]
- xfs: move xfs_clear_li_failed out of xfs_ail_delete_one() (Bill O'Donnell) [1937116]
- xfs: unwind log item error flagging (Bill O'Donnell) [1937116]
- xfs: handle buffer log item IO errors directly (Bill O'Donnell) [1937116]
- xfs: get rid of log item callbacks (Bill O'Donnell) [1937116]
- xfs: clean up the buffer iodone callback functions (Bill O'Donnell) [1937116]
- xfs: use direct calls for dquot IO completion (Bill O'Donnell) [1937116]
- xfs: make inode IO completion buffer centric (Bill O'Donnell) [1937116]
- xfs: clean up whacky buffer log item list reinit (Bill O'Donnell) [1937116]
- xfs: call xfs_buf_iodone directly (Bill O'Donnell) [1937116]
- xfs: mark log recovery buffers for completion (Bill O'Donnell) [1937116]
- xfs: mark dquot buffers in cache (Bill O'Donnell) [1937116]
- xfs: mark inode buffers in cache (Bill O'Donnell) [1937116]
- xfs: add an inode item lock (Bill O'Donnell) [1937116]
- xfs: remove logged flag from inode log item (Bill O'Donnell) [1937116]
- xfs: Don't allow logging of XFS_ISTALE inodes (Bill O'Donnell) [1937116]
- xfs: remove useless definitions in xfs_linux.h (Bill O'Donnell) [1937116]
- xfs: use MMAPLOCK around filemap_map_pages() (Bill O'Donnell) [1937116]
- xfs: move helpers that lock and unlock two inodes against userspace IO (Bill O'Donnell) [1937116]
- xfs: refactor locking and unlocking two inodes against userspace IO (Bill O'Donnell) [1937116]
- xfs: fix xfs_reflink_remap_prep calling conventions (Bill O'Donnell) [1937116]
- xfs: reflink can skip remap existing mappings (Bill O'Donnell) [1937116]
- xfs: only reserve quota blocks if we're mapping into a hole (Bill O'Donnell) [1937116]
- xfs: only reserve quota blocks for bmbt changes if we're changing the data fork (Bill O'Donnell) [1937116]
- xfs: redesign the reflink remap loop to fix blkres depletion crash (Bill O'Donnell) [1937116]
- xfs: rename xfs_bmap_is_real_extent to is_written_extent (Bill O'Donnell) [1937116]
- xfs: Couple of typo fixes in comments (Bill O'Donnell) [1937116]
- xfs: fix use-after-free on CIL context on shutdown (Bill O'Donnell) [1937116]
- xfs: flag files as supporting buffered async reads (Bill O'Donnell) [1937116]
- fs: add FMODE_BUF_RASYNC (Bill O'Donnell) [1937116]
- xfs: more lockdep whackamole with kmem_alloc* (Bill O'Donnell) [1937116 1965923]
- xfs: rearrange xfs_inode_walk_ag parameters (Bill O'Donnell) [1937116]
- xfs: straighten out all the naming around incore inode tree walks (Bill O'Donnell) [1937116]
- xfs: move xfs_inode_ag_iterator to be closer to the perag walking code (Bill O'Donnell) [1937116]
- xfs: use bool for done in xfs_inode_ag_walk (Bill O'Donnell) [1937116]
- xfs: fix inode ag walk predicate function return values (Bill O'Donnell) [1937116]
- xfs: refactor eofb matching into a single helper (Bill O'Donnell) [1937116]
- xfs: remove __xfs_icache_free_eofblocks (Bill O'Donnell) [1937116]
- xfs: remove flags argument from xfs_inode_ag_walk (Bill O'Donnell) [1937116]
- xfs: remove xfs_inode_ag_iterator_flags (Bill O'Donnell) [1937116]
- xfs: remove unused xfs_inode_ag_iterator function (Bill O'Donnell) [1937116]
- xfs: replace open-coded XFS_ICI_NO_TAG (Bill O'Donnell) [1937116]
- xfs: move eofblocks conversion function to xfs_ioctl.c (Bill O'Donnell) [1937116]
- xfs: remove the m_active_trans counter (Bill O'Donnell) [1937116]
- xfs: separate read-only variables in struct xfs_mount (Bill O'Donnell) [1937116]
- xfs: reduce free inode accounting overhead (Bill O'Donnell) [1937116]
- xfs: gut error handling in xfs_trans_unreserve_and_mod_sb() (Bill O'Donnell) [1937116]
- xfs: cleanup xfs_idestroy_fork (Bill O'Donnell) [1937116]
- xfs: move the fork format fields into struct xfs_ifork (Bill O'Donnell) [1937116]
- xfs: move the per-fork nextents fields into struct xfs_ifork (Bill O'Donnell) [1937116]
- xfs: remove xfs_ifree_local_data (Bill O'Donnell) [1937116]
- xfs: remove the XFS_DFORK_Q macro (Bill O'Donnell) [1937116]
- xfs: clean up xchk_bmap_check_rmaps usage of XFS_IFORK_Q (Bill O'Donnell) [1937116]
- xfs: remove the NULL fork handling in xfs_bmapi_read (Bill O'Donnell) [1937116]
- xfs: remove the special COW fork handling in xfs_bmapi_read (Bill O'Donnell) [1937116]
- xfs: improve local fork verification (Bill O'Donnell) [1937116]
- xfs: refactor xfs_inode_verify_forks (Bill O'Donnell) [1937116]
- xfs: remove xfs_ifork_ops (Bill O'Donnell) [1937116]
- xfs: remove xfs_iread (Bill O'Donnell) [1937116]
- xfs: don't reset i_delayed_blks in xfs_iread (Bill O'Donnell) [1937116]
- xfs: call xfs_dinode_verify from xfs_inode_from_disk (Bill O'Donnell) [1937116]
- xfs: handle unallocated inodes in xfs_inode_from_disk (Bill O'Donnell) [1937116]
- xfs: split xfs_iformat_fork (Bill O'Donnell) [1937116]
- xfs: call xfs_iformat_fork from xfs_inode_from_disk (Bill O'Donnell) [1937116]
- xfs: xfs_bmapi_read doesn't take a fork id as the last argument (Bill O'Donnell) [1937116]
- xfs: fix the warning message in xfs_validate_sb_common() (Bill O'Donnell) [1937116]
- xfs: don't allow SWAPEXT if we'd screw up quota accounting (Bill O'Donnell) [1937116]
- xfs: use ordered buffers to initialize dquot buffers during quotacheck (Bill O'Donnell) [1937116]
- xfs: don't fail verifier on empty attr3 leaf block (Bill O'Donnell) [1937116]
- xfs: Use the correct style for SPDX License Identifier (Bill O'Donnell) [1937116]
- xfs: Replace zero-length array with flexible-array (Bill O'Donnell) [1937116]
- xfs: ensure f_bfree returned by statfs() is non-negative (Bill O'Donnell) [1937116]
- xfs: remove duplicate headers (Bill O'Donnell) [1937116]
- xfs: fix unused variable warning in buffer completion on !DEBUG (Bill O'Donnell) [1937116]
- xfs: remove unnecessary includes from xfs_log_recover.c (Bill O'Donnell) [1937116]
- xfs: move log recovery buffer cancellation code to xfs_buf_item_recover.c (Bill O'Donnell) [1937116]
- xfs: hoist setting of XFS_LI_RECOVERED to caller (Bill O'Donnell) [1937116]
- xfs: refactor intent item iop_recover calls (Bill O'Donnell) [1937116]
- xfs: refactor intent item RECOVERED flag into the log item (Bill O'Donnell) [1937116]
- xfs: refactor adding recovered intent items to the log (Bill O'Donnell) [1937116]
- xfs: refactor releasing finished intents during log recovery (Bill O'Donnell) [1937116]
- xfs: refactor xlog_item_is_intent now that we're done converting (Bill O'Donnell) [1937116]
- xfs: refactor recovered BUI log item playback (Bill O'Donnell) [1937116]
- xfs: refactor recovered CUI log item playback (Bill O'Donnell) [1937116]
- xfs: refactor recovered RUI log item playback (Bill O'Donnell) [1937116]
- xfs: refactor recovered EFI log item playback (Bill O'Donnell) [1937116]
- xfs: remove log recovery quotaoff item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery BUI item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery CUI item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery RUI item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery EFI item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery icreate item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery dquot item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery inode item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery buffer item dispatch for pass2 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery item dispatch for pass1 commit functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery item dispatch for pass2 readhead functions (Bill O'Donnell) [1937116]
- xfs: refactor log recovery item sorting into a generic dispatch structure (Bill O'Donnell) [1937116]
- xfs: convert xfs_log_recover_item_t to struct xfs_log_recover_item (Bill O'Donnell) [1937116]
- xfs: remove unused iget_flags param from xfs_imap_to_bp() (Bill O'Donnell) [1937116]
- xfs: remove unused shutdown types (Bill O'Donnell) [1937116]
- xfs: random buffer write failure errortag (Bill O'Donnell) [1937116]
- xfs: remove unused iflush stale parameter (Bill O'Donnell) [1937116]
- xfs: combine xfs_trans_ail_[remove|delete]() (Bill O'Donnell) [1937116]
- xfs: drop unused shutdown parameter from xfs_trans_ail_remove() (Bill O'Donnell) [1937116]
- xfs: use delete helper for items expected to be in AIL (Bill O'Donnell) [1937116]
- xfs: acquire ->ail_lock from xfs_trans_ail_delete() (Bill O'Donnell) [1937116]
- xfs: abort consistently on dquot flush failure (Bill O'Donnell) [1937116]
- xfs: ratelimit unmount time per-buffer I/O error alert (Bill O'Donnell) [1937116]
- xfs: refactor ratelimited buffer error messages into helper (Bill O'Donnell) [1937116]
- xfs: reset buffer write failure state on successful completion (Bill O'Donnell) [1937116]
- xfs: remove unnecessary shutdown check from xfs_iflush() (Bill O'Donnell) [1937116]
- xfs: simplify inode flush error handling (Bill O'Donnell) [1937116]
- xfs: factor out buffer I/O failure code (Bill O'Donnell) [1937116]
- xfs: refactor failed buffer resubmission into xfsaild (Bill O'Donnell) [1937116]
- xfs: spell out the parameter name for ->cancel_item (Bill O'Donnell) [1937116]
- xfs: use a xfs_btree_cur for the ->finish_cleanup state (Bill O'Donnell) [1937116]
- xfs: turn dfp_done into a xfs_log_item (Bill O'Donnell) [1937116]
- xfs: refactor xfs_defer_finish_noroll (Bill O'Donnell) [1937116]
- xfs: turn dfp_intent into a xfs_log_item (Bill O'Donnell) [1937116]
- xfs: merge the ->diff_items defer op into ->create_intent (Bill O'Donnell) [1937116]
- xfs: merge the ->log_item defer op into ->create_intent (Bill O'Donnell) [1937116]
- xfs: factor out a xfs_defer_create_intent helper (Bill O'Donnell) [1937116]
- xfs: remove the xfs_inode_log_item_t typedef (Bill O'Donnell) [1937116]
- xfs: remove the xfs_efd_log_item_t typedef (Bill O'Donnell) [1937116]
- xfs: remove the xfs_efi_log_item_t typedef (Bill O'Donnell) [1937116]
- xfs: refactor xlog_recover_buffer_pass1 (Bill O'Donnell) [1937116]
- xfs: simplify xlog_recover_inode_ra_pass2 (Bill O'Donnell) [1937116]
- xfs: factor out a xlog_buf_readahead helper (Bill O'Donnell) [1937116]
- xfs: rename inode_list xlog_recover_reorder_trans (Bill O'Donnell) [1937116]
- xfs: refactor the buffer cancellation table helpers (Bill O'Donnell) [1937116]
- xfs: define printk_once variants for xfs messages (Bill O'Donnell) [1937116]
- xfs: stop CONFIG_XFS_DEBUG from changing compiler flags (Bill O'Donnell) [1937116]
- xfs: remove unnecessary check of the variable resblks in xfs_symlink (Bill O'Donnell) [1937116]
- xfs: simplify the flags setting in xfs_qm_scall_quotaon (Bill O'Donnell) [1937116]
- xfs: remove unnecessary assertion from xfs_qm_vop_create_dqattach (Bill O'Donnell) [1937116]
- xfs: remove unnecessary variable udqp from xfs_ioctl_setattr (Bill O'Donnell) [1937116]
- xfs: reserve quota inode transaction space only when needed (Bill O'Donnell) [1937116]
- xfs: combine two if statements with same condition (Bill O'Donnell) [1937116]
- xfs: trace quota allocations for all quota types (Bill O'Donnell) [1937116]
- xfs: report unrecognized log item type codes during recovery (Bill O'Donnell) [1937116]
- xfs: move inode flush to the sync workqueue (Bill O'Donnell) [1937116]
- xfs: fix partially uninitialized structure in xfs_reflink_remap_extent (Bill O'Donnell) [1937116]
- xfs: fix inode number overflow in ifree cluster helper (Bill O'Donnell) [1937116]
- xfs: remove redundant variable assignment in xfs_symlink() (Bill O'Donnell) [1937116]
- xfs: ratelimit inode flush on buffered write ENOSPC (Bill O'Donnell) [1937116]
- xfs: return locked status of inode buffer on xfsaild push (Bill O'Donnell) [1937116]
- xfs: trylock underlying buffer on dquot flush (Bill O'Donnell) [1937116]
- xfs: remove unnecessary ternary from xfs_create (Bill O'Donnell) [1937116]
- xfs: don't write a corrupt unmount record to force summary counter recalc (Bill O'Donnell) [1937116]
- xfs: factor inode lookup from xfs_ifree_cluster (Bill O'Donnell) [1937116]
- xfs: tail updates only need to occur when LSN changes (Bill O'Donnell) [1937116]
- xfs: factor common AIL item deletion code (Bill O'Donnell) [1937116]
- xfs: correctly acount for reclaimable slabs (Bill O'Donnell) [1937116]
- xfs: Improve metadata buffer reclaim accountability (Bill O'Donnell) [1937116]
- xfs: don't allow log IO to be throttled (Bill O'Donnell) [1937116]
- xfs: Throttle commits on delayed background CIL push (Bill O'Donnell) [1937116]
- xfs: Lower CIL flush limit for large logs (Bill O'Donnell) [1937116]
- xfs: remove some stale comments from the log code (Bill O'Donnell) [1937116]
- xfs: refactor unmount record writing (Bill O'Donnell) [1937116]
- xfs: merge xlog_commit_record with xlog_write_done (Bill O'Donnell) [1937116]
- xfs: split xlog_ticket_done (Bill O'Donnell) [1937116]
- xfs: kill XLOG_TIC_INITED (Bill O'Donnell) [1937116]
- xfs: refactor and split xfs_log_done() (Bill O'Donnell) [1937116]
- xfs: re-order initial space accounting checks in xlog_write (Bill O'Donnell) [1937116]
- xfs: don't try to write a start record into every iclog (Bill O'Donnell) [1937116]
- xfs: validate the realtime geometry in xfs_validate_sb_common (Bill O'Donnell) [1937116]
- xfs: shutdown on failure to add page to log bio (Bill O'Donnell) [1937116]
- xfs: directory bestfree check should release buffers (Bill O'Donnell) [1937116]
- xfs: drop all altpath buffers at the end of the sibling check (Bill O'Donnell) [1937116]
- xfs: remove xlog_state_want_sync (Bill O'Donnell) [1937116]
- xfs: move the ioerror check out of xlog_state_clean_iclog (Bill O'Donnell) [1937116]
- xfs: refactor xlog_state_clean_iclog (Bill O'Donnell) [1937116]
- xfs: remove the aborted parameter to xlog_state_done_syncing (Bill O'Donnell) [1937116]
- xfs: simplify log shutdown checking in xfs_log_release_iclog (Bill O'Donnell) [1937116]
- xfs: simplify the xfs_log_release_iclog calling convention (Bill O'Donnell) [1937116]
- xfs: factor out a xlog_wait_on_iclog helper (Bill O'Donnell) [1937116]
- xfs: merge xlog_cil_push into xlog_cil_push_work (Bill O'Donnell) [1937116]
- xfs: remove the di_version field from struct icdinode (Bill O'Donnell) [1937116]
- xfs: simplify a check in xfs_ioctl_setattr_check_cowextsize (Bill O'Donnell) [1937116]
- xfs: simplify di_flags2 inheritance in xfs_ialloc (Bill O'Donnell) [1937116]
- xfs: only check the superblock version for dinode size calculation (Bill O'Donnell) [1937116]
- xfs: add a new xfs_sb_version_has_v3inode helper (Bill O'Donnell) [1937116]
- xfs: add support for rmap btree staging cursors (Bill O'Donnell) [1937116]
- xfs: add support for refcount btree staging cursors (Bill O'Donnell) [1937116]
- xfs: add support for inode btree staging cursors (Bill O'Donnell) [1937116]
- xfs: add support for free space btree staging cursors (Bill O'Donnell) [1937116]
- xfs: support bulk loading of staged btrees (Bill O'Donnell) [1937116]
- xfs: introduce fake roots for inode-rooted btrees (Bill O'Donnell) [1937116]
- xfs: introduce fake roots for ag-rooted btrees (Bill O'Donnell) [1937116]
- xfs: replace open-coded bitmap weight logic (Bill O'Donnell) [1937116]
- xfs: rename xfs_bitmap to xbitmap (Bill O'Donnell) [1937116]
- xfs: xrep_reap_extents should not destroy the bitmap (Bill O'Donnell) [1937116]
- xfs: cleanup xfs_log_unmount_write (Bill O'Donnell) [1937116]
- xfs: remove dead code from xfs_log_unmount_write (Bill O'Donnell) [1937116]
- xfs: remove the unused return value from xfs_log_unmount_write (Bill O'Donnell) [1937116]
- xfs: remove the unused XLOG_UNMOUNT_REC_TYPE define (Bill O'Donnell) [1937116]
- xfs: mark XLOG_FORCED_SHUTDOWN as unlikely (Bill O'Donnell) [1937116]
- xfs: make the btree ag cursor private union anonymous (Bill O'Donnell) [1937116]
- xfs: make the btree cursor union members named structure (Bill O'Donnell) [1937116]
- xfs: make btree cursor private union anonymous (Bill O'Donnell) [1937116]
- xfs: rename btree cursor private btree member flags (Bill O'Donnell) [1937116]
- xfs: convert btree cursor inode-private member names (Bill O'Donnell) [1937116]
- xfs: convert btree cursor ag-private member name (Bill O'Donnell) [1937116]
- xfs: introduce new private btree cursor names (Bill O'Donnell) [1937116]
- xfs: Use scnprintf() for avoiding potential buffer overflow (Bill O'Donnell) [1937116]
- xfs: mark extended attr corrupt when lookup-by-hash fails (Bill O'Donnell) [1937116]
- xfs: mark dir corrupt when lookup-by-hash fails (Bill O'Donnell) [1937116]
- xfs: check owner of dir3 blocks (Bill O'Donnell) [1937116]
- xfs: check owner of dir3 data blocks (Bill O'Donnell) [1937116]
- xfs: check owner of dir3 free blocks (Bill O'Donnell) [1937116]
- xfs: fix buffer corruption reporting when xfs_dir3_free_header_check fails (Bill O'Donnell) [1937116]
- xfs: xfs_buf_corruption_error should take __this_address (Bill O'Donnell) [1937116]
- xfs: add a function to deal with corrupt buffers post-verifiers (Bill O'Donnell) [1937116]
- xfs: remove XFS_BUF_TO_SBP (Bill O'Donnell) [1937116]
- xfs: remove XFS_BUF_TO_AGF (Bill O'Donnell) [1937116]
- xfs: remove XFS_BUF_TO_AGI (Bill O'Donnell) [1937116]
- xfs: remove the xfs_agfl_t typedef (Bill O'Donnell) [1937116]
- xfs: remove the agfl_bno member from struct xfs_agfl (Bill O'Donnell) [1937116]
- xfs: switch xfs_attrmulti_attr_get to lazy attr buffer allocation (Bill O'Donnell) [1937116]
- xfs: only allocate the buffer size actually needed in __xfs_set_acl (Bill O'Donnell) [1937116]
- xfs: clean up bufsize alignment in xfs_ioc_attr_list (Bill O'Donnell) [1937116]
- xfs: embedded the attrlist cursor into struct xfs_attr_list_context (Bill O'Donnell) [1937116]
- xfs: remove XFS_DA_OP_INCOMPLETE (Bill O'Donnell) [1937116]
- xfs: clean up the attr flag confusion (Bill O'Donnell) [1937116]
- xfs: clean up the ATTR_REPLACE checks (Bill O'Donnell) [1937116]
- xfs: improve xfs_forget_acl (Bill O'Donnell) [1937116]
- xfs: lift cursor copy in/out into xfs_ioc_attr_list (Bill O'Donnell) [1937116]
- xfs: lift buffer allocation into xfs_ioc_attr_list (Bill O'Donnell) [1937116]
- xfs: lift common checks into xfs_ioc_attr_list (Bill O'Donnell) [1937116]
- xfs: rename xfs_attr_list_int to xfs_attr_list (Bill O'Donnell) [1937116]
- xfs: move the legacy xfs_attr_list to xfs_ioctl.c (Bill O'Donnell) [1937116]
- xfs: open code ATTR_ENTSIZE (Bill O'Donnell) [1937116]
- xfs: remove the unused ATTR_ENTRY macro (Bill O'Donnell) [1937116]
- xfs: cleanup struct xfs_attr_list_context (Bill O'Donnell) [1937116]
- xfs: factor out a xfs_attr_match helper (Bill O'Donnell) [1937116]
- xfs: replace ATTR_KERNOTIME with XFS_DA_OP_NOTIME (Bill O'Donnell) [1937116]
- xfs: remove ATTR_ALLOC and XFS_DA_OP_ALLOCVAL (Bill O'Donnell) [1937116]
- xfs: remove ATTR_KERNOVAL (Bill O'Donnell) [1937116]
- xfs: remove the xfs_inode argument to xfs_attr_get_ilocked (Bill O'Donnell) [1937116]
- xfs: pass an initialized xfs_da_args to xfs_attr_get (Bill O'Donnell) [1937116]
- xfs: pass an initialized xfs_da_args structure to xfs_attr_set (Bill O'Donnell) [1937116]
- xfs: turn xfs_da_args.value into a void pointer (Bill O'Donnell) [1937116]
- xfs: remove the MAXNAMELEN check from xfs_attr_args_init (Bill O'Donnell) [1937116]
- xfs: remove the name == NULL check from xfs_attr_args_init (Bill O'Donnell) [1937116]
- xfs: factor out a helper for a single XFS_IOC_ATTRMULTI_BY_HANDLE op (Bill O'Donnell) [1937116]
- xfs: use strndup_user in XFS_IOC_ATTRMULTI_BY_HANDLE (Bill O'Donnell) [1937116]
- xfs: merge xfs_attrmulti_attr_remove into xfs_attrmulti_attr_set (Bill O'Donnell) [1937116]
- xfs: merge xfs_attr_remove into xfs_attr_set (Bill O'Donnell) [1937116]
- xfs: remove the ATTR_INCOMPLETE flag (Bill O'Donnell) [1937116]
- xfs: reject invalid flags combinations in XFS_IOC_ATTRLIST_BY_HANDLE (Bill O'Donnell) [1937116]
- xfs: rework collapse range into an atomic operation (Bill O'Donnell) [1937116]
- xfs: rework insert range into an atomic operation (Bill O'Donnell) [1937116]
- xfs: open code insert range extent split helper (Bill O'Donnell) [1937116]
- xfs: Add missing annotation to xfs_ail_check() (Bill O'Donnell) [1937116]
- xfs: fix an undefined behaviour in _da3_path_shift (Bill O'Donnell) [1937116]
- xfs: ratelimit xfs_discard_page messages (Bill O'Donnell) [1937116]
- xfs: ratelimit xfs_buf_ioerror_alert messages (Bill O'Donnell) [1937116]
- xfs: remove the kuid/kgid conversion wrappers (Bill O'Donnell) [1937116]
- xfs: remove the icdinode di_uid/di_gid members (Bill O'Donnell) [1937116]
- xfs: ensure that the inode uid/gid match values match the icdinode ones (Bill O'Donnell) [1937116]
- xfs: improve error message when we can't allocate memory for xfs_buf (Bill O'Donnell) [1937116]
- ceph: fix test for whether we can skip read when writing beyond EOF (Jeff Layton) [1971101]
- redhat/configs: Add CONFIG_X86_SGX_KVM (Bandan Das) [1494649]
- KVM: x86: Fix implicit enum conversion goof in scattered reverse CPUID code (Bandan Das) [1494649]
- KVM: x86: Add capability to grant VM access to privileged SGX attribute (Bandan Das) [1494649]
- KVM: VMX: Enable SGX virtualization for SGX1, SGX2 and LC (Bandan Das) [1494649]
- KVM: VMX: Add ENCLS[EINIT] handler to support SGX Launch Control (LC) (Bandan Das) [1494649]
- KVM: VMX: Add emulation of SGX Launch Control LE hash MSRs (Bandan Das) [1494649]
- KVM: VMX: Add SGX ENCLS[ECREATE] handler to enforce CPUID restrictions (Bandan Das) [1494649]
- KVM: VMX: Frame in ENCLS handler for SGX virtualization (Bandan Das) [1494649]
- KVM: VMX: Add basic handling of VM-Exit from SGX enclave (Bandan Das) [1494649]
- KVM: x86: Add reverse-CPUID lookup support for scattered SGX features (Bandan Das) [1494649]
- KVM: x86: Add support for reverse CPUID lookup of scattered features (Bandan Das) [1494649]
- KVM: x86: Define new #PF SGX error code bit (Bandan Das) [1494649]
- KVM: x86: Export kvm_mmu_gva_to_gpa_{read,write}() for SGX (VMX) (Bandan Das) [1494649]
- x86/sgx: Mark sgx_vepc_vm_ops static (Bandan Das) [1494649]
- x86/sgx: Do not update sgx_nr_free_pages in sgx_setup_epc_section() (Bandan Das) [1494649]
- x86/sgx: Move provisioning device creation out of SGX driver (Bandan Das) [1494649]
- x86/sgx: Add helpers to expose ECREATE and EINIT to KVM (Bandan Das) [1494649]
- x86/sgx: Add helper to update SGX_LEPUBKEYHASHn MSRs (Bandan Das) [1494649]
- x86/sgx: Add encls_faulted() helper (Bandan Das) [1494649]
- x86/sgx: Add SGX2 ENCLS leaf definitions (EAUG, EMODPR and EMODT) (Bandan Das) [1494649]
- x86/sgx: Move ENCLS leaf definitions to sgx.h (Bandan Das) [1494649]
- x86/sgx: Expose SGX architectural definitions to the kernel (Bandan Das) [1494649]
- x86/sgx: Initialize virtual EPC driver even when SGX driver is disabled (Bandan Das) [1494649]
- x86/cpu/intel: Allow SGX virtualization without Launch Control support (Bandan Das) [1494649]
- x86/sgx: Introduce virtual EPC for use by KVM guests (Bandan Das) [1494649]
- x86/sgx: Add SGX_CHILD_PRESENT hardware error code (Bandan Das) [1494649]
- x86/sgx: Wipe out EREMOVE from sgx_free_epc_page() (Bandan Das) [1494649]
- x86/cpufeatures: Add SGX1 and SGX2 sub-features (Bandan Das) [1494649]
- x86/cpufeatures: Make SGX_LC feature bit depend on SGX bit (Bandan Das) [1494649]
- x86/sgx: Remove unnecessary kmap() from sgx_ioc_enclave_init() (Bandan Das) [1494649]
- selftests/sgx: Use getauxval() to simplify test code (Bandan Das) [1494649]
- selftests/sgx: Improve error detection and messages (Bandan Das) [1494649]
- x86/sgx: Add a basic NUMA allocation scheme to sgx_alloc_epc_page() (Bandan Das) [1494649]
- x86/sgx: Replace section->init_laundry_list with sgx_dirty_page_list (Bandan Das) [1494649]
- x86/sgx: Maintain encl->refcount for each encl->mm_list entry (Bandan Das) [1494649]
- MAINTAINERS: Add Dave Hansen as reviewer for INTEL SGX (Bandan Das) [1494649]
- x86/NUMA: Provide a range-to-target_node lookup facility (Bandan Das) [1494649]
- x86/mm: Introduce CONFIG_NUMA_KEEP_MEMINFO (Bandan Das) [1494649]
- configs: Enable CONFIG_MLXBF_GIGE on aarch64 (Alaa Hleihel) [1803489]
- Add Mellanox BlueField Gigabit Ethernet driver (Alaa Hleihel) [1803489]
- integrity: Use current_uid() in integrity_audit_message() (Richard Guy Briggs) [1957052]
- ima: AppArmor satisfies the audit rule requirements (Richard Guy Briggs) [1957052]
- IMA: Add audit log for failure conditions (Richard Guy Briggs) [1957052]
- integrity: Add errno field in audit message (Richard Guy Briggs) [1957052]
- audit: add blank line after variable declarations (Richard Guy Briggs) [1957052]
- audit: drop /proc/PID/loginuid documentation Format field (Richard Guy Briggs) [1957052]
- audit: avoid -Wempty-body warning (Richard Guy Briggs) [1957052]
- audit: document /proc/PID/sessionid (Richard Guy Briggs) [1957052]
- audit: document /proc/PID/loginuid (Richard Guy Briggs) [1957052]
- MAINTAINERS: update audit files (Richard Guy Briggs) [1957052]
- audit: further cleanup of AUDIT_FILTER_ENTRY deprecation (Richard Guy Briggs) [1957052]
- netfilter: nftables: fix a warning message in nf_tables_commit_audit_collect() (Richard Guy Briggs) [1957052]
- audit: log nftables configuration change events once per table (Richard Guy Briggs) [1957052]
- audit_alloc_mark(): don't open-code ERR_CAST() (Richard Guy Briggs) [1957052]
- make dump_common_audit_data() safe to be called from RCU pathwalk (Richard Guy Briggs) [1957052]
- new helper: d_find_alias_rcu() (Richard Guy Briggs) [1957052]
- audit: Make audit_filter_syscall() return void (Richard Guy Briggs) [1957052]
- audit: Remove leftover reference to the audit_tasklet (Richard Guy Briggs) [1957052]
- kernel/audit: convert comma to semicolon (Richard Guy Briggs) [1957052]
- dump_common_audit_data(): fix racy accesses to ->d_name (Richard Guy Briggs) [1957052]
- audit: replace atomic_add_return() (Richard Guy Briggs) [1957052]
- x86/audit: Fix a -Wmissing-prototypes warning for ia32_classify_syscall() (Richard Guy Briggs) [1957052]
- ethtool: fix kdoc attr name (Ivan Vecera) [1967261]
- ethtool: Remove link_mode param and derive link params from driver (Ivan Vecera) [1967261]
- ethtool: Add lanes parameter for ETHTOOL_LINK_MODE_10000baseR_FEC_BIT (Ivan Vecera) [1967261]
- ethtool: fix kdoc in headers (Ivan Vecera) [1967261]
- ethtool: document reserved fields in the uAPI (Ivan Vecera) [1967261]
- ethtool: un-kdocify extended link state (Ivan Vecera) [1967261]
- ethtool: document PHY tunable callbacks (Ivan Vecera) [1967261]
- docs: ethtool: fix some copy-paste errors (Ivan Vecera) [1967261]
- ethtool: fix incorrect datatype in set_eee ops (Ivan Vecera) [1967261]
- net: selftests: Add lanes setting test (Ivan Vecera) [1967261]
- mlxsw: ethtool: Pass link mode in use to ethtool (Ivan Vecera) [1967261]
- mlxsw: ethtool: Add support for setting lanes when autoneg is off (Ivan Vecera) [1967261]
- mlxsw: ethtool: Remove max lanes filtering (Ivan Vecera) [1967261]
- ethtool: Expose the number of lanes in use (Ivan Vecera) [1967261]
- ethtool: Get link mode in use instead of speed and duplex parameters (Ivan Vecera) [1967261]
- ethtool: prepare __ethtool_get_link_ksettings for subsequent changes (Ivan Vecera) [1967261]
- ethtool: Extend link modes settings uAPI with lanes (Ivan Vecera) [1967261]
- ethtool: Validate master slave configuration before rtnl_lock() (Ivan Vecera) [1967261]
- ethtool: fix string set id check (Ivan Vecera) [1967261]
- ethtool: fix stack overflow in ethnl_parse_bitset() (Ivan Vecera) [1967261]
- selftests: add ring and coalesce selftests (Ivan Vecera) [1967261]
- selftests: refactor get_netdev_name function (Ivan Vecera) [1967261]
- selftests: extract common functions in ethtool-common.sh (Ivan Vecera) [1967261]
- netdevsim: support ethtool ring and coalesce settings (Ivan Vecera) [1967261]
- netdevsim: move ethtool pause params in separate struct (Ivan Vecera) [1967261]
- ethtool: add ETHTOOL_COALESCE_ALL_PARAMS define (Ivan Vecera) [1967261]
- ethtool: netlink: add missing netdev_features_change() call (Ivan Vecera) [1967261]
- ethtool: remove unneeded semicolon (Ivan Vecera) [1967261]
- ethtool: allow netdev driver to define phy tunables (Ivan Vecera) [1967261]
- ethtool: mark netlink family as __ro_after_init (Ivan Vecera) [1967261]
- ethtool: Add 100base-FX link mode entries (Ivan Vecera) [1967261]
- ethtool: fix error handling in ethtool_phys_id (Ivan Vecera) [1967261]
- ethtool: allow flow-type ether without IP protocol field (Ivan Vecera) [1967261]
- net: phy: Uninline PHY ethtool statistics operations (Ivan Vecera) [1967261]
- net: phy: Define PHY statistics ethtool_phy_ops (Ivan Vecera) [1967261]
- net: ethtool: Remove PHYLIB direct dependency (Ivan Vecera) [1967261]
- net: phy: Register ethtool PHY operations (Ivan Vecera) [1967261]
- genksyms: Ignore module scoped _Static_assert() (Ivan Vecera) [1967261]
- net: ethtool: Introduce ethtool_phy_ops (Ivan Vecera) [1967261]
- Documentation: networking: fix ethtool-netlink table formats (Ivan Vecera) [1967261]
- ethtool: ioctl: Use array_size() in copy_to_user() (Ivan Vecera) [1967261]
- net: ethtool: cabletest: Make ethnl_act_cable_test_tdr_cfg static (Ivan Vecera) [1967261]
- SUNRPC: Handle major timeout in xprt_adjust_timeout() (Scott Mayhew) [1979070]
- gro_cells: reduce number of synchronize_net() calls (Ivan Vecera) [1959015]
- net: make sure napi_list is safe for RCU traversal (Ivan Vecera) [1959015]
- net: manage napi add/del idempotence explicitly (Ivan Vecera) [1959015]
- net: remove napi_hash_del() from driver-facing API (Ivan Vecera) [1959015]
- net: disable netpoll on fresh napis (Ivan Vecera) [1959015]
- usb: dwc3-meson-g12a: fix usb2 PHY glue init when phy0 is disabled (Torez Smith) [1942772]
- xhci: Fix 5.12 regression of missing xHC cache clearing command after a Stall (Torez Smith) [1942772]
- xhci: fix giving back URB with incorrect status regression in 5.12 (Torez Smith) [1942772]
- usb: typec: ucsi: Clear pending after acking connector change (Torez Smith) [1942772]
- net: hso: check for allocation failure in hso_create_bulk_serial_device() (Torez Smith) [1942772]
- usb: typec: tcpm: Fix wrong handling in GET_SINK_CAP (Torez Smith) [1942772]
- net: hso: fix NULL-deref on disconnect regression (Torez Smith) [1942772]
- USB: CDC-ACM: fix poison/unpoison imbalance (Torez Smith) [1942772]
- usbip: vudc: fix missing unlock on error in usbip_sockfd_store() (Torez Smith) [1942772]
- usb: xhci-mtk: improve bandwidth scheduling with TT (Torez Smith) [1942772]
- usb: xhci-mtk: remove or operator for setting schedule parameters (Torez Smith) [1942772]
- usb: typec: tcpm: Wait for vbus discharge to VSAFE0V before toggling (Torez Smith) [1942772]
- software node: Provide replacement for device_add_properties() (Torez Smith) [1942772]
- driver core: platform: Reimplement devm_platform_ioremap_resource (Torez Smith) [1942772]
- USB: usblp: initialize newChannel (Torez Smith) [1942772]
- net: hso: fix null-ptr-deref during tty device unregistration (Torez Smith) [1942772]
- usbip: synchronize event handler with sysfs code paths (Torez Smith) [1942772]
- usbip: vudc synchronize sysfs code paths (Torez Smith) [1942772]
- usbip: stub-dev synchronize sysfs code paths (Torez Smith) [1942772]
- usbip: add sysfs_lock to synchronize sysfs code paths (Torez Smith) [1942772]
- drivers: net: fix memory leak in peak_usb_create_dev (Torez Smith) [1942772]
- thunderbolt: Fix off by one in tb_port_find_retimer() (Torez Smith) [1942772]
- thunderbolt: Fix a leak in tb_retimer_add() (Torez Smith) [1942772]
- usb: dwc2: Prevent core suspend when port connection flag is 0 (Torez Smith) [1942772]
- usb: dwc2: Fix HPRT0.PrtSusp bit setting for HiKey 960 board. (Torez Smith) [1942772]
- usb: xhci-mtk: fix broken streams issue on 0.96 xHCI (Torez Smith) [1942772]
- usbip: vhci_hcd fix shift out-of-bounds in vhci_hub_control() (Torez Smith) [1942772]
- USB: quirks: ignore remote wake-up on Fibocom L850-GL LTE modem (Torez Smith) [1942772]
- USB: cdc-acm: do not log successful probe on later errors (Torez Smith) [1942772]
- USB: cdc-acm: always claim data interface (Torez Smith) [1942772]
- USB: cdc-acm: use negation for NULL checks (Torez Smith) [1942772]
- USB: cdc-acm: clean up probe error labels (Torez Smith) [1942772]
- USB: cdc-acm: drop redundant driver-data reset (Torez Smith) [1942772]
- USB: cdc-acm: drop redundant driver-data assignment (Torez Smith) [1942772]
- USB: cdc-acm: fix use-after-free after probe failure (Torez Smith) [1942772]
- USB: cdc-acm: fix double free on probe failure (Torez Smith) [1942772]
- USB: cdc-acm: downgrade message to debug (Torez Smith) [1942772]
- USB: cdc-acm: untangle a circular dependency between callback and softint (Torez Smith) [1942772]
- cdc-acm: fix BREAK rx code path adding necessary calls (Torez Smith) [1942772]
- usb: dwc3: pci: Enable dis_uX_susphy_quirk for Intel Merrifield (Torez Smith) [1942772]
- usb: dwc3: qcom: skip interconnect init for ACPI probe (Torez Smith) [1942772]
- can: peak_usb: Revert "can: peak_usb: add forgotten supported devices" (Torez Smith) [1942772]
- r8152: limit the RX buffer size of RTL8153A for USB 2.0 (Torez Smith) [1942772]
- net: cdc-phonet: fix data-interface release on probe failure (Torez Smith) [1942772]
- usb: typec: tcpm: Skip sink_cap query only when VDM sm is busy (Torez Smith) [1942772]
- usb: typec: tcpm: Invoke power_supply_changed for tcpm-source-psy- (Torez Smith) [1942772]
- usb: typec: Remove vdo[3] part of tps6598x_rx_identity_reg struct (Torez Smith) [1942772]
- usb-storage: Add quirk to defeat Kindle's automatic unload (Torez Smith) [1942772]
- usbip: Fix incorrect double assignment to udc->ud.tcp_rx (Torez Smith) [1942772]
- can: kvaser_usb: Add support for USBcan Pro 4xHS (Torez Smith) [1942772]
- can: peak_usb: add forgotten supported devices (Torez Smith) [1942772]
- xhci: Fix repeated xhci wake after suspend due to uncleared internal wake state (Torez Smith) [1942772]
- usb: xhci: Fix ASMedia ASM1042A and ASM3242 DMA addressing (Torez Smith) [1942772]
- xhci: Improve detection of device initiated wake signal. (Torez Smith) [1942772]
- usb: xhci: do not perform Soft Retry for some xHCI hosts (Torez Smith) [1942772]
- usbip: fix vudc usbip_sockfd_store races leading to gpf (Torez Smith) [1942772]
- usbip: fix vhci_hcd attach_store() races leading to gpf (Torez Smith) [1942772]
- usbip: fix stub_dev usbip_sockfd_store() races leading to gpf (Torez Smith) [1942772]
- usbip: fix vudc to check for stream socket (Torez Smith) [1942772]
- usbip: fix vhci_hcd to check for stream socket (Torez Smith) [1942772]
- usbip: fix stub_dev to check for stream socket (Torez Smith) [1942772]
- USB: usblp: fix a hang in poll() if disconnected (Torez Smith) [1942772]
- usb: dwc3: qcom: Add missing DWC3 OF node refcount decrement (Torez Smith) [1942772]
- usb: dwc3: qcom: Honor wakeup enabled/disabled state (Torez Smith) [1942772]
- usb: dwc3: qcom: add ACPI device id for sc8180x (Torez Smith) [1942772]
- Goodix Fingerprint device is not a modem (Torez Smith) [1942772]
- USB: serial: io_edgeport: fix memory leak in edge_startup (Torez Smith) [1942772]
- USB: serial: ch341: add new Product ID (Torez Smith) [1942772]
- USB: serial: cp210x: add some more GE USB IDs (Torez Smith) [1942772]
- USB: serial: cp210x: add ID for Acuity Brands nLight Air Adapter (Torez Smith) [1942772]
- net: usb: log errors to dmesg/syslog (Torez Smith) [1942772]
- net: usb: cdc_ncm: emit dev_err on error paths (Torez Smith) [1942772]
- thunderbolt: Increase runtime PM reference count on DP tunnel discovery (Torez Smith) [1942772]
- thunderbolt: Initialize HopID IDAs in tb_switch_alloc() (Torez Smith) [1942772]
- net: usb: qmi_wwan: allow qmimux add/del with master up (Torez Smith) [1942772]
- Revert "r8152: adjust the settings about MAC clock speed down for RTL8153" (Torez Smith) [1942772]
- net: usb: qmi_wwan: support ZTE P685M modem (Torez Smith) [1942772]
- r8152: spilt rtl_set_eee_plus and r8153b_green_en (Torez Smith) [1942772]
- r8152: replace netif_err with dev_err (Torez Smith) [1942772]
- r8152: check if the pointer of the function exists (Torez Smith) [1942772]
- r8152: enable U1/U2 for USB_SPEED_SUPER (Torez Smith) [1942772]
- usb: misc: usb3503: Fix logic in usb3503_init() (Torez Smith) [1942772]
- usb: Replace lkml.org links with lore (Torez Smith) [1942772]
- usb: quirks: add quirk to start video capture on ELMO L-12F document camera reliable (Torez Smith) [1942772]
- USB: quirks: sort quirk entries (Torez Smith) [1942772]
- USB: serial: drop bogus to_usb_serial_port() checks (Torez Smith) [1942772]
- USB: serial: drop if with an always false condition (Torez Smith) [1942772]
- usb: typec: tcpm: Get Sink VDO from fwnode (Torez Smith) [1942772]
- dt-bindings: connector: Add SVDM VDO properties (Torez Smith) [1942772]
- usb: typec: displayport: Fill the negotiated SVDM Version in the header (Torez Smith) [1942772]
- usb: typec: ucsi: Determine common SVDM Version (Torez Smith) [1942772]
- usb: typec: tcpm: Determine common SVDM Version (Torez Smith) [1942772]
- usb: pd: Make SVDM Version configurable in VDM header (Torez Smith) [1942772]
- usb: typec: Manage SVDM version (Torez Smith) [1942772]
- usb: dwc3: gadget: Fix dep->interval for fullspeed interrupt (Torez Smith) [1942772]
- usb: dwc3: gadget: Fix setting of DEPCFG.bInterval_m1 (Torez Smith) [1942772]
- USB: serial: option: update interface mapping for ZTE P685M (Torez Smith) [1942772]
- usb: dwc3: gadget: Track connected SSP rate and lane count (Torez Smith) [1942772]
- usb: dwc3: gadget: Implement setting of SSP rate (Torez Smith) [1942772]
- usb: dwc3: core: Check maximum_speed SSP genXxY (Torez Smith) [1942772]
- usb: common: Parse for USB SSP genXxY (Torez Smith) [1942772]
- usb: dwc2: Fix endpoint direction check in ep_from_windex (Torez Smith) [1942772]
- usb: dwc3: fix clock issue during resume in OTG mode (Torez Smith) [1942772]
- xhci: ext-caps: Use software node API with the properties (Torez Smith) [1942772]
- usb: dwc3: host: Use software node API with the properties (Torez Smith) [1942772]
- r8152: replace several functions about phy patch request (Torez Smith) [1942772]
- usb: dwc3: qcom: Constify the software node (Torez Smith) [1942772]
- usb: dwc3: haps: Constify the software node (Torez Smith) [1942772]
- usb: dwc2: pci: Drop the empty quirk function (Torez Smith) [1942772]
- thunderbolt: Add support for native USB4 _OSC (Torez Smith) [1942772]
- thunderbolt: Allow disabling XDomain protocol (Torez Smith) [1942772]
- thunderbolt: Add support for PCIe tunneling disabled (SL5) (Torez Smith) [1942772]
- thunderbolt: dma_test: Drop unnecessary include (Torez Smith) [1942772]
- thunderbolt: Add clarifying comments about USB4 terms router and adapter (Torez Smith) [1942772]
- thunderbolt: switch: Fix kernel-doc descriptions of non-static functions (Torez Smith) [1942772]
- thunderbolt: nhi: Fix kernel-doc descriptions of non-static functions (Torez Smith) [1942772]
- thunderbolt: path: Fix kernel-doc descriptions of non-static functions (Torez Smith) [1942772]
- thunderbolt: eeprom: Fix kernel-doc descriptions of non-static functions (Torez Smith) [1942772]
- thunderbolt: ctl: Fix kernel-doc descriptions of non-static functions (Torez Smith) [1942772]
- usb: pd: Reland VDO definitions of PD2.0 (Torez Smith) [1942772]
- NET: usb: qmi_wwan: Adding support for Cinterion MV31 (Torez Smith) [1942772]
- usb: pd: Update VDO definitions (Torez Smith) [1942772]
- xhci: fix bounce buffer usage for non-sg list case (Torez Smith) [1942772]
- usb: xhci-mtk: break loop when find the endpoint to drop (Torez Smith) [1942772]
- usb: typec: Return void in typec_partner_set_pd_revision (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Enable data path when partner is USB Comm capable (Torez Smith) [1942772]
- usb: typec: tcpci: Add Callback to Usb Communication capable partner (Torez Smith) [1942772]
- usb: typec: tcpm: Add Callback to Usb Communication capable partner (Torez Smith) [1942772]
- usb: typec: tcpm: Set in_ams flag when Source caps have been received (Torez Smith) [1942772]
- usb: typec: tcpm: Handle vbus shutoff when in source mode (Torez Smith) [1942772]
- usb: typec: Add typec_partner_set_pd_revision (Torez Smith) [1942772]
- usb: typec: Provide PD Specification Revision for cable and partner (Torez Smith) [1942772]
- usb: typec: Standardize PD Revision format with Type-C Revision (Torez Smith) [1942772]
- usb: xhci-mtk: skip dropping bandwidth of unchecked endpoints (Torez Smith) [1942772]
- USB: serial: ftdi_sio: restore divisor-encoding comments (Torez Smith) [1942772]
- USB: serial: ftdi_sio: fix FTX sub-integer prescaler (Torez Smith) [1942772]
- USB: serial: cp210x: clean up auto-RTS handling (Torez Smith) [1942772]
- USB: serial: cp210x: fix RTS handling (Torez Smith) [1942772]
- USB: serial: cp210x: clean up printk zero padding (Torez Smith) [1942772]
- USB: serial: cp210x: clean up flow-control debug message (Torez Smith) [1942772]
- USB: serial: cp210x: drop shift macros (Torez Smith) [1942772]
- USB: serial: cp210x: fix modem-control handling (Torez Smith) [1942772]
- USB: serial: cp210x: suppress modem-control errors (Torez Smith) [1942772]
- xhci: handle halting transfer event properly after endpoint stop and halt raced. (Torez Smith) [1942772]
- xhci: Check for pending reset endpoint command before queueing a new one. (Torez Smith) [1942772]
- xhci: remove obsolete dequeue pointer moving code (Torez Smith) [1942772]
- xhci: introduce a new move_dequeue_past_td() function to replace old code. (Torez Smith) [1942772]
- xhci: handle stop endpoint command completion with endpoint in running state. (Torez Smith) [1942772]
- xhci: Fix halted endpoint at stop endpoint command completion (Torez Smith) [1942772]
- xhci: split handling halted endpoints into two steps (Torez Smith) [1942772]
- xhci: move and rename xhci_cleanup_halted_endpoint() (Torez Smith) [1942772]
- xhci: turn cancelled td cleanup to its own function (Torez Smith) [1942772]
- xhci: store TD status in the td struct instead of passing it along (Torez Smith) [1942772]
- xhci: use xhci_td_cleanup() helper when giving back cancelled URBs (Torez Smith) [1942772]
- xhci: move xhci_td_cleanup so it can be called by more functions (Torez Smith) [1942772]
- xhci: Add xhci_reset_halted_ep() helper function (Torez Smith) [1942772]
- xhci: flush endpoint start to reduce race risk with stop endpoint command. (Torez Smith) [1942772]
- xhci: Check link TRBs when updating ring enqueue and dequeue pointers. (Torez Smith) [1942772]
- xhci: avoid DMA double fetch when reading event trb type. (Torez Smith) [1942772]
- xhci: remove extra loop in interrupt context (Torez Smith) [1942772]
- xhci: check slot_id is valid before gathering slot info (Torez Smith) [1942772]
- xhci: prevent a theoretical endless loop while preparing rings. (Torez Smith) [1942772]
- xhci: remove xhci_stream_id_to_ring() helper (Torez Smith) [1942772]
- xhci: add xhci_virt_ep_to_ring() helper (Torez Smith) [1942772]
- xhci: check virt_dev is valid before dereferencing it (Torez Smith) [1942772]
- xhci: add xhci_get_virt_ep() helper (Torez Smith) [1942772]
- xhci: remove unused event parameter from completion handlers (Torez Smith) [1942772]
- xhci: adjust parameters passed to cleanup_halted_endpoint() (Torez Smith) [1942772]
- xhci: get isochronous ring directly from endpoint structure (Torez Smith) [1942772]
- xhci: Avoid parsing transfer events several times (Torez Smith) [1942772]
- net: qmi_wwan: Add pass through mode (Torez Smith) [1942772]
- net: usb: qmi_wwan: add qmap id sysfs file for qmimux interfaces (Torez Smith) [1942772]
- net: usb: cdc_ether: added support for Thales Cinterion PLSx3 modem family. (Torez Smith) [1942772]
- thunderbolt: Fix possible NULL pointer dereference in tb_acpi_add_link() (Torez Smith) [1942772]
- thunderbolt: switch: Fix function name in the header (Torez Smith) [1942772]
- thunderbolt: tunnel: Fix misspelling of 'receive_path' (Torez Smith) [1942772]
- thunderbolt: icm: Fix a couple of formatting issues (Torez Smith) [1942772]
- thunderbolt: switch: Demote a bunch of non-conformant kernel-doc headers (Torez Smith) [1942772]
- thunderbolt: tb: Kernel-doc function headers should document their parameters (Torez Smith) [1942772]
- thunderbolt: nhi: Demote some non-conformant kernel-doc headers (Torez Smith) [1942772]
- thunderbolt: xdomain: Fix 'tb_unregister_service_driver()'s 'drv' param (Torez Smith) [1942772]
- thunderbolt: eeprom: Demote non-conformant kernel-doc headers to standard comment blocks (Torez Smith) [1942772]
- USB: serial: mos7720: fix error code in mos7720_write() (Torez Smith) [1942772]
- thunderbolt: ctl: Demote non-conformant kernel-doc headers (Torez Smith) [1942772]
- thunderbolt: cap: Fix kernel-doc formatting issue (Torez Smith) [1942772]
- thunderbolt: dma_port: Check 'dma_port_flash_write_block()'s return value (Torez Smith) [1942772]
- USB: serial: option: Adding support for Cinterion MV31 (Torez Smith) [1942772]
- can: mcba_usb: remove h from printk format specifier (Torez Smith) [1942772]
- usbnet: fix the indentation of one code snippet (Torez Smith) [1942772]
- usb: usb251xb: Use of_device_get_match_data() (Torez Smith) [1942772]
- usb: dwc2: Make "trimming xfer length" a debug message (Torez Smith) [1942772]
- usb: dwc2: Abort transaction after errors with unknown reason (Torez Smith) [1942772]
- usb: dwc2: Do not update data length if it is 0 on inbound transfers (Torez Smith) [1942772]
- usb: xhci-mtk: fix unreleased bandwidth data (Torez Smith) [1942772]
- USB: serial: mos7840: fix error code in mos7840_write() (Torez Smith) [1942772]
- USB: usblp: don't call usb_set_interface if there's a single alt (Torez Smith) [1942772]
- USB: serial: cp210x: add pid/vid for WSDA-200-USB (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: add terminating newlines to logging (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: remove redundant assignment (Torez Smith) [1942772]
- usb: typec: tcpm: Create legacy PDOs for PD2 connection (Torez Smith) [1942772]
- net: usb: qmi_wwan: added support for Thales Cinterion PLSx3 modem family (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Drop GPIO includes (Torez Smith) [1942772]
- usb: typec: tcpm: Respond Wait if VDM state machine is running (Torez Smith) [1942772]
- usb: typec: tcpm: Protocol Error handling (Torez Smith) [1942772]
- usb: typec: tcpm: AMS and Collision Avoidance (Torez Smith) [1942772]
- net: usb: cdc_ncm: don't spew notifications (Torez Smith) [1942772]
- usb: typec: ucsi: Add conditional dependency on USB role switch (Torez Smith) [1942772]
- usb: ch9: Add USB 3.2 SSP attributes (Torez Smith) [1942772]
- USB: serial: f81232: drop short control-transfer checks (Torez Smith) [1942772]
- USB: serial: io_ti: fix a debug-message copy-paste error (Torez Smith) [1942772]
- USB: serial: io_ti: drop short control-transfer check (Torez Smith) [1942772]
- USB: serial: upd78f0730: drop short control-transfer check (Torez Smith) [1942772]
- USB: serial: cp210x: add copyright notice (Torez Smith) [1942772]
- USB: serial: cp210x: drop unused includes (Torez Smith) [1942772]
- USB: serial: cp210x: drop short control-transfer checks (Torez Smith) [1942772]
- USB: serial: cp210x: update control-characters on every change (Torez Smith) [1942772]
- USB: serial: cp210x: set IXOFF thresholds (Torez Smith) [1942772]
- USB: serial: cp210x: add support for software flow control (Torez Smith) [1942772]
- USB: serial: pl2303: fix line-speed handling on newer chips (Torez Smith) [1942772]
- xhci: tegra: Delay for disabling LFPS detector (Torez Smith) [1942772]
- xhci: make sure TRB is fully written before giving it to the controller (Torez Smith) [1942772]
- usb: dwc3: qcom: add URS Host support for sdm845 ACPI boot (Torez Smith) [1942772]
- usb: dwc3: pci: add support for the Intel Alder Lake-P (Torez Smith) [1942772]
- usb: dwc3: pci: ID for Tiger Lake CPU (Torez Smith) [1942772]
- usb: dwc3: pci: Register a software node for the dwc3 platform device (Torez Smith) [1942772]
- thunderbolt: Add support for de-authorizing devices (Torez Smith) [1942772]
- nt: usb: USB_RTL8153_ECM should not default to y (Torez Smith) [1942772]
- USB: dwc3: document gadget_max_speed (Torez Smith) [1942772]
- usb: dwc3: gadget: Disable Vendor Test LMP Received event (Torez Smith) [1942772]
- USB: serial: cp210x: add new VID/PID for supporting Teraoka AD2000 (Torez Smith) [1942772]
- r8153_ecm: Add Lenovo Powered USB-C Hub as a fallback of r8152 (Torez Smith) [1942772]
- r8152: Add Lenovo Powered USB-C Travel Hub (Torez Smith) [1942772]
- USB: ehci: fix an interrupt calltrace error (Torez Smith) [1942772]
- ehci: fix EHCI host controller initialization sequence (Torez Smith) [1942772]
- usb: typec: ucsi: Add support for USB role switch (Torez Smith) [1942772]
- usb: dwc2: disable Link Power Management on STM32MP15 HS OTG (Torez Smith) [1942772]
- usb: dwc2: enable FS/LS PHY clock select on STM32MP15 FS OTG (Torez Smith) [1942772]
- usb: dwc2: set ahbcfg parameter for STM32MP15 OTG HS and FS (Torez Smith) [1942772]
- usb: dwc3: Simplify with dev_err_probe() (Torez Smith) [1942772]
- usb: dwc3: keystone: Simplify with dev_err_probe() (Torez Smith) [1942772]
- usb: dwc3: core: Replace devm_reset_control_array_get() (Torez Smith) [1942772]
- USB: serial: mos7720: improve OOM-handling in read_mos_reg() (Torez Smith) [1942772]
- rndis_host: set proper input size for OID_GEN_PHYSICAL_MEDIUM request (Torez Smith) [1942772]
- thunderbolt: Start lane initialization after sleep (Torez Smith) [1942772]
- thunderbolt: Constify static attribute_group structs (Torez Smith) [1942772]
- qmi_wwan: Increase headroom for QMAP SKBs (Torez Smith) [1942772]
- usb: usbip: Use DEFINE_SPINLOCK() for spinlock (Torez Smith) [1942772]
- usb: dwc3: gadget: Clear wait flag on dequeue (Torez Smith) [1942772]
- usb: typec: Send uevent for num_altmodes update (Torez Smith) [1942772]
- usb: typec: Fix copy paste error for NVIDIA alt-mode description (Torez Smith) [1942772]
- kcov, usb: hide in_serving_softirq checks in __usb_hcd_giveback_urb (Torez Smith) [1942772]
- thunderbolt: Drop duplicated 0x prefix from format string (Torez Smith) [1942772]
- net: cdc_ncm: correct overhead in delayed_ndp_size (Torez Smith) [1942772]
- net: usb: Use DEFINE_SPINLOCK() for spinlock (Torez Smith) [1942772]
- usb: uas: Add PNY USB Portable SSD to unusual_uas (Torez Smith) [1942772]
- net: usb: qmi_wwan: add Quectel EM160R-GL (Torez Smith) [1942772]
- usb: usbip: vhci_hcd: protect shift size (Torez Smith) [1942772]
- USB: usblp: fix DMA to stack (Torez Smith) [1942772]
- usb: dwc3: gadget: Preserve UDC max speed setting (Torez Smith) [1942772]
- usb: dwc3: gadget: Allow runtime suspend if UDC unbinded (Torez Smith) [1942772]
- usb: dwc3: gadget: Introduce a DWC3 VBUS draw callback (Torez Smith) [1942772]
- usb: dwc3: add imx8mp dwc3 glue layer driver (Torez Smith) [1942772]
- USB: serial: iuu_phoenix: fix DMA from stack (Torez Smith) [1942772]
- USB: serial: option: add LongSung M5710 module support (Torez Smith) [1942772]
- USB: serial: option: add Quectel EM160R-GL (Torez Smith) [1942772]
- CDC-NCM: remove "connected" log message (Torez Smith) [1942772]
- usb: dwc3: ulpi: Fix USB2.0 HS/FS/LS PHY suspend regression (Torez Smith) [1942772]
- usb: dwc3: ulpi: Replace CPU-based busyloop with Protocol-based one (Torez Smith) [1942772]
- usb: dwc3: ulpi: Use VStsDone to detect PHY regs access completion (Torez Smith) [1942772]
- usb: dwc3: drd: Improve dwc3_get_extcon() style (Torez Smith) [1942772]
- usb: dwc3: drd: Avoid error when extcon is missing (Torez Smith) [1942772]
- USB: usbtmc: Bump USBTMC_API_VERSION value (Torez Smith) [1942772]
- USB: usbtmc: Add separate USBTMC_IOCTL_GET_SRQ_STB (Torez Smith) [1942772]
- USB: usbtmc: Add USBTMC_IOCTL_GET_STB (Torez Smith) [1942772]
- USB: usbtmc: Fix reading stale status byte (Torez Smith) [1942772]
- kcov, usbip: collect coverage from vhci_rx_loop (Torez Smith) [1942772]
- USB: yurex: fix control-URB timeout handling (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: disable clk on error handling path in probe (Torez Smith) [1942772]
- USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST quirk set (Torez Smith) [1942772]
- usb: typec: intel_pmc_mux: Configure HPD first for HPD+IRQ request (Torez Smith) [1942772]
- USB: cdc-wdm: Fix use after free in service_outstanding_interrupt(). (Torez Smith) [1942772]
- USB: cdc-acm: blacklist another IR Droid device (Torez Smith) [1942772]
- thunderbolt: Use kmemdup instead of kzalloc and memcpy (Torez Smith) [1942772]
- usb: ucsi: convert comma to semicolon (Torez Smith) [1942772]
- usb: typec: tcpm: convert comma to semicolon (Torez Smith) [1942772]
- usb: typec: tcpm: Update vbus_vsafe0v on init (Torez Smith) [1942772]
- usb: typec: tcpci: Enable bleed discharge when auto discharge is enabled (Torez Smith) [1942772]
- usb: typec: Add class for plug alt mode device (Torez Smith) [1942772]
- USB: typec: tcpci: Add Bleed discharge to POWER_CONTROL definition (Torez Smith) [1942772]
- USB: typec: tcpm: Add a 30ms room for tPSSourceOn in PR_SWAP (Torez Smith) [1942772]
- USB: typec: tcpm: Fix PR_SWAP error handling (Torez Smith) [1942772]
- USB: typec: tcpm: Hard Reset after not receiving a Request (Torez Smith) [1942772]
- usb: typec: intel_pmc_mux: Configure cable generation value for USB4 (Torez Smith) [1942772]
- net: usb: convert comma to semicolon (Torez Smith) [1942772]
- USB: UAS: introduce a quirk to set no_write_same (Torez Smith) [1942772]
- USB: serial: ftdi_sio: log the CBUS GPIO validity (Torez Smith) [1942772]
- USB: serial: ftdi_sio: drop GPIO line checking dead code (Torez Smith) [1942772]
- USB: serial: ftdi_sio: report the valid GPIO lines to gpiolib (Torez Smith) [1942772]
- drivers: usb: atm: use atm_info() instead of atm_printk(KERN_INFO ... (Torez Smith) [1942772]
- drivers: usb: atm: reduce noise (Torez Smith) [1942772]
- USB: serial: option: add interface-number sanity check to flag handling (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Enable VSAFE0V signalling (Torez Smith) [1942772]
- usb: typec: tcpci: Add support to report vSafe0V (Torez Smith) [1942772]
- usb: typec: tcpm: Introduce vsafe0v for vbus (Torez Smith) [1942772]
- usb: typec: tcpm: Clear send_discover in tcpm_check_send_discover (Torez Smith) [1942772]
- usb: typec: tcpm: Pass down negotiated rev to update retry count (Torez Smith) [1942772]
- usb: typec: intel_pmc_mux: Use correct response message bits (Torez Smith) [1942772]
- xhci: Give USB2 ports time to enter U3 in bus suspend (Torez Smith) [1942772]
- xhci-pci: Allow host runtime PM as default for Intel Maple Ridge xHCI (Torez Smith) [1942772]
- xhci-pci: Allow host runtime PM as default for Intel Alpine Ridge LP (Torez Smith) [1942772]
- usb: xhci: Use temporary buffer to consolidate SG (Torez Smith) [1942772]
- usb: xhci: Set quirk for XHCI_SG_TRB_CACHE_SIZE_QUIRK (Torez Smith) [1942772]
- USB: legotower: fix logical error in recent commit (Torez Smith) [1942772]
- USB: legousbtower: use usb_control_msg_recv() (Torez Smith) [1942772]
- USB: add RESET_RESUME quirk for Snapscan 1212 (Torez Smith) [1942772]
- usb: typec: tps6598x: Export some power supply properties (Torez Smith) [1942772]
- usb: typec: tps6598x: Select USB_ROLE_SWITCH and REGMAP_I2C (Torez Smith) [1942772]
- USB: core: drop pipe-type check from new control-message helpers (Torez Smith) [1942772]
- USB: core: return -EREMOTEIO on short usb_control_msg_recv() (Torez Smith) [1942772]
- USB: core: drop short-transfer check from usb_control_msg_send() (Torez Smith) [1942772]
- USB: apple-mfi-fastcharge: Fix use after free in probe (Torez Smith) [1942772]
- Revert "usb-storage: fix sdev->host->dma_dev" (Torez Smith) [1942772]
- Revert "uas: fix sdev->host->dma_dev" (Torez Smith) [1942772]
- Revert "uas: bump hw_max_sectors to 2048 blocks for SS or faster drives" (Torez Smith) [1942772]
- USB: serial: cp210x: clean up dtr_rts() (Torez Smith) [1942772]
- USB: serial: cp210x: refactor flow-control handling (Torez Smith) [1942772]
- USB: serial: cp210x: drop flow-control debugging (Torez Smith) [1942772]
- USB: serial: cp210x: set terminal settings on open (Torez Smith) [1942772]
- USB: serial: cp210x: clean up line-control handling (Torez Smith) [1942772]
- USB: serial: cp210x: return early on unchanged termios (Torez Smith) [1942772]
- USB: serial: kl5kusb105: fix memleak on open (Torez Smith) [1942772]
- USB: serial: ch341: sort device-id entries (Torez Smith) [1942772]
- USB: serial: ch341: add new Product ID for CH341A (Torez Smith) [1942772]
- USB: serial: option: fix Quectel BG96 matching (Torez Smith) [1942772]
- can: pcan_usb_core: fix fall-through warnings for Clang (Torez Smith) [1942772]
- usb: typec: stusb160x: fix power-opmode property with typec-power-opmode (Torez Smith) [1942772]
- USB: serial: option: add support for Thales Cinterion EXS82 (Torez Smith) [1942772]
- usb: typec: Add type sysfs attribute file for partners (Torez Smith) [1942772]
- usb: common: ulpi: Constify static attribute_group struct (Torez Smith) [1942772]
- usb: typec: Constify static attribute_group structs (Torez Smith) [1942772]
- USB: core: Constify static attribute_group structs (Torez Smith) [1942772]
- usb: typec: tcpm: Stay in SNK_TRY_WAIT_DEBOUNCE_CHECK_VBUS till Rp is seen (Torez Smith) [1942772]
- usb: typec: tcpm: Disregard vbus off while in PR_SWAP_SNK_SRC_SOURCE_ON (Torez Smith) [1942772]
- usb: typec: Expose Product Type VDOs via sysfs (Torez Smith) [1942772]
- usb: pd: DFP product types (Torez Smith) [1942772]
- usb: Fix fall-through warnings for Clang (Torez Smith) [1942772]
- usbnet: ipheth: fix connectivity with iOS 14 (Torez Smith) [1942772]
- USB: core: Change pK for __user pointers to px (Torez Smith) [1942772]
- USB: core: Fix regression in Hercules audio card (Torez Smith) [1942772]
- USB: quirks: Add USB_QUIRK_DISCONNECT_SUSPEND quirk for Lenovo A630Z TIO built-in usb-audio card (Torez Smith) [1942772]
- can: kvaser_usb: Add new Kvaser hydra devices (Torez Smith) [1942772]
- can: kvaser_usb: kvaser_usb_hydra: Add support for new device variant (Torez Smith) [1942772]
- can: kvaser_usb: Add new Kvaser Leaf v2 devices (Torez Smith) [1942772]
- can: kvaser_usb: Add USB_{LEAF,HYDRA}_PRODUCT_ID_END defines (Torez Smith) [1942772]
- USB: serial: option: add Fibocom NL668 variants (Torez Smith) [1942772]
- usb: typec: Fix num_altmodes kernel-doc error (Torez Smith) [1942772]
- r8153_ecm: avoid to be prior to r8152 driver (Torez Smith) [1942772]
- net: usb: qmi_wwan: Set DTR quirk for MR400 (Torez Smith) [1942772]
- usb: typec: Add plug num_altmodes sysfs attr (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Fix the compatible string (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Fix uninitialized return variable (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Enable auto discharge disconnect (Torez Smith) [1942772]
- usb: typec: tcpci: Implement Auto discharge disconnect callbacks (Torez Smith) [1942772]
- usb: typec: tcpm: Implement enabling Auto Discharge disconnect support (Torez Smith) [1942772]
- usb: typec: tcpci_maxim: Fix vbus stuck on upon diconnecting sink (Torez Smith) [1942772]
- usb: typec: tcpci: frs sourcing vbus callback (Torez Smith) [1942772]
- usb: typec: tcpm: frs sourcing vbus callback (Torez Smith) [1942772]
- usb: typec: tcpm: Refactor logic for new-source-frs-typec-current (Torez Smith) [1942772]
- usb: typec: Add number of altmodes partner attr (Torez Smith) [1942772]
- usb: pd: Add captive Type C cable type (Torez Smith) [1942772]
- USB: apple-mfi-fastcharge: Fix kfree after failed kzalloc (Torez Smith) [1942772]
- usb: typec: Remove one bit support for the Thunderbolt rounded/non-rounded cable (Torez Smith) [1942772]
- usb: typec: intel_pmc_mux: Configure Thunderbolt cable generation bits (Torez Smith) [1942772]
- usb: typec: Correct the bit values for the Thunderbolt rounded/non-rounded cable support (Torez Smith) [1942772]
- can: kvaser_usb: kvaser_usb_hydra: Fix KCAN bittiming limits (Torez Smith) [1942772]
- cx82310_eth: fix error return code in cx82310_bind() (Torez Smith) [1942772]
- usb: typec: qcom-pmic-typec: fix builtin build errors (Torez Smith) [1942772]
- can: peak_usb: fix potential integer overflow on shift of a int (Torez Smith) [1942772]
- can: mcba_usb: mcba_usb_start_xmit(): first fill skb, then pass to can_put_echo_skb() (Torez Smith) [1942772]
- usb: hcd.h: Remove RUN_CONTEXT (Torez Smith) [1942772]
- USB: storage: avoid use of uninitialized values in error path (Torez Smith) [1942772]
- usb: fix a few cases of -Wfallthrough (Torez Smith) [1942772]
- usbnet: switch to core handling of rx/tx byte/packet counters (Torez Smith) [1942772]
- qmi_wwan: switch to core handling of rx/tx byte/packet counters (Torez Smith) [1942772]
- net: usb: fix spelling typo in cdc_ncm.c (Torez Smith) [1942772]
- usb: typec: ucsi: Work around PPM losing change information (Torez Smith) [1942772]
- usb: typec: ucsi: acpi: Always decode connector change information (Torez Smith) [1942772]
- net/usb/r8153_ecm: support ECM mode for RTL8153 (Torez Smith) [1942772]
- USB: serial: mos7720: fix parallel-port state restore (Torez Smith) [1942772]
- USB: serial: remove write wait queue (Torez Smith) [1942772]
- USB: serial: digi_acceleport: fix write-wakeup deadlocks (Torez Smith) [1942772]
- USB: serial: keyspan_pda: drop redundant usb-serial pointer (Torez Smith) [1942772]
- USB: serial: keyspan_pda: use BIT() macro (Torez Smith) [1942772]
- USB: serial: keyspan_pda: add write-fifo support (Torez Smith) [1942772]
- USB: serial: keyspan_pda: increase transmitter threshold (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix write implementation (Torez Smith) [1942772]
- USB: serial: keyspan_pda: refactor write-room handling (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix write unthrottling (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix tx-unthrottle use-after-free (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix write-wakeup use-after-free (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix stalled writes (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix write deadlock (Torez Smith) [1942772]
- USB: serial: keyspan_pda: fix dropped unthrottle interrupts (Torez Smith) [1942772]
- net: usb: r8152: Fix a couple of spelling errors in fw_phy_nc's docs (Torez Smith) [1942772]
- net: usb: lan78xx: Remove lots of set but unused 'ret' variables (Torez Smith) [1942772]
- net: usb: r8152: Provide missing documentation for some struct members (Torez Smith) [1942772]
- can: peak_usb: peak_usb_get_ts_time(): fix timestamp wrapping (Torez Smith) [1942772]
- can: peak_usb: add range checking in decode operations (Torez Smith) [1942772]
- net: usb: qmi_wwan: add Telit LE910Cx 0x1230 composition (Torez Smith) [1942772]
- kcov, usb: only collect coverage from __usb_hcd_giveback_urb in softirq (Torez Smith) [1942772]
- dt-bindings: connector: Add property to set initial current cap for FRS (Torez Smith) [1942772]
- usb: xhci: Remove in_interrupt() checks (Torez Smith) [1942772]
- usbip: Remove in_interrupt() check (Torez Smith) [1942772]
- usb: core: Replace in_interrupt() in comments (Torez Smith) [1942772]
- usb: atm: Replace in_interrupt() usage in comment (Torez Smith) [1942772]
- USB: sisusbvga: Make console support depend on BROKEN (Torez Smith) [1942772]
- usb: host: xhci-mem: remove unneeded break (Torez Smith) [1942772]
- usb: storage: freecom: remove unneeded break (Torez Smith) [1942772]
- usb: misc: iowarrior: remove unneeded break (Torez Smith) [1942772]
- usb: host: ehci-sched: add comment about find_tt() not returning error (Torez Smith) [1942772]
- usb: dwc3: ep0: Fix delay status handling (Torez Smith) [1942772]
- USB: serial: iuu_phoenix: remove unneeded break (Torez Smith) [1942772]
- USB: serial: digi_acceleport: remove in_interrupt() usage (Torez Smith) [1942772]
- usb: dwc3: pci: add support for the Intel Alder Lake-S (Torez Smith) [1942772]
- net: usb: rtl8150: don't incorrectly assign random MAC addresses (Torez Smith) [1942772]
- net: usbnet: use new function dev_fetch_sw_netstats (Torez Smith) [1942772]
- net: usb: qmi_wwan: use new function dev_fetch_sw_netstats (Torez Smith) [1942772]
- cx82310_eth: use netdev_err instead of dev_err (Torez Smith) [1942772]
- cx82310_eth: re-enable ethernet mode after router reboot (Torez Smith) [1942772]
- net: usbnet: remove driver version (Torez Smith) [1942772]
- net: usb: qmi_wwan: add Cellient MPL200 card (Torez Smith) [1942772]
- usbip: vhci_hcd: fix calling usb_hcd_giveback_urb() with irqs enabled (Torez Smith) [1942772]
- net: usb: rtl8150: set random MAC address when set_ethernet_addr() fails (Torez Smith) [1942772]
- usbnet: Use fallthrough pseudo-keyword (Torez Smith) [1942772]
- net/smscx5xx: change to of_get_mac_address() eth_platform_get_mac_address() (Torez Smith) [1942772]
- net: usb: pegasus: Proper error handing when setting pegasus' MAC address (Torez Smith) [1942772]
- usb: dwc3: gadget: Support up to max stream id (Torez Smith) [1942772]
- usb: dwc2: Fix INTR OUT transfers in DDMA mode. (Torez Smith) [1942772]
- usb: dwc3: of-simple: Add compatible string for Intel Keem Bay platform (Torez Smith) [1942772]
- net: rtl8150: Use the new usb control message API. (Torez Smith) [1942772]
- net: pegasus: Use the new usb control message API. (Torez Smith) [1942772]
- usb: dwc3: gadget: Return early if no TRB update (Torez Smith) [1942772]
- usb: dwc3: gadget: Keep TRBs in request order (Torez Smith) [1942772]
- usb: dwc3: gadget: Revise setting IOC when no TRB left (Torez Smith) [1942772]
- usb: dwc3: gadget: Look ahead when setting IOC (Torez Smith) [1942772]
- usb: dwc3: gadget: Allow restarting a transfer (Torez Smith) [1942772]
- usb: dwc3: Stop active transfers before halting the controller (Torez Smith) [1942772]
- usb: dwc3: gadget: Rename misleading function names (Torez Smith) [1942772]
- usb: dwc3: Add splitdisable quirk for Hisilicon Kirin Soc (Torez Smith) [1942772]
- usb: dwc3: gadget: Refactor preparing last TRBs (Torez Smith) [1942772]
- usb: dwc3: gadget: Set IOC if not enough for extra TRBs (Torez Smith) [1942772]
- usb: dwc3: gadget: Check for number of TRBs prepared (Torez Smith) [1942772]
- usb: dwc3: gadget: Return the number of prepared TRBs (Torez Smith) [1942772]
- usb: dwc3: ep0: Fix ZLP for OUT ep0 requests (Torez Smith) [1942772]
- usb: dwc3: gadget: Improve TRB ZLP setup (Torez Smith) [1942772]
- usb: dwc3: gadget: Refactor preparing extra TRB (Torez Smith) [1942772]
- usb: dwc3: gadget: Reclaim extra TRBs after request completion (Torez Smith) [1942772]
- usb: dwc3: gadget: Check MPS of the request length (Torez Smith) [1942772]
- usb: dwc3: gadget: Refactor ep command completion (Torez Smith) [1942772]
- usb: dwc3: allocate gadget structure dynamically (Torez Smith) [1942772]
- usb: dwc3: core: add phy cleanup for probe error handling (Torez Smith) [1942772]
- usb: dwc3: core: don't trigger runtime pm when remove driver (Torez Smith) [1942772]
- usb: dwc3: debugfs: do not queue work if try to change mode on non-drd (Torez Smith) [1942772]
- usb: dwc3: pci: Allow Elkhart Lake to utilize DSM method for PM functionality (Torez Smith) [1942772]
- usb: dwc2: add support for APM82181 USB OTG (Torez Smith) [1942772]
- usb: dwc-meson-g12a: Add support for USB on AXG SoCs (Torez Smith) [1942772]
- usb: dwc3: gadget: fix checkpatch warnings (Torez Smith) [1942772]
- usb: dwc3: core: do not queue work if dr_mode is not USB_DR_MODE_OTG (Torez Smith) [1942772]
- usb: dwc3: debugfs: fix checkpatch warnings (Torez Smith) [1942772]
- usb: dwc3: qcom: fix checkpatch warnings (Torez Smith) [1942772]
- usb: dwc3: ep0: fix checkpatch warnings (Torez Smith) [1942772]
- usb: dwc3: core: fix checkpatch warnings (Torez Smith) [1942772]
- usb: dwc3: debug: fix checkpatch warning (Torez Smith) [1942772]
- usb: dwc3: trace: fix checkpatch warnings (Torez Smith) [1942772]
- usb: dwc3: ulpi: fix checkpatch warning (Torez Smith) [1942772]
- usb: dwc3: meson: fix checkpatch errors and warnings (Torez Smith) [1942772]
- usb: dwc3: debug: fix sparse warning (Torez Smith) [1942772]
- usb: dwc3: meson: fix coccinelle WARNING (Torez Smith) [1942772]
- usb: dwc3: qcom: Add interconnect support in dwc3 driver (Torez Smith) [1942772]
- net: usb: net1080: Remove in_interrupt() comment (Torez Smith) [1942772]
- net: usb: kaweth: Remove last user of kaweth_control() (Torez Smith) [1942772]
- net: usb: kaweth: Replace kaweth_control() with usb_control_msg() (Torez Smith) [1942772]
- net: usb: ax88179_178a: add MCT usb 3.0 adapter (Torez Smith) [1942772]
- net: usb: ax88179_178a: fix missing stop entry in driver_info (Torez Smith) [1942772]
- net: usb: ax88179_178a: add Toshiba usb 3.0 adapter (Torez Smith) [1942772]
- Revert "usbip: Implement a match function to fix usbip" (Torez Smith) [1942772]
- usb: dwc2: Fix parameter type in function pointer prototype (Torez Smith) [1942772]
- usb: dwc3: core: Print warning on unsupported speed (Torez Smith) [1942772]
- usb: dwc3: core: Properly default unspecified speed (Torez Smith) [1942772]
- usb: dwc2: Add missing cleanups when usb_add_gadget_udc() fails (Torez Smith) [1942772]
- usb: dwc3: gadget: END_TRANSFER before CLEAR_STALL command (Torez Smith) [1942772]
- usb: dwc3: gadget: Resume pending requests after CLEAR_STALL (Torez Smith) [1942772]
- can: peak_usb: convert to use le32_add_cpu() (Torez Smith) [1942772]
- can: pcan_usb: add support of rxerr/txerr counters (Torez Smith) [1942772]
- can: pcan_usb: Document the commands sent to the device (Torez Smith) [1942772]
- can: mcba_usb: remove redundant initialization of variable err (Torez Smith) [1942772]
- usb: dwc2: Always disable regulators on driver teardown (Torez Smith) [1942772]
- usbip: simplify the return expression of usbip_core_init() (Torez Smith) [1942772]
- rndis_host: increase sleep time in the query-response loop (Torez Smith) [1942772]
- Revert "usb: dwc3: meson-g12a: fix shared reset control use" (Torez Smith) [1942772]
- net: usb: dm9601: Add USB ID of Keenetic Plus DSL (Torez Smith) [1942772]
- smsc95xx: add phylib support (Torez Smith) [1942772]
- smsc95xx: use usbnet->driver_priv (Torez Smith) [1942772]
- smsc95xx: remove redundant function arguments (Torez Smith) [1942772]
- net: usb: Fix uninit-was-stored issue in asix_read_phy_addr() (Torez Smith) [1942772]
- net: cdc_ncm: Fix build error (Torez Smith) [1942772]
- tools: usb: move to tools buildsystem (Torez Smith) [1942772]
- usbip: Implement a match function to fix usbip (Torez Smith) [1942772]
- usb: dwc3: gadget: Handle ZLP for sg requests (Torez Smith) [1942772]
- usb: dwc3: gadget: Fix handling ZLP (Torez Smith) [1942772]
- usb: dwc3: gadget: Don't setup more than requested (Torez Smith) [1942772]
- r8152: Use MAC address from correct device tree node (Torez Smith) [1942772]
- usb: hso: remove bogus check for EINPROGRESS (Torez Smith) [1942772]
- usb: hso: no complaint about kmalloc failure (Torez Smith) [1942772]
- hso: fix bailout in error case of probe (Torez Smith) [1942772]
- usb: dwc3: convert to devm_platform_ioremap_resource_byname (Torez Smith) [1942772]
- net: lan78xx: replace bogus endpoint lookup (Torez Smith) [1942772]
- net: lan78xx: fix transfer-buffer memory leak (Torez Smith) [1942772]
- net: lan78xx: add missing endpoint sanity check (Torez Smith) [1942772]
- usb: hso: check for return value in hso_serial_common_create() (Torez Smith) [1942772]
- Revert "usb: dwc2: override PHY input signals with usb role switch support" (Torez Smith) [1942772]
- Revert "usb: dwc2: don't use ID/Vbus detection if usb-role-switch on STM32MP15 SoCs" (Torez Smith) [1942772]
- usb: dwc3: gadget: when the started list is empty stop the active xfer (Torez Smith) [1942772]
- usb: dwc3: gadget: make starting isoc transfers more robust (Torez Smith) [1942772]
- usb: dwc3: gadget: add frame number mask (Torez Smith) [1942772]
- usb: dwc2: Fix error path in gadget registration (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: fix shared reset control use (Torez Smith) [1942772]
- usb: dwc2: don't use ID/Vbus detection if usb-role-switch on STM32MP15 SoCs (Torez Smith) [1942772]
- usb: dwc2: override PHY input signals with usb role switch support (Torez Smith) [1942772]
- net: cdc_ncm: hook into set_rx_mode to admit multicast traffic (Torez Smith) [1942772]
- net: cdc_ncm: add .ndo_set_rx_mode to cdc_ncm_netdev_ops (Torez Smith) [1942772]
- net: usbnet: export usbnet_set_rx_mode() (Torez Smith) [1942772]
- net: cdc_ether: export usbnet_cdc_update_filter (Torez Smith) [1942772]
- net: cdc_ether: use dev->intf to get interface information (Torez Smith) [1942772]
- ax88172a: fix ax88172a_unbind() failures (Torez Smith) [1942772]
- usb: dwc2: gadget: Avoid pointless read of EP control register (Torez Smith) [1942772]
- usb: dwc2: gadget: Make use of GINTMSK2 (Torez Smith) [1942772]
- usb: dwc3: Replace HTTP links with HTTPS ones (Torez Smith) [1942772]
- tools: usb: usbip: Replace HTTP links with HTTPS ones (Torez Smith) [1942772]
- usb: hso: Fix debug compile warning on sparc32 (Torez Smith) [1942772]
- usbip: Use fallthrough pseudo-keyword (Torez Smith) [1942772]
- Documentation/driver-api: usb/URB: drop doubled word (Torez Smith) [1942772]
- usb: dwc3: dwc3-qcom: Do not define 'struct acpi_device_id' when !CONFIG_ACPI (Torez Smith) [1942772]
- usb: dwc3: pci: add support for the Intel Jasper Lake (Torez Smith) [1942772]
- usb: dwc2: Fix shutdown callback in platform (Torez Smith) [1942772]
- usb: dwc3: pci: add support for the Intel Tiger Lake PCH -H variant (Torez Smith) [1942772]
- net: usb: qmi_wwan: add support for Quectel EG95 LTE modem (Torez Smith) [1942772]
- smsc95xx: avoid memory leak in smsc95xx_bind (Torez Smith) [1942772]
- smsc95xx: check return value of smsc95xx_reset (Torez Smith) [1942772]
- usb: dwc2: gadget: Remove assigned but never used 'maxsize' (Torez Smith) [1942772]
- usb: dwc3: dwc3-of-simple: Function headers are not good candidates for kerneldoc (Torez Smith) [1942772]
- usb: dwc3: dwc3-haps: Function headers are not suitable for kerneldoc (Torez Smith) [1942772]
- usb: dwc3: dwc3-omap: Do not read DMA status (Torez Smith) [1942772]
- usb: dwc3: ulpi: File headers are not doc headers (Torez Smith) [1942772]
- usb: dwc3: drd: File headers are not doc headers (Torez Smith) [1942772]
- usbnet: ipheth: fix ipheth_tx()'s return type (Torez Smith) [1942772]
- usbip: tools: add in man page how to load the client's module (Torez Smith) [1942772]
- usbip: tools: fix build error for multiple definition (Torez Smith) [1942772]
- usbip: tools: fix module name in man page (Torez Smith) [1942772]
- Revert "usb: dwc3: exynos: Add support for Exynos5422 suspend clk" (Torez Smith) [1942772]
- usb: dwc3: pci: Fix reference count leak in dwc3_pci_resume_work (Torez Smith) [1942772]
- media: USB: cdc-acm: blacklist IR Droid / IR Toy device (Torez Smith) [1942772]
- usbnet: smsc95xx: Fix use-after-free after removal (Torez Smith) [1942772]
- usb: dwc2: Postponed gadget registration to the udc class driver (Torez Smith) [1942772]
- usb: dwc2: use well defined macros for power_down (Torez Smith) [1942772]
- net: usb: ax88179_178a: fix packet alignment padding (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: fix USB2 PHY initialization on G12A and A1 SoCs (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: fix error path when fetching the reset line fails (Torez Smith) [1942772]
- net: usb: qmi_wwan: add Telit LE910C1-EUX composition (Torez Smith) [1942772]
- usb: dwc3: keystone: Turn on USB3 PHY before controller (Torez Smith) [1942772]
- usb: dwc2: Update Core Reset programming flow. (Torez Smith) [1942772]
- usb: dwc3: gadget: Check for prepared TRBs (Torez Smith) [1942772]
- usb: dwc3: Increase timeout for CmdAct cleared by device controller (Torez Smith) [1942772]
- usb: dwc3: gadget: Use SET_EP_PRIME for NoStream (Torez Smith) [1942772]
- usb: dwc3: gadget: Handle stream transfers (Torez Smith) [1942772]
- usb: dwc3: gadget: Don't prepare beyond a transfer (Torez Smith) [1942772]
- usb: dwc3: gadget: Wait for transfer completion (Torez Smith) [1942772]
- usb: dwc3: gadget: Handle XferComplete for streams (Torez Smith) [1942772]
- usb: dwc3: gadget: Enable XferComplete event (Torez Smith) [1942772]
- usb: dwc3: gadget: Refactor TRB completion handler (Torez Smith) [1942772]
- usb: dwc3: gadget: Check for in-progress END_TRANSFER (Torez Smith) [1942772]
- usb: dwc3: Get MDWIDTH for DWC_usb32 (Torez Smith) [1942772]
- usb: dwc3: Add support for DWC_usb32 IP (Torez Smith) [1942772]
- usb: dwc3: use true,false for dwc->otg_restart_host (Torez Smith) [1942772]
- usb: dwc2: gadget: move gadget resume after the core is in L0 state (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: add support for GXL and GXM SoCs (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: support the GXL/GXM DWC3 host phy disconnect (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: refactor usb init (Torez Smith) [1942772]
- usb: dwc3: gadget: Continue to process pending requests (Torez Smith) [1942772]
- r8152: support additional Microsoft Surface Ethernet Adapter variant (Torez Smith) [1942772]
- r8152: Use MAC address from device tree if available (Torez Smith) [1942772]
- net: usb: qmi_wwan: remove redundant assignment to variable status (Torez Smith) [1942772]
- net: huawei_cdc_ncm: remove redundant assignment to variable ret (Torez Smith) [1942772]
- net: usb: ax88179_178a: remove redundant assignment to variable ret (Torez Smith) [1942772]
- usb: dwc3: select USB_ROLE_SWITCH (Torez Smith) [1942772]
- usb: dwc3: pci: Enable extcon driver for Intel Merrifield (Torez Smith) [1942772]
- dwc3: Remove check for HWO flag in dwc3_gadget_ep_reclaim_trb_sg() (Torez Smith) [1942772]
- usb: hso: correct debug message (Torez Smith) [1942772]
- net: sierra_net: Remove unused inline function (Torez Smith) [1942772]
- usb: dwc3: gadget: WARN on no-resource status (Torez Smith) [1942772]
- usb: dwc3: gadget: Issue END_TRANSFER to retry isoc transfer (Torez Smith) [1942772]
- usb: dwc3: gadget: Store resource index of start cmd (Torez Smith) [1942772]
- usb: dwc3: core: Use role-switch default dr_mode (Torez Smith) [1942772]
- usb: dwc3: drd: Don't free non-existing irq (Torez Smith) [1942772]
- usb: dwc3: gadget: Properly handle failed kick_transfer (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: refactor usb2 phy init (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: check return of dwc3_meson_g12a_usb_init (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: get the reset as shared (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: handle the phy and glue registers separately (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: specify phy names in soc data (Torez Smith) [1942772]
- usb: dwc3: gadget: Refactor dwc3_gadget_ep_dequeue (Torez Smith) [1942772]
- usb: dwc3: gadget: Remove unnecessary checks (Torez Smith) [1942772]
- usb: dwc3: gadget: Give back staled requests (Torez Smith) [1942772]
- usb: dwc3: gadget: Properly handle ClearFeature(halt) (Torez Smith) [1942772]
- usb: dwc3: support continuous runtime PM with dual role (Torez Smith) [1942772]
- USB: dwc3: Use the correct style for SPDX License Identifier (Torez Smith) [1942772]
- net: usb: qmi_wwan: add support for DW5816e (Torez Smith) [1942772]
- net: usb: ax88179_178a: Implement ethtool_ops set_eeprom (Torez Smith) [1942772]
- usb: dwc3: gadget: Fix request completion check (Torez Smith) [1942772]
- USB: dwc2: Use the correct style for SPDX License Identifier (Torez Smith) [1942772]
- usb: dwc3: gadget: Do link recovery for SS and SSP (Torez Smith) [1942772]
- usb: dwc3: gadget: Properly set maxpacket limit (Torez Smith) [1942772]
- usb: dwc3: Fix GTXFIFOSIZ.TXFDEP macro name (Torez Smith) [1942772]
- Documentation: driver-api/usb/writing_usb_driver.rst Updates documentation links (Torez Smith) [1942772]
- pegasus: Remove pegasus' own workqueue (Torez Smith) [1942772]
- usb: dwc2: convert to devm_platform_get_and_ioremap_resource (Torez Smith) [1942772]
- usb: host: hisilicon: convert to devm_platform_get_and_ioremap_resource (Torez Smith) [1942772]
- usb: host: xhci-plat: convert to devm_platform_get_and_ioremap_resource (Torez Smith) [1942772]
- net: qmi_wwan: add support for ASKEY WWHC050 (Torez Smith) [1942772]
- usb: dwc3: fix up for role switch API change (Torez Smith) [1942772]
- usb: dwc2: Silence warning about supplies during deferred probe (Torez Smith) [1942772]
- usb: dwc2: Implement set_selfpowered() (Torez Smith) [1942772]
- usb: dwc3: core: don't do suspend for device mode if already suspended (Torez Smith) [1942772]
- usb: dwc3: Rework resets initialization to be more flexible (Torez Smith) [1942772]
- usb: dwc3: Rework clock initialization to be more flexible (Torez Smith) [1942772]
- usb: dwc3: Add support for role-switch-default-mode binding (Torez Smith) [1942772]
- usb: dwc3: Registering a role switch in the DRD code. (Torez Smith) [1942772]
- usb: dwc3: core: add support for disabling SS instances in park mode (Torez Smith) [1942772]
- usb: dwc3: gadget: Wrap around when skip TRBs (Torez Smith) [1942772]
- usb: dwc3: gadget: Don't clear flags before transfer ended (Torez Smith) [1942772]
- usb: dwc3: Remove kernel doc annotation where it's not needed (Torez Smith) [1942772]
- usb: dwc3: Add ACPI support for xHCI ports (Torez Smith) [1942772]
- usb: dwc3: exynos: Add support for Exynos5422 suspend clk (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: Don't use ret uninitialized in dwc3_meson_g12a_otg_init (Torez Smith) [1942772]
- usb: dwc3: trace: print enqueue/dequeue pointers too (Torez Smith) [1942772]
- usb: dwc2: add support for STM32MP15 SoCs USB OTG HS and FS (Torez Smith) [1942772]
- usb: dwc3: Add Amlogic A1 DWC3 glue (Torez Smith) [1942772]
- cdc_ncm: Fix the build warning (Torez Smith) [1942772]
- cdc_ncm: Implement the 32-bit version of NCM Transfer Block (Torez Smith) [1942772]
- r8152: reject unsupported coalescing params (Torez Smith) [1942772]
- usb: dwc3: gadget: Update chain bit correctly when using sg list (Torez Smith) [1942772]
- r8152: Replace zero-length array with flexible-array member (Torez Smith) [1942772]
- r8152: check disconnect status after long sleep (Torez Smith) [1942772]
- net: usb: qmi_wwan: restore mtu min/max values after raw_ip switch (Torez Smith) [1942772]
- USB: Replace zero-length array with flexible-array member (Torez Smith) [1942772]
- r8152: use new helper tcp_v6_gso_csum_prep (Torez Smith) [1942772]
- net: usb: cdc-phonet: Replace zero-length array with flexible-array member (Torez Smith) [1942772]
- usb: dwc3: qcom: Replace <linux/clk-provider.h> by <linux/of_clk.h> (Torez Smith) [1942772]
- usb: dwc3: gadget: Check for IOC/LST bit in TRB->ctrl fields (Torez Smith) [1942772]
- usb: dwc2: Fix in ISOC request length checking (Torez Smith) [1942772]
- usb: dwc2: Fix SET/CLEAR_FEATURE and GET_STATUS flows (Torez Smith) [1942772]
- usb: dwc3: debug: fix string position formatting mixup with ret and len (Torez Smith) [1942772]
- qmi_wwan: unconditionally reject 2 ep interfaces (Torez Smith) [1942772]
- qmi_wwan: re-add DW5821e pre-production variant (Torez Smith) [1942772]
- r8152: Add MAC passthrough support to new device (Torez Smith) [1942772]
- r8152: disable DelayPhyPwrChg (Torez Smith) [1942772]
- r8152: avoid the MCU to clear the lanwake (Torez Smith) [1942772]
- r8152: don't enable U1U2 with USB_SPEED_HIGH for RTL8153B (Torez Smith) [1942772]
- r8152: disable test IO for RTL8153B (Torez Smith) [1942772]
- r8152: Disable PLA MCU clock speed down (Torez Smith) [1942772]
- r8152: disable U2P3 for RTL8153B (Torez Smith) [1942772]
- r8152: get default setting of WOL before initializing (Torez Smith) [1942772]
- r8152: reset flow control patch when linking on for RTL8153B (Torez Smith) [1942772]
- r8152: fix runtime resume for linking change (Torez Smith) [1942772]
- usb: dwc3: pci: add ID for the Intel Comet Lake -V variant (Torez Smith) [1942772]
- net: usb: lan78xx: Add .ndo_features_check (Torez Smith) [1942772]
- usb: dwc2: Drop unlock/lock upon queueing a work item (Torez Smith) [1942772]
- usb: dwc3: gadget: Remove END_TRANSFER delay (Torez Smith) [1942772]
- usb: dwc3: gadget: Delay starting transfer (Torez Smith) [1942772]
- usb: dwc3: gadget: Check END_TRANSFER completion (Torez Smith) [1942772]
- usb: dwc3: turn off VBUS when leaving host mode (Torez Smith) [1942772]
- usb: dwc2: fix debugfs FIFO count (Torez Smith) [1942772]
- usb: dwc2: Fix IN FIFO allocation (Torez Smith) [1942772]
- usb: dwc2: Fix Stalling a Non-Isochronous OUT EP (Torez Smith) [1942772]
- usb: dwc3: gadget: Clear DCTL.ULSTCHNGREQ before set (Torez Smith) [1942772]
- usb: dwc2: Fix NULL qh in dwc2_queue_transaction (Torez Smith) [1942772]
- usb: dwc3: gadget: Set link state to RX_Detect on disconnect (Torez Smith) [1942772]
- usb: dwc3: gadget: Don't send unintended link state change (Torez Smith) [1942772]
- r8152: add missing endpoint sanity check (Torez Smith) [1942772]
- net: usb: lan78xx: limit size of local TSO packets (Torez Smith) [1942772]
- qmi_wwan: Add support for Quectel RM500Q (Torez Smith) [1942772]
- usbip: Fix unsafe unaligned pointer usage (Torez Smith) [1942772]
- usb: dwc3: use proper initializers for property entries (Torez Smith) [1942772]
- net: r8152: use skb_list_walk_safe helper for gso segments (Torez Smith) [1942772]
- net: usb: lan78xx: fix possible skb leak (Torez Smith) [1942772]
- net: ch9200: remove unnecessary return (Torez Smith) [1942772]
- net: ch9200: use __func__ in debug message (Torez Smith) [1942772]
- tools: usb: usbip: Get rid of driver name printout in README (Torez Smith) [1942772]
- can: gs_usb: gs_usb_probe(): use descriptors of current altsetting (Torez Smith) [1942772]
- can: kvaser_usb: fix interface sanity check (Torez Smith) [1942772]
- usb: dwc3: gadget: Fix request complete check (Torez Smith) [1942772]
- thunderbolt: Update documentation with the USB4 information (Torez Smith) [1942772]
- usbip: Fix error path of vhci_recv_ret_submit() (Torez Smith) [1942772]
- usbip: Fix receive error in vhci-hcd when using scatter-gather (Torez Smith) [1942772]
- net: usb: lan78xx: Fix error message format specifier (Torez Smith) [1942772]
- net: usb: lan78xx: Fix suspend/resume PHY register access error (Torez Smith) [1942772]
- usb: dwc3: pci: add ID for the Intel Comet Lake -H variant (Torez Smith) [1942772]
- usb: dwc3: ep0: Clear started flag on completion (Torez Smith) [1942772]
- usb: dwc3: gadget: Clear started flag for non-IOC (Torez Smith) [1942772]
- usb: dwc3: gadget: Fix logical condition (Torez Smith) [1942772]
- can: kvaser_usb: kvaser_usb_leaf: Fix some info-leaks to USB devices (Torez Smith) [1942772]
- can: ucan: fix non-atomic allocation in completion handler (Torez Smith) [1942772]
- net: usb: aqc111: Use the correct style for SPDX License Identifier (Torez Smith) [1942772]
- net: usbnet: Fix -Wcast-function-type (Torez Smith) [1942772]
- net: hso: Fix -Wcast-function-type (Torez Smith) [1942772]
- ax88179_178a: add ethtool_op_get_ts_info() (Torez Smith) [1942772]
- r8152: avoid to call napi_disable twice (Torez Smith) [1942772]
- r8152: Re-order napi_disable in rtl8152_close (Torez Smith) [1942772]
- ax88172a: fix information leak on short answers (Torez Smith) [1942772]
- usb: dwc2: create debugfs directory under usb root (Torez Smith) [1942772]
- usb: dwc3: create debugfs directory under usb root (Torez Smith) [1942772]
- net: cdc_ncm: Signedness bug in cdc_ncm_set_dgram_size() (Torez Smith) [1942772]
- net: usb: qmi_wwan: add support for Foxconn T77W968 LTE modules (Torez Smith) [1942772]
- usbip: Fix uninitialized symbol 'nents' in stub_recv_cmd_submit() (Torez Smith) [1942772]
- USBIP: add config dependency for SGL_ALLOC (Torez Smith) [1942772]
- net: usb: qmi_wwan: add support for DW5821e with eSIM support (Torez Smith) [1942772]
- CDC-NCM: handle incomplete transfer of MTU (Torez Smith) [1942772]
- usbip: tools: fix fd leakage in the function of read_attr_usbip_status (Torez Smith) [1942772]
- can: peak_usb: fix a potential out-of-sync while decoding packets (Torez Smith) [1942772]
- can: usb_8dev: fix use-after-free on disconnect (Torez Smith) [1942772]
- can: mcba_usb: fix use-after-free on disconnect (Torez Smith) [1942772]
- can: peak_usb: report bus recovery as well (Torez Smith) [1942772]
- can: gs_usb: gs_can_open(): prevent memory leak (Torez Smith) [1942772]
- usb: Spelling s/enpoint/endpoint/ (Torez Smith) [1942772]
- usb: dwc3: gadget: fix race when disabling ep with cancelled xfers (Torez Smith) [1942772]
- usb: dwc3: of-simple: add a shutdown (Torez Smith) [1942772]
- usbip: Fix free of unallocated memory in vhci tx (Torez Smith) [1942772]
- usbip: tools: Fix read_usb_vudc_device() error path handling (Torez Smith) [1942772]
- usb: dwc3: pci: prevent memory leak in dwc3_pci_probe (Torez Smith) [1942772]
- usb: dwc3: remove the call trace of USBx_GFLADJ (Torez Smith) [1942772]
- usb: dwc3: select CONFIG_REGMAP_MMIO (Torez Smith) [1942772]
- r8152: check the pointer rtl_fw->fw before using it (Torez Smith) [1942772]
- net: lan78xx: remove set but not used variable 'event' (Torez Smith) [1942772]
- usb: dwc3: debug: Remove newline printout (Torez Smith) [1942772]
- r8152: support firmware of PHY NC for RTL8153A (Torez Smith) [1942772]
- r8152: move r8153_patch_request forward (Torez Smith) [1942772]
- r8152: add checking fw_offset field of struct fw_mac (Torez Smith) [1942772]
- r8152: rename fw_type_1 with fw_mac (Torez Smith) [1942772]
- usb: dwc2: use a longer core rest timeout in dwc2_core_reset() (Torez Smith) [1942772]
- usb: dwc3: Disable phy suspend after power-on reset (Torez Smith) [1942772]
- r8152: add device id for Lenovo ThinkPad USB-C Dock Gen 2 (Torez Smith) [1942772]
- net: usb: lan78xx: Connect PHY before registering MAC (Torez Smith) [1942772]
- usb: hso: obey DMA rules in tiocmget (Torez Smith) [1942772]
- r8152: support request_firmware for RTL8153 (Torez Smith) [1942772]
- net: usb: sr9800: fix uninitialized local variable (Torez Smith) [1942772]
- net: usb: ax88179_178a: write mac to hardware in get_mac_addr (Torez Smith) [1942772]
- net: usb: qmi_wwan: add Telit 0x1050 composition (Torez Smith) [1942772]
- usb: dwc3: Remove dev_err() on platform_get_irq() failure (Torez Smith) [1942772]
- usb: dwc3: Switch to platform_get_irq_byname_optional() (Torez Smith) [1942772]
- r8152: Set macpassthru in reset_resume callback (Torez Smith) [1942772]
- qmi_wwan: add support for Cinterion CLS8 devices (Torez Smith) [1942772]
- usbip: clean up an indentation issue (Torez Smith) [1942772]
- usbip: vhci_hcd indicate failed message (Torez Smith) [1942772]
- r8152: Add identifier names for function pointers (Torez Smith) [1942772]
- r8152: Use guard clause and fix comment typos (Torez Smith) [1942772]
- hso: fix NULL-deref on tty open (Torez Smith) [1942772]
- net: usb: ax88179_178a: allow optionally getting mac address from device tree (Torez Smith) [1942772]
- r8152: Factor out OOB link list waits (Torez Smith) [1942772]
- usbnet: ignore endpoints with invalid wMaxPacketSize (Torez Smith) [1942772]
- cdc_ncm: fix divide-by-zero caused by invalid wMaxPacketSize (Torez Smith) [1942772]
- usbnet: sanity checking of packet sizes and device mtu (Torez Smith) [1942772]
- r8152: adjust the settings of ups flags (Torez Smith) [1942772]
- r8152: modify rtl8152_set_speed function (Torez Smith) [1942772]
- usb: dwc3: remove generic PHY calibrate() calls (Torez Smith) [1942772]
- usb: gadget: net2280: Move all "ll" registers in one structure (Torez Smith) [1942772]
- usb: dwc3: gadget: Workaround Mirosoft's BESL check (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: fix suspend resume regulator unbalanced disables (Torez Smith) [1942772]
- usb: gadget: composite: Set recommended BESL values (Torez Smith) [1942772]
- usb: dwc3: gadget: Set BESL config parameter (Torez Smith) [1942772]
- usb: dwc3: Separate field holding multiple properties (Torez Smith) [1942772]
- usb: dwc3: don't set gadget->is_otg flag (Torez Smith) [1942772]
- usb: dwc3: st: Add of_dev_put() in probe function (Torez Smith) [1942772]
- usb: dwc3: st: Add of_node_put() before return in probe function (Torez Smith) [1942772]
- r8152: add a helper function about setting EEE (Torez Smith) [1942772]
- r8152: saving the settings of EEE (Torez Smith) [1942772]
- net: usb: Delete unnecessary checks before the macro call “dev_kfree_skb” (Torez Smith) [1942772]
- r8152: divide the tx and rx bottom functions (Torez Smith) [1942772]
- r8152: fix accessing skb after napi_gro_receive (Torez Smith) [1942772]
- r8152: change rx_copybreak and rx_pending through ethtool (Torez Smith) [1942772]
- r8152: support skb_add_rx_frag (Torez Smith) [1942772]
- r8152: use alloc_pages for rx buffer (Torez Smith) [1942772]
- r8152: replace array with linking list for rx information (Torez Smith) [1942772]
- r8152: separate the rx buffer size (Torez Smith) [1942772]
- usb: dwc3: Use clk_bulk_prepare_enable() (Torez Smith) [1942772]
- usb: dwc3: Use devres to get clocks (Torez Smith) [1942772]
- usb: dwc3: remove generic PHYs forwarding for XHCI device (Torez Smith) [1942772]
- USB: usbip: convert to use dev_groups (Torez Smith) [1942772]
- usb: dwc3: Update soft-reset wait polling rate (Torez Smith) [1942772]
- usb: dwc2: gadget: Fix kill_all_requests race (Torez Smith) [1942772]
- usb: dwc3: omap: use devm_platform_ioremap_resource() to simplify code (Torez Smith) [1942772]
- usb: dwc3: keystone: use devm_platform_ioremap_resource() to simplify code (Torez Smith) [1942772]
- usb: dwc3: omap: squash include/linux/platform_data/dwc3-omap.h (Torez Smith) [1942772]
- usb: dwc3: meson-g12a: use devm_platform_ioremap_resource() to simplify code (Torez Smith) [1942772]
- usbip: tools: fix GCC8 warning for strncpy (Torez Smith) [1942772]
- usb: dwc3: Switch to use device_property_count_u32() (Torez Smith) [1942772]
- usb: dwc2: Switch to use device_property_count_u32() (Torez Smith) [1942772]
- can: kvaser_usb: Use struct_size() in alloc_candev() (Torez Smith) [1942772]
- net: usb: Merge cpu_to_le32s + memcpy to put_unaligned_le32 (Torez Smith) [1942772]
- ax88179_178a: Merge memcpy + le32_to_cpus to get_unaligned_le32 (Torez Smith) [1942772]
- usbnet: smsc75xx: Merge memcpy + le32_to_cpus to get_unaligned_le32 (Torez Smith) [1942772]
- net: lan78xx: Merge memcpy + lexx_to_cpus to get_unaligned_lexx (Torez Smith) [1942772]
- bluetooth: eliminate the potential race condition when removing the HCI controller (Gopal Tiwari) [1971488]

* Wed Jul 07 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-322.el8]
- bareudp: add NETIF_F_FRAGLIST flag for dev features (Paolo Abeni) [1977850]
- vxlan: add NETIF_F_FRAGLIST flag for dev features (Paolo Abeni) [1977850]
- geneve: add NETIF_F_FRAGLIST flag for dev features (Paolo Abeni) [1977850]
- RDMA/siw: Release xarray entry (Kamal Heib) [1971483]
- RDMA/siw: Properly check send and receive CQ pointers (Kamal Heib) [1971483]
- RDMA/siw: Fix a use after free in siw_alloc_mr (Kamal Heib) [1971483]
- RDMA/rxe: Clear all QP fields if creation failed (Kamal Heib) [1971483]
- RDMA/rxe: Fix a bug in rxe_fill_ip_info() (Kamal Heib) [1971483]
- RDMA/rxe: Remove rxe_dma_device declaration (Kamal Heib) [1971483]
- IB/hfi1: Fix error return code in parse_platform_config() (Kamal Heib) [1971483]
- IB/hfi1: Remove unused function (Kamal Heib) [1971483]
- RDMA/srpt: Fix error return code in srpt_cm_req_recv() (Kamal Heib) [1971483]
- IB/isert: Fix a use after free in isert_connect_request (Kamal Heib) [1971483]
- RDMA: Verify port when creating flow rule (Kamal Heib) [1971483]
- RDMA/uverbs: Fix a NULL vs IS_ERR() bug (Kamal Heib) [1971483]
- RDMA/core: Don't access cm_id after its destruction (Kamal Heib) [1971483]
- RDMA/core: Prevent divide-by-zero error triggered by the user (Kamal Heib) [1971483]
- RDMA/core: Add CM to restrack after successful attachment to a device (Kamal Heib) [1971483]
- RDMA/core: Unify RoCE check and re-factor code (Kamal Heib) [1971483]
- RDMA/core: Fix corrupted SL on passive side (Kamal Heib) [1971483]
- mm: vmalloc: add cond_resched() in __vunmap() (Rafael Aquini) [1978469]
- /proc/PID/smaps: Add PMD migration entry parsing (Nico Pache) [1977066]
- s390: add 3f program exception handler (Nico Pache) [1977066]
- x86/ioremap: Fix CONFIG_EFI=n build (Nico Pache) [1977066]
- mm, slub: move slub_debug static key enabling outside slab_mutex (Nico Pache) [1977066]
- mm, slub: enable slub_debug static key when creating cache with explicit debug flags (Nico Pache) [1977066]
- locking/mutex: Remove repeated declaration (Nico Pache) [1977066]
- percpu: make pcpu_nr_empty_pop_pages per chunk type (Nico Pache) [1977066]
- mm/swap: don't SetPageWorkingset unconditionally during swapin (Nico Pache) [1977066]
- s390/tlb: make cleared_pXs flags consistent with generic code (Nico Pache) [1977066]
- mm, compaction: make fast_isolate_freepages() stay within zone (Nico Pache) [1977066]
- mm/vmscan: restore zone_reclaim_mode ABI (Nico Pache) [1977066]
- mm, compaction: move high_pfn to the for loop scope (Nico Pache) [1977066]
- memblock: do not start bottom-up allocations with kernel_end (Nico Pache) [1977066]
- mm, page_alloc: disable pcplists during memory offline (Nico Pache) [1977066]
- mm, page_alloc: move draining pcplists to page isolation users (Nico Pache) [1977066]
- mm, page_alloc: cache pageset high and batch in struct zone (Nico Pache) [1977066]
- mm, page_alloc: simplify pageset_update() (Nico Pache) [1977066]
- mm, page_alloc: fix core hung in free_pcppages_bulk() (Nico Pache) [1977066]
- mm, page_alloc: remove setup_pageset() (Nico Pache) [1977066]
- mm, page_alloc: calculate pageset high and batch once per zone (Nico Pache) [1977066]
- mm, pcp: share common code between memory hotplug and percpu sysctl handler (Nico Pache) [1977066]
- mm, page_alloc: clean up pageset high and batch update (Nico Pache) [1977066]
- s390/uv: handle destroy page legacy interface (Nico Pache) [1977066]
- mm/filemap: fix filemap_map_pages for THP (Nico Pache) [1977066]
- mm: filemap: add missing FGP_ flags in kerneldoc comment for pagecache_get_page (Nico Pache) [1977066]
- mm/filemap.c: rewrite pagecache_get_page documentation (Nico Pache) [1977066]
- mm: filemap: clear idle flag for writes (Nico Pache) [1977066]
- mm: document semantics of ZONE_MOVABLE (Nico Pache) [1977066]
- mm/page_isolation: cleanup set_migratetype_isolate() (Nico Pache) [1977066]
- mm/page_isolation: drop WARN_ON_ONCE() in set_migratetype_isolate() (Nico Pache) [1977066]
- mm/page_isolation: exit early when pageblock is isolated in set_migratetype_isolate() (Nico Pache) [1977066]
- mm/page_alloc: tweak comments in has_unmovable_pages() (Nico Pache) [1977066]
- mm: reuse only-pte-mapped KSM page in do_wp_page() (Nico Pache) [1977066]
- mm/memory.c: skip spurious TLB flush for retried page fault (Nico Pache) [1977066]
- /proc/PID/smaps: consistent whitespace output format (Nico Pache) [1977066]
- mm/memcontrol.c: prevent missed memory.low load tears (Nico Pache) [1977066]
- mm, memcg: prevent mem_cgroup_protected store tearing (Nico Pache) [1977066]
- mm, memcg: prevent memory.min load/store tearing (Nico Pache) [1977066]
- mm, mempolicy: fix up gup usage in lookup_node (Nico Pache) [1977066]
- mm/page_ext.c: drop pfn_present() check when onlining (Nico Pache) [1977066]
- drivers/base/memory.c: drop pages_correctly_probed() (Nico Pache) [1977066]
- drivers/base/memory.c: drop section_count (Nico Pache) [1977066]
- include/linux/mm.h: remove dead code totalram_pages_set() (Nico Pache) [1977066]
- tools headers uapi: Sync asm-generic/mman-common.h with the kernel (Nico Pache) [1977066]
- mm/memcg: Relocate tcpmem to below memory in struct mem_cgroup (Waiman Long) [1959772]
- mm/memcg: optimize user context object stock access (Waiman Long) [1959772]
- mm/memcg: improve refill_obj_stock() performance (Waiman Long) [1959772]
- mm/memcg: cache vmstat data in percpu memcg_stock_pcp (Waiman Long) [1959772]
- mm/memcg: move mod_objcg_state() to memcontrol.c (Waiman Long) [1959772]
- mm: memcontrol: move PageMemcgKmem to the scope of CONFIG_MEMCG_KMEM (Waiman Long) [1959772]
- mm: memcontrol: inline __memcg_kmem_{un}charge() into obj_cgroup_{un}charge_pages() (Waiman Long) [1959772]
- mm: memcontrol: use obj_cgroup APIs to charge kmem pages (Waiman Long) [1959772]
- mm: memcontrol: change ug->dummy_page only if memcg changed (Waiman Long) [1959772]
- mm: memcontrol: directly access page->memcg_data in mm/page_alloc.c (Waiman Long) [1959772]
- mm: memcontrol: introduce obj_cgroup_{un}charge_pages (Waiman Long) [1959772]
- mm: memcontrol: slab: fix obtain a reference to a freeing memcg (Waiman Long) [1959772]
- mm: memmap defer init doesn't work as expected (Baoquan He) [1906271]
- mm: check nr_initialised with PAGES_PER_SECTION directly in defer_init() (Baoquan He) [1906271]
- mm/memory_hotplug: mark pageblocks MIGRATE_ISOLATE while onlining memory (Baoquan He) [1906271]
- mm, memory_hotplug: update pcp lists everytime onlining a memory block (Baoquan He) [1906271]
- mm: pass migratetype into memmap_init_zone() and move_pfn_range_to_zone() (Baoquan He) [1906271]
- nfs: account for selinux security context when deciding to share superblock (Scott Mayhew) [1927027]
- nfs: remove unneeded null check in nfs_fill_super() (Scott Mayhew) [1927027]
- lsm,selinux: add new hook to compare new mount to an existing mount (Scott Mayhew) [1927027]
- libceph: allow addrvecs with a single NONE/blank address (Jeff Layton) [1972278]
- scsi: megaraid_sas: Update driver version to 07.717.02.00-rc1 (Tomas Henzl) [1968170]
- scsi: megaraid_sas: Handle missing interrupts while re-enabling IRQs (Tomas Henzl) [1968170]
- scsi: megaraid_sas: Early detection of VD deletion through RaidMap update (Tomas Henzl) [1968170]
- scsi: megaraid_sas: Fix resource leak in case of probe failure (Tomas Henzl) [1968170]
- scsi: megaraid_sas: Send all non-RW I/Os for TYPE_ENCLOSURE device through firmware (Tomas Henzl) [1968170]
- scsi: megaraid_sas: Use DEFINE_SPINLOCK() for spinlock (Tomas Henzl) [1968170]
- scsi: scsi_devinfo: Add blacklist entry for HPE OPEN-V (Ewan D. Milne) [1927508]
- drivers: do not build devm_platform_get_and_ioremap_resource() for s390x (Jaroslav Kysela) [1917388]
- redhat: update ALSA configs and add regmap-sdw-mbq to redhat/filter-modules.sh (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: fix the return value in dpcm_apply_symmetry() (Jaroslav Kysela) [1917388]
- alsa: control_led - fix initialization in the mode show callback (Jaroslav Kysela) [1917388]
- ALSA: seq: Fix race of snd_seq_timer_open() (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ZBook Power G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: headphone and mic don't work on an Acer laptop (Jaroslav Kysela) [1917388]
- ALSA: firewire-lib: fix the context to call snd_pcm_stop_xrun() (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook 840 Aero G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP EliteBook x360 1040 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP Elite Dragonfly G2 (Jaroslav Kysela) [1917388]
- ASoC: rt5682: Fix the fast discharge for headset unplugging in soundwire mode (Jaroslav Kysela) [1917388]
- ASoC: tas2562: Fix TDM_CFG0_SAMPRATE values (Jaroslav Kysela) [1917388]
- ASoC: AMD Renoir: Remove fix for DMI entry on Lenovo 2020 platforms (Jaroslav Kysela) [1917388]
- ASoC: AMD Renoir - add DMI entry for Lenovo 2020 AMD platforms (Jaroslav Kysela) [1917388]
- ASoC: SOF: reset enabled_cores state at suspend (Jaroslav Kysela) [1917388]
- ASoC: fsl-asoc-card: Set .owner attribute when registering card. (Jaroslav Kysela) [1917388]
- ASoC: topology: Fix spelling mistake "vesion" -> "version" (Jaroslav Kysela) [1917388]
- ASoC: rt5659: Fix the lost powers for the HDA header (Jaroslav Kysela) [1917388]
- ASoC: core: Fix Null-point-dereference in fmt_single_name() (Jaroslav Kysela) [1917388]
- spi: pxa2xx: Drop useless comment in the pxa2xx_ssp.h (Jaroslav Kysela) [1917388]
- spi: pxa2xx: Switch to use BIT() and GENMASK() in pxa2xx_ssp.h (Jaroslav Kysela) [1917388]
- spi: pxa2xx: Update header block in pxa2xx_ssp.h (Jaroslav Kysela) [1917388]
- spi: pxa2xx: Add SSC2 and SSPSP2 SSP registers (Jaroslav Kysela) [1917388]
- ASoC: pxa: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: pxa: pxa-ssp: Remove redundant null check before clk_prepare_enable/clk_disable_unprepare (Jaroslav Kysela) [1917388]
- ASoC: mmp-sspa: drop unneeded snd_soc_dai_set_drvdata (Jaroslav Kysela) [1917388]
- ASoC: mmp-sspa: set phase two word length register (Jaroslav Kysela) [1917388]
- ASoC: pxa: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: Fix 7/8 spaces indentation in Kconfig (Jaroslav Kysela) [1917388]
- ASoC: jz4740-i2s: Remove manual DMA peripheral ID assignment (Jaroslav Kysela) [1917388]
- ASoC: jz4740-i2s: add missed checks for clk_get() (Jaroslav Kysela) [1917388]
- ASoC: Intel: fix error code cnl_set_dsp_D0() (Jaroslav Kysela) [1917388]
- ASoC: Intel: Skylake: Unassign ram_read and read_write ops (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove haswell solution (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove sst_dsp_get_thread_context (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove unused DSP interface fields (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: remove unneeded semicolon (Jaroslav Kysela) [1917388]
- catpt: Switch to use list_entry_is_head() helper (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Optimize applying user settings (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Correct clock selection for dai trigger (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Skip position update for unprepared streams (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Relax clock selection conditions (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Fix compilation when CONFIG_MODULES is disabled (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Cleanup after power routines streamlining (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Replace open coded variant of resource_intersection() (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Streamline power routines across LPT and WPT (Jaroslav Kysela) [1917388]
- ASoC: Intel: haswell: Add missing pm_ops (Jaroslav Kysela) [1917388]
- ASoC: Intel: cht_bsw_nau8824: Change SSP2-Codec DAI id to 0 (Jaroslav Kysela) [1917388]
- ASoC: Intel: cht_bsw_nau8824: Drop compress-cpu-dai bits (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5651: use semicolons rather than commas to separate statements (Jaroslav Kysela) [1917388]
- ASoC: Intel: broadwell: add missing pm_ops (Jaroslav Kysela) [1917388]
- ASoC: Intel: bdw-rt5677: add missing pm_ops (Jaroslav Kysela) [1917388]
- ASoC: Intel: broadwell: set card and driver name dynamically (Jaroslav Kysela) [1917388]
- ASoC: Intel: bdw-rt5650: Mark FE DAIs as nonatomic (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove rt5640 support for baytrail solution (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove max98090 support for baytrail solution (Jaroslav Kysela) [1917388]
- ASoC: Intel: atom: use inclusive language for SSP bclk/fsync (Jaroslav Kysela) [1917388]
- ASoC: Intel: Atom: add dynamic selection of DSP driver (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: select WANT_DEV_COREDUMP (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: add dynamic selection of DSP driver (Jaroslav Kysela) [1917388]
- ASoC: intel: SND_SOC_INTEL_KEEMBAY should depend on ARCH_KEEMBAY (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Add explicit DMADEVICES kconfig dependency (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove baytrail solution (Jaroslav Kysela) [1917388]
- ASoC: Intel: atom: Remove duplicate kconfigs (Jaroslav Kysela) [1917388]
- ASoC: remove zte zx drivers (Jaroslav Kysela) [1917388]
- ASoC: codecs: wsa881x: add missing stream rates and format (Jaroslav Kysela) [1917388]
- ASoC: wm_adsp: Remove unused control callback structure (Jaroslav Kysela) [1917388]
- ASoC: wm8994: Fix PM disable depth imbalance on error (Jaroslav Kysela) [1917388]
- ASoC: wm8903: remove useless assignments (Jaroslav Kysela) [1917388]
- ASoC: wm8523: Fix a typo in a comment (Jaroslav Kysela) [1917388]
- ASoC: wm8350: use semicolons rather than commas to separate statements (Jaroslav Kysela) [1917388]
- ASoC: wm5102: Use get_unaligned_be16() for dac_comp_coeff (Jaroslav Kysela) [1917388]
- ASoC: codecs: wcd934x: Set digital gain range correctly (Jaroslav Kysela) [1917388]
- ASoC: wcd9335: Remove unnecessary conversion to bool (Jaroslav Kysela) [1917388]
- ASoC: rt715: remove unused parameter (Jaroslav Kysela) [1917388]
- ASoC: mediatek: mt6359: add the calibration functions (Jaroslav Kysela) [1917388]
- ASoC: rt5682: clock driver must use the clock provider API (Jaroslav Kysela) [1917388]
- ASoC: rt1015: enable BCLK detection after calibration (Jaroslav Kysela) [1917388]
- ASoC: pcm512x: Add support for more data formats (Jaroslav Kysela) [1917388]
- ASoC: pcm512x: Move format check into `set_fmt()` (Jaroslav Kysela) [1917388]
- ASoC: pcm512x: Rearrange operations in `hw_params()` (Jaroslav Kysela) [1917388]
- ASoC: pcm512x: Fix not setting word length if DAIFMT_CBS_CFS (Jaroslav Kysela) [1917388]
- ASoC: mediatek: mt6359: Fix regulator_dev_lookup() fails for id "LDO_VAUD18" (Jaroslav Kysela) [1917388]
- ASoC: Remove mt6359_platform_driver_remove (Jaroslav Kysela) [1917388]
- ASoC: Fix vaud18 power leakage of mt6359 (Jaroslav Kysela) [1917388]
- ASoC: es8316: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Fix Bitclock polarity inversion (Jaroslav Kysela) [1917388]
- ASoC: cs35l33: fix an error code in probe() (Jaroslav Kysela) [1917388]
- ASoC: cs35l34: Add missing regmap use_single config (Jaroslav Kysela) [1917388]
- ASoC: wm8998: Fix PM disable depth imbalance on error (Jaroslav Kysela) [1917388]
- ASoC: codecs: wcd9335: Set digital gain range correctly (Jaroslav Kysela) [1917388]
- ASoC: TSCS454: remove unneeded semicolon (Jaroslav Kysela) [1917388]
- ASoC: TSCS42xx: remove unneeded semicolon (Jaroslav Kysela) [1917388]
- ASoC: ts3a227e: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: tlv320: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: tas571x: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: tas*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: tas2562: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: remove remnants of sirf prima/atlas audio codec (Jaroslav Kysela) [1917388]
- ASoC: rt5645: add error checking to rt5645_probe function (Jaroslav Kysela) [1917388]
- Revert "ASoC: rt5645: fix a NULL pointer dereference" (Jaroslav Kysela) [1917388]
- ASoC: rt1015: modify calibration sequence for better performance (Jaroslav Kysela) [1917388]
- ASoC: rk3328: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: pcm179x: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: pcm1789: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: nau8315: revise the power event of EN_PIN dapm widget for symmetry (Jaroslav Kysela) [1917388]
- ASoC: nau8315: add codec driver (Jaroslav Kysela) [1917388]
- ASoC: gtm601: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: es8328: Remove redundant null check before clk_disable_unprepare (Jaroslav Kysela) [1917388]
- ASoC: es7241: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: es7134: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: da9055: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: da7219: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: codecs/jz4770: Add DAPM widget to set HP out to cap-less mode (Jaroslav Kysela) [1917388]
- ASoC: codecs/jz4770: Don't change cap-couple setting in HP PMU/PMD (Jaroslav Kysela) [1917388]
- ASoC: codecs/jz4770: Adjust timeouts for cap-coupled outputs (Jaroslav Kysela) [1917388]
- ASoC: codecs/jz4770: Reset interrupt flags in bias PREPARE (Jaroslav Kysela) [1917388]
- ASoC: codecs/jz47xx: Use regmap_{set,clear}_bits (Jaroslav Kysela) [1917388]
- treewide: Use fallthrough pseudo-keyword (Jaroslav Kysela) [1917388]
- ASoC: inno_rk3036: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: hdac_hdmi: remove cancel_work_sync in runtime suspend (Jaroslav Kysela) [1917388]
- ASoC: hdmi-codec: Add RX support (Jaroslav Kysela) [1917388]
- ALSA: cx46xx: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ASoC: topology: KUnit: Convert from cpu to data format (Jaroslav Kysela) [1917388]
- ASoC: topology: KUnit: Add KUnit tests passing topology with PCM to snd_soc_tplg_component_load (Jaroslav Kysela) [1917388]
- ASoC: topology: KUnit: Add KUnit tests passing empty topology with variants to snd_soc_tplg_component_load (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: use semicolons rather than commas to separate statements (Jaroslav Kysela) [1917388]
- ASoC: tegra: Simplify with dma_set_mask_and_coherent() (Jaroslav Kysela) [1917388]
- ASoC: tegra: Don't warn on probe deferral (Jaroslav Kysela) [1917388]
- ASoC: tegra: tegra_rt5640: use devm_snd_soc_register_card() (Jaroslav Kysela) [1917388]
- ASoC: tegra: tegra_wm8753: use devm_snd_soc_register_card() (Jaroslav Kysela) [1917388]
- ASoC: tegra: trimslice.c: use devm_snd_soc_register_card() (Jaroslav Kysela) [1917388]
- ASoC: ti: davinci-evm: Remove redundant null check before clk_disable_unprepare (Jaroslav Kysela) [1917388]
- ASoC: ti: davinci: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: ti: j721e-evm: Fix compiler warning when CONFIG_OF=n (Jaroslav Kysela) [1917388]
- ASoC: ti: omap-abe-twl6040: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: ti: omap-mcsp: remove duplicate test (Jaroslav Kysela) [1917388]
- ASoC: uniphier: Simplify the return expression of uniphier_aio_startup (Jaroslav Kysela) [1917388]
- ASoC: uniphier: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: ux500: mop500: rename shadowing variable (Jaroslav Kysela) [1917388]
- ASoC: ux500: mop500: align function prototype (Jaroslav Kysela) [1917388]
- ALSA: x86: Simplify with dma_set_mask_and_coherent() (Jaroslav Kysela) [1917388]
- ASoC: cx2072x: Fix doubly definitions of Playback and Capture streams (Jaroslav Kysela) [1917388]
- ASoC: cs42l56: fix up error handling in probe (Jaroslav Kysela) [1917388]
- ASoC: cs42l52: Minor tidy up of error paths (Jaroslav Kysela) [1917388]
- ASoC: cs42l51: manage mclk shutdown delay (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Wait for PLL to lock before switching to it (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Only start PLL if it is needed (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Wait at least 150us after writing SCLK_PRESENT (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Use bclk from hw_params if set_sysclk was not called (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Report jack and button detection (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Add Capture Support (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Fix channel width support (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Always wait at least 3ms after reset (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Don't enable/disable regulator at Bias Level (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Fix mixer volume control (Jaroslav Kysela) [1917388]
- ASoC: cs*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: bd28623: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: alc5632: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: ak4458: Add MODULE_DEVICE_TABLE (Jaroslav Kysela) [1917388]
- ASoC: ak4118: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: alc5623: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1917388]
- ASoC: ak5558: Correct the dai name for ak5552 (Jaroslav Kysela) [1917388]
- ASoC: ak5558: change function name to ak5558_reset (Jaroslav Kysela) [1917388]
- ASoC: ak5558: Add support for ak5552 (Jaroslav Kysela) [1917388]
- ASoC: ak5558: Add MODULE_DEVICE_TABLE (Jaroslav Kysela) [1917388]
- ASoC: ak5558: mark OF related data as maybe unused (Jaroslav Kysela) [1917388]
- ASoC: adau1977: remove platform data and move micbias bindings include (Jaroslav Kysela) [1917388]
- ASoC: adau17x1: Remove redundant null check before clk_disable_unprepare (Jaroslav Kysela) [1917388]
- ASoC: adau*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: Add ADAU1372 audio CODEC support (Jaroslav Kysela) [1917388]
- ASoC: amd: fix for pcm_read() error (Jaroslav Kysela) [1917388]
- ASoC: amd: drop S24_LE format support (Jaroslav Kysela) [1917388]
- ASoC: amd: Add support for ALC1015P codec in acp3x machine driver (Jaroslav Kysela) [1917388]
- ASoC: amd: renoir: acp3x-pdm-dma: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: amd: raven: acp3x-i2s: Constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: amd: renoir: acp3x-pdm-dma: remove unnecessary assignments (Jaroslav Kysela) [1917388]
- ASoC: amd: fix acpi dependency kernel warning (Jaroslav Kysela) [1917388]
- ASoC: amd: update spdx license for acp machine driver (Jaroslav Kysela) [1917388]
- ASoC: amd: Add support for RT5682 codec in machine driver (Jaroslav Kysela) [1917388]
- ASoC: amd: Adding DAI LINK for rt1015 codec (Jaroslav Kysela) [1917388]
- ASoC: amd: Adding support for ALC1015 codec in machine driver (Jaroslav Kysela) [1917388]
- ASoC: amd: AMD RV RT5682 should depends on CROS_EC (Jaroslav Kysela) [1917388]
- ASoC: amd: renoir: remove invalid kernel-doc comment (Jaroslav Kysela) [1917388]
- ASoC: AMD Renoir - refine DMI entries for some Lenovo products (Jaroslav Kysela) [1917388]
- ASoC: AMD Renoir - add DMI entry for Lenovo ThinkPad X395 (Jaroslav Kysela) [1917388]
- ASoC: amd: Replacing MSI with Legacy IRQ model (Jaroslav Kysela) [1917388]
- ASoC: AMD Renoir - add DMI entry for Lenovo ThinkPad E14 Gen 2 (Jaroslav Kysela) [1917388]
- ASoC: AMD Renoir - add DMI table to avoid the ACP mic probe (broken BIOS) (Jaroslav Kysela) [1917388]
- ASoC: AMD Raven/Renoir - fix the PCI probe (PCI revision) (Jaroslav Kysela) [1917388]
- ASoC: amd: change clk_get() to devm_clk_get() and add missed checks (Jaroslav Kysela) [1917388]
- ASoC: amd: Return -ENODEV for non-existing ACPI call (Jaroslav Kysela) [1917388]
- ASoC: amd: support other audio modes for raven (Jaroslav Kysela) [1917388]
- ASoC: topology: adhere to KUNIT formatting standard (Jaroslav Kysela) [1917388]
- ASoC: topology: KUnit: Add KUnit tests passing various arguments to snd_soc_tplg_component_load (Jaroslav Kysela) [1917388]
- ALSA: trident: Use DIV_ROUND_CLOSEST() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: sonicvibes: Use DIV_ROUND_CLOSEST() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: sis7019: Use DIV_ROUND_CLOSEST() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: remove unneeded break (Jaroslav Kysela) [1917388]
- ALSA: hdsp: don't disable if not enabled (Jaroslav Kysela) [1917388]
- ALSA: hdsp: hardware output loopback (Jaroslav Kysela) [1917388]
- ALSA: pci: mixart: fix kernel-doc warning (Jaroslav Kysela) [1917388]
- ALSA: maestro: Use DIV_ROUND_CLOSEST() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: lola: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: intel8x0: Fix missing check in snd_intel8x0m_create (Jaroslav Kysela) [1917388]
- ALSA: intel8x0: Don't update period unless prepared (Jaroslav Kysela) [1917388]
- ALSA: hda: Avoid spurious unsol event handling during S3/S4 (Jaroslav Kysela) [1917388]
- ALSA: ens1370: Use DIV_ROUND_CLOSEST() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: emu10k1: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: emu10k1: Use dma_set_mask_and_coherent to simplify code (Jaroslav Kysela) [1917388]
- ALSA: ctxfi: fix comment syntax in file headers (Jaroslav Kysela) [1917388]
- ALSA: ctxfi: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: ctxfi: cthw20k2: fix mask on conf to allow 4 bits (Jaroslav Kysela) [1917388]
- ALSA: bt87x: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: azt3328: Assign boolean values to a bool variable (Jaroslav Kysela) [1917388]
- ALSA: asihpi: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: dice: fix stream format for TC Electronic Konnekt Live at high sampling transfer frequency (Jaroslav Kysela) [1917388]
- ALSA: dice: disable double_pcm_frames mode for M-Audio Profire 610, 2626 and Avid M-Box 3 Pro (Jaroslav Kysela) [1917388]
- ALSA: firewire-lib: fix amdtp_packet tracepoints event for packet_index field (Jaroslav Kysela) [1917388]
- ALSA: firewire-lib: fix calculation for size of IR context payload (Jaroslav Kysela) [1917388]
- ALSA: firewire-lib: fix check for the size of isochronous packet payload (Jaroslav Kysela) [1917388]
- ALSA: bebob/oxfw: fix Kconfig entry for Mackie d.2 Pro (Jaroslav Kysela) [1917388]
- ALSA: dice: fix stream format at middle sampling rate for Alesis iO 26 (Jaroslav Kysela) [1917388]
- ALSA: bebob: enable to deliver MIDI messages for multiple ports (Jaroslav Kysela) [1917388]
- ALSA: bebob: detect the number of available MIDI ports (Jaroslav Kysela) [1917388]
- ALSA: bebob: code refactoring for stream format detection (Jaroslav Kysela) [1917388]
- ALSA: dice: fix null pointer dereference when node is disconnected (Jaroslav Kysela) [1917388]
- ALSA: fireface: fix to parse sync status register of latter protocol (Jaroslav Kysela) [1917388]
- ALSA: bebob: remove an unnecessary condition in hwdep_read() (Jaroslav Kysela) [1917388]
- ALSA: fireface: remove unnecessary condition in hwdep_read() (Jaroslav Kysela) [1917388]
- ALSA: oxfw: remove an unnecessary condition in hwdep_read() (Jaroslav Kysela) [1917388]
- ALSA: dice: add support for Lexicon I-ONIX FW810s (Jaroslav Kysela) [1917388]
- ALSA: firewire-tascam: Fix integer overflow in midi_port_work() (Jaroslav Kysela) [1917388]
- ALSA: fireface: Fix integer overflow in transmit_midi_msg() (Jaroslav Kysela) [1917388]
- ALSA: firewire: Clean up a locking issue in copy_resp_to_buf() (Jaroslav Kysela) [1917388]
- ALSA: firewire: fix comparison to bool warning (Jaroslav Kysela) [1917388]
- ALSA: firewire: Replace tasklet with work (Jaroslav Kysela) [1917388]
- ALSA: firewire: convert tasklets to use new tasklet_setup() API (Jaroslav Kysela) [1917388]
- ALSA: vx: Use roundup() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: pcsp: Fix fall-through warnings for Clang (Jaroslav Kysela) [1917388]
- ALSA: dummy: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: aloop: Fix initialization of controls (Jaroslav Kysela) [1917388]
- ALSA: aloop: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: atmel: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1917388]
- ASoC: SOF: ext_manifest: use explicit number for elem_type (Jaroslav Kysela) [1917388]
- ASoC: soc-acpi: allow for partial match in parent name (Jaroslav Kysela) [1917388]
- ASoC: soc-acpi: add helper to identify parent driver. (Jaroslav Kysela) [1917388]
- ASoC: soc-acpi: add new fields for mach_params (Jaroslav Kysela) [1917388]
- ASoC: rt5682: Add a new property for the DMIC clock driving (Jaroslav Kysela) [1917388]
- ALSA: hda: Change AZX_MAX_BUF_SIZE from 1GB to 4MB (Jaroslav Kysela) [1917388]
- soundwire: sysfs: Constify static struct attribute_group (Jaroslav Kysela) [1917388]
- ALSA: remove trailing semicolon in macro definition (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: don't send DAI_CONFIG IPC for older firmware (Jaroslav Kysela) [1917388]
- ASoC: SOF: use current DAI config during resume (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: Update ADL P to use its own descriptor (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: add missing use_acpi_target_states for TGL platforms (Jaroslav Kysela) [1917388]
- ASoC: SOF: topology: remove useless code (Jaroslav Kysela) [1917388]
- ASoC: SOF: Kconfig: fix typo of SND_SOC_SOF_PCI (Jaroslav Kysela) [1917388]
- ASOC: SOF: simplify nocodec mode (Jaroslav Kysela) [1917388]
- ASoC: SOF: pcm: export snd_pcm_dai_link_fixup (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: update set_mach_params() (Jaroslav Kysela) [1917388]
- ASoC: SOF: change signature of set_mach_params() callback (Jaroslav Kysela) [1917388]
- ASoC: SOF: add Kconfig option for probe workqueues (Jaroslav Kysela) [1917388]
- ASoC: SOF: Simplify sof_probe_complete handling for acpi/pci/of (Jaroslav Kysela) [1917388]
- ASoC: SOF: core: Add missing error prints to device probe operation (Jaroslav Kysela) [1917388]
- ASoC: SOF: match SSP config with pcm hw params (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: HDA: add hw params callback for SSP DAIs (Jaroslav Kysela) [1917388]
- ASoC: SOF: parse multiple SSP DAI and hw configs (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: drop display power on/off in D0i3 flows (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: move ELH chip info (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: APL: set shutdown callback to hda_dsp_shutdown (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: CNL: set shutdown callback to hda_dsp_shutdown (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: ICL: set shutdown callback to hda_dsp_shutdown (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: TGL: set shutdown callback to hda_dsp_shutdown (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: TGL: fix EHL ops (Jaroslav Kysela) [1917388]
- ASoC: SOF: core: harden shutdown helper (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: HDA: fix core status verification (Jaroslav Kysela) [1917388]
- ASoC: SOF: add a helper to get topology configured mclk (Jaroslav Kysela) [1917388]
- ASoC: SOF: only allocate debugfs cache buffers for IPC flood entries (Jaroslav Kysela) [1917388]
- ASoC: SOF: fix debugfs initialisation error handling (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: enable async suspend (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: turn off display power in resume (Jaroslav Kysela) [1917388]
- ASoC: SOF: intel: fix wrong poll bits in dsp power down (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: unregister DMIC device on probe error (Jaroslav Kysela) [1917388]
- ALSA: hda: move Intel SoundWire ACPI scan to dedicated module (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: SoundWire: simplify Kconfig (Jaroslav Kysela) [1917388]
- ASoC: SOF: pci: move DSP_CONFIG use to platform-specific drivers (Jaroslav Kysela) [1917388]
- ASoC: SOF: pci: split PCI into different drivers (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: add sof_icl_ops for ICL platforms (Jaroslav Kysela) [1917388]
- ASoC: SOF: ACPI: avoid reverse module dependency (Jaroslav Kysela) [1917388]
- ASoC: SOF: relax ABI checks and avoid unnecessary warnings (Jaroslav Kysela) [1917388]
- ASoC: SOF: fix runtime pm usage mismatch after probe errors (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: add dev_dbg() when DMIC number is overridden (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: HDA: don't keep a temporary variable (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: detect DMIC number in SoundWire mixed config (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: SoundWire: refine ACPI match (Jaroslav Kysela) [1917388]
- ASoC: SOF: HDA: (cosmetic) simplify hda_dsp_d0i3_work() (Jaroslav Kysela) [1917388]
- ASoC: SOF: remove unused functions (Jaroslav Kysela) [1917388]
- ASoC: SOF: fix string format for errors (Jaroslav Kysela) [1917388]
- ASoC: SOF: add missing pm debug (Jaroslav Kysela) [1917388]
- ASoC: SOF: sof-pci-dev: add missing Up-Extreme quirk (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: release display power at link_power (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: use hdac_ext fine-grained link management (Jaroslav Kysela) [1917388]
- ASoC: SOF: debug: Fix a potential issue on string buffer termination (Jaroslav Kysela) [1917388]
- ASoC: SOF: add be_hw_params_fixup() for ALH (Jaroslav Kysela) [1917388]
- ASoC: SOF: topology: Prevent NULL pointer dereference with no TLV (Jaroslav Kysela) [1917388]
- ASoC: SOF: intel: hda-loader: use snd_sof_dsp_core_power_down/up APIs (Jaroslav Kysela) [1917388]
- ASoC: SOF: Filter out unneeded core power up/downs (Jaroslav Kysela) [1917388]
- ASoC: SOF: update dsp core power status in common APIs (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda-loader: keep init cores alive (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: use snd_sof_dsp_core_power_up/down API (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: cancel D0i3 work during runtime suspend (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: Enable DMI L1 for trace (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: enable DMI L1 for D0i3-compatible streams (Jaroslav Kysela) [1917388]
- ASoC: SOF: add a pointer to download repo in case FW request fails (Jaroslav Kysela) [1917388]
- ASoC: SOF: SND_INTEL_DSP_CONFIG dependency (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: soundwire: fix select/depend unmet dependencies (Jaroslav Kysela) [1917388]
- ASoC: SOF: intel: Simplify with dma_set_mask_and_coherent() (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: initial support to AlderLake-P (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: tgl: do thorough remove at .shutdown() callback (Jaroslav Kysela) [1917388]
- ASoC: SOF: sof-pci-dev: add .shutdown() callback (Jaroslav Kysela) [1917388]
- ASoC: SOF: add snd_sof_device_shutdown() helper for shutdown (Jaroslav Kysela) [1917388]
- ASoC: SOF: add .shutdown() callback to snd_sof_dsp_ops (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: Avoid checking jack on system suspend (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: Modify existing helper to disable WAKEEN (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: hda: Resume codec to do jack detection (Jaroslav Kysela) [1917388]
- ASoC: SOF: add mutex to protect the dsp_power_state access (Jaroslav Kysela) [1917388]
- ASoC: SOF: Fix spelling mistake in Kconfig "ond" -> "and" (Jaroslav Kysela) [1917388]
- ASoC: SOF: imx: update kernel-doc description (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: add SoundWire support for ADL-S (Jaroslav Kysela) [1917388]
- ASoC: SOF: control: fix cppcheck warning in snd_sof_volume_info() (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: allow for coexistence between SOF and catpt drivers (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: allow for coexistence between SOF and Atom/SST drivers (Jaroslav Kysela) [1917388]
- ASoC: SOF: acpi: add dynamic selection of DSP driver (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: initial support for Alderlake-S (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: fix Kconfig dependency for SND_INTEL_DSP_CONFIG (Jaroslav Kysela) [1917388]
- ASoC: SOF: Intel: fix Kconfig punctuation and wording (Jaroslav Kysela) [1917388]
- ASoC: SOF: Kconfig: fix Kconfig punctuation and wording (Jaroslav Kysela) [1917388]
- ASoC: SOF: imx: fix Kconfig punctuation (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Lenovo Miix 3-830 tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Glavey TM800A550L tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: KMB: Fix random noise at the HDMI output (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: add quirk for new ADL-P Rvp (Jaroslav Kysela) [1917388]
- ASoC: Intel: soc-acpi: add ADL jack-less SoundWire configurations (Jaroslav Kysela) [1917388]
- ASoC: Intel: soc-acpi: add ADL SoundWire base configurations (Jaroslav Kysela) [1917388]
- ASoC: Intel: kbl_da7219_max98927: Fix kabylake_ssp_fixup function (Jaroslav Kysela) [1917388]
- ASoC: Intel: KMB: Constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoc: Intel: board: add BE DAI link for WoV (Jaroslav Kysela) [1917388]
- ASoC: Intel: kbl: Add MST route change to kbl machine drivers (Jaroslav Kysela) [1917388]
- ASoC: Intel: cht_bsw_rt5672: Set card.components string (Jaroslav Kysela) [1917388]
- ASoC: Intel: cht_bsw_rt5672: Add support for Bay Trail CR / SSP0 (Jaroslav Kysela) [1917388]
- ASoC: Intel: Baytrail: Add quirk for the Dell Venue 10 Pro 5055 tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: Unify the thinkpad10 and aegex10 byt-match quirks (Jaroslav Kysela) [1917388]
- ASoC: Intel: Boards: cml_da7219_max98390: add capture stream for echo reference (Jaroslav Kysela) [1917388]
- ASoC: Intel: Fix a typo (Jaroslav Kysela) [1917388]
- ASoC: Intel: Fix a typo (Jaroslav Kysela) [1917388]
- ASoC: Intel: Fix a typo (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Chuwi Hi8 tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: add max98390 echo reference support (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_wm5102: Add jack detect support (Jaroslav Kysela) [1917388]
- ASoC: intel: atom: Remove 44100 sample-rate from the media and deep-buffer DAI descriptions (Jaroslav Kysela) [1917388]
- ASoC: intel: atom: Stop advertising non working S24LE support (Jaroslav Kysela) [1917388]
- ASoC: intel: sof_rt5682: use the topology mclk (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_rt5682: Add ALC1015Q-VB speaker amp support (Jaroslav Kysela) [1917388]
- ASoC: Intel: Skylake: skl-topology: fix -frame-larger-than (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add used AIF to the components string (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Enable jack-detect support on Asus T100TAF (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_wm5102: remove unused static variable (Jaroslav Kysela) [1917388]
- ASoC: Intel: atom: fix kernel-doc (Jaroslav Kysela) [1917388]
- ASoC: Intel: soc-acpi: remove TGL RVP mixed SoundWire/TDM config (Jaroslav Kysela) [1917388]
- ASoC: Intel: soc-acpi: remove unused TGL table with rt5682 only (Jaroslav Kysela) [1917388]
- ASoC: Intel: Skylake: Compile when any configuration is selected (Jaroslav Kysela) [1917388]
- ASoC: Intel: boards: sof-wm8804: add check for PLL setting (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 10-p0XX OVCD current threshold (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Acer One S1002 tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5651: Add quirk for the Jumper EZpad 7 tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Voyo Winpad A15 tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Estar Beauty HD MID 7316R tablet (Jaroslav Kysela) [1917388]
- ASoC: Intel: soc-acpi: add ACPI matching table for HP Spectre x360 (Jaroslav Kysela) [1917388]
- ASoC: intel: sof_sdw: add trace for dai links (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: detect DMIC number based on mach params (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: add mic:dmic and cfg-mics component strings (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: add quirk for HP Spectre x360 convertible (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof-sdw: indent and add quirks consistently (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: reorganize quirks by generation (Jaroslav Kysela) [1917388]
- ASoC: Intel: boards: max98373: get dapm from cpu_dai (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_wm5102: Add machine driver for BYT/WM5102 (Jaroslav Kysela) [1917388]
- ASoC: Intel: Add DMI quirk table to soc_intel_is_byt_cr() (Jaroslav Kysela) [1917388]
- ASoC: Intel: KMB: Support IEC958 encoded PCM format (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU 0A3E (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU 0A32 (Jaroslav Kysela) [1917388]
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU 0A5E (Jaroslav Kysela) [1917388]
- ASoC: Intel: remove unneeded semicolon (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Wake up device before configuring SSP port (Jaroslav Kysela) [1917388]
- ASoC: Intel: remove duplicate MODULE_LICENSE/DESCRIPTION tags (Jaroslav Kysela) [1917388]
- ASoC: Intel: adl: remove sof_fw_filename setting in ADL snd_soc_acpi_mach (Jaroslav Kysela) [1917388]
- ASoC: Intel: common: add ACPI matching tables for Alder Lake (Jaroslav Kysela) [1917388]
- ASoC: Intel: Skylake: Zero snd_ctl_elem_value (Jaroslav Kysela) [1917388]
- ASoC: Intel: Skylake: skl-topology: Fix OOPs ib skl_tplg_complete (Jaroslav Kysela) [1917388]
- ASoC: intel: skl: Simplify with dma_set_mask_and_coherent() (Jaroslav Kysela) [1917388]
- ASoC: Intel: cht_bsw_nau8824: Move snd_soc_dai_set_tdm_slot call to cht_codec_fixup (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Mele PCG03 Mini PC (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add new BYT_RT5640_NO_INTERNAL_MIC_MAP input-mapping (Jaroslav Kysela) [1917388]
- ASoC: Intel: byt/cht: set pm ops dynamically (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove sst_pdata structure (Jaroslav Kysela) [1917388]
- ASoC: Intel: Make atom components independent of sst-dsp (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove SST-legacy specific constants (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove unused DSP operations (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove SST firmware components (Jaroslav Kysela) [1917388]
- ASoC: Intel: Remove SST ACPI component (Jaroslav Kysela) [1917388]
- ASoC: Intel: Select catpt and deprecate haswell (Jaroslav Kysela) [1917388]
- ASoC: Intel: bdw-5677: Remove haswell-solution specific code (Jaroslav Kysela) [1917388]
- ASoC: Intel: bdw-5650: Remove haswell-solution specific code (Jaroslav Kysela) [1917388]
- ASoC: Intel: broadwell: Remove haswell-solution specific code (Jaroslav Kysela) [1917388]
- ASoC: Intel: haswell: Remove haswell-solution specific code (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Simple sysfs attributes (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Event tracing (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Device driver lifecycle (Jaroslav Kysela) [1917388]
- drivers: provide devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: PCM operations (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Firmware loading and context restore (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Define DSP operations (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Add IPC message handlers (Jaroslav Kysela) [1917388]
- ASoC: Intel: catpt: Implement IPC protocol (Jaroslav Kysela) [1917388]
- ASoC: Intel: Add catpt base members (Jaroslav Kysela) [1917388]
- resource: Introduce resource_intersection() for overlapping resources (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add quirk for ARCHOS Cesium 140 (Jaroslav Kysela) [1917388]
- ASoC: Intel: boards: byt/cht: set card and driver name at run time (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcr_rt5640: Add new BYT_RT5640_NO_SPEAKERS quirk-flag (Jaroslav Kysela) [1917388]
- ASoC: Intel: KMB: Enable DMA transfer mode (Jaroslav Kysela) [1917388]
- ASoC: Intel: keembay: use inclusive language for bclk and fsync (Jaroslav Kysela) [1917388]
- ASoC: Intel: bytcht_es8316: Remove comment about SSP0 being untested (Jaroslav Kysela) [1917388]
- ASoC: rt1015: remove bclk_ratio (Jaroslav Kysela) [1917388]
- ASoC: cs42l73: Add missing regmap use_single config (Jaroslav Kysela) [1917388]
- ASoC: cs53l30: Add missing regmap use_single config (Jaroslav Kysela) [1917388]
- ASoC: sti-sas: add missing MODULE_DEVICE_TABLE (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Regmap must use_single_read/write (Jaroslav Kysela) [1917388]
- ASoC: rt711-sdca: fix the function number of SDCA control for feature unit 0x1E (Jaroslav Kysela) [1917388]
- ASoC: da7219: do not request a new clock consummer reference (Jaroslav Kysela) [1917388]
- ASoC: max98088: fix ni clock divider calculation (Jaroslav Kysela) [1917388]
- ASoC: rt711-sdca: add the notification when volume changed (Jaroslav Kysela) [1917388]
- ASoC: rt711-sdca: change capture switch controls (Jaroslav Kysela) [1917388]
- ASoC: da7219: properly get clk from the provider (Jaroslav Kysela) [1917388]
- ASoC: wcd934x: use the clock provider API (Jaroslav Kysela) [1917388]
- ASoC: adau17x1: Avoid overwriting CHPF (Jaroslav Kysela) [1917388]
- ASoC: ak4458: enable daisy chain (Jaroslav Kysela) [1917388]
- ASoC: rt1015p: add support on format S32_LE (Jaroslav Kysela) [1917388]
- ASoC: rt286: Generalize support for ALC3263 codec (Jaroslav Kysela) [1917388]
- ASoC: rt298: Configure combo jack for headphones (Jaroslav Kysela) [1917388]
- ASoC: rt286: Configure combo jack for headphones (Jaroslav Kysela) [1917388]
- ASoC: sigmadsp: Disable cache mechanism for readbacks (Jaroslav Kysela) [1917388]
- ASoC: rt286: Make RT286_SET_GPIO_* readable and writable (Jaroslav Kysela) [1917388]
- ASoC: rt286: Fix upper byte in DMIC2 configuration (Jaroslav Kysela) [1917388]
- ASoC: ak4458: check reset control status (Jaroslav Kysela) [1917388]
- ASoC: codecs: rt5682: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt715: remove kcontrols which no longer be used (Jaroslav Kysela) [1917388]
- ASoC: rt715: add main capture switch and main capture volume (Jaroslav Kysela) [1917388]
- ASoC: rt715: modification for code simplicity (Jaroslav Kysela) [1917388]
- ASoC: codecs: wcd934x: Fix missing IRQF_ONESHOT as only threaded handler (Jaroslav Kysela) [1917388]
- ASoC: cs35l35: remove unused including <linux/version.h> (Jaroslav Kysela) [1917388]
- ASoC: ak5558: correct reset polarity (Jaroslav Kysela) [1917388]
- ASoC: cs35l36: Fix an error handling path in 'cs35l36_i2c_probe()' (Jaroslav Kysela) [1917388]
- ASoC: cs35l35: Fix an error handling path in 'cs35l35_i2c_probe()' (Jaroslav Kysela) [1917388]
- ASoC: wcd9335: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: rt1019: remove registers to sync with rt1019 datasheet (Jaroslav Kysela) [1917388]
- ASoC: rt711-sdca: Constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: wcd934x: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: rt715-sdca: Constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: tas2770: Constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: cx2072x: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: rt1019: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: codecs: tlv320aic3x: add AIC3106 (Jaroslav Kysela) [1917388]
- ASoC: codecs: wsa881x: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: codecs: Fix runtime PM imbalance in tas2552_probe (Jaroslav Kysela) [1917388]
- ASoC: rt1011: remove pack_id check in rt1011 (Jaroslav Kysela) [1917388]
- ASoC: codecs: tlv320aic3x: add SPI support (Jaroslav Kysela) [1917388]
- ASoC: codecs: tlv320aic3x: move I2C to separated file (Jaroslav Kysela) [1917388]
- ASoC: codecs: tlv320aic3x: rename probe function (Jaroslav Kysela) [1917388]
- ASoC: codecs: tlv320aic3x: move model definitions (Jaroslav Kysela) [1917388]
- ASoC: max98390: Add support for tx slot configuration. (Jaroslav Kysela) [1917388]
- ASoC: ak5558: Fix s/show/slow/ typo (Jaroslav Kysela) [1917388]
- ASoC: tlv320aic32x4: Register clocks before registering component (Jaroslav Kysela) [1917388]
- ASoC: tlv320aic32x4: Increase maximum register in regmap (Jaroslav Kysela) [1917388]
- ASoC: rt5670: Add a rt5670_components() helper (Jaroslav Kysela) [1917388]
- ASoC: rt5670: Add a quirk for the Dell Venue 10 Pro 5055 (Jaroslav Kysela) [1917388]
- ASoC: da732x: simplify code (Jaroslav Kysela) [1917388]
- ASoC: lm49453: fix useless assignment before return (Jaroslav Kysela) [1917388]
- ASoC: mediatek: mt6359: Fix spelling mistake "reate" -> "create" (Jaroslav Kysela) [1917388]
- ASoC: mediatek: mt6359: add MT6359 accdet jack driver (Jaroslav Kysela) [1917388]
- ASoC: max98373: Added 30ms turn on/off time delay (Jaroslav Kysela) [1917388]
- ASoC: max98373: Changed amp shutdown register as volatile (Jaroslav Kysela) [1917388]
- ASoC: wm8960: Remove bitclk relax condition in wm8960_configure_sysclk (Jaroslav Kysela) [1917388]
- ASoC: max98373: Added controls for autorestart config (Jaroslav Kysela) [1917388]
- ASoC: rt1015: Add bclk detection and dc detection (Jaroslav Kysela) [1917388]
- ASoC: wm8960: Fix wrong bclk and lrclk with pll enabled for some chips (Jaroslav Kysela) [1917388]
- ASoC: rt1019: make symbol 'rt1019_i2c_driver' static (Jaroslav Kysela) [1917388]
- ASoC: rt1019: add rt1019 amplifier driver (Jaroslav Kysela) [1917388]
- ASoC: tscs454: remove useless test on PLL disable (Jaroslav Kysela) [1917388]
- ASoC: tlv320dac33: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: tas2770: remove useless initialization (Jaroslav Kysela) [1917388]
- ASoC: tas2562: remove warning on return value (Jaroslav Kysela) [1917388]
- ASoC: tas2562: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: sti-sas: remove unused struct members (Jaroslav Kysela) [1917388]
- ASoC: sigmadsp: align function prototype (Jaroslav Kysela) [1917388]
- ASoC: pcm1681: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: nau8825: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: mt6359: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: mt6358: remove useless initializations (Jaroslav Kysela) [1917388]
- ASoC: max98090: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: hdmi-codec: remove unused spk_mask member (Jaroslav Kysela) [1917388]
- ASoC: hdmi-codec: remove useless initialization (Jaroslav Kysela) [1917388]
- ASoC: hdac_hdmi: align function arguments (Jaroslav Kysela) [1917388]
- ASoC: hdac_hdmi: remove useless initializations (Jaroslav Kysela) [1917388]
- ASoC: da7219-aad: remove useless initialization (Jaroslav Kysela) [1917388]
- ASoC: cx2070x: remove duplicate else branch (Jaroslav Kysela) [1917388]
- ASoC: cx2070x: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: adau1977: remove useless return (Jaroslav Kysela) [1917388]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 177 (Jaroslav Kysela) [1917388]
- ASoC: ad1836: remove useless return (Jaroslav Kysela) [1917388]
- ASoC: ab8500-codec: remove useless structure (Jaroslav Kysela) [1917388]
- ASoC: rt711: add snd_soc_component remove callback (Jaroslav Kysela) [1917388]
- ASoC: rt5659: Update MCLK rate in set_sysclk() (Jaroslav Kysela) [1917388]
- ASoC: rt5640: Rename 'Mono DAC Playback Volume' to 'DAC2 Playback Volume' (Jaroslav Kysela) [1917388]
- ASoC: rt1015p: add acpi device id for rt1015p (Jaroslav Kysela) [1917388]
- ASoC: wm_hubs: align function prototype (Jaroslav Kysela) [1917388]
- ASoC: wm_adsp: simplify return value (Jaroslav Kysela) [1917388]
- ASoC: wm8996: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: wm8994: align function prototype (Jaroslav Kysela) [1917388]
- ASoC: wm8978: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: wm8958-dsp2: rename local 'control' arrays (Jaroslav Kysela) [1917388]
- ASoC: arizona: fix function argument (Jaroslav Kysela) [1917388]
- ASoC: wm2200: remove unused structure (Jaroslav Kysela) [1917388]
- ASoC: rt5682: add delay time of workqueue to control next IRQ event (Jaroslav Kysela) [1917388]
- ASoC: rt715-sdca: Remove unused including <linux/version.h> (Jaroslav Kysela) [1917388]
- ASoC: rt715-sdca: Fix return value check in rt715_sdca_sdw_probe() (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Set clock source for both ways of stream (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Provide finer control on playback path (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Disable regulators if probe fails (Jaroslav Kysela) [1917388]
- ASoC: cs42l42: Remove power if the driver is being removed (Jaroslav Kysela) [1917388]
- ASoC: rt711-sdca: Add RT711 SDCA vendor-specific driver (Jaroslav Kysela) [1917388]
- ASoC: rt5645: The ALC3270 variant does not have a headset-mic pin (Jaroslav Kysela) [1917388]
- ASoC: rt5645: Move rt5645_platform_data to sound/soc/codecs/rt5645.c (Jaroslav Kysela) [1917388]
- ASoC: codecs/jz4770: Remove superfluous error message (Jaroslav Kysela) [1917388]
- ASoC: rt715-sdca: Add RT715 sdca vendor-specific driver (Jaroslav Kysela) [1917388]
- ASoC: wm8962: Relax bit clock divider searching (Jaroslav Kysela) [1917388]
- ASoC: rt1316: Fix return value check in rt1316_sdw_probe() (Jaroslav Kysela) [1917388]
- ASoC: sgtl5000: Fix identation of .driver elements (Jaroslav Kysela) [1917388]
- ASoC: codec: Omit superfluous error message in jz4760_codec_probe() (Jaroslav Kysela) [1917388]
- ASoC: sigmadsp-regmap: fix kernel-doc warning (Jaroslav Kysela) [1917388]
- ASoC: rt5631: fix kernel-doc warning (Jaroslav Kysela) [1917388]
- ASoC: jz4760: fix set but not used warning (Jaroslav Kysela) [1917388]
- ASoC: cs4270: fix kernel-doc (Jaroslav Kysela) [1917388]
- ASoC: rt5682: remove useless initialization (Jaroslav Kysela) [1917388]
- ASoC: rt5682: remove useless assignments (Jaroslav Kysela) [1917388]
- ASoC: rt5682: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5677: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: rt5677: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5670: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5668: remove useless assignments (Jaroslav Kysela) [1917388]
- ASoC: rt5668: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5665: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5663: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5660: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5659: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5651: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: rt5651: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5645: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt5645: use logical OR (Jaroslav Kysela) [1917388]
- ASoC: rt5640: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt1308: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt1305: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt1016: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt1015: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt1011: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: rt1011: remove redundant test (Jaroslav Kysela) [1917388]
- ASoC: rt1011: use logical OR (Jaroslav Kysela) [1917388]
- ASoC: wm8524: Do not print probe defer error (Jaroslav Kysela) [1917388]
- ASoC: codecs: nau8825: fix kernel-doc (Jaroslav Kysela) [1917388]
- ASoC: rt1316: Add RT1316 SDCA vendor-specific driver (Jaroslav Kysela) [1917388]
- ASoc: rt5631: Constify static struct coeff_clk_div (Jaroslav Kysela) [1917388]
- ASoC: rt*: Constify static struct acpi_device_id (Jaroslav Kysela) [1917388]
- ASoC: rt*: Constify static struct snd_soc_dai_ops (Jaroslav Kysela) [1917388]
- ASoC: rt*: Constify static struct sdw_slave_ops (Jaroslav Kysela) [1917388]
- ASoC: wcd934x: remove useless return (Jaroslav Kysela) [1917388]
- ASoC: wcd9335: clarify return value (Jaroslav Kysela) [1917388]
- ASoC: wcd-clsh-v2: align function prototypes (Jaroslav Kysela) [1917388]
- ASoC: codecs: wcd934x: add a sanity check in set channel map (Jaroslav Kysela) [1917388]
- ASoC: es8316: Simplify adc_pga_gain_tlv table (Jaroslav Kysela) [1917388]
- ASoC: sgtl5000: set DAP_AVC_CTRL register to correct default value on probe (Jaroslav Kysela) [1917388]
- ASoC: rt5651: Fix dac- and adc- vol-tlv values being off by a factor of 10 (Jaroslav Kysela) [1917388]
- ASoC: rt5640: Fix dac- and adc- vol-tlv values being off by a factor of 10 (Jaroslav Kysela) [1917388]
- ASoC: rt5670: Add emulated 'DAC1 Playback Switch' control (Jaroslav Kysela) [1917388]
- ASoC: rt5670: Remove ADC vol-ctrl mute bits poking from Sto1 ADC mixer settings (Jaroslav Kysela) [1917388]
- ASoC: rt5670: Remove 'HP Playback Switch' control (Jaroslav Kysela) [1917388]
- ASoC: rt5670: Remove 'OUT Channel Switch' control (Jaroslav Kysela) [1917388]
- ASoC: rt1015: fix i2c communication error (Jaroslav Kysela) [1917388]
- ASoC: codec: Add driver for JZ4760 internal codec (Jaroslav Kysela) [1917388]
- ASoC: codec/ingenic: Depend on MACH_INGENIC (Jaroslav Kysela) [1917388]
- ASoC: codec: hdmi-codec: Support IEC958 encoded PCM format (Jaroslav Kysela) [1917388]
- ASoC: rt5682: Fix panic in rt5682_jack_detect_handler happening during system shutdown (Jaroslav Kysela) [1917388]
- ASoC: rt5682: do nothing in rt5682_suspend/resume in sdw mode (Jaroslav Kysela) [1917388]
- ASoC: rt5682-sdw: cancel_work_sync() in .remove and .suspend (Jaroslav Kysela) [1917388]
- ASoC: rt711-sdw: use cancel_work_sync() for .remove (Jaroslav Kysela) [1917388]
- ASoC: rt700-sdw: use cancel_work_sync() in .remove as well as .suspend (Jaroslav Kysela) [1917388]
- ASoC: mt6359: reduce log verbosity for optional DT properties (Jaroslav Kysela) [1917388]
- ASoC: codecs: add missing max_register in regmap config (Jaroslav Kysela) [1917388]
- ASoC: cpcap: fix microphone timeslot mask (Jaroslav Kysela) [1917388]
- ASoC: rt5659: Add Kconfig prompt (Jaroslav Kysela) [1917388]
- ASoC: max98373: Fixes a typo in max98373_feedback_get (Jaroslav Kysela) [1917388]
- ASoC: ak4458: correct reset polarity (Jaroslav Kysela) [1917388]
- ASoC: rt5682: remove connection with LDO2 in DAPM graph (Jaroslav Kysela) [1917388]
- ASoC: ml26124: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: lm49453: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: inno_rk3036: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: cx2072x: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: alc5632: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: ab8500: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: lochnagar-sc: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: mt6660: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: mc13783: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: sgtl5000: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: ssm2602: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: zl38060: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: jz4740: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: ak*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: tscs*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: max*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: es*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: da*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: nau*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: rt*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: tlv*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: wm*: sync parameter naming (rate/sample_bits) (Jaroslav Kysela) [1917388]
- ASoC: remove sirf prima/atlas drivers (Jaroslav Kysela) [1917388]
- ASoC: codecs: soundwire: increase resume timeout (Jaroslav Kysela) [1917388]
- ASoC: es8316: Fix possible NULL pointer deref in es8316_disable_jack_detect() (Jaroslav Kysela) [1917388]
- ASoC: rt5682: enable fast discharge for headset unplugging (Jaroslav Kysela) [1917388]
- ASoC: rt5682: fix getting the wrong device id when the suspend_stress_test (Jaroslav Kysela) [1917388]
- ASoC: rt5645: Enable internal microphone and JD on ECS EF20 (Jaroslav Kysela) [1917388]
- ASoC: rt5645: add inv_hp_det flag (Jaroslav Kysela) [1917388]
- ASoC: rt5645: Add ACPI-defined GPIO for ECS EF20 series (Jaroslav Kysela) [1917388]
- ASoC: rt5645: Introduce mapping for ACPI-defined GPIO (Jaroslav Kysela) [1917388]
- ASoC: rt1015: re-calibrate again when resuming (Jaroslav Kysela) [1917388]
- ASoC: rt5645: Remove the redundant delay time (Jaroslav Kysela) [1917388]
- ASoC: rt1015: remove unneeded variables in rt1015_priv (Jaroslav Kysela) [1917388]
- ASoC: rt1015: refactor retry loop and rt1015_priv allocation (Jaroslav Kysela) [1917388]
- ASoC: rt1015: return error if any when setting bypass_boost (Jaroslav Kysela) [1917388]
- ASoC: rt1015: save boost_mode only if valid (Jaroslav Kysela) [1917388]
- ASoC: rt1015: sort header inclusions (Jaroslav Kysela) [1917388]
- ASoC: Intel: common: Fix some typos (Jaroslav Kysela) [1917388]
- ASoC: soc.h: remove for_each_rtd_dais_rollback() (Jaroslav Kysela) [1917388]
- ASoC: soc.h: return error if multi platform at snd_soc_fixup_dai_links_platform_name() (Jaroslav Kysela) [1917388]
- ASoC: soc.h: fixup return timing for snd_soc_fixup_dai_links_platform_name() (Jaroslav Kysela) [1917388]
- ASoC: soc.h: add asoc_link_to_cpu/codec/platform() macro (Jaroslav Kysela) [1917388]
- ASoC: add soc-jack.h (Jaroslav Kysela) [1917388]
- ASoC: soc-dai.h: Align the word of comment for SND_SOC_DAIFMT_CBC_CFC (Jaroslav Kysela) [1917388]
- ASoC: soc-core: fix always-false condition (Jaroslav Kysela) [1917388]
- ASoC: soc-core: fix signed/unsigned issue (Jaroslav Kysela) [1917388]
- ASoC: soc-acpi: remove useless initialization (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: ignore dummy-DAI at soc_pcm_params_symmetry() (Jaroslav Kysela) [1917388]
- ASoC: soc-utils: add snd_soc_component_is_dummy() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate DAI name if soc_pcm_params_symmetry() failed (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: don't use "name" on __soc_pcm_params_symmetry() macro (Jaroslav Kysela) [1917388]
- ASoC: core: Don't set platform name when of_node is set (Jaroslav Kysela) [1917388]
- ASoC: soc-compress: lock pcm_mutex to resolve lockdep error (Jaroslav Kysela) [1917388]
- ASoC: soc-core: use device_unregister() if rtd allocation failed (Jaroslav Kysela) [1917388]
- ASoC: soc-core: add comment for rtd freeing (Jaroslav Kysela) [1917388]
- ASoC: soc-component: Add snd_soc_pcm_component_ack (Jaroslav Kysela) [1917388]
- ASoC: don't indicate error message for snd_soc_[pcm_]component_xxx() (Jaroslav Kysela) [1917388]
- ASoC: don't indicate error message for snd_soc_[pcm_]dai_xxx() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: don't indicate error message for dpcm_be_dai_hw_free() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: don't indicate error message for soc_pcm_hw_free() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_fe/be_dai_prepare() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_fe/be_dai_hw_params() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_fe/be_dai_startup() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_run_update_startup/shutdown() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_apply_symmetry() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_be_dai_trigger() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at dpcm_path_get() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at soc_pcm_prepare() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at soc_pcm_hw_params() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: indicate error message at soc_pcm_open() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: share DPCM BE DAI stop operation (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: remove unneeded !rtd->dai_link check (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: fixup dpcm_be_dai_startup() user count (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_hw_sanity_check() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_pcm_update_symmetry() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: direct copy at snd_soc_set_runtime_hwparams() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_cpu/codec_dai_name() macro (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: check DAI activity under soc_pcm_apply_symmetry() (Jaroslav Kysela) [1917388]
- ASoC: soc-core: fix DMI handling (Jaroslav Kysela) [1917388]
- ASoC: soc-dai: fix kernel-doc (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add error log (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: remove shadowing variable (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: remove redundant assignment (Jaroslav Kysela) [1917388]
- ASoC: soc-ops: remove useless assignment (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: unpack dpcm_set_fe_runtime() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add dpcm_runtime_setup() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add dpcm_runtime_setup_fe() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: unpack dpcm_init_runtime_hw() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: remove strange format storing (Jaroslav Kysela) [1917388]
- ASoC: soc-core: Prevent warning if no DMI table is present (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: fix hw param limits calculation for multi-DAI (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: fix hwparams min/max init for dpcm (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_pcm_hw_update_format() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_pcm_hw_update_chan() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_pcm_hw_update_rate() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: change error message to debug message (Jaroslav Kysela) [1917388]
- ASoC: dapm: use component prefix when checking widget names (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: fixup snd_pcm_limit_hw_rates() timing (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: use snd_pcm_hardware at dpcm_runtime_merge_xxx() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_create_pcm() and simplify soc_new_pcm() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_get_playback_capture() and simplify soc_new_pcm() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: tidyup pcm setting (Jaroslav Kysela) [1917388]
- ASoC: soc-component: fix undefined reference to __ffssi2 (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_read/write_field() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: cleanup soc_pcm_params_symmetry() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: cleanup soc_pcm_apply_symmetry() (Jaroslav Kysela) [1917388]
- ASoC: soc-dai.h: remove symmetric_rates/samplebits (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_pcm_set_dai_params() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add dpcm_set_be_update_state() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: move dpcm_set_fe_update_state() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: Fix an uninitialized error code (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: return correct -ERRNO in failure path (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: disconnect BEs if the FE is not ready (Jaroslav Kysela) [1917388]
- ASoC: dapm: remove widget from dirty list on free (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: care trigger rollback (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: remove dpcm_do_trigger() (Jaroslav Kysela) [1917388]
- ASoC: pcm: send DAPM_STREAM_STOP event in dpcm_fe_dai_shutdown (Jaroslav Kysela) [1917388]
- ASoC: soc-core: tidyup jack.h (Jaroslav Kysela) [1917388]
- ASoC: soc-core: add soc_dapm_suspend_resume() (Jaroslav Kysela) [1917388]
- ASoC: soc-core: add soc_playback_digital_mute() (Jaroslav Kysela) [1917388]
- ASoC: soc-compress: add soc_compr_clean() and call it from soc_compr_open/free() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add mark for snd_soc_link_compr_startup/shutdown() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add mark for snd_soc_component_compr_open/free() (Jaroslav Kysela) [1917388]
- ASoC: soc-dai: add mark for snd_soc_dai_compr_startup/shutdown() (Jaroslav Kysela) [1917388]
- ASoC: soc-compress: move soc_compr_free() next to soc_compr_open() (Jaroslav Kysela) [1917388]
- ASoC: pcm: call snd_soc_dapm_stream_stop() in soc_pcm_hw_clean (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_get_metadata() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_set_metadata() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_copy() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_pointer() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_ack() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_get_codec_caps() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_get_caps() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_get_params() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_set_params() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_trigger() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_free() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add snd_soc_component_compr_open() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: Get all BEs along DAPM path (Jaroslav Kysela) [1917388]
- ASoC: soc-core: Fix component name_prefix parsing (Jaroslav Kysela) [1917388]
- ASoC: soc-compress: assume SNDRV_PCM_STREAM_xxx and SND_COMPRESS_xxx are same (Jaroslav Kysela) [1917388]
- ASoC: soc-compress: tidyup STREAM vs COMPRESS (Jaroslav Kysela) [1917388]
- ASoC: soc-topology: clarify expression (Jaroslav Kysela) [1917388]
- ASoC: sync parameter naming : rate / sample_bits (Jaroslav Kysela) [1917388]
- ASoC: topology: Check if ops is set before dereference (Jaroslav Kysela) [1917388]
- ASoC: topology: Ensure that needed parameters are set (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: add soc_pcm_hw_clean() and call it from soc_pcm_hw_params/free() (Jaroslav Kysela) [1917388]
- ASoC: soc-dai: add mark for snd_soc_dai_hw_params/free() (Jaroslav Kysela) [1917388]
- ASoC: soc-component: add mark for snd_soc_pcm_component_hw_params/free() (Jaroslav Kysela) [1917388]
- ASoC: soc-link: add mark for snd_soc_link_hw_params/free() (Jaroslav Kysela) [1917388]
- ASoC: soc-pcm: move soc_pcm_hw_free() next to soc_pcm_hw_params() (Jaroslav Kysela) [1917388]
- ASoC: dapm: use semicolons rather than commas to separate statements (Jaroslav Kysela) [1917388]
- ASoC: dmaengine: Document support for TX only or RX only streams (Jaroslav Kysela) [1917388]
- ASoC: soc-core: use devm_snd_soc_register_card() (Jaroslav Kysela) [1917388]
- ALSA: usb: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix control 'access overflow' errors from chmap (Jaroslav Kysela) [1917388]
- ALSA: line6: Fix racy initialization of LINE6 MIDI (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Disable sample read check if firmware doesn't give back (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: scarlett2: snd_scarlett_gen2_controls_create() can be static (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: scarlett2: Improve driver startup messages (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: scarlett2: Fix device hang with ehci-pci (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: fix control-request direction (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix potential out-of-bounce access in MIDI EP parser (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Validate MS endpoint descriptors (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add dB range mapping for Sennheiser Communications Headset PC 8 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Remove redundant assignment to len (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix implicit sync clearance at stopping stream (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Generic application of implicit fb to Roland/BOSS devices (Jaroslav Kysela) [1917388]
- Revert "ALSA: usb-audio: Add support for many Roland devices..." (Jaroslav Kysela) [1917388]
- ALSA: usb: midi: don't return -ENOMEM when usb_urb_ep_type_check fails (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Re-apply implicit feedback mode to Pioneer devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: DJM-750: ensure format is set (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add support for many Roland devices' implicit feedback quirks (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Apply implicit feedback mode for BOSS devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Explicitly set up the clock selector (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add MIDI quirk for Vox ToneLab EX (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Skip probe of UA-101 devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Drop implicit fb quirk entries dubbed for capture (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit feeback support for the BOSS GT-1 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add error checks for usb_driver_claim_interface() calls (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Apply sample rate quirk to Logitech Connect (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Check connector value on resume (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Carve out connector value checking into a helper (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix unintentional sign extension issue (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Apply the control quirk to Plantronics headsets (Jaroslav Kysela) [1917388]
- ALSA: usb: Add Plantronics C320-M USB ctrl msg delay quirk (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix "cannot get freq eq" errors on Dell AE515 sound bar (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: fix Pioneer DJM-850 control label info (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Configure Pioneer DJM-850 samplerate (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Declare Pioneer DJM-850 mixer controls (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add Pioneer DJM-850 to quirks-table (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix Pioneer DJM devices URB_CONTROL request direction to set samplerate (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: use Corsair Virtuoso mapping for Corsair Virtuoso SE (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: generate midi streaming substream names from jack names (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: use usb headers rather than define structs locally (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Allow modifying parameters with succeeding hw_params calls (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Drop bogus dB range in too low level (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Don't abort even if the clock rate differs (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit fb quirk for BOSS GP-10 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add quirk for RC-505 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Don't avoid stopping the stream at disconnection (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: More strict state change in EP (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Handle invalid running state at releasing EP (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: add mixer quirks for Pioneer DJM-900NXS2 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add DJM750 to Pioneer mixer quirk (Jaroslav Kysela) [1917388]
- ALSA: Convert strlcpy to strscpy when return value is unused (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix PCM buffer allocation in non-vmalloc mode (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Correct document for snd_usb_endpoint_free_all() (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add DJM-450 to the quirks table (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add DJM450 to Pioneer format quirk (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: workaround for iface reset issue (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix "RANGE setting not yet supported" errors (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Skip the clock selector inquiry for single connections (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix hw constraints dependencies (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add support for Pioneer DJM-750 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Avoid implicit feedback on Pioneer devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Set sample rate for all sharing EPs on UAC1 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix UAC1 rate setup for secondary endpoints (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Convert the last strlcpy() usage (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Convert remaining strlcpy() to strscpy() (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Always apply the hw constraints for implicit fb sync (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix implicit feedback sync setup for Pioneer devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Annotate the endpoint index in audioformat (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Avoid unnecessary interface re-setup (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Choose audioformat of a counter-part substream (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix the missing endpoints creations for quirks (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add quirk for BOSS AD-10 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix UBSAN warnings for MIDI jacks (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add alias entry for ASUS PRIME TRX40 PRO-S (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add VID to support native DSD reproduction on FiiO devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix potential out-of-bounds shift (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit fb support for Steinberg UR22 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add support for Pioneer DJ DDJ-RR controller (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: US16x08: fix value count for level meters (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix MOTU M-Series quirks (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix quirks for other BOSS devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit_fb module option (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add generic implicit fb parsing (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Factor out the implicit feedback quirk code (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Quirk for BOSS GT-001 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Show sync endpoint information in proc outputs (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Use unsigned char for iface and altsettings fields (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Replace slave/master terms (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Simplify rate_min/max and rates set up (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Unify the code for the next packet size calculation (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Drop unneeded snd_usb_substream fields (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Refactoring endpoint URB deactivation (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Use atomic_t for endpoint use_count (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Constify audioformat pointer references (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix possible stall of implicit fb packet ring-buffer (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Refactor endpoint management (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Fix EP matching for continuous rates (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Always set up the parameters after resume (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add quirk for Pioneer DJ DDJ-SR2 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Set callbacks via snd_usb_endpoint_set_callback() (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Stop both endpoints properly at error (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Simplify snd_usb_init_pitch() arguments (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Simplify snd_usb_init_sample_rate() arguments (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Don't set altsetting before initializing sample rate (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Pass snd_usb_audio object to quirk functions (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add snd_usb_get_host_interface() helper (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Drop keep_interface flag again (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Create endpoint objects at parsing phase (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Avoid doubly initialization for implicit fb (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Drop debug.h (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Simplify hw_params rules (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add hw constraint for implicit fb sync (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Move snd_usb_autoresume() call out of setup_hw_info() (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Track implicit fb sync endpoint in audioformat list (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Improve some debug prints (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Set and clear sync EP link properly (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add snd_usb_get_endpoint() helper (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Check implicit feedback EP generically for UAC2 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Check valid altsetting at parsing rates for UAC2/3 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Don't call usb_set_interface() at trigger callback (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Handle discrete rates properly in hw constraints (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add delay quirk for all Logitech USB devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Use ALC1220-VB-DT mapping for ASUS ROG Strix TRX40 mobo (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit feedback quirk for Qu-16 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit feedback quirk for MODX (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: add usb vendor id as DSD-capable for Khadas devices (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add implicit feedback quirk for Zoom UAC-2 (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Line6 Pod Go interface requires static clock rate quirk (Jaroslav Kysela) [1917388]
- ALSA: usb-audio: Add mixer support for Pioneer DJ DJM-250MK2 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: reset eapd coeff to default value for alc287 (Jaroslav Kysela) [1917388]
- ALSA: hda/hdmi: Cancel pending works before suspend (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132: Fix compile warning without PCI (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132: Move unsol callback setups to parser (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132: make some const arrays static, makes object smaller (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Add ZxR surround DAC setup. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Add 8051 PLL write helper functions. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Remove now unnecessary DSP setup functions. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Ensure DSP is properly setup post-firmware download. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Add 8051 exram helper functions. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Add stream port remapping function. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Reset codec upon initialization. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Change Input Source enum strings. (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132 - Fix AE-5 rear headphone pincfg. (Jaroslav Kysela) [1917388]
- ALSA: hda: Reinstate runtime_allow() for all hda controllers (Jaroslav Kysela) [1917388]
- ACPI: Test for ACPI_SUCCESS rather than !ACPI_FAILURE (Jaroslav Kysela) [1917388]
- ALSA: hda: Flush pending unsolicited events before suspend (Jaroslav Kysela) [1917388]
- ALSA: hda: Re-add dropped snd_poewr_change_state() calls (Jaroslav Kysela) [1917388]
- ALSA: hda: Add missing sanity checks in PM prepare/complete callbacks (Jaroslav Kysela) [1917388]
- ALSA: hda: Separate runtime and system suspend (Jaroslav Kysela) [1917388]
- ALSA: hda: update the power_state during the direct-complete (Jaroslav Kysela) [1917388]
- ALSA: hda: Balance runtime/system PM if direct-complete is disabled (Jaroslav Kysela) [1917388]
- ALSA: hda: Refactor codec PM to use direct-complete optimization (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Set Initial DMIC volume to -26 dB (Jaroslav Kysela) [1917388]
- ALSA: hda: Fix a regression in Capture Switch mixer read (Jaroslav Kysela) [1917388]
- ALSA: hda: Add AlderLake-M PCI ID (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP Zbook Fury 17 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP Zbook Fury 15 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP Zbook G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 855 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Chain in pop reduction fixup for ThinkStation P340 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: the bass speaker can't output sound on Yoga 9i (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Headphone volume is controlled by Front mixer (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add some CLOVE SSIDs of ALC293 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add fixup for HP Spectre x360 15-df0xxx (Jaroslav Kysela) [1917388]
- ALSA: hda: fixup headset for ASUS GU502 laptop (Jaroslav Kysela) [1917388]
- ALSA: hda: Fix for mute key LED for HP Pavilion 15-CK0xx (Jaroslav Kysela) [1917388]
- ALSA: hda: generic: change the DAC ctl name for LO+SPK or LO+HP (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add fixup for HP OMEN laptop (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Fix speaker amp on HP Envy AiO 32 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Fix silent headphone output on ASUS UX430UA (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: ALC285 Thinkpad jack pin quirk is unreachable (Jaroslav Kysela) [1917388]
- ALSA: hda/conexant: Re-order CX5066 quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Remove redundant entry for ALC861 Haier/Uniwill devices (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC662 quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order remaining ALC269 quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC269 Lenovo quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC269 Sony quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC269 ASUS quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC269 Dell quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC269 Acer quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC269 HP quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC882 Clevo quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC882 Sony quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Re-order ALC882 Acer quirk table entries (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add quirk for Intel Clevo PCx0Dx (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Use CS8409 filter to fix abnormal sounds on Bullseye (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Set Initial DMIC volume for Bullseye to -26 dB (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix static noise on ALC285 Lenovo laptops (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook 845 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek - Headset Mic issue on HP platform (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: GA503 use same quirks as GA401 (Jaroslav Kysela) [1917388]
- ALSA: hda/hdmi: fix race in handling acomp ELD notification at resume (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 445 G7 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add quirk for Lenovo Ideapad S740 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mic boost on Intel NUC 8 (Jaroslav Kysela) [1917388]
- ALSA: HDA: Add access description in __snd_hda_add_vmaster (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Fix speaker amp setup on Acer Aspire E1 (Jaroslav Kysela) [1917388]
- ALSA: hda/conexant: Apply quirk for another HP ZBook G5 model (Jaroslav Kysela) [1917388]
- ALSA: HDA - remove the custom implementation for the audio LED trigger (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 640 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/hdmi: fix max DP-MST dev_num for Intel TGL+ platforms (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: call alc_update_headset_mode() in hp_automute_hook (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix a determine_headset_type issue for a Dell AIO (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 850 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 440 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Make CS8409 driver more generic by using fixups. (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Fix CS42L42 Headset Mic volume control name (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Cleanup patch_cirrus.c code. (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Add error handling into CS8409 I2C functions (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 840 G8 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: apply pin quirk for XiaomiNotebook Pro (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Apply headset-mic quirks for Xiaomi Redmibook Air (Jaroslav Kysela) [1917388]
- ALSA: hda: generic: Fix the micmute led init state (Jaroslav Kysela) [1917388]
- ALSA: hda/ca0132: Add Sound BlasterX AE-5 Plus support (Jaroslav Kysela) [1917388]
- ALSA: hda: Drop the BATCH workaround for AMD controllers (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Add Headphone and Headset MIC Volume Control (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Add jack detect interrupt support from CS42L42 companion codec. (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Add support for CS8409 HDA bridge and CS42L42 companion codec. (Jaroslav Kysela) [1917388]
- ALSA: hda/cirrus: Increase AUTO_CFG_MAX_INS from 8 to 18 (Jaroslav Kysela) [1917388]
- ALSA: hda/conexant: Add quirk for mute LED control on HP ZBook G5 (Jaroslav Kysela) [1917388]
- ALSA: hda - bind headset buttons to the headphone jack (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Apply dual codec quirks for MSI Godlike X570 board (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add quirk for Intel NUC 10 (Jaroslav Kysela) [1917388]
- ALSA: hda/hdmi: let new platforms assign the pcm slot dynamically (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Add quirk for Clevo NH55RZQ (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Enable headset mic of Acer SWIFT with ALC256 (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup (Jaroslav Kysela) [1917388]
- ALSA: hda: Add another CometLake-H PCI ID (Jaroslav Kysela) [1917388]
- ALSA: hda/hdmi: Drop bogus check at closing a stream (Jaroslav Kysela) [1917388]
- ALSA: hda: Drop power save deny list entry for Clevo W65_67SB (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: modify EAPD in the ALC886 (Jaroslav Kysela) [1917388]
- ALSA: hda/via: Apply the workaround generically for Clevo machines (Jaroslav Kysela) [1917388]
- ALSA: hda/tegra: Remove unnecessary null-check from hda_tegra_runtime_resume() (Jaroslav Kysela) [1917388]
- ALSA: hda/tegra: Reset hardware (Jaroslav Kysela) [1917388]
- ALSA: hda/tegra: Use clk_bulk helpers (Jaroslav Kysela) [1917388]
- ALSA: hda: Assign boolean values to a bool variable (Jaroslav Kysela) [1917388]
- ALSA: hda: boolean values to a bool variable (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek: Enable headset of ASUS B1400CEPE with ALC256 (Jaroslav Kysela) [1917388]
- ALSA: pci: Simplify with dma_set_mask_and_coherent() (Jaroslav Kysela) [1917388]
- ALSA: hda/via: Add minimum mute flag (Jaroslav Kysela) [1917388]
- ALSA: hda/realtek - Limit int mic boost on Acer Aspire E5-575T (Jaroslav Kysela) [1917388]
- ALSA: hda: Add AlderLake-P PCI ID and HDMI codec vid (Jaroslav Kysela) [1917388]
- ALSA: hda/hdmi - enable runtime pm for CI AMD display audio (Jaroslav Kysela) [1917388]
- ALSA: hda/tegra: fix tegra-hda on tegra30 soc (Jaroslav Kysela) [1917388]
- ALSA: hda: Revert "ALSA: hda: Allow setting preallocation again for x86" (Jaroslav Kysela) [1917388]
- ALSA: hda: Fix spelling mistakes (Jaroslav Kysela) [1917388]
- ALSA: hda: ignore invalid NHLT table (Jaroslav Kysela) [1917388]
- ALSA: hda: intel-nhlt: verify config type (Jaroslav Kysela) [1917388]
- ALSA: hda: fix kernel-doc warnings (Jaroslav Kysela) [1917388]
- ALSA: hda: intel-dsp-config: add Alder Lake support (Jaroslav Kysela) [1917388]
- ALSA: hda: intel-dsp-config: Add SND_INTEL_BYT_PREFER_SOF Kconfig option (Jaroslav Kysela) [1917388]
- ALSA: hda: add link_power op to hdac_bus_ops (Jaroslav Kysela) [1917388]
- ALSA: hda: Constify static attribute_group (Jaroslav Kysela) [1917388]
- ALSA: hda: Use DIV_ROUND_UP()/roundup() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: hda: intel-dsp-config: ignore dsp_driver parameter for PCI legacy devices (Jaroslav Kysela) [1917388]
- ALSA: hda: intel-dsp-config: add Broadwell ACPI DSP driver selection (Jaroslav Kysela) [1917388]
- ALSA: hda: intel-dsp-config: add helper for ACPI DSP driver selection (Jaroslav Kysela) [1917388]
- ALSA: pcm: Fix missing check of the new non-cached buffer type (Jaroslav Kysela) [1917388]
- ALSA: pcm: use dma_can_mmap() to check if a device supports dma_mmap_* (Jaroslav Kysela) [1917388]
- ALSA: timer: Fix master timer notification (Jaroslav Kysela) [1917388]
- ALSA: control led: fix memory leak in snd_ctl_led_register (Jaroslav Kysela) [1917388]
- ALSA: control: Fix racy management of user ctl memory size account (Jaroslav Kysela) [1917388]
- ALSA: control_led - fix the stack usage (control element ops) (Jaroslav Kysela) [1917388]
- ALSA: control - double free in snd_ctl_led_init() (Jaroslav Kysela) [1917388]
- ALSA: control: Add memory consumption limit to user controls (Jaroslav Kysela) [1917388]
- ALSA: control - off by one in store_mode() (Jaroslav Kysela) [1917388]
- ALSA: control led - improve the set_led_id() parser (Jaroslav Kysela) [1917388]
- ALSA: control - add the missing prev_lops2 initialization (Jaroslav Kysela) [1917388]
- ALSA: led control - add sysfs kcontrol LED marking layer (Jaroslav Kysela) [1917388]
- ALSA: control - add sysfs support to the LED trigger module (Jaroslav Kysela) [1917388]
- ALSA: control - add generic LED trigger module as the new control layer (Jaroslav Kysela) [1917388]
- ALSA: control - add layer registration routines (Jaroslav Kysela) [1917388]
- ALSA: control - introduce snd_ctl_notify_one() helper (Jaroslav Kysela) [1917388]
- ALSA: core: remove redundant spin_lock pair in snd_card_disconnect (Jaroslav Kysela) [1917388]
- ALSA: pcm: Fix couple of typos (Jaroslav Kysela) [1917388]
- ALSA: core: avoid -Wempty-body warnings (Jaroslav Kysela) [1917388]
- ALSA: pcm: Add debug print on memory allocation failure (Jaroslav Kysela) [1917388]
- ALSA: core - add missing compress device type to /proc/asound/devices (Jaroslav Kysela) [1917388]
- ALSA: pcm: Use for_each_pcm_substream() macro (Jaroslav Kysela) [1917388]
- ALSA: pcm: Don't call sync_stop if it hasn't been stopped (Jaroslav Kysela) [1917388]
- ALSA: pcm: Assure sync with the pending stop operation at suspend (Jaroslav Kysela) [1917388]
- ALSA: pcm: Call sync_stop at disconnection (Jaroslav Kysela) [1917388]
- ASoC: dmaengine_pcm: add peripheral configuration (Jaroslav Kysela) [1917388]
- ALSA: core: Fix the debugfs removal at snd_card_free() (Jaroslav Kysela) [1917388]
- ALSA: jack: implement software jack injection via debugfs (Jaroslav Kysela) [1917388]
- ALSA: pcm: One more dependency for hw constraints (Jaroslav Kysela) [1917388]
- ALSA: seq: oss: Fix missing error check in snd_seq_oss_synth_make_info() (Jaroslav Kysela) [1917388]
- ALSA: oss: Use DIV_ROUND_CLOSEST() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: core: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [1917388]
- ALSA: core: Remove redundant comments (Jaroslav Kysela) [1917388]
- ALSA: pcm: oss: Fix a few more UBSAN fixes (Jaroslav Kysela) [1917388]
- ALSA: pcm: Clear the full allocated memory at hw_params (Jaroslav Kysela) [1917388]
- ALSA: memalloc: Align buffer allocations in page size (Jaroslav Kysela) [1917388]
- ALSA: pcm: Remove snd_pcm_lib_preallocate_dma_free() (Jaroslav Kysela) [1917388]
- ALSA: core: memalloc: add page alignment for iram (Jaroslav Kysela) [1917388]
- ALSA: pcm: oss: Fix potential out-of-bounds shift (Jaroslav Kysela) [1917388]
- ALSA: rawmidi: Access runtime->avail always in spinlock (Jaroslav Kysela) [1917388]
- ALSA: seq: Use bool for snd_seq_queue internal flags (Jaroslav Kysela) [1917388]
- ALSA: compress: allow pause and resume during draining (Jaroslav Kysela) [1917388]
- ALSA: ctl: fix error path at adding user-defined element set (Jaroslav Kysela) [1917388]
- ALSA: seq: remove useless function (Jaroslav Kysela) [1917388]
- ALSA: fix kernel-doc markups (Jaroslav Kysela) [1917388]
- soundwire: SDCA: add helper macro to access controls (Jaroslav Kysela) [1917388]
- soundwire: add static port mapping support (Jaroslav Kysela) [1917388]
- soundwire: add definition for DPn BlockPackingMode (Jaroslav Kysela) [1917388]
- soundwire: add master quirks for bus clash and parity (Jaroslav Kysela) [1917388]
- soundwire: intel: don't return error when clock stop failed (Jaroslav Kysela) [1917388]
- soundwire: intel: Use kzalloc for allocating only one thing (Jaroslav Kysela) [1917388]
- soundwire: cadence: add status in dev_dbg 'State change' log (Jaroslav Kysela) [1917388]
- soundwire: cadence: adjust verbosity in response handling (Jaroslav Kysela) [1917388]
- soundwire: cadence: fix ACK/NAK handling (Jaroslav Kysela) [1917388]
- soundwire: cadence: reduce timeout on transactions (Jaroslav Kysela) [1917388]
- soundwire: bus: use consistent tests for return values (Jaroslav Kysela) [1917388]
- soundwire: qcom: fix handling of qcom,ports-block-pack-mode (Jaroslav Kysela) [1917388]
- soundwire: intel_init: test link->cdns (Jaroslav Kysela) [1917388]
- soundwire: qcom: handle return correctly in qcom_swrm_transport_params (Jaroslav Kysela) [1917388]
- soundwire: qcom: cleanup internal port config indexing (Jaroslav Kysela) [1917388]
- soundwire: qcom: wait for fifo space to be available before read/write (Jaroslav Kysela) [1917388]
- soundwire: qcom: add static port map support (Jaroslav Kysela) [1917388]
- soundwire: qcom: update port map allocation bit mask (Jaroslav Kysela) [1917388]
- soundwire: stream: fix memory leak in stream config error path (Jaroslav Kysela) [1917388]
- soundwire: qcom: use signed variable for error return (Jaroslav Kysela) [1917388]
- soundwire: qcom: wait for enumeration to be complete in probe (Jaroslav Kysela) [1917388]
- soundwire: qcom: add auto enumeration support (Jaroslav Kysela) [1917388]
- soundwire: export sdw_compare_devid, sdw_extract_slave_id and sdw_slave_add (Jaroslav Kysela) [1917388]
- soundwire: qcom: add support to new interrupts (Jaroslav Kysela) [1917388]
- soundwire: qcom: update register read/write routine (Jaroslav Kysela) [1917388]
- soundwire: qcom: start the clock during initialization (Jaroslav Kysela) [1917388]
- soundwire: qcom: set continue execution flag for ignored commands (Jaroslav Kysela) [1917388]
- soundwire: qcom: add support to missing transport params (Jaroslav Kysela) [1917388]
- soundwire: cadence: only prepare attached devices on clock stop (Jaroslav Kysela) [1917388]
- soundwire: generic_allocation: fix confusion between group and packing (Jaroslav Kysela) [1917388]
- soundwire: bus: Fix device found flag correctly (Jaroslav Kysela) [1917388]
- soundwire: cadence_master: fix kernel-doc (Jaroslav Kysela) [1917388]
- soundwire: stream: remove useless bus initializations (Jaroslav Kysela) [1917388]
- soundwire: stream: remove useless initialization (Jaroslav Kysela) [1917388]
- soundwire: qcom: check of_property_read status (Jaroslav Kysela) [1917388]
- soundwire: intel: remove useless readl (Jaroslav Kysela) [1917388]
- soundwire: generic_bandwidth_allocation: remove useless init (Jaroslav Kysela) [1917388]
- soundwire: bus: remove useless initialization (Jaroslav Kysela) [1917388]
- soundwire: bus: uniquify dev_err() for SCP_INT access (Jaroslav Kysela) [1917388]
- soundwire: bus: demote clock stop prepare log to dev_dbg() (Jaroslav Kysela) [1917388]
- soundwire: bus: clarify dev_err/dbg device references (Jaroslav Kysela) [1917388]
- soundwire: bus: fix confusion on device used by pm_runtime (Jaroslav Kysela) [1917388]
- soundwire: export sdw_write/read_no_pm functions (Jaroslav Kysela) [1917388]
- soundwire: bus: use no_pm IO routines for all interrupt handling (Jaroslav Kysela) [1917388]
- soundwire: bus: use sdw_write_no_pm when setting the bus scale registers (Jaroslav Kysela) [1917388]
- soundwire: bus: use sdw_update_no_pm when initializing a device (Jaroslav Kysela) [1917388]
- soundwire: return earlier if no slave is attached (Jaroslav Kysela) [1917388]
- soundwire: bus: add better dev_dbg to track complete() calls (Jaroslav Kysela) [1917388]
- soundwire: bus: add more details to track failed transfers (Jaroslav Kysela) [1917388]
- soundwire: use consistent format for Slave devID logs (Jaroslav Kysela) [1917388]
- soundwire: bus: test read status (Jaroslav Kysela) [1917388]
- soundwire: bus: use correct driver name in error messages (Jaroslav Kysela) [1917388]
- soundwire: qcom: add missing \n in dev_err() (Jaroslav Kysela) [1917388]
- soundwire: stream: add missing \n in dev_err() (Jaroslav Kysela) [1917388]
- soundwire: cadence: add missing \n in dev_err() (Jaroslav Kysela) [1917388]
- soundwire: bandwidth_allocation: add missing \n in dev_err() (Jaroslav Kysela) [1917388]
- soundwire: intel: add missing \n in dev_err() (Jaroslav Kysela) [1917388]
- soundwire: intel: add master quirks for bus clash and parity (Jaroslav Kysela) [1917388]
- soundwire: bus: handle master quirks for bus clash and parity (Jaroslav Kysela) [1917388]
- soundwire: Intel: add DMI quirk for Dell SKU 0A3E (Jaroslav Kysela) [1917388]
- soundwire: Intel: introduce DMI quirks for HP Spectre x360 Convertible (Jaroslav Kysela) [1917388]
- soundwire: add override addr ops (Jaroslav Kysela) [1917388]
- regmap/SoundWire: sdw: add support for SoundWire 1.2 MBQ (Jaroslav Kysela) [1917388]
- tracing: Fix __print_hex_dump scope (Jaroslav Kysela) [1917388]
- tracing: Use seq_buf_hex_dump() to dump buffers (Jaroslav Kysela) [1917388]
- seq_buf: Add printing formatted hex dumps (Jaroslav Kysela) [1917388]
- powerpc/64: Don't trace code that runs with the soft irq mask unreconciled (Desnes A. Nunes do Rosario) [1921631]
- powerpc/64: Disable irq restore warning for now (Desnes A. Nunes do Rosario) [1921631]
- powerpc/64s: make PACA_IRQ_HARD_DIS track MSR[EE] closely (Desnes A. Nunes do Rosario) [1921631]

* Mon Jul 05 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-321.el8]
- watchdog/hpwdt: New PCI IDs (Joseph Szczypek) [1967765]
- watchdog: hpwdt: Assign boolean values to a bool variable (Joseph Szczypek) [1967765]
- scsi: libfc: Avoid invoking response handler twice if ep is already completed (Chris Leech) [1867301]
- Bluetooth: SMP: Fail if remote and local public keys are identical (Gopal Tiwari) [1965083]
- rq-qos: fix missed wake-ups in rq_qos_throttle try two (Ming Lei) [1972111]
- mm: memcg/slab: disable cache merging for KMALLOC_NORMAL caches (Waiman Long) [1955561]
- mm: memcg/slab: create a new set of kmalloc-cg-<n> caches (Waiman Long) [1955561]
- mm: memcg/slab: properly set up gfp flags for objcg pointer array (Waiman Long) [1955561]
- mm/vmalloc.c:__vmalloc_area_node(): avoid 32-bit overflow (Rafael Aquini) [1970194]
- mm: remove the filename in the top of file comment in vmalloc.c (Rafael Aquini) [1970194]
- mm: cleanup the gfp_mask handling in __vmalloc_area_node (Rafael Aquini) [1970194]
- mm/vmalloc.c: remove unnecessary highmem_mask from parameter of gfpflags_allow_blocking() (Rafael Aquini) [1970194]
- mm/swap: fix pte_same_as_swp() not removing uffd-wp bit when compare (Chris von Recklinghausen) [1945442]
- userfaultfd: hugetlbfs: fix new flag usage in error path (Chris von Recklinghausen) [1945442]
- mm/hugetlb: fix cow where page writtable in child (Chris von Recklinghausen) [1945442]
- ovl: fix reference counting in ovl_mmap error path (Chris von Recklinghausen) [1945442]
- hugetlb: do early cow when page pinned on src mm (Chris von Recklinghausen) [1945442]
- mm: introduce page_needs_cow_for_dma() for deciding whether cow (Chris von Recklinghausen) [1945442]
- hugetlb: convert page_huge_active() HPageMigratable flag (Chris von Recklinghausen) [1945442]
- hugetlb: use page.private for hugetlb specific page flags (Chris von Recklinghausen) [1945442]
- x86/mm: Remove duplicate definition of _PAGE_PAT_LARGE (Chris von Recklinghausen) [1945442]
- mm: hugetlbfs: fix cannot migrate the fallocated HugeTLB page (Chris von Recklinghausen) [1945442]
- mm: hugetlb: fix a race between isolating and freeing page (Chris von Recklinghausen) [1945442]
- mm: hugetlb: remove VM_BUG_ON_PAGE from page_huge_active (Chris von Recklinghausen) [1945442]
- mm: introduce vma_set_file function v5 (Chris von Recklinghausen) [1945442]
- mm: mmap: fix fput in error path v2 (Chris von Recklinghausen) [1945442]
- mm/gup: prevent gup_fast from racing with COW during fork (Chris von Recklinghausen) [1945442]
- mm/gup: reorganize internal_get_user_pages_fast() (Chris von Recklinghausen) [1945442]
- mm: remove src/dst mm parameter in copy_page_range() (Chris von Recklinghausen) [1945442]
- mm: avoid early COW write protect games during fork() (Chris von Recklinghausen) [1945442]
- mm/thp: Split huge pmds/puds if they're pinned when fork() (Chris von Recklinghausen) [1945442]
- mm: Do early cow for pinned pages during fork() for ptes (Chris von Recklinghausen) [1945442]
- mm/fork: Pass new vma pointer into copy_page_range() (Chris von Recklinghausen) [1945442]
- mm: move the copy_one_pte() pte_present check into the caller (Chris von Recklinghausen) [1945442]
- mm: split out the non-present case from copy_one_pte() (Chris von Recklinghausen) [1945442]
- mm/gup: Remove enfornced COW mechanism (Chris von Recklinghausen) [1945442]
- mm/hmm.c: delete duplicated word (Chris von Recklinghausen) [1945442]
- mm/hmm: provide the page mapping order in hmm_range_fault() (Chris von Recklinghausen) [1945442]
- mmap locking API: add mmap_assert_locked() and mmap_assert_write_locked() (Chris von Recklinghausen) [1945442]
- mm/gup: introduce pin_user_pages_locked() (Chris von Recklinghausen) [1945442]
- mm/gup: introduce pin_user_pages_unlocked (Chris von Recklinghausen) [1945442]
- mm: remove the prot argument from vm_map_ram (Chris von Recklinghausen) [1945442]
- mm: remove unmap_vmap_area (Chris von Recklinghausen) [1945442]
- mm: don't return the number of pages from map_kernel_range{,_noflush} (Chris von Recklinghausen) [1945442]
- x86: fix vmap arguments in map_irq_stack (Chris von Recklinghausen) [1945442]
- mm/memory: remove unnecessary pte_devmap case in copy_one_pte() (Chris von Recklinghausen) [1945442]
- mm/hmm: remove the customizable pfn format from hmm_range_fault (Chris von Recklinghausen) [1945442]
- mm/hmm: remove HMM_PFN_SPECIAL (Chris von Recklinghausen) [1945442]
- mm/hmm: make hmm_range_fault return 0 or -1 (Chris von Recklinghausen) [1945442]
- mm/hugetlb: fix build failure with HUGETLB_PAGE but not HUGEBTLBFS (Chris von Recklinghausen) [1945442]
- mm/hmm: return error for non-vma snapshots (Chris von Recklinghausen) [1945442]
- mm/hmm: do not set pfns when returning an error code (Chris von Recklinghausen) [1945442]
- mm/hmm: do not unconditionally set pfns when returning EBUSY (Chris von Recklinghausen) [1945442]
- mm/hmm: use device_private_entry_to_pfn() (Chris von Recklinghausen) [1945442]
- mm/hmm: remove HMM_FAULT_SNAPSHOT (Chris von Recklinghausen) [1945442]
- mm/hmm: remove unused code and tidy comments (Chris von Recklinghausen) [1945442]
- mm/hmm: return the fault type from hmm_pte_need_fault() (Chris von Recklinghausen) [1945442]
- mm/hmm: remove pgmap checking for devmap pages (Chris von Recklinghausen) [1945442]
- mm/hmm: check the device private page owner in hmm_range_fault() (Chris von Recklinghausen) [1945442]
- mm: simplify device private page handling in hmm_range_fault (Chris von Recklinghausen) [1945442]
- mm: merge hmm_vma_do_fault into into hmm_vma_walk_hole_ (Chris von Recklinghausen) [1945442]
- mm/hmm: don't handle the non-fault case in hmm_vma_walk_hole_() (Chris von Recklinghausen) [1945442]
- mm/hmm: simplify hmm_vma_walk_hugetlb_entry() (Chris von Recklinghausen) [1945442]
- mm/hmm: remove the unused HMM_FAULT_ALLOW_RETRY flag (Chris von Recklinghausen) [1945442]
- mm/hmm: don't provide a stub for hmm_range_fault() (Chris von Recklinghausen) [1945442]
- mm/hmm: do not check pmd_protnone twice in hmm_vma_handle_pmd() (Chris von Recklinghausen) [1945442]
- mm/hmm: return -EFAULT when setting HMM_PFN_ERROR on requested valid pages (Chris von Recklinghausen) [1945442]
- mm/hmm: reorganize how !pte_present is handled in hmm_vma_handle_pte() (Chris von Recklinghausen) [1945442]
- mm/hmm: add missing call to hmm_range_need_fault() before returning EFAULT (Chris von Recklinghausen) [1945442]
- mm/hmm: add missing pfns set to hmm_vma_walk_pmd() (Chris von Recklinghausen) [1945442]
- mm/hmm: remove hmm_range_dma_map and hmm_range_dma_unmap (Chris von Recklinghausen) [1945442]
- mm/hmm: make full use of walk_page_range() (Chris von Recklinghausen) [1945442]
- mm/hmm: remove hmm_mirror and related (Chris von Recklinghausen) [1945442]
- mm/hmm: define the pre-processor related parts of hmm.h even if disabled (Chris von Recklinghausen) [1945442]
- mm/hmm: allow hmm_range to be used with a mmu_interval_notifier or hmm_mirror (Chris von Recklinghausen) [1945442]
- mm/hmm: hmm_range_fault() infinite loop (Chris von Recklinghausen) [1945442]
- mm/hmm: hmm_range_fault() NULL pointer bug (Chris von Recklinghausen) [1945442]
- hmm: use mmu_notifier_get/put for 'struct hmm' (Chris von Recklinghausen) [1945442]
- mm/hmm: cleanup the hmm_vma_handle_pmd stub (Chris von Recklinghausen) [1945442]
- mm/hmm: only define hmm_vma_walk_pud if needed (Chris von Recklinghausen) [1945442]
- mm/hmm: cleanup the hmm_vma_walk_hugetlb_entry stub (Chris von Recklinghausen) [1945442]
- mm/hmm: don't abuse pte_index() in hmm_vma_handle_pmd (Chris von Recklinghausen) [1945442]
- mm/hmm: comment on VM_FAULT_RETRY semantics in handle_mm_fault (Chris von Recklinghausen) [1945442]
- mm/hmm: remove the legacy hmm_pfn_* APIs (Chris von Recklinghausen) [1945442]
- mm/hmm: remove the mask variable in hmm_vma_walk_hugetlb_entry (Chris von Recklinghausen) [1945442]
- mm/hmm: remove the page_shift member from struct hmm_range (Chris von Recklinghausen) [1945442]
- mm/hmm: remove superfluous arguments from hmm_range_register (Chris von Recklinghausen) [1945442]
- mm/hmm: remove the unused vma argument to hmm_range_dma_unmap (Chris von Recklinghausen) [1945442]
- mm/hmm: remove hmm_range vma (Chris von Recklinghausen) [1945442]
- mm/hmm: remove hugetlbfs check in hmm_vma_walk_pmd (Chris von Recklinghausen) [1945442]
- mm/hmm: merge hmm_range_snapshot into hmm_range_fault (Chris von Recklinghausen) [1945442]
- mm/hmm: replace the block argument to hmm_range_fault with a flags value (Chris von Recklinghausen) [1945442]
- mm/large system hash: use vmalloc for size > MAX_ORDER when !hashdist (Chris von Recklinghausen) [1945442]
- mm/hmm: update HMM documentation (Chris von Recklinghausen) [1945442]
- mm: remove the HMM config option (Chris von Recklinghausen) [1945442]
- hugetlbfs: on restore reserve error path retain subpool reservation (Chris von Recklinghausen) [1945442]
- mm/vmalloc.c: fix potential memory leak (Chris von Recklinghausen) [1945442]
- mm/vmalloc: separate put pages and flush VM flags (Chris von Recklinghausen) [1945442]
- zsmalloc: switch from alloc_vm_area to get_vm_area (Chris von Recklinghausen) [1945442]
- mm: allow a NULL fn callback in apply_to_page_range (Chris von Recklinghausen) [1945442]
- mm: add a vmap_pfn function (Chris von Recklinghausen) [1945442]
- mm: add a VM_MAP_PUT_PAGES flag for vmap (Chris von Recklinghausen) [1945442]
- mm: update the documentation for vfree (Chris von Recklinghausen) [1945442]
- mm, slub: use kmem_cache_debug_flags() in deactivate_slab() (Chris von Recklinghausen) [1945442]
- mm, slab, slub: clear the slab_cache field when freeing page (Chris von Recklinghausen) [1945442]
- mm: slab: provide krealloc_array() (Chris von Recklinghausen) [1945442]
- mm: slab: clarify krealloc()'s behavior with __GFP_ZERO (Chris von Recklinghausen) [1945442]
- mm/slab_common.c: use list_for_each_entry in dump_unreclaimable_slab() (Chris von Recklinghausen) [1945442]
- mm/slub: make add_full() condition more explicit (Chris von Recklinghausen) [1945442]
- mm/slub: fix missing ALLOC_SLOWPATH stat when bulk alloc (Chris von Recklinghausen) [1945442]
- mm/slub.c: branch optimization in free slowpath (Chris von Recklinghausen) [1945442]
- include/linux/slab.h: fix a typo error in comment (Chris von Recklinghausen) [1945442]
- mm/vmalloc.c: fix a warning while make xmldocs (Chris von Recklinghausen) [1945442]
- mm/userfaultfd: fix memory corruption due to writeprotect (Chris von Recklinghausen) [1945442]
- mm/migrate: fixup setting UFFD_WP flag (Chris von Recklinghausen) [1945442]
- mm/rmap: fixup copying of soft dirty and uffd ptes (Chris von Recklinghausen) [1945442]
- mm/userfaultfd: disable userfaultfd-wp on x86_32 (Chris von Recklinghausen) [1945442]
- userfaultfd: selftests: fix SIGSEGV if huge mmap fails (Chris von Recklinghausen) [1945442]
- mm: do not rely on mm == current->mm in __get_user_pages_locked (Chris von Recklinghausen) [1945442]
- mm: Introduce mm_struct.has_pinned (Chris von Recklinghausen) [1945442]
- mm/gup: might_lock_read(mmap_sem) in get_user_pages_fast() (Chris von Recklinghausen) [1945442]
- mm: enforce that vmap can't map pages executable (Chris von Recklinghausen) [1945442]
- mm: remove map_vm_range (Chris von Recklinghausen) [1945442]
- mm: rename vmap_page_range to map_kernel_range (Chris von Recklinghausen) [1945442]
- mm: remove vmap_page_range_noflush and vunmap_page_range (Chris von Recklinghausen) [1945442]
- mm: only allow page table mappings for built-in zsmalloc (Chris von Recklinghausen) [1945442]
- mm: unexport unmap_kernel_range_noflush (Chris von Recklinghausen) [1945442]
- userfaultfd: selftests: add write-protect test (Chris von Recklinghausen) [1945442]
- userfaultfd: selftests: refactor statistics (Chris von Recklinghausen) [1945442]
- userfaultfd: selftest: fix compiler warning (Chris von Recklinghausen) [1945442]
- hugetlbfs: call VM_BUG_ON_PAGE earlier in free_huge_page() (Chris von Recklinghausen) [1945442]
- userfaultfd: selftest: recycle lock threads first (Chris von Recklinghausen) [1945442]
- userfaultfd: selftest: generalize read and poll (Chris von Recklinghausen) [1945442]
- userfaultfd: selftest: cleanup help messages (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: declare _UFFDIO_WRITEPROTECT conditionally (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: UFFDIO_REGISTER_MODE_WP documentation update (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: don't wake up when doing write protect (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: enabled write protection in userfaultfd API (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: add the writeprotect API to userfaultfd ioctl (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: support write protection for userfault vma range (Chris von Recklinghausen) [1945442]
- khugepaged: skip collapse if uffd-wp detected (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: support swap and page migration (Chris von Recklinghausen) [1945442]
- mm/mprotect.c: fix compilation warning because of unused 'mm' variable (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: add pmd_swp_*uffd_wp() helpers (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: drop _PAGE_UFFD_WP properly when fork (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: apply _PAGE_UFFD_WP bit (Chris von Recklinghausen) [1945442]
- mm: merge parameters for change_protection() (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: add UFFDIO_COPY_MODE_WP (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: userfaultfd_pte/huge_pmd_wp() helpers (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: add WP pagetable tracking to x86 (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: hook userfault handler to write protection fault (Chris von Recklinghausen) [1945442]
- userfaultfd: wp: add helper for writeprotect check (Chris von Recklinghausen) [1945442]
- userfaultfd: untag user pointers (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Fix typo in the Kconfig help text (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Clean up <asm/memtype.h> externs (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Rename <asm/pat.h> => <asm/memtype.h> (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Standardize on memtype_*() prefix for APIs (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Move the memtype related files to arch/x86/mm/pat/ (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Clean up PAT initialization flags (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Harmonize 'struct memtype *' local variable and function parameter use (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Simplify the free_memtype() control flow (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Create fixed width output in /sys/kernel/debug/x86/pat_memtype_list, similar to the E820 debug printouts (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Disambiguate PAT-disabled boot messages (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Update the comments in pat.c and pat_interval.c and refresh the code a bit (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Fix off-by-one bugs in interval tree search (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Rename pat_rbtree.c to pat_interval.c (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Drop the rbt_ prefix from external memtype calls (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Do not pass 'rb_root' down the memtype tree helper functions (Chris von Recklinghausen) [1945442]
- x86/mm/pat: Convert the PAT tree to a generic interval tree (Chris von Recklinghausen) [1945442]
- x86/mm: Tabulate the page table encoding definitions (Chris von Recklinghausen) [1945442]
- x86/mm: Remove the unused set_memory_wt() function (Chris von Recklinghausen) [1945442]
- x86/mm: Remove set_pages_x() and set_pages_nx() (Chris von Recklinghausen) [1945442]
- x86/mm: Remove the unused set_memory_array_*() functions (Chris von Recklinghausen) [1945442]
- x86/mm: Unexport set_memory_x() and set_memory_nx() (Chris von Recklinghausen) [1945442]
- x86/Kconfig: Fix spelling mistake "effectivness" -> "effectiveness" (Chris von Recklinghausen) [1945442]
- x86/mm: Remove unused variable 'old_pte' (Chris von Recklinghausen) [1945442]
- Revert "x86/mm/pat: Rename pat_rbtree.c to pat_interval.c" (Chris von Recklinghausen) [1945442]
- Revert "x86/mm/pat: Move the memtype related files to arch/x86/mm/pat/" (Chris von Recklinghausen) [1945442]
- ipv6: Allow the l3mdev to be a loopback (Antoine Tenart) [1973229]
- vrf: do not push non-ND strict packets with a source LLA through packet taps again (Antoine Tenart) [1965600]
- vrf: packets with lladdr src needs dst at input with orig_iif when needs strict (Antoine Tenart) [1965600]
- ipv6: Fix handling of LLA with VRF and sockets bound to VRF (Antoine Tenart) [1965600]
- ipv6: allow ping to link-local address in VRF (Antoine Tenart) [1965600]
- vrf: mark skb for multicast or link-local as enslaved to VRF (Antoine Tenart) [1965600]
- net: allow traceroute with a specified interface in a vrf (Antoine Tenart) [1965600]
- virtchnl: Enable RSS configure for AVF (Ivan Vecera) [1966954]
- virtchnl: Advertise virtchnl UDP segmentation offload capability (Ivan Vecera) [1966954]
- virtchnl: Allow ignoring opcodes on specific VF (Ivan Vecera) [1966954]
- virtchnl: Fix layout of RSS structures (Ivan Vecera) [1966954]
- virtchnl: Enable FDIR Configure for AVF (Ivan Vecera) [1966954]
- virtchnl: Add missing explicit padding to structures (Ivan Vecera) [1966954]
- virtchnl: use u8 type for a field in the virtchnl_filter struct (Ivan Vecera) [1966954]
- tools headers uapi: Sync tools/include/uapi/linux/perf_event.h (Michael Petlan) [1944685]
- tools headers uapi: Update tools's copy of linux/perf_event.h (Michael Petlan) [1944685]
- bpf: Add size arg to build_id_parse function (Michael Petlan) [1944685]
- bpf: Move stack_map_get_build_id into lib (Michael Petlan) [1944685]
- perf map: Fix error return code in maps__clone() (Michael Petlan) [1944685]
- perf ftrace: Fix access to pid in array when setting a pid filter (Michael Petlan) [1944685]
- perf auxtrace: Fix potential NULL pointer dereference (Michael Petlan) [1944685]
- perf data: Fix error return code in perf_data__create_dir() (Michael Petlan) [1944685]
- perf arm-spe: Avoid potential buffer overrun (Michael Petlan) [1944685]
- perf report: Fix wrong LBR block sorting (Michael Petlan) [1944685]
- perf inject: Fix repipe usage (Michael Petlan) [1944685]
- perf test: Change to use bash for daemon test (Michael Petlan) [1944685]
- perf record: Fix memory leak in vDSO found using ASAN (Michael Petlan) [1944685]
- perf test: Remove now useless failing sub test "BPF relocation checker" (Michael Petlan) [1944685]
- perf daemon: Return from kill functions (Michael Petlan) [1944685]
- perf daemon: Force waipid for all session on SIGCHLD delivery (Michael Petlan) [1944685]
- perf top: Fix BPF support related crash with perf_event_paranoid=3 + kptr_restrict (Michael Petlan) [1944685]
- perf pmu: Validate raw event with sysfs exported format bits (Michael Petlan) [1944685]
- perf synthetic events: Avoid write of uninitialized memory when generating PERF_RECORD_MMAP* records (Michael Petlan) [1944685]
- perf synthetic-events: Fix uninitialized 'kernel_thread' variable (Michael Petlan) [1944685]
- perf auxtrace: Fix auxtrace queue conflict (Michael Petlan) [1944685]
- perf cs-etm: Fix bitmap for option (Michael Petlan) [1944685]
- perf map: Tighten snprintf() string precision to pass gcc check on some 32-bit arches (Michael Petlan) [1944685]
- perf report: Fix -F for branch & mem modes (Michael Petlan) [1944685]
- perf tests x86: Move insn.h include to make sure it finds stddef.h (Michael Petlan) [1944685]
- perf test: Support the ins_lat check in the X86 specific test (Michael Petlan) [1944685]
- perf test: Fix sample-parsing failure on non-x86 platforms (Michael Petlan) [1944685]
- perf archive: Fix filtering of empty build-ids (Michael Petlan) [1944685]
- perf daemon: Fix compile error with Asan (Michael Petlan) [1944685]
- perf stat: Fix use-after-free when -r option is used (Michael Petlan) [1944685]
- libperf: Add perf_evlist__reset_id_hash() (Michael Petlan) [1944685]
- perf stat: Fix wrong skipping for per-die aggregation (Michael Petlan) [1944685]
- tools headers UAPI: Update tools' copy of linux/coresight-pmu.h (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in perf_time_to_tsc test (Michael Petlan) [1944685]
- perf test: Fix cpu map leaks in cpu_map_print test (Michael Petlan) [1944685]
- perf test: Fix a memory leak in thread_map_remove test (Michael Petlan) [1944685]
- perf test: Fix a thread map leak in thread_map_synthesize test (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in switch_tracking test (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in keep_tracking test (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in code_reading test (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in sw_clock_freq test (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in task_exit test (Michael Petlan) [1944685]
- perf test: Fix a memory leak in attr test (Michael Petlan) [1944685]
- perf test: Fix cpu and thread map leaks in basic mmap test (Michael Petlan) [1944685]
- perf tools: Fix event's PMU name parsing (Michael Petlan) [1944685]
- perf daemon: Fix running test for non root user (Michael Petlan) [1944685]
- perf daemon: Fix control fifo permissions (Michael Petlan) [1944685]
- perf build: Fix ccache usage in $(CC) when generating arch errno table (Michael Petlan) [1944685]
- perf tools: Fix documentation of verbose options (Michael Petlan) [1944685]
- perf traceevent: Ensure read cmdlines are null terminated. (Michael Petlan) [1944685]
- perf diff: Don't crash on freeing errno-session on the error path (Michael Petlan) [1944685]
- perf tools: Clean 'generated' directory used for creating the syscall table on x86 (Michael Petlan) [1944685]
- perf build: Move feature cleanup under tools/build (Michael Petlan) [1944685]
- perf tools: Cast (struct timeval).tv_sec when printing (Michael Petlan) [1944685]
- perf buildid-cache: Don't skip 16-byte build-ids (Michael Petlan) [1944685]
- perf buildid-cache: Add test for 16-byte build-id (Michael Petlan) [1944685]
- perf symbol: Remove redundant libbfd checks (Michael Petlan) [1944685]
- perf test: Output the sub testing result in cs-etm (Michael Petlan) [1944685]
- perf test: Suppress logs in cs-etm testing (Michael Petlan) [1944685]
- perf tools: Fix arm64 build error with gcc-11 (Michael Petlan) [1944685]
- perf intel-pt: Add documentation for tracing virtual machines (Michael Petlan) [1944685]
- perf intel-pt: Split VM-Entry and VM-Exit branches (Michael Petlan) [1944685]
- perf intel-pt: Adjust sample flags for VM-Exit (Michael Petlan) [1944685]
- perf intel-pt: Allow for a guest kernel address filter (Michael Petlan) [1944685]
- perf intel-pt: Support decoding of guest kernel (Michael Petlan) [1944685]
- perf machine: Factor out machine__idle_thread() (Michael Petlan) [1944685]
- perf machine: Factor out machines__find_guest() (Michael Petlan) [1944685]
- perf intel-pt: Amend decoder to track the NR flag (Michael Petlan) [1944685]
- perf intel-pt: Retain the last PIP packet payload as is (Michael Petlan) [1944685]
- perf intel_pt: Add vmlaunch and vmresume as branches (Michael Petlan) [1944685]
- perf script: Add branch types for VM-Entry and VM-Exit (Michael Petlan) [1944685]
- perf auxtrace: Automatically group aux-output events (Michael Petlan) [1944685]
- perf test: Fix unaligned access in sample parsing test (Michael Petlan) [1944685]
- perf tools: Support arch specific PERF_SAMPLE_WEIGHT_STRUCT processing (Michael Petlan) [1944685]
- perf intel-pt: Add PSB events (Michael Petlan) [1944685]
- perf intel-pt: Fix IPC with CYC threshold (Michael Petlan) [1944685]
- perf intel-pt: Fix premature IPC (Michael Petlan) [1944685]
- perf intel-pt: Fix missing CYC processing in PSB (Michael Petlan) [1944685]
- perf record: Fix continue profiling after draining the buffer (Michael Petlan) [1944685]
- perf tools: Simplify the calculation of variables (Michael Petlan) [1944685]
- perf vendor events arm64: Add JSON metrics for imx8mp DDR Perf (Michael Petlan) [1944685]
- perf vendor events arm64: Add JSON metrics for imx8mq DDR Perf (Michael Petlan) [1944685]
- perf vendor events arm64: Add JSON metrics for imx8mn DDR Perf (Michael Petlan) [1944685]
- perf vendor events arm64: Fix indentation of brackets in imx8mm metrics (Michael Petlan) [1944685]
- perf annotate: Do not jump after 'k' is pressed (Michael Petlan) [1944685]
- perf metricgroup: Remove unneeded semicolon (Michael Petlan) [1944685]
- perf tools: Add OCaml demangling (Michael Petlan) [1944685]
- tools api fs: Cache cgroupfs mount point (Michael Petlan) [1944685]
- tools api fs: Diet cgroupfs_find_mountpoint() (Michael Petlan) [1944685]
- tools api fs: Prefer cgroup v1 path in cgroupfs_find_mountpoint() (Michael Petlan) [1944685]
- perf symbols: Resolve symbols against debug file first (Michael Petlan) [1944685]
- perf probe: Fix kretprobe issue caused by GCC bug (Michael Petlan) [1944685]
- perf symbols: Fix return value when loading PE DSO (Michael Petlan) [1944685]
- perf symbols: Make dso__load_bfd_symbols() load PE files from debug cache only (Michael Petlan) [1944685]
- perf symbols: Use (long) for iterator for bfd symbols (Michael Petlan) [1944685]
- perf annotate: Fix jump parsing for C++ code. (Michael Petlan) [1944685]
- perf arm-spe: Set sample's data source field (Michael Petlan) [1944685]
- perf arm-spe: Synthesize memory event (Michael Petlan) [1944685]
- perf arm-spe: Fill address info for samples (Michael Petlan) [1944685]
- perf arm-spe: Store operation type in packet (Michael Petlan) [1944685]
- perf arm-spe: Store memory address in packet (Michael Petlan) [1944685]
- perf arm-spe: Enable sample type PERF_SAMPLE_DATA_SRC (Michael Petlan) [1944685]
- perf env: Remove unneeded internal/cpumap inclusions (Michael Petlan) [1944685]
- perf tools: Remove unused xyarray.c as it was moved to tools/lib/perf (Michael Petlan) [1944685]
- perf tools: Replace lkml.org links with lore (Michael Petlan) [1944685]
- perf tests: Add daemon 'lock' test (Michael Petlan) [1944685]
- perf tests: Add daemon 'ping' command test (Michael Petlan) [1944685]
- perf tests: Add daemon 'signal' command test (Michael Petlan) [1944685]
- perf tests: Add daemon 'stop' command test (Michael Petlan) [1944685]
- perf tests: Add daemon reconfig test (Michael Petlan) [1944685]
- perf tests: Add daemon 'list' command test (Michael Petlan) [1944685]
- perf daemon: Add examples to man page (Michael Petlan) [1944685]
- perf daemon: Add up time for daemon/session list (Michael Petlan) [1944685]
- perf daemon: Use control to stop session (Michael Petlan) [1944685]
- perf daemon: Add 'ping' command (Michael Petlan) [1944685]
- perf daemon: Set control fifo for session (Michael Petlan) [1944685]
- perf daemon: Allow only one daemon over base directory (Michael Petlan) [1944685]
- perf daemon: Add 'stop' command (Michael Petlan) [1944685]
- perf daemon: Add 'signal' command (Michael Petlan) [1944685]
- perf daemon: Add 'list' command (Michael Petlan) [1944685]
- perf daemon: Add signalfd support (Michael Petlan) [1944685]
- perf daemon: Add background support (Michael Petlan) [1944685]
- perf daemon: Add config file change check (Michael Petlan) [1944685]
- perf daemon: Add config file support (Michael Petlan) [1944685]
- perf daemon: Add client socket support (Michael Petlan) [1944685]
- perf daemon: Add server socket support (Michael Petlan) [1944685]
- perf daemon: Add base option (Michael Petlan) [1944685]
- perf daemon: Add config option (Michael Petlan) [1944685]
- perf daemon: Add daemon command (Michael Petlan) [1944685]
- perf script: Simplify bool conversion (Michael Petlan) [1944685]
- perf arm64/s390: Fix printf conversion specifier for IP addresses (Michael Petlan) [1944685]
- perf script: Support filtering by hex address (Michael Petlan) [1944685]
- perf intlist: Change 'struct intlist' int member to 'unsigned long' (Michael Petlan) [1944685]
- perf tools: Update topdown documentation for Sapphire Rapids (Michael Petlan) [1944685]
- perf stat: Support L2 Topdown events (Michael Petlan) [1944685]
- perf test: Support PERF_SAMPLE_WEIGHT_STRUCT (Michael Petlan) [1944685]
- perf report: Support instruction latency (Michael Petlan) [1944685]
- perf tools: Support PERF_SAMPLE_WEIGHT_STRUCT (Michael Petlan) [1944685]
- perf c2c: Support data block and addr block (Michael Petlan) [1944685]
- perf tools: Support data block and addr block (Michael Petlan) [1944685]
- perf tools: Support the auxiliary event (Michael Petlan) [1944685]
- perf probe: Add protection to avoid endless loop (Michael Petlan) [1944685]
- perf trace-event-info: Rename for_each_event. (Michael Petlan) [1944685]
- perf inject jit: Add namespaces support (Michael Petlan) [1944685]
- perf namespaces: Add 'in_pidns' to nsinfo struct (Michael Petlan) [1944685]
- perf tools: Use scandir() to iterate threads when synthesizing PERF_RECORD_ events (Michael Petlan) [1944685]
- perf tools: Skip PERF_RECORD_MMAP event synthesis for kernel threads (Michael Petlan) [1944685]
- perf tools: Use /proc/<PID>/task/<TID>/status for PERF_RECORD_ event synthesis (Michael Petlan) [1944685]
- perf vendor events arm64: Reference common and uarch events for A76 (Michael Petlan) [1944685]
- perf vendor events arm64: Reference common and uarch events for Ampere eMag (Michael Petlan) [1944685]
- perf vendor events arm64: Add common and uarch event JSON (Michael Petlan) [1944685]
- perf vendor events arm64: Fix Ampere eMag event typo (Michael Petlan) [1944685]
- perf script: Support DSO filter like in other perf tools (Michael Petlan) [1944685]
- perf tools: Fix DSO filtering when not finding a map for a sampled address (Michael Petlan) [1944685]
- perf stat: Add Topdown metrics events as default events (Michael Petlan) [1944685]
- perf test: Add parse-metric memory bandwidth testcase (Michael Petlan) [1944685]
- perf tools: Add 'ping' control command (Michael Petlan) [1944685]
- perf tools: Add 'stop' control command (Michael Petlan) [1944685]
- perf config: Make perf_config_global() global (Michael Petlan) [1944685]
- perf config: Make perf_config_system() global (Michael Petlan) [1944685]
- perf config: Add perf_home_perfconfig function (Michael Petlan) [1944685]
- perf debug: Add debug_set_display_time function (Michael Petlan) [1944685]
- perf config: Add config set interface (Michael Petlan) [1944685]
- perf config: Make perf_config_from_file() static (Michael Petlan) [1944685]
- perf test: Add test case for PERF_SAMPLE_CODE_PAGE_SIZE (Michael Petlan) [1944685]
- perf report: Add support for PERF_SAMPLE_CODE_PAGE_SIZE (Michael Petlan) [1944685]
- perf script: Add support for PERF_SAMPLE_CODE_PAGE_SIZE (Michael Petlan) [1944685]
- perf record: Add support for PERF_SAMPLE_CODE_PAGE_SIZE (Michael Petlan) [1944685]
- perf mem: Support data page size (Michael Petlan) [1944685]
- perf mem: Clean up output format (Michael Petlan) [1944685]
- perf cs-etm: Update ARM's CoreSight hardware tracing OpenCSD library to v1.0.0 (Michael Petlan) [1944685]
- perf c2c: Add local variables for output metrics (Michael Petlan) [1944685]
- perf c2c: Refactor node display (Michael Petlan) [1944685]
- perf c2c: Fix argument type for percent() (Michael Petlan) [1944685]
- perf c2c: Refactor display filter (Michael Petlan) [1944685]
- perf c2c: Refactor hist entry validation (Michael Petlan) [1944685]
- perf c2c: Rename for shared cache line stats (Michael Petlan) [1944685]
- perf stat: Enable counting events for BPF programs (Michael Petlan) [1944685]
- perf build: Support build BPF skeletons with perf (Michael Petlan) [1944685]
- perf record: Tweak "Lowering..." warning in record_opts__config_freq (Michael Petlan) [1944685]
- perf buildid-list: Add support for mmap2's buildid events (Michael Petlan) [1944685]
- perf buildid-cache: Add --debuginfod option to specify a server to fetch debug files (Michael Petlan) [1944685]
- perf tools: Add support to display build ids when available in PERF_RECORD_MMAP2 events (Michael Petlan) [1944685]
- perf record: Add --buildid-mmap option to enable PERF_RECORD_MMAP2's build id (Michael Petlan) [1944685]
- perf tools: Allow synthesizing the build id for kernel/modules/tasks in PERF_RECORD_MMAP2 (Michael Petlan) [1944685]
- perf tools: Allow using PERF_RECORD_MMAP2 to synthesize the kernel modules maps (Michael Petlan) [1944685]
- perf tools: Allow using PERF_RECORD_MMAP2 to synthesize the kernel map (Michael Petlan) [1944685]
- perf tools: Store build id when available in PERF_RECORD_MMAP2 metadata events (Michael Petlan) [1944685]
- perf tools: Do not swap mmap2 fields in case it contains build id (Michael Petlan) [1944685]
- perf arm64: Add argument support for SDT (Michael Petlan) [1944685]
- perf probe: Fixup Arm64 SDT arguments (Michael Petlan) [1944685]
- perf/x86/kvm: Fix Broadwell Xeon stepping in isolation_ucodes[] (Michael Petlan) [1944685]
- perf/x86/intel: Fix unchecked MSR access error caused by VLBR_EVENT (Michael Petlan) [1944685]
- perf/x86/intel: Fix a crash caused by zero PEBS status (Michael Petlan) [1944685]
- perf/x86/intel: Set PERF_ATTACH_SCHED_CB for large PEBS and LBR (Michael Petlan) [1944685]
- perf/core: Flush PMU internal buffers for per-CPU events (Michael Petlan) [1944685]
- perf/x86/rapl: Fix psys-energy event on Intel SPR platform (Michael Petlan) [1944685]
- perf/x86/rapl: Only check lower 32bits for RAPL energy counters (Michael Petlan) [1944685]
- perf/x86/rapl: Add msr mask support (Michael Petlan) [1944685]
- perf/x86/kvm: Add Cascade Lake Xeon steppings to isolation_ucodes[] (Michael Petlan) [1944685]
- perf/x86/intel: Support CPUID 10.ECX to disable fixed counters (Michael Petlan) [1944685]
- perf/x86/intel: Add perf core PMU support for Sapphire Rapids (Michael Petlan) [1944685]
- perf/x86/intel: Filter unsupported Topdown metrics event (Michael Petlan) [1944685]
- perf/x86/intel: Factor out intel_update_topdown_event() (Michael Petlan) [1944685]
- perf/core: Add PERF_SAMPLE_WEIGHT_STRUCT (Michael Petlan) [1944685]
- perf/intel: Remove Perfmon-v4 counter_freezing support (Michael Petlan) [1944685]
- perf: Add build id data in mmap2 event (Michael Petlan) [1944685]
- bpf: Remove atomics tests from test_progs (Jiri Olsa) [1874007]
- libbpf: Fixes incorrect rx_ring_setup_done (Jiri Olsa) [1874007]
- error-injection: Consolidate override function definition (Jiri Olsa) [1874007]
- selftests/bpf: Fix endianness issues in atomic tests (Jiri Olsa) [1874007]
- bpf: Fix a spelling typo in bpf_atomic_alu_string disasm (Jiri Olsa) [1874007]
- bpf, x86: Fix BPF_FETCH atomic and/or/xor with r0 as src (Jiri Olsa) [1874007]
- bpf: Explicitly zero-extend R0 after 32-bit cmpxchg (Jiri Olsa) [1874007]
- bpf: Account for BPF_FETCH in insn_has_def32() (Jiri Olsa) [1874007]
- bpf: Fix subreg optimization for BPF_FETCH (Jiri Olsa) [1874007]
- bpf: Fix the irq and nmi check in bpf_sk_storage for tracing usage (Jiri Olsa) [1874007]
- selftests/bpf: Fix a compiler warning in local_storage test (Jiri Olsa) [1874007]
- bpf: Change 'BPF_ADD' to 'BPF_AND' in print_bpf_insn() (Jiri Olsa) [1874007]
- selftests/bpf: Don't exit on failed bpf_testmod unload (Jiri Olsa) [1874007]
- bpf: Avoid old-style declaration warnings (Jiri Olsa) [1874007]
- bpf: Dont allow vmlinux BTF to be used in map_create and prog_load. (Jiri Olsa) [1874007]
- tools: Factor Clang, LLC and LLVM utils definitions (Jiri Olsa) [1874007]
- tools/runqslower: Build bpftool using HOSTCC (Jiri Olsa) [1874007]
- tools/runqslower: Enable out-of-tree build (Jiri Olsa) [1874007]
- tools/runqslower: Use Makefile.include (Jiri Olsa) [1874007]
- bpf: Expose bpf_sk_storage_* to iterator programs (Jiri Olsa) [1874007]
- tools/resolve_btfids: Warn when having multiple IDs for single type (Jiri Olsa) [1874007]
- tools/resolve_btfids: Fix some error messages (Jiri Olsa) [1874007]
- samples/bpf: Add BPF_ATOMIC_OP macro for BPF samples (Jiri Olsa) [1874007]
- samples/bpf: Fix possible hang in xdpsock with multiple threads (Jiri Olsa) [1874007]
- bpf: samples: Do not touch RLIMIT_MEMLOCK (Jiri Olsa) [1874007]
- samples/bpf: Use recvfrom() in xdpsock/l2fwd (Jiri Olsa) [1874007]
- samples/bpf: Use recvfrom() in xdpsock/rxdrop (Jiri Olsa) [1874007]
- samples: bpf: Remove bpf_load loader completely (Jiri Olsa) [1874007]
- samples: bpf: Fix lwt_len_hist reusing previous BPF map (Jiri Olsa) [1874007]
- samples: bpf: Refactor test_overhead program with libbpf (Jiri Olsa) [1874007]
- samples: bpf: Refactor task_fd_query program with libbpf (Jiri Olsa) [1874007]
- samples: bpf: Refactor test_cgrp2_sock2 program with libbpf (Jiri Olsa) [1874007]
- samples: bpf: Refactor hbm program with libbpf (Jiri Olsa) [1874007]
- samples/bpf: Increment Tx stats at sending (Jiri Olsa) [1874007]
- samples/bpf: Remove unused test_ipip.sh (Jiri Olsa) [1874007]
- samples/bpf: Remove duplicate include in hbm (Jiri Olsa) [1874007]
- bpftool: Fix compilation failure for net.o with older glibc (Jiri Olsa) [1874007]
- tools/bpftool: Auto-detect split BTFs in common cases (Jiri Olsa) [1874007]
- tools/bpftool: Emit name <anon> for anonymous BTFs (Jiri Olsa) [1874007]
- bpftool: Add {i,d}tlb_misses support for bpftool profile (Jiri Olsa) [1874007]
- tools/bpf: Always run the *-clean recipes (Jiri Olsa) [1874007]
- tools/bpf: Add bootstrap/ to .gitignore (Jiri Olsa) [1874007]
- tools/bpftool: Fix cross-build (Jiri Olsa) [1874007]
- tools/bpftool: Force clean of out-of-tree build (Jiri Olsa) [1874007]
- tools/bpftool: Add support for in-kernel and named BTF in `btf show` (Jiri Olsa) [1874007]
- bpftool: Add support for task local storage (Jiri Olsa) [1874007]
- tools/bpftool: Add bpftool support for split BTF (Jiri Olsa) [1874007]
- bpf: Unbreak BPF_PROG_TYPE_KPROBE when kprobe is called via do_int3 (Jiri Olsa) [1874007]
- bpf: Fix bpf_put_raw_tracepoint()'s use of __module_address() (Jiri Olsa) [1874007]
- bpf: Expose bpf_d_path helper to sleepable LSM hooks (Jiri Olsa) [1874007]
- bpf: Allow using bpf_sk_storage in FENTRY/FEXIT/RAW_TP (Jiri Olsa) [1874007]
- selftests/bpf: Add remaining ASSERT_xxx() variants (Jiri Olsa) [1874007]
- libbpf: Fix potential NULL pointer dereference (Jiri Olsa) [1874007]
- libbpf: Only create rx and tx XDP rings when necessary (Jiri Olsa) [1874007]
- libbpf: Ensure umem pointer is non-NULL before dereferencing (Jiri Olsa) [1874007]
- libbpf: Restore umem state after socket create failure (Jiri Olsa) [1874007]
- selftests/bpf: Fix core_reloc test runner (Jiri Olsa) [1874007]
- bpf: Fix umd memory leak in copy_process() (Jiri Olsa) [1874007]
- libbpf: Fix error path in bpf_object__elf_init() (Jiri Olsa) [1874007]
- bpf: Change inode_storage's lookup_elem return value from NULL to -EBADF (Jiri Olsa) [1874007]
- bpf: Prohibit alu ops for pointer types not defining ptr_limit (Jiri Olsa) [1874007]
- selftests/bpf: Use the last page in test_snprintf_btf on s390 (Jiri Olsa) [1874007]
- bpf: Be less specific about socket cookies guarantees (Jiri Olsa) [1874007]
- bpf: Fix 32 bit src register truncation on div/mod (Jiri Olsa) [1874007]
- bpf: Fix verifier jmp32 pruning decision logic (Jiri Olsa) [1874007]
- bpf: Fix verifier jsgt branch analysis on max bound (Jiri Olsa) [1874007]
- bpf: Check for integer overflow when using roundup_pow_of_two() (Jiri Olsa) [1874007]
- bpf, preload: Fix build when $(O) points to a relative path (Jiri Olsa) [1874007]
- bpf: Drop disabled LSM hooks from the sleepable set (Jiri Olsa) [1874007]
- bpf, cgroup: Fix problematic bounds check (Jiri Olsa) [1874007]
- bpf, cgroup: Fix optlen WARN_ON_ONCE toctou (Jiri Olsa) [1874007]
- bpf: Fix signed_{sub,add32}_overflows type handling (Jiri Olsa) [1874007]
- bpf: Fix helper bpf_map_peek_elem_proto pointing to wrong callback (Jiri Olsa) [1874007]
- selftests/bpf: Add verifier test for PTR_TO_MEM spill (Jiri Olsa) [1874007]
- bpf: Support PTR_TO_MEM{,_OR_NULL} register spilling (Jiri Olsa) [1874007]
- libbpf: Allow loading empty BTFs (Jiri Olsa) [1874007]
- bpf: Allow empty module BTFs (Jiri Olsa) [1874007]
- bpf: Don't leak memory in bpf getsockopt when optlen == 0 (Jiri Olsa) [1874007]
- bpf: Update local storage test to check handling of null ptrs (Jiri Olsa) [1874007]
- bpf: Fix typo in bpf_inode_storage.c (Jiri Olsa) [1874007]
- bpf: Add size arg to build_id_parse function (Jiri Olsa) [1874007]
- bpf: Move stack_map_get_build_id into lib (Jiri Olsa) [1874007]
- bpf: Add tests for new BPF atomic operations (Jiri Olsa) [1874007]
- bpf: Add bitwise atomic instructions (Jiri Olsa) [1874007]
- bpf: Pull out a macro for interpreting atomic ALU operations (Jiri Olsa) [1874007]
- bpf: Add instructions for atomic_[cmp]xchg (Jiri Olsa) [1874007]
- bpf: Add BPF_FETCH field / create atomic_fetch_add instruction (Jiri Olsa) [1874007]
- bpf: Move BPF_STX reserved field check into BPF_STX verifier code (Jiri Olsa) [1874007]
- bpf: Rename BPF_XADD and prepare to encode other atomics in .imm (Jiri Olsa) [1874007]
- bpf: x86: Factor out a lookup table for some ALU opcodes (Jiri Olsa) [1874007]
- bpf: x86: Factor out emission of REX byte (Jiri Olsa) [1874007]
- bpf: x86: Factor out emission of ModR/M for *(reg + off) (Jiri Olsa) [1874007]
- bpf, libbpf: Avoid unused function warning on bpf_tail_call_static (Jiri Olsa) [1874007]
- selftests/bpf: Install btf_dump test cases (Jiri Olsa) [1874007]
- selftests/bpf: Fix installation of urandom_read (Jiri Olsa) [1874007]
- selftests/bpf: Move generated test files to $(TEST_GEN_FILES) (Jiri Olsa) [1874007]
- selftests/bpf: Fix out-of-tree build (Jiri Olsa) [1874007]
- selftests/bpf: Enable cross-building (Jiri Olsa) [1874007]
- selftests/bpf: Test kernel module ksym externs (Jiri Olsa) [1874007]
- libbpf: Support kernel module ksym externs (Jiri Olsa) [1874007]
- bpf: Support BPF ksym variables in kernel modules (Jiri Olsa) [1874007]
- selftests/bpf: Sync RCU before unloading bpf_testmod (Jiri Olsa) [1874007]
- bpf: Fix a verifier message for alloc size helper arg (Jiri Olsa) [1874007]
- bpf: Clarify return value of probe str helpers (Jiri Olsa) [1874007]
- libbpf: Clarify kernel type use with USER variants of CORE reading macros (Jiri Olsa) [1874007]
- selftests/bpf: Remove duplicate include in test_lsm (Jiri Olsa) [1874007]
- bpf: Remove unnecessary <argp.h> include from preload/iterators (Jiri Olsa) [1874007]
- selftests/bpf: Add tests for user- and non-CO-RE BPF_CORE_READ() variants (Jiri Olsa) [1874007]
- libbpf: Add non-CO-RE variants of BPF_CORE_READ() macro family (Jiri Olsa) [1874007]
- selftests/bpf: Fix a compile error for BPF_F_BPRM_SECUREEXEC (Jiri Olsa) [1874007]
- bpf: Use thread_group_leader() (Jiri Olsa) [1874007]
- bpf: Save correct stopping point in file seq iteration (Jiri Olsa) [1874007]
- selftests/bpf: Work-around EBUSY errors from hashmap update/delete (Jiri Olsa) [1874007]
- bpf: Add schedule point in htab_init_buckets() (Jiri Olsa) [1874007]
- bpf: Remove unused including <linux/version.h> (Jiri Olsa) [1874007]
- selftests/bpf: Fix spelling mistake "tranmission" -> "transmission" (Jiri Olsa) [1874007]
- selftests/bpf: Clarify build error if no vmlinux (Jiri Olsa) [1874007]
- tweewide: Fix most Shebang lines (Jiri Olsa) [1874007]
- bpf: In bpf_task_fd_query use fget_task (Jiri Olsa) [1874007]
- selftests/bpf: Add a test for ptr_to_map_value on stack for helper access (Jiri Olsa) [1874007]
- bpf: Permits pointers on stack for helper calls (Jiri Olsa) [1874007]
- libbpf: Expose libbpf ring_buffer epoll_fd (Jiri Olsa) [1874007]
- selftests/bpf: Add set_attach_target() API selftest for module target (Jiri Olsa) [1874007]
- libbpf: Support modules in bpf_program__set_attach_target() API (Jiri Olsa) [1874007]
- selftests/bpf: Silence ima_setup.sh when not running in verbose mode. (Jiri Olsa) [1874007]
- selftests/bpf: Drop the need for LLVM's llc (Jiri Olsa) [1874007]
- selftests/bpf: fix bpf_testmod.ko recompilation logic (Jiri Olsa) [1874007]
- selftests/bpf: Make selftest compilation work on clang 11 (Jiri Olsa) [1874007]
- selftests/bpf: Xsk selftests - adding xdpxceiver to .gitignore (Jiri Olsa) [1874007]
- selftests/bpf: Drop tcp-{client,server}.py from Makefile (Jiri Olsa) [1874007]
- selftests/bpf: Xsk selftests - Bi-directional Sockets - SKB, DRV (Jiri Olsa) [1874007]
- selftests/bpf: Xsk selftests - Socket Teardown - SKB, DRV (Jiri Olsa) [1874007]
- selftests/bpf: Xsk selftests - DRV POLL, NOPOLL (Jiri Olsa) [1874007]
- selftests/bpf: Xsk selftests - SKB POLL, NOPOLL (Jiri Olsa) [1874007]
- selftests/bpf: Xsk selftests framework (Jiri Olsa) [1874007]
- bpf: Return -ENOTSUPP when attaching to non-kernel BTF (Jiri Olsa) [1874007]
- bpf: Propagate __user annotations properly (Jiri Olsa) [1874007]
- bpf: Avoid overflows involving hash elem_size (Jiri Olsa) [1874007]
- selftests/bpf: Test bpf_sk_storage_get in tcp iterators (Jiri Olsa) [1874007]
- selftests/bpf: Add an iterator selftest for bpf_sk_storage_get (Jiri Olsa) [1874007]
- selftests/bpf: Add an iterator selftest for bpf_sk_storage_delete (Jiri Olsa) [1874007]
- bpf: Add a bpf_sock_from_file helper (Jiri Olsa) [1874007]
- selftests/bpf: Avoid errno clobbering (Jiri Olsa) [1874007]
- selftests/bpf: Print reason when a tester could not run a program (Jiri Olsa) [1874007]
- selftests/bpf: Fix invalid use of strncat in test_sockmap (Jiri Olsa) [1874007]
- libbpf: Use memcpy instead of strncpy to please GCC (Jiri Olsa) [1874007]
- selftests/bpf: Add fentry/fexit/fmod_ret selftest for kernel module (Jiri Olsa) [1874007]
- selftests/bpf: Add tp_btf CO-RE reloc test for modules (Jiri Olsa) [1874007]
- libbpf: Support attachment of BPF tracing programs to kernel modules (Jiri Olsa) [1874007]
- libbpf: Factor out low-level BPF program loading helper (Jiri Olsa) [1874007]
- bpf: Allow to specify kernel module BTFs when attaching BPF programs (Jiri Olsa) [1874007]
- bpf: Remove hard-coded btf_vmlinux assumption from BPF verifier (Jiri Olsa) [1874007]
- selftests/bpf: Add CO-RE relocs selftest relying on kernel module BTF (Jiri Olsa) [1874007]
- selftests/bpf: Add support for marking sub-tests as skipped (Jiri Olsa) [1874007]
- selftests/bpf: Add bpf_testmod kernel module for testing (Jiri Olsa) [1874007]
- libbpf: Add kernel module BTF support for CO-RE relocations (Jiri Olsa) [1874007]
- libbpf: Refactor CO-RE relocs to not assume a single BTF object (Jiri Olsa) [1874007]
- libbpf: Add internal helper to load BTF data by FD (Jiri Olsa) [1874007]
- selftests/bpf: Add Userspace tests for TCP_WINDOW_CLAMP (Jiri Olsa) [1874007]
- bpf: Fix cold build of test_progs-no_alu32 (Jiri Olsa) [1874007]
- libbpf: Cap retries in sys_bpf_prog_load (Jiri Olsa) [1874007]
- libbpf: Sanitise map names before pinning (Jiri Olsa) [1874007]
- libbpf: Fail early when loading programs with unspecified type (Jiri Olsa) [1874007]
- selftests/bpf: Indent ima_setup.sh with tabs. (Jiri Olsa) [1874007]
- selftests/bpf: Add config dependency on BLK_DEV_LOOP (Jiri Olsa) [1874007]
- selftests/bpf: Ensure securityfs mount before writing ima policy (Jiri Olsa) [1874007]
- selftests/bpf: Update ima_setup.sh for busybox (Jiri Olsa) [1874007]
- libbpf: Separate XDP program load with xsk socket creation (Jiri Olsa) [1874007]
- selftests/bpf: Copy file using read/write in local storage test (Jiri Olsa) [1874007]
- libbpf: Add base BTF accessor (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for bpf progs (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for bpf local storage maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for stackmap maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for bpf ringbuffer (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for reuseport_array maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for queue_stack_maps maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for lpm_trie maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for hashtab maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for devmap maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for cgroup storage maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for cpumap maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for bpf_struct_ops maps (Jiri Olsa) [1874007]
- bpf: Eliminate rlimit-based memory accounting for arraymap maps (Jiri Olsa) [1874007]
- bpf: Memcg-based memory accounting for bpf local storage maps (Jiri Olsa) [1874007]
- bpf: Memcg-based memory accounting for bpf ringbuffer (Jiri Olsa) [1874007]
- bpf: Memcg-based memory accounting for lpm_trie maps (Jiri Olsa) [1874007]
- bpf: Refine memcg-based memory accounting for hashtab maps (Jiri Olsa) [1874007]
- bpf: Refine memcg-based memory accounting for devmap maps (Jiri Olsa) [1874007]
- bpf: Memcg-based memory accounting for cgroup storage maps (Jiri Olsa) [1874007]
- bpf: Refine memcg-based memory accounting for cpumap maps (Jiri Olsa) [1874007]
- bpf: Refine memcg-based memory accounting for arraymap maps (Jiri Olsa) [1874007]
- bpf: Memcg-based memory accounting for bpf maps (Jiri Olsa) [1874007]
- bpf: Prepare for memcg-based memory accounting for bpf maps (Jiri Olsa) [1874007]
- bpf: Memcg-based memory accounting for bpf progs (Jiri Olsa) [1874007]
- selftests/bpf: Extend bind{4,6} programs with a call to bpf_setsockopt (Jiri Olsa) [1874007]
- selftests/bpf: Rewrite test_sock_addr bind bpf into C (Jiri Olsa) [1874007]
- selftests/bpf: Fix flavored variants of test_ima (Jiri Olsa) [1874007]
- libbpf: Replace size_t with __u32 in xsk interfaces (Jiri Olsa) [1874007]
- bpf: Add a selftest for bpf_ima_inode_hash (Jiri Olsa) [1874007]
- bpf: Add a BPF helper for getting the IMA hash of an inode (Jiri Olsa) [1874007]
- libbpf: Add support for canceling cached_cons advance (Jiri Olsa) [1874007]
- bpf: Refactor check_cfg to use a structured loop. (Jiri Olsa) [1874007]
- selftest/bpf: Fix rst formatting in readme (Jiri Olsa) [1874007]
- selftest/bpf: Fix link in readme (Jiri Olsa) [1874007]
- bpf: Simplify task_file_seq_get_next() (Jiri Olsa) [1874007]
- selftests/bpf: Mark tests that require unaligned memory access (Jiri Olsa) [1874007]
- selftests/bpf: Avoid running unprivileged tests with alignment requirements (Jiri Olsa) [1874007]
- selftests/bpf: Fix broken riscv build (Jiri Olsa) [1874007]
- bpf: Add bpf_ktime_get_coarse_ns helper (Jiri Olsa) [1874007]
- bpf: Add tests for bpf_bprm_opts_set helper (Jiri Olsa) [1874007]
- bpf: Add bpf_bprm_opts_set helper (Jiri Olsa) [1874007]
- libbpf: bpf__find_by_name[_kind] should use btf__get_nr_types() (Jiri Olsa) [1874007]
- selftest/bpf: Fix IPV6FR handling in flow dissector (Jiri Olsa) [1874007]
- bpf: Augment the set of sleepable LSM hooks (Jiri Olsa) [1874007]
- bpf: selftest: Use bpf_sk_storage in FENTRY/FEXIT/RAW_TP (Jiri Olsa) [1874007]
- selftests/bpf: Add asm tests for pkt vs pkt_end comparison. (Jiri Olsa) [1874007]
- selftests/bpf: Add skb_pkt_end test (Jiri Olsa) [1874007]
- bpf: Support for pointers beyond pkt_end. (Jiri Olsa) [1874007]
- bpf: Compile out btf_parse_module() if module BTF is not enabled (Jiri Olsa) [1874007]
- selftest/bpf: Add missed ip6ip6 test back (Jiri Olsa) [1874007]
- bpf: Keep module's btf_data_size intact after load (Jiri Olsa) [1874007]
- bpf: Sanitize BTF data pointer after module is loaded (Jiri Olsa) [1874007]
- bpf: Load and verify kernel module BTFs (Jiri Olsa) [1874007]
- bpf: Assign ID to vmlinux BTF and return extra info for BTF in GET_OBJ_INFO (Jiri Olsa) [1874007]
- bpf: Add in-kernel split BTF support (Jiri Olsa) [1874007]
- bpf, btf: Remove the duplicate btf_ids.h include (Jiri Olsa) [1874007]
- selftests/bpf: Fix selftest build with old libc (Jiri Olsa) [1874007]
- bpf: Exercise syscall operations for inode and sk storage (Jiri Olsa) [1874007]
- bpf: Add tests for task_local_storage (Jiri Olsa) [1874007]
- bpf: Update selftests for local_storage to use vmlinux.h (Jiri Olsa) [1874007]
- bpf: Implement get_current_task_btf and RET_PTR_TO_BTF_ID (Jiri Olsa) [1874007]
- libbpf: Add support for task local storage (Jiri Olsa) [1874007]
- bpf: Implement task local storage (Jiri Olsa) [1874007]
- bpf: Allow LSM programs to use bpf spin locks (Jiri Olsa) [1874007]
- bpf: Lift hashtab key_size limit (Jiri Olsa) [1874007]
- selftests/bpf: Add split BTF dedup selftests (Jiri Olsa) [1874007]
- libbpf: Accomodate DWARF/compiler bug with duplicated identical arrays (Jiri Olsa) [1874007]
- libbpf: Support BTF dedup of split BTFs (Jiri Olsa) [1874007]
- libbpf: Fix BTF data layout checks and allow empty BTF (Jiri Olsa) [1874007]
- selftests/bpf: Add checking of raw type dump in BTF writer APIs selftests (Jiri Olsa) [1874007]
- selftests/bpf: Add split BTF basic test (Jiri Olsa) [1874007]
- libbpf: Implement basic split BTF support (Jiri Olsa) [1874007]
- libbpf: Unify and speed up BTF string deduplication (Jiri Olsa) [1874007]
- selftest/bpf: Relax btf_dedup test checks (Jiri Olsa) [1874007]
- libbpf: Factor out common operations in BTF writing APIs (Jiri Olsa) [1874007]
- selftest/bpf: Use global variables instead of maps for test_tcpbpf_kern (Jiri Olsa) [1874007]
- selftests/bpf: Migrate tcpbpf_user.c to use BPF skeleton (Jiri Olsa) [1874007]
- selftests/bpf: Replace EXPECT_EQ with ASSERT_EQ and refactor verify_results (Jiri Olsa) [1874007]
- selftests/bpf: Drop python client/server in favor of threads (Jiri Olsa) [1874007]
- selftests/bpf: Move test_tcppbf_user into test_progs (Jiri Olsa) [1874007]
- bpf: Fix error path in htab_map_alloc() (Jiri Olsa) [1874007]
- bpf: Avoid hashtab deadlock with map_locked (Jiri Olsa) [1874007]
- bpf: Use separate lockdep class for each hashtab (Jiri Olsa) [1874007]
- fault-injection: handle EI_ETYPE_TRUE (Jiri Olsa) [1874007]
- vfs, fdtable: Add fget_task helper (Jiri Olsa) [1874007]
- [s390] vfio-pci/zdev: Add zPCI capabilities to VFIO_DEVICE_GET_INFO (Claudio Imbrenda) [1858844]
- [s390] vfio: Introduce capability definitions for VFIO_DEVICE_GET_INFO (Claudio Imbrenda) [1858844]
- [s390] s390/pci: track whether util_str is valid in the zpci_dev (Claudio Imbrenda) [1858844]
- [s390] s390/pci: stash version in the zpci_dev (Claudio Imbrenda) [1858844]

* Thu Jul 01 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-320.el8]
- Enable CRYPTO_SHA512 and _SSSE3 so these are available in FIPS mode (Vladis Dronov) [1973106]
- crypto: drbg - self test for HMAC(SHA-512) (Vladis Dronov) [1973106]
- xfrm: xfrm_state_mtu should return at least 1280 for ipv6 (Sabrina Dubroca) [1919786]
- xfrm: remove get_mtu indirection from xfrm_type (Sabrina Dubroca) [1919786]
- netfilter: move endif to correct location (Florian Westphal) [1971991]
- netfilter: nft_compat: remove flush counter optimization (Florian Westphal) [1974323]
- mptcp: fix soft lookup in subflow_error_report() (Florian Westphal) [1936368]
- selftests: mptcp: enable syncookie only in absence of reorders (Florian Westphal) [1936368]
- mptcp: do not warn on bad input from the network (Florian Westphal) [1936368]
- mptcp: wake-up readers only for in sequence data (Florian Westphal) [1936368]
- mptcp: try harder to borrow memory from subflow under pressure (Florian Westphal) [1936368]
- mptcp: Fix out of bounds when parsing TCP options (Florian Westphal) [1936368]
- selftests: mptcp_connect: add SO_TIMESTAMPNS cmsg support (Florian Westphal) [1936368]
- mptcp: receive path cmsg support (Florian Westphal) [1936368]
- tcp: export timestamp helpers for mptcp (Florian Westphal) [1936368]
- mptcp: setsockopt: handle SOL_SOCKET in one place only (Florian Westphal) [1936368]
- mptcp: sockopt: propagate timestamp request to subflows (Florian Westphal) [1936368]
- sock: expose so_timestamping options for mptcp (Florian Westphal) [1936368]
- mptcp: restrict values of 'enabled' sysctl (Florian Westphal) [1936368]
- mptcp: support SYSCTL only if enabled (Florian Westphal) [1936368]
- mptcp: make sure flag signal is set when add addr with port (Florian Westphal) [1936368]
- mptcp: remove redundant initialization in pm_nl_init_net() (Florian Westphal) [1936368]
- mptcp: generate subflow hmac after mptcp_finish_join() (Florian Westphal) [1936368]
- mptcp: using TOKEN_MAX_RETRIES instead of magic number (Florian Westphal) [1936368]
- mptcp: fix pr_debug in mptcp_token_new_connect (Florian Westphal) [1936368]
- mptcp: update selftest for fallback due to OoO (Florian Westphal) [1936368]
- mptcp: do not reset MP_CAPABLE subflow on mapping errors (Florian Westphal) [1936368]
- mptcp: always parse mptcp options for MPC reqsk (Florian Westphal) [1936368]
- mptcp: fix sk_forward_memory corruption on retransmission (Florian Westphal) [1936368]
- mptcp: validate 'id' when stopping the ADD_ADDR retransmit timer (Florian Westphal) [1936368]
- mptcp: avoid error message on infinite mapping (Florian Westphal) [1936368]
- mptcp: drop unconditional pr_warn on bad opt (Florian Westphal) [1936368]
- mptcp: avoid OOB access in setsockopt() (Florian Westphal) [1936368]
- mptcp: fix data stream corruption (Florian Westphal) [1936368]
- mptcp: fix splat when closing unaccepted socket (Florian Westphal) [1936368]
- selftests: mptcp: add a test case for MSG_PEEK (Florian Westphal) [1936368]
- mptcp: add MSG_PEEK support (Florian Westphal) [1936368]
- mptcp: ignore unsupported msg flags (Florian Westphal) [1936368]
- mptcp: implement MSG_TRUNC support (Florian Westphal) [1936368]
- mptcp: implement dummy MSG_ERRQUEUE support (Florian Westphal) [1936368]
- mptcp: Retransmit DATA_FIN (Florian Westphal) [1936368]
- selftests: mptcp: add packet mark test case (Florian Westphal) [1936368]
- selftests: mptcp: add the net device name testcase (Florian Westphal) [1936368]
- selftests: mptcp: dump more info on mpjoin errors (Florian Westphal) [1936368]
- selftests: mptcp: init nstat history (Florian Westphal) [1936368]
- selftests: mptcp: launch mptcp_connect with timeout (Florian Westphal) [1936368]
- selftests: mptcp: remove id 0 address testcases (Florian Westphal) [1936368]
- selftests: mptcp: add addr argument for del_addr (Florian Westphal) [1936368]
- selftests: mptcp: avoid calling pm_nl_ctl with bad IDs (Florian Westphal) [1936368]
- selftests: mptcp: signal addresses testcases (Florian Westphal) [1936368]
- selftests: mptcp: timeout testcases for multi addresses (Florian Westphal) [1936368]
- selftests: mptcp: add cfg_do_w for cfg_remove (Florian Westphal) [1936368]
- selftests: mptcp: Restore packet capture option in join tests (Florian Westphal) [1936368]
- selftests: mptcp: add testcases for removing addrs (Florian Westphal) [1936368]
- selftests: mptcp: set addr id for removing testcases (Florian Westphal) [1936368]
- selftests: mptcp: add invert argument for chk_rm_nr (Florian Westphal) [1936368]
- selftests: mptcp: fail if not enough SYN/3rd ACK (Florian Westphal) [1936368]
- selftests: mptcp: display warnings on one line (Florian Westphal) [1936368]
- selftests: mptcp: fix ACKRX debug message (Florian Westphal) [1936368]
- selftests: mptcp: dump more info on errors (Florian Westphal) [1936368]
- selftests: mptcp: add command line arguments for mptcp_join.sh (Florian Westphal) [1936368]
- selftests: mptcp: add testcases for ADD_ADDR with port (Florian Westphal) [1936368]
- selftests: mptcp: add port argument for pm_nl_ctl (Florian Westphal) [1936368]
- selftests: mptcp: add testcases for newly added addresses (Florian Westphal) [1936368]
- selftests: mptcp: use minus values for removing address numbers (Florian Westphal) [1936368]
- selftests: increase timeout to 10 min (Florian Westphal) [1936368]
- selftests: mptcp: add IPv4-mapped IPv6 testcases (Florian Westphal) [1936368]
- mptcp: use mptcp_for_each_subflow in mptcp_close (Florian Westphal) [1936368]
- mptcp: add tracepoint in subflow_check_data_avail (Florian Westphal) [1936368]
- mptcp: add tracepoint in ack_update_msk (Florian Westphal) [1936368]
- mptcp: add tracepoint in get_mapping_status (Florian Westphal) [1936368]
- mptcp: add tracepoint in mptcp_subflow_get_send (Florian Westphal) [1936368]
- mptcp: export mptcp_subflow_active (Florian Westphal) [1936368]
- mptcp: fix format specifiers for unsigned int (Florian Westphal) [1936368]
- mptcp: sockopt: add TCP_CONGESTION and TCP_INFO (Florian Westphal) [1936368]
- mptcp: setsockopt: SO_DEBUG and no-op options (Florian Westphal) [1936368]
- mptcp: setsockopt: add SO_INCOMING_CPU (Florian Westphal) [1936368]
- mptcp: setsockopt: add SO_MARK support (Florian Westphal) [1936368]
- mptcp: setsockopt: support SO_LINGER (Florian Westphal) [1936368]
- mptcp: setsockopt: handle receive/send buffer and device bind (Florian Westphal) [1936368]
- mptcp: setsockopt: handle SO_KEEPALIVE and SO_PRIORITY (Florian Westphal) [1936368]
- mptcp: tag sequence_seq with socket state (Florian Westphal) [1936368]
- mptcp: add skeleton to sync msk socket options to subflows (Florian Westphal) [1936368]
- mptcp: only admit explicitly supported sockopt (Florian Westphal) [1936368]
- mptcp: move sockopt function into a new file (Florian Westphal) [1936368]
- mptcp: drop all sub-options except ADD_ADDR when the echo bit is set (Florian Westphal) [1936368]
- mptcp: unify add_addr(6)_generate_hmac (Florian Westphal) [1936368]
- mptcp: drop MPTCP_ADDR_IPVERSION_4/6 (Florian Westphal) [1936368]
- mptcp: use mptcp_addr_info in mptcp_options_received (Florian Westphal) [1936368]
- mptcp: drop OPTION_MPTCP_ADD_ADDR6 (Florian Westphal) [1936368]
- mptcp: use mptcp_addr_info in mptcp_out_options (Florian Westphal) [1936368]
- mptcp: move flags and ifindex out of mptcp_addr_info (Florian Westphal) [1936368]
- mptcp: add mptcp reset option support (Florian Westphal) [1936368]
- mptcp: remove unneeded check on first subflow (Florian Westphal) [1936368]
- mptcp: add active MPC mibs (Florian Westphal) [1936368]
- mptcp: add mib for token creation fallback (Florian Westphal) [1936368]
- mptcp: remove id 0 address (Florian Westphal) [1936368]
- mptcp: unify RM_ADDR and RM_SUBFLOW receiving (Florian Westphal) [1936368]
- mptcp: remove all subflows involving id 0 address (Florian Westphal) [1936368]
- mptcp: subflow.c: Fix a typo (Florian Westphal) [1936368]
- mptcp: rename mptcp_pm_nl_add_addr_send_ack (Florian Westphal) [1936368]
- mptcp: send ack for rm_addr (Florian Westphal) [1936368]
- mptcp: drop useless addr_signal clear (Florian Westphal) [1936368]
- mptcp: move to next addr when subflow creation fail (Florian Westphal) [1936368]
- mptcp: export lookup_anno_list_by_saddr (Florian Westphal) [1936368]
- mptcp: move to next addr when timeout (Florian Westphal) [1936368]
- mptcp: drop unused subflow in mptcp_pm_subflow_established (Florian Westphal) [1936368]
- mptcp: skip connecting the connected address (Florian Westphal) [1936368]
- mptcp: drop argument port from mptcp_pm_announce_addr (Florian Westphal) [1936368]
- mptcp: clean-up the rtx path (Florian Westphal) [1936368]
- mptcp: fix ADD_ADDR HMAC in case port is specified (Florian Westphal) [1936368]
- mptcp: remove a list of addrs when flushing (Florian Westphal) [1936368]
- mptcp: remove multi addresses and subflows in PM (Florian Westphal) [1936368]
- mptcp: remove multi subflows in PM (Florian Westphal) [1936368]
- mptcp: remove multi addresses in PM (Florian Westphal) [1936368]
- mptcp: add rm_list_rx in mptcp_pm_data (Florian Westphal) [1936368]
- mptcp: add rm_list in mptcp_options_received (Florian Westphal) [1936368]
- mptcp: add rm_list_tx in mptcp_pm_data (Florian Westphal) [1936368]
- mptcp: add rm_list in mptcp_out_options (Florian Westphal) [1936368]
- mptcp: fix bit MPTCP_PUSH_PENDING tests (Florian Westphal) [1936368]
- mptcp: fix length of ADD_ADDR with port sub-option (Florian Westphal) [1936368]
- mptcp: free resources when the port number is mismatched (Florian Westphal) [1936368]
- mptcp: fix missing wakeup (Florian Westphal) [1936368]
- mptcp: fix race in release_cb (Florian Westphal) [1936368]
- mptcp: factor out __mptcp_retrans helper() (Florian Westphal) [1936368]
- mptcp: reset 'first' and ack_hint on subflow close (Florian Westphal) [1936368]
- mptcp: dispose initial struct socket when its subflow is closed (Florian Westphal) [1936368]
- mptcp: fix memory accounting on allocation error (Florian Westphal) [1936368]
- mptcp: put subflow sock on connect error (Florian Westphal) [1936368]
- mptcp: reset last_snd on subflow close (Florian Westphal) [1936368]
- mptcp: do not wakeup listener for MPJ subflows (Florian Westphal) [1936368]
- mptcp: fix DATA_FIN generation on early shutdown (Florian Westphal) [1936368]
- mptcp: fix DATA_FIN processing for orphaned sockets (Florian Westphal) [1936368]
- mptcp: add local addr info in mptcp_info (Florian Westphal) [1936368]
- mptcp: add netlink event support (Florian Westphal) [1936368]
- mptcp: avoid lock_fast usage in accept path (Florian Westphal) [1936368]
- netlink: don't call ->netlink_bind with table lock held (Florian Westphal) [1936368]
- genetlink: restrict upcoming mptcp netlink events to CAP_NET_ADMIN (Florian Westphal) [1936368]
- mptcp: pass subflow socket to a few helpers (Florian Westphal) [1936368]
- mptcp: move subflow close loop after sk close check (Florian Westphal) [1936368]
- mptcp: schedule worker when subflow is closed (Florian Westphal) [1936368]
- mptcp: split __mptcp_close_ssk helper (Florian Westphal) [1936368]
- mptcp: move pm netlink work into pm_netlink (Florian Westphal) [1936368]
- mptcp: add a missing retransmission timer scheduling (Florian Westphal) [1936368]
- mptcp: better msk receive window updates (Florian Westphal) [1936368]
- mptcp: init mptcp request socket earlier (Florian Westphal) [1936368]
- mptcp: fix spurious retransmissions (Florian Westphal) [1936368]
- mptcp: fix poll after shutdown (Florian Westphal) [1936368]
- mptcp: deliver ssk errors to msk (Florian Westphal) [1936368]
- mptcp: pm: add lockdep assertions (Florian Westphal) [1936368]
- mptcp: add the mibs for ADD_ADDR with port (Florian Westphal) [1936368]
- mptcp: deal with MPTCP_PM_ADDR_ATTR_PORT in PM netlink (Florian Westphal) [1936368]
- mptcp: enable use_port when invoke addresses_equal (Florian Westphal) [1936368]
- mptcp: add port number check for MP_JOIN (Florian Westphal) [1936368]
- mptcp: add a new helper subflow_req_create_thmac (Florian Westphal) [1936368]
- mptcp: drop unused skb in subflow_token_join_request (Florian Westphal) [1936368]
- mptcp: create the listening socket for new port (Florian Westphal) [1936368]
- mptcp: create subflow or signal addr for newly added address (Florian Westphal) [1936368]
- mptcp: drop *_max fields in mptcp_pm_data (Florian Westphal) [1936368]
- mptcp: use WRITE_ONCE for the pernet *_max (Florian Westphal) [1936368]
- mptcp: pm nl: reduce variable scope (Florian Westphal) [1936368]
- mptcp: pm nl: support IPv4 mapped in v6 addresses (Florian Westphal) [1936368]
- mptcp: support MPJoin with IPv4 mapped in v6 sk (Florian Westphal) [1936368]
- mptcp: use sha256() instead of open coding (Florian Westphal) [1936368]
- crypto: lib/sha256 - add sha256() function (Florian Westphal) [1936368]
- mptcp: use SHA256_BLOCK_SIZE, not SHA_MESSAGE_BYTES (Florian Westphal) [1936368]
- xprtrdma: Pad optimization, revisited (Steve Dickson) [1926957]
- ibmvnic: remove set but not used variable 'netdev' (Diego Domingos) [1922193]
- net/ibmvnic: Remove tests of member address (Diego Domingos) [1922193]
- ibmvnic: remove duplicate napi_schedule call in do_reset function (Diego Domingos) [1922193]
- ibmvnic: avoid calling napi_disable() twice (Diego Domingos) [1922193]
- ibmvnic: queue reset work in system_long_wq (Diego Domingos) [1922193]
- ibmvnic: correctly use dev_consume/free_skb_irq (Diego Domingos) [1922193]
- ibmvnic: improve failover sysfs entry (Diego Domingos) [1922193]
- ibmvnic: print adapter state as a string (Diego Domingos) [1922193]
- ibmvnic: print reset reason as a string (Diego Domingos) [1922193]
- ibmvnic: clean up the remaining debugfs data structures (Diego Domingos) [1922193]
- ibmvnic: Use 'skb_frag_address()' instead of hand coding it (Diego Domingos) [1922193]
- ibmvnic: remove excessive irqsave (Diego Domingos) [1922193]
- ibmvnic: always store valid MAC address (Diego Domingos) [1922193]
- ibmvnic: Fix possibly uninitialized old_num_tx_queues variable warning. (Diego Domingos) [1922193]
- vio: make remove callback return void (Diego Domingos) [1922193]
- tty: hvcs: Drop unnecessary if block (Diego Domingos) [1922193]
- ibmvnic: serialize access to work queue on remove (Diego Domingos) [1922193]
- ibmvnic: skip send_request_unmap for timeout reset (Diego Domingos) [1922193]
- ibmvnic: add memory barrier to protect long term buffer (Diego Domingos) [1922193]
- ibmvnic: substitute mb() with dma_wmb() for send_*crq* functions (Diego Domingos) [1922193]
- ibmvnic: prefer strscpy over strlcpy (Diego Domingos) [1922193]
- ibmvnic: remove unused spinlock_t stats_lock definition (Diego Domingos) [1922193]
- ibmvnic: add comments for spinlock_t definitions (Diego Domingos) [1922193]
- ibmvnic: fix miscellaneous checks (Diego Domingos) [1922193]
- ibmvnic: avoid multiple line dereference (Diego Domingos) [1922193]
- ibmvnic: fix braces (Diego Domingos) [1922193]
- ibmvnic: fix block comments (Diego Domingos) [1922193]
- ibmvnic: prefer 'unsigned long' over 'unsigned long int' (Diego Domingos) [1922193]
- ibmvnic: remove unnecessary rmb() inside ibmvnic_poll (Diego Domingos) [1922193]
- ibmvnic: rework to ensure SCRQ entry reads are properly ordered (Diego Domingos) [1922193]
- ibmvnic: Ensure that CRQ entry read are correctly ordered (Diego Domingos) [1922193]
- net: ethernet: ibm: ibmvnic: Fix some kernel-doc misdemeanours (Diego Domingos) [1922193]
- powerpc/hmi: Fix kernel hang when TB is in error state. (Gustavo Walbon) [1924091]
- powerpc/eeh: Fix EEH handling for hugepages in ioremap space. (Gustavo Walbon) [1924090]
- powerpc/pseries: Only register vio drivers if vio bus exists (Gustavo Walbon) [1924090]
- powerpc/pci: Remove unimplemented prototypes (Gustavo Walbon) [1924090]
- powerpc/powernv/pci: Use kzalloc() for phb related allocations (Gustavo Walbon) [1924090]
- powerpc/pasemi: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/embedded6xx/mve5100: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/embedded6xx/mpc7448: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/embedded6xx/linkstation: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/embedded6xx/holly: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/chrp: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/amigaone: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/83xx: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/82xx/*: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/52xx/mpc5200_simple: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/52xx/media5200: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/52xx/lite5200: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/52xx/efika: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/512x: Move PHB discovery (Gustavo Walbon) [1924090]
- powerpc/pci: Move PHB discovery for PCI_DN using platforms (Gustavo Walbon) [1924090]
- powerpc/maple: Fix declaration made after definition (Gustavo Walbon) [1924090]
- powerpc/pci: Add ppc_md.discover_phbs() (Gustavo Walbon) [1924090]
- powerpc/pci: Delete traverse_pci_dn() (Gustavo Walbon) [1924090]
- powerpc/eeh: Rework pci_dev lookup in debugfs attributes (Gustavo Walbon) [1924090]
- selftests/powerpc: Add VF recovery tests (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Make pseries_send_allow_unfreeze() static (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Make pseries_pcibios_bus_add_device() static (Gustavo Walbon) [1924090]
- selftests/powerpc: Make the test check in eeh-basic.sh posix compliant (Gustavo Walbon) [1924090]
- powernv/pci: Print an error when device enable is blocked (Gustavo Walbon) [1924090]
- selftests/powerpc/eeh: disable kselftest timeout setting for eeh-basic (Gustavo Walbon) [1924090]
- powerpc/eeh_cache: Fix a possible debugfs deadlock (Gustavo Walbon) [1924090]
- powerpc/eeh: Fix eeh_dev_check_failure() for PE#0 (Gustavo Walbon) [1924090]
- selftests/powerpc: Fix eeh-basic.sh exit codes (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Fix use of uninitialised variable (Gustavo Walbon) [1924090]
- powerpc/eeh: Delete eeh_pe->config_addr (Gustavo Walbon) [1924090]
- powerpc/eeh: Clean up PE addressing (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Allow zero to be a valid PE configuration address (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Rework device EEH PE determination (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Clean up pe_config_addr lookups (Gustavo Walbon) [1924090]
- powerpc/eeh: Move EEH initialisation to an arch initcall (Gustavo Walbon) [1924090]
- powerpc/eeh: Delete eeh_ops->init (Gustavo Walbon) [1924090]
- powerpc/pseries: Stop using eeh_ops->init() (Gustavo Walbon) [1924090]
- powerpc/powernv: Stop using eeh_ops->init() (Gustavo Walbon) [1924090]
- powerpc/eeh: Rework EEH initialisation (Gustavo Walbon) [1924090]
- powerpc/pseries/eeh: Fix dumb linebreaks (Gustavo Walbon) [1924090]
- selftests/powerpc: Squash spurious errors due to device removal (Gustavo Walbon) [1924090]
- powerpc/eeh: Move PE tree setup into the platform (Gustavo Walbon) [1924090]
- powerpc/eeh: Drop pdn use in eeh_pe_tree_insert() (Gustavo Walbon) [1924090]
- powerpc/eeh: Rename eeh_{add_to|remove_from}_parent_pe() (Gustavo Walbon) [1924090]
- powerpc/eeh: Remove class code field from edev (Gustavo Walbon) [1924090]
- powerpc/eeh: Remove spurious use of pci_dn in eeh_dump_dev_log (Gustavo Walbon) [1924090]
- powerpc/eeh: Pass eeh_dev to eeh_ops->{read|write}_config() (Gustavo Walbon) [1924090]
- powerpc/eeh: Pass eeh_dev to eeh_ops->resume_notify() (Gustavo Walbon) [1924090]
- powerpc/eeh: Pass eeh_dev to eeh_ops->restore_config() (Gustavo Walbon) [1924090]
- powerpc/eeh: Remove VF config space restoration (Gustavo Walbon) [1924090]
- powerpc/eeh: Kill off eeh_ops->get_pe_addr() (Gustavo Walbon) [1924090]
- powerpc/pseries: Stop using pdn->pe_number (Gustavo Walbon) [1924090]
- powerpc/eeh: Move vf_index out of pci_dn and into eeh_dev (Gustavo Walbon) [1924090]
- powerpc/eeh: Remove eeh_dev.c (Gustavo Walbon) [1924090]
- powerpc/eeh: Remove eeh_dev_phb_init_dynamic() (Gustavo Walbon) [1924090]
- powerpc/powernv: Make pnv_pci_sriov_enable() and friends static (Gustavo Walbon) [1924090]
- powerpc/pseries: Make vio and ibmebus initcalls pseries specific (Gustavo Walbon) [1924090]
- powerpc/eeh: Release EEH device state synchronously (Gustavo Walbon) [1924090]
- powerpc/eeh: Rework eeh_ops->probe() (Gustavo Walbon) [1924090]
- powerpc/eeh: Make early EEH init pseries specific (Gustavo Walbon) [1924090]
- powerpc/eeh: Remove PHB check in probe (Gustavo Walbon) [1924090]
- powerpc/eeh: Do early EEH init only when required (Gustavo Walbon) [1924090]
- powerpc/eeh: Only dump stack once if an MMIO loop is detected (Gustavo Walbon) [1924090]
- powernv/pci: Add a debugfs entry to dump PHB's IODA PE state (Gustavo Walbon) [1924090]
- powernv/pci: Allow any write trigger the diag dump (Gustavo Walbon) [1924090]
- powernv/pci: Use pnv_phb as the private data for debugfs entries (Gustavo Walbon) [1924090]
- powerpc/powernv/npu: Fix debugfs_simple_attr.cocci warnings (Gustavo Walbon) [1924090]
- powerpc/pcidn: Warn when sriov pci_dn management is used incorrectly (Gustavo Walbon) [1924090]
- powerpc/pcidn: Make VF pci_dn management CONFIG_PCI_IOV specific (Gustavo Walbon) [1924090]
- powerpc/sriov: Remove VF eeh_dev state when disabling SR-IOV (Gustavo Walbon) [1924090]
- powerpc/eeh_sysfs: Make clearing EEH_DEV_SYSFS saner (Gustavo Walbon) [1924090]
- powerpc/eeh_sysfs: Remove double pci_dn lookup. (Gustavo Walbon) [1924090]
- powerpc/eeh_sysfs: ifdef pseries sr-iov sysfs properties (Gustavo Walbon) [1924090]
- powerpc/eeh_cache: Don't use pci_dn when inserting new ranges (Gustavo Walbon) [1924090]
- powerpc/eeh: differentiate duplicate detection message (Gustavo Walbon) [1924090]
- powerpc/eeh: Handle hugepages in ioremap space (Gustavo Walbon) [1924090]
- powerpc/powernv-eeh: Consisely desribe what this file does (Gustavo Walbon) [1924090]
- powerpc/eeh_cache: fix a W=1 kernel-doc warning (Gustavo Walbon) [1924090]
- powerpc/eeh_cache: Add a way to dump the EEH address cache (Gustavo Walbon) [1924090]
- powerpc/powernv: Escalate reset when IODA reset fails (Gustavo Walbon) [1924090]
- powerpc/powernv/eeh/npu: Fix uninitialized variables in opal_pci_eeh_freeze_status (Gustavo Walbon) [1924090]
- powerpc: eeh_event: convert semaphore to completion (Gustavo Walbon) [1924090]
- powerpc/eeh: Declare pci_ers_result_name() as static (Gustavo Walbon) [1924090]
- Bluetooth: verify AMP hci_chan before amp_destroy (Gopal Tiwari) [1962546] {CVE-2021-33034}
- NFSv4.2 fix handling of sr_eof in SEEK's reply (Steve Dickson) [1948015]
- SUNRPC: Fix null pointer dereference in svc_rqst_free() (Benjamin Coddington) [1952008]
- NFSv4: Use sequence counter with associated spinlock (Benjamin Coddington) [1952008]
- NFSv4.2: fix return value of _nfs4_get_security_label() (Benjamin Coddington) [1952008]
- NFSD: fix error handling in NFSv4.0 callbacks (Benjamin Coddington) [1952008]
- NFS: Don't gratuitously clear the inode cache when lookup failed (Benjamin Coddington) [1952008]
- NFS: Don't revalidate the directory permissions on a lookup failure (Benjamin Coddington) [1952008]
- nfsd: register pernet ops last, unregister first (Benjamin Coddington) [1952008]
- SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow() (Benjamin Coddington) [1952008]
- lockd: fix access beyond unterminated strings in prints (Benjamin Coddington) [1952008]
- tty: Protect disc_data in n_tty_close and n_tty_flush_buffer (Rafael Aquini) [1879861]
- hwmon: (amd_energy) Add AMD family 19h model 30h x86 match (Terry Bowman) [1949280]

* Mon Jun 28 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-319.el8]
- redhat/configs: Re-enable dptf_power module (Prarit Bhargava) [1962349]
- net/sched: act_ct: Offload connections with commit action (Marcelo Ricardo Leitner) [1965817]
- netfilter: flowtable: Remove redundant hw refresh bit (Marcelo Ricardo Leitner) [1965817]
- inet_diag: add support for tw_mark (Xin Long) [1972967]
- mm: thp: fix MADV_REMOVE deadlock on shmem THP (Waiman Long) [1974659] {CVE-2020-29368}
- mm: thp: make the THP mapcount atomic against __split_huge_pmd_locked() (Waiman Long) [1974659] {CVE-2020-29368}
- mmap locking API: add mmap_lock_is_contended() (Waiman Long) [1970177]
- mm: madvise: fix vma user-after-free (Waiman Long) [1970177]
- khugepaged: collapse_pte_mapped_thp() protect the pmd lock (Waiman Long) [1970177]
- khugepaged: collapse_pte_mapped_thp() flush the right range (Waiman Long) [1970177]
- mm/mmap.c: close race between munmap() and expand_upwards()/downwards() (Waiman Long) [1970177]
- mm: document warning in move_normal_pmd() and make it warn only once (Waiman Long) [1970177]
- mmap locking API: convert mmap_sem comments (Waiman Long) [1970177]
- mmap locking API: convert mmap_sem API comments (Waiman Long) [1970177]
- mmap locking API: rename mmap_sem to mmap_lock (Waiman Long) [1970177]
- mmap locking API: add mmap_assert_locked() and mmap_assert_write_locked() (Waiman Long) [1970177]
- mmap locking API: add MMAP_LOCK_INITIALIZER (Waiman Long) [1970177]
- mmap locking API: convert nested write lock sites (Waiman Long) [1970177]
- mmap locking API: convert mmap_sem call sites missed by coccinelle (Waiman Long) [1970177]
- mmap locking API: use coccinelle to convert mmap_sem rwsem call sites (Waiman Long) [1970177]
- MMU notifier: use the new mmap locking API (Waiman Long) [1970177]
- mm/gup.c: further document vma_permits_fault() (Waiman Long) [1970177]
- mm/gup.c: update the documentation (Waiman Long) [1970177]
- mm/ksm: fix NULL pointer dereference when KSM zero page is enabled (Waiman Long) [1970177]
- proc: inline vma_stop into m_stop (Waiman Long) [1970177]
- mm: remove CONFIG_TRANSPARENT_HUGE_PAGECACHE (Waiman Long) [1970177]
- fs/io_uring: set FOLL_PIN via pin_user_pages() (Waiman Long) [1970177]
- shmem: pin the file in shmem_fault() if mmap_sem is dropped (Waiman Long) [1970177]
- mm/gup.c: fix comments of __get_user_pages() and get_user_pages_remote() (Waiman Long) [1970177]
- mm/init-mm.c: include <linux/mman.h> for vm_committed_as_batch (Waiman Long) [1970177]
- lib/generic-radix-tree.c: add kmemleak annotations (Waiman Long) [1970177]
- mm: Remove BUG_ON mmap_sem not held from xxx_trans_huge_lock() (Waiman Long) [1970177]
- lib/generic-radix-tree.c: make 2 functions static inline (Waiman Long) [1970177]
- x86/mm: Clean up the pmd_read_atomic() comments (Waiman Long) [1970177]
- x86/mm: Fix function name typo in pmd_read_atomic() comment (Waiman Long) [1970177]
- khugepaged: enable collapse pmd for pte-mapped THP (Waiman Long) [1970177]
- mm: Handle MADV_WILLNEED through vfs_fadvise() (Waiman Long) [1970177]
- pagewalk: use lockdep_assert_held for locking validation (Waiman Long) [1970177]
- mm: use down_read_killable for locking mmap_sem in access_remote_vm (Waiman Long) [1970177]
- proc: use down_read_killable mmap_sem for /proc/pid/map_files (Waiman Long) [1970177]
- proc: use down_read_killable mmap_sem for /proc/pid/clear_refs (Waiman Long) [1970177]
- proc: use down_read_killable mmap_sem for /proc/pid/pagemap (Waiman Long) [1970177]
- proc: use down_read_killable mmap_sem for /proc/pid/smaps_rollup (Waiman Long) [1970177]
- proc: use down_read_killable mmap_sem for /proc/pid/maps (Waiman Long) [1970177]
- mm/filemap.c: correct the comment about VM_FAULT_RETRY (Waiman Long) [1970177]
- mm: mmu_gather: remove __tlb_reset_range() for force flush (Waiman Long) [1970177]
- arm64/mm: Drop mmap_sem before calling __do_kernel_fault() (Waiman Long) [1970177]
- docs/vm: Minor editorial changes in the THP and hugetlbfs (Waiman Long) [1970177]
- x86/mpx, mm/core: Fix recursive munmap() corruption (Waiman Long) [1970177]
- doc: mm: migration doesn't use FOLL_SPLIT anymore (Waiman Long) [1970177]
- filemap: add a comment about FAULT_FLAG_RETRY_NOWAIT behavior (Waiman Long) [1970177]
- proc: commit to genradix (Waiman Long) [1970177]
- generic radix trees (Waiman Long) [1970177]
- mm: swap: add comment for swap_vma_readahead (Waiman Long) [1970177]
- x86/mm: Make set_pmd_at() paravirt aware (Waiman Long) [1970177]
- mm: select HAVE_MOVE_PMD on x86 for faster mremap (Waiman Long) [1970177]
- mm: speed up mremap by 20x on large regions (Waiman Long) [1970177]
- mm/mmap.c: remove verify_mm_writelocked() (Waiman Long) [1970177]
- x86/fault: Check user_mode(regs) when avoiding an mmap_sem deadlock (Waiman Long) [1970177]
- mm: brk: downgrade mmap_sem to read when shrinking (Waiman Long) [1970177]
- mm: mremap: downgrade mmap_sem to read when shrinking (Waiman Long) [1970177]
- mm: unmap VM_PFNMAP mappings with optimized path (Waiman Long) [1970177]
- mm: unmap VM_HUGETLB mappings with optimized path (Waiman Long) [1970177]
- mm: mmap: zap pages with read mmap_sem in munmap (Waiman Long) [1970177]
- x86/mm: Fix exception table comments (Waiman Long) [1970177]
- ACPI: x86: Call acpi_boot_table_init() after acpi_table_upgrade() (Mark Langsdorf) [1946282]
- acpi/drivers/thermal: Remove TRIPS_NONE cooling device binding (Mark Langsdorf) [1946282]
- thermal/drivers/acpi: Use hot and critical ops (Mark Langsdorf) [1946282]
- thermal/core: Add critical and hot ops (Mark Langsdorf) [1946282]
- thermal/core: Emit a warning if the thermal zone is updated without ops (Mark Langsdorf) [1946282]
- ACPI: scan: Fix _STA getting called on devices with unmet dependencies (Mark Langsdorf) [1946282]
- ACPI: tables: x86: Reserve memory occupied by ACPI tables (Mark Langsdorf) [1946282]
- ACPICA: Always create namespace nodes using acpi_ns_create_node() (Mark Langsdorf) [1946282]
- ACPI: platform: Add balanced-performance platform profile (Mark Langsdorf) [1946282]
- ACPI: platform: Hide ACPI_PLATFORM_PROFILE option (Mark Langsdorf) [1946282]
- ACPICA: Remove some code duplication from acpi_ev_address_space_dispatch (Mark Langsdorf) [1946282]
- ACPICA: Fix race in generic_serial_bus (I2C) and GPIO op_region parameter handling (Mark Langsdorf) [1946282]
- ACPI: property: Satisfy kernel doc validator (part 2) (Mark Langsdorf) [1946282]
- ACPI: property: Satisfy kernel doc validator (part 1) (Mark Langsdorf) [1946282]
- ACPI: property: Make acpi_node_prop_read() static (Mark Langsdorf) [1946282]
- ACPI: property: Remove dead code (Mark Langsdorf) [1946282]
- iommu/amd: Fix performance counter initialization (Mark Langsdorf) [1946282]
- ACPI: property: Fix fwnode string properties matching (Mark Langsdorf) [1946282]
- ACPI / NUMA: add a stub function for node_to_pxm() (Mark Langsdorf) [1946282]
- ACPI: OSL: Rework acpi_check_resource_conflict() (Mark Langsdorf) [1946282]
- ACPI: APEI: ERST: remove unneeded semicolon (Mark Langsdorf) [1946282]
- iommu/vt-d: Add new enum value and structure for SATC (Mark Langsdorf) [1946282]
- ACPI: Add support for native USB4 control _OSC (Mark Langsdorf) [1946282]
- ACPI: Execute platform _OSC also with query bit clear (Mark Langsdorf) [1946282]
- redhat/configs: Add CONFIG_ACPI_FPDT (Mark Langsdorf) [1946282]
- ACPI: tables: introduce support for FPDT table (Mark Langsdorf) [1946282]
- ACPI: APEI: Add is_generic_error() to identify GHES sources (Mark Langsdorf) [1946282]
- ACPI: platform-profile: Fix possible deadlock in platform_profile_remove() (Mark Langsdorf) [1946282]
- ACPI: platform-profile: Introduce object pointers to callbacks (Mark Langsdorf) [1946282]
- PCI/ACPI: Clarify message about _OSC failure (Mark Langsdorf) [1946282]
- PCI/ACPI: Remove unnecessary osc_lock (Mark Langsdorf) [1946282]
- PCI/ACPI: Make acpi_pci_osc_control_set() static (Mark Langsdorf) [1946282]
- media: ACPI / bus: Add acpi_dev_get_next_match_dev() and helper macro (Mark Langsdorf) [1946282]
- ACPI: scan: Adjust white space in acpi_device_add() (Mark Langsdorf) [1946282]
- ACPI: scan: Rearrange memory allocation in acpi_device_add() (Mark Langsdorf) [1946282]
- ACPI: platform-profile: Drop const qualifier for cur_profile (Mark Langsdorf) [1946282]
- ACPI: configfs: add missing check after configfs_register_default_group() (Mark Langsdorf) [1946282]
- ACPI: CPPC: initialise vaddr pointers to NULL (Mark Langsdorf) [1946282]
- ACPI: CPPC: add __iomem annotation to generic_comm_base pointer (Mark Langsdorf) [1946282]
- ACPI: CPPC: remove __iomem annotation for cpc_reg's address (Mark Langsdorf) [1946282]
- ACPI: Use DEVICE_ATTR_<RW|RO|WO> macros (Mark Langsdorf) [1946282]
- ACPICA: Update version to 20210105 (Mark Langsdorf) [1946282]
- ACPICA: Updated all copyrights to 2021 (Mark Langsdorf) [1946282]
- ACPICA: Remove the VRTC table (Mark Langsdorf) [1946282]
- ACPICA: Remove the MTMR (Mid-Timer) table (Mark Langsdorf) [1946282]
- ACPICA: Update version to 20201217 (Mark Langsdorf) [1946282]
- ACPICA: add type casts for string functions (Mark Langsdorf) [1946282]
- ACPICA: fix -Wfallthrough (Mark Langsdorf) [1946282]
- ACPICA: Clean up exception code class checks (Mark Langsdorf) [1946282]
- ACPICA: Fix exception code class checks (Mark Langsdorf) [1946282]
- redhat/configs: Add CONFIG_ACPI_PLATFORM_PROFILE (Mark Langsdorf) [1946282]
- ACPI: platform: Add platform profile support (Mark Langsdorf) [1946282]
- NTB/msi: Use irq_has_action() (Myron Stowe) [1933153]
- NTB: Use struct_size() helper in devm_kzalloc() (Myron Stowe) [1933153]
- ntb: intel: Fix memleak in intel_ntb_pci_probe (Myron Stowe) [1933153]
- NTB: hw: amd: fix an issue about leak system resources (Myron Stowe) [1933153]
- ntb: hw: remove the code that sets the DMA mask (Myron Stowe) [1933153]
- [s390] s390/qdio: remove 'merge_pending' mechanism (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: improve handling of PENDING buffers for QEBSM devices (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: rework q->qdio_error indication (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: inline qdio_kick_handler() (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: track time of last data IRQ for each device (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: make thinint registration symmetric (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: adopt new tasklet API (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: remove qdio_inbound_q_moved() wrapper (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: remove Input tasklet code (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Do not set COMMAND_COMPLETE (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Handle event-lost notification for Version Change events (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Process Version Change events (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Clarify & assert the stat_lock locking in zfcp_qdio_send() (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Remove orphaned function declarations (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Lift Input Queue tasklet from qdio (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Clarify access to erp_action in zfcp_fsf_req_complete() (Claudio Imbrenda) [1919251]
- [s390] scsi: zfcp: Use list_first_entry_or_null() in zfcp_erp_thread() (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: always use dev_name() for device name in QIB (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: clean up QDR setup (Claudio Imbrenda) [1919251]
- [s390] s390/qdio: make qdio_handle_aobs() more robust (Claudio Imbrenda) [1919251]
- [s390] s390/cpumf: disable preemption when accessing per-cpu variable (Claudio Imbrenda) [1925527]
- [s390] s390/cpumf: rename header file to hwctrset.h (Claudio Imbrenda) [1925527]
- [s390] s390/cpumf: remove 60 seconds read limit (Claudio Imbrenda) [1925527]
- [s390] s390/cpumf: Add support for complete counter set extraction (Claudio Imbrenda) [1925527]

* Fri Jun 25 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-318.el8]
- KVM: X86: hyper-v: Task srcu lock when accessing kvm_memslots() (Vitaly Kuznetsov) [1904570]
- KVM: nSVM: remove a warning about vmcb01 VM exit reason (Vitaly Kuznetsov) [1904570]
- KVM: x86: Consolidate guest enter/exit logic to common helpers (Vitaly Kuznetsov) [1904570]
- KVM: x86: Defer vtime accounting 'til after IRQ handling (Vitaly Kuznetsov) [1904570]
- context_tracking: Move guest exit vtime accounting to separate helpers (Vitaly Kuznetsov) [1904570]
- context_tracking: Move guest exit context tracking to separate helpers (Vitaly Kuznetsov) [1904570]
- context_tracking: Make guest_enter/exit() .noinstr ready (Vitaly Kuznetsov) [1904570]
- sched/cputime: Rename vtime_account_system() to vtime_account_kernel() (Vitaly Kuznetsov) [1904570]
- x86/kvm/svm: Move guest enter/exit into .noinstr.text (Vitaly Kuznetsov) [1904570]
- x86/kvm/vmx: Move guest enter/exit into .noinstr.text (Vitaly Kuznetsov) [1904570]
- x86/kvm/svm: Add hardirq tracing on guest enter/exit (Vitaly Kuznetsov) [1904570]
- x86/kvm/vmx: Add hardirq tracing to guest enter/exit (Vitaly Kuznetsov) [1904570]
- x86/kvm: Move context tracking where it belongs (Vitaly Kuznetsov) [1904570]
- Move some more variables to kernel job templates (Michael Hofmann)
- Use a different branch name for realtime pipelines (Michael Hofmann)
- block: mark queue init done at the end of blk_register_queue (Ming Lei) [1963766]
- block: fix race between adding/removing rq qos and normal IO (Ming Lei) [1963766]
- netfilter: x_tables: Use correct memory barriers. (Phil Sutter) [1949090]
- Revert "netfilter: x_tables: Switch synchronization to RCU" (Phil Sutter) [1949090]
- vfio/pci/nvlink2: Do not attempt NPU2 setup on POWER8NVL NPU (Gustavo Walbon) [1891589]
- powerpc/powernv/npu: Do not attempt NPU2 setup on POWER8NVL NPU (Gustavo Walbon) [1891589]
- cpupower: Add cpuid cap flag for MSR_AMD_HWCR support (Steve Best) [1949161]
- cpupower: Remove family arg to decode_pstates() (Steve Best) [1949161]
- cpupower: Condense pstate enabled bit checks in decode_pstates() (Steve Best) [1949161]
- cpupower: Update family checks when decoding HW pstates (Steve Best) [1949161]
- cpupower: Remove unused pscur variable. (Steve Best) [1949161]
- cpupower: Add CPUPOWER_CAP_AMD_HW_PSTATE cpuid caps flag (Steve Best) [1949161]
- cpupower: Correct macro name for CPB caps flag (Steve Best) [1949161]
- cpupower: Update msr_pstate union struct naming (Steve Best) [1949161]
- cpupower: add Makefile dependencies for install targets (Steve Best) [1949161]
- tools/power/cpupower: Read energy_perf_bias from sysfs (Steve Best) [1949161]
- tools: Avoid comma separated statements (Steve Best) [1949161]
- cpupower: speed up generating git version string (Steve Best) [1949161]
- cpupowerutils: fix spelling mistake "dependant" -> "dependent" (Steve Best) [1949161]
- ext4: fix ext4_error_err save negative errno into superblock (Lukas Czerner) [1964928]
- ext4: do not set SB_ACTIVE in ext4_orphan_cleanup() (Lukas Czerner) [1964928]
- ext4: fix check to prevent false positive report of incorrect used inodes (Lukas Czerner) [1964928]
- ext4: fix potential error in ext4_do_update_inode (Lukas Czerner) [1964928]
- ext4: do not try to set xattr into ea_inode if value is empty (Lukas Czerner) [1964928]
- ext4: fix potential htree index checksum corruption (Lukas Czerner) [1964928]
- ext4: don't leak old mountpoint samples (Lukas Czerner) [1964928]
- ext4: don't remount read-only with errors=continue on reboot (Lukas Czerner) [1964928]
- ext4: fix deadlock with fs freezing and EA inodes (Lukas Czerner) [1964928]
- ext4: fix a memory leak of ext4_free_data (Lukas Czerner) [1964928]
- ext4: find old entry again if failed to rename whiteout (Lukas Czerner) [1945503]
- ext4: fix bug for rename with RENAME_WHITEOUT (Lukas Czerner) [1945503]
- mount: fix mounting of detached mounts onto targets that reside on shared mounts (Carlos Maiolino) [1959172]
- fs: fix lazytime expiration handling in __writeback_single_inode() (Carlos Maiolino) [1936260]
- tty: Don't hold ldisc lock in tty_reopen() if ldisc present (Waiman Long) [1968271]
- tty/ldsem: Add lockdep asserts for ldisc_sem (Waiman Long) [1968271]
- tty: Simplify tty->count math in tty_reopen() (Waiman Long) [1968271]
- tty: Don't block on IO when ldisc change is pending (Waiman Long) [1968271]
- tty: Hold tty_ldisc_lock() during tty_reopen() (Waiman Long) [1968271]
- tty: Drop tty->count on tty_reopen() failure (Waiman Long) [1968271]
- net: udp: Add support for getsockopt(..., ..., UDP_GRO, ..., ...); (Xin Long) [1951679]
- net: Fix gro aggregation for udp encaps with zero csum (Xin Long) [1951679]
- udp: ipv4: manipulate network header of NATed UDP GRO fraglist (Xin Long) [1951679]
- udp: not remove the CRC flag from dev features when need_csum is false (Xin Long) [1951679]
- udp: mask TOS bits in udp_v4_early_demux() (Xin Long) [1951679]
- net: fix use-after-free when UDP GRO with shared fraglist (Xin Long) [1951679]
- x86, sched: Treat Intel SNC topology as default, COD as exception (David Arcari) [1920040]
- dmaengine: idxd: iax bus removal (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix cdev setup and free device lifetime issues (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix group conf_dev lifetime (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix engine conf_dev lifetime (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix wq conf_dev 'struct device' lifetime (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix idxd conf_dev 'struct device' lifetime (Jerry Snitselaar) [1955744]
- dmaengine: idxd: use ida for device instance enumeration (Jerry Snitselaar) [1955744]
- dmaengine: idxd: removal of pcim managed mmio mapping (Jerry Snitselaar) [1955744]
- dmaengine: idxd: cleanup pci interrupt vector allocation management (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix dma device lifetime (Jerry Snitselaar) [1955744]
- dmaengine: idxd: Fix potential null dereference on pointer status (Jerry Snitselaar) [1927070]
- dmaengine: idxd: fix wq cleanup of WQCFG registers (Jerry Snitselaar) [1955744]
- dmaengine: idxd: clear MSIX permission entry on shutdown (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix wq size store permission state (Jerry Snitselaar) [1955744]
- dmaengine: idxd: fix opcap sysfs attribute output (Jerry Snitselaar) [1955744]
- dmaengine: idxd: Fix clobbering of SWERR overflow bit on writeback (Jerry Snitselaar) [1955744]
- dmaengine: idxd: add module parameter to force disable of SVA (Jerry Snitselaar) [1920734]
- dmaengine: idxd: set DMA channel to be private (Jerry Snitselaar) [1920759]
- dma: idxd: use DEFINE_MUTEX() for mutex lock (Jerry Snitselaar) [1955744]
- dmaengine: idxd: check device state before issue command (Jerry Snitselaar) [1927070]
- dmaengine: move channel device_node deletion to driver (Jerry Snitselaar) [1920721]
- dmaengine: idxd: fix misc interrupt completion (Jerry Snitselaar) [1920757]
- dmaengine: idxd: Fix list corruption in description completion (Jerry Snitselaar) [1920746]
- dmaengine: idxd: add IAX configuration support in the IDXD driver (Jerry Snitselaar) [1837233]
- dmaengine: idxd: add ATS disable knob for work queues (Jerry Snitselaar) [1921291]
- dmaengine: idxd: define table offset multiplier (Jerry Snitselaar) [1921290]
- dmaengine: idxd: Update calculation of group offset to be more readable (Jerry Snitselaar) [1955744]

* Wed Jun 23 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-317.el8]
- redhat/config: Double MAX_LOCKDEP_ENTRIES (Waiman Long) [1945937]
- dm writecache: flush origin device when writing and cache is full (Mike Snitzer) [1970513]
- dm snapshot: properly fix a crash when an origin has no snapshots (Mike Snitzer) [1970513]
- dm verity: fix require_signatures module_param permissions (Mike Snitzer) [1970513]
- dm snapshot: fix crash with transient storage and zero chunk size (Mike Snitzer) [1970513]
- dm rq: fix double free of blk_mq_tag_set in dev remove after table load fails (Mike Snitzer) [1970513]
- dm integrity: increase RECALC_SECTORS to improve recalculate speed (Mike Snitzer) [1970513]
- dm integrity: don't re-write metadata if discarding same blocks (Mike Snitzer) [1970513]
- dm raid: fix inconclusive reshape layout on fast raid4/5/6 table reload sequences (Mike Snitzer) [1970513]
- dm raid: fix fall-through warning in rs_check_takeover() for Clang (Mike Snitzer) [1970513]
- dm integrity: fix missing goto in bitmap_flush_interval error handling (Mike Snitzer) [1970513]
- dm space map common: fix division bug in sm_ll_find_free_block() (Mike Snitzer) [1970513]
- dm persistent data: packed struct should have an aligned() attribute too (Mike Snitzer) [1970513]
- dm btree spine: remove paranoid node_check call in node_prep_for_write() (Mike Snitzer) [1970513]
- dm space map disk: remove redundant calls to sm_disk_get_nr_free() (Mike Snitzer) [1970513]
- dm persistent data: remove unused return from exit_shadow_spine() (Mike Snitzer) [1970513]
- dm verity: allow only one error handling mode (Mike Snitzer) [1970513]
- dm: remove useless loop in __split_and_process_bio (Mike Snitzer) [1970513]
- redhat/configs: Update CONFIG_PINCTRL_AMD (David Arcari) [1964588]
- ionic: fix ptp support config breakage (Jonathan Toppins) [1951826]
- ionic: return -EFAULT if copy_to_user() fails (Jonathan Toppins) [1951826]
- ionic: git_ts_info bit shifters (Jonathan Toppins) [1951826]
- ionic: extend ts_config set locking (Jonathan Toppins) [1951826]
- ionic: add ts_config replay (Jonathan Toppins) [1951826]
- ionic: ignore EBUSY on queue start (Jonathan Toppins) [1951826]
- ionic: re-start ptp after queues up (Jonathan Toppins) [1951826]
- ionic: add SKBTX_IN_PROGRESS (Jonathan Toppins) [1951826]
- ionic: check for valid tx_mode on SKBTX_HW_TSTAMP xmit (Jonathan Toppins) [1951826]
- ionic: remove unnecessary compat ifdef (Jonathan Toppins) [1951826]
- ionic: fix up a couple of code style nits (Jonathan Toppins) [1951826]
- ionic: advertise support for hardware timestamps (Jonathan Toppins) [1951826]
- ionic: ethtool ptp stats (Jonathan Toppins) [1951826]
- ionic: add ethtool support for PTP (Jonathan Toppins) [1951826]
- ionic: add and enable tx and rx timestamp handling (Jonathan Toppins) [1951826]
- ethtool: add timestamping related string sets (Jonathan Toppins) [1951826]
- net: Introduce peer to peer one step PTP time stamping. (Jonathan Toppins) [1951826]
- ionic: set up hw timestamp queues (Jonathan Toppins) [1951826]
- ionic: add rx filtering for hw timestamp steering (Jonathan Toppins) [1951826]
- ionic: link in the new hw timestamp code (Jonathan Toppins) [1951826]
- ionic: add hw timestamp support files (Jonathan Toppins) [1951826]
- ionic: split adminq post and wait calls (Jonathan Toppins) [1951826]
- ionic: add hw timestamp structs to interface (Jonathan Toppins) [1951826]
- ionic: add handling of larger descriptors (Jonathan Toppins) [1951826]
- ionic: add new queue features to interface (Jonathan Toppins) [1951826]
- ionic: pull per-q stats work out of queue loops (Jonathan Toppins) [1951826]
- ionic: avoid races in ionic_heartbeat_check (Jonathan Toppins) [1951826]
- ionic: fix sizeof usage (Jonathan Toppins) [1951826]
- ionic: count dma errors (Jonathan Toppins) [1951826]
- ionic: protect adminq from early destroy (Jonathan Toppins) [1951826]
- ionic: stop watchdog when in broken state (Jonathan Toppins) [1951826]
- ionic: block actions during fw reset (Jonathan Toppins) [1951826]
- ionic: update ethtool support bits for BASET (Jonathan Toppins) [1951826]
- ionic: fix unchecked reference (Jonathan Toppins) [1951826]
- ionic: simplify the intr_index use in txq_init (Jonathan Toppins) [1951826]
- ionic: code cleanup details (Jonathan Toppins) [1951826]
- ionic: Update driver to use ethtool_sprintf (Jonathan Toppins) [1951826]
- ionic: aggregate Tx byte counting calls (Jonathan Toppins) [1951826]
- ionic: simplify tx clean (Jonathan Toppins) [1951826]
- ionic: generic tx skb mapping (Jonathan Toppins) [1951826]
- ionic: simplify TSO descriptor mapping (Jonathan Toppins) [1951826]
- ionic: simplify use of completion types (Jonathan Toppins) [1951826]
- ionic: rebuild debugfs on qcq swap (Jonathan Toppins) [1951826]
- ionic: simplify rx skb alloc (Jonathan Toppins) [1951826]
- ionic: optimize fastpath struct usage (Jonathan Toppins) [1951826]
- ionic: implement Rx page reuse (Jonathan Toppins) [1951826]
- ionic: move rx_page_alloc and free (Jonathan Toppins) [1951826]
- drivers: net: ionic: simplify the return expression of ionic_set_rxfh() (Jonathan Toppins) [1951826]
- ionic: change mtu after queues are stopped (Jonathan Toppins) [1951826]
- ionic: remove some unnecessary oom messages (Jonathan Toppins) [1951826]
- ionic: useful names for booleans (Jonathan Toppins) [1951826]
- ionic: change set_rx_mode from_ndo to can_sleep (Jonathan Toppins) [1951826]
- ionic: flatten calls to ionic_lif_rx_mode (Jonathan Toppins) [1951826]
- ionic: batch rx buffer refilling (Jonathan Toppins) [1951826]
- ionic: add lif quiesce (Jonathan Toppins) [1951826]
- ionic: check for link after netdev registration (Jonathan Toppins) [1951826]
- ionic: check port ptr before use (Jonathan Toppins) [1951826]
- platform/x86: hp-wireless: add AMD's hardware id to the supported list (David Arcari) [1960472]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 1 (David Arcari) [1960472]
- net/bond: revert deletion of driver and module versions (Jarod Wilson) [1955702]
- net:sfc: fix non-freed irq in legacy irq mode (Íñigo Huguet) [1906728]
- devlink: Extend SF port attributes to have external attribute (Petr Oros) [1959002]
- netfilter: xt_SECMARK: add new revision to fix structure layout (Phil Sutter) [1961714]
- xfrm: ipcomp: remove unnecessary get_cpu() (Sabrina Dubroca) [1946885]
- platform/x86: intel_pmc_core: Add support for Alder Lake PCH-P (David Arcari) [1838624]
- scsi: qedf: Update the max_id value in host structure (Nilesh Javali) [1954876]
- scsi: qedf: Add pointer checks in qedf_update_link_speed() (Nilesh Javali) [1871687]
- [s390] s390/nvme: support firmware-assisted dump to NVMe disks (Claudio Imbrenda) [1847447]
- [s390] s390: nvme dump support (Claudio Imbrenda) [1847447]
- [s390] s390/boot: add build-id to decompressor (Philipp Rudo) [1897093]
- genirq: Reduce irqdebug cacheline bouncing (Gustavo Walbon) [1957729]

* Mon Jun 21 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-316.el8]
- CI: Merge MR, baseline and private configs (Michael Hofmann)
- RDMA/rxe: Fix failure during driver load (Kamal Heib) [1930263]
- xfrm: remove the fragment check for ipv6 beet mode (Xin Long) [1965185]
- SUNRPC: Fix NFS READs that start at non-page-aligned offsets (Benjamin Coddington) [1950303]
- pNFS/NFSv4: Improve rejection of out-of-order layouts (Benjamin Coddington) [1950303]
- pNFS/NFSv4: Update the layout barrier when we schedule a layoutreturn (Benjamin Coddington) [1950303]
- pNFS/NFSv4: Try to return invalid layout in pnfs_layout_process() (Benjamin Coddington) [1950303]
- SUNRPC: Move the svc_xdr_recvfrom tracepoint again (Benjamin Coddington) [1950303]
- nfsd4: readdirplus shouldn't return parent of export (Benjamin Coddington) [1950303]
- NFS: nfs_igrab_and_active must first reference the superblock (Benjamin Coddington) [1950303]
- NFS: nfs_delegation_find_inode_server must first reference the superblock (Benjamin Coddington) [1950303]
- NFS/pNFS: Fix a leak of the layout 'plh_outstanding' counter (Benjamin Coddington) [1950303]
- NFS/pNFS: Don't leak DS commits in pnfs_generic_retry_commit() (Benjamin Coddington) [1950303]
- NFS/pNFS: Don't call pnfs_free_bucket_lseg() before removing the request (Benjamin Coddington) [1950303]
- pNFS: Stricter ordering of layoutget and layoutreturn (Benjamin Coddington) [1950303]
- pNFS: Clean up pnfs_layoutreturn_free_lsegs() (Benjamin Coddington) [1950303]
- pNFS: We want return-on-close to complete when evicting the inode (Benjamin Coddington) [1950303]
- pNFS: Mark layout for return if return-on-close was not sent (Benjamin Coddington) [1950303]
- net: sunrpc: interpret the return value of kstrtou32 correctly (Benjamin Coddington) [1950303]
- SUNRPC: Handle TCP socket sends with kernel_sendpage() again (Benjamin Coddington) [1950303]
- NFS/pNFS: Fix a typo in ff_layout_resend_pnfs_read() (Benjamin Coddington) [1950303]
- pNFS/flexfiles: Avoid spurious layout returns in ff_layout_choose_ds_for_read (Benjamin Coddington) [1950303]
- NFSv4/pnfs: Add tracing for the deviceid cache (Benjamin Coddington) [1950303]
- fs/lockd: convert comma to semicolon (Benjamin Coddington) [1950303]
- SUNRPC: When expanding the buffer, we may need grow the sparse pages (Benjamin Coddington) [1950303]
- SUNRPC: Cleanup - constify a number of xdr_buf helpers (Benjamin Coddington) [1950303]
- SUNRPC: Clean up open coded setting of the xdr_stream 'nwords' field (Benjamin Coddington) [1950303]
- SUNRPC: _copy_to/from_pages() now check for zero length (Benjamin Coddington) [1950303]
- SUNRPC: Cleanup xdr_shrink_bufhead() (Benjamin Coddington) [1950303]
- SUNRPC: Fix xdr_expand_hole() (Benjamin Coddington) [1950303]
- SUNRPC: Fixes for xdr_align_data() (Benjamin Coddington) [1950303]
- SUNRPC: _shift_data_left/right_pages should check the shift length (Benjamin Coddington) [1950303]
- NFSv4.1: use BITS_PER_LONG macro in nfs4session.h (Benjamin Coddington) [1950303]
- xprtrdma: Fix XDRBUF_SPARSE_PAGES support (Benjamin Coddington) [1950303]
- sunrpc: fix xs_read_xdr_buf for partial pages receive (Benjamin Coddington) [1950303]
- Revert "nfsd4: support change_attr_type attribute" (Benjamin Coddington) [1950303]
- nfsd4: don't query change attribute in v2/v3 case (Benjamin Coddington) [1950303]
- nfsd: minor nfsd4_change_attribute cleanup (Benjamin Coddington) [1950303]
- nfsd: simplify nfsd4_change_info (Benjamin Coddington) [1950303]
- nfsd: only call inode_query_iversion in the I_VERSION case (Benjamin Coddington) [1950303]
- nfs_common: need lock during iterate through the list (Benjamin Coddington) [1950303]
- nfsd: Fix message level for normal termination (Benjamin Coddington) [1950303]
- NFS: switch nfsiod to be an UNBOUND workqueue. (Benjamin Coddington) [1950303]
- lockd: don't use interval-based rebinding over TCP (Benjamin Coddington) [1950303]
- net: sunrpc: Fix 'snprintf' return value check in 'do_xprt_debugfs' (Benjamin Coddington) [1950303]
- NFSv4: Refactor to use user namespaces for nfs4idmap (Benjamin Coddington) [1950303]
- NFS: NFSv2/NFSv3: Use cred from fs_context during mount (Benjamin Coddington) [1950303]
- NFSv4: Fix a pNFS layout related use-after-free race when freeing the inode (Benjamin Coddington) [1950303]
- SUNRPC: Fix up xdr_set_page() (Benjamin Coddington) [1950303]
- SUNRPC: Fix open coded xdr_stream_remaining() (Benjamin Coddington) [1950303]
- pNFS: Clean up open coded xdr string decoding (Benjamin Coddington) [1950303]
- SUNRPC: Fix up open coded kmemdup_nul() (Benjamin Coddington) [1950303]
- pNFS/flexfiles: Fix up layoutstats reporting for non-TCP transports (Benjamin Coddington) [1950303]
- NFSv4/pNFS: Store the transport type in struct nfs4_pnfs_ds_addr (Benjamin Coddington) [1950303]
- pNFS: Add helpers for allocation/free of struct nfs4_pnfs_ds_addr (Benjamin Coddington) [1950303]
- NFSv4/pNFS: Use connections to a DS that are all of the same protocol family (Benjamin Coddington) [1950303]
- SUNRPC: Remove unused function xprt_load_transport() (Benjamin Coddington) [1950303]
- NFS: Switch mount code to use xprt_find_transport_ident() (Benjamin Coddington) [1950303]
- SUNRPC: Add a helper to return the transport identifier given a netid (Benjamin Coddington) [1950303]
- SUNRPC: Close a race with transport setup and module put (Benjamin Coddington) [1950303]
- SUNRPC: xprt_load_transport() needs to support the netid "rdma6" (Benjamin Coddington) [1950303]
- SUNRPC: rpc_wake_up() should wake up tasks in the correct order (Benjamin Coddington) [1950303]
- NFSv4: Observe the NFS_MOUNT_SOFTREVAL flag in _nfs4_proc_lookupp (Benjamin Coddington) [1950303]
- NFSv3: Add emulation of the lookupp() operation (Benjamin Coddington) [1950303]
- NFSv3: Refactor nfs3_proc_lookup() to split out the dentry (Benjamin Coddington) [1950303]
- SUNRPC: Remove XDRBUF_SPARSE_PAGES flag in gss_proxy upcall (Benjamin Coddington) [1950303]
- NFSD: Add tracepoints in nfsd4_decode/encode_compound() (Benjamin Coddington) [1950303]
- NFSD: Add tracepoints in nfsd_dispatch() (Benjamin Coddington) [1950303]
- NFSD: Add common helpers to decode void args and encode void results (Benjamin Coddington) [1950303]
- SUNRPC: Prepare for xdr_stream-style decoding on the server-side (Benjamin Coddington) [1950303]
- SUNRPC: Add xdr_set_scratch_page() and xdr_reset_scratch_buffer() (Benjamin Coddington) [1950303]
- NFSD: Add SPDX header for fs/nfsd/trace.c (Benjamin Coddington) [1950303]
- SUNRPC: Move the svc_xdr_recvfrom() tracepoint (Benjamin Coddington) [1950303]
- NFSD: Add SPDX header for fs/nfsd/trace.c (Benjamin Coddington) [1950303]
- NFSD: A semicolon is not needed after a switch statement. (Benjamin Coddington) [1950303]
- svcrdma: support multiple Read chunks per RPC (Benjamin Coddington) [1950303]
- svcrdma: Use the new parsed chunk list when pulling Read chunks (Benjamin Coddington) [1950303]
- svcrdma: Rename info::ri_chunklen (Benjamin Coddington) [1950303]
- svcrdma: Clean up chunk tracepoints (Benjamin Coddington) [1950303]
- svcrdma: Remove chunk list pointers (Benjamin Coddington) [1950303]
- svcrdma: Support multiple Write chunks in svc_rdma_send_reply_chunk (Benjamin Coddington) [1950303]
- svcrdma: Support multiple Write chunks in svc_rdma_map_reply_msg() (Benjamin Coddington) [1950303]
- svcrdma: Support multiple write chunks when pulling up (Benjamin Coddington) [1950303]
- svcrdma: Use parsed chunk lists to encode Reply transport headers (Benjamin Coddington) [1950303]
- svcrdma: Use parsed chunk lists to construct RDMA Writes (Benjamin Coddington) [1950303]
- svcrdma: Use parsed chunk lists to detect reverse direction replies (Benjamin Coddington) [1950303]
- svcrdma: Use parsed chunk lists to derive the inv_rkey (Benjamin Coddington) [1950303]
- svcrdma: Add a "parsed chunk list" data structure (Benjamin Coddington) [1950303]
- svcrdma: Clean up svc_rdma_encode_reply_chunk() (Benjamin Coddington) [1950303]
- svcrdma: Post RDMA Writes while XDR encoding replies (Benjamin Coddington) [1950303]
- NFSD: Invoke svc_encode_result_payload() in "read" NFSD encoders (Benjamin Coddington) [1950303]
- SUNRPC: Rename svc_encode_read_payload() (Benjamin Coddington) [1950303]
- svcrdma: Refactor the RDMA Write path (Benjamin Coddington) [1950303]
- svcrdma: Const-ify the xdr_buf arguments (Benjamin Coddington) [1950303]
- SUNRPC: Adjust synopsis of xdr_buf_subsegment() (Benjamin Coddington) [1950303]
- svcrdma: Catch another Reply chunk overflow case (Benjamin Coddington) [1950303]
- xprtrdma: Micro-optimize MR DMA-unmapping (Benjamin Coddington) [1950303]
- xprtrdma: Move rpcrdma_mr_put() (Benjamin Coddington) [1950303]
- xprtrdma: Trace unmap_sync calls (Benjamin Coddington) [1950303]
- xprtrdma: Display the task ID when reporting MR events (Benjamin Coddington) [1950303]
- xprtrdma: Clean up trace_xprtrdma_nomrs() (Benjamin Coddington) [1950303]
- xprtrdma: Clean up xprtrdma callback tracepoints (Benjamin Coddington) [1950303]
- xprtrdma: Clean up tracepoints in the reply path (Benjamin Coddington) [1950303]
- xprtrdma: Clean up reply parsing error tracepoints (Benjamin Coddington) [1950303]
- xprtrdma: Clean up trace_xprtrdma_post_linv (Benjamin Coddington) [1950303]
- xprtrdma: Introduce FRWR completion IDs (Benjamin Coddington) [1950303]
- xprtrdma: Introduce Send completion IDs (Benjamin Coddington) [1950303]
- xprtrdma: Introduce Receive completion IDs (Benjamin Coddington) [1950303]
- xprtrdma: Replace dprintk call sites in ERR_CHUNK path (Benjamin Coddington) [1950303]
- xprtrdma: Fix a BUG when tracing is enabled with NFSv4.1 on RDMA (Benjamin Coddington) [1950303]
- drm: virtio: fix common struct sg_table related issues (Eric Auger) [1971821]
- net/mlx5e: Release skb in case of failure in tc update skb (Alaa Hleihel) [1915307]
- net/mlx5: Release devlink object if adev fails (Alaa Hleihel) [1915307]
- net/mlx5: Fix compilation warning for 32-bit platform (Alaa Hleihel) [1915307]
- net/mlx5: Use effective interrupt affinity (Alaa Hleihel) [1915307]
- net/mlx5: Replace irq_to_desc() abuse (Alaa Hleihel) [1915307]
- RDMA/mlx5: Remove unneeded semicolon (Alaa Hleihel) [1915307]
- net: mlx5: convert comma to semicolon (Alaa Hleihel) [1915307]
- net/mlx5e: Fill mlx5e_create_cq_param in a function (Alaa Hleihel) [1915307]
- net/mlx5e: Split between RX/TX tunnel FW support indication (Alaa Hleihel) [1915307]
- net/mlx5: Arm only EQs with EQEs (Alaa Hleihel) [1915307]
- net/mlx5e: Remove duplicated include (Alaa Hleihel) [1915307]
- net/mlx5e: Add TX port timestamp support (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Add TX PTP port object support (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Move MLX5E_RX_ERR_CQE macro (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Split SW group counters update function (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Change skb fifo push/pop API to be used without SQ (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Allow SQ outside of channel context (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Allow RQ outside of channel context (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Allow CQ outside of channel context (Alaa Hleihel) [1915307 1919646]
- net/mlx5e: Free drop RQ in a dedicated function (Alaa Hleihel) [1915307]
- RDMA/mlx5: Remove IB representors dead code (Alaa Hleihel) [1915307]
- net/mlx5: Simplify eswitch mode check (Alaa Hleihel) [1915307]
- net/mlx5: Delete custom device management logic (Alaa Hleihel) [1915307]
- RDMA/mlx5: Convert mlx5_ib to use auxiliary bus (Alaa Hleihel) [1915307]
- net/mlx5e: Connect ethernet part to auxiliary bus (Alaa Hleihel) [1915307]
- vdpa/mlx5: Connect mlx5_vdpa to auxiliary bus (Alaa Hleihel) [1915307]
- net/mlx5: Register mlx5 devices to auxiliary virtual bus (Alaa Hleihel) [1915307]
- vdpa/mlx5: Make hardware definitions visible to all mlx5 devices (Alaa Hleihel) [1915307]
- net/mlx5_core: Clean driver version and name (Alaa Hleihel) [1915307]
- net/mlx5: Treat host PF vport as other (non eswitch manager) vport (Alaa Hleihel) [1915307]
- net/mlx5: Export steering related functions (Alaa Hleihel) [1915307]
- net/mlx5: Expose other function ifc bits (Alaa Hleihel) [1915307]
- net/mlx5: Expose IP-in-IP TX and RX capability bits (Alaa Hleihel) [1915307]
- net/mlx5: Update the hardware interface definition for vhca state (Alaa Hleihel) [1915307]
- net/mlx5: Avoid exposing driver internal command helpers (Alaa Hleihel) [1915307]
- net/mlx5: Add ts_cqe_to_dest_cqn related bits (Alaa Hleihel) [1915307]
- net/mlx5: Add misc4 to mlx5_ifc_fte_match_param_bits (Alaa Hleihel) [1915307]
- net/mlx5: Check dr mask size against mlx5_match_param size (Alaa Hleihel) [1915307]
- net/mlx5: Add sampler destination type (Alaa Hleihel) [1915307]
- net/mlx5: Add sample offload hardware bits and structures (Alaa Hleihel) [1915307]
- RDMA/mlx5: Use PCI device for dma mappings (Alaa Hleihel) [1915307]
- RDMA/mlx5: Silence the overflow warning while building offset mask (Alaa Hleihel) [1915307]
- RDMA/mlx5: Check for ERR_PTR from uverbs_zalloc() (Alaa Hleihel) [1915307]
- RDMA/mlx5: Enable querying AH for XRC QP types (Alaa Hleihel) [1915307]
- RDMA/mlx5: Lower setting the umem's PAS for SRQ (Alaa Hleihel) [1915307]
- RDMA/mlx5: Use ib_umem_find_best_pgsz() for devx (Alaa Hleihel) [1915307]
- RDMA/mlx5: mlx5_umem_find_best_quantized_pgoff() for CQ (Alaa Hleihel) [1915307]
- RDMA/mlx5: Use mlx5_umem_find_best_quantized_pgoff() for QP (Alaa Hleihel) [1915307]
- RDMA/mlx5: Directly compute the PAS list for raw QP RQ's (Alaa Hleihel) [1915307]
- RDMA/mlx5: Use mlx5_umem_find_best_quantized_pgoff() for WQ (Alaa Hleihel) [1915307]
- RDMA/mlx5: Use ib_umem_find_best_pgoff() for SRQ (Alaa Hleihel) [1915307]
- net: mlx5: Replace in_irq() usage (Alaa Hleihel) [1915307]
- net/mlx5: Cleanup kernel-doc warnings (Alaa Hleihel) [1915307]
- net/mlx5e: Validate stop_room size upon user input (Alaa Hleihel) [1915307]
- net/mlx5: DR, Free unused buddy ICM memory (Alaa Hleihel) [1915307]
- net/mlx5: DR, ICM memory pools sync optimization (Alaa Hleihel) [1915307]
- net/mlx5: DR, Sync chunks only during free (Alaa Hleihel) [1915307]
- net/mlx5: DR, Handle ICM memory via buddy allocation instead of buckets (Alaa Hleihel) [1915307]
- net/mlx5: DR, Add buddy allocator utilities (Alaa Hleihel) [1915307]
- net/mlx5: DR, Rename matcher functions to be more HW agnostic (Alaa Hleihel) [1915307]
- net/mlx5: DR, Rename builders HW specific names (Alaa Hleihel) [1915307]
- net/mlx5: DR, Remove unused member of action struct (Alaa Hleihel) [1915307]
- IB/mlx5: Add support for NDR link speed (Alaa Hleihel) [1915307 1926596]
- RDMA/mlx5: Use ib_umem_find_best_pgsz() for mkc's (Alaa Hleihel) [1915307]
- RDMA/mlx5: Split the WR setup out of mlx5_ib_update_xlt() (Alaa Hleihel) [1915307]
- RDMA/mlx5: Move xlt_emergency_page_mutex into mr.c (Alaa Hleihel) [1915307]
- RDMA/mlx5: Change mlx5_ib_populate_pas() to use rdma_for_each_block() (Alaa Hleihel) [1915307]
- RDMA/mlx5: Remove npages from mlx5_ib_cont_pages() (Alaa Hleihel) [1915307]
- RDMA/mlx5: Remove ncont from mlx5_ib_cont_pages() (Alaa Hleihel) [1915307]
- RDMA/mlx5: Remove order from mlx5_ib_cont_pages() (Alaa Hleihel) [1915307]
- RDMA/mlx5: Move mlx5_ib_cont_pages() to the creation of the mlx5_ib_mr (Alaa Hleihel) [1915307]
- RDMA/mlx5: Remove mlx5_ib_mr->order (Alaa Hleihel) [1915307]
- net/mlx5: fix error return code in mlx5e_tc_nic_init() (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Fix IPsec packet drop by mlx5e_tc_update_skb (Alaa Hleihel) [1915306 1915307]
- net/mlx5e: Use spin_lock_bh for async_icosq_lock (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Replace zero-length array with flexible-array member (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Fix uininitialized pointer read on pointer attr (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Add support for devlink reload limit no reset (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Add support for fw live patch event (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Add devlink param enable_remote_dev_reset support (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Add support for devlink reload action fw activate (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Handle sync reset abort event (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Handle sync reset now event (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Handle sync reset request event (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Set cap for pci sync for fw update event (Alaa Hleihel) [1915306 1915307]
- net/mlx5: Add functions to set/query MFRL register (Alaa Hleihel) [1915306 1915307]
- net/mlx5e: Fix potential null pointer dereference (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5: Fix dereference on pointer attr after null check (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5: Use dma device access helper (Alaa Hleihel) [1915306 1915307]
- mlx5: cross-tree: phase out dma_zalloc_coherent() (Alaa Hleihel) [1915306 1915307]
- net/mlx5: E-Switch, Support flow source for local vport (Alaa Hleihel) [1915306 1915307]
- net/mlx5: E-switch, Move devlink eswitch ports closer to eswitch (Alaa Hleihel) [1915306 1915307]
- net/mlx5: E-switch, Use helper function to load unload representor (Alaa Hleihel) [1915306 1915307]
- net/mlx5: E-switch, Add helper to check egress ACL need (Alaa Hleihel) [1915306 1915307]
- net/mlx5: E-switch, Use PF num in metadata reg c0 (Alaa Hleihel) [1915306 1915307]
- net/mlx5: DR, Add support for rule creation with flow source hint (Alaa Hleihel) [1915306 1915307]
- net/mlx5: DR, Call ste_builder directly with tag pointer (Alaa Hleihel) [1915306 1915307]
- net/mlx5: DR, Remove unneeded local variable (Alaa Hleihel) [1915306 1915307]
- net/mlx5: DR, Remove unneeded vlan check from L2 builder (Alaa Hleihel) [1915306 1915307]
- net/mlx5: DR, Remove unneeded check from source port builder (Alaa Hleihel) [1915306 1915307]
- net/mlx5: DR, Replace the check for valid STE entry (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Delete not needed GSI QP signal QP type (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Change GSI QP to have same creation flow like other QPs (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Reuse existing fields in parent QP storage object (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Embed GSI QP into general mlx5_ib QP (Alaa Hleihel) [1915306 1915307]
- net/mlx5: remove unreachable return (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Use kfree() to free fd->g in accel_fs_tcp_create_groups() (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Keep direct reference to mlx5_core_dev in tc ct (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Support CT offload for tc nic flows (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: rework ct offload init messages (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Add tc chains offload support for nic flows (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5: Refactor tc flow attributes structure (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Split nic tc flow allocation and creation (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5e: Tc nic flows to use mlx5_chains flow tables (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5: Allow ft level ignore for nic rx tables (Alaa Hleihel) [1915306 1915307 1919642]
- net/mlx5: Refactor multi chains and prios support (Alaa Hleihel) [1915306 1915307 1919642]
- RDMA/mlx5: Don't call to restrack recursively (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Expose TIR and QP ICM address for sw_owner_v2 devices (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Allow DM allocation for sw_owner_v2 enabled devices (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Add sw_owner_v2 bit capability (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Delete duplicated mlx5_ptys_width enum (Alaa Hleihel) [1915306 1915307]
- net/mlx5: IPsec: make spdxcheck.py happy (Alaa Hleihel) [1915306 1915307]
- mlx5: add pause frame stats (Alaa Hleihel) [1915306 1915307]
- net/mlx5e: Add CQE compression support for multi-strides packets (Alaa Hleihel) [1915306 1915307]
- net/mlx5e: Add support for tc trap (Alaa Hleihel) [1915306 1915307 1919643]
- net/mlx5: E-Switch, Use vport metadata matching by default (Alaa Hleihel) [1915306 1915307]
- net/mlx5: remove erroneous fallthrough (Alaa Hleihel) [1915306 1915307]
- IB/mlx5: Add DCT RoCE LAG support (Alaa Hleihel) [1915306 1915307]
- IB/mlx5: Add tx_affinity support for DCI QP (Alaa Hleihel) [1915306 1915307]
- net/mlx5e: RX, Add a prefetch command for small L1_CACHE_BYTES (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Enable sniffer when device is in switchdev mode (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Add new IB rates support (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Replace open-coded offsetofend() macro (Alaa Hleihel) [1915306 1915307]
- RDMA/mlx5: Simplify multiple else-if cases with switch keyword (Alaa Hleihel) [1915306 1915307]
- net/mlx5e: Link non uplink representors to PCI device (Alaa Hleihel) [1915306 1915307 1959367]
- perf stat: Use nftw() instead of ftw() (Michael Petlan) [1944684]
- perf unwind: Set userdata for all __report_module() paths (Michael Petlan) [1944684]
- perf debug: Move debug initialization earlier (Michael Petlan) [1944684]
- perf script: Fix overrun issue for dynamically-allocated PMU type number (Michael Petlan) [1944684]
- perf metricgroup: Fix system PMU metrics (Michael Petlan) [1944684]
- perf metricgroup: Fix for metrics containing duration_time (Michael Petlan) [1944684]
- perf evlist: Fix id index for heterogeneous systems (Michael Petlan) [1944684]
- perf inject: Correct event attribute sizes (Michael Petlan) [1944684]
- perf intel-pt: Fix 'CPU too large' error (Michael Petlan) [1944684]
- perf stat: Take cgroups into account for shadow stats (Michael Petlan) [1944684]
- perf stat: Introduce struct runtime_stat_data (Michael Petlan) [1944684]
- libperf tests: Fail when failing to get a tracepoint id (Michael Petlan) [1944684]
- libperf tests: If a test fails return non-zero (Michael Petlan) [1944684]
- libperf tests: Avoid uninitialized variable warning (Michael Petlan) [1944684]
- perf test: Fix shadow stat test for non-bash shells (Michael Petlan) [1944684]
- perf bpf examples: Fix bpf.h header include directive in 5sec.c example (Michael Petlan) [1944684]
- perf probe: Fix memory leak when synthesizing SDT probes (Michael Petlan) [1944684]
- perf stat aggregation: Add separate thread member (Michael Petlan) [1944684]
- perf stat aggregation: Add separate core member (Michael Petlan) [1944684]
- perf stat aggregation: Add separate die member (Michael Petlan) [1944684]
- perf stat aggregation: Add separate socket member (Michael Petlan) [1944684]
- perf stat aggregation: Add separate node member (Michael Petlan) [1944684]
- perf stat aggregation: Start using cpu_aggr_id in map (Michael Petlan) [1944684]
- perf cpumap: Drop in cpu_aggr_map struct (Michael Petlan) [1944684]
- perf cpumap: Add new map type for aggregation (Michael Petlan) [1944684]
- perf stat: Replace aggregation ID with a struct (Michael Petlan) [1944684]
- perf cpumap: Add new struct for cpu aggregation (Michael Petlan) [1944684]
- perf cpumap: Use existing allocator to avoid using malloc (Michael Petlan) [1944684]
- perf tests: Improve topology test to check all aggregation types (Michael Petlan) [1944684]
- perf powerpc: Move syscall.tbl check to check-headers.sh (Michael Petlan) [1944684]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Michael Petlan) [1944684]
- perf mem: Factor out a function to generate sort order (Michael Petlan) [1944684]
- perf sort: Add sort option for data page size (Michael Petlan) [1944684]
- perf script: Support data page size (Michael Petlan) [1944684]
- tools headers UAPI: Sync linux/stat.h with the kernel sources (Michael Petlan) [1944684]
- tools: Factor HOSTCC, HOSTLD, HOSTAR definitions (Michael Petlan) [1944684]
- perf config: Fix example command in manpage to conform to syntax specified in the SYNOPSIS section. (Michael Petlan) [1944684]
- perf test: Make sample-parsing test aware of PERF_SAMPLE_{CODE,DATA}_PAGE_SIZE (Michael Petlan) [1944684]
- perf tools: Add support to read build id from compressed elf (Michael Petlan) [1944684]
- perf debug: Add debug_set_file function (Michael Petlan) [1944684]
- perf evlist: Support pipe mode display (Michael Petlan) [1944684]
- perf report: Support --header-only for pipe mode (Michael Petlan) [1944684]
- perf vendor events: Add JSON metrics for imx8mm DDR Perf (Michael Petlan) [1944684]
- perf metricgroup: Support adding metrics for system PMUs (Michael Petlan) [1944684]
- perf metricgroup: Support printing metric groups for system PMUs (Michael Petlan) [1944684]
- perf metricgroup: Split up metricgroup__print() (Michael Petlan) [1944684]
- perf metricgroup: Fix metrics using aliases covering multiple PMUs (Michael Petlan) [1944684]
- perf evlist: Change evlist__splice_list_tail() ordering (Michael Petlan) [1944684]
- perf pmu: Add pmu_add_sys_aliases() (Michael Petlan) [1944684]
- perf pmu: Add pmu_id() (Michael Petlan) [1944684]
- perf jevents: Add support for system events tables (Michael Petlan) [1944684]
- perf jevents: Add support for an extra directory level (Michael Petlan) [1944684]
- perf evsel: Emit warning about kernel not supporting the data page size sample_type bit (Michael Petlan) [1944684]
- perf record: Support new sample type for data page size (Michael Petlan) [1944684]
- perf unwind: Fix separate debug info files when using elfutils' libdw's unwinder (Michael Petlan) [1944684]
- perf record: Fix memory leak when using '--user-regs=?' to list registers (Michael Petlan) [1944684]
- tools headers UAPI: Update tools's copy of linux/perf_event.h (Michael Petlan) [1944684]
- tools build: Add missing libcap to test-all.bin target (Michael Petlan) [1944684]
- perf test: Fix metric parsing test (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' record methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' diff methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' nr_threads method (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' deliver event method (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' header methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' raw samples methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' mmap pages parsing method (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' event attribute config methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for alternative 'struct evlist' constructors (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' event selection methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' event group methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' create maps methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' print methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' evsel list methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' pause/resume methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' id_pos methods (Michael Petlan) [1944684]
- perf tools: Add aarch64 registers to --user-regs (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' tracking event methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' browser methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' sample id lookup methods (Michael Petlan) [1944684]
- perf evlist: Ditch unused set/reset sample_bit methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' sample parsing methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' sideband thread methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' 'filter' methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' stats methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' 'workload' methods (Michael Petlan) [1944684]
- perf evlist: Use the right prefix for 'struct evlist' methods: evlist__set_leader() (Michael Petlan) [1944684]
- perf evsel: Convert last 'struct evsel' methods to the right evsel__ prefix (Michael Petlan) [1944684]
- perf test: Add shadow stat test (Michael Petlan) [1944684]
- perf build-id: Add build_id_cache__add function (Michael Petlan) [1944684]
- perf build-id: Add __perf_session__cache_build_ids function (Michael Petlan) [1944684]
- perf build-id: Use machine__for_each_dso in perf_session__cache_build_ids (Michael Petlan) [1944684]
- perf data: Add is_perf_data function (Michael Petlan) [1944684]
- perf symbols: Try to load vmlinux from buildid database (Michael Petlan) [1944684]
- perf tools: Use struct extra_kernel_map in machine__process_kernel_mmap_event (Michael Petlan) [1944684]
- perf build-id: Add check for existing link in buildid dir (Michael Petlan) [1944684]
- perf tools: Add filename__decompress function (Michael Petlan) [1944684]
- perf tools: Add build_id__is_defined function (Michael Petlan) [1944684]
- tools lib: Adopt memchr_inv() from kernel (Michael Petlan) [1944684]
- perf arm-spe: Add support for ARMv8.3-SPE (Michael Petlan) [1944684]
- perf arm_spe: Decode memory tagging properties (Michael Petlan) [1944684]
- perf arm-spe: Add more sub classes for operation packet (Michael Petlan) [1944684]
- perf arm-spe: Refactor operation packet handling (Michael Petlan) [1944684]
- perf arm-spe: Add new function arm_spe_pkt_desc_op_type() (Michael Petlan) [1944684]
- perf arm-spe: Remove size condition checking for events (Michael Petlan) [1944684]
- perf arm-spe: Refactor event type handling (Michael Petlan) [1944684]
- perf arm-spe: Add new function arm_spe_pkt_desc_event() (Michael Petlan) [1944684]
- perf arm-spe: Refactor counter packet handling (Michael Petlan) [1944684]
- perf arm-spe: Add new function arm_spe_pkt_desc_counter() (Michael Petlan) [1944684]
- perf arm-spe: Refactor context packet handling (Michael Petlan) [1944684]
- perf arm_spe: Fixup top byte for data virtual address (Michael Petlan) [1944684]
- perf arm-spe: Refactor address packet handling (Michael Petlan) [1944684]
- perf arm-spe: Add new function arm_spe_pkt_desc_addr() (Michael Petlan) [1944684]
- perf arm-spe: Refactor packet header parsing (Michael Petlan) [1944684]
- perf arm-spe: Refactor printing string to buffer (Michael Petlan) [1944684]
- perf expr: Force encapsulation on expr_id_data (Michael Petlan) [1944684]
- perf vendor events: Update Skylake client events to v50 (Michael Petlan) [1944684]
- perf data: Allow to use stdio functions for pipe mode (Michael Petlan) [1944684]
- perf arm-spe: Fix packet length handling (Michael Petlan) [1944684]
- perf arm-spe: Refactor arm_spe_get_events() (Michael Petlan) [1944684]
- perf arm-spe: Refactor payload size calculation (Michael Petlan) [1944684]
- perf arm-spe: Fix a typo in comment (Michael Petlan) [1944684]
- perf arm-spe: Include bitops.h for BIT() macro (Michael Petlan) [1944684]
- perf mem: Support ARM SPE events (Michael Petlan) [1944684]
- perf c2c: Support AUX trace (Michael Petlan) [1944684]
- perf mem: Support AUX trace (Michael Petlan) [1944684]
- perf auxtrace: Add itrace option '-M' for memory events (Michael Petlan) [1944684]
- perf mem: Only initialize memory event for recording (Michael Petlan) [1944684]
- perf c2c: Support memory event PERF_MEM_EVENTS__LOAD_STORE (Michael Petlan) [1944684]
- perf mem: Support new memory event PERF_MEM_EVENTS__LOAD_STORE (Michael Petlan) [1944684]
- perf mem: Introduce weak function perf_mem_events__ptr() (Michael Petlan) [1944684]
- perf mem: Search event name with more flexible path (Michael Petlan) [1944684]
- perf jevents: Add test for arch std events (Michael Petlan) [1944684]
- perf jevents: Tidy error handling (Michael Petlan) [1944684]
- perf trace beauty: Allow header files in a different path (Michael Petlan) [1944684]
- perf stat: Add --quiet option (Michael Petlan) [1944684]
- perf stat: Support regex pattern in --for-each-cgroup (Michael Petlan) [1944684]
- perf kvm: Add kvm-stat for arm64 (Michael Petlan) [1944684]
- perf env: Conditionally compile BPF support code on having HAVE_LIBBPF_SUPPORT (Michael Petlan) [1944684]
- perf annotate: Move bpf header inclusion to inside HAVE_LIBBPF_SUPPORT (Michael Petlan) [1944684]
- perf tests: Skip the llvm and bpf tests if HAVE_LIBBPF_SUPPORT isn't defined (Michael Petlan) [1944684]
- perf bpf: Enclose libbpf.h include within HAVE_LIBBPF_SUPPORT (Michael Petlan) [1944684]
- perf test: Implement skip_reason callback for watchpoint tests (Michael Petlan) [1944684]
- perf tests tsc: Add checking helper is_supported() (Michael Petlan) [1944684]
- perf tests tsc: Make tsc testing as a common testing (Michael Petlan) [1944684]
- perf mem2node: Improve warning if detected no memory nodes (Michael Petlan) [1944684]
- perf version: Add a feature for libpfm4 (Michael Petlan) [1944684]
- perf annotate mips: Add perf arch instructions annotate handlers (Michael Petlan) [1944684]
- perf/x86/intel: Add Tremont Topdown support (Michael Petlan) [1944684]
- perf/x86: Fix fall-through warnings for Clang (Michael Petlan) [1944684]
- perf/x86/intel/lbr: Fix the return type of get_lbr_cycles() (Michael Petlan) [1944684]
- perf/x86/intel: Fix rtm_abort_event encoding on Ice Lake (Michael Petlan) [1944684]
- perf: Break deadlock involving exec_update_mutex (Michael Petlan) [1944684]
- perf/x86/intel: Add event constraint for CYCLE_ACTIVITY.STALLS_MEM_ANY (Michael Petlan) [1944684]
- perf/x86: Avoid TIF_IA32 when checking 64bit mode (Michael Petlan) [1944684]
- bpf, ringbuf: Deny reserve of buffers larger than ringbuf (Wander Lairson Costa) [1968591]
- bpf: Fix propagation of 32 bit unsigned bounds from 64 bit bounds (Wander Lairson Costa) [1965938]
- tools/power turbostat: Support Alder Lake Mobile (Steve Best) [1962291]
- ACPI: PM: Add ACPI ID of Alder Lake Fan (Steve Best) [1961617]
- powercap/intel_rapl: add support for AlderLake Mobile (Steve Best) [1961816]
- platform/x86: intel_pmc_core: Uninitialized data in pmc_core_lpm_latch_mode_write() (David Arcari) [1783557]
- platform/x86: intel_pmc_core: add ACPI dependency (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Fix "unsigned 'ret' is never less than zero" smatch warning (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Add LTR registers for Tiger Lake (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Add option to set/clear LPM mode (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Add requirements file to debugfs (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Get LPM requirements for Tiger Lake (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Show LPM residency in microseconds (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Handle sub-states generically (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Remove global struct pmc_dev (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Don't use global pmcdev in quirks (David Arcari) [1783557]
- platform/x86: intel_pmc_core: export platform global reset bits via etr3 sysfs file (David Arcari) [1783557]
- MAINTAINERS: Update maintainers for pmc_core driver (David Arcari) [1783557]
- MAINTAINERS: intel_pmc_core: Update MAINTAINERS (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Ignore GBE LTR on Tiger Lake platforms (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Assign boolean values to a bool variable (David Arcari) [1783557]
- platform/x86: intel_pmc_core: fix: Replace dev_dbg macro with dev_info() (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Clean up: Remove the duplicate comments and reorganize (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Fix the slp_s0 counter displayed value (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Fix TigerLake power gating status map (David Arcari) [1783557]
- platform/x86: pmc_core: Use descriptive names for LPM registers (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Change Jasper Lake S0ix debug reg map back to ICL (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Add Atom based Jasper Lake (JSL) platform support (David Arcari) [1783557]
- platform/x86: intel_pmc_core: Add Intel Elkhart Lake support (David Arcari) [1783557]
- [s390] s390/ipl: support NVMe IPL kernel parameters (Claudio Imbrenda) [1963120]
- [s390] net/smc: use memcpy instead of snprintf to avoid out of bounds read (Claudio Imbrenda) [1919249]
- [s390] smc: fix out of bound access in smc_nl_get_sys_info() (Claudio Imbrenda) [1919249]
- [s390] net/smc: fix access to parent of an ib device (Claudio Imbrenda) [1919249]
- [s390] s390/vtime: fix increased steal time accounting (Claudio Imbrenda) [1963075]
- [s390] tools/kvm_stat: Add restart delay (Claudio Imbrenda) [1963082]
- [s390] s390/dasd: fix hanging IO request during DASD driver unbind (Claudio Imbrenda) [1963077]
- [s390] s390/dasd: fix hanging DASD driver unbind (Claudio Imbrenda) [1963077]

* Thu Jun 17 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-315.el8]
- Add New KUNIT Tests to Redhat kernel-modules-internal (Nico Pache) [1939309]
- kunit: lib: adhear to KUNIT formatting standard (Nico Pache) [1939309]
- kunit: mptcp: adhere to KUNIT formatting standard (Nico Pache) [1939309]
- ASoC: topology: adhere to KUNIT formatting standard (Nico Pache) [1939309]
- kunit: software node: adhear to KUNIT formatting standard (Nico Pache) [1939309]
- resource: provide meaningful MODULE_LICENSE() in test suite (Nico Pache) [1939309]
- resource: Add test cases for new resource API (Nico Pache) [1939309]
- resource: Introduce resource_intersection() for overlapping resources (Nico Pache) [1939309]
- resource: Introduce resource_union() for overlapping resources (Nico Pache) [1939309]
- mm/resource: Use resource_overlaps() to simplify region_intersects() (Nico Pache) [1939309]
- kernel.h: split out min()/max() et al. helpers (Nico Pache) [1939309]
- lib/math/rational.c: fix possible incorrect result from rational fractions helper (Nico Pache) [1939309]
- lib: Move mathematic helpers to separate folder (Nico Pache) [1939309]
- lib/cmdline: remove an unneeded local variable in next_arg() (Nico Pache) [1939309]
- lib/cmdline: Allow get_options() to take 0 to validate the input (Nico Pache) [1939309]
- lib/cmdline: Update documentation to reflect behaviour (Nico Pache) [1939309]
- lib/cmdline_kunit: add a new test case for get_options() (Nico Pache) [1939309]
- ext4: add .kunitconfig fragment to enable ext4-specific tests (Nico Pache) [1939309]
- ext: EXT4_KUNIT_TESTS should depend on EXT4_FS instead of selecting it (Nico Pache) [1939309]
- kunit: tool: fix unintentional statefulness in run_kernel() (Nico Pache) [1939309]
- kunit: tool: add support for filtering suites by glob (Nico Pache) [1939309]
- kunit: add kunit.filter_glob cmdline option to filter suites (Nico Pache) [1939309]
- kunit: don't show `1 == 1` in failed assertion messages (Nico Pache) [1939309]
- kunit: make kunit_tool accept optional path to .kunitconfig fragment (Nico Pache) [1939309]
- Documentation: kunit: add tips.rst for small examples (Nico Pache) [1939309]
- KUnit: Docs: make start.rst example Kconfig follow style.rst (Nico Pache) [1939309]
- kunit: tool: simplify kconfig is_subset_of() logic (Nico Pache) [1939309]
- minor: kunit: tool: fix unit test so it can run from non-root dir (Nico Pache) [1939309]
- kunit: tool: use `with open()` in unit test (Nico Pache) [1939309]
- kunit: tool: stop using bare asserts in unit test (Nico Pache) [1939309]
- kunit: tool: fix unit test cleanup handling (Nico Pache) [1939309]
- ASoC: topology: KUnit: Convert from cpu to data format (Nico Pache) [1939309]
- drivers/base: build kunit tests without structleak plugin (Nico Pache) [1939309]
- ASoC: topology: KUnit: Add KUnit tests passing topology with PCM to snd_soc_tplg_component_load (Nico Pache) [1939309]
- ASoC: topology: KUnit: Add KUnit tests passing empty topology with variants to snd_soc_tplg_component_load (Nico Pache) [1939309]
- ASoC: topology: KUnit: Add KUnit tests passing various arguments to snd_soc_tplg_component_load (Nico Pache) [1939309]
- ASoC: topology: Check if ops is set before dereference (Nico Pache) [1939309]
- ASoC: topology: Ensure that needed parameters are set (Nico Pache) [1939309]
- kunit: tool: move kunitconfig parsing into __init__, make it optional (Nico Pache) [1939309]
- kunit: tool: fix minor typing issue with None status (Nico Pache) [1939309]
- kunit: tool: surface and address more typing issues (Nico Pache) [1939309]
- Documentation: kunit: include example of a parameterized test (Nico Pache) [1939309]
- kunit: tool: Fix spelling of "diagnostic" in kunit_parser (Nico Pache) [1939309]
- kunit: tool: Force the use of the 'tty' console for UML (Nico Pache) [1939309]
- lib/cmdline_kunit: add a new test suite for cmdline API (Nico Pache) [1939309]
- lib/cmdline: allow NULL to be an output for get_option() (Nico Pache) [1939309]
- lib/cmdline: fix get_option() for strings starting with hyphen (Nico Pache) [1939309]
- lib/cmdline.c: mark expected switch fall-throughs (Nico Pache) [1939309]
- lib/test_bits.c: add tests of GENMASK (Nico Pache) [1939309]
- linux/bits.h: add compile time sanity check of GENMASK inputs (Nico Pache) [1939309]
- linux/build_bug.h: change type to int (Nico Pache) [1939309]
- fs: ext4: Modify inode-test.c to use KUnit parameterized testing feature (Nico Pache) [1939309]
- kunit: Support for Parameterized Testing (Nico Pache) [1939309]
- kunit: kunit_tool: Correctly parse diagnostic messages (Nico Pache) [1939309]
- Documentation: kunit: provide guidance for testing many inputs (Nico Pache) [1939309]
- kunit: Introduce get_file_path() helper (Nico Pache) [1939309]
- kunit: fix display of failed expectations for strings (Nico Pache) [1939309]
- kunit: tool: fix extra trailing \n in raw + parsed test output (Nico Pache) [1939309]
- kunit: tool: print out stderr from make (like build warnings) (Nico Pache) [1939309]
- KUnit: Docs: usage: wording fixes (Nico Pache) [1939309]
- KUnit: Docs: style: fix some Kconfig example issues (Nico Pache) [1939309]
- KUnit: Docs: fix a wording typo (Nico Pache) [1939309]
- kunit: Do not pollute source directory with generated files (test.log) (Nico Pache) [1939309]
- kunit: Do not pollute source directory with generated files (.kunitconfig) (Nico Pache) [1939309]
- kunit: tool: fix pre-existing python type annotation errors (Nico Pache) [1939309]
- kunit: Fix kunit.py parse subcommand (use null build_dir) (Nico Pache) [1939309]
- kunit: test: fix remaining kernel-doc warnings (Nico Pache) [1939309]
- lib: kunit: Fix compilation test when using TEST_BIT_FIELD_COMPILE (Nico Pache) [1939309]
- kunit: test.h: fix a bad kernel-doc markup (Nico Pache) [1939309]
- kunit: test.h: solve kernel-doc warnings (Nico Pache) [1939309]
- lib: kunit: add bitfield test conversion to KUnit (Nico Pache) [1939309]
- Documentation: kunit: add a brief blurb about kunit_test_suite (Nico Pache) [1939309]
- kunit: test: add test plan to KUnit TAP format (Nico Pache) [1939309]
- init: main: add KUnit to kernel init (Nico Pache) [1939309]
- init: unify opening /dev/console as stdin/stdout/stderr (Nico Pache) [1939309]
- kunit: test: create a single centralized executor for all tests (Nico Pache) [1939309]
- Documentation: test.h - fix warnings (Nico Pache) [1939309]
- vmlinux.lds.h: add linker section for KUnit test suites (Nico Pache) [1939309]
- Documentation: kunit: Add naming guidelines (Nico Pache) [1939309]
- kunit: tool: fix display of make errors (Nico Pache) [1939309]
- kunit: tool: handle when .kunit exists but .kunitconfig does not (Nico Pache) [1939309]
- kunit: tool: fix --alltests flag (Nico Pache) [1939309]
- kunit: tool: allow generating test results in JSON (Nico Pache) [1939309]
- kunit: tool: fix running kunit_tool from outside kernel tree (Nico Pache) [1939309]
- lib: add linear ranges helpers (Nico Pache) [1939309]
- PCI/RCEC: Fix RCiEP device to RCEC association (Myron Stowe) [1895942]
- PCI/portdrv: Report reset for frozen channel (Myron Stowe) [1895942]
- PCI/AER: Specify the type of Port that was reset (Myron Stowe) [1895942]
- PCI/ERR: Retain status from error notification (Myron Stowe) [1895942]
- PCI/AER: Clear AER status from Root Port when resetting Downstream Port (Myron Stowe) [1895942]
- PCI/ERR: Clear status of the reporting device (Myron Stowe) [1895942]
- PCI/AER: Add RCEC AER error injection support (Myron Stowe) [1895942]
- PCI/PME: Add pcie_walk_rcec() to RCEC PME handling (Myron Stowe) [1895942]
- PCI/AER: Add pcie_walk_rcec() to RCEC AER handling (Myron Stowe) [1895942]
- PCI/ERR: Recover from RCiEP AER errors (Myron Stowe) [1895942]
- PCI/ERR: Add pcie_link_rcec() to associate RCiEPs (Myron Stowe) [1895942]
- PCI/ERR: Recover from RCEC AER errors (Myron Stowe) [1895942]
- PCI/ERR: Clear AER status only when we control AER (Myron Stowe) [1895942]
- PCI/ERR: Add pci_walk_bridge() to pcie_do_recovery() (Myron Stowe) [1895942]
- PCI/ERR: Avoid negated conditional for clarity (Myron Stowe) [1895942]
- PCI/ERR: Use "bridge" for clarity in pcie_do_recovery() (Myron Stowe) [1895942]
- PCI/ERR: Simplify by computing pci_pcie_type() once (Myron Stowe) [1895942]
- PCI/ERR: Simplify by using pci_upstream_bridge() (Myron Stowe) [1895942]
- PCI/ERR: Rename reset_link() to reset_subordinates() (Myron Stowe) [1895942]
- PCI/ERR: Cache RCEC EA Capability offset in pci_init_capabilities() (Myron Stowe) [1895942]
- PCI/ERR: Bind RCEC devices to the Root Port driver (Myron Stowe) [1895942]
- PCI/AER: Write AER Capability only when we control it (Myron Stowe) [1895942]
- PCI: Export pcie_has_flr() (Myron Stowe) [1895942]
- xfs: don't reuse busy extents on extent trim (Brian Foster) [1960380]
- nvme: add 'kato' sysfs attribute (Gopal Tiwari) [1970260]
- scsi: qla2xxx: Update version to 10.02.00.106-k (Nilesh Javali) [1925465]
- scsi: qla2xxx: Add marginal path handling support (Nilesh Javali) [1925465]
- scsi: qla2xxx: Do logout even if fabric scan retries got exhausted (Nilesh Javali) [1925465]
- scsi: qla2xxx: Update default AER debug mask (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix mailbox recovery during PCIe error (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix crash in PCIe error handling (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix RISC RESET completion polling (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix crash in qla2xxx_mqueuecommand() (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix use after free in bsg (Nilesh Javali) [1925465]
- scsi: qla2xxx: Consolidate zio threshold setting for both FCP & NVMe (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix stuck session (Nilesh Javali) [1925465]
- scsi: qla2xxx: Add H:C:T info in the log message for fc ports (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix IOPS drop seen in some adapters (Nilesh Javali) [1925465]
- scsi: qla2xxx: Check kzalloc() return value (Nilesh Javali) [1925465]
- scsi: qla2xxx: Always check the return value of qla24xx_get_isp_stats() (Nilesh Javali) [1925465]
- scsi: qla2xxx: Simplify qla8044_minidump_process_control() (Nilesh Javali) [1925465]
- scsi: qla2xxx: Suppress Coverity complaints about dseg_r* (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix endianness annotations (Nilesh Javali) [1925465]
- scsi: qla2xxx: Constify struct qla_tgt_func_tmpl (Nilesh Javali) [1925465]
- scsi: qla2xxx: Use dma_pool_zalloc() (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix a couple of misdocumented functions (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix incorrectly named function qla8044_check_temp() (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix a couple of misnamed functions (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix some incorrect formatting/spelling issues (Nilesh Javali) [1925465]
- scsi: qla2xxx: Replace __qla2x00_marker()'s missing underscores (Nilesh Javali) [1925465]
- scsi: Revert "qla2xxx: Make sure that aborted commands are freed" (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix broken #endif placement (Nilesh Javali) [1925465]
- scsi: qla2xxx: Simplify if statement (Nilesh Javali) [1925465]
- scsi: qla2xxx: Simplify the calculation of variables (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix some memory corruption (Nilesh Javali) [1925465]
- scsi: qla2xxx: Remove redundant NULL check (Nilesh Javali) [1925465]
- scsi: qla2xxx: Remove unnecessary NULL check (Nilesh Javali) [1925465]
- scsi: qla2xxx: Assign boolean values to a bool variable (Nilesh Javali) [1925465]
- scsi: qla2xxx: fc_remote_port_chkready() returns a SCSI result value (Nilesh Javali) [1925465]
- scsi: qla2xxx: Fix description for parameter ql2xenforce_iocb_limit (Nilesh Javali) [1925465]
- scsi: qla2xxx: Update version to 10.02.00.105-k (Nilesh Javali) [1925465]
- scsi: qla2xxx: Enable NVMe CONF (BIT_7) when enabling SLER (Nilesh Javali) [1925465]
- scsi: qla2xxx: Wait for ABTS response on I/O timeouts for NVMe (Nilesh Javali) [1925465]
- scsi: qla2xxx: Move some messages from debug to normal log level (Nilesh Javali) [1925465]
- scsi: qla2xxx: Add error counters to debugfs node (Nilesh Javali) [1925465]
- scsi: qla2xxx: Implementation to get and manage host, target stats and initiator port (Nilesh Javali) [1925465]
- scsi: ibmvfc: Reinit target retries (Steve Best) [1965010]
- scsi: ibmvfc: Avoid move login if fast fail is enabled (Steve Best) [1965010]
- scsi: ibmvfc: Handle move login failure (Steve Best) [1965010]
- scsi: ibmvfc: Fix invalid state machine BUG_ON() (Steve Best) [1965010]
- scsi: qedf: Do not put host in qedf_vport_create() unconditionally (Nilesh Javali) [1899384]
- scsi: storvsc: Enable scatterlist entry lengths > 4Kbytes (Cathy Avery) [1941664]
- scsi: storvsc: Parameterize number hardware queues (Cathy Avery) [1941664]
- scsi: storvsc: Return DID_ERROR for invalid commands (Cathy Avery) [1941664]
- scsi: storvsc: Validate length of incoming packet in storvsc_on_channel_callback() (Cathy Avery) [1941664]
- scsi: storvsc: Resolve data race in storvsc_probe() (Cathy Avery) [1941664]
- scsi: storvsc: Fix max_outstanding_req_per_channel for Win8 and newer (Cathy Avery) [1941664]
- scsi: storvsc: Use vmbus_requestor to generate transaction IDs for VMBus hardening (Cathy Avery) [1941664]
- RDMA/ipoib: Fix warning caused by destroying non-initial netns (Kamal Heib) [1961815]
- can: dev: Move device back to init netns on owning netns delete (Kamal Heib) [1961815]
- net: ena: remove extra words from comments (Petr Oros) [1955155]
- net: ena: fix inaccurate print type (Petr Oros) [1955155]
- ena: Update driver to use ethtool_sprintf (Petr Oros) [1955155]
- docs: net: ena: Fix ena_start_xmit() function name typo (Petr Oros) [1955155]
- ethernet: amazon: ena: A typo fix in the file ena_com.h (Petr Oros) [1955155]
- net: ena: Update XDP verdict upon failure (Petr Oros) [1955155]
- net: ena: introduce ndo_xdp_xmit() function for XDP_REDIRECT (Petr Oros) [1955155]
- net: ena: use xdp_return_frame() to free xdp frames (Petr Oros) [1955155]
- net: ena: introduce XDP redirect implementation (Petr Oros) [1955155]
- net: ena: use xdp_frame in XDP TX flow (Petr Oros) [1955155]
- net: ena: aggregate stats increase into a function (Petr Oros) [1955155]
- net: ena: fix coding style nits (Petr Oros) [1955155]
- net: ena: store values in their appropriate variables types (Petr Oros) [1955155]
- net: ena: add device distinct log prefix to files (Petr Oros) [1955155]
- net: ena: use constant value for net_device allocation (Petr Oros) [1955155]
- net: ena: set initial DMA width to avoid intel iommu issue (Petr Oros) [1955155]
- net: ena: update ena documentation (Petr Oros) [1955155]
- net: ena: Fix all static chekers' warnings (Petr Oros) [1955155]
- net: ena: Change RSS related macros and variables names (Petr Oros) [1955155]
- net: ena: Remove redundant print of placement policy (Petr Oros) [1955155]
- net: ena: Capitalize all log strings and improve code readability (Petr Oros) [1955155]
- net: ena: Change log message to netif/dev function (Petr Oros) [1955155]
- net: ena: Change license into format to SPDX in all files (Petr Oros) [1955155]
- net: ena: xdp: add queue counters for xdp actions (Petr Oros) [1955155]
- net: ena: ethtool: add stats printing to XDP queues (Petr Oros) [1955155]
- net: ena: ethtool: Add new device statistics (Petr Oros) [1955155]
- net: ena: ethtool: convert stat_offset to 64 bit resolution (Petr Oros) [1955155]
- net: ena: Make missed_tx stat incremental (Petr Oros) [1955155]
- net: ena: Prevent reset after device destruction (Petr Oros) [1955155]
- treewide: replace '---help---' in Kconfig files with 'help' (Petr Oros) [1955155]
- treewide: Add SPDX license identifier - Makefile/Kconfig (Petr Oros) [1955155]
- cross-tree: phase out dma_zalloc_coherent() (Petr Oros) [1955155]
- net: ena: fix compilation error in xtensa architecture (Petr Oros) [1955155]
- docs: networking: reorganize driver documentation again (Petr Oros) [1955155]
- docs: networking: device drivers: convert amazon/ena.txt to ReST (Petr Oros) [1955155]
- net: ena: documentation: update ena.txt (Petr Oros) [1955155]
- net: documentation: build a directory structure for drivers (Petr Oros) [1955155]
- xfrm: interface: fix ipv4 pmtu check to honor ip header df (Sabrina Dubroca) [1931942]
- vti: fix ipv4 pmtu check to honor ip header df (Sabrina Dubroca) [1931942]
- vti6: fix ipv4 pmtu check to honor ip header df (Sabrina Dubroca) [1931942]
- net/sched: act_ct: Fix ct template allocation for zone 0 (Marcelo Ricardo Leitner) [1881824]
- uio: Fix use-after-free in uio_unregister_device() (Myron Stowe) [1897285]
- uio: free uio id after uio file node is freed (Myron Stowe) [1897285]
- drivers: uio: remove redundant assignment to variable retval (Myron Stowe) [1897285]
- driver: uio: fix possible use-after-free in __uio_register_device (Myron Stowe) [1897285]
- driver: uio: fix possible memory leak in __uio_register_device (Myron Stowe) [1897285]
- uio: remove redundant check (Myron Stowe) [1897285]
- uio: fix potential memory leak in error case (Myron Stowe) [1897285]
- uio: dismiss waiters on device unregistration (Myron Stowe) [1897285]
- uio: Fix an Oops on load (Myron Stowe) [1897285]
- uio: make symbol 'uio_class_registered' static (Myron Stowe) [1897285]
- uio: convert to vm_fault_t (Myron Stowe) [1897285]
- uio: ensure class is registered before devices (Myron Stowe) [1897285]
- uio: potential double frees if __uio_register_device() fails (Myron Stowe) [1897285]
- uio: fix possible circular locking dependency (Myron Stowe) [1897285]
- uio: fix wrong return value from uio_mmap() (Myron Stowe) [1897285]
- uio: add SPDX license tag (Myron Stowe) [1897285]
- net: zero-initialize tc skb extension on allocation (Ivan Vecera) [1946986]
- net: sched: fix tx action reschedule issue with stopped queue (Ivan Vecera) [1946986]
- net: sched: fix tx action rescheduling issue during deactivation (Ivan Vecera) [1946986]
- net: sched: fix packet stuck problem for lockless qdisc (Ivan Vecera) [1946986]
- net/sched: act_ct: Remove redundant ct get and check (Ivan Vecera) [1946986]
- net: sched: tapr: prevent cycle_time == 0 in parse_taprio_schedule (Ivan Vecera) [1946986]
- tc-testing: add simple action test to verify batch change cleanup (Ivan Vecera) [1946986]
- tc-testing: add simple action test to verify batch add cleanup (Ivan Vecera) [1946986]
- tc-testing: add simple action change test (Ivan Vecera) [1946986]
- selftests: forwarding: Add tc-police tests for packets per second (Ivan Vecera) [1946986]
- selftests: tc-testing: add action police selftest for packets per second (Ivan Vecera) [1946986]
- net: sched: Mundane typo fixes (Ivan Vecera) [1946986]
- net/sched: cls_flower: use nla_get_be32 for TCA_FLOWER_KEY_FLAGS (Ivan Vecera) [1946986]
- net/sched: cls_flower: use ntohs for struct flow_dissector_key_ports (Ivan Vecera) [1946986]
- taprio: Handle short intervals and large packets (Ivan Vecera) [1946986]
- net/sched: cls_flower: fix only mask bit check in the validate_ct_state (Ivan Vecera) [1946986]
- treewide: Remove uninitialized_var() usage (Ivan Vecera) [1946986]
- lockdep: Provide dummy forward declaration of *_is_held() helpers (Ivan Vecera) [1946986]
- net: sched: Remove broken definitions and un-hide for !LOCKDEP (Ivan Vecera) [1946986]
- net: sched: sch_teql: fix null-pointer dereference (Ivan Vecera) [1946986]
- net: sched: fix err handler in tcf_action_init() (Ivan Vecera) [1946986]
- net: sched: fix action overwrite reference counting (Ivan Vecera) [1946986]
- Revert "net: sched: bump refcount for new action in ACT replace mode" (Ivan Vecera) [1946986]
- net: cls_api: Fix uninitialised struct field bo->unlocked_driver_cb (Ivan Vecera) [1946986]
- net: sched: bump refcount for new action in ACT replace mode (Ivan Vecera) [1946986]
- net/sched: act_api: fix miss set post_ct for ovs after do conntrack in act_ct (Ivan Vecera) [1946986]
- net/sched: act_police: add support for packet-per-second policing (Ivan Vecera) [1946986]
- flow_offload: reject configuration of packet-per-second policing in offload drivers (Ivan Vecera) [1946986]
- flow_offload: add support for packet-per-second policing (Ivan Vecera) [1946986]
- net: sched: validate stab values (Ivan Vecera) [1946986]
- net: add a helper to avoid issues with HW TX timestamping and SO_TXTIME (Ivan Vecera) [1946986]
- sched: act_sample: Implement stats_update callback (Ivan Vecera) [1946986]
- net: sched: avoid duplicates in classes dump (Ivan Vecera) [1946986]
- net/sched: cls_flower: validate ct_state for invalid and reply flags (Ivan Vecera) [1946986]
- net: sched: fix police ext initialization (Ivan Vecera) [1946986]
- selftests: tc: Add generic mpls matching support for tc-flower (Ivan Vecera) [1946986]
- selftests: tc: Add basic mpls_* matching support for tc-flower (Ivan Vecera) [1946986]
- selftests: tc-testing: u32: Add tests covering sample option (Ivan Vecera) [1946986]
- net: sched: Return the correct errno code (Ivan Vecera) [1946986]
- net: sched: replaced invalid qdisc tree flush helper in qdisc_replace (Ivan Vecera) [1946986]
- selftests: forwarding: Fix spelling mistake "succeded" -> "succeeded" (Ivan Vecera) [1946986]
- taprio: boolean values to a bool variable (Ivan Vecera) [1946986]
- net_sched: fix RTNL deadlock again caused by request_module() (Ivan Vecera) [1946986]
- cls_flower: call nla_ok() before nla_next() (Ivan Vecera) [1946986]
- net/sched: sch_taprio: ensure to reset/destroy all child qdiscs (Ivan Vecera) [1946986]
- net/sched: sch_taprio: reset child qdiscs before freeing them (Ivan Vecera) [1946986]
- net: sched: incorrect Kconfig dependencies on Netfilter modules (Ivan Vecera) [1946986]
- treewide: replace '---help---' in Kconfig files with 'help' (Ivan Vecera) [1946986]
- net/sched: cls_u32: simplify the return expression of u32_reoffload_knode() (Ivan Vecera) [1946986]
- net: sched: fix spelling mistake in Kconfig "trys" -> "tries" (Ivan Vecera) [1946986]
- net/sched: fq_pie: initialize timer earlier in fq_pie_init() (Ivan Vecera) [1946986]
- net: sched: remove redundant 'rtnl_held' argument (Ivan Vecera) [1946986]
- selftests: tc-testing: enable CONFIG_NET_SCH_RED as a module (Ivan Vecera) [1946986]
- net: sched: alias action flags with TCA_ACT_ prefix (Ivan Vecera) [1946986]
- treewide: rename nla_strlcpy to nla_strscpy. (Ivan Vecera) [1946986]
- Modify return value of nla_strlcpy to match that of strscpy. (Ivan Vecera) [1946986]
- Fix unefficient call to memset before memcpu in nla_strlcpy. (Ivan Vecera) [1946986]
- net: sched: fix misspellings using misspell-fixer tool (Ivan Vecera) [1946986]
- selftest: fix flower terse dump tests (Ivan Vecera) [1946986]
- net: sched: implement action-specific terse dump (Ivan Vecera) [1946986]
- net: cls_api: remove unneeded local variable in tc_dump_chain() (Ivan Vecera) [1946986]
- openvswitch: fix send of uninitialized stack memory in ct limit reply (Antoine Tenart) [1950022]
- net/sched: act_api: fix miss set post_ct for ovs after do conntrack in act_ct (Antoine Tenart) [1950022]
- xsk: Clear pool even for inactive queues (Jiri Benc) [1882710]
- xsk: Fix memory leak for failed bind (Jiri Benc) [1882710]
- xsk: Return error code if force_zc is set (Jiri Benc) [1882710]
- xsk: Change the tx writeable condition (Jiri Benc) [1882710]
- xsk: Replace datagram_poll by sock_poll_wait (Jiri Benc) [1882710]
- xdp: Handle MEM_TYPE_XSK_BUFF_POOL correctly in xdp_return_buff() (Jiri Benc) [1882710]
- xsk: Fix incorrect netdev reference count (Jiri Benc) [1882710]
- xsk: Fix umem cleanup bug at socket destruct (Jiri Benc) [1882710]
- netdevsim: set .owner to THIS_MODULE (Jiri Benc) [1882710]
- bpf: selftest: Use static globals in tcp_hdr_options and btf_skc_cls_ingress (Jiri Benc) [1882710]
- xsk: Fix possible memory leak at socket close (Jiri Benc) [1882710]
- samples/bpf: Set rlimit for memlock to infinity in all samples (Jiri Benc) [1882710]
- bpf, selftests: Extend test_tc_redirect to use modified bpf_redirect_neigh() (Jiri Benc) [1882710]
- bpf: Fix bpf_redirect_neigh helper api to support supplying nexthop (Jiri Benc) [1882710]
- bpf, selftest: Fix flaky tcp_hdr_options test when adding addr to lo (Jiri Benc) [1882710]
- bpf, selftests: Add redirect_peer selftest (Jiri Benc) [1882710]
- bpf, selftests: Make redirect_neigh test more extensible (Jiri Benc) [1882710]
- bpf: Add redirect_peer helper (Jiri Benc) [1882710]
- bpf: Improve bpf_redirect_neigh helper description (Jiri Benc) [1882710]
- bpf: Always return target ifindex in bpf_fib_lookup (Jiri Benc) [1882710]
- xsk: Introduce padding between ring pointers (Jiri Benc) [1882710]
- xsk: Remove internal DMA headers (Jiri Benc) [1882710]
- bpf: selftest: Ensure the child sk inherited all bpf_sock_ops_cb_flags (Jiri Benc) [1882710]
- bpf: tcp: Do not limit cb_flags when creating child sk from listen sk (Jiri Benc) [1882710]
- bpf, selftests: Add redirect_neigh selftest (Jiri Benc) [1882710]
- bpf: Add redirect_neigh helper as redirect drop-in (Jiri Benc) [1882710]
- tools, bpf: Synchronise BPF UAPI header with tools (Jiri Benc) [1882710]
- bpf: Fix formatting in documentation for BPF helpers (Jiri Benc) [1882710]
- xsk: Fix a documentation mistake in xsk_queue.h (Jiri Benc) [1882710]
- xsk: Fix possible crash in socket_release when out-of-memory (Jiri Benc) [1882710]
- xsk: Fix refcount warning in xp_dma_map (Jiri Benc) [1882710]
- tcp: Only init congestion control if not initialized already (Jiri Benc) [1882710]
- xsk: Fix null check on error return path (Jiri Benc) [1882710]
- xsk: Fix possible segfault at xskmap entry insertion (Jiri Benc) [1882710]
- xsk: Fix possible segfault in xsk umem diagnostics (Jiri Benc) [1882710]
- xsk: Fix use-after-free in failed shared_umem bind (Jiri Benc) [1882710]
- xsk: Documentation for XDP_SHARED_UMEM between queues and netdevs (Jiri Benc) [1882710]
- xsk: Add shared umem support between devices (Jiri Benc) [1882710]
- xsk: Add shared umem support between queue ids (Jiri Benc) [1882710]
- xsk: i40e: ice: ixgbe: mlx5: Test for dma_need_sync earlier for better performance (Jiri Benc) [1882710]
- xsk: Rearrange internal structs for better performance (Jiri Benc) [1882710]
- xsk: Enable sharing of dma mappings (Jiri Benc) [1882710]
- xsk: Move addrs from buffer pool to umem (Jiri Benc) [1882710]
- xsk: Move xsk_tx_list and its lock to buffer pool (Jiri Benc) [1882710]
- xsk: Move queue_id, dev and need_wakeup to buffer pool (Jiri Benc) [1882710]
- xsk: Move fill and completion rings to buffer pool (Jiri Benc) [1882710]
- xsk: Create and free buffer pool independently from umem (Jiri Benc) [1882710]
- xsk: i40e: ice: ixgbe: mlx5: Rename xsk zero-copy driver interfaces (Jiri Benc) [1882710]
- xsk: i40e: ice: ixgbe: mlx5: Pass buffer pool to driver instead of umem (Jiri Benc) [1882710]
- tcp: bpf: Optionally store mac header in TCP_SAVE_SYN (Jiri Benc) [1882710]
- bpf: selftests: Tcp header options (Jiri Benc) [1882710]
- bpf: selftests: Add fastopen_connect to network_helpers (Jiri Benc) [1882710]
- bpf: tcp: Allow bpf prog to write and parse TCP header option (Jiri Benc) [1882710]
- bpf: sock_ops: Change some members of sock_ops_kern from u32 to u8 (Jiri Benc) [1882710]
- bpf: tcp: Add bpf_skops_hdr_opt_len() and bpf_skops_write_hdr_opt() (Jiri Benc) [1882710]
- bpf: tcp: Add bpf_skops_parse_hdr() (Jiri Benc) [1882710]
- bpf: tcp: Add bpf_skops_established() (Jiri Benc) [1882710]
- tcp: Add saw_unknown to struct tcp_options_received (Jiri Benc) [1882710]
- tcp: bpf: Add TCP_BPF_RTO_MIN for bpf_setsockopt (Jiri Benc) [1882710]
- tcp: bpf: Add TCP_BPF_DELACK_MAX setsockopt (Jiri Benc) [1882710]
- tcp: Use a struct to represent a saved_syn (Jiri Benc) [1882710]
- tcp: tcp_init_buffer_space can be static (Jiri Benc) [1882710]
- tcp: refactor setting the initial congestion window (Jiri Benc) [1882710]
- tcp: fix code style in tcp_recvmsg() (Jiri Benc) [1882710]
- tcp: duplicate clear of icsk_backoff (Jiri Benc) [1882710]
- tcp: move rx_opt & syn_data_acked init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: move tp->rack init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: move app_limited init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: move retrans_out, sacked_out, tlp_high_seq, last_oow_ack_time init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: do not clear urg_data in tcp_create_openreq_child (Jiri Benc) [1882710]
- tcp: move snd_cwnd & snd_cwnd_cnt init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: move mdev_us init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: do not clear srtt_us in tcp_create_openreq_child (Jiri Benc) [1882710]
- tcp: do not clear packets_out in tcp_create_openreq_child() (Jiri Benc) [1882710]
- tcp: move icsk_rto init to tcp_disconnect() (Jiri Benc) [1882710]
- tcp: do not set snd_ssthresh in tcp_create_openreq_child() (Jiri Benc) [1882710]
- net-veth: Add type safety to veth_xdp_to_ptr() and veth_ptr_to_xdp() (Jiri Benc) [1882710]
- net-tun: Eliminate two tun/xdp related function calls from vhost-net (Jiri Benc) [1882710]
- net-tun: Add type safety to tun_xdp_to_ptr() and tun_ptr_to_xdp() (Jiri Benc) [1882710]
- ipv4: Add helpers for neigh lookup for nexthop (Jiri Benc) [1882710]
- net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Jiri Benc) [1882710]
- tipc: better validate user input in tipc_nl_retrieve_key() (Xin Long) [1950093]
- tipc: simplify the finalize work queue (Xin Long) [1958456]
- tipc: wait and exit until all work queues are done (Xin Long) [1958456]
- [s390] KVM: s390: diag9c (directed yield) forwarding (Claudio Imbrenda) [1874105]
- kvm/svm: Reenable nesting (Dr. David Alan Gilbert) [1790949]
- powerpc/papr_scm: Reduce error severity if nvdimm stats inaccessible (Steve Best) [1965193]
- Revert "[redhat] redhat/configs: Update CONFIG_ARM64_CNP" (Mark Salter) [1949533]
- arm64: kernel: disable CNP on Carmel (Mark Salter) [1949533]

* Mon Jun 14 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-314.el8]
- redhat/configs: Enable CONFIG_MICROSOFT_MANA=m (Vitaly Kuznetsov) [1957820]
- net: mana: Use int to check the return value of mana_gd_poll_cq() (Vitaly Kuznetsov) [1957820]
- net: mana: fix PCI_HYPERV dependency (Vitaly Kuznetsov) [1957820]
- net: mana: remove redundant initialization of variable err (Vitaly Kuznetsov) [1957820]
- net: mana: Add a driver for Microsoft Azure Network Adapter (MANA) (Vitaly Kuznetsov) [1957820]
- hv_netvsc: Make netvsc/VF binding check both MAC and serial number (Vitaly Kuznetsov) [1957820]
- net: evaluate net.ipvX.conf.all.ignore_routes_with_linkdown (Balazs Nemeth) [1957223]
- net: evaluate net.ipv4.conf.all.proxy_arp_pvlan (Balazs Nemeth) [1957223]
- netfilter: nf_log_syslog: Unset bridge logger in pernet exit (Phil Sutter) [1938214]
- netfilter: nft_log: perform module load from nf_tables (Phil Sutter) [1938214]
- netfilter: nft_dynset: fix timeouts later than 23 days (Phil Sutter) [1938214]
- netfilter: nft_compat: make sure xtables destructors have run (Phil Sutter) [1938214]
- netfilter: nftables: Add __printf() attribute (Phil Sutter) [1938214]
- netfilter: nf_log: add module softdeps (Phil Sutter) [1938214]
- netfilter: nf_log_common: merge with nf_log_syslog (Phil Sutter) [1938214]
- netfilter: nf_log_bridge: merge with nf_log_syslog (Phil Sutter) [1938214]
- netfilter: nf_log_netdev: merge with nf_log_syslog (Phil Sutter) [1938214]
- netfilter: nf_log_ipv6: merge with nf_log_syslog (Phil Sutter) [1938214]
- netfilter: move inline nf_ip6_ext_hdr() function to a more appropriate header. (Phil Sutter) [1938214]
- ipv6: Use ipv6_authlen for len (Phil Sutter) [1938214]
- netfilter: nf_log_arp: merge with nf_log_syslog (Phil Sutter) [1938214]
- netfilter: nf_log_ipv4: rename to nf_log_syslog (Phil Sutter) [1938214]
- net/sched: cls_api: increase max_reclassify_loop (Davide Caratti) [1955136]
- vsock/vmci: Remove redundant assignment to err (Stefano Garzarella) [1956861]
- vsock/virtio: free queued packets when closing socket (Stefano Garzarella) [1956861]
- net: vsock: Fix a typo (Stefano Garzarella) [1956861]
- selinux: vsock: Set SID for socket returned by accept() (Stefano Garzarella) [1956861]
- af_vsock: Assign the vsock transport considering the vsock address flags (Stefano Garzarella) [1956861]
- af_vsock: Set VMADDR_FLAG_TO_HOST flag on the receive path (Stefano Garzarella) [1956861]
- vsock_addr: Check for supported flag values (Stefano Garzarella) [1956861]
- vm_sockets: Add VMADDR_FLAG_TO_HOST vsock flag (Stefano Garzarella) [1956861]
- vm_sockets: Add flags field in the vsock address data structure (Stefano Garzarella) [1956861]
- hv_sock: Remove the accept port restriction (Stefano Garzarella) [1956861]
- hv_sock: use HV_HYP_PAGE_SIZE for Hyper-V communication (Stefano Garzarella) [1956861]
- net: add a helper to avoid issues with HW TX timestamping and SO_TXTIME (Corinna Vinschen) [1958988]
- net: ensure mac header is set in virtio_net_hdr_to_skb() (Balazs Nemeth) [1955441]
- devlink: Fix dmac_filter trap name, align to its documentation (Petr Oros) [1935701]
- devlink: Add DMAC filter generic packet trap (Petr Oros) [1935701]
- devlink: Add blackhole_nexthop trap (Petr Oros) [1935701]
- stm class: Fix module init return on allocation failure (Jiri Olsa) [1907791]
- stm class: ftrace: Use different channel accroding to CPU (Jiri Olsa) [1907791]
- stm class: ftrace: Enable supported trace export flag (Jiri Olsa) [1907791]
- stm class: ftrace: Change dependency to TRACING (Jiri Olsa) [1907791]
- stm class: Replace zero-length array with flexible-array (Jiri Olsa) [1907791]
- stm class: sys-t: Fix the use of time_after() (Jiri Olsa) [1907791]
- stm class: Lose the protocol driver when dropping its reference (Jiri Olsa) [1907791]
- stm class: Fix a double free of stm_source_device (Jiri Olsa) [1907791]
- stm class: Fix channel bitmap on 32-bit systems (Jiri Olsa) [1907791]
- stm class: Fix channel free in stm output free path (Jiri Olsa) [1907791]
- stm class: Prevent division by zero (Jiri Olsa) [1907791]
- stm class: Fix an endless loop in channel allocation (Jiri Olsa) [1907791]
- stm class: Fix a module refcount leak in policy creation error path (Jiri Olsa) [1907791]
- stm class: Use memcat_p() (Jiri Olsa) [1907791]
- stm class: heartbeat: Fix whitespace (Jiri Olsa) [1907791]
- stm class: p_sys-t: Add support for CLOCKSYNC packets (Jiri Olsa) [1907791]
- stm class: Add MIPI SyS-T protocol support (Jiri Olsa) [1907791]
- stm class: Switch over to the protocol driver (Jiri Olsa) [1907791]
- stm class: Factor out default framing protocol (Jiri Olsa) [1907791]
- stm class: Add a helper for writing data packets (Jiri Olsa) [1907791]
- stm class: Introduce framing protocol drivers (Jiri Olsa) [1907791]
- stm class: Clean up stp_configfs_init (Jiri Olsa) [1907791]
- stm class: Clarify configfs root type/operations names (Jiri Olsa) [1907791]
- stm class: Rework policy node fallback (Jiri Olsa) [1907791]
- lib: Add memcat_p(): paste 2 pointer arrays together (Jiri Olsa) [1907791]
- tracing: Add trace_export support for trace_marker (Jiri Olsa) [1907791]
- tracing: Add trace_export support for event trace (Jiri Olsa) [1907791]
- tracing: Add flag to control different traces (Jiri Olsa) [1907791]
- tracing: Make function ‘ftrace_exports’ static (Jiri Olsa) [1907791]
- tipc: increment the tmp aead refcnt before attaching it (Xin Long) [1931312]
- tipc: skb_linearize the head skb when reassembling msgs (Xin Long) [1912376]
- scsi: target: core: Fix warning on realtime kernels (Maurizio Lombardi) [1956416]
- scsi: bnx2fc: Fix a typo (Nilesh Javali) [1921617]
- scsi: bnx2fc: Fix misnaming of bnx2fc_free_session_resc() (Nilesh Javali) [1921617]
- scsi: bnx2fc: Fix typo in bnx2fc_indicate_kcqe() (Nilesh Javali) [1921617]
- scsi: bnx2fc: Fix Kconfig warning & CNIC build errors (Nilesh Javali) [1921617]
- scsi: bnx2fc: Fix comparison to bool warning (Nilesh Javali) [1921617]
- scsi: bnx2fc: Remove unneeded semicolon (Nilesh Javali) [1921617]
- scsi: bnx2fc: Make a bunch of symbols static in bnx2fc_fcoe.c (Nilesh Javali) [1921617]
- scsi: bnx2fc: Fix spelling mistake "couldnt" -> "couldn't" (Nilesh Javali) [1921617]
- scsi: bnx2fc: Demote obvious misuse of kerneldoc to standard comment blocks (Nilesh Javali) [1921617]
- scsi: bnx2fc: Fix a couple of bitrotted function documentation headers (Nilesh Javali) [1921617]
- scsi: bnx2fc: Repair a range of kerneldoc issues (Nilesh Javali) [1921617]
- scsi: bnx2fc: Removal of unused variables (Nilesh Javali) [1921617]
- scsi: bnx2fc: Remove unneeded semicolon in bnx2fc_fcoe.c (Nilesh Javali) [1921617]
- scsi: bnx2fc: Add missing annotation for bnx2fc_abts_cleanup() (Nilesh Javali) [1921617]
- tools/power turbostat: Enable tsc_tweak for Elkhart Lake and Jasper Lake (Puneet Sethi) [1920704]
- selinux: Allow context mounts for unpriviliged overlayfs (Miklos Szeredi) [1956486]
- md-cluster: fix use-after-free issue when removing rdev (Nigel Croxon) [1956355]
- md/bitmap: wait for external bitmap writes to complete during tear down (Nigel Croxon) [1956355]
- md: do not return existing mddevs from mddev_find_or_alloc (Nigel Croxon) [1956355]
- md: refactor mddev_find_or_alloc (Nigel Croxon) [1956355]
- md: factor out a mddev_alloc_unit helper from mddev_find (Nigel Croxon) [1956355]
- md: split mddev_find (Nigel Croxon) [1956355]
- md: factor out a mddev_find_locked helper from mddev_find (Nigel Croxon) [1956355]
- md: md_open returns -EBUSY when entering racing area (Nigel Croxon) [1956355]
- md: Fix missing unused status line of /proc/mdstat (Nigel Croxon) [1956355]
- md/raid10: improve discard request for far layout (Xiao Ni) [1956355]
- md/raid10: improve raid10 discard request (Nigel Croxon) [1956355]
- md/raid10: pull the code that wait for blocked dev into one function (Xiao Ni) [1956355]
- md/raid10: extend r10bio devs to raid disks (Xiao Ni) [1956355]
- md: add md_submit_discard_bio() for submitting discard bio (Nigel Croxon) [1956355]
- leds: trigger: fix potential deadlock with libata (Waiman Long) [1963373]
- x86/kvm: Unify kvm_pv_guest_cpu_reboot() with kvm_guest_cpu_offline() (Lenny Szubowicz) [1934273]
- x86/kvm: Disable all PV features on crash (Lenny Szubowicz) [1934273]
- x86/kvm: Disable kvmclock on all CPUs on shutdown (Lenny Szubowicz) [1934273]
- x86/kvm: Teardown PV features on boot CPU as well (Lenny Szubowicz) [1934273]
- x86/kvm: Fix pr_info() for async PF setup/teardown (Lenny Szubowicz) [1934273]
- RDMA/qedr: Fix error return code in qedr_iw_connect() (Manish Chopra) [1914922]
- qede: Use 'skb_add_rx_frag()' instead of hand coding it (Manish Chopra) [1914922]
- qede: Remove a erroneous ++ in 'qede_rx_build_jumbo()' (Manish Chopra) [1914922]
- qede: fix offload for IPIP tunnel packets (Manish Chopra) [1914922]
- RDMA/qedr: iWARP invalid(zero) doorbell address fix (Manish Chopra) [1914922]
- qed: fix ILT configuration of SRC block (Manish Chopra) [1914922]
- qed: fix error return code in qed_iwarp_ll2_start() (Manish Chopra) [1914922]
- RDMA/qedr: Fix resource leak in qedr_create_qp (Manish Chopra) [1914922]
- qede: make driver reliable on unload after failures (Manish Chopra) [1914922]
- net: qed: Remove unnecessary cast (Manish Chopra) [1914922]
- nvme: fix NULL derefence in nvme_ctrl_fast_io_fail_tmo_show/store (Gopal Tiwari) [1935135]
- nvme: export fast_io_fail_tmo to sysfs (Gopal Tiwari) [1935135]
- EDAC: enable CONFIG_EDAC_IGEN6 (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/igen6: ecclog_llist can be static (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/i10nm: Add Intel Sapphire Rapids server support (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC: Add DDR5 new memory type (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/i10nm: Use readl() to access MMIO registers (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/igen6: Add debugfs interface for Intel client SoC EDAC driver (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/igen6: Add EDAC driver for Intel client SoCs using IBECC (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC: Add three new memory types (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC, {skx,i10nm}: Use CPU stepping macro to pass configurations (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/skx: Use the mcmtr register to retrieve close_pg/bank_xor_enable (Aristeu Rozanski) [1837389 1783539 1861479]
- x86/cpu: Add a X86_MATCH_INTEL_FAM6_MODEL_STEPPINGS() macro (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC: Add missing MEM_LRDDR4 entry in edac_mem_types[] (Aristeu Rozanski) [1837389 1783539 1861479]
- x86: export x86_match_cpu_v2 (Aristeu Rozanski) [1837389 1783539 1861479]
- EDAC/amd64: Fix PCI component registration (Aristeu Rozanski) [1918583]
- EDAC/mce_amd: Use struct cpuinfo_x86.cpu_die_id for AMD NodeId (Aristeu Rozanski) [1918583]
- x86/CPU/AMD: Remove amd_get_nb_id() (Aristeu Rozanski) [1918583]
- EDAC/mce_amd: Make fam_ops static global (Aristeu Rozanski) [1918583]
- x86/MCE/AMD: Allow Reserved types to be overwritten in smca_banks[] (Aristeu Rozanski) [1918583]
- x86/MCE/AMD: Do not use rdmsr_safe_on_cpu() in smca_configure() (Aristeu Rozanski) [1918583]
- EDAC/amd64: Get rid of the ECC disabled long message (Aristeu Rozanski) [1918583]
- EDAC/amd64: Check for memory before fully initializing an instance (Aristeu Rozanski) [1918583]
- EDAC/amd64: Use cached data when checking for ECC (Aristeu Rozanski) [1918583]
- x86/MCE: Make the number of MCA banks a per-CPU variable (Aristeu Rozanski) [1918583]
- x86/MCE/AMD: Don't cache block addresses on SMCA systems (Aristeu Rozanski) [1918583]
- x86/MCE: Make mce_banks a per-CPU array (Aristeu Rozanski) [1918583]
- x86/MCE: Make struct mce_banks[] static (Aristeu Rozanski) [1918583]
- x86/MCE/AMD: Don't report L1 BTB MCA errors on some family 17h models (Aristeu Rozanski) [1918583]
- EDAC/mce_amd: Decode MCA_STATUS in bit definition order (Aristeu Rozanski) [1918583]
- EDAC/mce_amd: Decode MCA_STATUS[Scrub] bit (Aristeu Rozanski) [1918583]
- EDAC, mce_amd: Match error descriptions to latest documentation (Aristeu Rozanski) [1918583]
- x86/MCE/AMD: Carve out the MC4_MISC thresholding quirk (Aristeu Rozanski) [1918583]
- x86/MCE/AMD: Turn off MC4_MISC thresholding on all family 0x15 models (Aristeu Rozanski) [1918583]
- powerpc/64s: Fix unrelocated interrupt trampoline address test (Waiman Long) [1966462]
- intel_th: pci: Add Alder Lake CPU support (Jiri Olsa) [1840246]
- intel_th: pci: Add Alder Lake-S support (Jiri Olsa) [1840246]
- mfd: intel_pmt: Add support for DG1 (David Arcari) [1783144]
- mfd: intel_pmt: Fix nuisance messages and handling of disabled capabilities (David Arcari) [1783144]
- redhat/configs: Add CONFIG_INTEL_PMT_CRASHLOG (David Arcari) [1783144]
- redhat/configs: Add CONFIG_INTEL_PMT_TELEMETRY (David Arcari) [1783144]
- redhat/configs: Add CONFIG_MFD_INTEL_PMT (David Arcari) [1783144]
- platform/x86: intel_pmt_crashlog: Add dependency on MFD_INTEL_PMT (David Arcari) [1783144]
- platform/x86: intel_pmt_telemetry: Add dependency on MFD_INTEL_PMT (David Arcari) [1783144]
- platform/x86: intel_pmt: Make INTEL_PMT_CLASS non-user-selectable (David Arcari) [1783144]
- platform/x86: intel_pmt_crashlog: Fix incorrect macros (David Arcari) [1783144]
- platform/x86: intel_pmt_class: Initial resource to 0 (David Arcari) [1783144]
- mfd: Standardise MFD_CELL_* helper names (David Arcari) [1783144]
- platform/x86: pmt: Fix a potential Oops on error in probe (David Arcari) [1783144]
- platform/x86: Intel PMT Crashlog capability driver (David Arcari) [1783144]
- platform/x86: Intel PMT Telemetry capability driver (David Arcari) [1783144]
- platform/x86: Intel PMT class driver (David Arcari) [1783144]
- mfd: Intel Platform Monitoring Technology support (David Arcari) [1783144]
- mfd: mfd-core: Ensure disabled devices are ignored without error (David Arcari) [1783144]
- mfd: core: Fix double-free in mfd_remove_devices_fn() (David Arcari) [1783144]
- mfd: mfd-core: Add mechanism for removal of a subset of children (David Arcari) [1783144]
- mfd: core: Add OF_MFD_CELL_REG() helper (David Arcari) [1783144]
- mfd: core: Fix formatting of MFD helpers (David Arcari) [1783144]
- mfd: core: Make a best effort attempt to match devices with the correct of_nodes (David Arcari) [1783144]
- mfd: mfd-core: Complete kerneldoc header for devm_mfd_add_devices() (David Arcari) [1783144]
- mfd: Constify properties in mfd_cell (David Arcari) [1783144]
- mfd: mfd-core: Honour Device Tree's request to disable a child-device (David Arcari) [1783144]
- mfd: mfd-core: Move pdev->mfd_cell creation back into mfd_add_device() (David Arcari) [1783144]
- mfd: mfd-core: Remove usage counting for .{en,dis}able() call-backs (David Arcari) [1783144]
- mfd: mfd-core: Protect against NULL call-back function pointer (David Arcari) [1783144]
- mfd: mfd-core: Remove mfd_clone_cell() (David Arcari) [1783144]
- mfd: Provide MACRO to declare commonly defined MFD cell attributes (David Arcari) [1783144]
- mfd: core: Set fwnode for created devices (David Arcari) [1783144]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (David Arcari) [1783144]
- mfd: mfd-core: Document mfd_add_devices() (David Arcari) [1783144]
- PCI: Add defines for Designated Vendor-Specific Extended Capability (David Arcari) [1783144]
- tick/nohz: Update idle_exittime on actual idle exit (Phil Auld) [1962632]
- tick/nohz: Remove superflous check for CONFIG_VIRT_CPU_ACCOUNTING_NATIVE (Phil Auld) [1962632]
- tick/nohz: Conditionally restart tick on idle exit (Phil Auld) [1962632]
- x86, sched: Fix the AMD CPPC maximum performance value on certain AMD Ryzen generations (Phil Auld) [1960687]
- pinctrl: devicetree: Avoid taking direct reference to device name string (Aristeu Rozanski) [1922904] {CVE-2020-0427}
- redhat: ppc64: enable CONFIG_PPC_RTAS_FILTER (Aristeu Rozanski) [1906444] {CVE-2020-27777}
- powerpc/rtas: Fix typo of ibm,open-errinjct in RTAS filter (Aristeu Rozanski) [1906444] {CVE-2020-27777}
- powerpc/rtas: Restrict RTAS requests from userspace (Aristeu Rozanski) [1906444] {CVE-2020-27777}

* Thu Jun 10 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-313.el8]
- docs: vxlan: add info about device features (Petr Oros) [1941739]
- selftests: net: add a test for static UDP tunnel ports (Petr Oros) [1941739]
- netdevsim: support the static IANA VXLAN port flag (Petr Oros) [1941739]
- selftests: net: add a test for shared UDP tunnel info tables (Petr Oros) [1941739]
- netdevsim: shared UDP tunnel port table support (Petr Oros) [1941739]
- netdevsim: add warnings on unexpected UDP tunnel port errors (Petr Oros) [1941739]
- udp_tunnel: add the ability to share port tables (Petr Oros) [1941739]
- docs: networking: convert vxlan.txt to ReST (Petr Oros) [1941739]
- net: Treat __napi_schedule_irqoff() as __napi_schedule() on PREEMPT_RT (Ivan Vecera) [1960528]
- ethtool: fix incorrect datatype in set_eee ops (Balazs Nemeth) [1956698]
- ethtool: fix missing NLM_F_MULTI flag when dumping (Antoine Tenart) [1953847]
- y2038: remove CONFIG_64BIT_TIME (Waiman Long) [1965360]
- net/mlx4: Fix EEPROM dump support (Alaa Hleihel) [1915305]
- net/mlx4_en: update moderation when config reset (Alaa Hleihel) [1915305]
- net/mlx4_core: Add missed mlx4_free_cmd_mailbox() (Alaa Hleihel) [1915305]
- IB/mlx4: Use port iterator and validation APIs (Alaa Hleihel) [1915305]
- net/mlx4: Use effective interrupt affinity (Alaa Hleihel) [1915302 1915305]
- net/mlx4: Replace irq_to_desc() abuse (Alaa Hleihel) [1915302 1915305]
- net/mlx4: simplify the return expression of mlx4_init_srq_table() (Alaa Hleihel) [1915302 1915305]
- RDMA/mlx4: Remove bogus dev_base_lock usage (Alaa Hleihel) [1915302 1915305]
- net/mlx4: simplify the return expression of mlx4_init_cq_table() (Alaa Hleihel) [1915302 1915305]
- net/mlx4: Remove unused #define MAX_MSIX_P_PORT (Alaa Hleihel) [1915302 1915305]
- RDMA/mlx4: Enable querying AH for XRC QP types (Alaa Hleihel) [1915302 1915305]
- IB/mlx4: Fix fall-through warnings for Clang (Alaa Hleihel) [1915302 1915305]
- net/mlx4_en: Remove unused performance counters (Alaa Hleihel) [1915302 1915305]
- net/mlx4: Assign boolean values to a bool variable (Alaa Hleihel) [1915302 1915305]
- net/mlx4: Cleanup kernel-doc warnings (Alaa Hleihel) [1915302 1915305]
- net/mlx4_core : remove unneeded semicolon (Alaa Hleihel) [1915302 1915305]
- net/mlx4_core: Fix init_hca fields offset (Alaa Hleihel) [1915301 1915305]
- mlx4: handle non-napi callers to napi_poll (Alaa Hleihel) [1915301 1915305]
- mlx4: drivers/net/ethernet: clean up unused assignments (Alaa Hleihel) [1915301 1915305]
- mlx4: add pause frame stats (Alaa Hleihel) [1915301 1915305]
- mlx4: make sure to always set the port type (Alaa Hleihel) [1915301 1915305]
- net/mlx4_en: RX, Add a prefetch command for small L1_CACHE_BYTES (Alaa Hleihel) [1915301 1915305]
- cnic: remove redundant assignment to variable ret (Nilesh Javali) [1921619]
- net: cnic: fix spelling mistake "reserverd" -> "reserved" (Nilesh Javali) [1921619]
- cnic: Explicitly initialize all reference counts to 0. (Nilesh Javali) [1921619]
- cfg80211: fix locking in netlink owner interface destruction (Jarod Wilson) [1937053]
- brcmfmac: Avoid GFP_ATOMIC when GFP_KERNEL is enough (Jarod Wilson) [1937053]
- ath11k: fix warning in ath11k_mhi_config (Jarod Wilson) [1937053]
- ath11k: qmi: Fix spelling mistake "requeqst" -> "request" (Jarod Wilson) [1937053]
- ath10k: Fix ath10k_wmi_tlv_op_pull_peer_stats_info() unlock without lock (Jarod Wilson) [1937053]
- ath10k: Fix a use after free in ath10k_htc_send_bundle (Jarod Wilson) [1937053]
- ath9k: Fix error check in ath9k_hw_read_revisions() for PCI devices (Jarod Wilson) [1937053]
- mt76: mt7921: reinit wpdma during drv_own if necessary (Jarod Wilson) [1937053]
- mt76: move mt76_token_init in mt76_alloc_device (Jarod Wilson) [1937053]
- mt76: mt7921: fix a precision vs width bug in printk (Jarod Wilson) [1937053]
- mt76: mt7915: fix a precision vs width bug in printk (Jarod Wilson) [1937053]
- mt76: mt7615: fix a precision vs width bug in printk (Jarod Wilson) [1937053]
- mt76: mt7921: introduce mt7921_mcu_sta_add routine (Jarod Wilson) [1937053]
- mt76: mt7921: mt7921_stop should put device in fw_own state (Jarod Wilson) [1937053]
- mt76: connac: unschedule mac_work before going to sleep (Jarod Wilson) [1937053]
- mt76: mt7663: add awake and doze time accounting (Jarod Wilson) [1937053]
- mt76: mt7921: improve doze opportunity (Jarod Wilson) [1937053]
- mt76: mt7921: get rid of mcu_reset function pointer (Jarod Wilson) [1937053]
- mt76: mt7915: do not read rf value from efuse in flash mode (Jarod Wilson) [1937053]
- mt76: move token utilities in mt76 common module (Jarod Wilson) [1937053]
- mt76: move token_lock, token and token_count in mt76_dev (Jarod Wilson) [1937053]
- mt76: mt7921: fix possible invalid register access (Jarod Wilson) [1937053]
- mt76: mt7921: enable deep sleep when the device suspends (Jarod Wilson) [1937053]
- mt76: connac: introduce mt76_connac_mcu_set_deep_sleep utility (Jarod Wilson) [1937053]
- mt76: mt7921: introduce mt7921_wpdma_reinit_cond utility routine (Jarod Wilson) [1937053]
- mt76: mt7921: introduce mt7921_dma_{enable,disable} utilities (Jarod Wilson) [1937053]
- mt76: mt7921: introduce mt7921_wpdma_reset utility routine (Jarod Wilson) [1937053]
- mt76: mt7921: move mt7921_dma_reset in dma.c (Jarod Wilson) [1937053]
- mt76: mt7615: Fix a dereference of pointer sta before it is null checked (Jarod Wilson) [1937053]
- mt76: mt7921: enable sw interrupts (Jarod Wilson) [1937053]
- mt76: mt7921: add awake and doze time accounting (Jarod Wilson) [1937053]
- mt76: remove MT76_STATE_PM in tx path (Jarod Wilson) [1937053]
- mt76: connac: use waitqueue for runtime-pm (Jarod Wilson) [1937053]
- mt76: connac: do not run mt76_txq_schedule_all directly (Jarod Wilson) [1937053]
- mt76: mt7615: rely on pm refcounting in mt7615_led_set_config (Jarod Wilson) [1937053]
- mt76: connac: alaways wake the device before scanning (Jarod Wilson) [1937053]
- mt76: mt7921: get rid of useless MT76_STATE_PM in mt7921_mac_work (Jarod Wilson) [1937053]
- mt76: connac: remove MT76_STATE_PM in mac_tx_free (Jarod Wilson) [1937053]
- mt76: connac: check wake refcount in mcu_fw_pmctrl (Jarod Wilson) [1937053]
- mt76: connac: unschedule ps_work in mt76_connac_pm_wake (Jarod Wilson) [1937053]
- mt76: mt7663: rely on mt76_connac_pm_ref/mt76_connac_pm_unref in tx/rx napi (Jarod Wilson) [1937053]
- mt76: mt7921: rely on mt76_connac_pm_ref/mt76_connac_pm_unref in tx/rx napi (Jarod Wilson) [1937053]
- mt76: dma: add the capability to define a custom rx napi poll routine (Jarod Wilson) [1937053]
- mt76: mt7663: rely on mt76_connac_pm_ref/mt76_connac_pm_unref in tx path (Jarod Wilson) [1937053]
- mt76: mt7921: rely on mt76_connac_pm_ref/mt76_connac_pm_unref in tx path (Jarod Wilson) [1937053]
- mt76: connac: introduce wake counter for fw_pmctrl synchronization (Jarod Wilson) [1937053]
- mt76: mt7663: fix a race between mt7615_mcu_drv_pmctrl and mt7615_mcu_fw_pmctrl (Jarod Wilson) [1937053]
- mt76: mt7921: fix a race between mt7921_mcu_drv_pmctrl and mt7921_mcu_fw_pmctrl (Jarod Wilson) [1937053]
- mt76: mt7921: remove leftover function declaration (Jarod Wilson) [1937053]
- mt76: connac: move mcu_update_arp_filter in mt76_connac module (Jarod Wilson) [1937053]
- mt76: mt7921: do not use 0 as NULL pointer (Jarod Wilson) [1937053]
- mt76: mt7915: directly read per-rate tx power from registers (Jarod Wilson) [1937053]
- mt76: mt7915: rework the flow of txpower setting (Jarod Wilson) [1937053]
- mt76: mt7915: add support for DT rate power limits (Jarod Wilson) [1937053]
- mt76: mt7921: abort uncompleted scan by wifi reset (Jarod Wilson) [1937053]
- mt76: mt7921: add wifisys reset support in debugfs (Jarod Wilson) [1937053]
- mt76: mt7921: run mt7921_mcu_fw_log_2_host holding mt76 mutex (Jarod Wilson) [1937053]
- mt76: improve mcu error logging (Jarod Wilson) [1937053]
- mt76: mt7921: move hw configuration in mt7921_register_device (Jarod Wilson) [1937053]
- mt76: mt7915: add support for applying pre-calibration data (Jarod Wilson) [1937053]
- mt76: mt7615: load ROM patch before checking patch semaphore status (Jarod Wilson) [1937053]
- mt76: mt7615: fix entering driver-own state on mt7663 (Jarod Wilson) [1937053]
- mt76: mt7615: fix hardware error recovery for mt7663 (Jarod Wilson) [1937053]
- mt76: mt7921: add dumping Tx power table (Jarod Wilson) [1937053]
- mt76: introduce single-sku support for mt7663/mt7921 (Jarod Wilson) [1937053]
- mt76: mt7615: do not use mt7615 single-sku values for mt7663 (Jarod Wilson) [1937053]
- mt76: mt7615: implement support for using DT rate power limits (Jarod Wilson) [1937053]
- mt76: extend DT rate power limits to support 11ax devices (Jarod Wilson) [1937053]
- mt76: add functions for parsing rate power limits from DT (Jarod Wilson) [1937053]
- mt76: flush tx status queue on DMA reset (Jarod Wilson) [1937053]
- mt76: mt7921: add mt7921_dma_cleanup in mt7921_unregister_device (Jarod Wilson) [1937053]
- mt76: mt7615: use ieee80211_free_txskb() in mt7615_tx_token_put() (Jarod Wilson) [1937053]
- mt76: mt7615: only free skbs after mt7615_dma_reset() when reset happens (Jarod Wilson) [1937053]
- mt76: mt7915: only free skbs after mt7915_dma_reset() when reset happens (Jarod Wilson) [1937053]
- mt76: mt7915: fix memleak when mt7915_unregister_device() (Jarod Wilson) [1937053]
- mt76: mt7615: fix memleak when mt7615_unregister_device() (Jarod Wilson) [1937053]
- mt76: mt7915: fix rate setting of tx descriptor in testmode (Jarod Wilson) [1937053]
- mt76: mt7915: rework mt7915_tm_set_tx_len() (Jarod Wilson) [1937053]
- mt76: testmode: add support to send larger packet (Jarod Wilson) [1937053]
- rtlwifi: implement set_tim by update beacon content (Jarod Wilson) [1937053]
- rtw88: refine napi deinit flow (Jarod Wilson) [1937053]
- rtw88: Fix potential unrecoverable tx queue stop (Jarod Wilson) [1937053]
- rtw88: 8821c: Don't set RX_FLAG_DECRYPTED if packet has no encryption (Jarod Wilson) [1937053]
- rtw88: 8822c: debug: allow debugfs to enable/disable TXGAPK (Jarod Wilson) [1937053]
- rtw88: 8822c: Add gap-k calibration to improve long range performance (Jarod Wilson) [1937053]
- rtw88: 8822c: reorder macro position according to the register number (Jarod Wilson) [1937053]
- iwlwifi: Fix softirq/hardirq disabling in iwl_pcie_gen2_enqueue_hcmd() (Jarod Wilson) [1937053]
- cfg80211: scan: drop entry from hidden_list on overflow (Jarod Wilson) [1937053]
- wireless: fix spelling of A-MSDU in HE capabilities (Jarod Wilson) [1937053]
- wireless: align HE capabilities A-MPDU Length Exponent Extension (Jarod Wilson) [1937053]
- wireless: align some HE capabilities with the spec (Jarod Wilson) [1937053]
- mac80211: drop the connection if firmware crashed while in CSA (Jarod Wilson) [1937053]
- nl80211: Add new RSNXE related nl80211 extended features (Jarod Wilson) [1937053]
- mac80211: properly drop the connection in case of invalid CSA IE (Jarod Wilson) [1937053]
- mac80211: make ieee80211_vif_to_wdev work when the vif isn't in the driver (Jarod Wilson) [1937053]
- nl80211/cfg80211: add a flag to negotiate for LMR feedback in NDP ranging (Jarod Wilson) [1937053]
- ieee80211: add the values of ranging parameters max LTF total field (Jarod Wilson) [1937053]
- mac80211: aes_cmac: check crypto_shash_setkey() return value (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: remove extraneous indentation on if statement (Jarod Wilson) [1937053]
- mac80211: properly process TXQ management frames (Jarod Wilson) [1937053]
- cfg80211: constify ieee80211_get_response_rate return (Jarod Wilson) [1937053]
- cfg80211: fix a few kernel-doc warnings (Jarod Wilson) [1937053]
- cfg80211: fix an htmldoc warning (Jarod Wilson) [1937053]
- rtw88: 8822c: add CFO tracking (Jarod Wilson) [1937053]
- iwlwifi: pcie: don't enable BHs with IRQs disabled (Jarod Wilson) [1937053]
- rtw88: Fix array overrun in rtw_get_tx_power_params() (Jarod Wilson) [1937053]
- brcmfmac: Remove duplicate struct declaration (Jarod Wilson) [1937053]
- rtw88: update statistics to fw for fine-tuning performance (Jarod Wilson) [1937053]
- brcmfmac: A typo fix (Jarod Wilson) [1937053]
- rtl8xxxu: Simplify locking of a skb list accesses (Jarod Wilson) [1937053]
- mwifiex: Remove unneeded variable: "ret" (Jarod Wilson) [1937053]
- rtl8xxxu: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- mwifiex: don't print SSID to logs (Jarod Wilson) [1937053]
- rtlwifi: rtl8192de: Use DEFINE_SPINLOCK() for spinlock (Jarod Wilson) [1937053]
- rtlwifi: Simplify locking of a skb list accesses (Jarod Wilson) [1937053]
- rtlwifi: remove rtl_get_tid_h (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: remove redundant assignment of variable rtlpriv->btcoexist.reg_bt_sco (Jarod Wilson) [1937053]
- rtlwifi: remove redundant assignment to variable err (Jarod Wilson) [1937053]
- rtlwifi: Few mundane typo fixes (Jarod Wilson) [1937053]
- rtlwifi: 8821ae: upgrade PHY and RF parameters (Jarod Wilson) [1937053]
- iwlwifi: dbg: disable ini debug in 9000 family and below (Jarod Wilson) [1937053]
- iwlwifi: pcie: Change ma product string name (Jarod Wilson) [1937053]
- iwlwifi: fw: print out trigger delay when collecting data (Jarod Wilson) [1937053]
- iwlwifi: trans/pcie: defer transport initialisation (Jarod Wilson) [1937053]
- iwlwifi: bump FW API to 63 for AX devices (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't WARN if we can't remove a time event (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't disconnect immediately if we don't hear beacons after CSA (Jarod Wilson) [1937053]
- iwlwifi: rs-fw: don't support stbc for HE 160 (Jarod Wilson) [1937053]
- iwlwifi: warn on SKB free w/o op-mode (Jarod Wilson) [1937053]
- iwlwifi: mvm: add support for version 3 of LARI_CONFIG_CHANGE command. (Jarod Wilson) [1937053]
- iwlwifi: pcie: add ISR debug info for msix debug (Jarod Wilson) [1937053]
- iwlwifi: pcie: merge napi_poll_msix functions (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't lock mutex in RCU critical section (Jarod Wilson) [1937053]
- iwlwifi: mvm: remove PS from lower rates. (Jarod Wilson) [1937053]
- iwlwifi: mvm: umac error table mismatch (Jarod Wilson) [1937053]
- iwlwifi: queue: avoid memory leak in reset flow (Jarod Wilson) [1937053]
- iwlwifi: don't warn if we can't wait for empty tx queues (Jarod Wilson) [1937053]
- iwlwifi: remove remaining software checksum code (Jarod Wilson) [1937053]
- iwlwifi: remove TCM events (Jarod Wilson) [1937053]
- iwlwifi: mvm: Use IWL_INFO in fw_reset_handshake() (Jarod Wilson) [1937053]
- iwlwifi: mvm: refactor ACPI DSM evaluation function (Jarod Wilson) [1937053]
- iwlwifi: mvm: support BIOS enable/disable for 11ax in Ukraine (Jarod Wilson) [1937053]
- iwlwifi: move iwl_configure_rxq to be used by other op_modes (Jarod Wilson) [1937053]
- iwlwifi: add new so-gf device (Jarod Wilson) [1937053]
- iwlwifi: mvm: enable PPAG in China (Jarod Wilson) [1937053]
- iwlwifi: mvm: Add support for 6GHz passive scan (Jarod Wilson) [1937053]
- iwlwifi: add ax201 killer device (Jarod Wilson) [1937053]
- iwlwifi: mvm: when associated with PMF, use protected NDP ranging negotiation (Jarod Wilson) [1937053]
- iwlwifi: mvm: clean up queue sync implementation (Jarod Wilson) [1937053]
- iwlwifi: mvm: write queue_sync_state only for sync (Jarod Wilson) [1937053]
- iwlwifi: mvm: responder: support responder config command version 8 (Jarod Wilson) [1937053]
- iwlwifi: mvm: support range request command version 12 (Jarod Wilson) [1937053]
- iwlwifi: pcie: make cfg vs. trans_cfg more robust (Jarod Wilson) [1937053]
- iwlwifi: pcie: clear only FH bits handle in the interrupt (Jarod Wilson) [1937053]
- iwlwifi: add 160Mhz to killer 1550 name (Jarod Wilson) [1937053]
- iwlwifi: change name to AX 211 and 411 family (Jarod Wilson) [1937053]
- iwlwifi: change step in so-gf struct (Jarod Wilson) [1937053]
- iwlwifi: pcie: Add support for Bz Family (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't allow CSA if we haven't been fully associated (Jarod Wilson) [1937053]
- iwlwifi: pcie: normally grab NIC access for inflight-hcmd (Jarod Wilson) [1937053]
- iwlwifi: pcie: avoid unnecessarily taking spinlock (Jarod Wilson) [1937053]
- iwlwifi: mvm: enable TX on new CSA channel before disconnecting (Jarod Wilson) [1937053]
- mt76: mt7921: add rcu section in mt7921_mcu_tx_rate_report (Jarod Wilson) [1937053]
- mt76: mt7921: introduce MCU_EVENT_LP_INFO event parsing (Jarod Wilson) [1937053]
- mt76: mt7615: always add rx header translation tlv when adding stations (Jarod Wilson) [1937053]
- mt76: mt7615: add missing SPDX tag in mmio.c (Jarod Wilson) [1937053]
- mt76: mt7915: add mmio.c (Jarod Wilson) [1937053]
- mt76: report Rx timestamp (Jarod Wilson) [1937053]
- mt76: mt7921: remove 80+80 MHz support capabilities (Jarod Wilson) [1937053]
- mt76: fix potential DMA mapping leak (Jarod Wilson) [1937053]
- mt76: mt7921: reduce the data latency during hw scan (Jarod Wilson) [1937053]
- mt76: mt7921: fix the insmod hangs (Jarod Wilson) [1937053]
- mt76: mt7921: fix kernel crash when the firmware fails to download (Jarod Wilson) [1937053]
- mt76: mt7921: fix the dwell time control (Jarod Wilson) [1937053]
- mt76: mt7921: fix inappropriate WoW setup with the missing ARP informaiton (Jarod Wilson) [1937053]
- mt76: mt7921: introduce MT_WFDMA_DUMMY_CR definition (Jarod Wilson) [1937053]
- mt76: mt7915: add wifi subsystem reset (Jarod Wilson) [1937053]
- mt76: mt7915: fix mt7915_mcu_add_beacon (Jarod Wilson) [1937053]
- mt76: mt7615: fix .add_beacon_offload() (Jarod Wilson) [1937053]
- mt76: mt7921: rework mt7921_mcu_debug_msg_event routine (Jarod Wilson) [1937053]
- mt76: mt7921: always wake the device in mt7921_remove_interface (Jarod Wilson) [1937053]
- mt76: mt7921: fix key set/delete issue (Jarod Wilson) [1937053]
- mt76: mt7915: fix txpower init for TSSI off chips (Jarod Wilson) [1937053]
- mt76: mt7915: limit firmware log message printk to buffer length (Jarod Wilson) [1937053]
- mt76: mt7615: limit firmware log message printk to buffer length (Jarod Wilson) [1937053]
- mt76: mt7615: fix chip reset on MT7622 and MT7663e (Jarod Wilson) [1937053]
- mt76: mt7915: cleanup mcu tx queue in mt7915_dma_reset() (Jarod Wilson) [1937053]
- mt76: mt7915: keep mcu_add_bss_info enabled till interface removal (Jarod Wilson) [1937053]
- mt76: mt7615: keep mcu_add_bss_info enabled till interface removal (Jarod Wilson) [1937053]
- mt76: mt7622: trigger hif interrupt for system reset (Jarod Wilson) [1937053]
- mt76: mt7615: cleanup mcu tx queue in mt7615_dma_reset() (Jarod Wilson) [1937053]
- mt76: mt7615: only enable DFS test knobs for mt7615 (Jarod Wilson) [1937053]
- mt76: mt7921: properly configure rcpi adding a sta to the fw (Jarod Wilson) [1937053]
- mt76: connac: introduce mt76_sta_cmd_info data structure (Jarod Wilson) [1937053]
- mt76: mt7921: get rid of mt7921_mac_wtbl_lmac_addr (Jarod Wilson) [1937053]
- mt76: mt7915: refresh repeater entry MAC address when setting BSSID (Jarod Wilson) [1937053]
- mt76: mt7915: fix key set/delete issue (Jarod Wilson) [1937053]
- mt76: mt7921: remove duplicated macros in mcu.h (Jarod Wilson) [1937053]
- mt76: mt7921: remove redundant check on type (Jarod Wilson) [1937053]
- mt76: mt7921: remove leftovers from dbdc configuration (Jarod Wilson) [1937053]
- mt76: mt7921: add wifi reset support (Jarod Wilson) [1937053]
- mt76: dma: export mt76_dma_rx_cleanup routine (Jarod Wilson) [1937053]
- mt76: dma: introduce mt76_dma_queue_reset routine (Jarod Wilson) [1937053]
- mt76: mt7921: introduce __mt7921_start utility routine (Jarod Wilson) [1937053]
- mt76: mt7921: introduce mt7921_run_firmware utility routine. (Jarod Wilson) [1937053]
- mt76: introduce mcu_reset function pointer in mt76_mcu_ops structure (Jarod Wilson) [1937053]
- mt76: mt7921: reduce mcu timeouts for suspend, offload and hif_ctrl msg (Jarod Wilson) [1937053]
- mt76: mt7915: fix possible deadlock while mt7915_register_ext_phy() (Jarod Wilson) [1937053]
- mt76: mt7615: add missing capabilities for DBDC (Jarod Wilson) [1937053]
- mt76: mt7663s: fix the possible device hang in high traffic (Jarod Wilson) [1937053]
- mt76: mt7663s: make all of packets 4-bytes aligned in sdio tx aggregation (Jarod Wilson) [1937053]
- mt76: mt7663: fix when beacon filter is being applied (Jarod Wilson) [1937053]
- mt76: mt7615: check mcu returned values in mt7615_ops (Jarod Wilson) [1937053]
- mt76: mt7915: check mcu returned values in mt7915_ops (Jarod Wilson) [1937053]
- mt76: mt7915: fix txrate reporting (Jarod Wilson) [1937053]
- mt76: mt7915: fix rxrate reporting (Jarod Wilson) [1937053]
- mt76: mt76x0u: Add support for TP-Link T2UHP(UN) v1 (Jarod Wilson) [1937053]
- mt76: mt7915: fix PHY mode for DBDC (Jarod Wilson) [1937053]
- mt76: mt7915: stop ext_phy queue when mac reset happens (Jarod Wilson) [1937053]
- mt76: mt7915: fix CSA notification for DBDC (Jarod Wilson) [1937053]
- mt76: mt7615: stop ext_phy queue when mac reset happens (Jarod Wilson) [1937053]
- mt76: mt7615: fix CSA notification for DBDC (Jarod Wilson) [1937053]
- mt76: mt7915: add missing capabilities for DBDC (Jarod Wilson) [1937053]
- mt76: mt7921: check mcu returned values in mt7921_start (Jarod Wilson) [1937053]
- mt76: mt7921: fix the base of the dynamic remap (Jarod Wilson) [1937053]
- mt76: mt7921: fix the base of PCIe interrupt (Jarod Wilson) [1937053]
- mt76: mt7921: get rid of mt7921_sta_rc_update routine (Jarod Wilson) [1937053]
- mt76: check return value of mt76_txq_send_burst in mt76_txq_schedule_list (Jarod Wilson) [1937053]
- mt76: connac: fix kernel warning adding monitor interface (Jarod Wilson) [1937053]
- mt76: mt7915: fix mib stats counter reporting to mac80211 (Jarod Wilson) [1937053]
- mt76: mt7615: fix mib stats counter reporting to mac80211 (Jarod Wilson) [1937053]
- mt76: mt7615: remove hdr->fw_ver check (Jarod Wilson) [1937053]
- mt76: mt7615: fix TSF configuration (Jarod Wilson) [1937053]
- mt76: mt7921: fix stats register definitions (Jarod Wilson) [1937053]
- mt76: mt7921: remove unneeded semicolon (Jarod Wilson) [1937053]
- mt76: mt7915: fix aggr len debugfs node (Jarod Wilson) [1937053]
- mt76: mt7921: fix aggr length histogram (Jarod Wilson) [1937053]
- mt76: mt7615: fix memory leak in mt7615_coredump_work (Jarod Wilson) [1937053]
- mt76: mt7615: add support for rx decapsulation offload (Jarod Wilson) [1937053]
- mt76: mt7615: add rx checksum offload support (Jarod Wilson) [1937053]
- mt76: mt7615: enable hw rx-amsdu de-aggregation (Jarod Wilson) [1937053]
- mt76: connac: update sched_scan cmd usage (Jarod Wilson) [1937053]
- mt76: mt7921: add flush operation (Jarod Wilson) [1937053]
- mt76: mt7921: fixup rx bitrate statistics (Jarod Wilson) [1937053]
- mt76: connac: fix up the setting for ht40 mode in mt76_connac_mcu_uni_add_bss (Jarod Wilson) [1937053]
- mt76: mt7921: switch to new api for hardware beacon filter (Jarod Wilson) [1937053]
- mt76: mt7921: fix memory leak in mt7921_coredump_work (Jarod Wilson) [1937053]
- mt76: mt7921: fix suspend/resume sequence (Jarod Wilson) [1937053]
- mt76: use PCI_VENDOR_ID_MEDIATEK to avoid open coded (Jarod Wilson) [1937053]
- mt76: mt7915: always check return value from mt7915_mcu_alloc_wtbl_req (Jarod Wilson) [1937053]
- mt76: connac: always check return value from mt76_connac_mcu_alloc_wtbl_req (Jarod Wilson) [1937053]
- mt76: mt76x0: disable GTK offloading (Jarod Wilson) [1937053]
- mt76: always use WTBL_MAX_SIZE for tlv allocation (Jarod Wilson) [1937053]
- mt76: mt7921: removed unused definitions in mcu.h (Jarod Wilson) [1937053]
- mt76: mt7921: remove unnecessary variable (Jarod Wilson) [1937053]
- mt76: mt7921: enable random mac addr during scanning (Jarod Wilson) [1937053]
- mt76: mt7615: support loading EEPROM for MT7613BE (Jarod Wilson) [1937053]
- mt76: mt7915: fix tx skb dma unmap (Jarod Wilson) [1937053]
- mt76: mt7615: fix tx skb dma unmap (Jarod Wilson) [1937053]
- mt76: mt7615: fix key set/delete issues (Jarod Wilson) [1937053]
- mt76: mt7915: add support for rx decapsulation offload (Jarod Wilson) [1937053]
- mt76: mt7915: add rx checksum offload support (Jarod Wilson) [1937053]
- mt76: mt7915: enable hw rx-amsdu de-aggregation (Jarod Wilson) [1937053]
- mt76: add support for 802.3 rx frames (Jarod Wilson) [1937053]
- cfg80211: Remove wrong RNR IE validation check (Jarod Wilson) [1937053]
- mac80211: bail out if cipher schemes are invalid (Jarod Wilson) [1937053]
- mac80211: clear the beacon's CRC after channel switch (Jarod Wilson) [1937053]
- mac80211: Set priority and queue mapping for injected frames (Jarod Wilson) [1937053]
- mac80211: Allow concurrent monitor iface and ethernet rx decap (Jarod Wilson) [1937053]
- nl80211: Add interface to indicate TDLS peer's HE capability (Jarod Wilson) [1937053]
- cfg80211: allow specifying a reason for hw_rfkill (Jarod Wilson) [1937053]
- nl80211: better document CMD_ROAM behavior (Jarod Wilson) [1937053]
- mac80211: set sk_pacing_shift for 802.3 txpath (Jarod Wilson) [1937053]
- mac80211: don't apply flow control on management frames (Jarod Wilson) [1937053]
- nl80211: Add missing line in nl80211_fils_discovery_policy (Jarod Wilson) [1937053]
- mac80211: remove redundant assignment of variable result (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: remove unused variable 'mg' in minstrel_ht_next_jump_rate() (Jarod Wilson) [1937053]
- cfg80211: regulatory: use DEFINE_SPINLOCK() for spinlock (Jarod Wilson) [1937053]
- mac80211_hwsim: use DEFINE_SPINLOCK() for spinlock (Jarod Wilson) [1937053]
- rfkill: use DEFINE_SPINLOCK() for spinlock (Jarod Wilson) [1937053]
- mt7601u: enable TDLS support (Jarod Wilson) [1937053]
- mt7601u: fix always true expression (Jarod Wilson) [1937053]
- rtw88: Fix an error code in rtw_debugfs_set_rsvd_page() (Jarod Wilson) [1937053]
- rtw88: coex: fix A2DP stutters while WL busy + WL scan (Jarod Wilson) [1937053]
- rtw88: 8822c: add LC calibration for RTL8822C (Jarod Wilson) [1937053]
- rtw88: 8822c: update tx power limit table to RF v40.1 (Jarod Wilson) [1937053]
- rtw88: fix DIG min setting (Jarod Wilson) [1937053]
- rtw88: add flush hci support (Jarod Wilson) [1937053]
- rtw88: 8822c: support FW crash dump when FW crash (Jarod Wilson) [1937053]
- rtw88: remove unnecessary variable (Jarod Wilson) [1937053]
- rtw88: coex: add power off setting (Jarod Wilson) [1937053]
- ath11k: Add support for STA to handle beacon miss (Jarod Wilson) [1937053]
- ath11k: Update signal filled flag during sta_statistics drv op (Jarod Wilson) [1937053]
- ath10k: skip the wait for completion to recovery in shutdown path (Jarod Wilson) [1937053]
- ath11k: fix thermal temperature read (Jarod Wilson) [1937053]
- ath11k: fix potential wmi_mgmt_tx_queue race condition (Jarod Wilson) [1937053]
- ath11k: qmi: cosmetic changes to error messages (Jarod Wilson) [1937053]
- ath11k: qmi: add more debug messages (Jarod Wilson) [1937053]
- Revert "ath9k: fix ath_tx_process_buffer() potential null ptr dereference" (Jarod Wilson) [1937053]
- ath11k: print hardware name and version during initialisation (Jarod Wilson) [1937053]
- ath11k: Enable radar detection for 160MHz secondary segment (Jarod Wilson) [1937053]
- ath11k: Fix sounding dimension config in HE cap (Jarod Wilson) [1937053]
- ath11k: add qcn9074 pci device support (Jarod Wilson) [1937053]
- ath11k: add extended interrupt support for QCN9074 (Jarod Wilson) [1937053]
- ath11k: add CE interrupt support for QCN9074 (Jarod Wilson) [1937053]
- ath11k: add data path support for QCN9074 (Jarod Wilson) [1937053]
- ath11k: add hal support for QCN9074 (Jarod Wilson) [1937053]
- ath11k: add static window support for register access (Jarod Wilson) [1937053]
- ath11k: Add qcn9074 mhi controller config (Jarod Wilson) [1937053]
- ath11k: Update memory segment count for qcn9074 (Jarod Wilson) [1937053]
- ath11k: qmi: increase the number of fw segments (Jarod Wilson) [1937053]
- ath11k: Move qmi service_ins_id to hw_params (Jarod Wilson) [1937053]
- ath11k: Refactor ath11k_msi_config (Jarod Wilson) [1937053]
- ath11k: debugfs: Fix spelling mistake "Opportunies" -> "Opportunities" (Jarod Wilson) [1937053]
- ath9k: fix ath_tx_process_buffer() potential null ptr dereference (Jarod Wilson) [1937053]
- nl80211: fix beacon head validation (Jarod Wilson) [1937053]
- nl80211: fix potential leak of ACL params (Jarod Wilson) [1937053]
- cfg80211: check S1G beacon compat element length (Jarod Wilson) [1937053]
- cfg80211: remove WARN_ON() in cfg80211_sme_connect (Jarod Wilson) [1937053]
- mac80211: fix time-is-after bug in mlme (Jarod Wilson) [1937053]
- mac80211: fix TXQ AC confusion (Jarod Wilson) [1937053]
- rfkill: revert back to old userspace API by default (Jarod Wilson) [1937053]
- mac80211: clear sta->fast_rx when STA removed from 4-addr VLAN (Jarod Wilson) [1937053]
- iwlwifi: mvm: fix beacon protection checks (Jarod Wilson) [1937053]
- iwlwifi: mvm: rfi: don't lock mvm->mutex when sending config command (Jarod Wilson) [1937053]
- iwlwifi: pcie: add support for So-F devices (Jarod Wilson) [1937053]
- iwlwifi: fw: fix notification wait locking (Jarod Wilson) [1937053]
- iwlwifi: add support for Qu with AX201 device (Jarod Wilson) [1937053]
- iwlwifi: pcie: properly set LTR workarounds on 22000 devices (Jarod Wilson) [1937053]
- iwlwifi: fix 11ax disabled bit in the regulatory capability flags (Jarod Wilson) [1937053]
- brcmfmac: p2p: Fix recently introduced deadlock issue (Jarod Wilson) [1937053]
- mt76: mt7921: fix airtime reporting (Jarod Wilson) [1937053]
- iwlwifi: Fix softirq/hardirq disabling in iwl_pcie_enqueue_hcmd() (Jarod Wilson) [1937053]
- mt76: mt7615: remove redundant dev_err call in mt7622_wmac_probe() (Jarod Wilson) [1937053]
- mt76: Convert to DEFINE_SHOW_ATTRIBUTE (Jarod Wilson) [1937053]
- reg.c: Fix a spello (Jarod Wilson) [1937053]
- mac80211: cfg.c: A typo fix (Jarod Wilson) [1937053]
- wireless: remove never implemented MODULE_SUPPORTED_DEVICE (Jarod Wilson) [1937053]
- wireless/nl80211: fix wdev_id may be used uninitialized (Jarod Wilson) [1937053]
- nl80211: fix locking for wireless device netns change (Jarod Wilson) [1937053]
- iwlwifi: don't call netif_napi_add() with rxq->lock held (was Re: Lockdep warning in iwl_pcie_rx_handle()) (Jarod Wilson) [1937053]
- iwlwifi: fix ARCH=i386 compilation warnings (Jarod Wilson) [1937053]
- iwlwifi: mvm: add terminate entry for dmi_system_id tables (Jarod Wilson) [1937053]
- mt76: mt7915: fix unused 'mode' variable (Jarod Wilson) [1937053]
- mt76: dma: do not report truncated frames to mac80211 (Jarod Wilson) [1937053]
- mt76: mt7921: remove incorrect error handling (Jarod Wilson) [1937053]
- iwlwifi: pcie: fix iwl_so_trans_cfg link error when CONFIG_IWLMVM is disabled (Jarod Wilson) [1937053]
- ath11k: fix AP mode for QCA6390 (Jarod Wilson) [1937053]
- ath11k: qmi: use pad to format dma_addr_t (Jarod Wilson) [1937053]
- iwlwifi: avoid crash on unsupported debug collection (Jarod Wilson) [1937053]
- mt76: mt7915: only modify tx buffer list after allocating tx token id (Jarod Wilson) [1937053]
- mt76: fix tx skb error handling in mt76_dma_tx_queue_skb (Jarod Wilson) [1937053]
- ath9k: fix transmitting to stations in dynamic SMPS mode (Jarod Wilson) [1937053]
- redhat: Enable ath11k PCI device support (Jarod Wilson) [1937053]
- soc: qcom: Do not depend on ARCH_QCOM for QMI helpers (Jarod Wilson) [1937053]
- net: qrtr: Do not depend on ARCH_QCOM (Jarod Wilson) [1937053]
- b43: N-PHY: Fix the update of coef for the PHY revision >= 3case (Jarod Wilson) [1937053]
- nl80211: add documentation for HT/VHT/HE disable attributes (Jarod Wilson) [1937053]
- cfg80211/mac80211: Support disabling HE mode (Jarod Wilson) [1937053]
- mac80211: add STBC encoding to ieee80211_parse_tx_radiotap (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: remove sample rate switching code for constrained devices (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: show sampling rates in debugfs (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: significantly redesign the rate probing strategy (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: reduce the need to sample slower rates (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: update total packets counter in tx status path (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: use bitfields to encode rate indexes (Jarod Wilson) [1937053]
- cfg80211: initialize reg_rule in __freq_reg_info() (Jarod Wilson) [1937053]
- mac80211: fix potential overflow when multiplying to u32 integers (Jarod Wilson) [1937053]
- mac80211: enable QoS support for nl80211 ctrl port (Jarod Wilson) [1937053]
- cfg80211: remove unused callback (Jarod Wilson) [1937053]
- rtw88: 8822c: update RF_B (2/2) parameter tables to v60 (Jarod Wilson) [1937053]
- rtw88: 8822c: update RF_B (1/2) parameter tables to v60 (Jarod Wilson) [1937053]
- rtw88: 8822c: update RF_A parameter tables to v60 (Jarod Wilson) [1937053]
- rtw88: 8822c: update MAC/BB parameter tables to v60 (Jarod Wilson) [1937053]
- rtw88: replace tx tasklet with work queue (Jarod Wilson) [1937053]
- rtw88: add napi support (Jarod Wilson) [1937053]
- rtw88: add rts condition (Jarod Wilson) [1937053]
- rtw88: add dynamic rrsr configuration (Jarod Wilson) [1937053]
- iwlwifi: remove incorrect comment in pnvm (Jarod Wilson) [1937053]
- ath11k: qmi: add debug message for allocated memory segment addresses and sizes (Jarod Wilson) [1937053]
- ath11k: pci: remove experimental warning (Jarod Wilson) [1937053]
- ath10k: hold RCU lock when calling ieee80211_find_sta_by_ifaddr() (Jarod Wilson) [1937053]
- ath10k: change ath10k_offchan_tx_work() peer present msg to a warn (Jarod Wilson) [1937053]
- ath9k: fix data bus crash when setting nf_override via debugfs (Jarod Wilson) [1937053]
- ath11k: add support to configure spatial reuse parameter set (Jarod Wilson) [1937053]
- ath10k: restore tx sk_buff of htt header for SDIO (Jarod Wilson) [1937053]
- brcmsmac: Fix the spelling configation to configuration in the file d11.h (Jarod Wilson) [1937053]
- iwlwifi: bump FW API to 62 for AX devices (Jarod Wilson) [1937053]
- iwlwifi: pnvm: implement reading PNVM from UEFI (Jarod Wilson) [1937053]
- iwlwifi: pnvm: move file loading code to a separate function (Jarod Wilson) [1937053]
- iwlwifi: pnvm: increment the pointer before checking the TLV (Jarod Wilson) [1937053]
- iwlwifi: pcie: define FW_RESET_TIMEOUT for clarity (Jarod Wilson) [1937053]
- iwlwifi: pnvm: set the PNVM again if it was already loaded (Jarod Wilson) [1937053]
- iwlwifi: mvm: global PM mode does not reset after FW crash (Jarod Wilson) [1937053]
- iwlwifi: mvm: reduce the print severity of failing getting NIC temp (Jarod Wilson) [1937053]
- iwlwifi: mvm: get NVM later in the mvm_start flow (Jarod Wilson) [1937053]
- iwlmvm: set properly NIC_NOT_ACK_ENABLED flag (Jarod Wilson) [1937053]
- iwlwifi: remove max_ht_ampdu_exponent config parameter (Jarod Wilson) [1937053]
- iwlwifi: remove max_vht_ampdu_exponent config parameter (Jarod Wilson) [1937053]
- iwlwifi: mvm: Check ret code for iwl_mvm_load_nvm_to_nic (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't check if CSA event is running before removing (Jarod Wilson) [1937053]
- iwlwifi: mvm: Support SCAN_CFG_CMD version 5 (Jarod Wilson) [1937053]
- iwlwifi: mvm: isolate the get nvm flow (Jarod Wilson) [1937053]
- iwlwifi: mvm: simplify iwl_mvm_dbgfs_register (Jarod Wilson) [1937053]
- iwlwifi: mvm: register to mac80211 last (Jarod Wilson) [1937053]
- iwlwifi: acpi: add support for DSM RFI (Jarod Wilson) [1937053]
- iwlwifi: mvm: add RFI-M support (Jarod Wilson) [1937053]
- iwlwifi:mvm: Add support for version 2 of the LARI_CONFIG_CHANGE command. (Jarod Wilson) [1937053]
- iwlwifi: pcie: don't crash when rx queues aren't allocated in interrupt (Jarod Wilson) [1937053]
- iwlwifi: correction of group-id once sending REPLY_ERROR (Jarod Wilson) [1937053]
- iwlwifi: pcie: add AX201 and AX211 radio modules for Ma devices (Jarod Wilson) [1937053]
- iwlwifi: pcie: add CDB bit to the device configuration parsing (Jarod Wilson) [1937053]
- iwlwifi: acpi: don't return valid pointer as an ERR_PTR (Jarod Wilson) [1937053]
- iwlwifi: queue: add fake tx time point (Jarod Wilson) [1937053]
- iwlwifi: remove flags argument for nic_access (Jarod Wilson) [1937053]
- iwlwifi: declare support for triggered SU/MU beamforming feedback (Jarod Wilson) [1937053]
- iwlwifi: dbg: add op_mode callback for collecting debug data. (Jarod Wilson) [1937053]
- iwlwifi: api: clean up some documentation/bits (Jarod Wilson) [1937053]
- iwlwifi: dbg: remove unsupported regions (Jarod Wilson) [1937053]
- iwlwifi: pcie: Change Ma device ID (Jarod Wilson) [1937053]
- iwlwifi: when HW has rate offload don't look at control field (Jarod Wilson) [1937053]
- iwlwifi: pcie: NULLify pointers after free (Jarod Wilson) [1937053]
- iwlwifi: mvm: assign SAR table revision to the command later (Jarod Wilson) [1937053]
- iwlwifi: mvm: remove useless iwl_mvm_resume_d3() function (Jarod Wilson) [1937053]
- iwlwifi: mvm: enhance a print in CSA flows (Jarod Wilson) [1937053]
- iwlwifi: mvm: send stored PPAG command instead of local (Jarod Wilson) [1937053]
- iwlwifi: mvm: store PPAG enabled/disabled flag properly (Jarod Wilson) [1937053]
- iwlwifi: mvm: fix the type we use in the PPAG table validity checks (Jarod Wilson) [1937053]
- iwlwifi: acpi: fix PPAG table sizes (Jarod Wilson) [1937053]
- iwlwifi: pcie: don't disable interrupts for reg_lock (Jarod Wilson) [1937053]
- iwlwifi: pcie: add a few missing entries for So with Hr (Jarod Wilson) [1937053]
- iwlwifi: dbg: Mark ucode tlv data as const (Jarod Wilson) [1937053]
- iwlwifi: add new cards for So and Qu family (Jarod Wilson) [1937053]
- ath11k: fix a locking bug in ath11k_mac_op_start() (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: phy: Simplify bool comparison (Jarod Wilson) [1937053]
- rtlwifi: rtl8192se: Simplify bool comparison (Jarod Wilson) [1937053]
- brcmfmac: add support for CQM RSSI notifications (Jarod Wilson) [1937053]
- ath10k: Add new debug level for sta related logs (Jarod Wilson) [1937053]
- ath11k: Update tx descriptor search index properly (Jarod Wilson) [1937053]
- ath10k: Fix lockdep assertion warning in ath10k_sta_statistics (Jarod Wilson) [1937053]
- ath10k: Fix suspicious RCU usage warning in ath10k_wmi_tlv_parse_peer_stats_info() (Jarod Wilson) [1937053]
- wl3501: fix alignment constraints (Jarod Wilson) [1937053]
- rt2800usb: add Sweex LW163V2 id's (Jarod Wilson) [1937053]
- rt2x00: remove duplicate word and fix typo in comment (Jarod Wilson) [1937053]
- mwifiex: Report connected BSS with cfg80211_connect_bss() (Jarod Wilson) [1937053]
- rtl8xxxu: remove unused assignment value (Jarod Wilson) [1937053]
- atmel: at76c50x: use DEFINE_MUTEX() for mutex lock (Jarod Wilson) [1937053]
- brcmsmac: fix alignment constraints (Jarod Wilson) [1937053]
- brcmfmac: Add DMI nvram filename quirk for Voyo winpad A15 tablet (Jarod Wilson) [1937053]
- brcmfmac: Add DMI nvram filename quirk for Predia Basic tablet (Jarod Wilson) [1937053]
- rtw88: 8821c: support RFE type2 wifi NIC (Jarod Wilson) [1937053]
- rtw88: 8821c: Correct CCK RSSI (Jarod Wilson) [1937053]
- rtw88: coex: 8821c: correct antenna switch function (Jarod Wilson) [1937053]
- rtlwifi: rtl8192se: remove redundant initialization of variable rtstatus (Jarod Wilson) [1937053]
- iwlwifi: pcie: Disable softirqs during Rx queue init (Jarod Wilson) [1937053]
- iwlwifi: bump FW API to 61 for AX devices (Jarod Wilson) [1937053]
- iwlwifi: mvm: add Asus to the PPAG approved list (Jarod Wilson) [1937053]
- iwlwifi: mvm: add Microsoft to the PPAG approved list (Jarod Wilson) [1937053]
- iwlwifi: mvm: add Samsung to the PPAG approved list (Jarod Wilson) [1937053]
- iwlwifi: mvm: add HP to the PPAG approved list (Jarod Wilson) [1937053]
- iwlwifi: mvm: implement approved list for the PPAG feature (Jarod Wilson) [1937053]
- iwlwifi: mvm: set enabled in the PPAG command properly (Jarod Wilson) [1937053]
- iwlwifi: mvm: add debugfs entry to trigger a dump as any time-point (Jarod Wilson) [1937053]
- iwlwifi: mvm: add tx fail time point (Jarod Wilson) [1937053]
- iwlwifi: fwrt: add suspend/resume time point (Jarod Wilson) [1937053]
- iwlwifi: mvm: add triggers for MLME events (Jarod Wilson) [1937053]
- iwlwifi: mvm: add IML/ROM information for other HW families (Jarod Wilson) [1937053]
- iwlwifi: mvm: fix CSA AP side (Jarod Wilson) [1937053]
- iwlwifi: mvm: make iwl_mvm_tt_temp_changed() static (Jarod Wilson) [1937053]
- iwlwifi: mvm: cancel the scan delayed work when scan is aborted (Jarod Wilson) [1937053]
- iwlwifi: pcie: add support for SnJ with Hr1 (Jarod Wilson) [1937053]
- iwlwifi: mvm: move early time-point before nvm_init in non-unified (Jarod Wilson) [1937053]
- iwlwifi: add support for SnJ with Jf devices (Jarod Wilson) [1937053]
- iwlwifi: move SnJ and So rules to the new tables (Jarod Wilson) [1937053]
- iwlwifi: mvm: slightly clean up rs_fw_set_supp_rates() (Jarod Wilson) [1937053]
- iwlwifi: fw api: make hdr a zero-size array again (Jarod Wilson) [1937053]
- iwlwifi: bump FW API to 60 for AX devices (Jarod Wilson) [1937053]
- iwlwifi: mvm: advertise BIGTK client support if available (Jarod Wilson) [1937053]
- iwlwifi: always allow maximum A-MSDU on newer devices (Jarod Wilson) [1937053]
- iwlwifi: mvm: debugfs: check length precisely in inject_packet (Jarod Wilson) [1937053]
- iwlwifi: mvm: simplify TX power setting (Jarod Wilson) [1937053]
- iwlwifi: tx: move handing sync/async host command to trans (Jarod Wilson) [1937053]
- iwlwifi: mvm: add explicit check for non-data frames in get Tx rate (Jarod Wilson) [1937053]
- iwlwifi: mvm: debugfs for phy-integration-ver (Jarod Wilson) [1937053]
- iwlwifi: parse phy integration string from FW TLV (Jarod Wilson) [1937053]
- iwlwifi: mvm: csa: do not abort CSA before disconnect (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't send commands during suspend\resume transition (Jarod Wilson) [1937053]
- iwlwifi: mvm: don't check system_pm_mode without mutex held (Jarod Wilson) [1937053]
- iwlwifi: remove TRANS_PM_OPS (Jarod Wilson) [1937053]
- iwlwifi: dbg: dump paged memory from index 1 (Jarod Wilson) [1937053]
- iwl-trans: iwlwifi: move sync NMI logic to trans (Jarod Wilson) [1937053]
- iwlwifi: pcie: properly implement NAPI (Jarod Wilson) [1937053]
- iwlwifi: mvm: add support for new flush queue response (Jarod Wilson) [1937053]
- iwlwifi: mvm: handle CCA-EXT delay firmware notification (Jarod Wilson) [1937053]
- iwlwifi: mvm: scan: fix scheduled scan restart handling (Jarod Wilson) [1937053]
- iwlwifi: mvm: remove debugfs injection limitations (Jarod Wilson) [1937053]
- iwlwifi: mvm: check more notification sizes (Jarod Wilson) [1937053]
- iwlwifi: mvm: add notification size checks (Jarod Wilson) [1937053]
- ath11k: remove h from printk format specifier (Jarod Wilson) [1937053]
- ath10k: remove h from printk format specifier (Jarod Wilson) [1937053]
- cfg80211: fix netdev registration deadlock (Jarod Wilson) [1937053]
- mac80211: fix station rate table updates on assoc (Jarod Wilson) [1937053]
- mt76: mt7663: introduce coredump support (Jarod Wilson) [1937053]
- mt76: mt7921: add coredump support (Jarod Wilson) [1937053]
- mt76: mt7921: enable MSI interrupts (Jarod Wilson) [1937053]
- mt76: mt7921: introduce regdomain notifier support (Jarod Wilson) [1937053]
- mt76: mt7921: introduce Runtime PM support (Jarod Wilson) [1937053]
- mt76: mt7921: rely on mt76_connac_mcu module for suspend and WoW support (Jarod Wilson) [1937053]
- mt76: mt7921: rely on mt76_connac_mcu module for sched_scan and hw_scan (Jarod Wilson) [1937053]
- mt76: mt7921: rely on mt76_connac_mcu common library (Jarod Wilson) [1937053]
- mt76: mt7921: introduce PM support (Jarod Wilson) [1937053]
- mt76: mt7921: introduce beacon_loss mcu event (Jarod Wilson) [1937053]
- mt76: mt7921: introduce support for hardware beacon filter (Jarod Wilson) [1937053]
- mt76: mt7921: introduce 802.11 PS support in sta mode (Jarod Wilson) [1937053]
- mt76: mt7921: introduce schedule scan support (Jarod Wilson) [1937053]
- mt76: mt7921: add debugfs support (Jarod Wilson) [1937053]
- mt76: mt7921: introduce mt7921e support (Jarod Wilson) [1937053]
- mt76: mt7921: add ieee80211_ops (Jarod Wilson) [1937053]
- mt76: mt7921: add EEPROM support (Jarod Wilson) [1937053]
- mt76: mt7921: add DMA support (Jarod Wilson) [1937053]
- mt76: mt7921: add MCU support (Jarod Wilson) [1937053]
- mt76: mt7921: add MAC support (Jarod Wilson) [1937053]
- wireless: Fix "ordering" comment typos (Jarod Wilson) [1937053]
- mt76: mt76_connac: move pm utility routines in mt76_connac_lib module (Jarod Wilson) [1937053]
- mt76: mt76_connac: move pm data struct in mt76_connac.h (Jarod Wilson) [1937053]
- mt76: mt76_connac: move WoW and suspend code in mt76_connac_mcu module (Jarod Wilson) [1937053]
- mt76: mt76_connac: move hw_scan and sched_scan routine in mt76_connac_mcu module (Jarod Wilson) [1937053]
- mt76: mt76_connac: create mcu library (Jarod Wilson) [1937053]
- mt76: introduce mt76_vif data structure (Jarod Wilson) [1937053]
- cfg80211: call cfg80211_destroy_ifaces() with wiphy lock held (Jarod Wilson) [1937053]
- wext: call cfg80211_set_encryption() with wiphy lock held (Jarod Wilson) [1937053]
- wext: call cfg80211_change_iface() with wiphy lock held (Jarod Wilson) [1937053]
- nl80211: call cfg80211_dev_rename() under RTNL (Jarod Wilson) [1937053]
- mt76: dma: fix a possible memory leak in mt76_add_fragment() (Jarod Wilson) [1937053]
- ath9k: fix build error with LEDS_CLASS=m (Jarod Wilson) [1937053]
- ath10k: fix wmi mgmt tx queue full due to race condition (Jarod Wilson) [1937053]
- ath10k: pass the ssid info to get the correct bss entity (Jarod Wilson) [1937053]
- ath10k: allow dynamic SAR power limits via common API (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: fix regression in the max_prob_rate fix (Jarod Wilson) [1937053]
- mt76: mt7615: reduce VHT maximum MPDU length (Jarod Wilson) [1937053]
- mt76: reduce q->lock hold time (Jarod Wilson) [1937053]
- mt76: usb: process URBs with status EPROTO properly (Jarod Wilson) [1937053]
- mt76: move vif_mask back from mt76_phy to mt76_dev (Jarod Wilson) [1937053]
- mt76: mt7915: make vif index per adapter instead of per band (Jarod Wilson) [1937053]
- mt76: mt7915: add support for using a secondary PCIe link for gen1 (Jarod Wilson) [1937053]
- mt76: fix crash on tearing down ext phy (Jarod Wilson) [1937053]
- mt76: mt7915: bring up the WA event rx queue for band1 (Jarod Wilson) [1937053]
- mt76: mt7615: unify init work (Jarod Wilson) [1937053]
- mt76: mt7915: support TxBF for DBDC (Jarod Wilson) [1937053]
- mt76: mt7915: Remove unneeded semicolon (Jarod Wilson) [1937053]
- mt76: mt7615: set mcu country code in mt7615_mcu_set_channel_domain() (Jarod Wilson) [1937053]
- mt76: mt7915: fix eeprom DBDC band selection (Jarod Wilson) [1937053]
- mt76: mt7915: fix eeprom parsing for DBDC (Jarod Wilson) [1937053]
- iwlwifi: provide gso_type to GSO packets (Jarod Wilson) [1937053]
- mt76: mt7915: disable RED support in the WA firmware (Jarod Wilson) [1937053]
- mt76: mt7915: rework mcu API (Jarod Wilson) [1937053]
- mt76: mt7915: do not set DRR group for stations (Jarod Wilson) [1937053]
- mt76: mt7915: ensure that init work completes before starting the device (Jarod Wilson) [1937053]
- mt76: mt7603: fix ED/CCA monitoring with single-stream devices (Jarod Wilson) [1937053]
- mt76: mt7915: add implicit Tx beamforming support (Jarod Wilson) [1937053]
- mt76: mt7915: simplify peer's TxBF capability check (Jarod Wilson) [1937053]
- mt76: mt7615: mt7915: disable txpower sku when testmode enabled (Jarod Wilson) [1937053]
- mt76: mt7915: add support for continuous tx in testmode (Jarod Wilson) [1937053]
- mt76: mt7915: rework set state part in testmode (Jarod Wilson) [1937053]
- mt76: testmode: add a new state for continuous tx (Jarod Wilson) [1937053]
- mt76: mt7915: clean hw queue before starting new testmode tx (Jarod Wilson) [1937053]
- mt76: mt7915: calculate new packet length when tx_time is set in testmode (Jarod Wilson) [1937053]
- mt76: mt7915: add support for ipg in testmode (Jarod Wilson) [1937053]
- mt76: mt7915: split edca update function (Jarod Wilson) [1937053]
- mt76: testmode: make tx queued limit adjustable (Jarod Wilson) [1937053]
- mt76: testmode: add attributes for ipg related parameters (Jarod Wilson) [1937053]
- mt76: testmode: add support to set user-defined spe index (Jarod Wilson) [1937053]
- mt76: mt7915: force ldpc for bw larger than 20MHz in testmode (Jarod Wilson) [1937053]
- mt76: move chainmask in mt76_phy (Jarod Wilson) [1937053]
- mt76: move mac_work in mt76_core module (Jarod Wilson) [1937053]
- mt76: mt7615: move testmode data from dev to phy (Jarod Wilson) [1937053]
- mt76: mt7915: move testmode data from dev to phy (Jarod Wilson) [1937053]
- mt76: testmode: move mtd part to mt76_dev (Jarod Wilson) [1937053]
- mt76: testmode: introduce dbdc support (Jarod Wilson) [1937053]
- mt76: mt7915: add partial add_bss_info command on testmode init (Jarod Wilson) [1937053]
- mt76: mt7915: drop zero-length packet to avoid Tx hang (Jarod Wilson) [1937053]
- mt76: mt7915: simplify mt7915_mcu_send_message routine (Jarod Wilson) [1937053]
- mt76: mt7915: fix endianness warning in mt7915_mcu_set_radar_th (Jarod Wilson) [1937053]
- mt76: mt7915: add support for flash mode (Jarod Wilson) [1937053]
- mt76: mt7915: run mt7915_configure_filter holding mt76 mutex (Jarod Wilson) [1937053]
- mt76: mt7915: convert comma to semicolon (Jarod Wilson) [1937053]
- mt76: mt7615: convert comma to semicolon (Jarod Wilson) [1937053]
- mt76: mt7615: reset token when mac_reset happens (Jarod Wilson) [1937053]
- mt76: mt7915: reset token when mac_reset happens (Jarod Wilson) [1937053]
- mt76: mt7915: fix MT_CIPHER_BIP_CMAC_128 setkey (Jarod Wilson) [1937053]
- mt76: mt7615: add vif check in mt7615_update_vif_beacon() (Jarod Wilson) [1937053]
- mt76: mt7915: add vif check in mt7915_update_vif_beacon() (Jarod Wilson) [1937053]
- ath11k: add ieee80211_unregister_hw to avoid kernel crash caused by NULL pointer (Jarod Wilson) [1937053]
- mac80211: pause TX while changing interface type (Jarod Wilson) [1937053]
- wext: fix NULL-ptr-dereference with cfg80211's lack of commit() (Jarod Wilson) [1937053]
- cfg80211: avoid holding the RTNL when calling the driver (Jarod Wilson) [1937053]
- iwl4965: do not process non-QOS frames on txq->sched_retry path (Jarod Wilson) [1937053]
- mt7601u: process tx URBs with status EPROTO properly (Jarod Wilson) [1937053]
- mt7601u: use ieee80211_rx_list to pass frames to the network stack as a batch (Jarod Wilson) [1937053]
- rtw88: 8723de: adjust the LTR setting (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: fix bool comparison in expressions (Jarod Wilson) [1937053]
- rtlwifi: rtl8192se: fix bool comparison in expressions (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: fix bool comparison in expressions (Jarod Wilson) [1937053]
- rtlwifi: rtl8192c-common: fix bool comparison in expressions (Jarod Wilson) [1937053]
- rtlwifi: rtl_pci: fix bool comparison in expressions (Jarod Wilson) [1937053]
- mt7601u: fix kernel crash unplugging the device (Jarod Wilson) [1937053]
- iwlwifi: queue: bail out on invalid freeing (Jarod Wilson) [1937053]
- iwlwifi: mvm: guard against device removal in reprobe (Jarod Wilson) [1937053]
- iwlwifi: Fix IWL_SUBDEVICE_NO_160 macro to use the correct bit. (Jarod Wilson) [1937053]
- iwlwifi: mvm: clear IN_D3 after wowlan status cmd (Jarod Wilson) [1937053]
- iwlwifi: pcie: add rules to match Qu with Hr2 (Jarod Wilson) [1937053]
- iwlwifi: mvm: invalidate IDs of internal stations at mvm start (Jarod Wilson) [1937053]
- iwlwifi: mvm: fix the return type for DSM functions 1 and 2 (Jarod Wilson) [1937053]
- iwlwifi: pcie: reschedule in long-running memory reads (Jarod Wilson) [1937053]
- iwlwifi: pcie: use jiffies for memory read spin time limit (Jarod Wilson) [1937053]
- iwlwifi: pcie: fix context info memory leak (Jarod Wilson) [1937053]
- iwlwifi: pcie: add a NULL check in iwl_pcie_txq_unmap (Jarod Wilson) [1937053]
- iwlwifi: pcie: set LTR on more devices (Jarod Wilson) [1937053]
- iwlwifi: queue: don't crash if txq->entries is NULL (Jarod Wilson) [1937053]
- iwlwifi: fix the NMI flow for old devices (Jarod Wilson) [1937053]
- iwlwifi: pnvm: don't try to load after failures (Jarod Wilson) [1937053]
- iwlwifi: pnvm: don't skip everything when not reloading (Jarod Wilson) [1937053]
- iwlwifi: pcie: avoid potential PNVM leaks (Jarod Wilson) [1937053]
- iwlwifi: mvm: take mutex for calling iwl_mvm_get_sync_time() (Jarod Wilson) [1937053]
- iwlwifi: mvm: skip power command when unbinding vif during CSA (Jarod Wilson) [1937053]
- cfg80211: change netdev registration/unregistration semantics (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: fix rounding error in throughput calculation (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: increase stats update interval (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: fix max probability rate selection (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: improve sample rate selection (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: improve ampdu length estimation (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: remove old ewma based rate average code (Jarod Wilson) [1937053]
- mac80211: remove legacy minstrel rate control (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: add support for OFDM rates on non-HT clients (Jarod Wilson) [1937053]
- mac80211: minstrel_ht: clean up CCK code (Jarod Wilson) [1937053]
- mac80211: introduce aql_enable node in debugfs (Jarod Wilson) [1937053]
- cfg80211: Add phyrate conversion support for extended MCS in 60GHz band (Jarod Wilson) [1937053]
- cfg80211: add VHT rate entries for MCS-10 and MCS-11 (Jarod Wilson) [1937053]
- mac80211: reduce peer HE MCS/NSS to own capabilities (Jarod Wilson) [1937053]
- mac80211: remove NSS number of 160MHz if not support 160MHz for HE (Jarod Wilson) [1937053]
- mac80211: 160MHz with extended NSS BW in CSA (Jarod Wilson) [1937053]
- mac80211: add LDPC encoding to ieee80211_parse_tx_radiotap (Jarod Wilson) [1937053]
- mac80211: add rx decapsulation offload support (Jarod Wilson) [1937053]
- ath10k: remove unused struct ath10k::dev_type (Jarod Wilson) [1937053]
- ath11k: remove duplicate function declaration (Jarod Wilson) [1937053]
- ath10k: increase rx buffer size to 2048 (Jarod Wilson) [1937053]
- ath10k: sanitity check for ep connectivity (Jarod Wilson) [1937053]
- mt76: mt7663s: fix rx buffer refcounting (Jarod Wilson) [1937053]
- mt7601u: fix rx buffer refcounting (Jarod Wilson) [1937053]
- mac80211: check if atf has been disabled in __ieee80211_schedule_txq (Jarod Wilson) [1937053]
- mac80211: do not drop tx nulldata packets on encrypted links (Jarod Wilson) [1937053]
- mac80211: fix encryption key selection for 802.3 xmit (Jarod Wilson) [1937053]
- mac80211: fix fast-rx encryption check (Jarod Wilson) [1937053]
- mac80211: fix incorrect strlen of .write in debugfs (Jarod Wilson) [1937053]
- cfg80211: fix a kerneldoc markup (Jarod Wilson) [1937053]
- brcmfmac: clear EAP/association status bits on linkdown events (Jarod Wilson) [1937053]
- brcmfmac: Delete useless kfree code (Jarod Wilson) [1937053]
- mt7601u: check the status of device in calibration (Jarod Wilson) [1937053]
- mt7601u: process URBs in status EPROTO properly (Jarod Wilson) [1937053]
- brcmfmac: support BCM4365E with 43666 ChipCommon chip ID (Jarod Wilson) [1937053]
- mwifiex: pcie: Drop bogus __refdata annotation (Jarod Wilson) [1937053]
- rtw88: Simplify bool comparison (Jarod Wilson) [1937053]
- rtw88: coex: set 4 slot TDMA for BT link and WL busy (Jarod Wilson) [1937053]
- rtw88: 8821c: apply CCK PD level which calculates from dynamic mechanism (Jarod Wilson) [1937053]
- rtw88: reduce the log level for failure of tx report (Jarod Wilson) [1937053]
- rtw88: Delete useless kfree code (Jarod Wilson) [1937053]
- iwlwifi: dbg: Don't touch the tlv data (Jarod Wilson) [1937053]
- mt76: Fix queue ID variable types after mcu queue split (Jarod Wilson) [1937053]
- cfg80211: Save the regulatory domain with a lock (Jarod Wilson) [1937053]
- cfg80211/mac80211: fix kernel-doc for SAR APIs (Jarod Wilson) [1937053]
- mt76: mt7915: fix MESH ifdef block (Jarod Wilson) [1937053]
- mt76: mt76s: fix NULL pointer dereference in mt76s_process_tx_queue (Jarod Wilson) [1937053]
- mt76: sdio: remove wake logic in mt76s_process_tx_queue (Jarod Wilson) [1937053]
- mt76: usb: remove wake logic in mt76u_status_worker (Jarod Wilson) [1937053]
- ath11k: dp: clean up a variable name (Jarod Wilson) [1937053]
- ath11k: pci: remove unnecessary mask in ath11k_pci_enable_ltssm() (Jarod Wilson) [1937053]
- ath11k: pci: disable ASPM L0sLs before downloading firmware (Jarod Wilson) [1937053]
- ath11k: qmi: try to allocate a big block of DMA memory first (Jarod Wilson) [1937053]
- rtlwifi: rise completion at the last step of firmware callback (Jarod Wilson) [1937053]
- mt76: mt76u: fix NULL pointer dereference in mt76u_status_worker (Jarod Wilson) [1937053]
- ath10k: prevent deinitializing NAPI twice (Jarod Wilson) [1937053]
- ath9k: Postpone key cache entry deletion for TXQ frames reference it (Jarod Wilson) [1937053]
- ath: Modify ath_key_delete() to not need full key entry (Jarod Wilson) [1937053]
- ath: Export ath_hw_keysetmac() (Jarod Wilson) [1937053]
- ath9k: Clear key cache explicitly on disabling hardware (Jarod Wilson) [1937053]
- ath: Use safer key clearing with key cache entries (Jarod Wilson) [1937053]
- ath10k: Remove voltage regulator votes during wifi disable (Jarod Wilson) [1937053]
- ath10k: Fix error handling in case of CE pipe init failure (Jarod Wilson) [1937053]
- ath11k: Fix ath11k_pci_fix_l1ss() (Jarod Wilson) [1937053]
- ath11k: Fix error code in ath11k_core_suspend() (Jarod Wilson) [1937053]
- ath11k: start vdev if a bss peer is already created (Jarod Wilson) [1937053]
- ath11k: fix crash caused by NULL rx_channel (Jarod Wilson) [1937053]
- ath11k: add missing null check on allocated skb (Jarod Wilson) [1937053]
- ath9k: make relay callbacks const (Jarod Wilson) [1937053]
- ath11k: make relay callbacks const (Jarod Wilson) [1937053]
- ath10k: make relay callbacks const (Jarod Wilson) [1937053]
- ath11k: implement suspend for QCA6390 PCI devices (Jarod Wilson) [1937053]
- ath11k: hif: add ce irq enable and disable functions (Jarod Wilson) [1937053]
- ath11k: implement WoW enable and wakeup commands (Jarod Wilson) [1937053]
- ath11k: set credit_update flag for flow controlled ep only (Jarod Wilson) [1937053]
- ath11k: dp: stop rx pktlog before suspend (Jarod Wilson) [1937053]
- ath11k: htc: implement suspend handling (Jarod Wilson) [1937053]
- ath11k: htc: remove unused struct ath11k_htc_ops (Jarod Wilson) [1937053]
- ath11k: pci: read select_window register to ensure write is finished (Jarod Wilson) [1937053]
- ath11k: hif: implement suspend and resume functions (Jarod Wilson) [1937053]
- ath11k: mhi: hook suspend and resume (Jarod Wilson) [1937053]
- ath11k: Fix incorrect tlvs in scan start command (Jarod Wilson) [1937053]
- ath11k: pci: disable VDD4BLOW (Jarod Wilson) [1937053]
- ath11k: pci: fix L1ss clock unstable problem (Jarod Wilson) [1937053]
- ath11k: pci: fix hot reset stability issues (Jarod Wilson) [1937053]
- ath11k: put hw to DBS using WMI_PDEV_SET_HW_MODE_CMDID (Jarod Wilson) [1937053]
- ath11k: mhi: print a warning if firmware crashed (Jarod Wilson) [1937053]
- ath11k: use MHI provided APIs to allocate and free MHI controller (Jarod Wilson) [1937053]
- ath10k: add atomic protection for device recovery (Jarod Wilson) [1937053]
- ath10k: add option for chip-id based BDF selection (Jarod Wilson) [1937053]
- mt76: remove unused variable q (Jarod Wilson) [1937053]
- mac80211: add ieee80211_set_sar_specs (Jarod Wilson) [1937053]
- nl80211: add common API to configure SAR power limitations (Jarod Wilson) [1937053]
- mac80211: fix a mistake check for rx_stats update (Jarod Wilson) [1937053]
- mac80211: mlme: save ssid info to ieee80211_bss_conf while assoc (Jarod Wilson) [1937053]
- mac80211: Update rate control on channel change (Jarod Wilson) [1937053]
- mac80211: don't filter out beacons once we start CSA (Jarod Wilson) [1937053]
- mac80211: Fix calculation of minimal channel width (Jarod Wilson) [1937053]
- mac80211: ignore country element TX power on 6 GHz (Jarod Wilson) [1937053]
- mac80211: use bitfield helpers for BA session action frames (Jarod Wilson) [1937053]
- mac80211: support Rx timestamp calculation for all preamble types (Jarod Wilson) [1937053]
- mac80211: don't set set TDLS STA bandwidth wider than possible (Jarod Wilson) [1937053]
- mac80211: support driver-based disconnect with reconnect hint (Jarod Wilson) [1937053]
- cfg80211: support immediate reconnect request hint (Jarod Wilson) [1937053]
- mac80211: use struct assignment for he_obss_pd (Jarod Wilson) [1937053]
- cfg80211: remove struct ieee80211_he_bss_color (Jarod Wilson) [1937053]
- nl80211: validate key indexes for cfg80211_registered_device (Jarod Wilson) [1937053]
- cfg80211: include block-tx flag in channel switch started event (Jarod Wilson) [1937053]
- mac80211: disallow band-switch during CSA (Jarod Wilson) [1937053]
- ieee80211: update reduced neighbor report TBTT info length (Jarod Wilson) [1937053]
- cfg80211: Save the regulatory domain when setting custom regulatory (Jarod Wilson) [1937053]
- nl80211: always accept scan request with the duration set (Jarod Wilson) [1937053]
- cfg80211: Update TSF and TSF BSSID for multi BSS (Jarod Wilson) [1937053]
- cfg80211: scan PSC channels in case of scan with wildcard SSID (Jarod Wilson) [1937053]
- mac80211: Skip entries with SAE H2E only membership selector (Jarod Wilson) [1937053]
- cfg80211: Parse SAE H2E only membership selector (Jarod Wilson) [1937053]
- mac80211: support MIC error/replay detected counters driver update (Jarod Wilson) [1937053]
- mac80211: he: remove non-bss-conf fields from bss_conf (Jarod Wilson) [1937053]
- mac80211: remove trailing semicolon in macro definitions (Jarod Wilson) [1937053]
- nl80211: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- mac80211: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- cfg80211: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- cfg80211: fix callback type mismatches in wext-compat (Jarod Wilson) [1937053]
- net: wireless: make a const array static, makes object smaller (Jarod Wilson) [1937053]
- net: mac80211: use core API for updating TX/RX stats (Jarod Wilson) [1937053]
- rfkill: add a reason to the HW rfkill state (Jarod Wilson) [1937053]
- rtlwifi: rtl8192de: fix ofdm power compensation (Jarod Wilson) [1937053]
- ath9k_htc: adhere to the DONT_REORDER transmit flag (Jarod Wilson) [1937053]
- ath11k: mesh: add support for 256 bitmap in blockack frames in 11ax (Jarod Wilson) [1937053]
- ath11k: support TXOP duration based RTS threshold (Jarod Wilson) [1937053]
- ath11k: fix incorrect wmi param for configuring HE operation (Jarod Wilson) [1937053]
- ath11k: unlock on error path in ath11k_mac_op_add_interface() (Jarod Wilson) [1937053]
- ath11k: fix rmmod failure if qmi sequence fails (Jarod Wilson) [1937053]
- rtw88: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- rt2x00: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- ath11k: pci: add MODULE_FIRMWARE macros (Jarod Wilson) [1937053]
- rtw88: reduce polling time of IQ calibration (Jarod Wilson) [1937053]
- rtw88: fix multiple definition of rtw_pm_ops (Jarod Wilson) [1937053]
- brcmfmac: remove redundant assignment to pointer 'entry' (Jarod Wilson) [1937053]
- rtw88: declare hw supports ch 144 (Jarod Wilson) [1937053]
- rtw88: coex: fix missing unitialization of variable 'interval' (Jarod Wilson) [1937053]
- mwifiex: change license text of Makefile and README from MARVELL to NXP (Jarod Wilson) [1937053]
- rtw88: pci: Add prototypes for .probe, .remove and .shutdown (Jarod Wilson) [1937053]
- ath9k: remove trailing semicolon in macro definition (Jarod Wilson) [1937053]
- ath11k: Ignore resetting peer auth flag in peer assoc cmd (Jarod Wilson) [1937053]
- ath11k: add 64bit check before reading msi high addr (Jarod Wilson) [1937053]
- ath10k: fix a check patch warning returnNonBoolInBooleanFunction of sdio.c (Jarod Wilson) [1937053]
- mac80211: mesh: fix mesh_pathtbl_init() error path (Jarod Wilson) [1937053]
- mt76: mt7615: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- mt76: mt7915: fix ht mcs in mt7915_mcu_get_rx_rate() (Jarod Wilson) [1937053]
- mt76: attempt to free up more room when filling the tx queue (Jarod Wilson) [1937053]
- mt76: mt7915: stop queues when running out of tx tokens (Jarod Wilson) [1937053]
- mt76: improve tx queue stop/wake (Jarod Wilson) [1937053]
- mt76: mt7915: fix memory leak in mt7915_mcu_get_rx_rate() (Jarod Wilson) [1937053]
- mt76: mt7615: fix rdd mcu cmd endianness (Jarod Wilson) [1937053]
- mt76: mt7915: fix endian issues (Jarod Wilson) [1937053]
- mt76: mt7915: get rid of dbdc debugfs knob (Jarod Wilson) [1937053]
- mt76: mt7915: introduce dbdc support (Jarod Wilson) [1937053]
- mt76: move hw mac_addr in mt76_phy (Jarod Wilson) [1937053]
- mt76: move band allocation in mt76_register_phy (Jarod Wilson) [1937053]
- mt76: rely on mt76_phy in mt76_init_sband_2g and mt76_init_sband_5g (Jarod Wilson) [1937053]
- mt76: move band capabilities in mt76_phy (Jarod Wilson) [1937053]
- mt76: move tx hw data queues in mt76_phy (Jarod Wilson) [1937053]
- mt76: move mcu queues to mt76_dev q_mcu array (Jarod Wilson) [1937053]
- mt76: rely on mt76_queue in tx_queue_skb_raw signature (Jarod Wilson) [1937053]
- mt76: introduce mt76_init_mcu_queue utility routine (Jarod Wilson) [1937053]
- mt76: rely on mt76_queue in tx_queue_skb signature (Jarod Wilson) [1937053]
- mt76: dma: rely on mt76_queue in mt76_dma_tx_cleanup signature (Jarod Wilson) [1937053]
- mt76: mt7663s: rely on mt76_queue in mt7663s_tx_run_queue signature (Jarod Wilson) [1937053]
- mt76: sdio: rely on mt76_queue in mt76s_process_tx_queue signature (Jarod Wilson) [1937053]
- mt76: sdio: introduce mt76s_alloc_tx_queue (Jarod Wilson) [1937053]
- mt76: move mt76_init_tx_queue in common code (Jarod Wilson) [1937053]
- mt76: mt7915: rely on eeprom definitions (Jarod Wilson) [1937053]
- mt76: mt7615: refactor usb/sdio rate code (Jarod Wilson) [1937053]
- mt76: mt7615: support 16 interfaces (Jarod Wilson) [1937053]
- mt76: mt7915: remove unused mt7915_mcu_bss_sync_tlv() (Jarod Wilson) [1937053]
- mt76: mt7915: use BIT_ULL for omac_idx (Jarod Wilson) [1937053]
- mt76: mt7915: make mt7915_eeprom_read static (Jarod Wilson) [1937053]
- mt76: mt7915: add support to set tx frequency offset in testmode (Jarod Wilson) [1937053]
- mt76: mt7915: add support to set txpower in testmode (Jarod Wilson) [1937053]
- mt76: mt7915: implement testmode rx support (Jarod Wilson) [1937053]
- mt76: mt7915: implement testmode tx support (Jarod Wilson) [1937053]
- mt76: testmode: add support for HE rate modes (Jarod Wilson) [1937053]
- mt76: mt7915: fix tx rate related fields in tx descriptor (Jarod Wilson) [1937053]
- mt76: testmode: add support for LTF and GI combinations for HE mode (Jarod Wilson) [1937053]
- mt76: testmode: add tx_rate_stbc parameter (Jarod Wilson) [1937053]
- mt76: testmode: add snr attribute in rx statistics (Jarod Wilson) [1937053]
- mt76: testmode: switch ib and wb rssi to array type for per-antenna report (Jarod Wilson) [1937053]
- mt76: mt76u: use dedicated thread for status work (Jarod Wilson) [1937053]
- mt76: mt76u: rely on woker APIs for rx work (Jarod Wilson) [1937053]
- mt76: mt7615: run key configuration in mt7615_set_key for usb/sdio devices (Jarod Wilson) [1937053]
- mt76: fix tkip configuration for mt7615/7663 devices (Jarod Wilson) [1937053]
- mt76: switch to wep sw crypto for mt7615/mt7915 (Jarod Wilson) [1937053]
- mt76: mt7663s: introduce WoW support via GPIO (Jarod Wilson) [1937053]
- mt76: move mt76_mcu_send_firmware in common module (Jarod Wilson) [1937053]
- mt76: mt7603: add additional EEPROM chip ID (Jarod Wilson) [1937053]
- mt76: fix memory leak if device probing fails (Jarod Wilson) [1937053]
- mt76: mt7915: fix sparse warning cast from restricted __le16 (Jarod Wilson) [1937053]
- mt76: dma: fix possible deadlock running mt76_dma_cleanup (Jarod Wilson) [1937053]
- mt76: set fops_tx_stats.owner to THIS_MODULE (Jarod Wilson) [1937053]
- mt76: mt7915: rename mt7915_mcu_get_rate_info to mt7915_mcu_get_tx_rate (Jarod Wilson) [1937053]
- mt76: mt7915: update ppe threshold (Jarod Wilson) [1937053]
- mt76: mt7915: set fops_sta_stats.owner to THIS_MODULE (Jarod Wilson) [1937053]
- mt76: sdio: get rid of sched.lock (Jarod Wilson) [1937053]
- mt76: mt7663s: fix a possible ple quota underflow (Jarod Wilson) [1937053]
- mt76: mt7663s: get rid of mt7663s_sta_add (Jarod Wilson) [1937053]
- mt76: mt7615: introduce quota debugfs node for mt7663s (Jarod Wilson) [1937053]
- mt76: mt7615: enable beacon filtering by default for offload fw (Jarod Wilson) [1937053]
- mt76: add back the SUPPORTS_REORDERING_BUFFER flag (Jarod Wilson) [1937053]
- mt76: mt7915: query station rx rate from firmware (Jarod Wilson) [1937053]
- mt76: mt7915: move eeprom parsing out of mt7915_mcu_parse_response (Jarod Wilson) [1937053]
- mt76: implement functions to get the response skb for MCU calls (Jarod Wilson) [1937053]
- mt76: mt7603: switch to .mcu_skb_send_msg (Jarod Wilson) [1937053]
- mt76: make mcu_ops->mcu_send_msg optional (Jarod Wilson) [1937053]
- mt76: move waiting and locking out of mcu_ops->mcu_skb_send_msg (Jarod Wilson) [1937053]
- mt76: move mcu timeout handling to .mcu_parse_response (Jarod Wilson) [1937053]
- mt76: implement .mcu_parse_response in struct mt76_mcu_ops (Jarod Wilson) [1937053]
- mt76: rename __mt76_mcu_skb_send_msg to mt76_mcu_skb_send_msg (Jarod Wilson) [1937053]
- mt76: rename __mt76_mcu_send_msg to mt76_mcu_send_msg (Jarod Wilson) [1937053]
- mt76: mt7915: disable OFDMA/MU-MIMO UL (Jarod Wilson) [1937053]
- mt76: mt7915: fix DRR sta bss group index (Jarod Wilson) [1937053]
- mt76: mt7915: use napi_consume_skb to bulk-free tx skbs (Jarod Wilson) [1937053]
- mt76: mt7915: fix processing txfree events (Jarod Wilson) [1937053]
- mt76: mt7915: support 32 station interfaces (Jarod Wilson) [1937053]
- mt76: do not set NEEDS_UNIQUE_STA_ADDR for 7615 and 7915 (Jarod Wilson) [1937053]
- mt76: mt7615: add debugfs knob for setting extended local mac addresses (Jarod Wilson) [1937053]
- mt76: use ieee80211_rx_list to pass frames to the network stack as a batch (Jarod Wilson) [1937053]
- mt76: mt7915: add encap offload for 4-address mode stations (Jarod Wilson) [1937053]
- mt76: mt7915: add 802.11 encap offload support (Jarod Wilson) [1937053]
- mt76: sdio: convert {status/net}_work to mt76_worker (Jarod Wilson) [1937053]
- mt76: mt7663s: disable interrupt during txrx_worker processing (Jarod Wilson) [1937053]
- mt76: mt7663s: convert txrx_work to mt76_worker (Jarod Wilson) [1937053]
- mt76: mt7663s: move tx/rx processing in the same txrx workqueue (Jarod Wilson) [1937053]
- mt76: mt7615: retry if mt7615_mcu_init returns -EAGAIN (Jarod Wilson) [1937053]
- mt76: mt7915: fix VHT LDPC capability (Jarod Wilson) [1937053]
- mt76: mt7915: measure channel noise and report it via survey (Jarod Wilson) [1937053]
- mac80211: set SDATA_STATE_RUNNING for monitor interfaces (Jarod Wilson) [1937053]
- cfg80211: initialize rekey_data (Jarod Wilson) [1937053]
- mac80211: fix return value of ieee80211_chandef_he_6ghz_oper (Jarod Wilson) [1937053]
- rtw88: debug: Fix uninitialized memory in debugfs code (Jarod Wilson) [1937053]
- brcmfmac: expose firmware config files through modinfo (Jarod Wilson) [1937053]
- rtw88: coex: add feature to enhance HID coexistence performance (Jarod Wilson) [1937053]
- rtw88: coex: upgrade coexistence A2DP mechanism (Jarod Wilson) [1937053]
- rtw88: coex: add action for coexistence in hardware initial (Jarod Wilson) [1937053]
- rtw88: coex: add function to avoid cck lock (Jarod Wilson) [1937053]
- rtw88: coex: change the coexistence mechanism for WLAN connected (Jarod Wilson) [1937053]
- rtw88: coex: change the coexistence mechanism for HID (Jarod Wilson) [1937053]
- rtw88: coex: update AFH information while in free-run mode (Jarod Wilson) [1937053]
- rtw88: coex: update the mechanism for A2DP + PAN (Jarod Wilson) [1937053]
- rtw88: coex: add debug message (Jarod Wilson) [1937053]
- rtw88: coex: run coexistence when WLAN entering/leaving LPS (Jarod Wilson) [1937053]
- Revert "rtl8xxxu: Add Buffalo WI-U3-866D to list of supported devices" (Jarod Wilson) [1937053]
- mt76: usb: fix crash on device removal (Jarod Wilson) [1937053]
- ath11k: dp_rx: fix monitor status dma unmap direction (Jarod Wilson) [1937053]
- ath10k: Constify static qmi structs (Jarod Wilson) [1937053]
- ath10k: Release some resources in an error handling path (Jarod Wilson) [1937053]
- ath10k: Fix an error handling path (Jarod Wilson) [1937053]
- ath10k: Fix the parsing error in service available event (Jarod Wilson) [1937053]
- ath11k: Fix an error handling path (Jarod Wilson) [1937053]
- ath11k: Build check size of ath11k_skb_cb (Jarod Wilson) [1937053]
- ath11k: Reset ath11k_skb_cb before setting new flags (Jarod Wilson) [1937053]
- ath11k: Don't cast ath11k_skb_cb to ieee80211_tx_info.control (Jarod Wilson) [1937053]
- ath11k: remove "ath11k_mac_get_ar_vdev_stop_status" references (Jarod Wilson) [1937053]
- ath11k: peer delete synchronization with firmware (Jarod Wilson) [1937053]
- ath11k: vdev delete synchronization with firmware (Jarod Wilson) [1937053]
- mwifiex: Remove duplicated REG_PORT definition (Jarod Wilson) [1937053]
- rtlwifi: rtl8723ae: avoid accessing the data mapped to streaming DMA (Jarod Wilson) [1937053]
- rtlwifi: rtl8192de: avoid accessing the data mapped to streaming DMA (Jarod Wilson) [1937053]
- rtlwifi: rtl8192ce: avoid accessing the data mapped to streaming DMA (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: avoid accessing the data mapped to streaming DMA (Jarod Wilson) [1937053]
- mwifiex: Fix fall-through warnings for Clang (Jarod Wilson) [1937053]
- brcmsmac: ampdu: Check BA window size before checking block ack (Jarod Wilson) [1937053]
- brcmfmac: Fix incorrect type in assignment (Jarod Wilson) [1937053]
- rtlwifi: rtl8192de: remove the useless value assignment (Jarod Wilson) [1937053]
- brcmfmac: fix error return code in brcmf_cfg80211_connect() (Jarod Wilson) [1937053]
- rtw88: wow: print key type when failing (Jarod Wilson) [1937053]
- rtw88: coex: change the decode method from firmware (Jarod Wilson) [1937053]
- rtw88: coex: remove unnecessary WLAN slot extend (Jarod Wilson) [1937053]
- rtw88: coex: remove write scan bit to scoreboard in scan and connect notify (Jarod Wilson) [1937053]
- rtw88: coex: fix BT performance drop during initial/power-on step (Jarod Wilson) [1937053]
- rtw88: coex: Change antenna setting to enhance free-run performance (Jarod Wilson) [1937053]
- rtw88: coex: update the TDMA parameter when leave LPS (Jarod Wilson) [1937053]
- rtw88: coex: add the mechanism for RF4CE (Jarod Wilson) [1937053]
- rtw88: coex: Add force flag for coexistence table function (Jarod Wilson) [1937053]
- rtw88: coex: add write scoreboard action when WLAN in critical procedure (Jarod Wilson) [1937053]
- rtw88: coex: remove unnecessary feature/function (Jarod Wilson) [1937053]
- rtw88: coex: update TDMA settings for different beacon interval (Jarod Wilson) [1937053]
- rtw88: add CCK_PD debug log (Jarod Wilson) [1937053]
- rtw88: 8723d: add cck pd seetings (Jarod Wilson) [1937053]
- ath11k: Fix the rx_filter flag setting for peer rssi stats (Jarod Wilson) [1937053]
- ath10k: add target IRAM recovery feature support (Jarod Wilson) [1937053]
- ath11k: Fix beamformee STS in HE cap (Jarod Wilson) [1937053]
- ath11k: add processor_id based ring_selector logic (Jarod Wilson) [1937053]
- mac80211: free sta in sta_info_insert_finish() on errors (Jarod Wilson) [1937053]
- mac80211: minstrel: fix tx status processing corner case (Jarod Wilson) [1937053]
- mac80211: minstrel: remove deferred sampling code (Jarod Wilson) [1937053]
- mac80211: fix memory leak on filtered powersave frames (Jarod Wilson) [1937053]
- rfkill: Fix use-after-free in rfkill_resume() (Jarod Wilson) [1937053]
- nl80211: fix kernel-doc warning in the new SAE attribute (Jarod Wilson) [1937053]
- cfg80211: remove WDS code (Jarod Wilson) [1937053]
- mac80211: remove WDS-related code (Jarod Wilson) [1937053]
- rt2x00: remove WDS code (Jarod Wilson) [1937053]
- b43: remove WDS code (Jarod Wilson) [1937053]
- ath9k: remove WDS code (Jarod Wilson) [1937053]
- rtw88: coex: simplify the setting and condition about WLAN TX limitation (Jarod Wilson) [1937053]
- rtw88: coex: add debug message (Jarod Wilson) [1937053]
- rtw88: coex: update WLAN 5G AFH parameter for 8822b (Jarod Wilson) [1937053]
- rtw88: coex: change the parameter for A2DP when WLAN connecting (Jarod Wilson) [1937053]
- rtw88: coex: modified for BT info notify (Jarod Wilson) [1937053]
- rtw88: coex: add separate flag for manual control (Jarod Wilson) [1937053]
- rtw88: coex: Modify the timing of set_ant_path/set_rf_para (Jarod Wilson) [1937053]
- rtw88: coex: coding style adjustment (Jarod Wilson) [1937053]
- rtw88: coex: reduce magic number (Jarod Wilson) [1937053]
- rtw88: coex: update coex parameter to improve A2DP quality (Jarod Wilson) [1937053]
- rtw88: coex: fixed some wrong register definition and setting (Jarod Wilson) [1937053]
- rtlwifi: fix spelling typo of workaround (Jarod Wilson) [1937053]
- mwifiex: pcie: skip cancel_work_sync() on reset failure path (Jarod Wilson) [1937053]
- mwifiex: update comment for shutdown_sw()/reinit_sw() to reflect current state (Jarod Wilson) [1937053]
- mwifiex: fix mwifiex_shutdown_sw() causing sw reset failure (Jarod Wilson) [1937053]
- ath11k: Handle errors if peer creation fails (Jarod Wilson) [1937053]
- ath9k: work around false-positive gcc warning (Jarod Wilson) [1937053]
- wireless: remove CONFIG_WIRELESS_WDS (Jarod Wilson) [1937053]
- brcmfmac: Fix memory leak for unpaired brcmf_{alloc/free} (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: Place braces around empty if() body (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: phy: Remove a couple of unused variables (Jarod Wilson) [1937053]
- rtlwifi: rtl8723be: Remove set but unused variable 'cck_highpwr' (Jarod Wilson) [1937053]
- rtlwifi: halbtc8821a2ant: Remove a bunch of unused variables (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: Remove set but unused variable 'reg_ea4' (Jarod Wilson) [1937053]
- rtlwifi: rtl8723be: Remove set but unused variable 'lc_cal' (Jarod Wilson) [1937053]
- rtlwifi: halbtc8821a1ant: Remove set but unused variable 'wifi_rssi_state' (Jarod Wilson) [1937053]
- rtlwifi: phy: Remove set but unused variable 'bbvalue' (Jarod Wilson) [1937053]
- rtlwifi: halbtc8723b2ant: Remove a bunch of set but unused variables (Jarod Wilson) [1937053]
- rtlwifi: rtl8192cu: trx: Demote clear abuse of kernel-doc format (Jarod Wilson) [1937053]
- rtlwifi: rtl8192cu: mac: Fix some missing/ill-documented function parameters (Jarod Wilson) [1937053]
- rtw88: rtw8822c: Remove unused variable 'corr_val' (Jarod Wilson) [1937053]
- mwifiex: pcie: Remove a couple of unchecked 'ret's (Jarod Wilson) [1937053]
- wl1251: cmd: Rename 'len' to 'buf_len' in the documentation (Jarod Wilson) [1937053]
- brcmfmac: fweh: Add missing description for 'gfp' (Jarod Wilson) [1937053]
- brcmfmac: pcie: Provide description for missing function parameter 'devinfo' (Jarod Wilson) [1937053]
- brcmfmac: bcmsdh: Fix description for function parameter 'pktlist' (Jarod Wilson) [1937053]
- rt2x00: save survey for every channel visited (Jarod Wilson) [1937053]
- rtlwifi: Remove in_interrupt() usage in halbtc_send_bt_mp_operation() (Jarod Wilson) [1937053]
- rtlwifi: Remove in_interrupt() usage in is_any_client_connect_to_ap(). (Jarod Wilson) [1937053]
- rtl8xxxu: Add Buffalo WI-U3-866D to list of supported devices (Jarod Wilson) [1937053]
- rtw88: decide lps deep mode from firmware feature. (Jarod Wilson) [1937053]
- rtw88: add C2H response for checking firmware leave lps (Jarod Wilson) [1937053]
- rtw88: store firmware feature in firmware header (Jarod Wilson) [1937053]
- rtw88: sync the power state between driver and firmware (Jarod Wilson) [1937053]
- rtw88: coex: separate BLE HID profile from BLE profile (Jarod Wilson) [1937053]
- rtlwifi: Fix non-canonical address access issues (Jarod Wilson) [1937053]
- brcmfmac: fix SDIO access for big-endian host (Jarod Wilson) [1937053]
- rtw88: remove extraneous 'const' qualifier (Jarod Wilson) [1937053]
- rtlwifi: fix -Wpointer-sign warning (Jarod Wilson) [1937053]
- ath11k: fix ZERO address in probe request (Jarod Wilson) [1937053]
- ath9k: dynack: Demote non-compliant function header (Jarod Wilson) [1937053]
- ath9k: ar5008_phy: Demote half completed function headers (Jarod Wilson) [1937053]
- ath9k: ar9003_2p2_initvals: Remove unused const variables (Jarod Wilson) [1937053]
- ath9k: ar9485_initvals: Remove unused const variable 'ar9485_fast_clock_1_1_baseband_postamble' (Jarod Wilson) [1937053]
- ath9k: ar9340_initvals: Remove unused const variable 'ar9340Modes_ub124_tx_gain_table_1p0' (Jarod Wilson) [1937053]
- ath9k: ar9330_1p1_initvals: Remove unused const variable 'ar9331_common_tx_gain_offset1_1' (Jarod Wilson) [1937053]
- ath: dfs_pri_detector: Demote zero/half completed kernel-doc headers (Jarod Wilson) [1937053]
- ath: dfs_pattern_detector: Fix some function kernel-doc headers (Jarod Wilson) [1937053]
- ath: regd: Provide description for ath_reg_apply_ir_flags's 'reg' param (Jarod Wilson) [1937053]
- ath11k: Add new dfs region name for JP (Jarod Wilson) [1937053]
- ath11k: fix wmi init configuration (Jarod Wilson) [1937053]
- ath11k: Fix the hal descriptor mask (Jarod Wilson) [1937053]
- ath11k: Fix single phy hw mode (Jarod Wilson) [1937053]
- ath11k: Fix number of rules in filtered ETSI regdomain (Jarod Wilson) [1937053]
- ath11k: Remove unused param from wmi_mgmt_params (Jarod Wilson) [1937053]
- ath11k: Initialize complete alpha2 for regulatory change (Jarod Wilson) [1937053]
- ath11k: cold boot calibration support (Jarod Wilson) [1937053]
- ath11k: search DT for qcom,ath11k-calibration-variant (Jarod Wilson) [1937053]
- ath11k: Remove unnecessary data sync to cpu on monitor buffer (Jarod Wilson) [1937053]
- ath10k: cancel rx worker in hif_stop for SDIO (Jarod Wilson) [1937053]
- ath10k: Don't iterate over not-sdata-in-driver interfaces. (Jarod Wilson) [1937053]
- ath10k: fix compilation warning (Jarod Wilson) [1937053]
- mac80211: assure that certain drivers adhere to DONT_REORDER flag (Jarod Wilson) [1937053]
- mac80211: don't overwrite QoS TID of injected frames (Jarod Wilson) [1937053]
- mac80211: adhere to Tx control flag that prevents frame reordering (Jarod Wilson) [1937053]
- mac80211: add radiotap flag to assure frames are not reordered (Jarod Wilson) [1937053]
- mac80211: save HE oper info in BSS config for mesh (Jarod Wilson) [1937053]
- cfg80211: add support to configure HE MCS for beacon rate (Jarod Wilson) [1937053]
- nl80211: fix beacon tx rate mask validation (Jarod Wilson) [1937053]
- cfg80211: Add support to calculate and report 4096-QAM HE rates (Jarod Wilson) [1937053]
- cfg80211: Add support to configure SAE PWE value to drivers (Jarod Wilson) [1937053]
- ieee80211: Add definition for WFA DPP (Jarod Wilson) [1937053]
- mac80211: use semicolons rather than commas to separate statements (Jarod Wilson) [1937053]
- ath11k: FILS discovery and unsolicited broadcast probe response support (Jarod Wilson) [1937053]
- ath10k: sdio: remove redundant check in for loop (Jarod Wilson) [1937053]
- mac80211: add KCOV remote annotations to incoming frame processing (Jarod Wilson) [1937053]
- rtw88: fix fw_fifo_addr check (Jarod Wilson) [1937053]
- mac80211: don't require VHT elements for HE on 2.4 GHz (Jarod Wilson) [1937053]
- cfg80211: regulatory: Fix inconsistent format argument (Jarod Wilson) [1937053]
- mac80211: fix kernel-doc markups (Jarod Wilson) [1937053]
- mac80211: always wind down STA state (Jarod Wilson) [1937053]
- cfg80211: initialize wdev data earlier (Jarod Wilson) [1937053]
- mac80211: fix use of skb payload instead of header (Jarod Wilson) [1937053]
- mac80211: fix regression where EAPOL frames were sent in plaintext (Jarod Wilson) [1937053]
- ath11k: remove repeated words in comments and warnings (Jarod Wilson) [1937053]
- ath10k: ath10k_pci_init_irq(): workaround for checkpatch fallthrough warning (Jarod Wilson) [1937053]
- ath10k: remove repeated words in comments (Jarod Wilson) [1937053]
- nl80211: docs: add a description for s1g_cap parameter (Jarod Wilson) [1937053]
- mac80211: use new function dev_fetch_sw_netstats (Jarod Wilson) [1937053]
- rtlwifi: rtl8192se: remove duplicated legacy_httxpowerdiff (Jarod Wilson) [1937053]
- ath11k: Fix memory leak on error path (Jarod Wilson) [1937053]
- mac80211: copy configured beacon tx rate to driver (Jarod Wilson) [1937053]
- cfg80211: only allow S1G channels on S1G band (Jarod Wilson) [1937053]
- mac80211: initialize last_rate for S1G STAs (Jarod Wilson) [1937053]
- mac80211: handle lack of sband->bitrates in rates (Jarod Wilson) [1937053]
- mac80211: avoid processing non-S1G elements on S1G band (Jarod Wilson) [1937053]
- nl80211: fix non-split wiphy information (Jarod Wilson) [1937053]
- nl80211: reduce non-split wiphy dump size (Jarod Wilson) [1937053]
- ath11k: remove unnecessary casts to u32 (Jarod Wilson) [1937053]
- ath11k: enable idle power save mode (Jarod Wilson) [1937053]
- ath11k: start a timer to update HP for CE pipe 4 (Jarod Wilson) [1937053]
- ath11k: start a timer to update REO cmd ring (Jarod Wilson) [1937053]
- ath11k: start a timer to update TCL HP (Jarod Wilson) [1937053]
- ath11k: set WMI pipe credit to 1 for QCA6390 (Jarod Wilson) [1937053]
- ath11k: enable shadow register configuration and access (Jarod Wilson) [1937053]
- ath11k: read and write registers below unwindowed address (Jarod Wilson) [1937053]
- ath11k: debugfs: fix crash during rmmod (Jarod Wilson) [1937053]
- ath11k: fix warning caused by lockdep_assert_held (Jarod Wilson) [1937053]
- ath11k: mac: remove unused conf_mutex to solve a deadlock (Jarod Wilson) [1937053]
- ath11k: pci: fix rmmod crash (Jarod Wilson) [1937053]
- ath11k: add packet log support for QCA6390 (Jarod Wilson) [1937053]
- ath11k: Use GFP_ATOMIC instead of GFP_KERNEL in idr_alloc (Jarod Wilson) [1937053]
- ath11k: Use GFP_ATOMIC instead of GFP_KERNEL in ath11k_dp_htt_get_ppdu_desc (Jarod Wilson) [1937053]
- ath11k: change to disable softirqs for ath11k_regd_update to solve deadlock (Jarod Wilson) [1937053]
- ath11k: disable monitor mode on QCA6390 (Jarod Wilson) [1937053]
- ath11k: pci: check TCSR_SOC_HW_VERSION (Jarod Wilson) [1937053]
- ath11k: add interface_modes to hw_params (Jarod Wilson) [1937053]
- ath11k: fix AP mode for QCA6390 (Jarod Wilson) [1937053]
- ath11k: support loading ELF board files (Jarod Wilson) [1937053]
- ath11k: Correctly check errors for calls to debugfs_create_dir() (Jarod Wilson) [1937053]
- ath11k: mac: fix parenthesis alignment (Jarod Wilson) [1937053]
- rtw88: pci: Power cycle device during shutdown (Jarod Wilson) [1937053]
- brcmfmac: Fix warning message after dongle setup failed (Jarod Wilson) [1937053]
- brcmfmac: Fix warning when hitting FW crash with flow control feature (Jarod Wilson) [1937053]
- net: rtlwifi: Replace in_interrupt() for context detection (Jarod Wilson) [1937053]
- net: rtlwifi: Remove in_interrupt() from debug macro (Jarod Wilson) [1937053]
- net: rtlwifi: Remove void* casts related to delayed work (Jarod Wilson) [1937053]
- net: mwifiex: Use netif_rx_any_context(). (Jarod Wilson) [1937053]
- net: iwlwifi: Remove in_interrupt() from tracing macro. (Jarod Wilson) [1937053]
- net: ipw2x00,iwlegacy,iwlwifi: Remove in_interrupt() from debug macros (Jarod Wilson) [1937053]
- net: brcmfmac: Convey allocation mode as argument (Jarod Wilson) [1937053]
- net: brcmfmac: Convey execution context via argument to brcmf_netif_rx() (Jarod Wilson) [1937053]
- net: brcmfmac: Replace in_interrupt() (Jarod Wilson) [1937053]
- ath11k: Move non-fatal warn logs to dbg level (Jarod Wilson) [1937053]
- ath9k: Remove set but not used variable (Jarod Wilson) [1937053]
- rtw88: show current regulatory in tx power table (Jarod Wilson) [1937053]
- rtw88: add dump fw crash log (Jarod Wilson) [1937053]
- rtw88: add dump firmware fifo support (Jarod Wilson) [1937053]
- rtw88: handle and recover when firmware crash (Jarod Wilson) [1937053]
- rtw88: increse the size of rx buffer size (Jarod Wilson) [1937053]
- nl80211: extend support to config spatial reuse parameter set (Jarod Wilson) [1937053]
- mac80211: Support not iterating over not-sdata-in-driver ifaces (Jarod Wilson) [1937053]
- mac80211: fix some more kernel-doc in mesh (Jarod Wilson) [1937053]
- cfg80211: regulatory: remove a bogus initialization (Jarod Wilson) [1937053]
- mac80211: fix regression in sta connection monitor (Jarod Wilson) [1937053]
- nl80211: include frequency offset in survey info (Jarod Wilson) [1937053]
- mac80211: support S1G association (Jarod Wilson) [1937053]
- mac80211: receive and process S1G beacons (Jarod Wilson) [1937053]
- mac80211: avoid rate init for S1G band (Jarod Wilson) [1937053]
- mac80211: handle S1G low rates (Jarod Wilson) [1937053]
- mac80211: don't calculate duration for S1G (Jarod Wilson) [1937053]
- mac80211: encode listen interval for S1G (Jarod Wilson) [1937053]
- cfg80211: handle Association Response from S1G STA (Jarod Wilson) [1937053]
- mac80211: convert S1G beacon to scan results (Jarod Wilson) [1937053]
- cfg80211: parse S1G Operation element for BSS channel (Jarod Wilson) [1937053]
- cfg80211: convert S1G beacon to scan results (Jarod Wilson) [1937053]
- mac80211: support S1G STA capabilities (Jarod Wilson) [1937053]
- nl80211: support S1G capability overrides in assoc (Jarod Wilson) [1937053]
- mac80211: s1g: choose scanning width based on frequency (Jarod Wilson) [1937053]
- mac80211: get correct default channel width for S1G (Jarod Wilson) [1937053]
- wireless: radiotap: fix some kernel-doc (Jarod Wilson) [1937053]
- mac80211: fix some missing kernel-doc (Jarod Wilson) [1937053]
- mac80211: Inform AP when returning operating channel (Jarod Wilson) [1937053]
- ath11k: fix undefined reference to 'ath11k_debugfs_htt_ext_stats_handler' (Jarod Wilson) [1937053]
- mt76: mt7663s: remove max_tx_fragments limitation (Jarod Wilson) [1937053]
- mt76: Convert to DEFINE_SHOW_ATTRIBUTE (Jarod Wilson) [1937053]
- mt76: mt7915: add offchannel condition in switch channel command (Jarod Wilson) [1937053]
- mt76: mt7915: convert to use le16_add_cpu() (Jarod Wilson) [1937053]
- mt76: Fix unsigned expressions compared with zero (Jarod Wilson) [1937053]
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_beacon (Jarod Wilson) [1937053]
- mt76: mt76x0: Move tables used only by init.c to their own header file (Jarod Wilson) [1937053]
- mt76: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- mt76: mt7615: unlock dfs bands (Jarod Wilson) [1937053]
- mt76: mt7663: check isr read return value in mt7663s_rx_work (Jarod Wilson) [1937053]
- mt76: mt7663s: introduce sdio tx aggregation (Jarod Wilson) [1937053]
- mt76: mt7663s: fix possible quota leak in mt7663s_refill_sched_quota (Jarod Wilson) [1937053]
- mt76: move pad estimation out of mt76_skb_adjust_pad (Jarod Wilson) [1937053]
- mt76: mt7663s: introduce __mt7663s_xmit_queue routine (Jarod Wilson) [1937053]
- mt76: mt7663s: split mt7663s_tx_update_sched in mt7663s_tx_{pick,update}_quota (Jarod Wilson) [1937053]
- mt76: mt7663s: do not use altx for ctl/mgmt traffic (Jarod Wilson) [1937053]
- mt76: mt7622: fix fw hang on mt7622 (Jarod Wilson) [1937053]
- mt76: mt7615: fix VHT LDPC capability (Jarod Wilson) [1937053]
- mt76: mt7615: Remove set but unused variable 'index' (Jarod Wilson) [1937053]
- mt76: remove retry_q from struct mt76_txq and related code (Jarod Wilson) [1937053]
- mt76: move txwi handling code to dma.c, since it is mmio specific (Jarod Wilson) [1937053]
- mt76: mt7915: fix queue/tid mapping for airtime reporting (Jarod Wilson) [1937053]
- mt76: mt7915: simplify mt7915_lmac_mapping (Jarod Wilson) [1937053]
- mt76: dma: cache dma map address/len in struct mt76_queue_entry (Jarod Wilson) [1937053]
- mt76: mt7915: fix HE BSS info (Jarod Wilson) [1937053]
- mt76: convert from tx tasklet to tx worker thread (Jarod Wilson) [1937053]
- mt76: add utility functions for deferring work to a kernel thread (Jarod Wilson) [1937053]
- mt76: testmode: add a limit for queued tx_frames packets (Jarod Wilson) [1937053]
- mt76: mt7615: fix antenna selection for testmode tx_frames (Jarod Wilson) [1937053]
- mt76: mt7615: fix MT_ANT_SWITCH_CON register definition (Jarod Wilson) [1937053]
- mt76: mt7915: fix unexpected firmware mode (Jarod Wilson) [1937053]
- mt76: mt76x02: tune tx ring size (Jarod Wilson) [1937053]
- mt76: mt7603: tune tx ring size (Jarod Wilson) [1937053]
- mt76: remove struct mt76_sw_queue (Jarod Wilson) [1937053]
- mt76: rely on AQL for burst size limits on tx queueing (Jarod Wilson) [1937053]
- mt76: remove swq from struct mt76_sw_queue (Jarod Wilson) [1937053]
- mt76: remove qid argument to drv->tx_complete_skb (Jarod Wilson) [1937053]
- mt76: unify queue tx cleanup code (Jarod Wilson) [1937053]
- mt76: sdio: fix use of q->head and q->tail (Jarod Wilson) [1937053]
- mt76: usb: fix use of q->head and q->tail (Jarod Wilson) [1937053]
- mt76: mt7603: check for single-stream EEPROM configuration (Jarod Wilson) [1937053]
- mt76: add memory barrier to DMA queue kick (Jarod Wilson) [1937053]
- mt76: mt7915: add support for accessing mapped registers via bus ops (Jarod Wilson) [1937053]
- mt76: mt7615: significantly reduce interrupt load (Jarod Wilson) [1937053]
- mt76: mt7915: significantly reduce interrupt load (Jarod Wilson) [1937053]
- mt76: mt7915: schedule tx tasklet in mt7915_mac_tx_free (Jarod Wilson) [1937053]
- mt76: dma: update q->queued immediately on cleanup (Jarod Wilson) [1937053]
- mt76: mt7915: optimize mt7915_mac_sta_poll (Jarod Wilson) [1937053]
- mt76: mt7615: fix reading airtime statistics (Jarod Wilson) [1937053]
- mt76: mt7663u: fix dma header initialization (Jarod Wilson) [1937053]
- mt76: fix a possible NULL pointer dereference in mt76_testmode_dump (Jarod Wilson) [1937053]
- mt76: mt7615: fix a possible NULL pointer dereference in mt7615_pm_wake_work (Jarod Wilson) [1937053]
- mt76: mt7615: fix possible memory leak in mt7615_tm_set_tx_power (Jarod Wilson) [1937053]
- mt76: mt7663s: fix unable to handle kernel paging request (Jarod Wilson) [1937053]
- mt76: mt7663s: fix resume failure (Jarod Wilson) [1937053]
- mt76: mt7663s: use NULL instead of 0 in sdio code (Jarod Wilson) [1937053]
- mt76: mt7615: release mutex in mt7615_reset_test_set (Jarod Wilson) [1937053]
- mt76: mt7915: add Tx A-MSDU offloading support (Jarod Wilson) [1937053]
- mt76: mt7915: add missing flags in WMM parameter settings (Jarod Wilson) [1937053]
- mt76: mt7915: simplify aggregation session check (Jarod Wilson) [1937053]
- mt76: mt7615: remove mtxq->agg_ssn assignment (Jarod Wilson) [1937053]
- mt76: move mt76_check_agg_ssn to driver tx_prepare calls (Jarod Wilson) [1937053]
- mt76: mt7915: enable offloading of sequence number assignment (Jarod Wilson) [1937053]
- mt76: mt7915: increase tx retry count (Jarod Wilson) [1937053]
- mt76: mt7915: clean up station stats polling and rate control update (Jarod Wilson) [1937053]
- mt76: mt7915: do not do any work in napi poll after calling napi_complete_done() (Jarod Wilson) [1937053]
- mt76: mt7615: do not do any work in napi poll after calling napi_complete_done() (Jarod Wilson) [1937053]
- mt76: mt76x02: clean up and fix interrupt masking in the irq handler (Jarod Wilson) [1937053]
- mt76: mt7615: only clear unmasked interrupts in irq tasklet (Jarod Wilson) [1937053]
- mt76: mt7915: clean up and fix interrupt masking in the irq handler (Jarod Wilson) [1937053]
- mt76: set interrupt mask register to 0 before requesting irq (Jarod Wilson) [1937053]
- mt76: fix double DMA unmap of the first buffer on 7615/7915 (Jarod Wilson) [1937053]
- mt76: mt7915: fix crash on tx rate report for invalid stations (Jarod Wilson) [1937053]
- mt76: mt7915: enable U-APSD on AP side (Jarod Wilson) [1937053]
- mt76: mt76s: get rid of unused variable (Jarod Wilson) [1937053]
- mt76: mt76s: move tx/rx processing in 2 separate works (Jarod Wilson) [1937053]
- mt76: mt76s: move status processing in txrx wq (Jarod Wilson) [1937053]
- mt76: mt7663s: move rx processing in txrx wq (Jarod Wilson) [1937053]
- mt76: mt76s: move tx processing in a dedicated wq (Jarod Wilson) [1937053]
- mt76: mt76s: fix oom in mt76s_tx_queue_skb_raw (Jarod Wilson) [1937053]
- mt76: mt7615: reschedule runtime-pm receiving a tx interrupt (Jarod Wilson) [1937053]
- mt76: do not inject packets if MT76_STATE_PM is set (Jarod Wilson) [1937053]
- mt76: mt7615: hold mt76 lock queueing wd in mt7615_queue_key_update (Jarod Wilson) [1937053]
- mt76: mt7663s: move drv_own/fw_own in mt7615_mcu_ops (Jarod Wilson) [1937053]
- mt76: mt7615: move drv_own/fw_own in mt7615_mcu_ops (Jarod Wilson) [1937053]
- mt76: mt7615: register ext_phy if DBDC is detected (Jarod Wilson) [1937053]
- brcmfmac: check return value of driver_for_each_device() (Jarod Wilson) [1937053]
- ath11k: Remove unused function ath11k_htc_restore_tx_skb() (Jarod Wilson) [1937053]
- ath11k: remove redundant num_keep_alive_pattern assignment (Jarod Wilson) [1937053]
- ath11k: wmi: remove redundant configuration values from init (Jarod Wilson) [1937053]
- ath11k: Add support spectral scan for IPQ6018 (Jarod Wilson) [1937053]
- ath11k: debugfs: move some function declarations to correct header files (Jarod Wilson) [1937053]
- ath11k: rename debug_htt_stats.[c|h] to debugfs_htt_stats.[c|h] (Jarod Wilson) [1937053]
- ath11k: debugfs: use ath11k_debugfs_ prefix (Jarod Wilson) [1937053]
- ath11k: refactor debugfs code into debugfs.c (Jarod Wilson) [1937053]
- ath10k: Use bdf calibration variant for snoc targets (Jarod Wilson) [1937053]
- rtlwifi: rtl8723be: use true,false for bool variable large_cfo_hit (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: use true,false for bool variable large_cfo_hit (Jarod Wilson) [1937053]
- rtlwifi: rtl8192ee: use true,false for bool variable large_cfo_hit (Jarod Wilson) [1937053]
- rtlwifi: Use ffs in <foo>_phy_calculate_bit_shift (Jarod Wilson) [1937053]
- mt7601u: Convert to DEFINE_SHOW_ATTRIBUTE (Jarod Wilson) [1937053]
- ath11k: Remove rproc references from common core layer (Jarod Wilson) [1937053]
- ath9k: hif_usb: fix race condition between usb_get_urb() and usb_kill_anchored_urbs() (Jarod Wilson) [1937053]
- rtlwifi: rtl8723be: fix comparison to bool warning in hw.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8192de: fix comparison to bool warning in hw.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8192ce: fix comparison to bool warning in hw.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8192cu: fix comparison to bool warning in hw.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: fix comparison to bool warning in phy.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: fix comparison to bool warning in hw.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8192cu: fix comparison to bool warning in mac.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8192c: fix comparison to bool warning in phy_common.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8192ee: fix comparison to bool warning in hw.c (Jarod Wilson) [1937053]
- mac80211: fix some encapsulation offload kernel-doc (Jarod Wilson) [1937053]
- cfg80211: add missing kernel-doc for S1G band capabilities (Jarod Wilson) [1937053]
- mac80211: Unsolicited broadcast probe response support (Jarod Wilson) [1937053]
- nl80211: Unsolicited broadcast probe response support (Jarod Wilson) [1937053]
- mac80211: Add FILS discovery support (Jarod Wilson) [1937053]
- nl80211: Add FILS discovery support (Jarod Wilson) [1937053]
- mac80211: allow bigger A-MSDU sizes in VHT, even if HT is limited (Jarod Wilson) [1937053]
- nl80211: support setting S1G channels (Jarod Wilson) [1937053]
- nl80211: correctly validate S1G beacon head (Jarod Wilson) [1937053]
- cfg80211: regulatory: handle S1G channels (Jarod Wilson) [1937053]
- nl80211: advertise supported channel width in S1G (Jarod Wilson) [1937053]
- ieee80211: redefine S1G bits with GENMASK (Jarod Wilson) [1937053]
- mac80211: reorganize code to remove a forward declaration (Jarod Wilson) [1937053]
- mac80211: extend ieee80211_tx_status_ext to support bulk free (Jarod Wilson) [1937053]
- mac80211: support using ieee80211_tx_status_ext to free skbs without status info (Jarod Wilson) [1937053]
- mac80211: unify 802.3 (offload) and 802.11 tx status codepath (Jarod Wilson) [1937053]
- mac80211: optimize station connection monitor (Jarod Wilson) [1937053]
- mac80211: notify the driver when a sta uses 4-address mode (Jarod Wilson) [1937053]
- mac80211: swap NEED_TXPROCESSING and HW_80211_ENCAP tx flags (Jarod Wilson) [1937053]
- mac80211: remove tx status call to ieee80211_sta_register_airtime (Jarod Wilson) [1937053]
- mac80211: reduce duplication in tx status functions (Jarod Wilson) [1937053]
- mac80211: rework tx encapsulation offload API (Jarod Wilson) [1937053]
- mac80211: set info->control.hw_key for encap offload packets (Jarod Wilson) [1937053]
- mac80211: skip encap offload for tx multicast/control packets (Jarod Wilson) [1937053]
- mac80211: check and refresh aggregation session in encap offload tx (Jarod Wilson) [1937053]
- mac80211: add missing queue/hash initialization to 802.3 xmit (Jarod Wilson) [1937053]
- cfg80211: add more comments for ap_isolate in bss_parameters (Jarod Wilson) [1937053]
- lib80211: Remove unused macro DRV_NAME (Jarod Wilson) [1937053]
- rtlwifi: rtl8723ae: fix comparison pointer to bool warning in phy.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8723ae: fix comparison pointer to bool warning in trx.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8723ae: fix comparison pointer to bool warning in rf.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: fix comparison pointer to bool warning in hw.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: fix comparison pointer to bool warning in trx.c (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: fix comparison pointer to bool warning in phy.c (Jarod Wilson) [1937053]
- rtw88: rtw8822c: eliminate code duplication, use native swap() function (Jarod Wilson) [1937053]
- brcmsmac: main: Eliminate empty brcms_c_down_del_timer() (Jarod Wilson) [1937053]
- brcmsmac: phy_lcn: Remove unused variable 'lcnphy_rx_iqcomp_table_rev0' (Jarod Wilson) [1937053]
- brcmsmac: phytbl_lcn: Remove unused array 'dot11lcn_gain_tbl_rev1' (Jarod Wilson) [1937053]
- brcmfmac: support SAE authentication offload in AP mode (Jarod Wilson) [1937053]
- brcmfmac: support 4-way handshake offloading for WPA/WPA2-PSK in AP mode (Jarod Wilson) [1937053]
- ath10k: Remove unused macro ATH10K_ROC_TIMEOUT_HZ (Jarod Wilson) [1937053]
- ath11k: Remove unused inline function htt_htt_stats_debug_dump() (Jarod Wilson) [1937053]
- ath11k: fix link error when CONFIG_REMOTEPROC is disabled (Jarod Wilson) [1937053]
- ath11k: remove calling ath11k_init_hw_params() second time (Jarod Wilson) [1937053]
- ath11k: add raw mode and software crypto support (Jarod Wilson) [1937053]
- ath11k: add ipq6018 support (Jarod Wilson) [1937053]
- ath11k: move target ce configs to hw_params (Jarod Wilson) [1937053]
- net: wireless: drop bogus CRYPTO_xxx Kconfig selects (Jarod Wilson) [1937053]
- rtlwifi: switch from 'pci_' to 'dma_' API (Jarod Wilson) [1937053]
- brcmsmac: fix memory leak in wlc_phy_attach_lcnphy (Jarod Wilson) [1937053]
- rtl8xxxu: prevent potential memory leak (Jarod Wilson) [1937053]
- rtlwifi: rtl8723ae: Delete a stray tab (Jarod Wilson) [1937053]
- ath11k: Add peer max mpdu parameter in peer assoc command (Jarod Wilson) [1937053]
- ath10k: Add support for chain1 regulator supply voting (Jarod Wilson) [1937053]
- brcmfmac: set F2 SDIO block size to 128 bytes for BCM4329 (Jarod Wilson) [1937053]
- brcmfmac: drop chip id from debug messages (Jarod Wilson) [1937053]
- brcmfmac: increase F2 watermark for BCM4329 (Jarod Wilson) [1937053]
- mwifiex: sdio: Fix -Wunused-const-variable warnings (Jarod Wilson) [1937053]
- mwifiex: wmm: Fix -Wunused-const-variable warnings (Jarod Wilson) [1937053]
- mt7601u: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- rtlwifi: Remove temporary definition of RT_TRACE (Jarod Wilson) [1937053]
- rtlwifi: rtl8821ae: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- brcmsmac: phytbl_n: Remove a few unused arrays (Jarod Wilson) [1937053]
- brcmsmac: phytbl_lcn: Remove unused array 'dot11lcnphytbl_rx_gain_info_rev1' (Jarod Wilson) [1937053]
- brcmsmac: phy_n: Remove a bunch of unused variables (Jarod Wilson) [1937053]
- brcmsmac: phy_lcn: Remove a bunch of unused variables (Jarod Wilson) [1937053]
- prism54: isl_ioctl: Remove unused variable 'j' (Jarod Wilson) [1937053]
- rtw88: debug: Remove unused variables 'val' (Jarod Wilson) [1937053]
- brcmfmac: fwsignal: Finish documenting 'brcmf_fws_mac_descriptor' (Jarod Wilson) [1937053]
- brcmsmac: phy_cmn: Remove a unused variables 'vbat' and 'temp' (Jarod Wilson) [1937053]
- brcmfmac: p2p: Fix a couple of function headers (Jarod Wilson) [1937053]
- brcmsmac: ampdu: Remove a couple set but unused variables (Jarod Wilson) [1937053]
- mwifiex: pcie: Move tables to the only place they're used (Jarod Wilson) [1937053]
- ath10k: Get rid of "per_ce_irq" hw param (Jarod Wilson) [1937053]
- ath10k: Keep track of which interrupts fired, don't poll them (Jarod Wilson) [1937053]
- ath10k: Add interrupt summary based CE processing (Jarod Wilson) [1937053]
- rtlwifi: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- rtl818x_pci: switch from 'pci_' to 'dma_' API (Jarod Wilson) [1937053]
- p54: avoid accessing the data mapped to streaming DMA (Jarod Wilson) [1937053]
- rtlwifi: rtl8192c: phy_common: Remove unused variable 'bbvalue' (Jarod Wilson) [1937053]
- brcmfmac: fwsignal: Remove unused variable 'brcmf_fws_prio2fifo' (Jarod Wilson) [1937053]
- b43: phy_ht: Remove 9 year old TODO (Jarod Wilson) [1937053]
- brcmfmac: btcoex: Update 'brcmf_btcoex_state' and demote others (Jarod Wilson) [1937053]
- brcmfmac: firmware: Demote seemingly unintentional kernel-doc header (Jarod Wilson) [1937053]
- brcmsmac: main: Remove a bunch of unused variables (Jarod Wilson) [1937053]
- brcmfmac: p2p: Fix a bunch of function docs (Jarod Wilson) [1937053]
- brcmsmac: ampdu: Remove a bunch of unused variables (Jarod Wilson) [1937053]
- brcmfmac: p2p: Deal with set but unused variables (Jarod Wilson) [1937053]
- mt7601u: phy: Fix misnaming when documented function parameter 'dac' (Jarod Wilson) [1937053]
- rtlwifi: rtl8723-common: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8723be Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8723ae Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8192se Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8192ee: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8192de: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8192cu: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8192ce: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8192-common: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: rtl8188ee: Rename RT_TRACE to rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: btcoexist: Replace RT_TRACE with rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: Replace RT_TRACE with rtl_dbg (Jarod Wilson) [1937053]
- rtlwifi: Start changing RT_TRACE into rtl_dbg (Jarod Wilson) [1937053]
- ath10k: wmi: Use struct_size() helper in ath10k_wmi_alloc_skb() (Jarod Wilson) [1937053]
- ath11k: fix missing error check on call to ath11k_pci_get_user_msi_assignment (Jarod Wilson) [1937053]
- ath11k: fix spelling mistake "moniter" -> "monitor" (Jarod Wilson) [1937053]
- nl80211: support SAE authentication offload in AP mode (Jarod Wilson) [1937053]
- atmel: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- b43: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- brcmfmac: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- rt2x00: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- b43: phy_n: Add empty braces around empty statements (Jarod Wilson) [1937053]
- b43: phy_common: Demote non-conformant kerneldoc header (Jarod Wilson) [1937053]
- brcmsmac: mac80211_if: Demote a few non-conformant kerneldoc headers (Jarod Wilson) [1937053]
- brcmfmac: fweh: Fix docrot related function documentation issues (Jarod Wilson) [1937053]
- brcmfmac: fweh: Remove set but unused variable 'err' (Jarod Wilson) [1937053]
- b43: main: Add braces around empty statements (Jarod Wilson) [1937053]
- atmel: Demote non-kerneldoc header to standard comment block (Jarod Wilson) [1937053]
- nl80211: rename csa counter attributes countdown counters (Jarod Wilson) [1937053]
- nl80211: add support for setting fixed HE rate/gi/ltf (Jarod Wilson) [1937053]
- ath11k: return -ENOMEM on allocation failure (Jarod Wilson) [1937053]
- ath11k: return error if firmware request fails (Jarod Wilson) [1937053]
- ath9k: Do not select MAC80211_LEDS by default (Jarod Wilson) [1937053]
- ath9k: ar5008_initvals: Move ar5416Bank{0,1,2,3,7} to where they are used (Jarod Wilson) [1937053]
- ath9k: ar5008_initvals: Remove unused table entirely (Jarod Wilson) [1937053]
- ath9k: ar9001_initvals: Remove unused array 'ar5416Bank6_9100' (Jarod Wilson) [1937053]
- ath9k: ar9002_initvals: Remove unused array 'ar9280PciePhy_clkreq_off_L1_9280' (Jarod Wilson) [1937053]
- ath9k_htc: Do not select MAC80211_LEDS by default (Jarod Wilson) [1937053]
- rtw88: 8822c: update tx power limit tables to RF v20.1 (Jarod Wilson) [1937053]
- rtw88: use read_poll_timeout_atomic() for poll loop (Jarod Wilson) [1937053]
- rtw88: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- rtw88: switch from 'pci_' to 'dma_' API (Jarod Wilson) [1937053]
- mwifiex: don't call del_timer_sync() on uninitialized timer (Jarod Wilson) [1937053]
- mwifiex: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- mwifiex: Clean up some err and dbg messages (Jarod Wilson) [1937053]
- mwifiex: switch from 'pci_' to 'dma_' API (Jarod Wilson) [1937053]
- nl80211: fix PORT_AUTHORIZED wording to reflect behavior (Jarod Wilson) [1937053]
- cfg80211: add helper fn for adjacent rule channels (Jarod Wilson) [1937053]
- cfg80211: add helper fn for single rule channels (Jarod Wilson) [1937053]
- nl80211: use NLA_POLICY_RANGE(NLA_BINARY, ...) for a few attributes (Jarod Wilson) [1937053]
- nl80211: clean up code/policy a bit (Jarod Wilson) [1937053]
- net: wireless: wext_compat.c: delete duplicated word (Jarod Wilson) [1937053]
- net: wireless: sme.c: delete duplicated word (Jarod Wilson) [1937053]
- net: wireless: scan.c: delete or fix duplicated words (Jarod Wilson) [1937053]
- net: wireless: reg.c: delete duplicated words + fix punctuation (Jarod Wilson) [1937053]
- net: wireless: delete duplicated word + fix grammar (Jarod Wilson) [1937053]
- net: mac80211: mesh.h: delete duplicated word (Jarod Wilson) [1937053]
- net: mac80211: agg-rx.c: fix duplicated words (Jarod Wilson) [1937053]
- net: ath11k: constify ath11k_thermal_ops (Jarod Wilson) [1937053]
- ath10k: Add new api to support reset TID config (Jarod Wilson) [1937053]
- ath10k: Add new api to support TID specific configuration (Jarod Wilson) [1937053]
- ath10k: Move rate mask validation function up in the file (Jarod Wilson) [1937053]
- ath10k: Add wmi command support for station specific TID config (Jarod Wilson) [1937053]
- ath10k: sdio: add firmware coredump support (Jarod Wilson) [1937053]
- ath10k: add bus type for each layout of coredump (Jarod Wilson) [1937053]
- netlink/wireless: consistently use NLA_POLICY_MIN_LEN() (Jarod Wilson) [1937053]
- netlink/wireless: consistently use NLA_POLICY_EXACT_LEN() (Jarod Wilson) [1937053]
- rndis_wlan: tighten check of rndis_query_oid return (Jarod Wilson) [1937053]
- rtw88: fix spelling mistake: "unsupport" -> "unsupported" (Jarod Wilson) [1937053]
- brcmfmac: use *ph to print small buffer (Jarod Wilson) [1937053]
- brcm80211: fix possible memleak in brcmf_proto_msgbuf_attach (Jarod Wilson) [1937053]
- ath11k: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- ath10k: fix VHT NSS calculation when STBC is enabled (Jarod Wilson) [1937053]
- ath10k: Register shutdown handler (Jarod Wilson) [1937053]
- ath11k: reset MHI during power down and power up (Jarod Wilson) [1937053]
- ath11k: use TCL_DATA_RING_0 for QCA6390 (Jarod Wilson) [1937053]
- ath11k: process both lmac rings for QCA6390 (Jarod Wilson) [1937053]
- ath11k: assign correct search flag and type for QCA6390 (Jarod Wilson) [1937053]
- ath11k: delay vdev_start for QCA6390 (Jarod Wilson) [1937053]
- ath11k: refine the phy_id check in ath11k_reg_chan_list_event (Jarod Wilson) [1937053]
- ath11k: setup QCA6390 rings for both rxdmas (Jarod Wilson) [1937053]
- ath11k: don't initialize rxdma1 related ring (Jarod Wilson) [1937053]
- ath11k: enable DP interrupt setup for QCA6390 (Jarod Wilson) [1937053]
- ath11k: dp: redefine peer_map and peer_unmap (Jarod Wilson) [1937053]
- ath11k: wmi: put hardware to DBS mode (Jarod Wilson) [1937053]
- ath11k: initialize wmi config based on hw_params (Jarod Wilson) [1937053]
- ath11k: force single pdev only for QCA6390 (Jarod Wilson) [1937053]
- ath11k: disable CE interrupt before hif start (Jarod Wilson) [1937053]
- ath11k: ce: get msi_addr and msi_data before srng setup (Jarod Wilson) [1937053]
- ath11k: hal: assign msi_addr and msi_data to srng (Jarod Wilson) [1937053]
- ath11k: ce: remove CE_COUNT() macro (Jarod Wilson) [1937053]
- ath11k: ce: remove host_ce_config_wlan macro (Jarod Wilson) [1937053]
- ath11k: ce: support different CE configurations (Jarod Wilson) [1937053]
- ath11k: hal: cleanup dynamic register macros (Jarod Wilson) [1937053]
- ath11k: hal: create register values dynamically (Jarod Wilson) [1937053]
- ath10k: move enable_pll_clk call to ath10k_core_start() (Jarod Wilson) [1937053]
- ath10k: Fix the size used in a 'dma_free_coherent()' call in an error handling path (Jarod Wilson) [1937053]
- ath10k: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- ath9k: add NL80211_EXT_FEATURE_CAN_REPLACE_PTK0 support (Jarod Wilson) [1937053]
- ath11k: hal: create hw_srng_config dynamically (Jarod Wilson) [1937053]
- ath11k: enable internal sleep clock (Jarod Wilson) [1937053]
- ath11k: fix KASAN warning of ath11k_qmi_wlanfw_wlan_cfg_send (Jarod Wilson) [1937053]
- ath11k: fix memory OOB access in qmi_decode (Jarod Wilson) [1937053]
- ath11k: allocate smaller chunks of memory for firmware (Jarod Wilson) [1937053]
- ath11k: setup ce tasklet for control path (Jarod Wilson) [1937053]
- ath11k: configure copy engine msi address in CE srng (Jarod Wilson) [1937053]
- ath11k: pci: add read32() and write32() hif operations (Jarod Wilson) [1937053]
- ath11k: fill appropriate QMI service instance id for QCA6390 (Jarod Wilson) [1937053]
- ath11k: add board file support for PCI devices (Jarod Wilson) [1937053]
- ath11k: add support for m3 firmware (Jarod Wilson) [1937053]
- ath11k: use remoteproc only with AHB devices (Jarod Wilson) [1937053]
- ath11k: pci: add HAL, CE and core initialisation (Jarod Wilson) [1937053]
- ath11k: register MHI controller device for QCA6390 (Jarod Wilson) [1937053]
- ath11k: implement ath11k_core_pre_init() (Jarod Wilson) [1937053]
- ath11k: pci: add MSI config initialisation (Jarod Wilson) [1937053]
- ath11k: pci: setup resources (Jarod Wilson) [1937053]
- ath11k: add simple PCI client driver for QCA6390 chipset (Jarod Wilson) [1937053]
- ath11k: move ring mask definitions to hw_params (Jarod Wilson) [1937053]
- ath11k: add hw_params entry for QCA6390 (Jarod Wilson) [1937053]
- ath11k: do not depend on ARCH_QCOM for ath11k (Jarod Wilson) [1937053]
- ath10k: correct the array index from mcs index for HT mode for QCA6174 (Jarod Wilson) [1937053]
- ath10k: enable supports_peer_stats_info for QCA6174 PCI devices (Jarod Wilson) [1937053]
- ath10k: remove return for NL80211_STA_INFO_TX_BITRATE (Jarod Wilson) [1937053]
- ath10k: add wmi service peer stat info for wmi tlv (Jarod Wilson) [1937053]
- ath10k: start recovery process when payload length exceeds max htc length for sdio (Jarod Wilson) [1937053]
- ath: drop unnecessary list_empty (Jarod Wilson) [1937053]
- ath9k: Use fallthrough pseudo-keyword (Jarod Wilson) [1937053]
- ath9k: Fix typo in function name (Jarod Wilson) [1937053]
- ath9k: Replace HTTP links with HTTPS ones (Jarod Wilson) [1937053]
- ath10k: check idx validity in __ath10k_htt_rx_ring_fill_n() (Jarod Wilson) [1937053]
- ath9k: Check the return value of pcie_capability_read_*() (Jarod Wilson) [1937053]
- ath11k: remove define ATH11K_QMI_DEFAULT_CAL_FILE_NAME (Jarod Wilson) [1937053]
- ath11k: don't use defines in hw_params (Jarod Wilson) [1937053]
- ath11k: qmi: cleanup info messages (Jarod Wilson) [1937053]
- ath11k: remove useless info messages (Jarod Wilson) [1937053]
- ath11k: change ath11k_core_fetch_board_data_api_n() to use ath11k_core_create_firmware_path() (Jarod Wilson) [1937053]
- ath11k: don't use defines for hw specific firmware directories (Jarod Wilson) [1937053]
- ath11k: create a common function to request all firmware files (Jarod Wilson) [1937053]
- ath11k: Add bdf-addr in hw_params (Jarod Wilson) [1937053]
- ath11k: add hw_ops for pdev id to hw_mac mapping (Jarod Wilson) [1937053]
- ath11k: define max_radios in hw_params (Jarod Wilson) [1937053]
- ath11k: convert ath11k_hw_params to an array (Jarod Wilson) [1937053]
- ath11k: ahb: call ath11k_core_init() before irq configuration (Jarod Wilson) [1937053]
- ath10k: pci: fix memcpy size of bmi response (Jarod Wilson) [1937053]
- ath11k: rename default board file (Jarod Wilson) [1937053]
- ath11k: update firmware files read path (Jarod Wilson) [1937053]
- ath10k: provide survey info as accumulated data (Jarod Wilson) [1937053]
- ath10k: fix retry packets update in station dump (Jarod Wilson) [1937053]
- ath10k: Wait until copy complete is actually done before completing (Jarod Wilson) [1937053]
- mac80211_hwsim: add 6GHz channels (Jarod Wilson) [1937053]
- mac80211_hwsim: indicate support for S1G (Jarod Wilson) [1937053]
- mac80211_hwsim: write TSF timestamp correctly to S1G beacon (Jarod Wilson) [1937053]
- mac80211_hwsim: fix typo in kernel-doc (Jarod Wilson) [1937053]
- mac80211: rename csa counters to countdown counters (Jarod Wilson) [1937053]
- mac80211_hwsim: report the WIPHY_FLAG_SUPPORTS_5_10_MHZ capability (Jarod Wilson) [1937053]
- mac80211_hwsim: Claim support for setting Beacon frame TX legacy rate (Jarod Wilson) [1937053]
- mac80211_hwsim: Advertise support for multicast RX registration (Jarod Wilson) [1937053]
- mac80211_hwsim: indicate in IBSS that we have transmitted beacons (Jarod Wilson) [1937053]
- mac80211_hwsim: notify wmediumd of used MAC addresses (Jarod Wilson) [1937053]
- mac80211_hwsim: use GFP_ATOMIC under spin lock (Jarod Wilson) [1937053]
- mac80211_hwsim: Use kstrndup() in place of kasprintf() (Jarod Wilson) [1937053]
- mac80211_hwsim: add frame transmission support over virtio (Jarod Wilson) [1937053]
- mac80211_hwsim: enable Beacon protection (Jarod Wilson) [1937053]
- mac80211_hwsim: add power save support (Jarod Wilson) [1937053]
- mac80211_hwsim: remove maximum TX power (Jarod Wilson) [1937053]
- mac80211_hwsim: use DEFINE_DEBUGFS_ATTRIBUTE to define debugfs fops (Jarod Wilson) [1937053]
- mac80211_hwsim: add support for OCB (Jarod Wilson) [1937053]
- mac80211_hwsim: add more 5GHz channels, 5/10 MHz support (Jarod Wilson) [1937053]
- mac80211_hwsim: fix incorrect dev_alloc_name failure goto (Jarod Wilson) [1937053]
- mac80211_hwsim: Register support for HE meshpoint (Jarod Wilson) [1937053]
- mac80211_hwsim: fill boottime_ns in netlink RX path (Jarod Wilson) [1937053]
- mac80211_hwsim: Fix possible null-pointer dereferences in hwsim_dump_radio_nl() (Jarod Wilson) [1937053]
- mac80211_hwsim: Extended Key ID API update (Jarod Wilson) [1937053]
- mac80211_hwsim: Fix a typo in the name of function 'mac80211_hswim_he_capab()' (Jarod Wilson) [1937053]
- mac80211_hwsim: Extended Key ID support (Jarod Wilson) [1937053]
- mac80211_hwsim: set p2p device interface support indication (Jarod Wilson) [1937053]
- mac80211_hwsim: calculate if_combination.max_interfaces (Jarod Wilson) [1937053]
- mac80211_hwsim: propagate genlmsg_reply return code (Jarod Wilson) [1937053]
- mac80211_hwsim: Declare support for Multi-BSSID (Jarod Wilson) [1937053]
- mac80211_hwsim: Support boottime in scan results (Jarod Wilson) [1937053]
- mac80211_hwsim: check that n_limits makes sense (Jarod Wilson) [1937053]
- mac80211_hwsim: fix overwriting of if_combination (Jarod Wilson) [1937053]
- mac80211_hwsim: fixes kernel crash during mac80211_hwsim init (Jarod Wilson) [1937053]
- mac80211_hwsim: allow configurable cipher types (Jarod Wilson) [1937053]
- mac80211_hwsim: allow setting iftype support (Jarod Wilson) [1937053]
- mac80211_hwsim: move HWSIM_ATTR_RADIO_NAME parsing last (Jarod Wilson) [1937053]
- mac80211_hwsim: fix module init error paths for netlink (Jarod Wilson) [1937053]
- mac80211_hwsim: drop now unused work-queue from hwsim (Jarod Wilson) [1937053]
- mac80211_hwsim: do not omit multicast announce of first added radio (Jarod Wilson) [1937053]
- mac80211_hwsim: fix race in radio destruction from netlink notifier (Jarod Wilson) [1937053]
- mac80211_hwsim: fix locking when iterating radios during ns exit (Jarod Wilson) [1937053]
- wireless: align to draft 11ax D3.0 (Jarod Wilson) [1937053]
- mac80211_hwsim: correct use of IEEE80211_VHT_CAP_RXSTBC_X (Jarod Wilson) [1937053]
- mac80211_hwsim: require at least one channel (Jarod Wilson) [1937053]
- mac80211_hwsim: Add support for HE (Jarod Wilson) [1937053]
- net/fq_impl: do not maintain a backlog-sorted list of flows (Jarod Wilson) [1937053]
- net/fq_impl: drop get_default_func, move default flow to fq_tin (Jarod Wilson) [1937053]
- net/fq_impl: bulk-free packets from a flow on overmemory (Jarod Wilson) [1937053]
- net/fq_impl: use skb_get_hash instead of skb_get_hash_perturb (Jarod Wilson) [1937053]
- net/fq_impl: Switch to kvmalloc() for memory allocation (Jarod Wilson) [1937053]
- mac80211: set NETIF_F_LLTX when using intermediate tx queues (Jarod Wilson) [1937053]
- mac80211: calculate hash for fq without holding fq->lock in itxq enqueue (Jarod Wilson) [1937053]
- nvme-tcp: fix misuse of __smp_processor_id with preemption enabled (Gopal Tiwari) [1964227]
- powerpc/smp: Cache CPU to chip lookup (Daniel Henrique Barboza) [1934421]
- Revert "powerpc/topology: Update topology_core_cpumask" (Daniel Henrique Barboza) [1934421]
- powerpc/smp: Reintroduce cpu_core_mask (Daniel Henrique Barboza) [1934421]
- scsi: smartpqi: Remove unused functions (Don Brace) [1952154]
- scsi: smartpqi: Fix device pointer variable reference static checker issue (Don Brace) [1952154]
- scsi: smartpqi: Fix blocks_per_row static checker issue (Don Brace) [1952154]
- scsi: smartpqi: Update version to 2.1.8-045 (Don Brace) [1952154]
- scsi: smartpqi: Add new PCI IDs (Don Brace) [1952154]
- scsi: smartpqi: Correct system hangs when resuming from hibernation (Don Brace) [1952154]
- scsi: smartpqi: Update enclosure identifier in sysfs (Don Brace) [1952154]
- scsi: smartpqi: Add additional logging for LUN resets (Don Brace) [1952154]
- scsi: smartpqi: Update SAS initiator_port_protocols and target_port_protocols (Don Brace) [1952154]
- scsi: smartpqi: Add phy ID support for the physical drives (Don Brace) [1952154]
- scsi: smartpqi: Convert snprintf() to scnprintf() (Don Brace) [1952154]
- scsi: smartpqi: Fix driver synchronization issues (Don Brace) [1952154]
- scsi: smartpqi: Update device scan operations (Don Brace) [1952154]
- scsi: smartpqi: Update OFA management (Don Brace) [1952154]
- scsi: smartpqi: Update RAID bypass handling (Don Brace) [1952154]
- scsi: smartpqi: Update suspend/resume and shutdown (Don Brace) [1952154]
- scsi: smartpqi: Synchronize device resets with mutex (Don Brace) [1952154]
- scsi: smartpqi: Update soft reset management for OFA (Don Brace) [1952154]
- scsi: smartpqi: Update event handler (Don Brace) [1952154]
- scsi: smartpqi: Add support for wwid (Don Brace) [1952154]
- scsi: smartpqi: Remove timeouts from internal cmds (Don Brace) [1952154]
- scsi: smartpqi: Disable WRITE SAME for HBA NVMe disks (Don Brace) [1952154]
- scsi: smartpqi: Add host level stream detection enable (Don Brace) [1952154]
- scsi: smartpqi: Add stream detection (Don Brace) [1952154]
- scsi: smartpqi: Align code with oob driver (Don Brace) [1952154]
- scsi: smartpqi: Add support for long firmware version (Don Brace) [1952154]
- scsi: smartpqi: Add support for BMIC sense feature cmd and feature bits (Don Brace) [1952154]
- scsi: smartpqi: Add support for RAID1 writes (Don Brace) [1952154]
- scsi: smartpqi: Add support for RAID5 and RAID6 writes (Don Brace) [1952154]
- scsi: smartpqi: Refactor scatterlist code (Don Brace) [1952154]
- scsi: smartpqi: Refactor aio submission code (Don Brace) [1952154]
- scsi: smartpqi: Add support for new product ids (Don Brace) [1952154]
- scsi: smartpqi: Correct request leakage during reset operations (Don Brace) [1952154]
- scsi: smartpqi: Use host-wide tag space (Don Brace) [1952154]
- smartpqi: Use fallthrough pseudo-keyword (Don Brace) [1952154]
- scsi: smartpqi: Support device deletion via sysfs (Don Brace) [1952154]
- scsi: smartpqi: Use scnprintf() for avoiding potential buffer overflow (Don Brace) [1952154]
- smartpqi: remove ioremap_nocache and devm_ioremap_nocache (Don Brace) [1952154]
- smartpqi: Use sizeof_field() macro (Don Brace) [1952154]
- smartpqi: phase out dma_zalloc_coherent() (Don Brace) [1952154]
- scsi: smartpqi: add support for huawei controllers (Don Brace) [1952154]
- block: only update parent bi_status when bio fail (Ming Lei) [1945457]
- kbuild: trace functions in subdirectories of lib/ (Joe Lawrence) [1942601]
- kbuild: introduce ccflags-remove-y and asflags-remove-y (Joe Lawrence) [1942601]
- redhat/configs: Add CONFIG_AMD_PMC (David Arcari) [1961755]
- platform/x86: amd-pmc: put device on error paths (David Arcari) [1961755]
- platform/x86: amd-pmc: Fix CONFIG_DEBUG_FS check (David Arcari) [1961755]
- platform/x86: amd-pmc: Add AMD platform support for S2Idle (David Arcari) [1961755]
- crypto: DRBG - switch to HMAC SHA512 DRBG as default DRBG (Vladis Dronov) [1956808]
- x86/asm: Annotate movdir64b()'s dst argument with __iomem (Jerry Snitselaar) [1920747]
- x86/asm: Add a missing __iomem annotation in enqcmds() (Jerry Snitselaar) [1920747]

* Wed Jun 02 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-312.el8]
- fm10k: amend removal of MODULE_VERSION (Vladis Dronov) [1955730]
- hv_netvsc: Make netvsc/VF binding check both MAC and serial number (Mohammed Gamal) [1940927]
- hv_netvsc: Add error handling while switching data path (Mohammed Gamal) [1940927]
- netvsc: Update driver to use ethtool_sprintf (Mohammed Gamal) [1940927]
- hv_netvsc: Add a comment clarifying batching logic (Mohammed Gamal) [1940927]
- hv_netvsc: Fix validation in netvsc_linkstatus_callback() (Mohammed Gamal) [1940927]
- hv_netvsc: Restrict configurations on isolated guests (Mohammed Gamal) [1940927]
- hv_netvsc: Load and store the proper (NBL_HASH_INFO) per-packet info (Mohammed Gamal) [1940927]
- hv_netvsc: Allocate the recv_buf buffers after NVSP_MSG1_TYPE_SEND_RECV_BUF (Mohammed Gamal) [1940927]
- hv_netvsc: Reset the RSC count if NVSP_STAT_FAIL in netvsc_receive() (Mohammed Gamal) [1940927]
- hv_netvsc: Copy packets sent by Hyper-V out of the receive buffer (Mohammed Gamal) [1940927]
- net/hyperv: use skb_vlan_tag_*() helpers (Mohammed Gamal) [1940927]
- net/vlan: introduce skb_vlan_tag_get_cfi() helper (Mohammed Gamal) [1940927]
- hv_netvsc: Add (more) validation for untrusted Hyper-V values (Mohammed Gamal) [1940927]
- hv_netvsc: Process NETDEV_GOING_DOWN on VF hot remove (Mohammed Gamal) [1940927]
- hv_netvsc: Wait for completion on request SWITCH_DATA_PATH (Mohammed Gamal) [1940927]
- hv_netvsc: Check VF datapath when sending traffic to VF (Mohammed Gamal) [1940927]
- hv_netvsc: Validate number of allocated sub-channels (Mohammed Gamal) [1940927]
- hv_netvsc: Use vmbus_requestor to generate transaction IDs for VMBus hardening (Mohammed Gamal) [1940927]
- hv_netvsc: Use HV_HYP_PAGE_SIZE for Hyper-V communication (Mohammed Gamal) [1940927]
- scsi: fnic: Use scsi_host_busy_iter() to traverse commands (Ewan D. Milne) [1949250]
- scsi: fnic: Kill 'exclude_id' argument to fnic_cleanup_io() (Ewan D. Milne) [1949250]
- net: vlan: Avoid using BUG() in vlan_proto_idx() (Davide Caratti) [1964456]
- sch_htb: fix null pointer dereference on a null new_q (Ivan Vecera) [1935703]
- sch_htb: Fix offload cleanup in htb_destroy on htb_init failure (Ivan Vecera) [1935703]
- sch_htb: Fix select_queue for non-offload mode (Ivan Vecera) [1935703]
- sch_htb: Stats for offloaded HTB (Ivan Vecera) [1935703]
- sch_htb: Hierarchical QoS hardware offload (Ivan Vecera) [1935703]
- net: sched: Add extack to Qdisc_class_ops.delete (Ivan Vecera) [1935703]
- net: sched: Add multi-queue support to sch_tree_lock (Ivan Vecera) [1935703]
- capabilities: require CAP_SETFCAP to map uid 0 (Alexey Gladkov) [1961202]
- locking/qrwlock: Cleanup queued_write_lock_slowpath() (Waiman Long) [1954361]
- locking/rtmutex: Clean up signal handling in __rt_mutex_slowlock() (Waiman Long) [1954361]
- locking/rtmutex: Restrict the trylock WARN_ON() to debug (Waiman Long) [1954361]
- locking/rtmutex: Fix misleading comment in rt_mutex_postunlock() (Waiman Long) [1954361]
- locking/rtmutex: Consolidate the fast/slowpath invocation (Waiman Long) [1954361]
- locking/rtmutex: Make text section and inlining consistent (Waiman Long) [1954361]
- locking/rtmutex: Move debug functions as inlines into common header (Waiman Long) [1954361]
- locking/rtmutex: Decrapify __rt_mutex_init() (Waiman Long) [1954361]
- locking/rtmutex: Remove pointless CONFIG_RT_MUTEXES=n stubs (Waiman Long) [1954361]
- locking/rtmutex: Inline chainwalk depth check (Waiman Long) [1954361]
- locking/rtmutex: Move rt_mutex_debug_task_free() to rtmutex.c (Waiman Long) [1954361]
- locking/rtmutex: Remove empty and unused debug stubs (Waiman Long) [1954361]
- locking/rtmutex: Consolidate rt_mutex_init() (Waiman Long) [1954361]
- locking/rtmutex: Remove output from deadlock detector (Waiman Long) [1954361]
- locking/rtmutex: Remove rtmutex deadlock tester leftovers (Waiman Long) [1954361]
- locking/rtmutex: Remove rt_mutex_timed_lock() (Waiman Long) [1954361]
- kernel: delete repeated words in comments (Waiman Long) [1954361]
- rbtree, rtmutex: Use rb_add_cached() (Waiman Long) [1954361]
- rbtree: Add generic add and find helpers (Waiman Long) [1954361]
- locking/rtmutex: Remove unused rt_mutex_cmpxchg_relaxed() (Waiman Long) [1954361]
- lib/rbtree: avoid generating code twice for the cached versions (Waiman Long) [1954361]
- locking/rtmutex: Fix the preprocessor logic with normal #ifdef #else #endif (Waiman Long) [1954361]
- kernel/futex: Explicitly document pi_lock for pi_state owner fixup (Waiman Long) [1954361]
- kernel/futex: Move hb unlock out of unqueue_me_pi() (Waiman Long) [1954361]
- kernel/futex: Make futex_wait_requeue_pi() only call fixup_owner() (Waiman Long) [1954361]
- kernel/futex: Kill rt_mutex_next_owner() (Waiman Long) [1954361]
- futex: Remove unused empty compat_exit_robust_list() (Waiman Long) [1954361]
- futex: Handle transient "ownerless" rtmutex state correctly (Waiman Long) [1954361]
- futex: Convert to use the preferred 'fallthrough' macro (Waiman Long) [1954361]
- futex: get rid of a kernel-docs build warning (Waiman Long) [1954361]
- futex: arch_futex_atomic_op_inuser() calling conventions change (Waiman Long) [1954361]
- s390: Use arch_local_irq_{save,restore}() in early boot code (Waiman Long) [1954361]
- lockdep: Add a missing initialization hint to the "INFO: Trying to register non-static key" message (Waiman Long) [1954361]
- locking: Fix typos in comments (Waiman Long) [1954361]
- locking/lockdep: Update the comment for __lock_release() (Waiman Long) [1954361]
- lockdep: Allow tuning tracing capacity constants. (Waiman Long) [1954361]
- lockdep: Address clang -Wformat warning printing for hd (Waiman Long) [1954361]
- lockdep: Add lockdep lock state defines (Waiman Long) [1954361]
- lockdep: Add lockdep_assert_not_held() (Waiman Long) [1954361]
- lockdep: Noinstr annotate warn_bogus_irq_restore() (Waiman Long) [1954361]
- locking/lockdep: Avoid unmatched unlock (Waiman Long) [1954361]
- locking/rwsem: Remove empty rwsem.h (Waiman Long) [1954361]
- lockdep: report broken irq restoration (Waiman Long) [1954361]
- locking/lockdep: Avoid noinstr warning for DEBUG_LOCKDEP (Waiman Long) [1954361]
- locking/lockdep: Exclude local_lock_t from IRQ inversions (Waiman Long) [1954361]
- locking/lockdep: Clean up check_redundant() a bit (Waiman Long) [1954361]
- locking/lockdep: Add a skip() function to __bfs() (Waiman Long) [1954361]
- locking/lockdep: Mark local_lock_t (Waiman Long) [1954361]
- lockdep: Put graph lock/unlock under lock_recursion protection (Waiman Long) [1954361]
- locking/rtmutex: Add missing kernel-doc markup (Waiman Long) [1954361]
- lockdep: Avoid to modify chain keys in validate_chain() (Waiman Long) [1954361]
- lockdep: Fix nr_unused_locks accounting (Waiman Long) [1954361]
- lockdep: Optimize the memory usage of circular queue (Waiman Long) [1954361]
- lockdep: Take read/write status in consideration when generate chainkey (Waiman Long) [1954361]
- lockdep/selftest: Add a R-L/L-W test case specific to chain cache behavior (Waiman Long) [1954361]
- lockdep: Add recursive read locks into dependency graph (Waiman Long) [1954361]
- lockdep: Fix recursive read lock related safe->unsafe detection (Waiman Long) [1954361]
- lockdep: Adjust check_redundant() for recursive read change (Waiman Long) [1954361]
- lockdep: Support deadlock detection for recursive read locks in check_noncircular() (Waiman Long) [1954361]
- lockdep: Make __bfs(.match) return bool (Waiman Long) [1954361]
- lockdep: Extend __bfs() to work with multiple types of dependencies (Waiman Long) [1954361]
- lockdep: Introduce lock_list::dep (Waiman Long) [1954361]
- lockdep: Reduce the size of lock_list::distance (Waiman Long) [1954361]
- lockdep: Make __bfs() visit every dependency until a match (Waiman Long) [1954361]
- lockdep: Demagic the return value of BFS (Waiman Long) [1954361]
- lockdep/Documention: Recursive read lock detection reasoning (Waiman Long) [1954361]
- locking: More accurate annotations for read_lock() (Waiman Long) [1954361]
- Documentation/locking/locktypes: Fix local_locks documentation (Waiman Long) [1954361]
- treewide: Remove uninitialized_var() usage (Waiman Long) [1954361]
- lockdep: Use this_cpu_ptr instead of get_cpu_var stats (Waiman Long) [1954361]
- KVM: arm/arm64: Fix KVM_VGIC_V3_ADDR_TYPE_REDIST read (Gavin Shan) [1939323]
- KVM: arm64: Don't advertise FEAT_SPE to guests (Gavin Shan) [1939323]
- KVM: arm64: Don't print warning when trapping SPE registers (Gavin Shan) [1939323]
- KVM: arm64: Fully zero the vcpu state on reset (Gavin Shan) [1939323]
- KVM: arm64: Clarify vcpu reset behaviour (Gavin Shan) [1939323]
- Documentation: KVM: Document KVM_GUESTDBG_USE_HW control flag for arm64 (Gavin Shan) [1939323]
- KVM: arm64: Initialize VCPU mdcr_el2 before loading it (Gavin Shan) [1939323]
- KVM: arm64: Handle access to TRFCR_EL1 (Gavin Shan) [1939323]
- arm64: Add TRFCR_ELx definitions (Gavin Shan) [1939323]
- KVM: arm64: Unify trap handlers injecting an UNDEF (Gavin Shan) [1939323]
- KVM: arm64: Use find_vma_intersection() (Gavin Shan) [1939323]
- KVM: arm64: Hide kvm_mmu_wp_memory_region() (Gavin Shan) [1939323]
- KVM: selftests: vgic_init kvm selftests fixup (Gavin Shan) [1939323]
- KVM: selftests: aarch64/vgic-v3 init sequence tests (Gavin Shan) [1939323]
- KVM: arm64: vgic-v3: Expose GICR_TYPER.Last for userspace (Gavin Shan) [1939323]
- kvm: arm64: vgic-v3: Introduce vgic_v3_free_redist_region() (Gavin Shan) [1939323]
- KVM: arm64: Simplify argument passing to vgic_uaccess_[read|write] (Gavin Shan) [1939323]
- docs: kvm: devices/arm-vgic-v3: enhance KVM_DEV_ARM_VGIC_CTRL_INIT doc (Gavin Shan) [1939323]
- KVM: arm/arm64: vgic: Reset base address on kvm_vgic_dist_destroy() (Gavin Shan) [1939323]
- KVM: arm64: vgic-v3: Fix error handling in vgic_v3_set_redist_base() (Gavin Shan) [1939323]
- KVM: arm64: Fix KVM_VGIC_V3_ADDR_TYPE_REDIST_REGION read (Gavin Shan) [1939323]
- KVM: arm64: vgic-v3: Fix some error codes when setting RDIST base (Gavin Shan) [1939323]
- KVM: arm64: Disable guest access to trace filter controls (Gavin Shan) [1939323]
- KVM: arm64: Fix CPU interface MMIO compatibility detection (Gavin Shan) [1939323]
- KVM: arm64: Hide system instruction access to Trace registers (Gavin Shan) [1939323]
- KVM: arm64: Fix exclusive limit for IPA size (Gavin Shan) [1939323]
- KVM: arm64: Ensure I-cache isolation between vcpus of a same VM (Gavin Shan) [1939323]
- KVM: arm64: nvhe: Save the SPE context early (Gavin Shan) [1939323]
- KVM: arm64: Correct spelling of DBGDIDR register (Gavin Shan) [1939323]
- KVM: arm64: Fix AArch32 PMUv3 capping (Gavin Shan) [1939323]
- KVM: arm64: Fix missing RES1 in emulation of DBGBIDR (Gavin Shan) [1939323]
- KVM: arm64: Remove spurious semicolon in reg_to_encoding() (Gavin Shan) [1939323]
- KVM: arm64: Fix hyp_cpu_pm_{init,exit} __init annotation (Gavin Shan) [1939323]
- KVM: arm64: Workaround firmware wrongly advertising GICv2-on-v3 compatibility (Gavin Shan) [1939323]
- KVM: arm64: Rename __vgic_v3_get_ich_vtr_el2() to __vgic_v3_get_gic_config() (Gavin Shan) [1939323]
- KVM: arm64: Some fixes of PV-time interface document (Gavin Shan) [1939323]
- KVM: arm64: CSSELR_EL1 max is 13 (Gavin Shan) [1939323]
- idr test suite: Improve reporting from idr_find_test_1 (Chris von Recklinghausen) [1946304]
- idr test suite: Create anchor before launching throbber (Chris von Recklinghausen) [1946304]
- idr test suite: Take RCU read lock in idr_find_test_1 (Chris von Recklinghausen) [1946304]
- radix tree test suite: Register the main thread with the RCU library (Chris von Recklinghausen) [1946304]
- radix tree test suite: Fix compilation (Chris von Recklinghausen) [1946304]
- XArray: Add xa_limit_16b (Chris von Recklinghausen) [1946304]
- XArray: Fix splitting to non-zero orders (Chris von Recklinghausen) [1946304]
- XArray: Fix split documentation (Chris von Recklinghausen) [1946304]
- PCI/P2PDMA: Drop double zeroing for sg_init_table() (Myron Stowe) [1955693]
- PCI: Simplify bool comparisons (Myron Stowe) [1955693]
- PCI: endpoint: Use "NULL" instead of "0" as a NULL pointer (Myron Stowe) [1955693]
- PCI: Simplify pci_dev_reset_slot_function() (Myron Stowe) [1955693]
- PCI: Update mmap-related #ifdef comments (Myron Stowe) [1955693]
- PCI/LINK: Print IRQ number used by port (Myron Stowe) [1955693]
- PCI/IOV: Simplify pci-pf-stub with module_pci_driver() (Myron Stowe) [1955693]
- PCI: Use scnprintf(), not snprintf(), in sysfs "show" functions (Myron Stowe) [1955693]
- x86/PCI: Fix intel_mid_pci.c build error when ACPI is not enabled (Myron Stowe) [1955693]
- PCI: Remove unnecessary header includes (Myron Stowe) [1955693]
- PCI/PM: Revert "PCI/PM: Apply D2 delay as milliseconds, not microseconds" (Myron Stowe) [1955693]
- PCI/PM: Remove unused PCI_PM_BUS_WAIT (Myron Stowe) [1955693]
- PCI: shpchp: Remove unused 'rc' assignment (Myron Stowe) [1955693]
- PCI: pciehp: Reduce noisiness on hot removal (Myron Stowe) [1955693 1812902]
- PCI: rpadlpar: Use for_each_child_of_node() and for_each_node_by_name() (Myron Stowe) [1955693]
- PCI: Add Kconfig options for MPS/MRRS strategy (Myron Stowe) [1955693]
- PCI: Add schedule point in pci_read_config() (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct pcie_link_state.l1ss (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.l1ss_cap (Myron Stowe) [1955693]
- PCI/ASPM: Pass L1SS Capabilities value, not struct aspm_register_info (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.l1ss_ctl1 (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.l1ss_ctl2 (unused) (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.l1ss_cap_ptr (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.latency_encoding (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.enabled (Myron Stowe) [1955693]
- PCI/ASPM: Remove struct aspm_register_info.support (Myron Stowe) [1955693]
- PCI/ASPM: Use 'parent' and 'child' for readability (Myron Stowe) [1955693]
- PCI/ASPM: Move LTR path check to where it's used (Myron Stowe) [1955693]
- PCI/ASPM: Move pci_clear_and_set_dword() earlier (Myron Stowe) [1955693]
- PCI/ACS: Enable Translation Blocking for external devices (Myron Stowe) [1955693]
- scsi: qedi: Remove redundant assignment to variable err (Nilesh Javali) [1920855]
- scsi: qedi: Fix error return code of qedi_alloc_global_queues() (Nilesh Javali) [1920855]
- scsi: qedi: Fix missing destroy_workqueue() on error in __qedi_probe (Nilesh Javali) [1920855]
- scsi: qedf: Simplify bool comparison (Nilesh Javali) [1921608]
- bpf, sockmap: Fix incorrect fwd_alloc accounting (Yauheni Kaliuta) [1874006]
- bpf: Local storage helpers should check nullness of owner ptr passed (Yauheni Kaliuta) [1874006]
- bpf, inode_storage: Put file handler if no storage was found (Yauheni Kaliuta) [1874006]
- kbuild: explicitly specify the build id style (Yauheni Kaliuta) [1874006]
- bpf: Reject too big ctx_size_in for raw_tp test run (Yauheni Kaliuta) [1874006]
- bpf: Fix enum names for bpf_this_cpu_ptr() and bpf_per_cpu_ptr() helpers (Yauheni Kaliuta) [1874006]
- bpf: Don't rely on GCC __attribute__((optimize)) to disable GCSE (Jiri Benc) [1874006]
- bpf: Fix tests for local_storage (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix "dubious pointer arithmetic" test (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix array access with signed variable test (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add test for signed 32-bit bound check bug (Yauheni Kaliuta) [1874006]
- bpf: Fix propagation of 32-bit signed bounds from 64-bit bounds. (Yauheni Kaliuta) [1874006]
- lwt_bpf: Replace preempt_disable() with migrate_disable() (Yauheni Kaliuta) [1874006]
- lwt: Disable BH too in run_lwt_bpf() (Yauheni Kaliuta) [1874006]
- selftests/bpf: Drain ringbuf samples at the end of test (Yauheni Kaliuta) [1874006]
- libbpf: Fix ring_buffer__poll() to return number of consumed samples (Yauheni Kaliuta) [1874006]
- bpf: Add MAINTAINERS entry for BPF LSM (Yauheni Kaliuta) [1874006]
- bpftool: Fix error return value in build_btf_type_table (Yauheni Kaliuta) [1874006]
- fail_function: Remove a redundant mutex unlock (Yauheni Kaliuta) [1874006]
- selftest/bpf: Test bpf_probe_read_user_str() strips trailing bytes after NUL (Yauheni Kaliuta) [1874006]
- lib/strncpy_from_user.c: Mask out bytes after NUL terminator. (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Avoid failures from skb_to_sgvec when skb has frag_list (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Handle memory acct if skb_verdict prog redirects to self (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Avoid returning unneeded EAGAIN when redirecting to self (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Use truesize with sk_rmem_schedule() (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Ensure SO_RCVBUF memory is observed on ingress redirect (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Fix partial copy_page_to_iter so progress can still be made (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix error return code in run_getsockopt_test() (Yauheni Kaliuta) [1874006]
- bpf: Relax return code check for subprograms (Yauheni Kaliuta) [1874006]
- tools, bpftool: Add missing close before bpftool net attach exit (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix unused attribute usage in subprogs_unused test (Yauheni Kaliuta) [1874006]
- bpf: Fix unsigned 'datasec_id' compared with zero in check_pseudo_btf_id (Yauheni Kaliuta) [1874006]
- bpf: Fix passing zero to PTR_ERR() in bpf_btf_printf_prepare (Yauheni Kaliuta) [1874006]
- libbpf: Don't attempt to load unused subprog as an entry-point BPF program (Yauheni Kaliuta) [1874006]
- bpf: Update verification logic for LSM programs (Yauheni Kaliuta) [1874006]
- bpf: Zero-fill re-used per-cpu map element (Yauheni Kaliuta) [1874006]
- bpf: BPF_PRELOAD depends on BPF_SYSCALL (Yauheni Kaliuta) [1874006]
- libbpf: Fix possible use after free in xsk_socket__delete (Yauheni Kaliuta) [1874006]
- libbpf: Fix null dereference in xsk_socket__delete (Yauheni Kaliuta) [1874006]
- libbpf, hashmap: Fix undefined behavior in hash_bits (Yauheni Kaliuta) [1874006]
- tools, bpftool: Remove two unused variables. (Yauheni Kaliuta) [1874006]
- tools, bpftool: Avoid array index warnings. (Yauheni Kaliuta) [1874006]
- bpf: Add struct bpf_redir_neigh forward declaration to BPF helper defs (Yauheni Kaliuta) [1874006]
- bpf: Fix -Wshadow warnings (Yauheni Kaliuta) [1874006]
- bpf, libbpf: Guard bpf inline asm from bpf_tail_call_static (Yauheni Kaliuta) [1874006]
- bpf: selftest: Ensure the return value of the bpf_per_cpu_ptr() must be checked (Yauheni Kaliuta) [1874006]
- bpf: selftest: Ensure the return value of bpf_skc_to helpers must be checked (Yauheni Kaliuta) [1874006]
- bpf: Remove unneeded break (Yauheni Kaliuta) [1874006]
- net, sockmap: Don't call bpf_prog_put() on NULL pointer (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Add locking annotations to iterator (Yauheni Kaliuta) [1874006]
- bpf: Fix register equivalence tracking. (Yauheni Kaliuta) [1874006]
- bpf, selftests: Add three new sockmap tests for verdict only programs (Yauheni Kaliuta) [1874006]
- bpf, selftests: Add option to test_sockmap to omit adding parser program (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Allow skipping sk_skb parser program (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Check skb_verdict and skb_parser programs explicitly (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Add memory accounting so skbs on ingress lists are visible (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Remove skb_orphan and let normal skb_kfree do cleanup (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Remove dropped data on errors in redirect case (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Remove skb_set_owner_w wmem will be taken later from sendpage (Yauheni Kaliuta) [1874006]
- bpf, sockmap: On receive programs try to fast track SK_PASS ingress (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Skb verdict SK_PASS to self already checked rmem limits (Yauheni Kaliuta) [1874006]
- bpf: Migrate from patchwork.ozlabs.org to patchwork.kernel.org. (Yauheni Kaliuta) [1874006]
- samples: bpf: Refactor XDP kern program maps with BTF-defined map (Yauheni Kaliuta) [1874006]
- samples: bpf: Replace attach_tracepoint() to attach() in xdp_redirect_cpu (Yauheni Kaliuta) [1874006]
- samples: bpf: Refactor xdp_monitor with libbpf (Yauheni Kaliuta) [1874006]
- bpf, selftests: Add test for different array inner map size (Yauheni Kaliuta) [1874006]
- bpf: Allow for map-in-map with dynamic inner array map entries (Yauheni Kaliuta) [1874006]
- selftests/bpf: Asm tests for the verifier regalloc tracking. (Yauheni Kaliuta) [1874006]
- bpf: Fix selftest compilation on clang 11 (Yauheni Kaliuta) [1874006]
- selftest/bpf: Fix profiler test using CO-RE relocation for enums (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add profiler test (Yauheni Kaliuta) [1874006]
- bpf: Track spill/fill of bounded scalars. (Yauheni Kaliuta) [1874006]
- bpf: Propagate scalar ranges through register assignments. (Yauheni Kaliuta) [1874006]
- bpf: Add tcp_notsent_lowat bpf setsockopt (Yauheni Kaliuta) [1874006]
- selftests/bpf: Validate libbpf's auto-sizing of LD/ST/STX instructions (Yauheni Kaliuta) [1874006]
- libbpf: Allow specifying both ELF and raw BTF for CO-RE BTF override (Yauheni Kaliuta) [1874006]
- libbpf: Support safe subset of load/store instruction resizing with CO-RE (Yauheni Kaliuta) [1874006]
- libbpf: Skip CO-RE relocations for not loaded BPF programs (Yauheni Kaliuta) [1874006]
- libbpf: Fix compatibility problem in xsk_socket__create (Yauheni Kaliuta) [1874006]
- bpf: Fix typo in uapi/linux/bpf.h (Yauheni Kaliuta) [1874006]
- bpf: Fix build failure for kernel/trace/bpf_trace.c with CONFIG_NET=n (Yauheni Kaliuta) [1874006]
- kernel/bpf/verifier: Fix build when NET is not enabled (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix test_verifier after introducing resolve_pseudo_ldimm64 (Yauheni Kaliuta) [1874006]
- samples: bpf: Driver interrupt statistics in xdpsock (Yauheni Kaliuta) [1874006]
- samples: bpf: Count syscalls in xdpsock (Yauheni Kaliuta) [1874006]
- samples: bpf: Split xdpsock stats into new struct (Yauheni Kaliuta) [1874006]
- samples/bpf: Fix a compilation error with fallthrough marking (Yauheni Kaliuta) [1874006]
- samples/bpf: Change Makefile to cope with latest llvm (Yauheni Kaliuta) [1874006]
- bpf, libbpf: Use valid btf in bpf_program__set_attach_target (Yauheni Kaliuta) [1874006]
- selftest/bpf: Test pinning map with reused map fd (Yauheni Kaliuta) [1874006]
- libbpf: Check if pin_path was set even map fd exist (Yauheni Kaliuta) [1874006]
- libbpf: Close map fd if init map slots failed (Yauheni Kaliuta) [1874006]
- bpf: Use raw_spin_trylock() for pcpu_freelist_push/pop in NMI (Yauheni Kaliuta) [1874006]
- bpf, verifier: Use fallthrough pseudo-keyword (Yauheni Kaliuta) [1874006]
- bpf: Deref map in BPF_PROG_BIND_MAP when it's already used (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Update selftests to use skb_adjust_room (Yauheni Kaliuta) [1874006]
- bpf, sockmap: Add skb_adjust_room to pop bytes off ingress payload (Yauheni Kaliuta) [1874006]
- bpf/selftests: Test for bpf_per_cpu_ptr() and bpf_this_cpu_ptr() (Yauheni Kaliuta) [1874006]
- bpf: Introducte bpf_this_cpu_ptr() (Yauheni Kaliuta) [1874006]
- bpf: Introduce bpf_per_cpu_ptr() (Yauheni Kaliuta) [1874006]
- selftests/bpf: Ksyms_btf to test typed ksyms (Yauheni Kaliuta) [1874006]
- bpf/libbpf: BTF support for typed ksyms (Yauheni Kaliuta) [1874006]
- bpf: Introduce pseudo_btf_id (Yauheni Kaliuta) [1874006]
- selftests/bpf: Properly initialize linfo in sockmap_basic (Yauheni Kaliuta) [1874006]
- selftests/bpf: Initialize duration in xdp_noinline.c (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add tests for BPF_F_PRESERVE_ELEMS (Yauheni Kaliuta) [1874006]
- bpf: Introduce BPF_F_PRESERVE_ELEMS for perf event array (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix alignment of .BTF_ids (Yauheni Kaliuta) [1874006]
- selftests/bpf: Test "incremental" btf_dump in C format (Yauheni Kaliuta) [1874006]
- libbpf: Make btf_dump work with modifiable BTF (Yauheni Kaliuta) [1874006]
- bpf, selftests: Use bpf_tail_call_static where appropriate (Yauheni Kaliuta) [1874006]
- bpf, libbpf: Add bpf_tail_call_static helper for bpf programs (Yauheni Kaliuta) [1874006]
- bpf, net: Rework cookie generator as per-cpu one (Yauheni Kaliuta) [1874006]
- bpf: Add classid helper only based on skb->sk (Yauheni Kaliuta) [1874006]
- bpf: fix raw_tp test run in preempt kernel (Yauheni Kaliuta) [1874006]
- libbpf: Compile in PIC mode only for shared library case (Yauheni Kaliuta) [1874006]
- libbpf: Compile libbpf under -O2 level by default and catch extra warnings (Yauheni Kaliuta) [1874006]
- bpf: x64: Do not emit sub/add 0, rsp when !stack_depth (Yauheni Kaliuta) [1874006]
- bpf, x64: Drop "pop rcx" instruction on BPF JIT epilogue (Yauheni Kaliuta) [1874006]
- bpf, selftests: Fix warning in snprintf_btf where system() call unchecked (Yauheni Kaliuta) [1874006]
- selftests/bpf: Test BTF's handling of endianness (Yauheni Kaliuta) [1874006]
- selftests/bpf: Move and extend ASSERT_xxx() testing macros (Yauheni Kaliuta) [1874006]
- selftests: Make sure all 'skel' variables are declared static (Yauheni Kaliuta) [1874006]
- selftests/bpf_iter: Don't fail test due to missing __builtin_btf_type_id (Yauheni Kaliuta) [1874006]
- bpf/preload: Make sure Makefile cleans up after itself, and add .gitignore (Yauheni Kaliuta) [1874006]
- selftests/bpf: Ensure snprintf_btf/bpf_iter tests compatibility with old vmlinux.h (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix unused-result warning in snprintf_btf.c (Yauheni Kaliuta) [1874006]
- bpf, selftests: Fix cast to smaller integer type 'int' warning in raw_tp (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add test for bpf_seq_printf_btf helper (Yauheni Kaliuta) [1874006]
- bpf: Add bpf_seq_printf_btf helper (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix overflow tests to reflect iter size increase (Yauheni Kaliuta) [1874006]
- bpf: Bump iter seq size to support BTF representation of large data structures (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add bpf_snprintf_btf helper tests (Yauheni Kaliuta) [1874006]
- bpf: Add bpf_snprintf_btf helper (Yauheni Kaliuta) [1874006]
- bpf: Move to generic BTF show support, apply it to seq files/strings (Yauheni Kaliuta) [1874006]
- bpf: Provide function to get vmlinux BTF information (Yauheni Kaliuta) [1874006]
- selftest: bpf: Test copying a sockmap and sockhash (Yauheni Kaliuta) [1874006]
- selftests: bpf: Remove shared header from sockmap iter test (Yauheni Kaliuta) [1874006]
- selftests: bpf: Add helper to compare socket cookies (Yauheni Kaliuta) [1874006]
- bpf: sockmap: Enable map_update_elem from bpf_iter (Yauheni Kaliuta) [1874006]
- bpf, cpumap: Remove rcpu pointer from cpu_map_build_skb signature (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add raw_tp_test_run (Yauheni Kaliuta) [1874006]
- libbpf: Support test run of raw tracepoint programs (Yauheni Kaliuta) [1874006]
- bpf: Enable BPF_PROG_TEST_RUN for raw_tracepoint (Yauheni Kaliuta) [1874006]
- bpf: Add comment to document BTF type PTR_TO_BTF_ID_OR_NULL (Yauheni Kaliuta) [1874006]
- bpf: Add AND verifier test case where 32bit and 64bit bounds differ (Yauheni Kaliuta) [1874006]
- bpf, verifier: Remove redundant var_off.value ops in scalar known reg cases (Yauheni Kaliuta) [1874006]
- bpf: selftest: Add test_btf_skc_cls_ingress (Yauheni Kaliuta) [1874006]
- bpf: selftest: Remove enum tcp_ca_state from bpf_tcp_helpers.h (Yauheni Kaliuta) [1874006]
- bpf: selftest: Use bpf_skc_to_tcp_sock() in the sock_fields test (Yauheni Kaliuta) [1874006]
- bpf: selftest: Use network_helpers in the sock_fields test (Yauheni Kaliuta) [1874006]
- bpf: selftest: Adapt sock_fields test to use skel and global variables (Yauheni Kaliuta) [1874006]
- bpf: selftest: Move sock_fields test into test_progs (Yauheni Kaliuta) [1874006]
- bpf: selftest: Add ref_tracking verifier test for bpf_skc casting (Yauheni Kaliuta) [1874006]
- bpf: Change bpf_sk_assign to accept ARG_PTR_TO_BTF_ID_SOCK_COMMON (Yauheni Kaliuta) [1874006]
- bpf: Change bpf_tcp_*_syncookie to accept ARG_PTR_TO_BTF_ID_SOCK_COMMON (Yauheni Kaliuta) [1874006]
- bpf: Change bpf_sk_storage_*() to accept ARG_PTR_TO_BTF_ID_SOCK_COMMON (Yauheni Kaliuta) [1874006]
- bpf: Change bpf_sk_release and bpf_sk_*cgroup_id to accept ARG_PTR_TO_BTF_ID_SOCK_COMMON (Yauheni Kaliuta) [1874006]
- bpf: Enable bpf_skc_to_* sock casting helper to networking prog type (Yauheni Kaliuta) [1874006]
- bpf: Move the PTR_TO_BTF_ID check to check_reg_type() (Yauheni Kaliuta) [1874006]
- Revert "bpf: Fix potential call bpf_link_free() in atomic context" (Yauheni Kaliuta) [1874006]
- tools resolve_btfids: Always force HOSTARCH (Yauheni Kaliuta) [1874006]
- bpf: Check CONFIG_BPF option for resolve_btfids (Yauheni Kaliuta) [1874006]
- bpf: Explicitly size compatible_reg_types (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix stat probe in d_path test (Yauheni Kaliuta) [1874006]
- bpf: Using rcu_read_lock for bpf_sk_storage_map iterator (Yauheni Kaliuta) [1874006]
- bpf: Use a table to drive helper arg type checks (Yauheni Kaliuta) [1874006]
- bpf: Hoist type checking for nullable arg types (Yauheni Kaliuta) [1874006]
- bpf: Check ARG_PTR_TO_SPINLOCK register type in check_func_arg (Yauheni Kaliuta) [1874006]
- bpf: Set meta->raw_mode for pointers close to use (Yauheni Kaliuta) [1874006]
- bpf: Make context access check generic (Yauheni Kaliuta) [1874006]
- bpf: Make reference tracking generic (Yauheni Kaliuta) [1874006]
- bpf: Make BTF pointer type checking generic (Yauheni Kaliuta) [1874006]
- bpf: Allow specifying a BTF ID per argument in function protos (Yauheni Kaliuta) [1874006]
- btf: Add BTF_ID_LIST_SINGLE macro (Yauheni Kaliuta) [1874006]
- bpf: Check scalar or invalid register in check_helper_mem_access (Yauheni Kaliuta) [1874006]
- btf: Make btf_set_contains take a const pointer (Yauheni Kaliuta) [1874006]
- bpf: Fix potential call bpf_link_free() in atomic context (Yauheni Kaliuta) [1874006]
- bpf: Use hlist_add_head_rcu when linking to local_storage (Yauheni Kaliuta) [1874006]
- samples/bpf: Fix test_map_in_map on s390 (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix endianness issue in test_sockopt_sk (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix endianness issue in sk_assign (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add tailcall_bpf2bpf tests (Yauheni Kaliuta) [1874006]
- bpf: Add abnormal return checks. (Yauheni Kaliuta) [1874006]
- bpf: allow for tailcalls in BPF subprograms for x64 JIT (Yauheni Kaliuta) [1874006]
- bpf, x64: rework pro/epilogue and tailcall handling in JIT (Yauheni Kaliuta) [1874006]
- bpf: Limit caller's stack depth 256 for subprogs with tailcalls (Yauheni Kaliuta) [1874006]
- bpf: rename poke descriptor's 'ip' member to 'tailcall_target' (Yauheni Kaliuta) [1874006]
- bpf: propagate poke descriptors to subprograms (Yauheni Kaliuta) [1874006]
- bpf, x64: use rcx instead of rax for tail call retpolines (Yauheni Kaliuta) [1874006]
- selftests/bpf: Merge most of test_btf into test_progs (Yauheni Kaliuta) [1874006]
- selftests/bpf: Test load and dump metadata with btftool and skel (Yauheni Kaliuta) [1874006]
- bpftool: Support dumping metadata (Yauheni Kaliuta) [1874006]
- libbpf: Add BPF_PROG_BIND_MAP syscall and use it on .rodata section (Yauheni Kaliuta) [1874006]
- bpf: Add BPF_PROG_BIND_MAP syscall (Yauheni Kaliuta) [1874006]
- bpf: Mutex protect used_maps array and count (Yauheni Kaliuta) [1874006]
- libbpf: Fix a compilation error with xsk.c for ubuntu 16.04 (Yauheni Kaliuta) [1874006]
- samples/bpf: Add quiet option to xdpsock (Yauheni Kaliuta) [1874006]
- samples: bpf: Add an option for printing extra statistics in xdpsock (Yauheni Kaliuta) [1874006]
- samples/bpf: Fix possible deadlock in xdpsock (Yauheni Kaliuta) [1874006]
- samples/bpf: Fix one packet sending in xdpsock (Yauheni Kaliuta) [1874006]
- s390/bpf: Fix multiple tail calls (Yauheni Kaliuta) [1874006]
- tcp: Simplify tcp_set_congestion_control() load=false case (Yauheni Kaliuta) [1874006]
- tcp: simplify _bpf_setsockopt(): Remove flags argument (Yauheni Kaliuta) [1874006]
- tcp: simplify tcp_set_congestion_control(): Always reinitialize (Yauheni Kaliuta) [1874006]
- tcp: Simplify EBPF TCP_CONGESTION to always init CC (Yauheni Kaliuta) [1874006]
- bpftool: Fix build failure (Yauheni Kaliuta) [1874006]
- tools: bpftool: Automate generation for "SEE ALSO" sections in man pages (Yauheni Kaliuta) [1874006]
- bpf: Fix comment for helper bpf_current_task_under_cgroup() (Yauheni Kaliuta) [1874006]
- selftests/bpf: Define string const as global for test_sysctl_prog.c (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix test_ksyms on non-SMP kernels (Yauheni Kaliuta) [1874006]
- tools: bpftool: Add "inner_map" to "bpftool map create" outer maps (Yauheni Kaliuta) [1874006]
- tools: bpftool: Keep errors for map-of-map dumps if distinct from ENOENT (Yauheni Kaliuta) [1874006]
- tools: bpftool: Clean up function to dump map entry (Yauheni Kaliuta) [1874006]
- selftests: bpf: Test iterating a sockmap (Yauheni Kaliuta) [1874006]
- net: Allow iterating sockmap and sockhash (Yauheni Kaliuta) [1874006]
- net: sockmap: Remove unnecessary sk_fullsock checks (Yauheni Kaliuta) [1874006]
- tools: bpftool: Include common options from separate file (Yauheni Kaliuta) [1874006]
- tools: bpftool: Print optional built-in features along with version (Yauheni Kaliuta) [1874006]
- selftests, bpftool: Add bpftool (and eBPF helpers) documentation build (Yauheni Kaliuta) [1874006]
- tools: bpftool: Log info-level messages when building bpftool man pages (Yauheni Kaliuta) [1874006]
- bpf: Remove duplicate headers (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix test_sysctl_loop{1, 2} failure due to clang change (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add test for map_ptr arithmetic (Yauheni Kaliuta) [1874006]
- bpf: Permit map_ptr arithmetic with opcode add and offset 0 (Yauheni Kaliuta) [1874006]
- tools, bpf: Synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1874006]
- bpf: Fix formatting in documentation for BPF helpers (Yauheni Kaliuta) [1874006]
- tools: bpftool: Fix formatting in bpftool-link documentation (Yauheni Kaliuta) [1874006]
- samples, bpf: Add xsk_fwd test file to .gitignore (Yauheni Kaliuta) [1874006]
- samples, bpf: Replace bpf_program__title() with bpf_program__section_name() (Yauheni Kaliuta) [1874006]
- libbpf: Fix potential multiplication overflow (Yauheni Kaliuta) [1874006]
- libbpf: Fix another __u64 cast in printf (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix check in global_data_init. (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add __noinline variant of cls_redirect selftest (Yauheni Kaliuta) [1874006]
- selftests/bpf: Modernize xdp_noinline test w/ skeleton and __noinline (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add subprogs to pyperf, strobemeta, and l4lb_noinline tests (Yauheni Kaliuta) [1874006]
- tools/bpftool: Replace bpf_program__title() with bpf_program__section_name() (Yauheni Kaliuta) [1874006]
- selftests/bpf: Don't use deprecated libbpf APIs (Yauheni Kaliuta) [1874006]
- libbpf: Deprecate notion of BPF program "title" in favor of "section name" (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add selftest for multi-prog sections and bpf-to-bpf calls (Yauheni Kaliuta) [1874006]
- libbpf: Add multi-prog section support for struct_ops (Yauheni Kaliuta) [1874006]
- libbpf: Implement generalized .BTF.ext func/line info adjustment (Yauheni Kaliuta) [1874006]
- libbpf: Make RELO_CALL work for multi-prog sections and sub-program calls (Yauheni Kaliuta) [1874006]
- libbpf: Support CO-RE relocations for multi-prog sections (Yauheni Kaliuta) [1874006]
- libbpf: Parse multi-function sections into multiple BPF programs (Yauheni Kaliuta) [1874006]
- libbpf: Ensure ELF symbols table is found before further ELF processing (Yauheni Kaliuta) [1874006]
- selftests/bpf: Test task_file iterator without visiting pthreads (Yauheni Kaliuta) [1874006]
- bpf: Avoid iterating duplicated files for task_file iterator (Yauheni Kaliuta) [1874006]
- bpf: {cpu,dev}map: Change various functions return type from int to void (Yauheni Kaliuta) [1874006]
- module: Fix up module_notifier return values (Yauheni Kaliuta) [1874006]
- bpf: Remove bpf_lsm_file_mprotect from sleepable list. (Yauheni Kaliuta) [1874006]
- samples/bpf: Fix to xdpsock to avoid recycling frames (Yauheni Kaliuta) [1874006]
- samples/bpf: Optimize l2fwd performance in xdpsock (Yauheni Kaliuta) [1874006]
- samples/bpf: Add new sample xsk_fwd.c (Yauheni Kaliuta) [1874006]
- libbpf: Support shared umems between queues and devices (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add sleepable tests (Yauheni Kaliuta) [1874006]
- libbpf: Support sleepable progs (Yauheni Kaliuta) [1874006]
- bpf: Add bpf_copy_from_user() helper. (Yauheni Kaliuta) [1874006]
- bpf: Fix build without BPF_LSM. (Yauheni Kaliuta) [1874006]
- bpf: Introduce sleepable BPF programs (Yauheni Kaliuta) [1874006]
- mm/error_inject: Fix allow_error_inject function signatures. (Yauheni Kaliuta) [1874006]
- mm/filemap.c: enable error injection at add_to_page_cache() (Yauheni Kaliuta) [1874006]
- mm/page_alloc.c: allow error injection (Yauheni Kaliuta) [1874006]
- bpf: selftests: Add test for different inner map size (Yauheni Kaliuta) [1874006]
- bpf: Relax max_entries check for most of the inner map types (Yauheni Kaliuta) [1874006]
- bpf: Add map_meta_equal map ops (Yauheni Kaliuta) [1874006]
- bpf: Make bpf_link_info.iter similar to bpf_iter_link_info (Yauheni Kaliuta) [1874006]
- tools, bpf/build: Cleanup feature files on make clean (Yauheni Kaliuta) [1874006]
- libbpf: Fix compilation warnings for 64-bit printf args (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add verifier tests for xor operation (Yauheni Kaliuta) [1874006]
- libbpf: Fix unintentional success return code in bpf_object__load (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix spelling mistake "scoket" -> "socket" (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix open call in trigger_fstat_events (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add set test to resolve_btfids (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add test for d_path helper (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add verifier test for d_path helper (Yauheni Kaliuta) [1874006]
- bpf: Update .BTF_ids section in btf.rst with sets info (Yauheni Kaliuta) [1874006]
- bpf: Add d_path helper (Yauheni Kaliuta) [1874006]
- bpf: Add BTF_SET_START/END macros (Yauheni Kaliuta) [1874006]
- bpf: Add btf_struct_ids_match function (Yauheni Kaliuta) [1874006]
- bpf: Factor btf_struct_access function (Yauheni Kaliuta) [1874006]
- bpf: Remove recursion call in btf_struct_access (Yauheni Kaliuta) [1874006]
- bpf: Add type_id pointer as argument to __btf_resolve_size (Yauheni Kaliuta) [1874006]
- bpf: Add elem_id pointer as argument to __btf_resolve_size (Yauheni Kaliuta) [1874006]
- bpf: Move btf_resolve_size into __btf_resolve_size (Yauheni Kaliuta) [1874006]
- tools resolve_btfids: Add support for set symbols (Yauheni Kaliuta) [1874006]
- tools resolve_btfids: Add size check to get_id function (Yauheni Kaliuta) [1874006]
- bpf: Disallow BPF_PRELOAD in allmodconfig builds (Yauheni Kaliuta) [1874006]
- bpf: Add selftests for local_storage (Yauheni Kaliuta) [1874006]
- bpf: Allow local storage to be used from LSM programs (Yauheni Kaliuta) [1874006]
- bpf: Implement bpf_local_storage for inodes (Yauheni Kaliuta) [1874006]
- bpf: Split bpf_local_storage to bpf_sk_storage (Yauheni Kaliuta) [1874006]
- bpf: Generalize bpf_sk_storage (Yauheni Kaliuta) [1874006]
- bpf: Generalize caching for sk_storage. (Yauheni Kaliuta) [1874006]
- bpf: Renames in preparation for bpf_local_storage (Yauheni Kaliuta) [1874006]
- selftests/bpf: Enable tc verbose mode for test_sk_assign (Yauheni Kaliuta) [1874006]
- samples: bpf: Refactor tracepoint tracing programs with libbpf (Yauheni Kaliuta) [1874006]
- samples: bpf: Refactor kprobe tracing programs with libbpf (Yauheni Kaliuta) [1874006]
- selftests: bpf: Fix sockmap update nits (Yauheni Kaliuta) [1874006]
- libbpf: Fix type compatibility check copy-paste error (Yauheni Kaliuta) [1874006]
- libbpf: Avoid false unuinitialized variable warning in bpf_core_apply_relo (Yauheni Kaliuta) [1874006]
- bpf: sk_lookup: Add user documentation (Yauheni Kaliuta) [1874006]
- docs: Correct subject prefix and update LLVM info (Yauheni Kaliuta) [1874006]
- libbpf: Normalize and improve logging across few functions (Yauheni Kaliuta) [1874006]
- libbpf: Skip well-known ELF sections when iterating ELF (Yauheni Kaliuta) [1874006]
- libbpf: Add __noinline macro to bpf_helpers.h (Yauheni Kaliuta) [1874006]
- libbpf: Factor out common ELF operations and improve logging (Yauheni Kaliuta) [1874006]
- libbpf: Add perf_buffer APIs for better integration with outside epoll loop (Yauheni Kaliuta) [1874006]
- bpftool: Implement link_query for bpf iterators (Yauheni Kaliuta) [1874006]
- bpf: Implement link_query callbacks in map element iterators (Yauheni Kaliuta) [1874006]
- bpf: Implement link_query for bpf iterators (Yauheni Kaliuta) [1874006]
- selftests/bpf: List newest Clang built-ins needed for some CO-RE selftests (Yauheni Kaliuta) [1874006]
- selftests/bpf: Fix two minor compilation warnings reported by GCC 4.9 (Yauheni Kaliuta) [1874006]
- libbpf: Fix libbpf build on compilers missing __builtin_mul_overflow (Yauheni Kaliuta) [1874006]
- libbpf: Fix detection of BPF helper call instruction (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add bpffs preload test. (Yauheni Kaliuta) [1874006]
- bpf: Add kernel module with user mode driver that populates bpffs. (Yauheni Kaliuta) [1874006]
- bpf: Add BPF program and map iterators as built-in BPF programs. (Yauheni Kaliuta) [1874006]
- bpf: Factor out bpf_link_by_id() helper. (Yauheni Kaliuta) [1874006]
- libbpf: Simplify the return expression of build_map_pin_path() (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add tests for ENUMVAL_EXISTS/ENUMVAL_VALUE relocations (Yauheni Kaliuta) [1874006]
- libbpf: Implement enum value-based CO-RE relocations (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add CO-RE relo test for TYPE_ID_LOCAL/TYPE_ID_TARGET (Yauheni Kaliuta) [1874006]
- selftests/bpf: Test TYPE_EXISTS and TYPE_SIZE CO-RE relocations (Yauheni Kaliuta) [1874006]
- libbpf: Implement type-based CO-RE relocations support (Yauheni Kaliuta) [1874006]
- libbpf: Centralize poisoning and poison reallocarray() (Yauheni Kaliuta) [1874006]
- tools/bpftool: Remove libbpf_internal.h usage in bpftool (Yauheni Kaliuta) [1874006]
- selftests/bpf: Add test validating failure on ambiguous relocation value (Yauheni Kaliuta) [1874006]
- libbpf: Improve relocation ambiguity detection (Yauheni Kaliuta) [1874006]
- libbpf: Detect minimal BTF support and skip BTF loading, if missing (Yauheni Kaliuta) [1874006]
- libbpf: Sanitize BPF program code for bpf_probe_read_{kernel, user}[_str] (Yauheni Kaliuta) [1874006]
- libbpf: Factor out common logic of testing and closing FD (Yauheni Kaliuta) [1874006]
- libbpf: Make kernel feature probing lazy (Yauheni Kaliuta) [1874006]
- libbpf: Disable -Wswitch-enum compiler warning (Yauheni Kaliuta) [1874006]
- libbpf: Convert comma to semicolon (Yauheni Kaliuta) [1874006]
- samples: bpf: Fix broken bpf programs due to removed symbol (Yauheni Kaliuta) [1874006]
- bpf: Replace GPLv2 boilerplate/reference with SPDX - rule 206 (Jiri Benc) [1874006]
- LSM: Make some functions static (Yauheni Kaliuta) [1874006]
- LSM: Make lsm_early_cred() and lsm_early_task() local functions. (Yauheni Kaliuta) [1874006]
- LSM: Infrastructure management of the ipc security blob (Yauheni Kaliuta) [1874006]
- LSM: Infrastructure management of the task security (Yauheni Kaliuta) [1874006]
- LSM: Infrastructure management of the inode security (Yauheni Kaliuta) [1874006]
- LSM: Infrastructure management of the file security (Yauheni Kaliuta) [1874006]
- Infrastructure management of the cred security blob (Yauheni Kaliuta) [1874006]
- kernel: move CONFIG_TASKS_TRACE_RCU fields to task_struct_rh (Jiri Benc) [1874006]
- kernel: store pointer to task_struct in task_struct_rh (Jiri Benc) [1874006]

* Wed Jun 02 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-311.el8]
- igb: Add double-check MTA_REGISTER for i210 and i211 (Corinna Vinschen) [1920286]
- igb: Redistribute memory for transmit packet buffers when in Qav mode (Corinna Vinschen) [1920286]
- igb: Fix fall-through warnings for Clang (Corinna Vinschen) [1920286]
- intel: clean up mismatched header comments (Corinna Vinschen) [1920286]
- igb: check timestamp validity (Corinna Vinschen) [1920286]
- igb: Fix duplicate include guard (Corinna Vinschen) [1920286]
- intel: Update drivers to use ethtool_sprintf (Corinna Vinschen) [1920286]
- net: ethernet: intel: igb: Typo fix in the file igb_main.c (Corinna Vinschen) [1920286]
- igb: avoid premature Rx buffer reuse (Corinna Vinschen) [1920286]
- igb: remove h from printk format specifier (Corinna Vinschen) [1920286]
- igb: Enable RSS for Intel I211 Ethernet Controller (Corinna Vinschen) [1920286]
- igb: fix TDBAL register show incorrect value (Corinna Vinschen) [1920286]
- net: igb: use skb_csum_is_sctp instead of protocol check (Corinna Vinschen) [1920286]
- igb: avoid transmit queue timeout in xdp path (Corinna Vinschen) [1920286]
- igb: use xdp_do_flush (Corinna Vinschen) [1920286]
- igb: skb add metasize for xdp (Corinna Vinschen) [1920286]
- igb: XDP extack message on error (Corinna Vinschen) [1920286]
- igb: take VLAN double header into account (Corinna Vinschen) [1920286]
- igb: XDP xmit back fix error code (Corinna Vinschen) [1920286]
- igb: add XDP support (Corinna Vinschen) [1920286]
- r8169: don't advertise pause in jumbo mode (Josef Oskera) [1935346]
- r8169: fix DMA being used after buffer free if WoL is enabled (Josef Oskera) [1935346]
- r8169: fix r8168fp_adjust_ocp_cmd function (Josef Oskera) [1935346]
- r8169: use macro pm_ptr (Josef Oskera) [1935346]
- r8169: fix resuming from suspend on RTL8105e if machine runs on battery (Josef Oskera) [1935346]
- r8169: handle tx before rx in napi poll (Josef Oskera) [1935346]
- r8169: disable detection of bogus xid's 308/388 (Josef Oskera) [1935346]
- r8169: re-configure WOL settings on resume from hibernation (Josef Oskera) [1935346]
- r8169: don't try to disable interrupts if NAPI is scheduled already (Josef Oskera) [1935346]
- r8169: Add support for another RTL8168FP (Josef Oskera) [1935346]
- r8169: fix WoL on shutdown if CONFIG_DEBUG_SHIRQ is set (Josef Oskera) [1935346]
- r8169: work around RTL8125 UDP hw bug (Josef Oskera) [1935346]
- r8169: remove not needed call to rtl_wol_enable_rx from rtl_shutdown (Josef Oskera) [1935346]
- r8169: improve DASH support (Josef Oskera) [1935346]
- r8169: improve rtl8169_rx_csum (Josef Oskera) [1935346]
- r8169: align rtl_wol_suspend_quirk with vendor driver and rename it (Josef Oskera) [1935346]
- r8169: clean up rtl_pll_power_down/up functions (Josef Oskera) [1935346]
- r8169: improve handling D3 PLL power-down (Josef Oskera) [1935346]
- r8169: enable PLL power-down for chip versions 34, 35, 36, 42 (Josef Oskera) [1935346]
- r8169: make use of the unaligned access helpers (Josef Oskera) [1935346]
- r8169: tweak max read request size for newer chips also in jumbo mtu mode (Josef Oskera) [1935346]
- r8169: align RTL8168e jumbo pcie read request size with vendor driver (Josef Oskera) [1935346]
- r8169: don't wakeup-enable device on shutdown if WOL is disabled (Josef Oskera) [1935346]
- r8169: improve rtl_ocp_reg_failure (Josef Oskera) [1935346]
- r8169: replace BUG_ON with WARN in _rtl_eri_write (Josef Oskera) [1935346]
- r8169: improve RTL8168g PHY suspend quirk (Josef Oskera) [1935346]
- r8169: move ERI access functions to avoid forward declaration (Josef Oskera) [1935346]
- r8169: work around power-saving bug on some chip versions (Josef Oskera) [1935346]
- r8169: make NUM_RX_DESC a signed int (Josef Oskera) [1935346]
- r8169: improve rtl_rx (Josef Oskera) [1935346]
- r8169: set tc_offset only if tally counter reset isn't supported (Josef Oskera) [1935346]
- net: phy: realtek: read actual speed on rtl8211f to detect downshift (Josef Oskera) [1935346]
- r8169: use dev_err_probe in rtl_get_ether_clk (Josef Oskera) [1935346]
- r8169: reduce number of workaround doorbell rings (Josef Oskera) [1935346]
- r8169: remove not needed check in rtl8169_start_xmit (Josef Oskera) [1935346]
- r8169: remove nr_frags argument from rtl_tx_slots_avail (Josef Oskera) [1935346]
- r8169: improve rtl8169_start_xmit (Josef Oskera) [1935346]
- r8169: improve rtl_tx (Josef Oskera) [1935346]
- r8169: use READ_ONCE in rtl_tx_slots_avail (Josef Oskera) [1935346]
- net: phy: realtek: support paged operations on RTL8201CP (Josef Oskera) [1935346]
- r8169: disable hw csum for short packets on all chip versions (Josef Oskera) [1935346]
- r8169: fix potential skb double free in an error path (Josef Oskera) [1935346]
- r8169: work around short packet hw bug on RTL8125 (Josef Oskera) [1935346]
- net: phy: realtek: Add support for RTL8221B-CG series (Josef Oskera) [1935346]
- r8169: set IRQF_NO_THREAD if MSI(X) is enabled (Josef Oskera) [1935346]
- r8169: align number of tx descriptors with vendor driver (Josef Oskera) [1935346]
- r8169: use pm_runtime_put_sync in rtl_open error path (Josef Oskera) [1935346]
- r8169: remove unneeded memory barrier in rtl_tx (Josef Oskera) [1935346]
- r8169: remove no longer needed private rx/tx packet/byte counters (Josef Oskera) [1935346]
- r8169: use struct pcpu_sw_netstats for rx/tx packet/byte counters (Josef Oskera) [1935346]
- treewide: Use fallthrough pseudo-keyword (Josef Oskera) [1935346]
- r8169: fix jumbo packet handling on RTL8168e (Josef Oskera) [1915314]
- sctp: delay auto_asconf init until binding the first addr (Xin Long) [1952020]
- netfilter: x_tables: fix compat match/target pad out-of-bound write (Florian Westphal) [1950014]
- netfilter: arp_tables: add pre_exit hook for table unregister (Florian Westphal) [1950014]
- netfilter: bridge: add pre_exit hooks for ebtable unregistration (Florian Westphal) [1950014]
- netfilter: nft_limit: avoid possible divide error in nft_limit_init (Florian Westphal) [1950014]
- netfilter: conntrack: do not print icmpv6 as unknown via /proc (Florian Westphal) [1950014]
- netfilter: flowtable: fix NAT IPv6 offload mangling (Florian Westphal) [1950014]
- netfilter: flowtable: Make sure GC works periodically in idle system (Florian Westphal) [1950014]
- netfilter: nftables: report EOPNOTSUPP on unsupported flowtable flags (Florian Westphal) [1950014]
- netfilter: ctnetlink: fix dump of the expect mask attribute (Florian Westphal) [1950014]
- netfilter: x_tables: gpf inside xt_find_revision() (Florian Westphal) [1950014]
- netfilter: conntrack: skip identical origin tuple in same zone only (Florian Westphal) [1950014]
- flow_dissector: fix byteorder of dissected ICMP ID (Paolo Abeni) [1950288]
- flow_dissector: fix TTL and TOS dissection on IPv4 fragments (Paolo Abeni) [1950288]
- net: Disable NETIF_F_HW_TLS_RX when RXCSUM is disabled (Paolo Abeni) [1950288]
- net: core: devlink: use right genl user_ptr when handling port param get/set (Paolo Abeni) [1950288]
- net_sched: gen_estimator: support large ewma log (Paolo Abeni) [1950288]
- net: Allow NETIF_F_HW_TLS_TX if IP_CSUM && IPV6_CSUM (Paolo Abeni) [1950288]
- net: Disable NETIF_F_HW_TLS_TX when HW_CSUM is disabled (Paolo Abeni) [1950288]
- devlink: Add devlink port documentation (Petr Oros) [1935708]
- devlink: Support get and set state of port function (Petr Oros) [1935708]
- devlink: Support add and delete devlink port (Petr Oros) [1935708]
- devlink: Introduce PCI SF port flavour and port attribute (Petr Oros) [1935708]
- devlink: Prepare code to fill multiple port function attributes (Petr Oros) [1935708]
- net: core: devlink: simplify the return expression of devlink_nl_cmd_trap_set_doit() (Petr Oros) [1935708]
- video: hyperv_fb: Add ratelimit on error message (Mohammed Gamal) [1957804]
- ovl: allow upperdir inside lowerdir (Miklos Szeredi) [1903647]
- i2c: i801: Add support for Intel Alder Lake PCH-P (Steve Best) [1929488]
- pinctrl: tigerlake: Add Alder Lake-P ACPI ID (Steve Best) [1929492]
- xfs: set aside allocation btree blocks from block reservation (Brian Foster) [1911738]
- xfs: introduce in-core global counter of allocbt blocks (Brian Foster) [1911738]
- xfs: unconditionally read all AGFs on mounts with perag reservation (Brian Foster) [1911738]
- xfs: drop unnecessary setfilesize helper (Brian Foster) [1942348]
- xfs: drop unused ioend private merge and setfilesize code (Brian Foster) [1942348]
- xfs: open code ioend needs workqueue helper (Brian Foster) [1942348]
- xfs: drop submit side trans alloc for append ioends (Brian Foster) [1942348]
- blk-mq: Use request queue-wide tags for tagset-wide sbitmap (Ming Lei) [1932145]
- blk-mq: Some tag allocation code refactoring (Ming Lei) [1932145]
- blk-mq: Swap two calls in blk_mq_exit_queue() (Ming Lei) [1932145]
- blk-mq: plug request for shared sbitmap (Ming Lei) [1932145]
- blk-mq: set default elevator as deadline in case of hctx shared tagset (Ming Lei) [1932145]
- powerpc/perf: Fix PMU constraint check for EBB events (Diego Domingos) [1926573]
- s390/idle: fix suspicious RCU usage (Waiman Long) [1963142]
- x86/cpu: Add another Alder Lake CPU to the Intel family (Steve Best) [1962033]
- x86/split_lock: Don't write MSR_TEST_CTRL on CPUs that aren't whitelisted (Prarit Bhargava) [1837350]
- Documentation/admin-guide: Change doc for split_lock_detect parameter (Prarit Bhargava) [1837350]
- x86/traps: Handle #DB for bus lock (Prarit Bhargava) [1837350]
- x86/cpufeatures: Enumerate #DB for bus lock detection (Prarit Bhargava) [1837350]
- x86/split_lock: Enable the split lock feature on another Alder Lake CPU (Prarit Bhargava) [1925373]
- x86/cpu: Add another Alder Lake CPU to the Intel family (Prarit Bhargava) [1925373]
- x86/split_lock: Enable the split lock feature on Sapphire Rapids and Alder Lake CPUs (Prarit Bhargava) [1925373]

* Thu May 27 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-310.el8]
- libbpf: Add user-space variants of BPF_CORE_READ() family of macros (Jiri Olsa) [1896362]
- libbpf: Switch tracing and CO-RE helper macros to bpf_probe_read_kernel() (Jiri Olsa) [1896362]
- selftests/bpf: Fix test_vmlinux test to use bpf_probe_read_user() (Jiri Olsa) [1896362]
- samples/bpf, selftests/bpf: Use bpf_probe_read_kernel (Jiri Olsa) [1896362]
- bpf: Restrict bpf_probe_read{, str}() only to archs where they work (Jiri Olsa) [1896362]
- perf/x86/intel/uncore: Add Rocket Lake support (Michael Petlan) [1837502]
- perf/x86/cstate: Add Rocket Lake CPU support (Michael Petlan) [1837497]
- perf/x86/intel: Add Rocket Lake CPU support (Michael Petlan) [1837497]
- perf/x86/msr: Add Rocket Lake CPU support (Michael Petlan) [1837497]
- tick/nohz: Kick only _queued_ task whose tick dependency is updated (Waiman Long) [1922901]
- tick/nohz: Change signal tick dependency to wake up CPUs of member tasks (Waiman Long) [1922901]
- tick/nohz: Only wake up a single target cpu when kicking a task (Waiman Long) [1922901]
- tick/nohz: Narrow down noise while setting current task's tick dependency (Waiman Long) [1922901]
- sched/fair: Fix shift-out-of-bounds in load_balance() (Phil Auld) [1958730]
- redhat/configs: Update torture test configs (Waiman Long) [1941211]
- rcu: Do not report strict GPs for outgoing CPUs (Waiman Long) [1941211]
- rcu,ftrace: Fix ftrace recursion (Waiman Long) [1941211]
- arm64: smp: Tell RCU about CPUs that fail to come online (Waiman Long) [1941211]
- rcu: Don't invoke try_invoke_on_locked_down_task() with irqs disabled (Waiman Long) [1941211]
- rcu-tasks: Enclose task-list scan in rcu_read_lock() (Waiman Long) [1941211]
- rcu-tasks: Fix low-probability task_struct leak (Waiman Long) [1941211]
- rcu-tasks: Fix grace-period/unlock race in RCU Tasks Trace (Waiman Long) [1941211]
- rcu-tasks: Shorten per-grace-period sleep for RCU Tasks Trace (Waiman Long) [1941211]
- rcu-tasks: Selectively enable more RCU Tasks Trace IPIs (Waiman Long) [1941211]
- rcu-tasks: Use more aggressive polling for RCU Tasks Trace (Waiman Long) [1941211]
- rcu-tasks: Mark variables static (Waiman Long) [1941211]
- rcu-tasks: Prevent complaints of unused show_rcu_tasks_classic_gp_kthread() (Waiman Long) [1941211]
- rcu: Remove unused "cpu" parameter from rcu_report_qs_rdp() (Waiman Long) [1941211]
- torture: Add gdb support (Waiman Long) [1941211]
- rcuperf: Change rcuperf to rcuscale (Waiman Long) [1941211]
- sched,rcuperf: Convert to sched_set_fifo_low() (Waiman Long) [1941211]
- rcu/rcuperf: Convert to SPDX license identifier (Waiman Long) [1941211]
- rcutorture: Allow pointer leaks to test diagnostic code (Waiman Long) [1941211]
- rcu: Report QS for outermost PREEMPT=n rcu_read_unlock() for strict GPs (Waiman Long) [1941211]
- rcu: locking and unlocking need to always be at least barriers (Waiman Long) [1941211]
- rcu: Execute RCU reader shortly after rcu_core for strict GPs (Waiman Long) [1941211]
- rcu: Provide optional RCU-reader exit delay for strict GPs (Waiman Long) [1941211]
- rcu: Make FQS more aggressive in complaining about offline CPUs (Waiman Long) [1941211]
- rcu: Clarify comments about FQS loop reporting quiescent states (Waiman Long) [1941211]
- rcu: IPI all CPUs at GP end for strict GPs (Waiman Long) [1941211]
- rcu: IPI all CPUs at GP start for strict GPs (Waiman Long) [1941211]
- rcu: Attempt QS when CPU discovers GP for strict GPs (Waiman Long) [1941211]
- rcu: Do full report for .need_qs for strict GPs (Waiman Long) [1941211]
- rcu: Always set .need_qs from __rcu_read_lock() for strict GPs (Waiman Long) [1941211]
- rcu: Force DEFAULT_RCU_BLIMIT to 1000 for strict RCU GPs (Waiman Long) [1941211]
- rcu: Restrict default jiffies_till_first_fqs for strict RCU GPs (Waiman Long) [1941211]
- rcu: Reduce leaf fanout for strict RCU grace periods (Waiman Long) [1941211]
- rcu: Add Kconfig option for strict RCU grace periods (Waiman Long) [1941211]
- rcu/nocb: Add a warning for non-GP kthread running GP code (Waiman Long) [1941211]
- rcu: Move rcu_cpu_started per-CPU variable to rcu_data (Waiman Long) [1941211]
- scftorture: Add cond_resched() to test loop (Waiman Long) [1941211]
- rcutorture: Hoist OOM registry up one level (Waiman Long) [1941211]
- rcutorture: Properly synchronize with OOM notifier (Waiman Long) [1941211]
- rcutorture: Properly set rcu_fwds for OOM handling (Waiman Long) [1941211]
- torture: Add kvm.sh --help and update help message (Waiman Long) [1941211]
- refperf: Avoid null pointer dereference when buf fails to allocate (Waiman Long) [1941211]
- rcutorture: Add CONFIG_PROVE_RCU_LIST to TREE05 (Waiman Long) [1941211]
- torture: Update initrd documentation (Waiman Long) [1941211]
- rcutorture: Replace HTTP links with HTTPS ones (Waiman Long) [1941211]
- rcu: Fix kerneldoc comments in rcupdate.h (Waiman Long) [1941211]
- scftorture: Adapt memory-ordering test to UP operation (Waiman Long) [1941211]
- torture: document --allcpus argument added to the kvm.sh script (Waiman Long) [1941211]
- scftorture: Block scftorture_invoker() kthreads for offline CPUs (Waiman Long) [1941211]
- scftorture: Check unexpected "switch" statement value (Waiman Long) [1941211]
- scftorture: Make symbol 'scf_torture_rand' static (Waiman Long) [1941211]
- scftorture: Prevent compiler from reducing race probabilities (Waiman Long) [1941211]
- scftorture: Flag errors in torture-compatible manner (Waiman Long) [1941211]
- scftorture: Consolidate scftorture_invoke_one() scf_check initialization (Waiman Long) [1941211]
- scftorture: Consolidate scftorture_invoke_one() check and kfree() (Waiman Long) [1941211]
- scftorture: Add smp_call_function() memory-ordering checks (Waiman Long) [1941211]
- scftorture: Add smp_call_function_many() memory-ordering checks (Waiman Long) [1941211]
- scftorture: Add smp_call_function_single() memory-ordering checks (Waiman Long) [1941211]
- scftorture: Summarize per-thread statistics (Waiman Long) [1941211]
- torture: Declare parse-console.sh independence from rcutorture (Waiman Long) [1941211]
- tick-sched: Clarify "NOHZ: local_softirq_pending" warning (Waiman Long) [1941211]
- scftorture: Implement weighted primitive selection (Waiman Long) [1941211]
- torture: Add scftorture to the rcutorture scripting (Waiman Long) [1941211]
- scftorture: Add smp_call_function() torture test (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_do_batch() access to rcu_cpu_stall_ftrace_dump (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_do_batch() access to rcu_kick_kthreads (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_do_batch() access to rcu_resched_ns (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_do_batch() access to rcu_divisor (Waiman Long) [1941211]
- nocb: Remove show_rcu_nocb_state() false positive printout (Waiman Long) [1941211]
- rcu/tree: Remove CONFIG_PREMPT_RCU check in force_qs_rnp() (Waiman Long) [1941211]
- nocb: Clarify RCU nocb CPU error message (Waiman Long) [1941211]
- rcu/tree: Force quiescent state on callback overload (Waiman Long) [1941211]
- rcu/trace: Use gp_seq_req in acceleration's rcu_grace_period tracepoint (Waiman Long) [1941211]
- rcu/trace: Print negative GP numbers correctly (Waiman Long) [1941211]
- rcutorture: Output number of elapsed grace periods (Waiman Long) [1941211]
- rcu: Initialize at declaration time in rcu_exp_handler() (Waiman Long) [1941211]
- rcu: Remove KCSAN stubs from update.c (Waiman Long) [1941211]
- rcu: Remove KCSAN stubs (Waiman Long) [1941211]
- srcu: Remove KCSAN stubs (Waiman Long) [1941211]
- rcutorture: Remove KCSAN stubs (Waiman Long) [1941211]
- refscale: Change --torture type from refperf to refscale (Waiman Long) [1941211]
- refperf: Rename refperf.c to refscale.c and change internal names (Waiman Long) [1941211]
- refperf: Rename RCU_REF_PERF_TEST to RCU_REF_SCALE_TEST (Waiman Long) [1941211]
- torture: Remove obsolete "cd $KVM" (Waiman Long) [1941211]
- torture: Avoid duplicate specification of qemu command (Waiman Long) [1941211]
- torture: Dump ftrace at shutdown only if requested (Waiman Long) [1941211]
- torture: Add kvm-tranform.sh script for qemu-cmd files (Waiman Long) [1941211]
- torture: Add more tracing crib notes to kvm.sh (Waiman Long) [1941211]
- torture: Improve diagnostic for KCSAN-incapable compilers (Waiman Long) [1941211]
- torture: Correctly summarize build-only runs (Waiman Long) [1941211]
- torture: Pass --kmake-arg to all make invocations (Waiman Long) [1941211]
- kernel/rcu/tree.c: Fix kernel-doc warnings (Waiman Long) [1941211]
- rcu-tasks: Fix synchronize_rcu_tasks_trace() header comment (Waiman Long) [1941211]
- rcu: grpnum just records group number (Waiman Long) [1941211]
- rcu: grplo/grphi just records CPU number (Waiman Long) [1941211]
- rcu: gp_max is protected by root rcu_node's lock (Waiman Long) [1941211]
- rcutorture: Check for unwatched readers (Waiman Long) [1941211]
- torture: Abstract out console-log error detection (Waiman Long) [1941211]
- torture: Add a stop-run capability (Waiman Long) [1941211]
- rcu-tasks: Fix code-style issues (Waiman Long) [1941211]
- torture: Create qemu-cmd in --buildonly runs (Waiman Long) [1941211]
- rcu: Stop shrinker loop (Waiman Long) [1941211]
- refperf: Add test for RCU Tasks readers (Waiman Long) [1941211]
- refperf: Add test for RCU Tasks Trace readers. (Waiman Long) [1941211]
- rcu: Replace 1 with true (Waiman Long) [1941211]
- rcu/rcutorture: Replace 0 with false (Waiman Long) [1941211]
- refperf: Change readdelay module parameter to nanoseconds (Waiman Long) [1941211]
- refperf: Work around 64-bit division (Waiman Long) [1941211]
- doc: Document rcuperf's module parameters (Waiman Long) [1941211]
- refperf: Adjust refperf.loop default value (Waiman Long) [1941211]
- rcu-tasks: Conditionally compile show_rcu_tasks_gp_kthreads() (Waiman Long) [1941211]
- rcu-tasks: Add #include of rcupdate_trace.h to update.c (Waiman Long) [1941211]
- rcu-tasks: Make rcu_tasks_postscan() be static (Waiman Long) [1941211]
- refperf: Add read-side delay module parameter (Waiman Long) [1941211]
- lockdep: Complain only once about RCU in extended quiescent state (Waiman Long) [1941211]
- refperf: Simplify initialization-time wakeup protocol (Waiman Long) [1941211]
- rcu: Allow for smp_call_function() running callbacks from idle (Waiman Long) [1941211]
- refperf: Output per-experiment data points (Waiman Long) [1941211]
- refperf: Label experiment-number column "Runs" (Waiman Long) [1941211]
- refperf: Add warmup and cooldown processing phases (Waiman Long) [1941211]
- refperf: More closely synchronize reader start times (Waiman Long) [1941211]
- refperf: Convert reader_task structure's "start" field to int (Waiman Long) [1941211]
- refperf: Tune reader measurement interval (Waiman Long) [1941211]
- refperf: Make functions static (Waiman Long) [1941211]
- srcu: Avoid local_irq_save() before acquiring spinlock_t (Waiman Long) [1941211]
- refperf: Dynamically allocate thread-summary output buffer (Waiman Long) [1941211]
- refperf: Dynamically allocate experiment-summary output buffer (Waiman Long) [1941211]
- refperf: Provide module parameter to specify number of experiments (Waiman Long) [1941211]
- refperf: Convert nreaders to a module parameter (Waiman Long) [1941211]
- refperf: Allow decimal nanoseconds (Waiman Long) [1941211]
- refperf: Hoist function-pointer calls out of the loop (Waiman Long) [1941211]
- rcu: Introduce single argument kvfree_rcu() interface (Waiman Long) [1941211]
- refperf: Add holdoff parameter to allow CPUs to come online (Waiman Long) [1941211]
- torture: Add refperf to the rcutorture scripting (Waiman Long) [1941211]
- rcuperf: Add comments explaining the high reader overhead (Waiman Long) [1941211]
- refperf: Add a test to measure performance of read-side synchronization (Waiman Long) [1941211]
- rcuperf: Remove useless while loops around wait_event (Waiman Long) [1941211]
- rcu: Provide rcu_irq_exit_check_preempt() (Waiman Long) [1941211]
- sched,rcu,tracing: Avoid tracing before in_nmi() is correct (Waiman Long) [1941211]
- hardirq/nmi: Allow nested nmi_enter() (Waiman Long) [1941211]
- powerpc/64s: Include <asm/nmi.h> header file to fix a warning (Waiman Long) [1941211]
- powerpc/64s: system reset interrupt preserve HSRRs (Waiman Long) [1941211]
- powerpc/64s: Fix HV NMI vs HV interrupt recoverability test (Waiman Long) [1941211]
- powerpc/traps: fix recoverability of machine check handling on book3s/32 (Waiman Long) [1941211]
- powerpc/traps: restore recoverability of machine_check interrupts (Waiman Long) [1941211]
- rcu: Mark rcu_nmi_enter() call to rcu_cleanup_after_idle() noinstr (Waiman Long) [1941211]
- rcu: Remove initialized but unused rnp from check_slow_task() (Waiman Long) [1941211]
- rcu: Update comment from rsp->rcu_gp_seq to rsp->gp_seq (Waiman Long) [1941211]
- rcu: Provide __rcu_is_watching() (Waiman Long) [1941211]
- doc: Tasks RCU must protect instructions before trampoline (Waiman Long) [1941211]
- fs/btrfs: Add cond_resched() for try_release_extent_mapping() stalls (Waiman Long) [1941211]
- rcu-tasks: Convert sleeps to idle priority (Waiman Long) [1941211]
- rcu: Expedited grace-period sleeps to idle priority (Waiman Long) [1941211]
- rcu: No-CBs-related sleeps to idle priority (Waiman Long) [1941211]
- rcu: Priority-boost-related sleeps to idle priority (Waiman Long) [1941211]
- rcu: Grace-period-kthread related sleeps to idle priority (Waiman Long) [1941211]
- torture: Add --allcpus argument to the kvm.sh script (Waiman Long) [1941211]
- torture: Remove whitespace from identify_qemu_vcpus output (Waiman Long) [1941211]
- torture: Add script to smoke-test commits in a branch (Waiman Long) [1941211]
- trace: events: rcu: Change description of rcu_dyntick trace event (Waiman Long) [1941211]
- rcu: Add comment documenting rcu_callback_map's purpose (Waiman Long) [1941211]
- rcu: Provide rcu_irq_exit_preempt() (Waiman Long) [1941211]
- rcu: Add callbacks-invoked counters (Waiman Long) [1941211]
- doc: Timer problems can cause RCU CPU stall warnings (Waiman Long) [1941211]
- torture:  Remove qemu dependency on EFI firmware (Waiman Long) [1941211]
- rcutorture: NULL rcu_torture_current earlier in cleanup code (Waiman Long) [1941211]
- rcutorture: Handle non-statistic bang-string error messages (Waiman Long) [1941211]
- torture: Set configfile variable to current scenario (Waiman Long) [1941211]
- rcutorture: Add races with task-exit processing (Waiman Long) [1941211]
- docs: RCU: Don't duplicate chapter names in rculist_nulls.rst (Waiman Long) [1941211]
- docs: RCU: Convert stallwarn.txt to ReST (Waiman Long) [1941211]
- docs: RCU: Convert rcuref.txt to ReST (Waiman Long) [1941211]
- docs: RCU: Convert torture.txt to ReST (Waiman Long) [1941211]
- docs: RCU: Convert rculist_nulls.txt to ReST (Waiman Long) [1941211]
- docs: RCU: Convert lockdep.txt to ReST (Waiman Long) [1941211]
- docs: RCU: Convert lockdep-splat.txt to ReST (Waiman Long) [1941211]
- docs: RCU: Convert checklist.txt to ReST (Waiman Long) [1941211]
- doc: Add rcutorture scripting to torture.txt (Waiman Long) [1941211]
- doc: Fix typo "deference" to "dereference" (Waiman Long) [1941211]
- docs: locking: convert docs to ReST and rename to *.rst (Waiman Long) [1941211]
- doc/rcuref: Document real world examples in kernel (Waiman Long) [1941211]
- Documentation/locking/lockdep: Drop last two chars of sample states (Waiman Long) [1941211]
- doc: rcu: Suspicious RCU usage is a warning (Waiman Long) [1941211]
- RCU/torture.txt: Remove section MODULE PARAMETERS (Waiman Long) [1941211]
- Documentation/lockstat: Fix trivial typo (Waiman Long) [1941211]
- rcu: Simplify the calculation of rcu_state.ncpus (Waiman Long) [1941211]
- srcu: Fix a typo in comment "amoritized"->"amortized" (Waiman Long) [1941211]
- rcuperf: Fix printk format warning (Waiman Long) [1941211]
- mm/mmap.c: Add cond_resched() for exit_mmap() CPU stalls (Waiman Long) [1941211]
- rcu: Initialize and destroy rcu_synchronize only when necessary (Waiman Long) [1941211]
- rcu: Add KCSAN stubs to update.c (Waiman Long) [1941211]
- rcu: Add KCSAN stubs (Waiman Long) [1941211]
- srcu: Add KCSAN stubs (Waiman Long) [1941211]
- rcutorture: Add KCSAN stubs (Waiman Long) [1941211]
- rcu/rcutorture: Convert to SPDX license identifier (Waiman Long) [1941211]
- rcu: Convert rcu_nohz_full_cpu() ULONG_CMP_LT() to time_before() (Waiman Long) [1941211]
- rcu: Convert rcu_initiate_boost() ULONG_CMP_GE() to time_after() (Waiman Long) [1941211]
- rcutorture: Convert ULONG_CMP_LT() to time_before() (Waiman Long) [1941211]
- rcu: Convert ULONG_CMP_GE() to time_after() for jiffy comparison (Waiman Long) [1941211]
- rcu: Add rcu_gp_might_be_stalled() (Waiman Long) [1941211]
- torture: Add a --kasan argument (Waiman Long) [1941211]
- torture: Save a few lines by using config_override_param initially (Waiman Long) [1941211]
- torture: Allow scenario-specific Kconfig options to override CFcommon (Waiman Long) [1941211]
- torture: Allow --kconfig options to override --kcsan defaults (Waiman Long) [1941211]
- torture: Abstract application of additional Kconfig options (Waiman Long) [1941211]
- torture: Eliminate duplicate #CHECK# from ConfigFragment (Waiman Long) [1941211]
- torture: Make --kcsan argument also create a summary (Waiman Long) [1941211]
- rcutorture: Make rcu_fwds and rcu_fwd_emergency_stop static (Waiman Long) [1941211]
- torture: Add --kcsan argument to top-level kvm.sh script (Waiman Long) [1941211]
- rcu-tasks: Allow standalone use of TASKS_{TRACE_,}RCU (Waiman Long) [1941211]
- rcu: Remove self-stack-trace when all quiescent states seen (Waiman Long) [1941211]
- ftrace: Use synchronize_rcu_tasks_rude() instead of ftrace_sync() (Waiman Long) [1941211]
- ftrace: Protect ftrace_graph_hash with ftrace_sync (Waiman Long) [1941211]
- ftrace: Add comment to why rcu_dereference_sched() is open coded (Waiman Long) [1941211]
- tracing: Annotate ftrace_graph_notrace_hash pointer with __rcu (Waiman Long) [1941211]
- tracing: Annotate ftrace_graph_hash pointer with __rcu (Waiman Long) [1941211]
- tracing/fgraph: Fix set_graph_function from showing interrupts (Waiman Long) [1941211]
- rcu: Allow rcutorture to starve grace-period kthread (Waiman Long) [1941211]
- rcu: When GP kthread is starved, tag idle threads as false positives (Waiman Long) [1941211]
- rcutorture: Right-size TREE10 CPU consumption (Waiman Long) [1941211]
- rcu: Replace 1 by true (Waiman Long) [1941211]
- rcutorture: Add test of holding scheduler locks across rcu_read_unlock() (Waiman Long) [1941211]
- rcu: Replace assigned pointer ret value by corresponding boolean value (Waiman Long) [1941211]
- rcu-tasks: Add IPI failure count to statistics (Waiman Long) [1941211]
- rcutorture: Add TRACE02 scenario enabling RCU Tasks Trace IPIs (Waiman Long) [1941211]
- rcu-tasks: Add count for idle tasks on offline CPUs (Waiman Long) [1941211]
- rcu-tasks: Add rcu_dynticks_zero_in_eqs() effectiveness statistics (Waiman Long) [1941211]
- rcu-tasks: Make RCU tasks trace also wait for idle tasks (Waiman Long) [1941211]
- rcu-tasks: Handle the running-offline idle-task special case (Waiman Long) [1941211]
- rcu-tasks: Disable CPU hotplug across RCU tasks trace scans (Waiman Long) [1941211]
- rcu: Mark rcu_state.gp_seq to detect more concurrent writes (Waiman Long) [1941211]
- rcu-tasks: Allow rcu_read_unlock_trace() under scheduler locks (Waiman Long) [1941211]
- rcu-tasks: Avoid IPIing userspace/idle tasks if kernel is so built (Waiman Long) [1941211]
- rcu-tasks: Add Kconfig option to mediate smp_mb() vs. IPI (Waiman Long) [1941211]
- rcu-tasks: Add grace-period and IPI counts to statistics (Waiman Long) [1941211]
- rcu-tasks: Split ->trc_reader_need_end (Waiman Long) [1941211]
- rcu-tasks: Provide boot parameter to delay IPIs until late in grace period (Waiman Long) [1941211]
- rcu-tasks: Add a grace-period start time for throttling and debug (Waiman Long) [1941211]
- rcu: Get rid of some doc warnings in update.c (Waiman Long) [1941211]
- rcu-tasks: Make RCU Tasks Trace make use of RCU scheduler hooks (Waiman Long) [1941211]
- rcu-tasks: Use context-switch hook for PREEMPT=y kernels (Waiman Long) [1941211]
- rcu-tasks: Make rcutorture writer stall output include GP state (Waiman Long) [1941211]
- rcu-tasks: Add RCU tasks to rcutorture writer stall output (Waiman Long) [1941211]
- rcuperf: Add ability to increase object allocation size (Waiman Long) [1941211]
- rcu-tasks: Move #ifdef into tasks.h (Waiman Long) [1941211]
- rcutorture: Add flag to produce non-busy-wait task stalls (Waiman Long) [1941211]
- rcu: Add per-task state to RCU CPU stall warnings (Waiman Long) [1941211]
- sched/core: Add function to sample state of locked-down task (Waiman Long) [1941211]
- rcu-tasks: Add stall warnings for RCU Tasks Trace (Waiman Long) [1941211]
- rcutorture: Add torture tests for RCU Tasks Trace (Waiman Long) [1941211]
- rcu-tasks: Add an RCU Tasks Trace to simplify protection of tracing hooks (Waiman Long) [1941211]
- rcutorture: Add a test for synchronize_rcu_mult() (Waiman Long) [1941211]
- rcu: Reinstate synchronize_rcu_mult() (Waiman Long) [1941211]
- rcu-tasks: Code movement to allow more Tasks RCU variants (Waiman Long) [1941211]
- rcu: Fix the (t=0 jiffies) false positive (Waiman Long) [1941211]
- rcu-tasks: Further refactor RCU-tasks to allow adding more variants (Waiman Long) [1941211]
- rcu-tasks: Use unique names for RCU-Tasks kthreads and messages (Waiman Long) [1941211]
- rcutorture: Add torture tests for RCU Tasks Rude (Waiman Long) [1941211]
- rcu-tasks: Add an RCU-tasks rude variant (Waiman Long) [1941211]
- rcu-tasks: Refactor RCU-tasks to allow variants to be added (Waiman Long) [1941211]
- rcu-tasks: Create struct to hold state information (Waiman Long) [1941211]
- rcu-tasks: Move Tasks RCU to its own file (Waiman Long) [1941211]
- locktorture.c: Fix if-statement empty body warnings (Waiman Long) [1941211]
- rcu: Expedite first two FQS scans under callback-overload conditions (Waiman Long) [1941211]
- rcu: Mark rcu_state.gp_seq to detect concurrent writes (Waiman Long) [1941211]
- rcutorture: Mark data-race potential for rcu_barrier() test statistics (Waiman Long) [1941211]
- rcu: Don't use negative nesting depth in __rcu_read_unlock() (Waiman Long) [1941211]
- rcu: Remove unused ->rcu_read_unlock_special.b.deferred_qs field (Waiman Long) [1941211]
- rcu: Don't set nesting depth negative in rcu_preempt_deferred_qs() (Waiman Long) [1941211]
- rcu: Make rcu_read_unlock_special() safe for rq/pi locks (Waiman Long) [1941211]
- rcutorture: Make kvm-recheck-rcu.sh handle truncated lines (Waiman Long) [1941211]
- rcu: Make RCU IRQ enter/exit functions rely on in_nmi() (Waiman Long) [1941211]
- rcu/tree: Mark the idle relevant functions noinstr (Waiman Long) [1941211]
- rcu: Add comments marking transitions between RCU watching and not (Waiman Long) [1941211]
- rcu: Update __call_rcu() comments (Waiman Long) [1941211]
- rcu: Mark rcu_state.ncpus to detect concurrent writes (Waiman Long) [1941211]
- rcu: Use data_race() for RCU CPU stall-warning prints (Waiman Long) [1941211]
- rcutorture: Manually clean up after rcu_barrier() failure (Waiman Long) [1941211]
- rcutorture: Make rcu_torture_barrier_cbs() post from corresponding CPU (Waiman Long) [1941211]
- rcu: Make nocb_gp_wait() double-check unexpected-callback warning (Waiman Long) [1941211]
- rcu: Tighten rcu_lockdep_assert_cblist_protected() check (Waiman Long) [1941211]
- rcu: Optimize and protect atomic_cmpxchg() loop (Waiman Long) [1941211]
- rcu/nocb: Add missing annotation for rcu_nocb_bypass_unlock() (Waiman Long) [1941211]
- rcu: Don't flag non-starting GPs before GP kthread is running (Waiman Long) [1941211]
- rcu: Fix rcu_barrier_callback() race condition (Waiman Long) [1941211]
- rcu: Add WRITE_ONCE() to rcu_state ->gp_start (Waiman Long) [1941211]
- rcu: Add missing annotation for rcu_nocb_bypass_lock() (Waiman Long) [1941211]
- rcu: Add missing annotation for exit_tasks_rcu_finish() (Waiman Long) [1941211]
- rcu: Add missing annotation for exit_tasks_rcu_start() (Waiman Long) [1941211]
- rculist: Add brackets around cond argument in __list_check_rcu macro (Waiman Long) [1941211]
- rcu: Remove dead code from rcu_segcblist_insert_pend_cbs() (Waiman Long) [1941211]
- rcutorture: Annotation lockless accesses to rcu_torture_current (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_data ->gpwrap (Waiman Long) [1941211]
- rcu-tasks: *_ONCE() for rcu_tasks_cbs_head (Waiman Long) [1941211]
- rcu: Add *_ONCE() for grace-period progress indicators (Waiman Long) [1941211]
- rcu: Add WRITE_ONCE() to rcu_node ->boost_tasks (Waiman Long) [1941211]
- srcu: Add data_race() to ->srcu_lock_count and ->srcu_unlock_count arrays (Waiman Long) [1941211]
- rcutorture: Add READ_ONCE() to rcu_torture_count and rcu_torture_batch (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_segcblist ->tails[] (Waiman Long) [1941211]
- rcu: Add WRITE_ONCE() to rcu_node ->qsmaskinitnext (Waiman Long) [1941211]
- rcu: Add READ_ONCE and data_race() to rcu_node ->boost_tasks (Waiman Long) [1941211]
- rcu: Add WRITE_ONCE() to rcu_state ->gp_req_activity (Waiman Long) [1941211]
- rcu: Add READ_ONCE() to rcu_node ->gp_seq (Waiman Long) [1941211]
- rcu: Add *_ONCE() and data_race() to rcu_node ->exp_tasks plus locking (Waiman Long) [1941211]
- rcu: Add *_ONCE() to rcu_node ->boost_kthread_status (Waiman Long) [1941211]
- rcu: Add WRITE_ONCE to rcu_node ->exp_seq_rq store (Waiman Long) [1941211]
- srcu: Hold srcu_struct ->lock when updating ->srcu_gp_seq (Waiman Long) [1941211]
- rcu: Add WRITE_ONCE() to rcu_node ->qsmask update (Waiman Long) [1941211]
- rcu: Provide debug symbols and line numbers in KCSAN runs (Waiman Long) [1941211]
- rcu: Fix exp_funnel_lock()/rcu_exp_wait_wake() datarace (Waiman Long) [1941211]
- srcu: Fix process_srcu()/srcu_batches_completed() datarace (Waiman Long) [1941211]
- srcu: Fix __call_srcu()/srcu_get_delay() datarace (Waiman Long) [1941211]
- srcu: Fix __call_srcu()/process_srcu() datarace (Waiman Long) [1941211]
- rcutorture: Fix stray access to rcu_fwd_cb_nodelay (Waiman Long) [1941211]
- rcutorture: Fix rcu_torture_one_read()/rcu_torture_writer() data race (Waiman Long) [1941211]
- rcutorture: Make kvm-find-errors.sh abort on bad directory (Waiman Long) [1941211]
- rcutorture: Summarize summary of build and run results (Waiman Long) [1941211]
- rcutorture: Add 100-CPU configuration (Waiman Long) [1941211]
- rcu: Warn on for_each_leaf_node_cpu_mask() from non-leaf (Waiman Long) [1941211]
- rcu: Fix spelling mistake "leval" -> "level" (Waiman Long) [1941211]
- torture: Allow disabling of boottime CPU-hotplug torture operations (Waiman Long) [1941211]
- rcutorture: Suppress boottime bad-sequence warnings (Waiman Long) [1941211]
- rcutorture: Allow boottime stall warnings to be suppressed (Waiman Long) [1941211]
- torture: Forgive -EBUSY from boottime CPU-hotplug operations (Waiman Long) [1941211]
- rcutorture: Refrain from callback flooding during boot (Waiman Long) [1941211]
- torture: Make results-directory date format completion-friendly (Waiman Long) [1941211]
- rcutorture: Suppress forward-progress complaints during early boot (Waiman Long) [1941211]
- timer: Use hlist_unhashed_lockless() in timer_pending() (Waiman Long) [1941211]
- rcu: React to callback overload by boosting RCU readers (Waiman Long) [1941211]
- rcu: React to callback overload by aggressively seeking quiescent states (Waiman Long) [1941211]
- rcu: Add and update docbook header comments in list.h (Waiman Long) [1941211]
- list: Add hlist_unhashed_lockless() (Waiman Long) [1941211]
- list: Don't use WRITE_ONCE() in hlist_add_behind() (Waiman Long) [1941211]
- kcsan: Introduce ASSERT_EXCLUSIVE_BITS(var, mask) (Waiman Long) [1941211]
- kcsan: Add kcsan_set_access_mask() support (Waiman Long) [1941211]
- kcsan: Introduce kcsan_value_change type (Waiman Long) [1941211]
- kcsan: Move interfaces that affects checks to kcsan-checks.h (Waiman Long) [1941211]
- kcsan: Fix misreporting if concurrent races on same address (Waiman Long) [1941211]
- kcsan: Expose core configuration parameters as module params (Waiman Long) [1941211]
- kcsan: Add test to generate conflicts via debugfs (Waiman Long) [1941211]
- kcsan: Introduce ASSERT_EXCLUSIVE_*() macros (Waiman Long) [1941211]
- kcsan: Introduce KCSAN_ACCESS_ASSERT access type (Waiman Long) [1941211]
- kcsan: Fix 0-sized checks (Waiman Long) [1941211]
- kcsan: Clean up the main KCSAN Kconfig option (Waiman Long) [1941211]
- kcsan: Clarify Kconfig option KCSAN_IGNORE_ATOMICS (Waiman Long) [1941211]
- kcsan: Add option to assume plain aligned writes up to word size are atomic (Waiman Long) [1941211]
- kcsan: Add docbook header for data_race() (Waiman Long) [1941211]
- kcsan: Address missing case with KCSAN_REPORT_VALUE_CHANGE_ONLY (Waiman Long) [1941211]
- include/linux: Add instrumented.h infrastructure (Waiman Long) [1941211]
- kcsan: Make KCSAN compatible with lockdep (Waiman Long) [1941211]
- kcsan: Rate-limit reporting per data races (Waiman Long) [1941211]
- kcsan: Show full access type in report (Waiman Long) [1941211]
- kcsan: Prefer __always_inline for fast-path (Waiman Long) [1941211]
- kcsan: Improve various small stylistic details (Waiman Long) [1941211]
- x86, kcsan: Enable KCSAN for x86 (Waiman Long) [1941211]
- build, kcsan: Add KCSAN build exceptions (Waiman Long) [1941211]
- x86/uaccess, kcov: Disable stack protector (Waiman Long) [1941211]
- doc: Convert to rcubarrier.txt to ReST (Waiman Long) [1941211]
- doc: Convert to rcu_dereference.txt to rcu_dereference.rst (Waiman Long) [1941211]
- doc: Convert whatisRCU.txt to .rst (Waiman Long) [1941211]
- doc: Converted NMI-RCU.txt to NMI-RCU.rst. (Waiman Long) [1941211]
- doc: Convert arrayRCU.txt to arrayRCU.rst (Waiman Long) [1941211]
- doc: Update list_for_each_entry_rcu() documentation (Waiman Long) [1941211]
- Restore docs "rcu: Restore barrier() to rcu_read_lock() and rcu_read_unlock()" (Waiman Long) [1941211]
- Restore docs "treewide: Rename rcu_dereference_raw_notrace() to _check()" (Waiman Long) [1941211]
- docs: rcu: Increase toctree to 3 (Waiman Long) [1941211]
- docs: rcu: Correct links referring to titles (Waiman Long) [1941211]
- docs: rcu: convert some articles from html to ReST (Waiman Long) [1941211]
- Revert docs from "rcu: Restore barrier() to rcu_read_lock() and rcu_read_unlock()" (Waiman Long) [1941211]
- Documentation: RCU: Add TOC tree hooks (Waiman Long) [1941211]
- doc: Describe choice of rcu_dereference() APIs and __rcu usage (Waiman Long) [1941211]
- doc: Remove obsolete RCU update functions from RCU documentation (Waiman Long) [1941211]
- scsi: ibmvfc: Free channel_setup_buf during device tear down (Steve Best) [1938102]
- blk-mq: clearing flush request reference in tags->rqs[] (Ming Lei) [1811030]
- blk-mq: clear stale request in tags->rq[] before freeing one request pool (Ming Lei) [1811030]
- blk-mq: grab rq->refcount before calling ->fn in blk_mq_tagset_busy_iter (Ming Lei) [1811030]
- vsock/vmci: log once the failed queue pair allocation (Stefano Garzarella) [1958248]
- VMCI: Stop log spew when qp allocation isn't possible (Stefano Garzarella) [1958248]
- vsock/virtio: update credit only if socket is not closed (Stefano Garzarella) [1921694]
- powerpc/security: Fix debugfs data leak on 32-bit (Steve Best) [1935661]
- powerpc/security: Show powerpc_security_features in debugfs (Steve Best) [1935661]
- redhat/configs: Add CONFIG_SYSTEM_REVOCATION_KEYS and CONFIG_SYSTEM_REVOCATION_LIST (Vladis Dronov) [1893793] {CVE-2020-26541}
- certs: add 'x509_revocation_list' to gitignore (Vladis Dronov) [1893793] {CVE-2020-26541}
- integrity: Load mokx variables into the blacklist keyring (Vladis Dronov) [1893793] {CVE-2020-26541}
- certs: Add ability to preload revocation certs (Vladis Dronov) [1893793] {CVE-2020-26541}
- certs: Move load_system_certificate_list to a common function (Vladis Dronov) [1893793] {CVE-2020-26541}
- certs: Add EFI_CERT_X509_GUID support for dbx entries (Vladis Dronov) [1893793] {CVE-2020-26541}
- pNFS/flexfiles: Fix array overflow when flexfiles mirroring is enabled (Benjamin Coddington) [1949575]
- net/sunrpc: fix useless comparison in proc_do_xprt() (Benjamin Coddington) [1949575]
- net/sunrpc: return 0 on attempt to write to "transports" (Benjamin Coddington) [1949575]
- NFSD: MKNOD should return NFSERR_BADTYPE instead of NFSERR_INVAL (Benjamin Coddington) [1949575]
- NFSD: NFSv3 PATHCONF Reply is improperly formed (Benjamin Coddington) [1949575]
- nfsroot: Default mount option should ask for built-in NFS version (Benjamin Coddington) [1949575]
- nfsd: remove unneeded break (Benjamin Coddington) [1949575]
- net/sunrpc: Fix return value for sysctl sunrpc.transports (Benjamin Coddington) [1949575]
- NFSv4.2: support EXCHGID4_FLAG_SUPP_FENCE_OPS 4.2 EXCHANGE_ID flag (Benjamin Coddington) [1949575]
- NFSv4: Fix up RCU annotations for struct nfs_netns_client (Benjamin Coddington) [1949575]
- NFS: Only reference user namespace from nfs4idmap struct instead of cred (Benjamin Coddington) [1949575]
- NFSD: Hoist status code encoding into XDR encoder functions (Benjamin Coddington) [1949575]
- NFSv4: Use the net namespace uniquifier if it is set (Benjamin Coddington) [1949575]
- NFSv4: Clean up initialisation of uniquified client id strings (Benjamin Coddington) [1949575]
- SUNRPC: Add an xdr_align_data() function (Benjamin Coddington) [1949575]
- SUNRPC: Add the ability to expand holes in data pages (Benjamin Coddington) [1949575]
- SUNRPC: Split out _shift_data_right_tail() (Benjamin Coddington) [1949575]
- SUNRPC: Split out xdr_realign_pages() from xdr_align_pages() (Benjamin Coddington) [1949575]
- NFS: Use xdr_page_pos() in NFSv4 decode_getacl() (Benjamin Coddington) [1949575]
- SUNRPC: Implement a xdr_page_pos() function (Benjamin Coddington) [1949575]
- NFS: fix nfs_path in case of a rename retry (Benjamin Coddington) [1949575]
- NFSD: Map nfserr_wrongsec outside of nfsd_dispatch (Benjamin Coddington) [1949575]
- NFSD: Remove the RETURN_STATUS() macro (Benjamin Coddington) [1949575]
- NFSD: Call NFSv2 encoders on error returns (Benjamin Coddington) [1949575]
- NFSD: Fix .pc_release method for NFSv2 (Benjamin Coddington) [1949575]
- NFSD: Remove vestigial typedefs (Benjamin Coddington) [1949575]
- NFSD: Refactor nfsd_dispatch() error paths (Benjamin Coddington) [1949575]
- NFSD: Clean up nfsd_dispatch() variables (Benjamin Coddington) [1949575]
- NFSD: Clean up stale comments in nfsd_dispatch() (Benjamin Coddington) [1949575]
- NFSD: Clean up switch statement in nfsd_dispatch() (Benjamin Coddington) [1949575]
- NFSD: Encoder and decoder functions are always present (Benjamin Coddington) [1949575]
- NFSACL: Replace PROC() macro with open code (Benjamin Coddington) [1949575]
- lockd: Replace PROC() macro with open code (Benjamin Coddington) [1949575]
- NFSD: Add missing NFSv2 .pc_func methods (Benjamin Coddington) [1949575]
- fs: nfs: return per memcg count for xattr shrinkers (Benjamin Coddington) [1949575]
- nfs: remove incorrect fallthrough label (Benjamin Coddington) [1949575]
- nfsd: rq_lease_breaker cleanup (Benjamin Coddington) [1949575]
- sunrpc: simplify do_cache_clean (Benjamin Coddington) [1949575]
- sunrpc: cache : Replace seq_printf with seq_puts (Benjamin Coddington) [1949575]
- silence nfscache allocation warnings with kvzalloc (Benjamin Coddington) [1949575]
- nfsd: fix comparison to bool warning (Benjamin Coddington) [1949575]
- NFSD: Correct type annotations in user xattr XDR functions (Benjamin Coddington) [1949575]
- NFSD: Correct type annotations in user xattr helpers (Benjamin Coddington) [1949575]
- SUNRPC/NFSD: Implement xdr_reserve_space_vec() (Benjamin Coddington) [1949575]
- nfsd: rename delegation related tracepoints to make them less confusing (Benjamin Coddington) [1949575]
- nfsd: Remove unnecessary assignment in nfs4xdr.c (Benjamin Coddington) [1949575]
- net: sunrpc: delete repeated words (Benjamin Coddington) [1949575]
- nfsd: Fix typo in comment (Benjamin Coddington) [1949575]
- nfsd: give up callbacks on revoked delegations (Benjamin Coddington) [1949575]
- nfs: fix spellint typo in pnfs.c (Benjamin Coddington) [1949575]
- fs,nfs: lift compat nfs4 mount data handling into the nfs code (Benjamin Coddington) [1949575]
- nfs: simplify nfs4_parse_monolithic (Benjamin Coddington) [1949575]
- xprtrdma: drop double zeroing (Benjamin Coddington) [1949575]
- NFSv4.2: xattr cache: remove unused cache struct field (Benjamin Coddington) [1949575]
- nfs: Convert to use the preferred fallthrough macro (Benjamin Coddington) [1949575]
- NFS4: Fix oops when copy_file_range is attempted with NFS4.0 source (Benjamin Coddington) [1949575]
- Replace HTTP links with HTTPS ones: NFS, SUNRPC, and LOCKD clients (Benjamin Coddington) [1949575]
- sunrpc: fix duplicated word in <linux/sunrpc/cache.h> (Benjamin Coddington) [1949575]
- SUNRPC: Remove remaining dprintks from sched.c (Benjamin Coddington) [1949575]
- SUNRPC: Remove dprintk call sites in RPC queuing functions (Benjamin Coddington) [1949575]
- SUNRPC: Clean up RPC scheduler tracepoints (Benjamin Coddington) [1949575]
- SUNRPC: Replace rpcbind dprintk call sites with tracepoints (Benjamin Coddington) [1949575]
- SUNRPC: Remove more dprintks in rpcb_clnt.c (Benjamin Coddington) [1949575]
- SUNRPC: Remove dprintk call sites in rpcbind XDR functions (Benjamin Coddington) [1949575]
- SUNRPC: Hoist trace_xprtrdma_op_setport into generic code (Benjamin Coddington) [1949575]
- SUNRPC: Remove rpcb_getport_async dprintk call sites (Benjamin Coddington) [1949575]
- SUNRPC: Clean up call_bind_status() observability (Benjamin Coddington) [1949575]
- SUNRPC: Remove dprintk call site in call_decode (Benjamin Coddington) [1949575]
- SUNRPC: Trace call_refresh events (Benjamin Coddington) [1949575]
- SUNRPC: Add trace_rpc_timeout_status() (Benjamin Coddington) [1949575]
- SUNRPC: Mitigate cond_resched() in xprt_transmit() (Benjamin Coddington) [1949575]
- SUNRPC: Replace connect dprintk call sites with a tracepoint (Benjamin Coddington) [1949575]
- SUNRPC: Remove dprintk call site in call_start() (Benjamin Coddington) [1949575]
- SUNRPC: Remove the dprint_status() macro (Benjamin Coddington) [1949575]
- SUNRPC: Replace dprintk() call site in xs_nospace() (Benjamin Coddington) [1949575]
- SUNRPC: Replace dprintk() call site in xprt_prepare_transmit (Benjamin Coddington) [1949575]
- SUNRPC: Update debugging instrumentation in xprt_do_reserve() (Benjamin Coddington) [1949575]
- SUNRPC: Remove debugging instrumentation from xprt_release (Benjamin Coddington) [1949575]
- SUNRPC: Hoist trace_xprtrdma_op_allocate into generic code (Benjamin Coddington) [1949575]
- SUNRPC: Remove trace_xprt_complete_rqst() (Benjamin Coddington) [1949575]
- SUNRPC dont update timeout value on connection reset (Benjamin Coddington) [1949575]
- nfs4: strengthen error check to avoid unexpected result (Benjamin Coddington) [1949575]
- NFS: remove redundant pointer clnt (Benjamin Coddington) [1949575]
- sunrpc: Avoid comma separated statements (Benjamin Coddington) [1949575]

* Tue May 25 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-309.el8]
- Revert "sctp: Fix SHUTDOWN CTSN Ack in the peer restart case" (Xin Long) [1953839]
- sctp: do asoc update earlier in sctp_sf_do_dupcook_b (Xin Long) [1953839]
- sctp: do asoc update earlier in sctp_sf_do_dupcook_a (Xin Long) [1953839]
- NFSv4: Fixes for nfs4_bitmask_adjust() (Steve Dickson) [1926961]
- powerpc/paravirt: Use is_kvm_guest() in vcpu_is_preempted() (Desnes A. Nunes do Rosario) [1918720]
- powerpc: Reintroduce is_kvm_guest() as a fast-path check (Desnes A. Nunes do Rosario) [1918720]
- powerpc: Rename is_kvm_guest() to check_kvm_guest() (Desnes A. Nunes do Rosario) [1918720]
- powerpc: Refactor is_kvm_guest() declaration to new header (Desnes A. Nunes do Rosario) [1918720]
- powerpc/pseries: Move some PAPR paravirt functions to their own file (Desnes A. Nunes do Rosario) [1918720]
- powerpc/shared: Use static key to detect shared processor (Desnes A. Nunes do Rosario) [1918720]
- powerpc/spinlocks: Fix oops in __spin_yield() on bare metal (Desnes A. Nunes do Rosario) [1918720]
- powerpc/spinlocks: Rename SPLPAR-only spinlocks (Desnes A. Nunes do Rosario) [1918720]
- powerpc/spinlocks: Refactor SHARED_PROCESSOR (Desnes A. Nunes do Rosario) [1918720]
- Revert "ACPICA: Interpreter: fix memory leak by using existing buffer" (Mark Langsdorf) [1935928]
- x86/efi: Remove EFI PGD build time checks (Mark Langsdorf) [1935928]
- ACPI: scan: Fix battery devices sometimes never binding (Mark Langsdorf) [1935928]
- ACPI/IORT: Do not blindly trust DMA masks from firmware (Mark Langsdorf) [1935928]
- ACPI: thermal: Do not call acpi_thermal_check() directly (Mark Langsdorf) [1935928]
- ACPI: sysfs: Prefer "compatible" modalias (Mark Langsdorf) [1935928]
- ACPI: scan: Make acpi_bus_get_device() clear return pointer on error (Mark Langsdorf) [1935928]
- ACPI: scan: Harden acpi_device_add() against device ID overflows (Mark Langsdorf) [1935928]
- ACPI: Update Kconfig help text for items that are no longer modular (Mark Langsdorf) [1935928]
- ACPI: PM: s2idle: Drop unused local variables and related code (Mark Langsdorf) [1935928]
- ACPI: PM: s2idle: Move x86-specific code to the x86 directory (Mark Langsdorf) [1935928]
- ACPI: scan: Add Intel Baytrail Mailbox Device to acpi_ignore_dep_ids (Mark Langsdorf) [1935928]
- ACPI: scan: Avoid unnecessary second pass in acpi_bus_scan() (Mark Langsdorf) [1935928]
- ACPI: scan: Defer enumeration of devices with _DEP lists (Mark Langsdorf) [1935928]
- ACPI: scan: Evaluate _DEP before adding the device (Mark Langsdorf) [1935928]
- ACPI: PM: s2idle: Add AMD support to handle _DSM (Mark Langsdorf) [1935928]
- ACPI: processor: fix NONE coordination for domain mapping failure (Mark Langsdorf) [1935928]
- cpufreq: Fix cpufreq_online() return value on errors (Mark Langsdorf) [1935928]
- opp: of: Allow empty opp-table with opp-shared (Mark Langsdorf) [1935928]
- dt-bindings: opp: Allow empty OPP tables (Mark Langsdorf) [1935928]
- ACPI: Drop acpi_dev_irqresource_disabled() (Mark Langsdorf) [1935928]
- resource: Add irqresource_disabled() (Mark Langsdorf) [1935928]
- genirq/affinity: Add irq_update_affinity_desc() (Mark Langsdorf) [1935928]
- driver core: Add fwnode_init() (Mark Langsdorf) [1935928]
- ACPI: scan: Fix up _DEP-related terminology with supplier/consumer (Mark Langsdorf) [1935928]
- ACPI: scan: Drop INT3396 from acpi_ignore_dep_ids[] (Mark Langsdorf) [1935928]
- Revert "ACPI / resources: Use AE_CTRL_TERMINATE to terminate resources walks" (Mark Langsdorf) [1935928]
- ACPI: scan: Add PNP0D80 to the _DEP exceptions list (Mark Langsdorf) [1935928]
- PM: ACPI: Refresh wakeup device power configuration every time (Mark Langsdorf) [1935928]
- PM: ACPI: PCI: Drop acpi_pm_set_bridge_wakeup() (Mark Langsdorf) [1935928]
- ACPI: scan: Call acpi_get_object_info() from acpi_add_single_object() (Mark Langsdorf) [1935928]
- ACPI: scan: Add acpi_info_matches_hids() helper (Mark Langsdorf) [1935928]
- ACPICA: Update version to 20201113 (Mark Langsdorf) [1935928]
- ACPICA: Interpreter: fix memory leak by using existing buffer (Mark Langsdorf) [1935928]
- ACPICA: Add function trace macros to improve debugging (Mark Langsdorf) [1935928]
- ACPICA: Also handle "orphan" _REG methods for GPIO OpRegions (Mark Langsdorf) [1935928]
- ACPICA: Remove extreaneous "the" in comments (Mark Langsdorf) [1935928]
- ACPICA: Add 5 new UUIDs to the known UUID table (Mark Langsdorf) [1935928]
- ACPI: processor: Drop duplicate setting of shared_cpu_map (Mark Langsdorf) [1935928]
- ACPI: EC: Clean up status flags checks in advance_transaction() (Mark Langsdorf) [1935928]
- ACPI: EC: Untangle error handling in advance_transaction() (Mark Langsdorf) [1935928]
- ACPI: EC: Simplify error handling in advance_transaction() (Mark Langsdorf) [1935928]
- ACPI: EC: Rename acpi_ec_is_gpe_raised() (Mark Langsdorf) [1935928]
- ACPI: EC: Fold acpi_ec_clear_gpe() into its caller (Mark Langsdorf) [1935928]
- ACPI: EC: Eliminate in_interrupt() usage (Mark Langsdorf) [1935928]
- ACPI: acpi_drivers.h: Update the kernel doc (Mark Langsdorf) [1935928]
- ACPI: acpi_drivers.h: Remove the leftover dead code (Mark Langsdorf) [1935928]
- ACPI: tiny-power-button: Simplify the code using module_acpi_driver() (Mark Langsdorf) [1935928]
- ACPI: SBS: Simplify the code using module_acpi_driver() (Mark Langsdorf) [1935928]
- ACPI: SBS: Simplify the driver init code (Mark Langsdorf) [1935928]
- ACPI: debug: Remove the not used function (Mark Langsdorf) [1935928]
- ACPI: processor: Remove the duplicated ACPI_PROCESSOR_CLASS macro (Mark Langsdorf) [1935928]
- ACPI: watchdog: Replace open coded variant of resource_union() (Mark Langsdorf) [1935928]
- PCI/ACPI: Replace open coded variant of resource_union() (Mark Langsdorf) [1935928]
- resource: Introduce resource_union() for overlapping resources (Mark Langsdorf) [1935928]
- resource: Group resource_overlaps() with other inline helpers (Mark Langsdorf) [1935928]
- resource: Simplify region_intersects() by reducing conditionals (Mark Langsdorf) [1935928]
- ACPI, APEI: make apei_resources_all static (Mark Langsdorf) [1935928]
- mm/mmu_notifier: allocate mmu_notifier_rh in __mmu_notifier_register() (Jeremy Cline) [1909072]

* Mon May 24 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-308.el8]
- Amends commit ea6244cc248b to include a version string in module info. (Ken Cox) [1955726]
- i40e: use minimal admin queue for kdump (Stefan Assmann) [1834962]
- i40e: use minimal Rx and Tx ring buffers for kdump (Stefan Assmann) [1834962]
- i40e: use minimal Tx and Rx pairs for kdump (Stefan Assmann) [1834962]
- net/sched: sch_frag: fix stack OOB read while fragmenting IPv4 packets (Davide Caratti) [1924608]
- openvswitch: fix stack OOB read while fragmenting IPv4 packets (Davide Caratti) [1924608]
- net/sched: act_ct: fix wild memory access when clearing fragments (Davide Caratti) [1924608]
- selinux: fall back to SECURITY_FS_USE_GENFS if no xattr support (Ondrej Mosnacek) [1934093 1915825]
- selinux: mark some global variables __ro_after_init (Ondrej Mosnacek) [1934093]
- selinux: make selinuxfs_mount static (Ondrej Mosnacek) [1934093]
- selinux: drop the unnecessary aurule_callback variable (Ondrej Mosnacek) [1934093]
- selinux: remove unused global variables (Ondrej Mosnacek) [1934093]
- selinux: fix inconsistency between inode_getxattr and inode_listsecurity (Ondrej Mosnacek) [1934093]
- selinux: Fix fall-through warnings for Clang (Ondrej Mosnacek) [1934093]
- selinux: fix inode_doinit_with_dentry() LABEL_INVALID error handling (Ondrej Mosnacek) [1934093]
- selinux: allow dontauditx and auditallowx rules to take effect without allowx (Ondrej Mosnacek) [1934093]
- selinux: fix error initialization in inode_doinit_with_dentry() (Ondrej Mosnacek) [1934093]
- selinux: Fix error return code in sel_ib_pkey_sid_slow() (Ondrej Mosnacek) [1934093]
- selinux: access policycaps with READ_ONCE/WRITE_ONCE (Ondrej Mosnacek) [1934093]
- selinux: delete repeated words in comments (Ondrej Mosnacek) [1934093]
- selinux: add basic filtering for audit trace events (Ondrej Mosnacek) [1934093 1954024]
- selinux: add tracepoint on audited events (Ondrej Mosnacek) [1934093 1954024]
- selinux: permit removing security.selinux xattr before policy load (Ondrej Mosnacek) [1934093]
- exec: Always set cap_ambient in cap_bprm_set_creds (Ondrej Mosnacek) [1934093]
- security: remove duplicated include from security.h (Ondrej Mosnacek) [1934093]
- security/commoncap: Use xattr security prefix len (Ondrej Mosnacek) [1934093]
- LSM: switch to blocking policy update notifiers (Ondrej Mosnacek) [1934093]
- security: Make capability_hooks static (Ondrej Mosnacek) [1934093]
- securityfs: fix use-after-free on symlink traversal (Ondrej Mosnacek) [1934093]
- LSM: Check for NULL cred-security on free (Ondrej Mosnacek) [1934093]
- security: check for kstrdup() failure in lsm_append() (Ondrej Mosnacek) [1934093]
- scsi: mpt3sas: Block PCI config access from userspace during reset (Tomas Henzl) [1954555]
- scsi: mpt3sas: Fix endianness for ActiveCablePowerRequirement (Tomas Henzl) [1954555]
- scsi: mpt3sas: Fix error return code of mpt3sas_base_attach() (Tomas Henzl) [1954555]
- scsi: mpt3sas: Do not use GFP_KERNEL in atomic context (Tomas Henzl) [1954555]
- scsi: mpt3sas: Only one vSES is present even when IOC has multi vSES (Tomas Henzl) [1953421]
- scsi: bnx2i: Make bnx2i_process_iscsi_error() simpler and more robust (Nilesh Javali) [1921612]
- scsi: bnx2i: Fix bnx2i_set_ccell_info()'s name in description (Nilesh Javali) [1921612]
- scsi: bnx2i: Requires MMU (Nilesh Javali) [1921612]
- scsi: bnx2i: Remove unnecessary mutex_init() (Nilesh Javali) [1921612]
- scsi: bnx2i: Add parameter description and rename another (Nilesh Javali) [1921612]
- scsi: bnx2i: Add, remove and edit some function parameter descriptions (Nilesh Javali) [1921612]
- scsi: bnx2i: Fix a whole host of kerneldoc issues (Nilesh Javali) [1921612]
- scsi: bnx2i: Add missing descriptions for 'attr' parameter (Nilesh Javali) [1921612]
- scsi: bnx2i: Fix parameter misnaming in function header (Nilesh Javali) [1921612]
- mfd: intel-lpss: Add Intel Alder Lake PCH-P PCI IDs (Steve Best) [1929489]
- lib: list_sort.c: add a blank line to avoid kernel-doc warnings (Rafael Aquini) [1900774]
- lib/list_sort: fix kerneldoc build error (Rafael Aquini) [1900774]
- lib/list_sort: optimize number of calls to comparison function (Rafael Aquini) [1900774]
- lib/list_sort: simplify and remove MAX_LIST_LENGTH_BITS (Rafael Aquini) [1900774]
- perf bench numa: Fix the condition checks for max number of NUMA nodes (Steve Best) [1936333]
- powerpc/perf: Record counter overflow always if SAMPLE_IP is unset (Gustavo Walbon) [1921684]
- perf powerpc: Support exposing Performance Monitor Counter SPRs as part of extended regs (Gustavo Walbon) [1921684]
- powerpc/perf: Expose Performance Monitor Counter SPR's as part of extended regs (Gustavo Walbon) [1921684]
- powerpc/perf: Include PMCs as part of per-cpu cpuhw_events struct (Gustavo Walbon) [1921684]
- powerpc/perf: Adds support for programming of Thresholding in P10 (Gustavo Walbon) [1921684]
- x86/entry/64: Deduplicate multiple IBRS macros in paranoid_entry (Waiman Long) [1924364]
- x86/speculation: Fix prctl() when spectre_v2_user={seccomp,prctl},ibpb (Waiman Long) [1924364]
- x86/speculation: Allow IBPB to be conditionally enabled on CPUs with always-on STIBP (Waiman Long) [1924364]
- x86/bugs/multihit: Fix mitigation reporting when VMX is not in use (Waiman Long) [1924364]
- x86/speculation: Merge one test in spectre_v2_user_select_mitigation() (Waiman Long) [1924364]
- x86/bugs: Move enum taa_mitigations to bugs.c (Waiman Long) [1924364]
- mm/memcg: set memcg when splitting page (Waiman Long) [1937825]
- mm/memcg: rename mem_cgroup_split_huge_fixup to split_page_memcg and add nr_pages argument (Waiman Long) [1937825]
- mm, tracing: Fix kmem_cache_free trace event to not print stale pointers (Waiman Long) [1937825]
- mm: memcontrol: fix get_active_memcg return value (Waiman Long) [1937825]
- fs: buffer: use raw page_memcg() on locked page (Waiman Long) [1937825]
- mm/list_lru.c: remove kvfree_rcu_local() (Waiman Long) [1937825]
- mm: memcontrol: replace the loop with a list_for_each_entry() (Waiman Long) [1937825]
- mm/memcontrol: remove redundant NULL check (Waiman Long) [1937825]
- mm: page_counter: re-layout structure to reduce false sharing (Waiman Long) [1937825]
- mm: kmem: make __memcg_kmem_(un)charge static (Waiman Long) [1937825]
- mm: memcg: add swapcache stat for memcg v2 (Waiman Long) [1937825]
- mm/memcg: remove rcu locking for lock_page_lruvec function series (Waiman Long) [1937825]
- mm/memcg: revise the using condition of lock_page_lruvec function series (Waiman Long) [1937825]
- mm: memcontrol: make the slab calculation consistent (Waiman Long) [1937825]
- mm: memcontrol: convert NR_FILE_PMDMAPPED account to pages (Waiman Long) [1937825]
- mm: memcontrol: convert NR_SHMEM_PMDMAPPED account to pages (Waiman Long) [1937825]
- mm: memcontrol: convert NR_SHMEM_THPS account to pages (Waiman Long) [1937825]
- mm: memcontrol: convert NR_FILE_THPS account to pages (Waiman Long) [1937825]
- mm: memcontrol: convert NR_ANON_THPS account to pages (Waiman Long) [1937825]
- mm: memcontrol: optimize per-lruvec stats counter memory usage (Waiman Long) [1937825]
- mm: memcg/slab: pre-allocate obj_cgroups for slab caches with SLAB_ACCOUNT (Waiman Long) [1937825]
- mm/slub: minor coding style tweaks (Waiman Long) [1937825]
- mm, slub: remove slub_memcg_sysfs boot param and CONFIG_SLUB_MEMCG_SYSFS_ON (Waiman Long) [1937825]
- mm, slub: splice cpu and page freelists in deactivate_slab() (Waiman Long) [1937825]
- mm, slab, slub: stop taking cpu hotplug lock (Waiman Long) [1937825]
- mm, slab, slub: stop taking memory hotplug lock (Waiman Long) [1937825]
- mm, slub: stop freeing kmem_cache_node structures on node offline (Waiman Long) [1937825]
- mm/slub: disable user tracing for kmemleak caches by default (Waiman Long) [1937825]
- mm/slab: minor coding style tweaks (Waiman Long) [1937825]
- mm/sl?b.c: remove ctor argument from kmem_cache_flags (Waiman Long) [1937825]
- mm, tracing: record slab name for kmem_cache_free() (Waiman Long) [1937825]
- mm: fix numa stats for thp migration (Waiman Long) [1937825]
- mm: memcg: fix memcg file_dirty numa stat (Waiman Long) [1937825]
- mm/memcontrol: fix warning in mem_cgroup_page_lruvec() (Waiman Long) [1937825]
- mm: slub: call account_slab_page() after slab page initialization (Waiman Long) [1937825]
- mm/hugetlb: fix deadlock in hugetlb_cow error path (Waiman Long) [1937825]
- mm/memcontrol:rewrite mem_cgroup_page_lruvec() (Waiman Long) [1937825]
- mm/memcg: remove unused definitions (Waiman Long) [1937825]
- mm/memcg: warning on !memcg after readahead page charged (Waiman Long) [1937825]
- mm/memcg: bail early from swap accounting if memcg disabled (Waiman Long) [1937825]
- mm/lru: revise the comments of lru_lock (Waiman Long) [1937825]
- mm/lru: introduce relock_page_lruvec() (Waiman Long) [1937825]
- mm/lru: replace pgdat lru_lock with lruvec lock (Waiman Long) [1937825]
- mm/lru: move lock into lru_note_cost (Waiman Long) [1937825]
- mm/swap.c: serialize memcg changes in pagevec_lru_move_fn (Waiman Long) [1937825]
- mm/compaction: do page isolation first in compaction (Waiman Long) [1937825]
- mm/lru: introduce TestClearPageLRU() (Waiman Long) [1937825]
- mm/mlock: remove __munlock_isolate_lru_page() (Waiman Long) [1937825]
- mm/mlock: remove lru_lock on TestClearPageMlocked (Waiman Long) [1937825]
- mm/vmscan: remove lruvec reget in move_pages_to_lru (Waiman Long) [1937825]
- mm/swap.c: fold vm event PGROTATED into pagevec_move_tail_fn (Waiman Long) [1937825]
- mm/memcg: add debug checking in lock_page_memcg (Waiman Long) [1937825]
- mm: page_idle_get_page() does not need lru_lock (Waiman Long) [1937825]
- mm/rmap: stop store reordering issue on page->mapping (Waiman Long) [1937825]
- mm/vmscan: remove unnecessary lruvec adding (Waiman Long) [1937825]
- mm/thp: narrow lru locking (Waiman Long) [1937825]
- mm/thp: simplify lru_add_page_tail() (Waiman Long) [1937825]
- mm/thp: use head for head page in lru_add_page_tail() (Waiman Long) [1937825]
- mm/thp: move lru_add_page_tail() to huge_memory.c (Waiman Long) [1937825]
- mm: slub: convert sysfs sprintf family to sysfs_emit/sysfs_emit_at (Waiman Long) [1937825]
- mm: truncate_complete_page() does not exist any more (Waiman Long) [1937825]
- mm/vmscan: drop unneeded assignment in kswapd() (Waiman Long) [1937825]
- mm: memcontrol: account pagetables per node (Waiman Long) [1937825]
- mm: move lruvec stats update functions to vmstat.h (Waiman Long) [1937825]
- mm/memcg: remove incorrect comment (Waiman Long) [1937825]
- mm: memcontrol: sssign boolean values to a bool variable (Waiman Long) [1937825]
- mm: memcg/slab: rename *_lruvec_slab_state to *_lruvec_kmem_state (Waiman Long) [1937825]
- mm: memcg: remove obsolete memcg_has_children() (Waiman Long) [1937825]
- mm/page_counter: use page_counter_read in page_counter_set_max (Waiman Long) [1937825]
- cgroup: remove obsoleted broken_hierarchy and warned_broken_hierarchy (Waiman Long) [1937825]
- docs: cgroup-v1: reflect the deprecation of the non-hierarchical mode (Waiman Long) [1937825]
- mm: memcg: deprecate the non-hierarchical mode (Waiman Long) [1937825]
- mm: memcg: fix obsolete code comments (Waiman Long) [1937825]
- mm/memcg: update page struct member in comments (Waiman Long) [1937825]
- mm/rmap: always do TTU_IGNORE_ACCESS (Waiman Long) [1937825]
- mm: memcontrol: eliminate redundant check in __mem_cgroup_insert_exceeded() (Waiman Long) [1937825]
- mm: memcontrol: remove unused mod_memcg_obj_state() (Waiman Long) [1937825]
- mm: memcontrol: add file_thp, shmem_thp to memory.stat (Waiman Long) [1937825]
- mm/gup: combine put_compound_head() and unpin_user_page() (Waiman Long) [1937825]
- mm: Convert page kmemcg type to a page memcg flag (Waiman Long) [1937825]
- mm: Introduce page memcg flags (Waiman Long) [1937825]
- mm: memcontrol/slab: Use helpers to access slab page's memcg_data (Waiman Long) [1937825]
- mm: memcontrol: Use helpers to read page's memcg data (Waiman Long) [1937825]
- hugetlbfs: fix anon huge page migration race (Waiman Long) [1937825]
- mm: memcontrol: fix missing wakeup polling thread (Waiman Long) [1937825]
- mm/gup: use unpin_user_pages() in __gup_longterm_locked() (Waiman Long) [1937825]
- mm/vmscan: fix NR_ISOLATED_FILE corruption on 64-bit (Waiman Long) [1937825]
- mm/compaction: stop isolation if too many pages are isolated and we have pages to migrate (Waiman Long) [1937825]
- mm/compaction: count pages and stop correctly during page isolation (Waiman Long) [1937825]
- mm: kmem: enable kernel memcg accounting from interrupt contexts (Waiman Long) [1937825]
- mm: kmem: prepare remote memcg charging infra for interrupt contexts (Waiman Long) [1937825]
- mm: kmem: remove redundant checks from get_obj_cgroup_from_current() (Waiman Long) [1937825]
- mm, memcg: rework remote charging API to support nesting (Waiman Long) [1937825]
- mm: use self-explanatory macros rather than "2" (Waiman Long) [1937825]
- mm/vmscan: allow arbitrary sized pages to be paged out (Waiman Long) [1937825]
- mm/rmap: fix assumptions of THP size (Waiman Long) [1937825]
- mm/huge_memory: fix can_split_huge_page assumption of THP size (Waiman Long) [1937825]
- mm/huge_memory: fix page_trans_huge_mapcount assumption of THP size (Waiman Long) [1937825]
- mm/huge_memory: fix split assumption of page size (Waiman Long) [1937825]
- mm/huge_memory: fix total_mapcount assumption of page size (Waiman Long) [1937825]
- mm/page_owner: change split_page_owner to take a count (Waiman Long) [1937825]
- mm/memory: remove page fault assumption of compound page size (Waiman Long) [1937825]
- mm/filemap: fix page cache removal for arbitrary sized THPs (Waiman Long) [1937825]
- mm/vmscan: fix comments for isolate_lru_page() (Waiman Long) [1937825]
- mm/vmscan: fix infinite loop in drop_slab_node (Waiman Long) [1937825]
- mm: move call to compound_head() in release_pages() (Waiman Long) [1937825]
- mm: account PMD tables like PTE tables (Waiman Long) [1937825]
- mm/memcg: fix device private memcg accounting (Waiman Long) [1937825]
- mm: memcontrol: add the missing numa_stat interface for cgroup v2 (Waiman Long) [1937825]
- mm: remove activate_page() from unuse_pte() (Waiman Long) [1937825]
- bdi: replace BDI_CAP_NO_{WRITEBACK,ACCT_DIRTY} with a single flag (Waiman Long) [1937825]
- mm/thp: fix __split_huge_pmd_locked() for migration PMD (Waiman Long) [1937825]
- mm: fix check_move_unevictable_pages() on THP (Waiman Long) [1937825]
- mm: migration of hugetlbfs page skip memcg (Waiman Long) [1937825]
- mm: and drivers core: Convert hugetlb_report_node_meminfo to sysfs_emit (Waiman Long) [1937825]
- drivers core: Miscellaneous changes for sysfs_emit (Waiman Long) [1937825]
- drivers core: Reindent a couple uses around sysfs_emit (Waiman Long) [1937825]
- drivers core: Remove strcat uses around sysfs_emit and neaten (Waiman Long) [1937825]
- drivers core: Use sysfs_emit and sysfs_emit_at for show(device *...) functions (Waiman Long) [1937825]
- sysfs: Add sysfs_emit and sysfs_emit_at to format sysfs output (Waiman Long) [1937825]
- mm: fix pin vs. gup mismatch with gate pages (Waiman Long) [1937825]
- mm/gup: use a standard migration target allocation callback (Waiman Long) [1937825]
- mm/hugetlb: make hugetlb migration callback CMA aware (Waiman Long) [1937825]
- mm/gup: restrict CMA region by using allocation scope API (Waiman Long) [1937825]
- mm/page_alloc: remove a wrapper for alloc_migration_target() (Waiman Long) [1937825]
- mm/mempolicy: use a standard migration target allocation callback (Waiman Long) [1937825]
- mm/migrate: introduce a standard migration target allocation function (Waiman Long) [1937825]
- mm/migrate: clear __GFP_RECLAIM to make the migration callback consistent with regular THP allocations (Waiman Long) [1937825]
- mm/hugetlb: unify migration callbacks (Waiman Long) [1937825]
- mm/migrate: move migration helper from .h to .c (Waiman Long) [1937825]
- mm/page_isolation: prefer the node of the source page (Waiman Long) [1937825]
- hugetlbfs: remove call to huge_pte_alloc without i_mmap_rwsem (Waiman Long) [1937825]
- mm, oom: show process exiting information in __oom_kill_process() (Waiman Long) [1937825]
- doc, mm: clarify /proc/<pid>/oom_score value range (Waiman Long) [1937825]
- doc, mm: sync up oom_score_adj documentation (Waiman Long) [1937825]
- mm, oom: make the calculation of oom badness more accurate (Waiman Long) [1937825]
- mm: vmscan: consistent update to pgrefill (Waiman Long) [1937825]
- mm/vmscan.c: fix typo (Waiman Long) [1937825]
- mm: memcontrol: account kernel stack per node (Waiman Long) [1937825]
- mm/hugetlb.c: fix pages per hugetlb calculation (Waiman Long) [1937825]
- doc: THP CoW fault no longer allocate THP (Waiman Long) [1937825]
- driver core: platform: expose numa_node to users in sysfs (Waiman Long) [1937825]
- nilfs2: fix null pointer dereference at nilfs_segctor_do_construct() (Waiman Long) [1937825]
- mm, memcg: fix some typos in memcontrol.c (Waiman Long) [1937825]
- mm/vmsan: fix some typos in comment (Waiman Long) [1937825]
- mm: thp: don't need to drain lru cache when splitting and mlocking THP (Waiman Long) [1937825]
- mm/vmscan: update the comment of should_continue_reclaim() (Waiman Long) [1937825]
- mm/vmscan.c: change prototype for shrink_page_list (Waiman Long) [1937825]
- mm/vmscan: count layzfree pages and fix nr_isolated_* mismatch (Waiman Long) [1937825]
- mm/vmscan.c: use update_lru_size() in update_lru_sizes() (Waiman Long) [1937825]
- mm: simplify calling a compound page destructor (Waiman Long) [1937825]
- mm/page_alloc: integrate classzone_idx and high_zoneidx (Waiman Long) [1937825]
- mm/page_alloc: use ac->high_zoneidx for classzone_idx (Waiman Long) [1937825]
- mm/page_alloc.c: extract check_[new|free]_page_bad() common part to page_bad_reason() (Waiman Long) [1937825]
- mm/page_alloc.c: rename free_pages_check() to check_free_page() (Waiman Long) [1937825]
- mm/page_alloc.c: rename free_pages_check_bad() to check_free_page_bad() (Waiman Long) [1937825]
- mm/page_alloc.c: bad_flags is not necessary for bad_page() (Waiman Long) [1937825]
- mm/page_alloc.c: bad_[reason|flags] is not necessary when PageHWPoison (Waiman Long) [1937825]
- scs: Report SCS usage in bytes rather than number of entries (Waiman Long) [1937825]
- scs: Move accounting into alloc/free functions (Waiman Long) [1937825]
- mm/vmscan: remove unnecessary argument description of isolate_lru_pages() (Waiman Long) [1937825]
- scs: Add support for stack usage debugging (Waiman Long) [1937825]
- scs: Add page accounting for shadow call stack allocations (Waiman Long) [1937825]
- scs: Add support for Clang's Shadow Call Stack (SCS) (Waiman Long) [1937825]
- mm/migrate.c: unify "not queued for migration" handling in do_pages_move() (Waiman Long) [1937825]
- mm/migrate.c: check pagelist in move_pages_and_store_status() (Waiman Long) [1937825]
- mm/migrate.c: wrap do_move_pages_to_node() and store_status() (Waiman Long) [1937825]
- mm/migrate.c: no need to check for i > start in do_pages_move() (Waiman Long) [1937825]
- mm/hugetlb: remove unnecessary memory fetch in PageHeadHuge() (Waiman Long) [1937825]
- hugetlbfs: Use i_mmap_rwsem to address page fault/truncate race (Waiman Long) [1937825]
- hugetlbfs: use i_mmap_rwsem for more pmd sharing synchronization (Waiman Long) [1937825]
- mm,thp,compaction,cma: allow THP migration for CMA allocations (Waiman Long) [1937825]
- mm,compaction,cma: add alloc_contig flag to compact_control (Waiman Long) [1937825]
- mm/vmscan.c: do_try_to_free_pages(): clean code by removing unnecessary assignment (Waiman Long) [1937825]
- mm/vmscan.c: make may_enter_fs bool in shrink_page_list() (Waiman Long) [1937825]
- mm/vmscan.c: fix data races using kswapd_classzone_idx (Waiman Long) [1937825]
- mm/vmscan.c: remove cpu online notification for now (Waiman Long) [1937825]
- mm: vmscan: replace open codings to NUMA_NO_NODE (Waiman Long) [1937825]
- mm: swap: make page_evictable() inline (Waiman Long) [1937825]
- mm/swap.c: not necessary to export __pagevec_lru_add() (Waiman Long) [1937825]
- mm/gup: fix omission of check on FOLL_LONGTERM in gup fast path (Waiman Long) [1937825]
- mm: dump_page(): additional diagnostics for huge pinned pages (Waiman Long) [1937825]
- mm: improve dump_page() for compound pages (Waiman Long) [1937825]
- selftests/vm: run_vmtests: invoke gup_benchmark with basic FOLL_PIN coverage (Waiman Long) [1937825]
- mm/gup_benchmark: support pin_user_pages() and related calls (Waiman Long) [1937825]
- mm/gup: /proc/vmstat: pin_user_pages (FOLL_PIN) reporting (Waiman Long) [1937825]
- mm/gup: page->hpage_pinned_refcount: exact pin counts for huge pages (Waiman Long) [1937825]
- mm/gup: track FOLL_PIN pages (Waiman Long) [1937825]
- mm/gup: pass gup flags to two more routines (Waiman Long) [1937825]
- mm: introduce page_ref_sub_return() (Waiman Long) [1937825]
- mm/gup: pass a flags arg to __gup_device_* functions (Waiman Long) [1937825]
- mm/gup: split get_user_pages_remote() into two routines (Waiman Long) [1937825]
- sysfs: fix static inline declaration of sysfs_groups_change_owner() (Waiman Long) [1937825]
- drivers/base/cpu: Simplify s*nprintf() usages (Waiman Long) [1937825]
- drivers/base/cpu: Use scnprintf() for avoiding potential buffer overflow (Waiman Long) [1937825]
- sysfs: add sysfs_change_owner() (Waiman Long) [1937825]
- sysfs: add sysfs_group{s}_change_owner() (Waiman Long) [1937825]
- sysfs: add sysfs_link_change_owner() (Waiman Long) [1937825]
- sysfs: add sysfs_file_change_owner() (Waiman Long) [1937825]
- mm/huge_memory.c: reduce critical section protected by split_queue_lock (Waiman Long) [1937825]
- mm/huge_memory.c: use head to emphasize the purpose of page (Waiman Long) [1937825]
- mm/huge_memory.c: use head to check huge zero page (Waiman Long) [1937825]
- mm/gup: move try_get_compound_head() to top, fix minor issues (Waiman Long) [1937825]
- userfaultfd: wrap the common dst_vma check into an inlined function (Waiman Long) [1937825]
- userfaultfd: remove unnecessary WARN_ON() in __mcopy_atomic_hugetlb() (Waiman Long) [1937825]
- userfaultfd: use vma_pagesize for all huge page size calculation (Waiman Long) [1937825]
- mm/hugetlb: avoid looping to the same hugepage if !pages and !vmas (Waiman Long) [1937825]
- hugetlb: remove unused hstate in hugetlb_fault_mutex_hash() (Waiman Long) [1937825]
- hugetlbfs: convert macros to static inline, fix sparse warning (Waiman Long) [1937825]
- hugetlbfs: hugetlb_fault_mutex_hash() cleanup (Waiman Long) [1937825]
- mm/gup.c: allow CMA migration to propagate errors back to caller (Waiman Long) [1937825]
- mm/gup_benchmark: fix MAP_HUGETLB case (Waiman Long) [1937825]
- mm/gup_benchmark: add a missing "w" to getopt string (Waiman Long) [1937825]
- mm, page_owner: rename flag indicating that page is allocated (Waiman Long) [1937825]
- mm, page_owner: decouple freeing stack trace from debug_pagealloc (Waiman Long) [1937825]
- mm, page_owner: fix off-by-one error in __set_page_owner_handle() (Waiman Long) [1937825]
- mm/filemap.c: don't initiate writeback if mapping has no dirty pages (Waiman Long) [1937825]
- mm, page_owner, debug_pagealloc: save and dump freeing stack trace (Waiman Long) [1937825]
- mm, page_owner: keep owner info when freeing the page (Waiman Long) [1937825]
- mm, page_owner: record page owner for each subpage (Waiman Long) [1937825]
- mm: introduce page_size() (Waiman Long) [1937825]
- mm, tracing: Print symbol name for call_site in trace events (Waiman Long) [1937825]
- mm/gup.c: mark undo_dev_pagemap as __maybe_unused (Waiman Long) [1937825]
- mm, memcg: introduce memory.events.local (Waiman Long) [1937825]
- memcg, fsnotify: no oom-kill for remote memcg charging (Waiman Long) [1937825]
- mm/swap_state.c: simplify total_swapcache_pages() with get_swap_device() (Waiman Long) [1937825]
- mm: make !CONFIG_HUGE_PAGE wrappers into static inlines (Waiman Long) [1937825]
- include/linux/hugetlb.h: convert to use vm_fault_t (Waiman Long) [1937825]
- mm/page_ext.c: fix an imbalance with kmemleak (Waiman Long) [1937825]
- mm/hugetlb: add prot_modify_start/commit sequence for hugetlb update (Waiman Long) [1937825]
- iov_iter: optimize page_copy_sane() (Waiman Long) [1937825]
- mm: remove __hugepage_set_anon_rmap() (Waiman Long) [1937825]
- mm: remove pte_lock_deinit() (Waiman Long) [1937825]
- mm/debug.c: make "migrate_reason_names[]" const char * (Waiman Long) [1937825]
- vmscan: return NODE_RECLAIM_NOSCAN in node_reclaim() when CONFIG_NUMA is n (Waiman Long) [1937825]
- tools/testing/selftests/vm/gup_benchmark.c: add MAP_HUGETLB option (Waiman Long) [1937825]
- tools/testing/selftests/vm/gup_benchmark.c: add MAP_SHARED option (Waiman Long) [1937825]
- tools/testing/selftests/vm/gup_benchmark.c: allow user specified file (Waiman Long) [1937825]
- tools/testing/selftests/vm/gup_benchmark.c: fix 'write' flag usage (Waiman Long) [1937825]
- mm/page_ext.c: constify lookup_page_ext() argument (Waiman Long) [1937825]
- mm, page_alloc: actually ignore mempolicies for high priority allocations (Waiman Long) [1937825]
- thp: use mm_file_counter to determine update which rss counter (Waiman Long) [1937825]

* Fri May 21 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-307.el8]
- RDMA/cxgb4: Fix the reported max_recv_sge value (Kamal Heib) [1931850 1918264]
- RDMA/qedr: Fix kernel panic when trying to access recv_cq (Kamal Heib) [1931850]
- RDMA/addr: Be strict with gid size (Kamal Heib) [1931850]
- IB/hfi1: Fix probe time panic when AIP is enabled with a buggy BIOS (Kamal Heib) [1931850 1921704 1953593]
- RDMA/rxe: Fix errant WARN_ONCE in rxe_completer() (Kamal Heib) [1931850]
- RDMA/rxe: Fix extra deref in rxe_rcv_mcast_pkt() (Kamal Heib) [1931850]
- RDMA/rxe: Fix FIXME in rxe_udp_encap_recv() (Kamal Heib) [1931850]
- RDMA/rxe: Fix missed IB reference counting in loopback (Kamal Heib) [1931850]
- RDMA/uverbs: Fix kernel-doc warning of _uverbs_alloc (Kamal Heib) [1931850]
- RDMA/rxe: Fix missing kconfig dependency on CRYPTO (Kamal Heib) [1931850]
- RDMA/cm: Fix IRQ restore in ib_send_cm_sidr_rep (Kamal Heib) [1931850]
- RDMA/rxe: Remove unused pkt->offset (Kamal Heib) [1931850]
- RDMA/ucma: Fix use-after-free bug in ucma_create_uevent (Kamal Heib) [1931850]
- RDMA/core: Fix kernel doc warnings for ib_port_immutable_read() (Kamal Heib) [1931850]
- RDMA/ipoib: Remove racy Subnet Manager sendonly join checks (Kamal Heib) [1931850]
- RDMA/rxe: Cleanup init_send_wqe (Kamal Heib) [1931850]
- RDMA/rxe: Fix minor coding style issues (Kamal Heib) [1931850]
- RDMA/rxe: Correct skb on loopback path (Kamal Heib) [1931850]
- RDMA/rxe: Fix coding error in rxe_rcv_mcast_pkt (Kamal Heib) [1931850]
- RDMA/rxe: Remove useless code in rxe_recv.c (Kamal Heib) [1931850]
- RDMA/rxe: Fix coding error in rxe_recv.c (Kamal Heib) [1931850]
- RDMA/core: Introduce and use API to read port immutable data (Kamal Heib) [1931850]
- RDMA/pvrdma: Replace spin_lock_irqsave with spin_lock in hard IRQ (Kamal Heib) [1931850]
- IB/core: Use valid port number to check link layer (Kamal Heib) [1931850]
- IB/cm: Avoid a loop when device has 255 ports (Kamal Heib) [1931850]
- RDMA/efa: Remove unused syndrome enum values (Kamal Heib) [1931850]
- RDMA/efa: Remove unused 'select' field from get/set feature command descriptor (Kamal Heib) [1931850]
- RDMA/efa: Remove unnecessary indentation in defs comments (Kamal Heib) [1931850]
- RDMA/efa: Remove duplication of upper/lower_32_bits (Kamal Heib) [1931850]
- RDMA/efa: Remove redundant NULL pointer check of CQE (Kamal Heib) [1931850]
- RDMA/hw/hfi1/rc: Demote incorrectly populated kernel-doc header (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/verbs: Demote non-conforming doc header and fix a misspelling (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/user_exp_rcv: Demote half-documented and kernel-doc abuses (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/ud: Fix a little more doc-rot (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/uc: Fix a little doc-rot (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/tid_rdma: Fix a plethora of kernel-doc issues (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/sdma: Fix misnaming of 'sdma_send_txlist()'s 'count_out' param (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/ruc: Fix a small formatting and description issues (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/qp: Fix some formatting issues and demote kernel-doc abuse (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/rc: Fix a few function documentation issues (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/pio_copy: Provide entry for 'pio_copy()'s 'dd' param (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/pcie: Demote kernel-doc abuses (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/netdev_rx: Fix misdocumentation of the 'start_id' param (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/qp: Fix kernel-doc formatting problem (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/mad: Fix misspelling of 'rvt_process_mad()'s 'in_mad_size' param (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/msix: Add description for 'name' and remove superfluous param 'idx' (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/mad: Demote half-completed kernel-doc header fix another (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/iowait: Demote half-completed kernel-doc and fix formatting issue in another (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/srq: Fix a couple of kernel-doc issues (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/intr: Fix some kernel-doc formatting issues (Kamal Heib) [1931850 1921704]
- RDMA/rxe: Replace missing rxe_pool_get_index_locked (Kamal Heib) [1931850]
- RDMA/rxe: Remove unneeded pool->state (Kamal Heib) [1931850]
- RDMA/rxe: Remove references to ib_device and pool (Kamal Heib) [1931850]
- RDMA/rxe: Remove RXE_POOL_ATOMIC (Kamal Heib) [1931850]
- RDMA/rxe: Fix misleading comments and names (Kamal Heib) [1931850]
- RDMA/rxe: Fix bug in rxe_alloc() (Kamal Heib) [1931850]
- IB/umad: Return EPOLLERR in case of when device disassociated (Kamal Heib) [1931850]
- IB/umad: Return EIO in case of when device disassociated (Kamal Heib) [1931850]
- RDMA/sw/rdmavt/qp: Fix a bunch of kernel-doc misdemeanours (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/mr: Fix some issues related to formatting and missing descriptions (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/file_ops: Fix' manage_rcvq()'s 'arg' param (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/exp_rcv: Fix some kernel-doc formatting issues (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/mcast: Demote incomplete kernel-doc header (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/mad: Fix 'rvt_process_mad()'s documentation header (Kamal Heib) [1931850 1921704]
- RDMA/hw/hfi1/chip: Fix a bunch of kernel-doc formatting and spelling issues (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/cq: Demote hardly complete kernel-doc header (Kamal Heib) [1931850 1921704]
- RDMA/sw/rdmavt/vt: Fix formatting issue and update description for 'context' (Kamal Heib) [1931850 1921704]
- RDMA/hw/efa/efa_com: Stop using param description notation for non-params (Kamal Heib) [1931850]
- RDMA/uverbs: Don't set rcq for a QP if qp_type is IB_QPT_XRC_INI (Kamal Heib) [1931850]
- RDMA/core/iwpm_msg: Add proper descriptions for 'skb' param (Kamal Heib) [1931850]
- RDMA/core/iwpm_util: Fix some param description misspellings (Kamal Heib) [1931850]
- RDMA/core/counters: Demote non-conformant kernel-doc headers (Kamal Heib) [1931850]
- RDMA/core/restrack: Fix kernel-doc formatting issue (Kamal Heib) [1931850]
- RDMA/core/sa_query: Demote non-conformant kernel-doc header (Kamal Heib) [1931850]
- RDMA/core/multicast: Provide description for 'ib_init_ah_from_mcmember()'s 'rec' param (Kamal Heib) [1931850]
- RDMA/core/roce_gid_mgmt: Fix misnaming of 'rdma_roce_rescan_device()'s param 'ib_dev' (Kamal Heib) [1931850]
- RDMA/core/cache: Fix some misspellings, missing and superfluous param descriptions (Kamal Heib) [1931850]
- RDMA/core: device: Fix formatting in worthy kernel-doc header and demote another (Kamal Heib) [1931850]
- IB/iser: Simplify prot_caps setting (Kamal Heib) [1931850]
- IB/iser: Enforce iser_max_sectors to be greater than 0 (Kamal Heib) [1931850]
- IB/iser: Protect iscsi_max_lun module param using callback (Kamal Heib) [1931850]
- IB/iser: Remove unneeded semicolons (Kamal Heib) [1931850]
- IB/isert: Simplify signature cap check (Kamal Heib) [1931850]
- IB/isert: Remove unneeded semicolon (Kamal Heib) [1931850]
- IB/isert: Remove unneeded new lines (Kamal Heib) [1931850]
- RDMA/nldev: Return an error message on failure to turn auto mode (Kamal Heib) [1931850]
- RDMA/rxe: Fix race in rxe_mcast.c (Kamal Heib) [1931850]
- RDMA/rxe: Add unlocked versions of pool APIs (Kamal Heib) [1931850]
- RDMA/rxe: Make add/drop key/index APIs type safe (Kamal Heib) [1931850]
- RDMA/rxe: Make pool lookup and alloc APIs type safe (Kamal Heib) [1931850]
- RDMA/rxe: Add elem_offset field to rxe_type_info (Kamal Heib) [1931850]
- RDMA/rxe: Let pools support both keys and indices (Kamal Heib) [1931850]
- RDMA/rxe: Remove unneeded RXE_POOL_ATOMIC flag (Kamal Heib) [1931850]
- RDMA/rxe: Add check for supported QP types (Kamal Heib) [1931850]
- RDMA: Use kzalloc for allocating only one thing (Kamal Heib) [1931850]
- RDMA/cma: Delete useless kfree code (Kamal Heib) [1931850]
- RDMA/hfi1: remove h from printk format specifier (Kamal Heib) [1931850 1921704]
- RDMA: Convert comma to semicolon (Kamal Heib) [1931850]
- net: devlink: Add unused port flavour (Petr Oros) [1943273]
- devlink: add .trap_group_action_set() callback (Petr Oros) [1943273]
- devlink: add parser error drop packet traps (Petr Oros) [1943273]
- drop_monitor: Perform cleanup upon probe registration failure (Petr Oros) [1943273]
- selftests: net: Add drop monitor test (Petr Oros) [1943273]
- drop_monitor: Filter control packets in drop monitor (Petr Oros) [1943273]
- drop_monitor: Remove duplicate struct (Petr Oros) [1943273]
- drop_monitor: Remove no longer used functions (Petr Oros) [1943273]
- drop_monitor: Convert to using devlink tracepoint (Petr Oros) [1943273]
- drop_monitor: Prepare probe functions for devlink tracepoint (Petr Oros) [1943273]
- devlink: Add a tracepoint for trap reports (Petr Oros) [1943273]
- net: devlink: fix reporter dump dumpit (Petr Oros) [1943273]
- devlink: have genetlink code to parse the attrs during dumpit (Petr Oros) [1943273]
- netfilter: nf_tables: add direct calls for all builtin expressions (Florian Westphal) [1953320]
- netfilter: nf_tables: handle meta/lookup with direct call (Florian Westphal) [1953320]
- ionic: linearize tso skb with too many frags (Jonathan Toppins) [1940696]
- i40e: fix the restart auto-negotiation after FEC modified (Stefan Assmann) [1725560]
- ovl: skip getxattr of security labels (Miklos Szeredi) [1956340]
- ovl: fix dentry leak in ovl_get_redirect (Miklos Szeredi) [1956340]
- ovl: avoid deadlock on directory ioctl (Miklos Szeredi) [1956340]
- cap: fix conversions on getxattr (Miklos Szeredi) [1956340]
- ovl: perform vfs_getxattr() with mounter creds (Miklos Szeredi) [1956340]
- ovl: add warning on user_ns mismatch (Miklos Szeredi) [1956340]
- ovl: unprivieged mounts (Miklos Szeredi) [1956340]
- ovl: do not get metacopy for userxattr (Miklos Szeredi) [1956340]
- ovl: do not fail because of O_NOATIME (Miklos Szeredi) [1956340]
- ovl: do not fail when setting origin xattr (Miklos Szeredi) [1956340]
- ovl: user xattr (Miklos Szeredi) [1956340]
- ovl: simplify file splice (Miklos Szeredi) [1956340]
- ovl: make ioctl() safe (Miklos Szeredi) [1956340]
- ovl: check privs before decoding file handle (Miklos Szeredi) [1956340]
- vfs: verify source area in vfs_dedupe_file_range_one() (Miklos Szeredi) [1956340]
- vfs: move cap_convert_nscap() call into vfs_setxattr() (Miklos Szeredi) [1956340]
- ovl: fix incorrect extent info in metacopy case (Miklos Szeredi) [1956340]
- ovl: expand warning in ovl_d_real() (Miklos Szeredi) [1956340]
- ovl: document lower modification caveats (Miklos Szeredi) [1956340]
- ovl: warn about orphan metacopy (Miklos Szeredi) [1956340]
- ovl: doc clarification (Miklos Szeredi) [1956340]
- ovl: introduce new "uuid=off" option for inodes index feature (Miklos Szeredi) [1956340]
- ovl: propagate ovl_fs to ovl_decode_real_fh and ovl_encode_real_fh (Miklos Szeredi) [1956340]
- ovl: use generic vfs_ioc_setflags_prepare() helper (Miklos Szeredi) [1956340]
- ovl: support [S|G]ETFLAGS and FS[S|G]ETXATTR ioctls for directories (Miklos Szeredi) [1956340]
- ovl: rearrange ovl_can_list() (Miklos Szeredi) [1956340]
- ovl: enumerate private xattrs (Miklos Szeredi) [1956340]
- ovl: pass ovl_fs down to functions accessing private xattrs (Miklos Szeredi) [1956340]
- ovl: drop flags argument from ovl_do_setxattr() (Miklos Szeredi) [1956340]
- ovl: adhere to the vfs_ vs. ovl_do_ conventions for xattrs (Miklos Szeredi) [1956340]
- ovl: use ovl_do_getxattr() for private xattr (Miklos Szeredi) [1956340]
- ovl: fold ovl_getxattr() into ovl_get_redirect_xattr() (Miklos Szeredi) [1956340]
- ovl: clean up ovl_getxattr() in copy_up.c (Miklos Szeredi) [1956340]
- duplicate ovl_getxattr() (Miklos Szeredi) [1956340]
- ovl: provide a mount option "volatile" (Miklos Szeredi) [1956340 1928211]
- ovl: check for incompatible features in work dir (Miklos Szeredi) [1956340 1928211]
- ovl: fix lookup of indexed hardlinks with metacopy (Miklos Szeredi) [1956340]
- ovl: fix unneeded call to ovl_change_flags() (Miklos Szeredi) [1956340]
- ovl: fix mount option checks for nfs_export with no upperdir (Miklos Szeredi) [1956340]
- ovl: force read-only sb on failure to create index dir (Miklos Szeredi) [1956340]
- ovl: fix regression with re-formatted lower squashfs (Miklos Szeredi) [1956340]
- ovl: fix oops in ovl_indexdir_cleanup() with nfs_export=on (Miklos Szeredi) [1956340]
- ovl: relax WARN_ON() when decoding lower directory file handle (Miklos Szeredi) [1956340]
- ovl: remove not used argument in ovl_check_origin (Miklos Szeredi) [1956340]
- ovl: change ovl_copy_up_flags static (Miklos Szeredi) [1956340]
- ovl: inode reference leak in ovl_is_inuse true case. (Miklos Szeredi) [1956340]
- ovl: remove unnecessary lock check (Miklos Szeredi) [1956340]
- ovl: make oip->index bool (Miklos Szeredi) [1956340]
- ovl: only pass ->ki_flags to ovl_iocb_to_rwf() (Miklos Szeredi) [1956340]
- ovl: make private mounts longterm (Miklos Szeredi) [1956340]
- ovl: get rid of redundant members in struct ovl_fs (Miklos Szeredi) [1956340]
- ovl: add accessor for ofs->upper_mnt (Miklos Szeredi) [1956340]
- ovl: drop negative dentry in upper layer (Miklos Szeredi) [1956340]
- ovl: check permission to open real file (Miklos Szeredi) [1956340]
- ovl: call secutiry hook in ovl_real_ioctl() (Miklos Szeredi) [1956340]
- ovl: verify permissions in ovl_path_open() (Miklos Szeredi) [1956340]
- ovl: switch to mounter creds in readdir (Miklos Szeredi) [1956340]
- ovl: pass correct flags for opening real directory (Miklos Szeredi) [1956340]
- ovl: whiteout inode sharing (Miklos Szeredi) [1956340]
- ovl: inherit SB_NOSEC flag from upperdir (Miklos Szeredi) [1956340]
- ovl: skip overlayfs superblocks at global sync (Miklos Szeredi) [1956340]
- ovl: index dir act as work dir (Miklos Szeredi) [1956340]
- ovl: prepare to copy up without workdir (Miklos Szeredi) [1956340]
- ovl: cleanup non-empty directories in ovl_indexdir_cleanup() (Miklos Szeredi) [1956340]
- ocxl: Add new kernel traces (Steve Best) [1907530]
- ocxl: Add mmu notifier (Steve Best) [1907530]
- ocxl: Update the Process Element Entry (Steve Best) [1907530]
- ocxl: Initiate a TLB invalidate command (Steve Best) [1907530]
- ocxl: Assign a register set to a Logical Partition (Steve Best) [1907530]
- powerpc/mce: Remove per cpu variables from MCE handlers (Gustavo Walbon) [1921683]
- powerpc/mce: Reduce the size of event arrays (Gustavo Walbon) [1921683]
- tools/power turbostat: Support Ice Lake D (Prarit Bhargava) [1943439]
- PM: hibernate: x86: Use crc32 instead of md5 for hibernation e820 integrity check (Chris von Recklinghausen) [1944636]
- vhost/vsock: add IOTLB API support (Stefano Garzarella) [1894101]
- vhost: Fix vhost_vq_reset() (Laurent Vivier) [1919126]
- perf trace: Fix race in signal handling (Michael Petlan) [1928380]
- scsi: sd: sd_zbc: Don't pass GFP_NOIO to kvcalloc (Ewan D. Milne) [1953699]
- sd_zbc: clear zone resources for non-zoned case (Ewan D. Milne) [1953699]
- scsi: scsi_debug: Fix a memory leak (Ewan D. Milne) [1953699]
- scsi: sd: Warn if unsupported ZBC device is probed (Ewan D. Milne) [1953699]
- scsi: core: Add 'set_status_byte()' accessor (Ewan D. Milne) [1953699]
- scsi: scsi_debug: Do not set COMMAND_COMPLETE (Ewan D. Milne) [1953699]
- scsi: scsi_transport_srp: Don't block target in failfast state (Ewan D. Milne) [1953699]
- scsi: scsi_debug: Fix memleak in scsi_debug_init() (Ewan D. Milne) [1953699]
- scsi: core: Fix -Wformat for scsi_host (Ewan D. Milne) [1953699]
- scsi: doc: Fix some kernel-doc markups (Ewan D. Milne) [1953699]
- scsi: sr: Initialize ->cmd_len (Ewan D. Milne) [1953699]
- scsi: core: Set sc_data_direction to DMA_NONE for no-transfer commands (Ewan D. Milne) [1953699]
- scsi: core: Remove scsi_setup_cmnd() and scsi_setup_fs_cmnd() (Ewan D. Milne) [1953699]
- scsi: core: Clean up allocation and freeing of sgtables (Ewan D. Milne) [1953699]
- scsi: core: Rename scsi_mq_prep_fn() to scsi_prepare_cmd() (Ewan D. Milne) [1953699]
- scsi: core: Rename scsi_prep_state_check() to scsi_device_state_check() (Ewan D. Milne) [1953699]
- scsi: core: Use rq_dma_dir in scsi_setup_cmnd() (Ewan D. Milne) [1953699]
- scsi: core: Remove scsi_init_cmd_errh (Ewan D. Milne) [1953699]
- scsi: sd: Allow user to configure command retries (Ewan D. Milne) [1953699]
- scsi: sd: sd_zbc: Fix handling of host-aware ZBC disks (Ewan D. Milne) [1953699]
- scsi: sd_zbc: Improve zone revalidation (Ewan D. Milne) [1953699]
- scsi: sd_zbc: Don't limit max_zone_append sectors to max_hw_sectors (Ewan D. Milne) [1953699]
- scsi: sd_zbc: Remove unused inline functions (Ewan D. Milne) [1953699]
- nvme: fix the nsid value to print in nvme_validate_or_alloc_ns (Gopal Tiwari) [1921591]
- nvme-pci: add the DISABLE_WRITE_ZEROES quirk for a Samsung PM1725a (Gopal Tiwari) [1921591]
- nvme-rdma: Fix a use after free in nvmet_rdma_write_data_done (Gopal Tiwari) [1921591]
- nvme-core: check ctrl css before setting up zns (Gopal Tiwari) [1921591]
- nvme-fc: fix racing controller reset and create association (Gopal Tiwari) [1921591]
- nvme-fc: return NVME_SC_HOST_ABORTED_CMD when a command has been aborted (Gopal Tiwari) [1921591]
- nvme-fc: set NVME_REQ_CANCELLED in nvme_fc_terminate_exchange() (Gopal Tiwari) [1921591]
- nvme: add NVME_REQ_CANCELLED flag in nvme_cancel_request() (Gopal Tiwari) [1921591]
- nvme: simplify error logic in nvme_validate_ns() (Gopal Tiwari) [1921591]
- nvme: set max_zone_append_sectors nvme_revalidate_zones (Gopal Tiwari) [1921591]
- nvmet: model_number must be immutable once set (Gopal Tiwari) [1921591]
- nvme-fabrics: fix kato initialization (Gopal Tiwari) [1921591]
- nvme-hwmon: Return error code when registration fails (Gopal Tiwari) [1921591]
- nvme-pci: add quirks for Lexar 256GB SSD (Gopal Tiwari) [1921591]
- nvme-pci: mark Kingston SKC2000 as not supporting the deepest power state (Gopal Tiwari) [1921591]
- nvme-pci: mark Seagate Nytro XM1440 as QUIRK_NO_NS_DESC_LIST. (Gopal Tiwari) [1921591]
- nvme-tcp: fix crash triggered with a dataless request submission (Gopal Tiwari) [1921591]
- nvme-hwmon: rework to avoid devm allocation (Gopal Tiwari) [1921591]
- nvme: add 48-bit DMA address quirk for Amazon NVMe controllers (Gopal Tiwari) [1921591]
- nvmet: remove else at the end of the function (Gopal Tiwari) [1921591]
- nvmet: add helper to report invalid opcode (Gopal Tiwari) [1921591]
- nvmet: add nvmet_req_subsys() helper (Gopal Tiwari) [1921591]
- nvmet: use invalid cmd opcode helper (Gopal Tiwari) [1921591]
- nvmet: use invalid cmd opcode helper (Gopal Tiwari) [1921591]
- nvmet-fc: add a missing __rcu annotation to nvmet_fc_tgt_assoc.queues (Gopal Tiwari) [1921591]
- nvme-multipath: set nr_zones for zoned namespaces (Gopal Tiwari) [1921591]
- nvmet: make nvmet_find_namespace() req based (Gopal Tiwari) [1921591]
- nvmet: set status to 0 in case for invalid nsid (Gopal Tiwari) [1921591]
- nvmet: return uniform error for invalid ns (Gopal Tiwari) [1921591]
- nvmet: remove extra variable in id-ns handler (Gopal Tiwari) [1921591]
- nvmet-tcp: fix receive data digest calculation for multiple h2cdata PDUs (Gopal Tiwari) [1921591]
- nvme-fabrics: avoid double completions in nvmf_fail_nonready_command (Gopal Tiwari) [1921591]
- nvme: introduce a nvme_host_path_error helper (Gopal Tiwari) [1921591]
- blk-mq: introduce blk_mq_set_request_complete (Gopal Tiwari) [1921591]
- nvme-rdma: handle nvme_rdma_post_send failures better (Gopal Tiwari) [1921591]
- nvmet-tcp: fix potential race of tcp socket closing accept_work (Gopal Tiwari) [1921591]
- nvme: cleanup zone information initialization (Gopal Tiwari) [1921591]
- nvmet-tcp: fix out-of-bounds access when receiving multiple h2cdata PDUs (Gopal Tiwari) [1921591]
- nvme-pci: ignore the subsysem NQN on Phison E16 (Gopal Tiwari) [1921591]
- nvme-pci: avoid the deepest sleep state on Kingston A2000 SSDs (Gopal Tiwari) [1921591]
- nvme-tcp: use cancel tagset helper for tear down (Gopal Tiwari) [1921591]
- nvme-rdma: use cancel tagset helper for tear down (Gopal Tiwari) [1921591]
- nvme-rdma: add clean action for failed reconnection (Gopal Tiwari) [1921591]
- nvme-core: get rid of the extra space (Gopal Tiwari) [1921591]
- nvme-tcp: add clean action for failed reconnection (Gopal Tiwari) [1921591]
- nvme: add tracing of zns commands (Gopal Tiwari) [1921591]
- nvme: parse format nvm command details when tracing (Gopal Tiwari) [1921591]
- nvme-core: add cancel tagset helpers (Gopal Tiwari) [1921591]
- nvme: refactor ns->ctrl by request (Gopal Tiwari) [1921591]
- nvme-tcp: fix wrong setting of request iov_iter (Gopal Tiwari) [1921591]
- nvmet: remove extra variable in smart log nsid (Gopal Tiwari) [1921591]
- nvme-tcp: get rid of unused helper function (Gopal Tiwari) [1921591]
- nvmet: remove extra variable in identify ns (Gopal Tiwari) [1921591]
- nvmet: remove extra variable in id-desclist (Gopal Tiwari) [1921591]
- nvmet: add lba to sect conversion helpers (Gopal Tiwari) [1921591]
- nvme: support command retry delay for admin command (Gopal Tiwari) [1921591]
- nvmet: Use nvmet_is_port_enabled helper for pi_enable (Gopal Tiwari) [1921591]
- nvme: constify static attribute_group structs (Gopal Tiwari) [1921591]
- nvmet-fc: use RCU proctection for assoc_list (Gopal Tiwari) [1921591]
- nvmet: Fix nvmet_is_port_enabled indentation (Gopal Tiwari) [1921591]
- nvme-pci: add the DISABLE_WRITE_ZEROES quirk for a SPCC device (Gopal Tiwari) [1921591]
- nvme-core: use list_add_tail_rcu instead of list_add_tail for nvme_init_ns_head (Gopal Tiwari) [1921591]
- nvme: allow revalidate to set a namespace read-only (Gopal Tiwari) [1921591]
- nvmet: set right status on error in id-ns handler (Gopal Tiwari) [1921591]
- nvme-tcp: avoid request double completion for concurrent nvme_tcp_timeout (Gopal Tiwari) [1921591]
- nvme-rdma: avoid request double completion for concurrent nvme_rdma_timeout (Gopal Tiwari) [1921591]
- nvme-pci: allow use of cmb on v1.4 controllers (Gopal Tiwari) [1921591]
- nvme: check the PRINFO bit before deciding the host buffer length (Gopal Tiwari) [1921591]
- nvme-tcp: fix possible data corruption with bio merges (Gopal Tiwari) [1921591]
- nvme-tcp: Fix warning with CONFIG_DEBUG_PREEMPT (Gopal Tiwari) [1921591]
- nvme: don't intialize hwmon for discovery controllers (Gopal Tiwari) [1921591]
- nvmet-rdma: Fix NULL deref when setting pi_enable and traddr INADDR_ANY (Gopal Tiwari) [1921591]
- nvmet-rdma: Fix list_del corruption on queue establishment failure (Gopal Tiwari) [1921591]
- nvme: unexport functions with no external caller (Gopal Tiwari) [1921591]
- nvme: avoid possible double fetch in handling CQE (Gopal Tiwari) [1921591]
- nvme: remove the unused status argument from nvme_trace_bio_complete (Gopal Tiwari) [1921591]
- nvme-tcp: Fix possible race of io_work and direct send (Gopal Tiwari) [1921591]
- nvme-fcloop: Fix sscanf type and list_first_entry_or_null warnings (Gopal Tiwari) [1921591]
- nvme-fc: avoid calling _nvme_fc_abort_outstanding_ios from interrupt context (Gopal Tiwari) [1921591]
- nvme-loop: use blk_mq_hctx_set_fq_lock_class to set loop's lock class (Gopal Tiwari) [1921591]
- nvme: rename controller base dev_t char device (Gopal Tiwari) [1921591]
- nvme: remove unnecessary return values (Gopal Tiwari) [1921591]
- nvme: rename bdev operations (Gopal Tiwari) [1921591]
- nvme: export zoned namespaces without Zone Append support read-only (Gopal Tiwari) [1921591]
- nvme: print a warning for when listing active namespaces fails (Gopal Tiwari) [1921591]
- nvme: improve an error message on Identify failure (Gopal Tiwari) [1921591]
- nvmet: fix a spelling mistake "incuding" -> "including" in Kconfig (Gopal Tiwari) [1921591]
- nvme-fabrics: reject I/O to offline device (Gopal Tiwari) [1921591]
- nvmet: make sure discovery change log event is protected (Gopal Tiwari) [1921591]
- nvme-pci: don't allocate unused I/O queues (Gopal Tiwari) [1921591]
- nvme-pci: drop min() from nr_io_queues assignment (Gopal Tiwari) [1921591]
- nvmet: use inline bio for passthru fast path (Gopal Tiwari) [1921591]
- nvmet: use blk_rq_bio_prep instead of blk_rq_append_bio (Gopal Tiwari) [1921591]
- nvmet: remove unused ctrl->cqs (Gopal Tiwari) [1921591]
- nvmet: remove op_flags for passthru commands (Gopal Tiwari) [1921591]
- nvme: use consistent macro name for timeout (Gopal Tiwari) [1921591]
- nvmet: add passthru io timeout value attr (Gopal Tiwari) [1921591]
- nvmet: add passthru admin timeout value attr (Gopal Tiwari) [1921591]
- nvme: split nvme_alloc_request() (Gopal Tiwari) [1921591]
- nvme: centralize setting the timeout in nvme_alloc_request (Gopal Tiwari) [1921591]
- nvme: simplify nvme_req_qid() (Gopal Tiwari) [1921591]
- nvme-fcloop: add sysfs attribute to inject command drop (Gopal Tiwari) [1921591]
- nvme: let set_capacity_revalidate_and_notify update the bdev size (Gopal Tiwari) [1921591]
- nvme: directly cache command effects log (Gopal Tiwari) [1921591]
- nvme: fix memory leak freeing command effects (Gopal Tiwari) [1921591]
- nvme: free sq/cq dbbuf pointers when dbbuf set fails (Gopal Tiwari) [1921591]
- nvme-rdma: Use ibdev_to_node instead of dereferencing ->dma_device (Gopal Tiwari) [1921591]
- RDMA: Lift ibdev_to_node from rds to common code (Gopal Tiwari) [1921591]
- nvme: fix incorrect behavior when BLKROSET is called by the user (Gopal Tiwari) [1921591]
- Revert "nvme-pci: remove last_sq_tail" (Gopal Tiwari) [1921591]
- nvmet: fix a NULL pointer dereference when tracing the flush command (Gopal Tiwari) [1921591]
- nvme-fc: remove nvme_fc_terminate_io() (Gopal Tiwari) [1921591]
- nvme-fc: eliminate terminate_io use by nvme_fc_error_recovery (Gopal Tiwari) [1921591]
- nvme-fc: remove err_work work item (Gopal Tiwari) [1921591]
- nvme-fc: track error_recovery while connecting (Gopal Tiwari) [1921591]
- nvme-rdma: handle unexpected nvme completion data length (Gopal Tiwari) [1921591]
- nvme: ignore zone validate errors on subsequent scans (Gopal Tiwari) [1921591]
- nvme-fc: shorten reconnect delay if possible for FC (Gopal Tiwari) [1921591]
- nvme-fc: wait for queues to freeze before calling update_hr_hw_queues (Gopal Tiwari) [1921591]
- nvme-fc: fix error loop in create_hw_io_queues (Gopal Tiwari) [1921591]
- nvme-fc: fix io timeout to abort I/O (Gopal Tiwari) [1921591]
- nvmet: cleanup nvmet_passthru_map_sg() (Gopal Tiwari) [1921591]
- nvmet: don't use BLK_MQ_REQ_NOWAIT for passthru (Gopal Tiwari) [1921591]
- nvmet: limit passthru MTDS by BIO_MAX_PAGES (Gopal Tiwari) [1921591]
- nvme-rdma: fix crash due to incorrect cqe (Gopal Tiwari) [1921591]
- nvmet: fix uninitialized work for zero kato (Gopal Tiwari) [1921591]
- nvme: use queuedata for nvme_req_qid (Gopal Tiwari) [1921591]
- nvme-pci: disable Write Zeroes on Sandisk Skyhawk (Gopal Tiwari) [1921591]
- nvme-rdma: fix crash when connect rejected (Gopal Tiwari) [1921591]
- nvme: translate zone resource errors (Gopal Tiwari) [1921591]
- block: add zone specific block statuses (Gopal Tiwari) [1921591]
- nvme-core: remove extra condition for vwc (Gopal Tiwari) [1921591]
- nvme-core: remove extra variable (Gopal Tiwari) [1921591]
- nvme: remove nvme_identify_ns_list (Gopal Tiwari) [1921591]
- nvme: refactor nvme_validate_ns (Gopal Tiwari) [1921591]
- nvme: move nvme_validate_ns (Gopal Tiwari) [1921591]
- nvme: remove nvme_update_formats (Gopal Tiwari) [1921591]
- nvme: update the known admin effects (Gopal Tiwari) [1921591]
- nvme: query namespace identifiers before adding the namespace (Gopal Tiwari) [1921591]
- nvme: revalidate zone bitmaps in nvme_update_ns_info (Gopal Tiwari) [1921591]
- nvme: call nvme_identify_ns as the first thing in nvme_alloc_ns_block (Gopal Tiwari) [1921591]
- nvme: set the queue limits in nvme_update_ns_info (Gopal Tiwari) [1921591]
- nvme: remove the 0 lba_shift check in nvme_update_ns_info (Gopal Tiwari) [1921591]
- nvme: freeze the queue over ->lba_shift updates (Gopal Tiwari) [1921591]
- nvme: factor out a nvme_configure_metadata helper (Gopal Tiwari) [1921591]
- nvme: lift the check for an unallocated namespace into nvme_identify_ns (Gopal Tiwari) [1921591]
- nvme: clean up the check for too large logic block sizes (Gopal Tiwari) [1921591]
- nvme: remove the disk argument to nvme_update_zone_info (Gopal Tiwari) [1921591]
- nvme: rename __nvme_revalidate_disk (Gopal Tiwari) [1921591]
- nvme: rename _nvme_revalidate_disk (Gopal Tiwari) [1921591]
- nvme: rename nvme_validate_ns to nvme_validate_or_alloc_ns (Gopal Tiwari) [1921591]
- nvme: fix initialization of the zone bitmaps (Gopal Tiwari) [1921591]
- nvme-loop: don't put ctrl on nvme_init_ctrl error (Gopal Tiwari) [1921591]
- nvme-core: put ctrl ref when module ref get fail (Gopal Tiwari) [1921591]
- nvme-tcp: check page by sendpage_ok() before calling kernel_sendpage() (Gopal Tiwari) [1921591]
- nvmet-fc: fix missing check for no hostport struct (Gopal Tiwari) [1921591]
- nvme: fix error handling in nvme_ns_report_zones (Gopal Tiwari) [1921591]
- nvmet: add passthru ZNS support (Gopal Tiwari) [1921591]
- nvmet: handle keep-alive timer when kato is modified by a set features cmd (Gopal Tiwari) [1921591]
- nvme-pci: allocate separate interrupt for the reserved non-polled I/O queue (Gopal Tiwari) [1921591]
- nvmet-tcp: have queue io_work context run on sock incoming cpu (Gopal Tiwari) [1921591]
- nvme: lift the file open code from nvme_ctrl_get_by_path (Gopal Tiwari) [1921591]
- nvme: use an xarray to lookup the Commands Supported and Effects log (Gopal Tiwari) [1921591]
- nvme-pci: Move enumeration by class to be last in the table (Gopal Tiwari) [1921591]
- nvme-core: don't use NVME_NSID_ALL for command effects and supported log (Gopal Tiwari) [1921591]
- nvme-fc: fail new connections to a deleted host or remote port (Gopal Tiwari) [1921591]
- nvme: return errors for hwmon init (Gopal Tiwari) [1921591]
- nvme-pci: fix NULL req in completion handler (Gopal Tiwari) [1921591]
- nvmet: get transport reference for passthru ctrl (Gopal Tiwari) [1921591]
- nvme-core: get/put ctrl and transport module in nvme_dev_open/release() (Gopal Tiwari) [1921591]
- nvme-tcp: fix kconfig dependency warning when !CRYPTO (Gopal Tiwari) [1921591]
- nvme: use blk_mq_complete_request_remote to avoid an indirect function call (Gopal Tiwari) [1921591]
- nvme-core: replace ctrl page size with a macro (Gopal Tiwari) [1921591]
- nvme-pci: remove the inline scatterlist optimization (Gopal Tiwari) [1921591]
- block: optimize blk_queue_zoned_model for !CONFIG_BLK_DEV_ZONED (Gopal Tiwari) [1921591]
- nvme: support for zoned namespaces (Gopal Tiwari) [1921591]
- null_blk: introduce zone capacity for zoned device (Gopal Tiwari) [1921591]
- block: add capacity field to zone descriptors (Gopal Tiwari) [1921591]

* Wed May 19 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-306.el8]
- vmxnet3: Set the default of vxlan overlay offload to disabled (Cathy Avery) [1941714]
- vmxnet3: Update driver to use ethtool_sprintf (Cathy Avery) [1923796]
- vmxnet3: Remove buf_info from device accessible structures (Cathy Avery) [1923796]
- igc: Fix overwrites return value (Corinna Vinschen) [1920285]
- igc: Add set/clear large buffer helpers (Corinna Vinschen) [1920285]
- igc: Refactor Rx timestamp handling (Corinna Vinschen) [1920285]
- igc: Introduce igc_get_rx_frame_truesize() helper (Corinna Vinschen) [1920285]
- igc: Introduce igc_rx_buffer_flip() helper (Corinna Vinschen) [1920285]
- igc: Remove unused argument from igc_tx_cmd_type() (Corinna Vinschen) [1920285]
- igc: Fix prototype warning (Corinna Vinschen) [1920285]
- igc: Assign boolean values to a bool variable (Corinna Vinschen) [1920285]
- igc: Remove unused MII_CR_LOOPBACK (Corinna Vinschen) [1920285]
- igc: Remove unused MII_CR_SPEED (Corinna Vinschen) [1920285]
- igc: Remove unused MII_CR_RESET (Corinna Vinschen) [1920285]
- igc: Fix igc_ptp_rx_pktstamp() (Corinna Vinschen) [1920285]
- igc: Fix Supported Pause Frame Link Setting (Corinna Vinschen) [1920285]
- igc: Fix Pause Frame Advertising (Corinna Vinschen) [1920285]
- igc: reinit_locked() should be called with rtnl_lock (Corinna Vinschen) [1920285]
- igc: Fix TDBAL register show incorrect value (Corinna Vinschen) [1920285]
- igc: Remove unused FUNC_1 mask (Corinna Vinschen) [1920285]
- igc: Remove unused local receiver mask (Corinna Vinschen) [1920285]
- igc: Prefer strscpy over strlcpy (Corinna Vinschen) [1920285]
- igc: Expose the gPHY firmware version (Corinna Vinschen) [1920285]
- igc: Expose the NVM version (Corinna Vinschen) [1920285]
- igc: Add Host Good Packets Transmitted Count (Corinna Vinschen) [1920285]
- igc: Remove MULR mask define (Corinna Vinschen) [1920285]
- igc: Remove igc_set_fw_version comment (Corinna Vinschen) [1920285]
- igc: Clean up nvm_operations structure (Corinna Vinschen) [1920285]
- igc: check return value of ret_val in igc_config_fc_after_link_up (Corinna Vinschen) [1920285]
- igc: set the default return value to -IGC_ERR_NVM in igc_write_nvm_srwr (Corinna Vinschen) [1920285]
- igc: Report speed and duplex as unknown when device is runtime suspended (Corinna Vinschen) [1920285]
- net: igc: use skb_csum_is_sctp instead of protocol check (Corinna Vinschen) [1920285]
- igc: Add new device ID (Corinna Vinschen) [1920285]
- net: igbvf: use skb_csum_is_sctp instead of protocol check (Corinna Vinschen) [1920287]
- igbvf: Refactor traces (Corinna Vinschen) [1920287]
- igbvf: amend removal of MODULE_VERSION (Corinna Vinschen) [1955752]
- netlink: add tracepoint at NL_SET_ERR_MSG (Marcelo Ricardo Leitner) [1956983]
- xfrm: Provide private skb extensions for segmented and hw offloaded ESP packets (Sabrina Dubroca) [1935575]
- xfrm: BEET mode doesn't support fragments for inner packets (Xin Long) [1870900]
- xfrm: Fix NULL pointer dereference on policy lookup (Sabrina Dubroca) [1951965]
- xfrm: use secpath_exist where applicable (Sabrina Dubroca) [1951965]
- net: xfrm: Use sequence counter with associated spinlock (Sabrina Dubroca) [1951965]
- net: xfrm: Localize sequence counter per network namespace (Sabrina Dubroca) [1951965]
- xfrm: Return the correct errno code (Sabrina Dubroca) [1951965]
- xfrm: Fix wraparound in xfrm_policy_addr_delta() (Sabrina Dubroca) [1951965]
- xfrm: fix disable_xfrm sysctl when used on xfrm interfaces (Sabrina Dubroca) [1951965]
- xfrm: Fix oops in xfrm_replay_advance_bmp (Sabrina Dubroca) [1951965]
- ah6: fix error return code in ah6_input() (Sabrina Dubroca) [1951965]
- net: xfrm: fix a race condition during allocing spi (Sabrina Dubroca) [1951965]
- xfrm: policy: Use sequence counters with associated lock (Sabrina Dubroca) [1951965]
- selftests: net: mirror_gre_vlan_bridge_1q: Make an FDB entry static (Ivan Vecera) [1952586]
- net: bridge: switchdev: include local flag in FDB notifications (Ivan Vecera) [1952586]
- net: bridge: switchdev: refactor br_switchdev_fdb_notify (Ivan Vecera) [1952586]
- net: bridge: don't notify switchdev for local FDB addresses (Ivan Vecera) [1952586]
- net: bridge: use switchdev for port flags set through sysfs too (Ivan Vecera) [1952586]
- net: bridge: vlan: fix error return code in __vlan_add() (Ivan Vecera) [1952586]
- net: bridge: add missing counters to ndo_get_stats64 callback (Ivan Vecera) [1952586]
- net: bridge: use new function dev_fetch_sw_netstats (Ivan Vecera) [1952586]
- net: bridge: fdb: don't flush ext_learn entries (Ivan Vecera) [1952586]
- net: bridge: clear bridge's private skb space on xmit (Ivan Vecera) [1952586]
- bridge: mcast: Fix MLD2 Report IPv6 payload length check (Ivan Vecera) [1952586]
- net: bridge: enfore alignment for ethernet address (Ivan Vecera) [1952586]
- netfilter: nft_reject_bridge: enable reject with bridge vlan (Ivan Vecera) [1952586]
- net: bridge: vlan: Add a schedule point during VLAN processing (Ivan Vecera) [1952586]
- netfilter: ebtables: compat: reject all padding in matches/watchers (Ivan Vecera) [1952586]
- net: bridge: deny dev_set_mac_address() when unregistering (Ivan Vecera) [1952586]
- net: bridge: fdb: set flags directly in fdb_create (Ivan Vecera) [1952586]
- net: bridge: fdb: convert offloaded to use bitops (Ivan Vecera) [1952586]
- net: bridge: fdb: convert added_by_external_learn to use bitops (Ivan Vecera) [1952586]
- net: bridge: fdb: convert added_by_user to bitops (Ivan Vecera) [1952586]
- net: bridge: fdb: convert is_sticky to bitops (Ivan Vecera) [1952586]
- net: bridge: fdb: convert is_static to bitops (Ivan Vecera) [1952586]
- net: bridge: fdb: convert is_local to bitops (Ivan Vecera) [1952586]
- net: bridge: move default pvid init/deinit to NETDEV_REGISTER/UNREGISTER (Ivan Vecera) [1952586]
- bridge: Fix possible use-after-free when deleting bridge port (Ivan Vecera) [1952586]
- bridge: update vlan dev link state for bridge netdev changes (Ivan Vecera) [1952586]
- bridge: update vlan dev state when port added to or deleted from vlan (Ivan Vecera) [1952586]
- bridge: support binding vlan dev link state to vlan member bridge ports (Ivan Vecera) [1952586]
- vlan: do not transfer link state in vlan bridge binding mode (Ivan Vecera) [1952586]
- vlan: support binding link state to vlan member bridge ports (Ivan Vecera) [1952586]
- ipv6: weaken the v4mapped source check (Paolo Abeni) [1950298]
- tcp: relookup sock for RST+ACK packets handled by obsolete req sock (Paolo Abeni) [1950298]
- inet_connection_sock: remove unused parameter of reqsk_queue_unlink func (Paolo Abeni) [1950298]
- tcp: add sanity tests to TCP_QUEUE_SEQ (Paolo Abeni) [1950298]
- tcp: fix SO_RCVLOWAT related hangs under mem pressure (Paolo Abeni) [1950298]
- tcp: do not mess with cloned skbs in tcp_add_backlog() (Paolo Abeni) [1950298]
- tcp: fix cwnd-limited bug for TSO deferral where we send nothing (Paolo Abeni) [1950298]
- vfio-ccw: Wire in the request callback (Thomas Huth) [1940451]
- vfio-mdev: Wire in a request handler for mdev parent (Thomas Huth) [1940451]
- intel_idle: add Iclelake-D support (David Arcari) [1960287]
- scsi: ibmvfc: Fix potential race in ibmvfc_wait_for_ops() (Steve Best) [1941180]
- powerpc/sstep: Fix VSX instruction emulation (Steve Best) [1934187]
- powerpc/pseries/hibernation: remove pseries_suspend_cpu() (Steve Best) [1932970]
- powerpc/pseries: remove cede offline state for CPUs (Steve Best) [1932970]
- powerpc/pseries: export LPAR security flavor in lparcfg (Steve Best) [1935660]
- Makefile: update early devel phase flag (Bruno Meneguele) [1930504]

* Mon May 17 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.8.el8]
- configs: Enable CONFIG_BPF_KPROBE_OVERRIDE (Jiri Olsa) [1920439]
- powerpc/kvm: Fix build error when PPC_MEM_KEYS/PPC_PSERIES=n (Greg Kurz) [1945745]
- powerpc/kvm: Fix PR KVM with KUAP/MEM_KEYS enabled (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Ensure MSR[HV] is always clear in guest MSR (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Ensure MSR[ME] is always set in guest MSR (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Fix CONFIG_SPAPR_TCE_IOMMU=n default hcalls (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: remove unused kvmppc_h_protect argument (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Remove redundant mtspr PSPB (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Prevent radix guests setting LPCR[TC] (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Disallow LPCR[AIL] to be set to 1 or 2 (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Add a function to filter guest LPCR bits (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Nested move LPCR sanitising to sanitise_hv_regs (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV P9: Restore host CTRL SPR after guest exit (Greg Kurz) [1945745]
- KVM: PPC: Don't always report hash MMU capability for P9 < DD2.2 (Greg Kurz) [1945745]
- powerpc/xive: Assign boolean values to a bool variable (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Fix host radix SLB optimisation with hash guests (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Ensure radix guest has no SLB entries (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Save and restore FSCR in the P9 path (Greg Kurz) [1945745]
- KVM: PPC: remove unneeded semicolon (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Use POWER9 SLBIA IH=6 variant to clear SLB (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: No need to clear radix host SLB before loading HPT guest (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Fix radix guest SLB side channel (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Remove support for running HPT guest on RPT host without mixed mode support (Greg Kurz) [1945745]
- powerpc/mm: Update tlbiel loop on POWER10 (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Allow nested guest creation when L0 hv_guest_state > L1 (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Context tracking exit guest context before enabling irqs (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Include prototypes (Greg Kurz) [1945745]
- KVM: PPC: Make the VMX instruction emulation routines static (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Fix mask size for emulated msgsndp (Greg Kurz) [1945745]
- KVM: PPC: fix comparison to bool warning (Greg Kurz) [1945745]
- KVM: PPC: Book3S: Assign boolean values to a bool variable (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: XIVE: Add a comment regarding VP numbering (Greg Kurz) [1945745]
- powerpc/xive: Remove P9 DD1 flag XIVE_IRQ_FLAG_EOI_FW (Greg Kurz) [1945745]
- powerpc/xive: Remove P9 DD1 flag XIVE_IRQ_FLAG_MASK_FW (Greg Kurz) [1945745]
- powerpc/xive: Remove P9 DD1 flag XIVE_IRQ_FLAG_SHIFT_BUG (Greg Kurz) [1945745]
- powerpc/xive: Add a debug_show handler to the XIVE irq_domain (Greg Kurz) [1945745]
- powerpc/xive: Rename XIVE_IRQ_NO_EOI to show its a flag (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: XIVE: Show detailed configuration in debug output (Greg Kurz) [1945745]
- powerpc/64s: Remove MSR[ISF] bit (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Ratelimit machine check messages coming from guests (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: Don't attempt to recover machine checks for FWNMI enabled guests (Greg Kurz) [1945745]
- KVM: PPC: Book3S HV: XIVE: Fix possible oops when accessing ESB page (Greg Kurz) [1945745]
- clocksource/drivers/hyper-v: Move handling of STIMER0 interrupts (Mohammed Gamal) [1940901]
- clocksource/drivers/hyper-v: Set clocksource rating based on Hyper-V feature (Mohammed Gamal) [1940901]
- clocksource/drivers/hyper-v: Handle sched_clock differences inline (Mohammed Gamal) [1940901]
- clocksource/hyperv: use MSR-based access if running as root (Mohammed Gamal) [1940901]
- cifs: fix interrupted close commands (Ronnie Sahlberg) [1952263]
- cifs: add NULL check for ses->tcon_ipc (Ronnie Sahlberg) [1952263]
- smb3: set COMPOUND_FID to FileID field of subsequent compound request (Ronnie Sahlberg) [1952263]
- cifs: fix potential use-after-free in cifs_echo_request() (Ronnie Sahlberg) [1952263]
- cifs: allow syscalls to be restarted in __smb_send_rqst() (Ronnie Sahlberg) [1952263]
- smb3: Handle error case during offload read path (Ronnie Sahlberg) [1952263]
- smb3: Avoid Mid pending list corruption (Ronnie Sahlberg) [1952263]
- smb3: Call cifs reconnect from demultiplex thread (Ronnie Sahlberg) [1952263]
- cifs: fix a memleak with modefromsid (Ronnie Sahlberg) [1952263]
- cifs: update internal module version number (Ronnie Sahlberg) [1952263]
- smb3: add some missing definitions from MS-FSCC (Ronnie Sahlberg) [1952263]
- smb3: remove two unused variables (Ronnie Sahlberg) [1952263]
- smb3: add support for stat of WSL reparse points for special file types (Ronnie Sahlberg) [1952263]
- SMB3: add support for recognizing WSL reparse tags (Ronnie Sahlberg) [1952263]
- cifs: remove bogus debug code (Ronnie Sahlberg) [1952263]
- smb3.1.1: fix typo in compression flag (Ronnie Sahlberg) [1952263]
- cifs: move smb version mount options into fs_context.c (Ronnie Sahlberg) [1952263]
- cifs: move cache mount options to fs_context.ch (Ronnie Sahlberg) [1952263]
- cifs: move security mount options into fs_context.ch (Ronnie Sahlberg) [1952263]
- cifs: add files to host new mount api (Ronnie Sahlberg) [1952263]
- smb3: do not try to cache root directory if dir leases not supported (Ronnie Sahlberg) [1952263]
- smb3: fix stat when special device file and mounted with modefromsid (Ronnie Sahlberg) [1952263]
- cifs: Print the address and port we are connecting to in generic_ip_connect() (Ronnie Sahlberg) [1952263]
- SMB3: Resolve data corruption of TCP server info fields (Ronnie Sahlberg) [1952263]
- cifs: make const array static, makes object smaller (Ronnie Sahlberg) [1952263]
- SMB3.1.1: Fix ids returned in POSIX query dir (Ronnie Sahlberg) [1952263]
- smb3: add dynamic trace point to trace when credits obtained (Ronnie Sahlberg) [1952263]
- smb3.1.1: do not fail if no encryption required but server doesn't support it (Ronnie Sahlberg) [1952263]
- cifs: Return the error from crypt_message when enc/dec key not found. (Ronnie Sahlberg) [1952263]
- smb3.1.1: set gcm256 when requested (Ronnie Sahlberg) [1952263]
- smb3.1.1: rename nonces used for GCM and CCM encryption (Ronnie Sahlberg) [1952263]
- smb3.1.1: print warning if server does not support requested encryption type (Ronnie Sahlberg) [1952263]
- smb3.1.1: add new module load parm enable_gcm_256 (Ronnie Sahlberg) [1952263]
- smb3.1.1: add new module load parm require_gcm_256 (Ronnie Sahlberg) [1952263]
- cifs: map STATUS_ACCOUNT_LOCKED_OUT to -EACCES (Ronnie Sahlberg) [1952263]
- SMB3.1.1: add defines for new signing negotiate context (Ronnie Sahlberg) [1952263]
- Handle STATUS_IO_TIMEOUT gracefully (Ronnie Sahlberg) [1952263]
- cifs: compute full_path already in cifs_readdir() (Ronnie Sahlberg) [1952263]
- cifs: return cached_fid from open_shroot (Ronnie Sahlberg) [1952263]
- update structure definitions from updated protocol documentation (Ronnie Sahlberg) [1952263]
- smb3: add defines for new crypto algorithms (Ronnie Sahlberg) [1952263]
- cifs: fix check of tcon dfs in smb1 (Ronnie Sahlberg) [1952263]
- SMB3: Fix mkdir when idsfromsid configured on mount (Ronnie Sahlberg) [1952263]
- cifs: Convert to use the fallthrough macro (Ronnie Sahlberg) [1952263]
- cifs: Fix an error pointer dereference in cifs_mount() (Ronnie Sahlberg) [1952263]
- cifs: document and cleanup dfs mount (Ronnie Sahlberg) [1952263]
- cifs: only update prefix path of DFS links in cifs_tree_connect() (Ronnie Sahlberg) [1952263]
- cifs: fix double free error on share and prefix (Ronnie Sahlberg) [1952263]
- cifs: handle RESP_GET_DFS_REFERRAL.PathConsumed in reconnect (Ronnie Sahlberg) [1952263]
- cifs: handle empty list of targets in cifs_reconnect() (Ronnie Sahlberg) [1952263]
- cifs: rename reconn_inval_dfs_target() (Ronnie Sahlberg) [1952263]
- cifs: reduce number of referral requests in DFS link lookups (Ronnie Sahlberg) [1952263]
- cifs: merge __{cifs,smb2}_reconnect[_tcon]() into cifs_tree_connect() (Ronnie Sahlberg) [1952263]
- cifs: convert to use be32_add_cpu() (Ronnie Sahlberg) [1952263]
- cifs: delete duplicated words in header files (Ronnie Sahlberg) [1952263]
- cifs: Remove the superfluous break (Ronnie Sahlberg) [1952263]
- cifs: remove unused variable 'server' (Ronnie Sahlberg) [1952263]
- smb3: warn on confusing error scenario with sec=krb5 (Ronnie Sahlberg) [1952263]
- fuse: 32-bit user space ioctl compat for fuse device (Miklos Szeredi) [1949873]
- virtiofs: Fail dax mount if device does not support it (Miklos Szeredi) [1949873]
- fuse: fix live lock in fuse_iget() (Miklos Szeredi) [1949873]
- mm/filemap: remove unused parameter and change to void type for replace_page_cache_page() (Miklos Szeredi) [1949873]
- fuse: support SB_NOSEC flag to improve write performance (Miklos Szeredi) [1949873]
- fuse: add a flag FUSE_OPEN_KILL_SUIDGID for open() request (Miklos Szeredi) [1949873]
- fuse: don't send ATTR_MODE to kill suid/sgid for handle_killpriv_v2 (Miklos Szeredi) [1949873]
- fuse: setattr should set FATTR_KILL_SUIDGID (Miklos Szeredi) [1949873]
- fuse: set FUSE_WRITE_KILL_SUIDGID in cached write path (Miklos Szeredi) [1949873]
- fuse: rename FUSE_WRITE_KILL_PRIV to FUSE_WRITE_KILL_SUIDGID (Miklos Szeredi) [1949873]
- fuse: introduce the notion of FUSE_HANDLE_KILLPRIV_V2 (Miklos Szeredi) [1949873]
- fuse: always revalidate if exclusive create (Miklos Szeredi) [1949873]
- virtiofs: clean up error handling in virtio_fs_get_tree() (Miklos Szeredi) [1949873]
- fuse: add fuse_sb_destroy() helper (Miklos Szeredi) [1949873]
- fuse: simplify get_fuse_conn*() (Miklos Szeredi) [1949873]
- fuse: get rid of fuse_mount refcount (Miklos Szeredi) [1949873]
- virtiofs: simplify sb setup (Miklos Szeredi) [1949873]
- virtiofs fix leak in setup (Miklos Szeredi) [1949873]
- fuse: launder page should wait for page writeback (Miklos Szeredi) [1949873]
- fuse: connection remove fix (Miklos Szeredi) [1949873]
- fuse: implement crossmounts (Miklos Szeredi) [1949873]
- fuse: Allow fuse_fill_super_common() for submounts (Miklos Szeredi) [1949873]
- fuse: split fuse_mount off of fuse_conn (Miklos Szeredi) [1949873]
- fuse: drop fuse_conn parameter where possible (Miklos Szeredi) [1949873]
- fuse: store fuse_conn in fuse_req (Miklos Szeredi) [1949873]
- fuse: add submount support to <uapi/linux/fuse.h> (Miklos Szeredi) [1949873]
- fuse: fix page dereference after free (Miklos Szeredi) [1949873]
- fuse: update project homepage (Miklos Szeredi) [1949873]
- fuse: Fix parameter for FS_IOC_{GET,SET}FLAGS (Miklos Szeredi) [1949873]
- fuse: don't ignore errors from fuse_writepages_fill() (Miklos Szeredi) [1949873]
- fuse: clean up condition for writepage sending (Miklos Szeredi) [1949873]
- fuse: fix warning in tree_insert() and clean up writepage insertion (Miklos Szeredi) [1949873]
- fuse: move rb_erase() before tree_insert() (Miklos Szeredi) [1949873]
- fuse: optimize writepages search (Miklos Szeredi) [1949873]
- fuse: Update stale comment in queue_interrupt() (Miklos Szeredi) [1949873]
- fuse: use true,false for bool variable (Miklos Szeredi) [1949873]
- fuse: Add changelog entries for protocols 7.1 - 7.8 (Miklos Szeredi) [1949873]
- fuse: reserve byteswapped init opcodes (Miklos Szeredi) [1949873]
- convenience helper: get_tree_single() (finish backport) (Miklos Szeredi) [1949873]
- fuse: Convert fusectl to use the new mount API (Miklos Szeredi) [1949873]
- fuse: fix changelog entry for protocol 7.9 (Miklos Szeredi) [1949873]
- fuse: fix changelog entry for protocol 7.12 (Miklos Szeredi) [1949873]
- sfc: adjust efx->xdp_tx_queue_count with the real number of initialized queues (Íñigo Huguet) [1934254]
- sfc: Remove duplicate argument (Íñigo Huguet) [1934254]
- sfc: Use 'skb_add_rx_frag()' instead of hand coding it (Íñigo Huguet) [1934254]
- sfc-falcon: Fix a typo (Íñigo Huguet) [1934254]
- sfc: ef10: fix TX queue lookup in TX event handling (Íñigo Huguet) [1934254]
- sfc: farch: fix TX queue lookup in TX event handling (Íñigo Huguet) [1934254]
- sfc: farch: fix TX queue lookup in TX flush done handling (Íñigo Huguet) [1934254]
- sfc: reduce the number of requested xdp ev queues (Íñigo Huguet) [1934254]
- sfc: support GRE TSO on EF100 (Íñigo Huguet) [1934254]
- sfc: correctly support non-partial GSO_UDP_TUNNEL_CSUM on EF100 (Íñigo Huguet) [1934254]
- sfc: extend bitfield macros to 19 fields (Íñigo Huguet) [1934254]
- sfc: advertise our vlan features (Íñigo Huguet) [1934254]
- sfc: only use fixed-id if the skb asks for it (Íñigo Huguet) [1934254]
- sfc: implement encap TSO on EF100 (Íñigo Huguet) [1934254]
- sfc: extend bitfield macros to 17 fields (Íñigo Huguet) [1934254]
- sfc: move initialisation of efx->filter_sem to efx_init_struct() (Íñigo Huguet) [1934254]
- net: sfc: Use GFP_KERNEL in efx_ef10_try_update_nic_stats() (Íñigo Huguet) [1934254]
- net: sfc: Replace in_interrupt() usage (Íñigo Huguet) [1934254]
- sfc: clean up mis-targeted comments (Íñigo Huguet) [1934254]
- sfc: fix kdoc warning (Íñigo Huguet) [1934254]
- sfc: clean up unused assignments (Íñigo Huguet) [1934254]
- sfc: advertise encapsulated offloads on EF10 (Íñigo Huguet) [1934254]
- sfc: implement encapsulated TSO on EF10 (Íñigo Huguet) [1934254]
- sfc: de-indirect TSO handling (Íñigo Huguet) [1934254]
- sfc: select inner-csum-offload TX queues for skbs that need it (Íñigo Huguet) [1934254]
- sfc: create inner-csum queues on EF10 if supported (Íñigo Huguet) [1934254]
- sfc: define inner/outer csum offload TXQ types (Íñigo Huguet) [1934254]
- sfc: decouple TXQ type from label (Íñigo Huguet) [1934254]
- sfc: cleanups around efx_alloc_channel (Íñigo Huguet) [1934254]
- sfc: remove spurious unreachable return statement (Íñigo Huguet) [1934254]
- sfc: remove duplicate call to efx_init_channels from EF100 probe (Íñigo Huguet) [1934254]
- sfc: coding style cleanups in mcdi_port_common.c (Íñigo Huguet) [1934254]
- sfc: simplify DMA mask setting (Íñigo Huguet) [1934254]
- sfc: remove EFX_DRIVER_VERSION (Íñigo Huguet) [1934254]
- sfc: handle limited FEC support (Íñigo Huguet) [1934254]
- sfc: add ethtool ops and miscellaneous ndos to EF100 (Íñigo Huguet) [1934254]
- sfc: remove phy_op indirection (Íñigo Huguet) [1934254]
- sfc: remove efx_tx_queue_partner (Íñigo Huguet) [1934254]
- sfc: rewrite efx_tx_may_pio (Íñigo Huguet) [1934254]
- sfc: use efx_channel_tx_[old_]fill_level() in Siena/EF10 TX datapath (Íñigo Huguet) [1934254]
- sfc: use tx_queue->old_read_count in EF100 TX path (Íñigo Huguet) [1934254]
- sfc: make ef100 xmit_more handling look more like ef10's (Íñigo Huguet) [1934254]
- sfc: add and use efx_tx_send_pending in tx.c (Íñigo Huguet) [1934254]
- sfc: return errors from efx_mcdi_set_id_led, and de-indirect (Íñigo Huguet) [1934254]
- sfc: fix kernel-doc on struct efx_loopback_state (Íñigo Huguet) [1934254]
- sfc: fix unused-but-set-variable warning in efx_farch_filter_remove_safe (Íñigo Huguet) [1934254]
- sfc: fix W=1 warnings in efx_farch_handle_rx_not_ok (Íñigo Huguet) [1934254]
- sfc: convert to new udp_tunnel infrastructure (Íñigo Huguet) [1934254]
- net: don't warn in inet diag when IPV6 is disabled (Hangbin Liu) [1938639]
- tcp: do not mess with cloned skbs in tcp_add_backlog() (Hangbin Liu) [1880432]
- redhat: enable MHI bus driver support (Jarod Wilson) [1938030]
- bus: mhi: core: Fix invalid error returning in mhi_queue (Jarod Wilson) [1938030]
- bus: mhi: pci_generic: Remove WQ_MEM_RECLAIM flag from state workqueue (Jarod Wilson) [1938030]
- bus: mhi: core: Fix check for syserr at power_up (Jarod Wilson) [1938030]
- mhi: Fix double dma free (Jarod Wilson) [1938030]
- bus: mhi: pci_generic: Increase num of elements in hw event ring (Jarod Wilson) [1938030]
- mhi: pci_generic: Print warning in case of firmware crash (Jarod Wilson) [1938030]
- bus: mhi: core: Add helper API to return number of free TREs (Jarod Wilson) [1938030]
- mhi: core: Factorize mhi queuing (Jarod Wilson) [1938030]
- mhi: use irq_flags if controller driver configures it (Jarod Wilson) [1938030]
- mhi: pci_generic: Fix shared MSI vector support (Jarod Wilson) [1938030]
- mhi: unconstify mhi_event_config (Jarod Wilson) [1938030]
- bus: mhi: Ensure correct ring update ordering with memory barrier (Jarod Wilson) [1938030]
- mhi: pci_generic: Set irq moderation value to 1ms for hw channels (Jarod Wilson) [1938030]
- mhi: pci_generic: Add diag channels (Jarod Wilson) [1938030]
- mhi: pci_generic: Increase controller timeout value (Jarod Wilson) [1938030]
- mhi: pci_generic: Add health-check (Jarod Wilson) [1938030]
- mhi: pci_generic: Add PCI error handlers (Jarod Wilson) [1938030]
- mhi: pci_generic: Add suspend/resume/recovery procedure (Jarod Wilson) [1938030]
- mhi: pci_generic: Add support for reset (Jarod Wilson) [1938030]
- mhi: pci_generic: Enable burst mode for hardware channels (Jarod Wilson) [1938030]
- mhi: pci-generic: Increase number of hardware events (Jarod Wilson) [1938030]
- bus: mhi: core: Add device hardware reset support (Jarod Wilson) [1938030]
- mhi: pci_generic: Fix implicit conversion warning (Jarod Wilson) [1938030]
- bus: mhi: core: Fix error handling in mhi_register_controller() (Jarod Wilson) [1938030]
- bus: mhi: core: Fix device hierarchy (Jarod Wilson) [1938030]
- bus: mhi: core: Indexed MHI controller name (Jarod Wilson) [1938030]
- bus: mhi: core: Remove MHI event ring IRQ handlers when powering down (Jarod Wilson) [1938030]
- bus: mhi: core: Mark and maintain device states early on after power down (Jarod Wilson) [1938030]
- bus: mhi: core: Separate system error and power down handling (Jarod Wilson) [1938030]
- bus: mhi: core: Check for IRQ availability during registration (Jarod Wilson) [1938030]
- bus: mhi: core: Move to an error state on mission mode failure (Jarod Wilson) [1938030]
- bus: mhi: core: Use appropriate label in firmware load handler API (Jarod Wilson) [1938030]
- bus: mhi: core: Move to an error state on any firmware load failure (Jarod Wilson) [1938030]
- bus: mhi: core: Prevent sending multiple RDDM entry callbacks (Jarod Wilson) [1938030]
- bus: mhi: core: Move to SYS_ERROR regardless of RDDM capability (Jarod Wilson) [1938030]
- bus: mhi: core: Skip device wake in error or shutdown states (Jarod Wilson) [1938030]
- bus: mhi: core: Move to using high priority workqueue (Jarod Wilson) [1938030]
- bus: mhi: core: Use appropriate names for firmware load functions (Jarod Wilson) [1938030]
- bus: mhi: core: Skip RDDM download for unknown execution environment (Jarod Wilson) [1938030]
- bus: mhi: core: Rename RDDM download function to use proper words (Jarod Wilson) [1938030]
- bus: mhi: core: Remove unused mhi_fw_load_worker() declaration (Jarod Wilson) [1938030]
- bus: mhi: core: Expose mhi_get_exec_env() API for controllers (Jarod Wilson) [1938030]
- bus: mhi: core: Add missing EXPORT_SYMBOL for mhi_get_mhi_state() (Jarod Wilson) [1938030]
- bus: mhi: core: Remove unnecessary counter from mhi_firmware_copy() (Jarod Wilson) [1938030]
- bus: mhi: Fix channel close issue on driver remove (Jarod Wilson) [1938030]
- bus: mhi: core: Fix null pointer access when parsing MHI configuration (Jarod Wilson) [1938030]
- bus: mhi: Add MHI PCI support for WWAN modems (Jarod Wilson) [1938030]
- bus: mhi: core: fix potential operator-precedence with BHI macros (Jarod Wilson) [1938030]
- bus: mhi: core: Remove double locking from mhi_driver_remove() (Jarod Wilson) [1938030]
- bus: mhi: Remove auto-start option (Jarod Wilson) [1938030]
- bus: mhi: Add mhi_queue_is_full function (Jarod Wilson) [1938030]
- bus: mhi: debugfs: Print channel context read-pointer (Jarod Wilson) [1938030]
- bus: mhi: core: Fix the building of MHI module (Jarod Wilson) [1938030]
- bus: mhi: Remove unused nr_irqs_req variable (Jarod Wilson) [1938030]
- bus: mhi: core: Allow shared IRQ for event rings (Jarod Wilson) [1938030]
- bus: mhi: core: Introduce sysfs entries for MHI (Jarod Wilson) [1938030]
- bus: mhi: core: Introduce debugfs entries for MHI (Jarod Wilson) [1938030]
- bus: mhi: Fix entries based on Kconfig coding style (Jarod Wilson) [1938030]
- bus: mhi: Remove include of rwlock_types.h (Jarod Wilson) [1938030]
- bus: mhi: core: Add const qualifier to MHI config information (Jarod Wilson) [1938030]
- bus: mhi: core: Introduce APIs to allocate and free the MHI controller (Jarod Wilson) [1938030]
- bus: mhi: core: Read and save device hardware information from BHI (Jarod Wilson) [1938030]
- bus: mhi: core: Introduce counters to track MHI device state transitions (Jarod Wilson) [1938030]
- bus: mhi: core: Introduce helper function to check device state (Jarod Wilson) [1938030]
- bus: mhi: core: Use generic name field for an MHI device (Jarod Wilson) [1938030]
- bus: mhi: core: Trigger host resume if suspended during mhi_device_get() (Jarod Wilson) [1938030]
- bus: mhi: core: Use helper API to trigger a non-blocking host resume (Jarod Wilson) [1938030]
- bus: mhi: core: Abort suspends due to outgoing pending packets (Jarod Wilson) [1938030]
- bus: mhi: core: Remove double occurrence for mhi_ctrl_ev_task() declaration (Jarod Wilson) [1938030]
- bus: mhi: fix doubled words and struct image_info kernel-doc (Jarod Wilson) [1938030]
- bus: mhi: core: Handle syserr during power_up (Jarod Wilson) [1938030]
- bus: mhi: core: Handle write lock properly in mhi_pm_m0_transition (Jarod Wilson) [1938030]
- bus: mhi: core: Do not process SYS_ERROR if RDDM is supported (Jarod Wilson) [1938030]
- bus: mhi: core: Skip handling BHI irq if MHI reg access is not allowed (Jarod Wilson) [1938030]
- bus: mhi: core: Handle disable transitions in state worker (Jarod Wilson) [1938030]
- bus: mhi: core: Remove the system error worker thread (Jarod Wilson) [1938030]
- bus: mhi: core: Ensure non-zero session or sequence ID values are used (Jarod Wilson) [1938030]
- bus: mhi: core: Improve debug logs for loading firmware (Jarod Wilson) [1938030]
- bus: mhi: core: Return appropriate error codes for AMSS load failure (Jarod Wilson) [1938030]
- bus: mhi: core: Handle firmware load using state worker (Jarod Wilson) [1938030]
- bus: mhi: core: Read transfer length from an event properly (Jarod Wilson) [1938030]
- bus: mhi: core: Add range check for channel id received in event ring (Jarod Wilson) [1938030]
- bus: mhi: core: Cache intmod from mhi event to mhi channel (Jarod Wilson) [1938030]
- bus: mhi: core: Refactor mhi queue APIs (Jarod Wilson) [1938030]
- bus: mhi: core: Fix some error return code (Jarod Wilson) [1938030]
- bus: mhi: core: Fix channel device name conflict (Jarod Wilson) [1938030]
- bus: mhi: core: Fix typo in comment (Jarod Wilson) [1938030]
- bus: mhi: core: Offload register accesses to the controller (Jarod Wilson) [1938030]
- bus: mhi: core: Remove link_status() callback (Jarod Wilson) [1938030]
- bus: mhi: core: Make sure to powerdown if mhi_sync_power_up fails (Jarod Wilson) [1938030]
- bus: mhi: Fix parsing of mhi_flags (Jarod Wilson) [1938030]
- bus: mhi: core: Fix a NULL vs IS_ERR check in mhi_create_devices() (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for MHI suspend and resume (Jarod Wilson) [1938030]
- bus: mhi: core: Drop the references to mhi_dev in mhi_destroy_device() (Jarod Wilson) [1938030]
- bus: mhi: core: Initialize bhie field in mhi_cntrl for RDDM capture (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for reading MHI info from device (Jarod Wilson) [1938030]
- bus: mhi: core: Pass module owner during client driver registration (Jarod Wilson) [1938030]
- bus/mhi: fix printk format for size_t (Jarod Wilson) [1938030]
- bus: mhi: core: Add uevent support for module autoloading (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for data transfer (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for processing events from client device (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for downloading RDDM image during panic (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for downloading firmware over BHIe (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for basic PM operations (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for PM state transitions (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for ringing channel/event ring doorbells (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for creating and destroying MHI devices (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for registering MHI client drivers (Jarod Wilson) [1938030]
- bus: mhi: core: Add support for registering MHI controllers (Jarod Wilson) [1938030]

* Fri May 14 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.7.el8]
- ipmi: remove open coded version of SMBus block write (Tony Camuso) [1947126]
- char: ipmi: convert comma to semicolon (Tony Camuso) [1947126]
- ipmi: msghandler: Suppress suspicious RCU usage warning (Tony Camuso) [1947126]
- ipmi/watchdog: replace atomic_add() and atomic_sub() (Tony Camuso) [1947126]
- char: ipmi: remove unneeded break (Tony Camuso) [1947126]
- ipmi_si: Fix wrong return value in try_smi_init() (Tony Camuso) [1947126]
- ipmi: msghandler: Fix a signedness bug (Tony Camuso) [1947126]
- ipmi: add retry in try_get_dev_id() (Tony Camuso) [1947126]
- ipmi: Clean up some printks (Tony Camuso) [1947126]
- ipmi:msghandler: retry to get device id on an error (Tony Camuso) [1947126]
- ipmi:sm: Print current state when the state is invalid (Tony Camuso) [1947126]
- ipmi: Reset response handler when failing to send the command (Tony Camuso) [1947126]
- ipmi: add a newline when printing parameter 'panic_op' by sysfs (Tony Camuso) [1947126]
- cpuidle: Select polling interval based on a c-state with a longer target residency (Mark Langsdorf) [1922024]
- cpuidle: big.LITTLE: enable driver only on Peach-Pit/Pi Chromebooks (Mark Langsdorf) [1922024]
- cpuidle: record state entry rejection statistics (Mark Langsdorf) [1922024]
- nitro_enclaves: Fix stale file descriptors on failed usercopy (Vitaly Kuznetsov) [1953717]
- iavf: amend removal of MODULE_VERSION (Stefan Assmann) [1955738]
- ixgbevf: Amend commit acf03026ec5a to include a version in module info. (Ken Cox) [1955764]
- devlink: move flash end and begin to core devlink (Petr Oros) [1935671]
- devlink: move request_firmware out of driver (Petr Oros) [1935671]
- ice: add additional debug logging for firmware update (Petr Oros) [1935671]
- ice: add support for flash update overwrite mask (Petr Oros) [1935671]
- driver core: auxiliary bus: Fix calling stage for auxiliary bus init (Ivan Vecera) [1933820]
- driver core: auxiliary bus: Fix auxiliary bus shutdown null auxdrv ptr (Ivan Vecera) [1933820]
- driver core: auxiliary bus: minor coding style tweaks (Ivan Vecera) [1933820]
- driver core: auxiliary bus: make remove function return void (Ivan Vecera) [1933820]
- driver core: auxiliary bus: move slab.h from include file (Ivan Vecera) [1933820]
- Add auxiliary bus support (Ivan Vecera) [1933820]
- modpost: file2alias: go back to simple devtable lookup (Ivan Vecera) [1933820]
- scsi: lpfc: Fix bad memory access during VPD DUMP mailbox command (Dick Kennedy) [1923762]
- scsi: lpfc: Fix DMA virtual address ptr assignment in bsg (Dick Kennedy) [1923762]
- scsi: lpfc: Fix illegal memory access on Abort IOCBs (Dick Kennedy) [1923762]
- scsi: lpfc: Copyright updates for 12.8.0.9 patches (Dick Kennedy) [1923762]
- scsi: lpfc: Update lpfc version to 12.8.0.9 (Dick Kennedy) [1923762]
- scsi: lpfc: Eliminate use of LPFC_DRIVER_NAME in lpfc_attr.c (Dick Kennedy) [1923762]
- scsi: lpfc: Standardize discovery object logging format (Dick Kennedy) [1923762]
- scsi: lpfc: Fix various trivial errors in comments and log messages (Dick Kennedy) [1923762]
- scsi: lpfc: Remove unsupported mbox PORT_CAPABILITIES logic (Dick Kennedy) [1923762]
- scsi: lpfc: Fix lpfc_hdw_queue attribute being ignored (Dick Kennedy) [1923762]
- scsi: lpfc: Fix missing FDMI registrations after Mgmt Svc login (Dick Kennedy) [1923762]
- scsi: lpfc: Fix silent memory allocation failure in lpfc_sli4_bsg_link_diag_test() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix use-after-free on unused nodes after port swap (Dick Kennedy) [1923762]
- scsi: lpfc: Fix error handling for mailboxes completed in MBX_POLL mode (Dick Kennedy) [1923762]
- scsi: lpfc: Fix lack of device removal on port swaps with PRLIs (Dick Kennedy) [1923762]
- scsi: lpfc: Fix NMI crash during rmmod due to circular hbalock dependency (Dick Kennedy) [1923762]
- scsi: lpfc: Fix reference counting errors in lpfc_cmpl_els_rsp() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix crash when a REG_RPI mailbox fails triggering a LOGO response (Dick Kennedy) [1923762]
- scsi: lpfc: Fix rmmod crash due to bad ring pointers to abort_iotag (Dick Kennedy) [1923762]
- scsi: lpfc: Fix gcc -Wstringop-overread warning (Dick Kennedy) [1923762]
- scsi: lpfc: Fix a typo (Dick Kennedy) [1923762]
- scsi: lpfc: Fix a typo (Dick Kennedy) [1923762]
- scsi: lpfc: Fix kernel-doc formatting issue (Dick Kennedy) [1923762]
- scsi: lpfc: Fix a few incorrectly named functions (Dick Kennedy) [1923762]
- scsi: lpfc: Fix incorrectly documented function lpfc_debugfs_commonxripools_data() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix a bunch of misnamed functions (Dick Kennedy) [1923762]
- scsi: lpfc: Fix a bunch of kernel-doc misdemeanours (Dick Kennedy) [1923762]
- scsi: lpfc: Fix incorrect naming of __lpfc_update_fcf_record() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix formatting and misspelling issues (Dick Kennedy) [1923762]
- scsi: lpfc: Fix a bunch of kernel-doc issues (Dick Kennedy) [1923762]
- scsi: lpfc: Update copyrights for 12.8.0.7 and 12.8.0.8 changes (Dick Kennedy) [1923762]
- scsi: lpfc: Update lpfc version to 12.8.0.8 (Dick Kennedy) [1923762]
- scsi: lpfc: Correct function header comments related to ndlp reference counting (Dick Kennedy) [1923762]
- scsi: lpfc: Reduce LOG_TRACE_EVENT logging for vports (Dick Kennedy) [1923762]
- scsi: lpfc: Change wording of invalid pci reset log message (Dick Kennedy) [1923762]
- scsi: lpfc: Fix crash caused by switch reboot (Dick Kennedy) [1923762]
- scsi: lpfc: Fix pt2pt state transition causing rmmod hang (Dick Kennedy) [1923762]
- scsi: lpfc: Fix nodeinfo debugfs output (Dick Kennedy) [1923762]
- scsi: lpfc: Fix ADISC handling that never frees nodes (Dick Kennedy) [1923762]
- scsi: lpfc: Fix PLOGI ACC to be transmit after REG_LOGIN (Dick Kennedy) [1923762]
- scsi: lpfc: Fix dropped FLOGI during pt2pt discovery recovery (Dick Kennedy) [1923762]
- scsi: lpfc: Fix status returned in lpfc_els_retry() error exit path (Dick Kennedy) [1923762]
- scsi: lpfc: Fix use after free in lpfc_els_free_iocb (Dick Kennedy) [1923762]
- scsi: lpfc: Fix null pointer dereference in lpfc_prep_els_iocb() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix unnecessary null check in lpfc_release_scsi_buf (Dick Kennedy) [1923762]
- scsi: lpfc: Fix pt2pt connection does not recover after LOGO (Dick Kennedy) [1923762]
- scsi: lpfc: Fix lpfc_els_retry() possible null pointer dereference (Dick Kennedy) [1923762]
- scsi: lpfc: Fix FLOGI failure due to accessing a freed node (Dick Kennedy) [1923762]
- scsi: lpfc: Fix stale node accesses on stale RRQ request (Dick Kennedy) [1923762]
- scsi: lpfc: Fix reftag generation sizing errors (Dick Kennedy) [1923762]
- scsi: lpfc: Fix vport indices in lpfc_find_vport_by_vpid() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix incorrect dbde assignment when building target abts wqe (Dick Kennedy) [1923762]
- scsi: lpfc: Fix 'physical' typos (Dick Kennedy) [1923762]
- scsi: lpfc: Fix ancient double free (Dick Kennedy) [1923762]
- scsi: lpfc: Fix kerneldoc inconsistency in lpfc_sli4_dump_page_a0() (Dick Kennedy) [1923762]
- scsi: lpfc: Add support for eh_should_retry_cmd() (Dick Kennedy) [1923762]
- scsi: lpfc: Simplify bool comparison (Dick Kennedy) [1923762]
- scsi: lpfc: Update lpfc version to 12.8.0.7 (Dick Kennedy) [1923762]
- scsi: lpfc: Enhancements to LOG_TRACE_EVENT for better readability (Dick Kennedy) [1923762]
- scsi: lpfc: Implement health checking when aborting I/O (Dick Kennedy) [1923762]
- scsi: lpfc: Fix crash when nvmet transport calls host_release (Dick Kennedy) [1923762]
- scsi: lpfc: Fix vport create logging (Dick Kennedy) [1923762]
- scsi: lpfc: Fix NVMe recovery after mailbox timeout (Dick Kennedy) [1923762]
- scsi: lpfc: Fix target reset failing (Dick Kennedy) [1923762]
- scsi: lpfc: Fix error log messages being logged following SCSI task mgnt (Dick Kennedy) [1923762]
- scsi: lpfc: Fix FW reset action if I/Os are outstanding (Dick Kennedy) [1923762]
- scsi: lpfc: Use the nvme-fc transport supplied timeout for LS requests (Dick Kennedy) [1923762]
- scsi: lpfc: Fix crash when a fabric node is released prematurely (Dick Kennedy) [1923762]
- scsi: lpfc: Refresh ndlp when a new PRLI is received in the PRLI issue state (Dick Kennedy) [1923762]
- scsi: lpfc: Fix auto sli_mode and its effect on CONFIG_PORT for SLI3 (Dick Kennedy) [1923762]
- scsi: lpfc: Fix PLOGI S_ID of 0 on pt2pt config (Dick Kennedy) [1923762]
- scsi: lpfc: Fix fall-through warnings for Clang (Dick Kennedy) [1923762]
- scsi: lpfc: Correct null ndlp reference on routine exit (Dick Kennedy) [1923762]
- scsi: lpfc: Use generic power management (Dick Kennedy) [1923762]
- scsi: lpfc: Fix variable 'vport' set but not used in lpfc_sli4_abts_err_handler() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix missing prototype for lpfc_nvmet_prep_abort_wqe() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix set but unused variables in lpfc_dev_loss_tmo_handler() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix set but not used warnings from Rework remote port lock handling (Dick Kennedy) [1923762]
- scsi: lpfc: Fix missing prototype warning for lpfc_fdmi_vendor_attr_mi() (Dick Kennedy) [1923762]
- scsi: lpfc: Fix memory leak on lcb_context (Dick Kennedy) [1923762]
- scsi: lpfc: Remove dead code on second !ndlp check (Dick Kennedy) [1923762]
- scsi: lpfc: Fix pointer defereference before it is null checked issue (Dick Kennedy) [1923762]
- scsi: lpfc: Update changed file copyrights for 2020 (Dick Kennedy) [1923762]
- scsi: lpfc: Update lpfc version to 12.8.0.6 (Dick Kennedy) [1923762]
- scsi: lpfc: Convert abort handling to SLI-3 and SLI-4 handlers (Dick Kennedy) [1923762]
- scsi: lpfc: Convert SCSI I/O completions to SLI-3 and SLI-4 handlers (Dick Kennedy) [1923762]
- scsi: lpfc: Convert SCSI path to use common I/O submission path (Dick Kennedy) [1923762]
- scsi: lpfc: Enable common send_io interface for SCSI and NVMe (Dick Kennedy) [1923762]
- scsi: lpfc: Enable common wqe_template support for both SCSI and NVMe (Dick Kennedy) [1923762]
- scsi: lpfc: Refactor WQE structure definitions for common use (Dick Kennedy) [1923762]
- scsi: lpfc: Fix NPIV Fabric Node reference counting (Dick Kennedy) [1923762]
- scsi: lpfc: Fix NPIV discovery and Fabric Node detection (Dick Kennedy) [1923762]
- scsi: lpfc: Unsolicited ELS leaves node in incorrect state while dropping it (Dick Kennedy) [1923762]
- scsi: lpfc: Remove ndlp when a PLOGI/ADISC/PRLI/REG_RPI ultimately fails (Dick Kennedy) [1923762]
- scsi: lpfc: Rework remote port lock handling (Dick Kennedy) [1923762]
- scsi: lpfc: Honor module parameter lpfc_use_adisc (Dick Kennedy) [1923762]
- scsi: lpfc: Fix refcounting around SCSI and NVMe transport APIs (Dick Kennedy) [1923762]
- scsi: lpfc: Fix removal of SCSI transport device get and put on dev structure (Dick Kennedy) [1923762]
- scsi: lpfc: Rework locations of ndlp reference taking (Dick Kennedy) [1923762]
- scsi: lpfc: Rework remote port ref counting and node freeing (Dick Kennedy) [1923762]
- scsi: lpfc: remove ScsiResult macro (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_nvmet: Fix-up some formatting and doc-rot issues (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_nvme: Fix some kernel-doc related issues (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_nvme: Remove unused variable 'phba' (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_bsg: Provide correct documentation for a bunch of functions (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_debugfs: Fix a couple of function documentation issues (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_attr: Fix-up a bunch of kernel-doc misdemeanours (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_attr: Demote kernel-doc format for redefined functions (Dick Kennedy) [1923762]
- scsi: lpfc: lpfc_scsi: Fix a whole host of kernel-doc issues (Dick Kennedy) [1923762]
- block: return -EBUSY when there are open partitions in blkdev_reread_part (Ming Lei) [1936800]
- block: Try to handle busy underlying device on discard (Ming Lei) [1936800]
- md: check for NULL ->meta_bdev before calling bdev_read_only (Ming Lei) [1936800]
- blk-settings: align max_sectors on "logical_block_size" boundary (Ming Lei) [1936800]
- nbd: handle device refs for DESTROY_ON_DISCONNECT properly (Ming Lei) [1936800]
- kyber: introduce kyber_depth_updated() (Ming Lei) [1936800]
- loop: fix I/O error on fsync() in detached loop devices (Ming Lei) [1936800]
- block: fix potential IO hang when turning off io_poll (Ming Lei) [1936800]
- bfq: Use only idle IO periods for think time calculations (Ming Lei) [1936800]
- bfq: Use 'ttime' local variable (Ming Lei) [1936800]
- bfq: Avoid false bfq queue merging (Ming Lei) [1936800]
- bfq: bfq_check_waker() should be static (Ming Lei) [1936800]
- block, bfq: make waker-queue detection more robust (Ming Lei) [1936800]
- block, bfq: save also injection state on queue merging (Ming Lei) [1936800]
- block, bfq: save also weight-raised service on queue merging (Ming Lei) [1936800]
- block, bfq: fix switch back from soft-rt weitgh-raising (Ming Lei) [1936800]
- block, bfq: re-evaluate convenience of I/O plugging on rq arrivals (Ming Lei) [1936800]
- block, bfq: replace mechanism for evaluating I/O intensity (Ming Lei) [1936800]
- block: set .bi_max_vecs as actual allocated vector number (Ming Lei) [1936800]
- block: don't allocate inline bvecs if this bioset needn't bvecs (Ming Lei) [1936800]
- block: don't pass BIOSET_NEED_BVECS for q->bio_split (Ming Lei) [1936800]
- block: manage bio slab cache by xarray (Ming Lei) [1936800]
- block, bfq: do not expire a queue when it is the only busy one (Ming Lei) [1936800]
- block, bfq: avoid spurious switches to soft_rt of interactive queues (Ming Lei) [1936800]
- block, bfq: do not raise non-default weights (Ming Lei) [1936800]
- block, bfq: increase time window for waker detection (Ming Lei) [1936800]
- block, bfq: use half slice_idle as a threshold to check short ttime (Ming Lei) [1936800]
- brd: remove the end of device check in brd_do_bvec (Ming Lei) [1936800]
- block: propagate BLKROSET on the whole device to all partitions (Ming Lei) [1936800]
- block: add a hard-readonly flag to struct gendisk (Ming Lei) [1936800]
- block: remove the NULL bdev check in bdev_read_only (Ming Lei) [1936800]
- dm: use bdev_read_only to check if a device is read-only (Ming Lei) [1936800]
- block: reopen the device in blkdev_reread_part (Ming Lei) [1936800]
- block, bfq: set next_rq to waker_bfqq->next_rq in waker injection (Ming Lei) [1936800]
- Revert "block: simplify set_init_blocksize" to regain lost performance (Ming Lei) [1936800]
- bfq-iosched: Revert "bfq: Fix computation of shallow depth" (Ming Lei) [1936800]
- blk-mq-debugfs: Add decode for BLK_MQ_F_TAG_HCTX_SHARED (Ming Lei) [1936800]
- bfq: Fix computation of shallow depth (Ming Lei) [1936800]
- block: rsxx: select CONFIG_CRC32 (Ming Lei) [1936800]
- block: add debugfs stanza for QUEUE_FLAG_NOWAIT (Ming Lei) [1936800]
- blk-mq: Don't complete on a remote CPU in force threaded mode (Ming Lei) [1936800]
- blk-mq: Remove 'running from the wrong CPU' warning (Ming Lei) [1936800]
- block: disable iopoll for split bio (Ming Lei) [1936800]
- block: Improve blk_revalidate_disk_zones() checks (Ming Lei) [1936800]
- sbitmap: replace CAS with atomic and (Ming Lei) [1936800]
- sbitmap: remove swap_lock (Ming Lei) [1936800]
- sbitmap: optimise sbitmap_deferred_clear() (Ming Lei) [1936800]
- blk-mq: skip hybrid polling if iopoll doesn't spin (Ming Lei) [1936800]
- blktrace: fix up a kerneldoc comment (Ming Lei) [1936800]
- block: remove the unused block_sleeprq tracepoint (Ming Lei) [1936800]
- blk-throttle: don't check whether or not lower limit is valid if CONFIG_BLK_DEV_THROTTLING_LOW is off (Ming Lei) [1936800]
- block: fix inflight statistics of part0 (Ming Lei) [1936800]
- block: optimise for_each_bvec() advance (Ming Lei) [1936800]
- block: opencode devcgroup_inode_permission (Ming Lei) [1936800]
- block: move bdput() to the callers of __blkdev_get (Ming Lei) [1936800]
- block: refactor blkdev_get (Ming Lei) [1936800]
- block: refactor __blkdev_put (Ming Lei) [1936800]
- block: switch bdgrab to use igrab (Ming Lei) [1936800]
- block: change the hash used for looking up block devices (Ming Lei) [1936800]
- block: use put_device in put_disk (Ming Lei) [1936800]
- block: use disk_part_iter_exit in disk_part_iter_next (Ming Lei) [1936800]
- block: add a bdev_kobj helper (Ming Lei) [1936800]
- block: remove a superflous check in blkpg_do_ioctl (Ming Lei) [1936800]
- block: remove a duplicate __disk_get_part prototype (Ming Lei) [1936800]
- loop: do not call set_blocksize (Ming Lei) [1936800]
- zram: do not call set_blocksize (Ming Lei) [1936800]
- block: wbt: Remove unnecessary invoking of wbt_update_limits in wbt_init (Ming Lei) [1936800]
- virtio-blk: remove a spurious call to revalidate_disk_size (Ming Lei) [1936800]
- md: remove a spurious call to revalidate_disk_size in update_size (Ming Lei) [1936800]
- aoe: don't call set_capacity from irq context (Ming Lei) [1936800]
- nbd: validate the block size in nbd_set_size (Ming Lei) [1936800]
- nbd: refactor size updates (Ming Lei) [1936800]
- nbd: move the task_recv check into nbd_size_update (Ming Lei) [1936800]
- nbd: remove the call to set_blocksize (Ming Lei) [1936800]
- loop: let set_capacity_revalidate_and_notify update the bdev size (Ming Lei) [1936800]
- block: remove the call to __invalidate_device in check_disk_size_change (Ming Lei) [1936800]
- block: fix the kerneldoc comment for __register_blkdev (Ming Lei) [1936800]
- block: switch gendisk lookup to a simple xarray (Ming Lei) [1936800]
- ide: switch to __register_blkdev for command set probing (Ming Lei) [1936800]
- md: use __register_blkdev to allocate devices on demand (Ming Lei) [1936800]
- loop: use __register_blkdev to allocate devices on demand (Ming Lei) [1936800]
- brd: use __register_blkdev to allocate devices on demand (Ming Lei) [1936800]
- sd: use __register_blkdev to avoid a modprobe for an unregistered dev_t (Ming Lei) [1936800]
- swim: don't call blk_register_region (Ming Lei) [1936800]
- ide: remove ide_{,un}register_region (Ming Lei) [1936800]
- block: add an optional probe callback to major_names (Ming Lei) [1936800]
- block: rework requesting modules for unclaimed devices (Ming Lei) [1936800]
- block: split block_class_lock (Ming Lei) [1936800]
- block: open code kobj_map into in block/genhd.c (Ming Lei) [1936800]
- block: cleanup del_gendisk a bit (Ming Lei) [1936800]
- loop: use set_disk_ro (Ming Lei) [1936800]
- dasd: implement ->set_read_only to hook into BLKROSET processing (Ming Lei) [1936800]
- md: implement ->set_read_only to hook into BLKROSET processing (Ming Lei) [1936800]
- rbd: implement ->set_read_only to hook into BLKROSET processing (Ming Lei) [1936800]
- block: add a new set_read_only method (Ming Lei) [1936800]
- blk-cgroup: fix a hd_struct leak in blkcg_fill_root_iostats (Ming Lei) [1936800]
- blk-cgroup: Pre-allocate tree node on blkg_conf_prep (Ming Lei) [1936800]
- blk-cgroup: Fix memleak on error path (Ming Lei) [1936800]
- blk-mq: remove the calling of local_memory_node() (Ming Lei) [1936800]
- zram: Fix __zram_bvec_{read,write}() locking order (Ming Lei) [1936800]
- skd_main: remove unused including <linux/version.h> (Ming Lei) [1936800]
- sgl_alloc_order: fix memory leak (Ming Lei) [1936800]
- block: fix uapi blkzoned.h comments (Ming Lei) [1936800]
- blk-mq: move cancel of hctx->run_work to the front of blk_exit_queue (Ming Lei) [1936800]
- blk-mq: get rid of the dead flush handle code path (Ming Lei) [1936800]
- block: get rid of unnecessary local variable (Ming Lei) [1936800]
- block: fix comment and add lockdep assert (Ming Lei) [1936800]
- blk-mq: use helper function to test hw stopped (Ming Lei) [1936800]
- block: use helper function to test queue register (Ming Lei) [1936800]
- block: remove redundant mq check (Ming Lei) [1936800]
- block: invoke blk_mq_exit_sched no matter whether have .exit_sched (Ming Lei) [1936800]
- block: ratelimit handle_bad_sector() message (Ming Lei) [1936800]
- blk-throttle: Re-use the throtl_set_slice_end() (Ming Lei) [1936800]
- blk-throttle: Open code __throtl_de/enqueue_tg() (Ming Lei) [1936800]
- blk-throttle: Move service tree validation out of the throtl_rb_first() (Ming Lei) [1936800]
- blk-throttle: Move the list operation after list validation (Ming Lei) [1936800]
- blk-throttle: Fix IO hang for a corner case (Ming Lei) [1936800]
- blk-throttle: Avoid tracking latency if low limit is invalid (Ming Lei) [1936800]
- blk-throttle: Avoid getting the current time if tg->last_finish_time is 0 (Ming Lei) [1936800]
- blk-throttle: Remove a meaningless parameter for throtl_downgrade_state() (Ming Lei) [1936800]
- block: Remove redundant 'return' statement (Ming Lei) [1936800]
- block: Consider only dispatched requests for inflight statistic (Ming Lei) [1936800]
- block: remove the unused blk_integrity_merge_bio export (Ming Lei) [1936800]
- block: remove the unused blk_integrity_merge_rq export (Ming Lei) [1936800]
- blk-mq: add cond_resched() in __blk_mq_alloc_rq_maps() (Ming Lei) [1936800]
- vsprintf: use bd_partno in bdev_name (Ming Lei) [1936800]
- block: use bd_partno in bdevname (Ming Lei) [1936800]
- target/iblock: fix holder printing in iblock_show_configfs_dev_params (Ming Lei) [1936800]
- drbd: don't set ->bd_contains (Ming Lei) [1936800]
- drbd: don't detour through bd_contains for the gendisk (Ming Lei) [1936800]
- block: add a bdev_is_partition helper (Ming Lei) [1936800]
- bdi: remove BDI_CAP_CGROUP_WRITEBACK (Ming Lei) [1936800]
- block: lift setting the readahead size into the block layer (Ming Lei) [1936800]
- bdi: initialize ->ra_pages and ->io_pages in bdi_init (Ming Lei) [1936800]
- block: ensure bdi->io_pages is always initialized (Ming Lei) [1936800]
- aoe: set an optimal I/O size (Ming Lei) [1936800]
- drbd: remove dead code in device_to_statistics (Ming Lei) [1936800]
- raw: don't keep unopened block device around (Ming Lei) [1936800]
- zram: cleanup backing_dev_store (Ming Lei) [1936800]
- zram: fix double free backing device (Ming Lei) [1936800]
- pktcdvd: use blkdev_get_by_dev instead of open coding it (Ming Lei) [1936800]
- pktcdvd: remove the if 0'ed pkt_start_recovery function (Ming Lei) [1936800]
- block: cleanup blkdev_bszset (Ming Lei) [1936800]
- block: move the NEED_PART_SCAN flag to struct gendisk (Ming Lei) [1936800]
- block: drop double zeroing (Ming Lei) [1936800]
- blk-throttle: Avoid checking bps/iops limitation if bps or iops is unlimited (Ming Lei) [1936800]
- blk-throttle: Avoid calculating bps/iops limitation repeatedly (Ming Lei) [1936800]
- blk-throttle: Define readable macros instead of static variables (Ming Lei) [1936800]
- blk-throttle: Use readable READ/WRITE macros (Ming Lei) [1936800]
- blk-throttle: Fix some comments' typos (Ming Lei) [1936800]
- block: introduce part_[begin|end]_io_acct (Ming Lei) [1936800]
- blkcg: add plugging support for punt bio (Ming Lei) [1936800]
- block: remove check_disk_change (Ming Lei) [1936800]
- sr: simplify sr_block_revalidate_disk (Ming Lei) [1936800]
- sr: use bdev_check_media_change (Ming Lei) [1936800]
- sd: use bdev_check_media_change (Ming Lei) [1936800]
- md: use bdev_check_media_change (Ming Lei) [1936800]
- gdrom: use bdev_check_media_change (Ming Lei) [1936800]
- paride/pcd: use bdev_check_media_change (Ming Lei) [1936800]
- xsysace: simplify media change handling (Ming Lei) [1936800]
- xsysace: use bdev_check_media_change (Ming Lei) [1936800]
- swim3: use bdev_check_media_changed (Ming Lei) [1936800]
- swim: simplify media change handling (Ming Lei) [1936800]
- swim: use bdev_check_media_change (Ming Lei) [1936800]
- ataflop: use bdev_check_media_change (Ming Lei) [1936800]
- amiflop: use bdev_check_media_change (Ming Lei) [1936800]
- block: add a bdev_check_media_change helper (Ming Lei) [1936800]
- block: Remove unused blk_mq_sched_free_hctx_data() (Ming Lei) [1936800]
- block: Do not discard buffers under a mounted filesystem (Ming Lei) [1936800]
- fs: Don't invalidate page buffers in block_write_full_page() (Ming Lei) [1936800]
- block: remove revalidate_disk() (Ming Lei) [1936800]
- nvdimm: simplify revalidate_disk handling (Ming Lei) [1936800]
- sd: open code revalidate_disk (Ming Lei) [1936800]
- nvme: opencode revalidate_disk in nvme_validate_ns (Ming Lei) [1936800]
- block: use revalidate_disk_size in set_capacity_revalidate_and_notify (Ming Lei) [1936800]
- block: add a new revalidate_disk_size helper (Ming Lei) [1936800]
- block: rename bd_invalidated (Ming Lei) [1936800]
- block: don't clear bd_invalidated in check_disk_size_change (Ming Lei) [1936800]
- block: better deal with the delayed not supported case in blk_cloned_rq_check_limits (Ming Lei) [1936800]
- block: Return blk_status_t instead of errno codes (Ming Lei) [1936800]
- block: grant IOPRIO_CLASS_RT to CAP_SYS_NICE (Ming Lei) [1936800]
- block: remove the unused q argument to part_in_flight and part_in_flight_rw (Ming Lei) [1936800]
- block: remove the disk argument to delete_partition (Ming Lei) [1936800]
- block: move the devcgroup_inode_permission call to blkdev_get (Ming Lei) [1936800]
- blk-mq: use BLK_MQ_NO_TAG for no tag (Ming Lei) [1936800]
- block: Move blk_mq_bio_list_merge() into blk-merge.c (Ming Lei) [1936800]
- block: Move bio merge related functions into blk-merge.c (Ming Lei) [1936800]
- blk-wbt: Remove obsolete multiqueue I/O scheduling comment (Ming Lei) [1936800]
- raw: deprecate the raw driver (Ming Lei) [1936800]
- nvme: don't call revalidate_disk from nvme_set_queue_dying (Ming Lei) [1936800]
- block: fix locking for struct block_device size updates (Ming Lei) [1936800]
- block: replace bd_set_size with bd_set_nr_sectors (Ming Lei) [1936800]
- block: Make request_queue.rpm_status an enum (Ming Lei) [1936800]
- mmc: remove the call to check_disk_change (Ming Lei) [1936800]
- block: integrate bd_start_claiming into __blkdev_get (Ming Lei) [1936800]
- block: use bd_prepare_to_claim directly in the loop driver (Ming Lei) [1936800]
- block: refactor bd_start_claiming (Ming Lei) [1936800]
- block: simplify the restart case in __blkdev_get (Ming Lei) [1936800]
- block: simplify set_init_blocksize (Ming Lei) [1936800]
- block: remove flush_disk (Ming Lei) [1936800]
- block: move block-related definitions out of fs.h (Ming Lei) [1936800]
- xen-blkfront.c: Convert to use set_capacity_revalidate_and_notify (Ming Lei) [1936800]

* Thu May 13 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.6.el8]
- redhat/configs: Add CONFIG_PINCTRL_EMMITSBURG (David Arcari) [1959506]
- redhat/configs: Remove CONFIG_EMMITSBURG (David Arcari) [1959506]
- fuse: fix write deadlock (Miklos Szeredi) [1904597]
- sched/debug: Fix cgroup_path[] serialization (Waiman Long) [1954363]
- KVM: x86/xen: Take srcu lock when accessing kvm_memslots() (Paolo Bonzini) [1945742]
- KVM: SVM: Allocate SEV command structures on local stack (Paolo Bonzini) [1945742]
- crypto: ccp: Use the stack and common buffer for INIT command (Paolo Bonzini) [1945742]
- crypto: ccp: Use the stack and common buffer for status commands (Paolo Bonzini) [1945742]
- crypto: ccp: Use the stack for small SEV command buffers (Paolo Bonzini) [1945742]
- crypto: ccp: Play nice with vmalloc'd memory for SEV command structs (Paolo Bonzini) [1945742]
- crypto: ccp: Reject SEV commands with mismatching command buffer (Paolo Bonzini) [1945742]
- crypto: ccp: Detect and reject "invalid" addresses destined for PSP (Paolo Bonzini) [1945742]
- crypto: ccp: Free SEV device if SEV init fails (Paolo Bonzini) [1945742]
- crypto: ccp - Fix sparse warnings in sev-dev (Paolo Bonzini) [1945742]
- drivers/crypto/ccp/sev-dev.c: get rid of pointless access_ok() (Paolo Bonzini) [1945742]
- crypto: ccp - Add support for SEV-ES to the PSP driver (Paolo Bonzini) [1945742]
- KVM: SVM: Add KVM_SEV_RECEIVE_FINISH command (Paolo Bonzini) [1945742]
- KVM: SVM: Add KVM_SEV_RECEIVE_UPDATE_DATA command (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for KVM_SEV_RECEIVE_START command (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for KVM_SEV_SEND_CANCEL command (Paolo Bonzini) [1945742]
- KVM: SVM: Add KVM_SEV_SEND_FINISH command (Paolo Bonzini) [1945742]
- KVM: SVM: Add KVM_SEND_UPDATE_DATA command (Paolo Bonzini) [1945742]
- KVM: SVM: Add KVM_SEV SEND_START command (Paolo Bonzini) [1945742]
- KVM: Boost vCPU candidate in user mode which is delivering interrupt (Paolo Bonzini) [1945742]
- nSVM: Check addresses of MSR and IO permission maps (Paolo Bonzini) [1945742]
- KVM: SVM: Define actual size of IOPM and MSRPM tables (Paolo Bonzini) [1945742]
- KVM: vmx: add mismatched size assertions in vmcs_check32() (Paolo Bonzini) [1945742]
- KVM: Add proper lockdep assertion in I/O bus unregister (Paolo Bonzini) [1945742]
- KVM: Stop looking for coalesced MMIO zones if the bus is destroyed (Paolo Bonzini) [1945742]
- KVM: Destroy I/O bus devices on unregister failure _after_ sync'ing SRCU (Paolo Bonzini) [1945742]
- KVM: SVM: Enhance and clean up the vmcb tracking comment in pre_svm_run() (Paolo Bonzini) [1945742]
- KVM: SVM: Add a comment to clarify what vcpu_svm.vmcb points at (Paolo Bonzini) [1945742]
- KVM: SVM: Drop vcpu_svm.vmcb_pa (Paolo Bonzini) [1945742]
- KVM: SVM: Don't set current_vmcb->cpu when switching vmcb (Paolo Bonzini) [1945742]
- KVM: SVM: Make sure GHCB is mapped before updating (Paolo Bonzini) [1945742]
- KVM: X86: Do not yield to self (Paolo Bonzini) [1945742]
- KVM: X86: Count attempted/successful directed yield (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Protect the tdp_mmu_roots list with RCU (Paolo Bonzini) [1945742]
- KVM: x86/mmu: handle cmpxchg failure in kvm_tdp_mmu_get_root (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Make TDP MMU root refcount atomic (Paolo Bonzini) [1945742]
- KVM: x86: implement KVM_CAP_SET_GUEST_DEBUG2 (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Refactor yield safe root iterator (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Merge TDP MMU put and free root (Paolo Bonzini) [1945742]
- KVM: x86/mmu: use tdp_mmu_free_sp to free roots (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Move kvm_mmu_(get|put)_root to TDP MMU (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Re-add const qualifier in kvm_tdp_mmu_zap_collapsible_sptes (Paolo Bonzini) [1945742]
- KVM: constify kvm_arch_flush_remote_tlbs_memslot (Paolo Bonzini) [1945742]
- KVM: Explicitly use GFP_KERNEL_ACCOUNT for 'struct kvm_vcpu' allocations (Paolo Bonzini) [1945742]
- KVM: MMU: protect TDP MMU pages only down to required level (Paolo Bonzini) [1945742]
- KVM: introduce KVM_CAP_SET_GUEST_DEBUG2 (Paolo Bonzini) [1945742]
- KVM: x86: pending exceptions must not be blocked by an injected event (Paolo Bonzini) [1945742]
- KVM: nSVM: call nested_svm_load_cr3 on nested state load (Paolo Bonzini) [1945742]
- KVM: x86: dump_vmcs should include the autoload/autostore MSR lists (Paolo Bonzini) [1945742]
- KVM: x86: dump_vmcs should show the effective EFER (Paolo Bonzini) [1945742]
- KVM: x86: dump_vmcs should consider only the load controls of EFER/PAT (Paolo Bonzini) [1945742]
- KVM: x86: dump_vmcs should not conflate EFER and PAT presence in VMCS (Paolo Bonzini) [1945742]
- KVM: x86: dump_vmcs should not assume GUEST_IA32_EFER is valid (Paolo Bonzini) [1945742]
- KVM: nSVM: improve SYSENTER emulation on AMD (Paolo Bonzini) [1945742]
- KVM: x86: add guest_cpuid_is_intel (Paolo Bonzini) [1945742]
- KVM: x86: Account a variety of miscellaneous allocations (Paolo Bonzini) [1945742]
- KVM: SVM: Do not allow SEV/SEV-ES initialization after vCPUs are created (Paolo Bonzini) [1945742]
- KVM: SVM: Do not set sev->es_active until KVM_SEV_ES_INIT completes (Paolo Bonzini) [1945742]
- KVM: SVM: Use online_vcpus, not created_vcpus, to iterate over vCPUs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Simplify code for aging SPTEs in TDP MMU (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Remove spurious clearing of dirty bit from TDP MMU SPTE (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use leaf-only loop for walking TDP SPTEs when changing SPTE (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Pass address space ID to TDP MMU root walkers (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Pass address space ID to __kvm_tdp_mmu_zap_gfn_range() (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Coalesce TLB flushes across address spaces for gfn range zap (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Coalesce TLB flushes when zapping collapsible SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Move flushing for "slot" handlers to caller for legacy MMU (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Coalesce TDP MMU TLB flushes when zapping collapsible SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/vPMU: Forbid reading from MSR_F15H_PERF MSRs when guest doesn't have X86_FEATURE_PERFCTR_CORE (Paolo Bonzini) [1945742]
- KVM: nSVM: If VMRUN is single-stepped, queue the #DB intercept in nested_svm_vmexit() (Paolo Bonzini) [1945742]
- KVM: MMU: load PDPTRs outside mmu_lock (Paolo Bonzini) [1945742]
- KVM: SVM: ensure that EFER.SVME is set when running nested guest or on nested vmexit (Paolo Bonzini) [1945742]
- KVM: SVM: load control fields from VMCB12 before checking them (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Don't allow TDP MMU to yield when recovering NX pages (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Ensure TLBs are flushed for TDP MMU during NX zapping (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Ensure TLBs are flushed when yielding during GFN range zap (Paolo Bonzini) [1945742]
- KVM: make: Fix out-of-source module builds (Paolo Bonzini) [1945742]
- KVM: x86/vPMU: Forbid writing to MSR_F15H_PERF MSRs when guest doesn't have X86_FEATURE_PERFCTR_CORE (Paolo Bonzini) [1945742]
- KVM: x86: remove unused declaration of kvm_write_tsc() (Paolo Bonzini) [1945742]
- KVM: clean up the unused argument (Paolo Bonzini) [1945742]
- x86/kvm: Fix broken irq restoration in kvm_wait (Paolo Bonzini) [1945742]
- KVM: X86: Fix missing local pCPU when executing wbinvd on all dirty pCPUs (Paolo Bonzini) [1945742]
- KVM: x86: Protect userspace MSR filter with SRCU, and set atomically-ish (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Store the address space ID in the TDP iterator (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Factor out tdp_iter_return_to_root (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Fix RCU usage when atomically zapping SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Fix RCU usage in handle_removed_tdp_mmu_page (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Mark the PAE roots as decrypted for shadow paging (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use '0' as the one and only value for an invalid PAE root (Paolo Bonzini) [1945742]
- KVM: VMX: Track root HPA instead of EPTP for paravirt Hyper-V TLB flush (Paolo Bonzini) [1945742]
- KVM: VMX: Skip additional Hyper-V TLB EPTP flushes if one fails (Paolo Bonzini) [1945742]
- KVM: VMX: Define Hyper-V paravirt TLB flush fields iff Hyper-V is enabled (Paolo Bonzini) [1945742]
- KVM: VMX: Explicitly check for hv_remote_flush_tlb when loading pgd (Paolo Bonzini) [1945742]
- KVM: VMX: Don't invalidate hv_tlb_eptp if the new EPTP matches (Paolo Bonzini) [1945742]
- KVM: VMX: Invalidate hv_tlb_eptp to denote an EPTP mismatch (Paolo Bonzini) [1945742]
- KVM: VMX: Do Hyper-V TLB flush iff vCPU's EPTP hasn't been flushed (Paolo Bonzini) [1945742]
- KVM: VMX: Fold Hyper-V EPTP checking into it's only caller (Paolo Bonzini) [1945742]
- KVM: VMX: Stash kvm_vmx in a local variable for Hyper-V paravirt TLB flush (Paolo Bonzini) [1945742]
- KVM: VMX: Track common EPTP for Hyper-V's paravirt TLB flush (Paolo Bonzini) [1945742]
- KVM: x86: Get active PCID only when writing a CR3 value (Paolo Bonzini) [1945742]
- KVM/SVM: Move vmenter.S exception fixups out of line (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Dump reserved bits if they're detected on non-MMIO SPTE (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use low available bits for removed SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use is_removed_spte() instead of open coded equivalents (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Tweak auditing WARN for A/D bits to !PRESENT (was MMIO) (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use a dedicated bit to track shadow/MMU-present SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use high bits for host/mmu writable masks for EPT SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Make Host-writable and MMU-writable bit locations dynamic (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Move logic for setting SPTE masks for EPT into the MMU proper (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Co-locate code for setting various SPTE masks (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Move initial kvm_mmu_set_mask_ptes() call into MMU proper (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Document dependency bewteen TDP A/D type and saved bits (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use MMIO SPTE bits 53 and 52 for the MMIO generation (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Rename and document A/D scheme for TDP SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Add module param to disable MMIO caching (for testing) (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Stop using software available bits to denote MMIO SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Rename 'mask' to 'spte' in MMIO SPTE helpers (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Drop redundant trace_kvm_mmu_set_spte() in the TDP MMU (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Handle MMIO SPTEs directly in mmu_set_spte() (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Don't install bogus MMIO SPTEs if MMIO caching is disabled (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Retry page faults that hit an invalid memslot (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Disable MMIO caching if MMIO value collides with L1TF (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Bail from fast_page_fault() if SPTE is not shadow-present (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Check for shadow-present SPTE before querying A/D status (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Add convenience wrapper for acting on single hva in TDP MMU (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Add typedefs for rmap/iter handlers (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use 'end' param in TDP MMU's test_age_gfn() (Paolo Bonzini) [1945742]
- KVM: x86/mmu: WARN if TDP MMU's set_tdp_spte() sees multiple GFNs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Remove spurious TLB flush from TDP MMU's change_pte() hook (Paolo Bonzini) [1945742]
- KVM: x86: mmu: initialize fault.async_page_fault in walk_addr_generic (Paolo Bonzini) [1945742]
- KVM: x86: determine if an exception has an error code only when injecting it. (Paolo Bonzini) [1945742]
- KVM: nSVM: Optimize vmcb12 to vmcb02 save area copies (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for Virtual SPEC_CTRL (Paolo Bonzini) [1945742]
- x86/cpufeatures: Add the Virtual SPEC_CTRL feature (Paolo Bonzini) [1945742]
- KVM: nSVM: always use vmcb01 to for vmsave/vmload of guest state (Paolo Bonzini) [1945742]
- KVM: SVM: move VMLOAD/VMSAVE to C code (Paolo Bonzini) [1945742]
- KVM: SVM: Skip intercepted PAUSE instructions after emulation (Paolo Bonzini) [1945742]
- KVM: SVM: Don't manually emulate RDPMC if nrips=0 (Paolo Bonzini) [1945742]
- KVM: x86: Move RDPMC emulation to common code (Paolo Bonzini) [1945742]
- KVM: x86: Move trivial instruction-based exit handlers to common code (Paolo Bonzini) [1945742]
- KVM: x86: Move XSETBV emulation to common code (Paolo Bonzini) [1945742]
- KVM: nSVM: Add VMLOAD/VMSAVE helper to deduplicate code (Paolo Bonzini) [1945742]
- KVM: nSVM: Add helper to synthesize nested VM-Exit without collateral (Paolo Bonzini) [1945742]
- KVM: x86: Handle triple fault in L2 without killing L1 (Paolo Bonzini) [1945742]
- KVM: SVM: Pass struct kvm_vcpu to exit handlers (and many, many other places) (Paolo Bonzini) [1945742]
- KVM: SVM: merge update_cr0_intercept into svm_set_cr0 (Paolo Bonzini) [1945742]
- KVM: nSVM: Trace VM-Enter consistency check failures (Paolo Bonzini) [1945742]
- KVM: x86: Move nVMX's consistency check macro to common code (Paolo Bonzini) [1945742]
- KVM: nSVM: Add missing checks for reserved bits to svm_set_nested_state() (Paolo Bonzini) [1945742]
- KVM: nSVM: only copy L1 non-VMLOAD/VMSAVE data in svm_set_nested_state() (Paolo Bonzini) [1945742]
- KVM: nSVM: do not mark all VMCB02 fields dirty on nested vmexit (Paolo Bonzini) [1945742]
- KVM: nSVM: do not mark all VMCB01 fields dirty on nested vmexit (Paolo Bonzini) [1945742]
- KVM: nSVM: do not copy vmcb01->control blindly to vmcb02->control (Paolo Bonzini) [1945742]
- KVM: nSVM: rename functions and variables according to vmcbXY nomenclature (Paolo Bonzini) [1945742]
- KVM: nSVM: Track the ASID generation of the vmcb vmrun through the vmcb (Paolo Bonzini) [1945742]
- KVM: nSVM: Track the physical cpu of the vmcb vmrun through the vmcb (Paolo Bonzini) [1945742]
- KVM: SVM: Use a separate vmcb for the nested L2 guest (Paolo Bonzini) [1945742]
- KVM: nSVM: Set the shadow root level to the TDP level for nested NPT (Paolo Bonzini) [1945742]
- KVM: SVM: Don't strip the C-bit from CR2 on #PF interception (Paolo Bonzini) [1945742]
- KVM: x86/mmu: WARN on NULL pae_root or lm_root, or bad shadow root level (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Sync roots after MMU load iff load as successful (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Unexport MMU load/unload functions (Paolo Bonzini) [1945742]
- KVM: x86: Defer the MMU unload to the normal path on an global INVPCID (Paolo Bonzini) [1945742]
- KVM: nVMX: Defer the MMU reload to the normal path on an EPTP switch (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Set the C-bit in the PDPTRs and LM pseudo-PDPTRs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Fix and unconditionally enable WARNs to detect PAE leaks (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Check PDPTRs before allocating PAE roots (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Ensure MMU pages are available when allocating roots (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Allocate pae_root and lm_root pages in dedicated helper (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Allocate the lm_root before allocating PAE roots (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Capture 'mmu' in a local variable when allocating roots (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Alloc page for PDPTEs when shadowing 32-bit NPT with 64-bit (Paolo Bonzini) [1945742]
- KVM: x86: to track if L1 is running L2 VM (Paolo Bonzini) [1945742]
- KVM: LAPIC: Advancing the timer expiration on guest initiated write (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Skip !MMU-present SPTEs when removing SP in exclusive mode (Paolo Bonzini) [1945742]
- KVM: kvmclock: Fix vCPUs > 64 can't be online/hotpluged (Paolo Bonzini) [1945742]
- kvm: x86: use NULL instead of using plain integer as pointer (Paolo Bonzini) [1945742]
- KVM: SVM: Connect 'npt' module param to KVM's internal 'npt_enabled' (Paolo Bonzini) [1945742]
- KVM: x86: Ensure deadline timer has truly expired before posting its IRQ (Paolo Bonzini) [1945742]
- KVM: x86/xen: Fix return code when clearing vcpu_info and vcpu_time_info (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Set SPTE_AD_WRPROT_ONLY_MASK if and only if PML is enabled (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Fix Hyper-V context null-ptr-deref (Paolo Bonzini) [1945742]
- KVM: SVM: Fix nested VM-Exit on #GP interception handling (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Fix dummy check if lbr_desc->event is created (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Consider the hva in mmu_notifier retry (Paolo Bonzini) [1945742]
- kernel.h: split out min()/max() et al. helpers (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Skip mmu_notifier check when handling MMIO page fault (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Remove a variety of unnecessary exports (Paolo Bonzini) [1945742]
- KVM: x86: Fold "write-protect large" use case into generic write-protect (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Don't set dirty bits when disabling dirty logging w/ PML (Paolo Bonzini) [1945742]
- KVM: VMX: Dynamically enable/disable PML based on memslot dirty logging (Paolo Bonzini) [1945742]
- KVM: x86: Further clarify the logic and comments for toggling log dirty (Paolo Bonzini) [1945742]
- KVM: x86: Move MMU's PML logic to common code (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Make dirty log size hook (PML) a value, not a function (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Expand on the comment in kvm_vcpu_ad_need_write_protect() (Paolo Bonzini) [1945742]
- KVM: nVMX: Disable PML in hardware when running L2 (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Consult max mapping level when zapping collapsible SPTEs (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Pass the memslot to the rmap callbacks (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Split out max mapping level calculation to helper (Paolo Bonzini) [1945742]
- KVM: nVMX: no need to undo inject_page_fault change on nested vmexit (Paolo Bonzini) [1945742]
- KVM: nSVM: move nested vmrun tracepoint to enter_svm_guest_mode (Paolo Bonzini) [1945742]
- KVM: VMX: read idt_vectoring_info a bit earlier (Paolo Bonzini) [1945742]
- KVM: VMX: Allow INVPCID in guest without PCID (Paolo Bonzini) [1945742]
- KVM: x86: Advertise INVPCID by default (Paolo Bonzini) [1945742]
- KVM: SVM: Intercept INVPCID when it's disabled to inject #UD (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Make HVA handler retpoline-friendly (Paolo Bonzini) [1945742]
- KVM: x86: move kvm_inject_gp up from kvm_set_dr to callers (Paolo Bonzini) [1945742]
- KVM: x86: reading DR cannot fail (Paolo Bonzini) [1945742]
- KVM: SVM: Remove an unnecessary forward declaration (Paolo Bonzini) [1945742]
- KVM: SVM: Move AVIC vCPU kicking snippet to helper function (Paolo Bonzini) [1945742]
- KVM: x86: Restore all 64 bits of DR6 and DR7 during RSM on x86-64 (Paolo Bonzini) [1945742]
- KVM: x86: Remove misleading DR6/DR7 adjustments from RSM emulation (Paolo Bonzini) [1945742]
- KVM: x86/xen: Use hva_t for holding hypercall page address (Paolo Bonzini) [1945742]
- KVM: x86/xen: Remove extra unlock in kvm_xen_hvm_set_attr() (Paolo Bonzini) [1945742]
- KVM: Use kvm_pfn_t for local PFN variable in hva_to_pfn_remapped() (Paolo Bonzini) [1945742]
- KVM: x86: Add helper to consolidate "raw" reserved GPA mask calculations (Paolo Bonzini) [1945742]
- KVM: selftests: Always run vCPU thread with blocked SIG_IPI (Paolo Bonzini) [1945742]
- KVM: selftests: Sync data verify of dirty logging with guest sync (Paolo Bonzini) [1945742]
- KVM: selftests: Add a test for kvm page table code (Paolo Bonzini) [1945742]
- KVM: selftests: Adapt vm_userspace_mem_region_add to new helpers (Paolo Bonzini) [1945742]
- KVM: selftests: List all hugetlb src types specified with page sizes (Paolo Bonzini) [1945742]
- tools/headers: sync headers of asm-generic/hugetlb_encode.h (Paolo Bonzini) [1945742]
- tools include uapi: Update linux/mmap.h copy (Paolo Bonzini) [1945742]
- tools UAPI: Update copy of linux/mman.h from the kernel sources (Paolo Bonzini) [1945742]
- mm/hugetlb: add mmap() encodings for 32MB and 512MB page sizes (Paolo Bonzini) [1945742]
- RHEL: Add #defines for 16k hugepages (Paolo Bonzini) [1945742]
- KVM: selftests: Add a helper to get system default hugetlb page size (Paolo Bonzini) [1945742]
- KVM: selftests: Add a helper to get system configured THP page size (Paolo Bonzini) [1945742]
- KVM: selftests: Make a generic helper to get vm guest mode strings (Paolo Bonzini) [1945742]
- KVM: selftests: Print the errno besides error-string in TEST_ASSERT (Paolo Bonzini) [1945742]
- KVM: selftests: remove redundant semi-colon (Paolo Bonzini) [1945742]
- selftests: kvm: Check that TSC page value is small after KVM_SET_CLOCK(0) (Paolo Bonzini) [1945742]
- KVM: x86: Prevent 'hv_clock->system_time' from going negative in kvm_guest_time_update() (Paolo Bonzini) [1945742]
- selftests: kvm: make hardware_disable_test less verbose (Paolo Bonzini) [1945742]
- selftests: kvm: add set_boot_cpu_id test (Paolo Bonzini) [1945742]
- selftests: kvm: add _vm_ioctl (Paolo Bonzini) [1945742]
- selftests: kvm: add get_msr_index_features (Paolo Bonzini) [1945742]
- KVM: x86/xen: Add support for vCPU runstate information (Paolo Bonzini) [1945742]
- RHEL: configs: do not enable CONFIG_KVM_XEN (Paolo Bonzini) [1945742]
- KVM: x86: allow compiling out the Xen hypercall interface (Paolo Bonzini) [1945742]
- KVM: x86: compile out TDP MMU on 32-bit systems (Paolo Bonzini) [1945742]
- KVM: xen: flush deferred static key before checking it (Paolo Bonzini) [1945742]
- KVM: x86/xen: Explicitly pad struct compat_vcpu_info to 64 bytes (Paolo Bonzini) [1945742]
- KVM: x86/xen: Allow reset of Xen attributes (Paolo Bonzini) [1945742]
- KVM: Documentation: rectify rst markup in kvm_run->flags (Paolo Bonzini) [1945742]
- Documentation: kvm: fix messy conversion from .txt to .rst (Paolo Bonzini) [1945742]
- KVM: Documentation: rectify rst markup in KVM_GET_SUPPORTED_HV_CPUID (Paolo Bonzini) [1945742]
- Documentation: kvm: fix warning (Paolo Bonzini) [1945742]
- KVM: Add documentation for Xen hypercall and shared_info updates (Paolo Bonzini) [1945742]
- KVM: X86: Add the Document for KVM_CAP_X86_BUS_LOCK_EXIT (Paolo Bonzini) [1945742]
- KVM: Documentation: Fix documentation for nested. (Paolo Bonzini) [1945742]
- KVM: Documentation: Add arm64 KVM_RUN error codes (Paolo Bonzini) [1945742]
- KVM: Documentation: Update entry for KVM_CAP_ENFORCE_PV_CPUID (Paolo Bonzini) [1945742]
- KVM: Documentation: Update entry for KVM_X86_SET_MSR_FILTER (Paolo Bonzini) [1945742]
- docs: kvm: add documentation for KVM_CAP_S390_DIAG318 (Paolo Bonzini) [1945742]
- selftests: kvm: Mmap the entire vcpu mmap area (Paolo Bonzini) [1945742]
- selftests: kvm: avoid uninitialized variable warning (Paolo Bonzini) [1945742]
- selftests: kvm: add hardware_disable test (Paolo Bonzini) [1945742]
- KVM: selftests: Don't bother mapping GVA for Xen shinfo test (Paolo Bonzini) [1945742]
- KVM: selftests: Fix hex vs. decimal snafu in Xen test (Paolo Bonzini) [1945742]
- KVM: selftests: Fix size of memslots created by Xen tests (Paolo Bonzini) [1945742]
- KVM: selftests: Ignore recently added Xen tests' build output (Paolo Bonzini) [1945742]
- KVM: x86: declare Xen HVM shared info capability and add test case (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Drop hv_vcpu_to_vcpu() helper (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Allocate Hyper-V context lazily (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Make Hyper-V emulation enablement conditional (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Allocate 'struct kvm_vcpu_hv' dynamically (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Prepare to meet unallocated Hyper-V context (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Always use to_hv_vcpu() accessor to get to 'struct kvm_vcpu_hv' (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Stop shadowing global 'current_vcpu' variable (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Introduce to_kvm_hv() helper (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Rename vcpu_to_hv_syndbg() to to_hv_syndbg() (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Rename vcpu_to_stimer()/stimer_to_vcpu() (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Rename vcpu_to_synic()/synic_to_vcpu() (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Rename vcpu_to_hv_vcpu() to to_hv_vcpu() (Paolo Bonzini) [1945742]
- KVM: x86: hyper-v: Drop unused kvm_hv_vapic_assist_page_enabled() (Paolo Bonzini) [1945742]
- KVM: x86/xen: Add event channel interrupt vector upcall (Paolo Bonzini) [1945742]
- KVM: x86/xen: register vcpu time info region (Paolo Bonzini) [1945742]
- KVM: x86/xen: setup pvclock updates (Paolo Bonzini) [1945742]
- KVM: x86/xen: register vcpu info (Paolo Bonzini) [1945742]
- KVM: x86/xen: Add KVM_XEN_VCPU_SET_ATTR/KVM_XEN_VCPU_GET_ATTR (Paolo Bonzini) [1945742]
- KVM: x86/xen: update wallclock region (Paolo Bonzini) [1945742]
- xen: add wc_sec_hi to struct shared_info (Paolo Bonzini) [1945742]
- KVM: x86/xen: register shared_info page (Paolo Bonzini) [1945742]
- KVM: x86/xen: add definitions of compat_shared_info, compat_vcpu_info (Paolo Bonzini) [1945742]
- KVM: x86/xen: latch long_mode when hypercall page is set up (Paolo Bonzini) [1945742]
- KVM: x86/xen: add KVM_XEN_HVM_SET_ATTR/KVM_XEN_HVM_GET_ATTR (Paolo Bonzini) [1945742]
- KVM: x86/xen: Add kvm_xen_enabled static key (Paolo Bonzini) [1945742]
- KVM: x86/xen: Move KVM_XEN_HVM_CONFIG handling to xen.c (Paolo Bonzini) [1945742]
- KVM: x86/xen: Fix coexistence of Xen and Hyper-V hypercalls (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Add helper to generate mask of reserved HPA bits (Paolo Bonzini) [1945742]
- KVM: x86: Use reserved_gpa_bits to calculate reserved PxE bits (Paolo Bonzini) [1945742]
- KVM: x86: SEV: Treat C-bit as legal GPA bit regardless of vCPU mode (Paolo Bonzini) [1945742]
- KVM: nSVM: Use common GPA helper to check for illegal CR3 (Paolo Bonzini) [1945742]
- KVM: VMX: Use GPA legality helpers to replace open coded equivalents (Paolo Bonzini) [1945742]
- KVM: x86: Add a helper to handle legal GPA with an alignment requirement (Paolo Bonzini) [1945742]
- KVM: x86: Add a helper to check for a legal GPA (Paolo Bonzini) [1945742]
- KVM: nSVM: Don't strip host's C-bit from guest's CR3 when reading PDPTRs (Paolo Bonzini) [1945742]
- KVM: x86: Set so called 'reserved CR3 bits in LM mask' at vCPU reset (Paolo Bonzini) [1945742]
- KVM: x86/xen: intercept xen hypercalls if enabled (Paolo Bonzini) [1945742]
- KVM: selftests: Add missing header file needed by xAPIC IPI tests (Paolo Bonzini) [1945742]
- KVM: selftests: Add operand to vmsave/vmload/vmrun in svm.c (Paolo Bonzini) [1945742]
- selftests: kvm: Properly set Hyper-V CPUIDs in evmcs_test (Paolo Bonzini) [1945742]
- selftests: kvm: Move kvm_get_supported_hv_cpuid() to common code (Paolo Bonzini) [1945742]
- selftest: kvm: x86: test KVM_GET_CPUID2 and guest visible CPUIDs against KVM_GET_SUPPORTED_CPUID (Paolo Bonzini) [1945742]
- selftests: kvm/x86: add test for pmu msr MSR_IA32_PERF_CAPABILITIES (Paolo Bonzini) [1945742]
- KVM: selftests: Disable dirty logging with vCPUs running (Paolo Bonzini) [1945742]
- KVM: selftests: Add backing src parameter to dirty_log_perf_test (Paolo Bonzini) [1945742]
- KVM: selftests: Add memslot modification stress test (Paolo Bonzini) [1945742]
- KVM: selftests: Add option to overlap vCPU memory access (Paolo Bonzini) [1945742]
- KVM: selftests: Fix population stage in dirty_log_perf_test (Paolo Bonzini) [1945742]
- KVM: selftests: Convert iterations to int in dirty_log_perf_test (Paolo Bonzini) [1945742]
- KVM: selftests: Avoid flooding debug log while populating memory (Paolo Bonzini) [1945742]
- KVM: selftests: Rename timespec_diff_now to timespec_elapsed (Paolo Bonzini) [1945742]
- KVM: selftests: Test IPI to halted vCPU in xAPIC while backing page moves (Paolo Bonzini) [1945742]
- KVM: selftests: Implement perf_test_util more conventionally (Paolo Bonzini) [1945742]
- KVM: selftests: Use vm_create_with_vcpus in create_vm (Paolo Bonzini) [1945742]
- KVM: selftests: Factor out guest mode code (Paolo Bonzini) [1945742]
- selftests: kvm: Merge user_msr_test into userspace_msr_exit_test (Paolo Bonzini) [1945742]
- selftests: kvm: Test MSR exiting to userspace (Paolo Bonzini) [1945742]
- KVM: selftests: sync_regs test for diag318 (Paolo Bonzini) [1945742]
- KVM: selftests: x86: Set supported CPUIDs on default VM (Paolo Bonzini) [1945742]
- KVM: selftests: Make test skipping consistent (Paolo Bonzini) [1945742]
- KVM: selftests: Introduce vm_create_[default_]_with_vcpus (Paolo Bonzini) [1945742]
- KVM: selftests: Make vm_create_default common (Paolo Bonzini) [1945742]
- KVM: selftests: always use manual clear in dirty_log_perf_test (Paolo Bonzini) [1945742]
- selftests: kvm: keep .gitignore add to date (Paolo Bonzini) [1945742]
- KVM: selftests: Add "-c" parameter to dirty log test (Paolo Bonzini) [1945742]
- KVM: selftests: Run dirty ring test asynchronously (Paolo Bonzini) [1945742]
- KVM: selftests: Add dirty ring buffer test (Paolo Bonzini) [1945742]
- KVM: selftests: Introduce after_vcpu_run hook for dirty log test (Paolo Bonzini) [1945742]
- KVM: selftests: Verify supported CR4 bits can be set before KVM_SET_CPUID2 (Paolo Bonzini) [1945742]
- KVM: selftests: allow two iterations of dirty_log_perf_test (Paolo Bonzini) [1945742]
- KVM: selftests: Introduce the dirty log perf test (Paolo Bonzini) [1945742]
- KVM: selftests: Make the number of vcpus global (Paolo Bonzini) [1945742]
- KVM: selftests: Make the per vcpu memory size global (Paolo Bonzini) [1945742]
- KVM: selftests: Drop pointless vm_create wrapper (Paolo Bonzini) [1945742]
- KVM: selftests: Add wrfract to common guest code (Paolo Bonzini) [1945742]
- KVM: selftests: Simplify demand_paging_test with timespec_diff_now (Paolo Bonzini) [1945742]
- KVM: selftests: Remove address rounding in guest code (Paolo Bonzini) [1945742]
- KVM: selftests: Factor code out of demand_paging_test (Paolo Bonzini) [1945742]
- KVM: selftests: Use a single binary for dirty/clear log test (Paolo Bonzini) [1945742]
- KVM: selftests: Always clear dirty bitmap after iteration (Paolo Bonzini) [1945742]
- selftests: kvm: test enforcement of paravirtual cpuid features (Paolo Bonzini) [1945742]
- selftests: kvm: Add exception handling to selftests (Paolo Bonzini) [1945742]
- selftests: kvm: Clear uc so UCALL_NONE is being properly reported (Paolo Bonzini) [1945742]
- selftests: kvm: Fix the segment descriptor layout to match the actual layout (Paolo Bonzini) [1945742]
- KVM: x86/xen: Fix __user pointer handling for hypercall page installation (Paolo Bonzini) [1945742]
- KVM: x86/xen: fix Xen hypercall page msr handling (Paolo Bonzini) [1945742]
- KVM: x86: move kvm_inject_gp up from kvm_set_xcr to callers (Paolo Bonzini) [1945742]
- KVM: cleanup DR6/DR7 reserved bits checks (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Add '__func__' in rmap_printk() (Paolo Bonzini) [1945742]
- KVM: SVM: Replace hard-coded value with #define (Paolo Bonzini) [1945742]
- KVM: SVM: use .prepare_guest_switch() to handle CPU register save/setup (Paolo Bonzini) [1945742]
- KVM: SVM: remove uneeded fields from host_save_users_msrs (Paolo Bonzini) [1945742]
- KVM: SVM: use vmsave/vmload for saving/restoring additional host state (Paolo Bonzini) [1945742]
- KVM: SVM: Use asm goto to handle unexpected #UD on SVM instructions (Paolo Bonzini) [1945742]
- KVM: VMX: Use the kernel's version of VMXOFF (Paolo Bonzini) [1945742]
- KVM: VMX: Move Intel PT shenanigans out of VMXON/VMXOFF flows (Paolo Bonzini) [1945742]
- KVM/nVMX: Use __vmx_vcpu_run in nested_vmx_check_vmentry_hw (Paolo Bonzini) [1945742]
- x86/virt: Mark flags and memory as clobbered by VMXOFF (Paolo Bonzini) [1945742]
- x86/reboot: Force all cpus to exit VMX root if VMX is supported (Paolo Bonzini) [1945742]
- x86/virt: Eat faults on VMXOFF in reboot flows (Paolo Bonzini) [1945742]
- KVM: x86: use static calls to reduce kvm_x86_ops overhead (Paolo Bonzini) [1945742]
- KVM: x86: introduce definitions to support static calls for kvm_x86_ops (Paolo Bonzini) [1945742]
- KVM: RHEL: include linux/static_call.h (Paolo Bonzini) [1945742]
- KVM: X86: prepend vmx/svm prefix to additional kvm_x86_ops functions (Paolo Bonzini) [1945742]
- KVM: Stop using deprecated jump label APIs (Paolo Bonzini) [1945742]
- locking/static_key: Add support for deferred static branches (Paolo Bonzini) [1945742]
- KVM: X86: Rename DR6_INIT to DR6_ACTIVE_LOW (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Expose LBR_FMT in the MSR_IA32_PERF_CAPABILITIES (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Release guest LBR event via lazy release mechanism (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Emulate legacy freezing LBRs on virtual PMI (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Reduce the overhead of LBR pass-through or cancellation (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Pass-through LBR msrs when the guest LBR event is ACTIVE (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Create a guest LBR event when vcpu sets DEBUGCTLMSR_LBR (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Add PMU_CAP_LBR_FMT check when guest LBR is enabled (Paolo Bonzini) [1945742]
- KVM: vmx/pmu: Add PMU_CAP_LBR_FMT check when guest LBR is enabled (Paolo Bonzini) [1945742]
- KVM: x86/pmu: preserve IA32_PERF_CAPABILITIES across CPUID refresh (Paolo Bonzini) [1945742]
- KVM: x86/vmx: Make vmx_set_intercept_for_msr() non-static (Paolo Bonzini) [1945742]
- KVM: VMX: read/write MSR_IA32_DEBUGCTLMSR from GUEST_IA32_DEBUGCTL (Paolo Bonzini) [1945742]
- KVM: VMX: Use x2apic_mode to avoid RDMSR when querying PI state (Paolo Bonzini) [1945742]
- x86/apic: Export x2apic_mode for use by KVM in "warm" path (Paolo Bonzini) [1945742]
- KVM: VMX: Enable bus lock VM exit (Paolo Bonzini) [1945742]
- KVM: X86: Reset the vcpu->run->flags at the beginning of vcpu_run (Paolo Bonzini) [1945742]
- KVM: VMX: Convert vcpu_vmx.exit_reason to a union (Paolo Bonzini) [1945742]
- KVM/SVM: add support for SEV attestation command (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Remove the defunct update_pte() paging hook (Paolo Bonzini) [1945742]
- KVM: Expose AVX_VNNI instruction to guset (Paolo Bonzini) [1945742]
- Enumerate AVX Vector Neural Network instructions (Paolo Bonzini) [1945742]
- x86: kvm: style: Simplify bool comparison (Paolo Bonzini) [1945742]
- KVM: x86: Zap the oldest MMU pages, not the newest (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Use boolean returns for (S)PTE accessors (Paolo Bonzini) [1945742]
- KVM: X86: use vzalloc() instead of vmalloc/memset (Paolo Bonzini) [1945742]
- KVM: x86: Take KVM's SRCU lock only if steal time update is needed (Paolo Bonzini) [1945742]
- KVM: x86: Remove obsolete disabling of page faults in kvm_arch_vcpu_put() (Paolo Bonzini) [1945742]
- KVM: do not assume PTE is writable after follow_pfn (Paolo Bonzini) [1945742]
- KVM: x86/mmu: Fix TDP MMU zap collapsible SPTEs (Paolo Bonzini) [1945742]
- KVM: x86: cleanup CR3 reserved bits checks (Paolo Bonzini) [1945742]
- KVM: SVM: Treat SVM as unsupported when running as an SEV guest (Paolo Bonzini) [1945742]
- KVM: x86: Update emulator context mode if SYSENTER xfers to 64-bit mode (Paolo Bonzini) [1945742]
- KVM: x86: Supplement __cr4_reserved_bits() with X86_FEATURE_PCID check (Paolo Bonzini) [1945742]
- KVM/x86: assign hva with the right value to vm_munmap the pages (Paolo Bonzini) [1945742]
- Fix unsynchronized access to sev members through svm_register_enc_region (Paolo Bonzini) [1945742]
- KVM: x86: Revert "KVM: x86: Mark GPRs dirty when written" (Paolo Bonzini) [1945742]
- KVM: SVM: Unconditionally sync GPRs to GHCB on VMRUN of SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: x86: __kvm_vcpu_halt can be static (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for booting APs in an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM/SVM: Remove leftover __svm_vcpu_run prototype from svm.c (Paolo Bonzini) [1945742]
- KVM: SVM: Add register operand to vmsave call in sev_es_vcpu_load (Paolo Bonzini) [1945742]
- KVM: SVM: fix 32-bit compilation (Paolo Bonzini) [1945742]
- KVM: SVM: Add AP_JUMP_TABLE support in prep for AP booting (Paolo Bonzini) [1945742]
- KVM: SVM: Provide support to launch and run an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Provide an updated VMRUN invocation for SEV-ES guests (Paolo Bonzini) [1945742]
- x86/kvm/svm: Use uninstrumented wrmsrl() to restore GS (Paolo Bonzini) [1945742]
- KVM: SVM: Provide support for SEV-ES vCPU loading (Paolo Bonzini) [1945742]
- KVM: SVM: Provide support for SEV-ES vCPU creation/loading (Paolo Bonzini) [1945742]
- KVM: SVM: Update ASID allocation to support SEV-ES guests (Paolo Bonzini) [1945742]
- KVM: SVM: Set the encryption mask for the SVM host save area (Paolo Bonzini) [1945742]
- KVM: SVM: Add NMI support for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Guest FPU state save/restore not needed for SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Do not report support for SMM for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: x86: Update __get_sregs() / __set_sregs() to support SEV-ES (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for CR8 write traps for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for CR4 write traps for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for CR0 write traps for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for EFER write traps for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Support string IO operations for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Support MMIO for an SEV-ES guest (Paolo Bonzini) [1945742]
- KVM: SVM: Create trace events for VMGEXIT MSR protocol processing (Paolo Bonzini) [1945742]
- KVM: SVM: Create trace events for VMGEXIT processing (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for SEV-ES GHCB MSR protocol function 0x100 (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for SEV-ES GHCB MSR protocol function 0x004 (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for SEV-ES GHCB MSR protocol function 0x002 (Paolo Bonzini) [1945742]
- KVM: SVM: Add initial support for a VMGEXIT VMEXIT (Paolo Bonzini) [1945742]
- KVM: SVM: Add GHCB accessor functions for retrieving fields (Paolo Bonzini) [1945742]
- KVM: SVM: Prepare for SEV-ES exit handling in the sev.c file (Paolo Bonzini) [1945742]
- KVM: SVM: Cannot re-initialize the VMCB after shutdown with SEV-ES (Paolo Bonzini) [1945742]
- KVM: SVM: Do not allow instruction emulation under SEV-ES (Paolo Bonzini) [1945742]
- KVM: SVM: Prevent debugging under SEV-ES (Paolo Bonzini) [1945742]
- KVM: SVM: Add required changes to support intercepts under SEV-ES (Paolo Bonzini) [1945742]
- KVM: x86: introduce complete_emulated_msr callback (Paolo Bonzini) [1945742]
- KVM: x86: Mark GPRs dirty when written (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for the SEV-ES VMSA (Paolo Bonzini) [1945742]
- x86/cpu: Add VM page flush MSR availablility as a CPUID feature (Paolo Bonzini) [1945742]
- KVM: SVM: Add support for SEV-ES capability in KVM (Paolo Bonzini) [1945742]
- KVM/VMX/SVM: Move kvm_machine_check function to x86.h (Paolo Bonzini) [1945742]
- KVM: Don't allocate dirty bitmap if dirty ring is enabled (Paolo Bonzini) [1945742]
- KVM: Make dirty ring exclusive to dirty bitmap log (Paolo Bonzini) [1945742]
- KVM: X86: Implement ring-based dirty memory tracking (Paolo Bonzini) [1945742]
- KVM: Pass in kvm pointer into mark_page_dirty_in_slot() (Paolo Bonzini) [1945742]
- kvm/eventfd: Drain events from eventfd in irqfd_wakeup() (Paolo Bonzini) [1945742]
- eventfd: Export eventfd_ctx_do_read() (Paolo Bonzini) [1945742]
- kvm/eventfd: Use priority waitqueue to catch events before userspace (Paolo Bonzini) [1945742]
- sched/wait: Add add_wait_queue_priority() (Paolo Bonzini) [1945742]
- cpuidle-haltpoll: fix error comments in arch_haltpoll_disable (Paolo Bonzini) [1945742]
- kvm/eventfd: Use sequence counter with associated spinlock (Paolo Bonzini) [1945742]
- x86/kvm/vmx: Use native read/write_cr2() (Paolo Bonzini) [1945742]
- KVM: SVM: convert get_user_pages() --> pin_user_pages() (Paolo Bonzini) [1945742]
- x86/asm: Change all ENTRY+ENDPROC to SYM_FUNC_* (Paolo Bonzini) [1945742]
- x86/entry/64: Fix unwind hints in __switch_to_asm() (Paolo Bonzini) [1945742]
- x86/asm/64: Change all ENTRY+END to SYM_CODE_* (Paolo Bonzini) [1945742]
- x86/head/64: Annotate start_cpu0() as non-callable (Paolo Bonzini) [1945742]
- x86/asm: Do not annotate functions with GLOBAL (Paolo Bonzini) [1945742]
- kprobes/x86/xen: blacklist non-attachable xen interrupt functions (Paolo Bonzini) [1945742]
- x86/asm/64: Add ENDs to some functions and relabel with SYM_CODE_* (Paolo Bonzini) [1945742]
- x86/asm: Use SYM_INNER_LABEL instead of GLOBAL (Paolo Bonzini) [1945742]
- x86/asm: Annotate aliases (Paolo Bonzini) [1945742]
- x86/asm/crypto: Annotate local functions (Paolo Bonzini) [1945742]
- static_call: Add static_call_cond() (Paolo Bonzini) [1945742]
- static_call: Add basic static call infrastructure (Paolo Bonzini) [1945742]
- devlink: use _BITUL() macro instead of BIT() in the UAPI header (Petr Oros) [1935646]
- devlink: Fix reload stats structure (Petr Oros) [1935646]
- devlink: Avoid overwriting port attributes of registered port (Petr Oros) [1935646]
- devlink: Add Documentation/networking/devlink/devlink-reload.rst (Petr Oros) [1935646]
- devlink: Add enable_remote_dev_reset generic parameter (Petr Oros) [1935646]
- devlink: Add remote reload stats (Petr Oros) [1935646]
- devlink: Add reload stats (Petr Oros) [1935646]
- devlink: Add devlink reload limit option (Petr Oros) [1935646]
- devlink: Add reload action option to devlink reload command (Petr Oros) [1935646]
- devlink: Change devlink_reload_supported() param type (Petr Oros) [1935646]

* Wed May 12 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.5.el8]
- CI: Rename KABI option (Veronika Kabatova)
- CI: Disable result checking for realtime checks (Veronika Kabatova)
- Revert "GFS2: Re-add a call to log_flush_wait when flushing the journal" (Bob Peterson) [1917930]
- md/raid1: properly indicate failure when ending a failed write request (Nigel Croxon) [1954588]
- Revert "uio: use request_threaded_irq instead" (Vitaly Kuznetsov) [1946644]
- drm/ast: Set format registers in primary plane's update (Lyude Paul) [1923857]
- drivers: hv: Create a consistent pattern for checking Hyper-V hypercall status (Mohammed Gamal) [1940926]
- x86/hyperv: Move hv_do_rep_hypercall to asm-generic (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Increase wait time for VMbus unload (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Initialize unload_event statically (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Check for pending channel interrupts before taking a CPU offline (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Drivers: hv: vmbus: Introduce CHANNELMSG_MODIFYCHANNEL_RESPONSE (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Introduce and negotiate VMBus protocol version 5.3 (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Use after free in __vmbus_open() (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: remove unused function (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Remove unused linux/version.h header (Mohammed Gamal) [1940926]
- x86/Hyper-V: Support for free page reporting (Mohammed Gamal) [1940926]
- x86/hyper-v: Move hv_message_type to architecture neutral module (Mohammed Gamal) [1940926]
- asm-generic/hyperv: import data structures for mapping device interrupts (Mohammed Gamal) [1940926]
- asm-generic/hyperv: introduce hv_device_id and auxiliary structures (Mohammed Gamal) [1940926]
- asm-generic/hyperv: update hv_interrupt_entry (Mohammed Gamal) [1940926]
- asm-generic/hyperv: update hv_msi_entry (Mohammed Gamal) [1940926]
- x86/hyperv: provide a bunch of helper functions (Mohammed Gamal) [1940926]
- x86/hyperv: extract partition ID from Microsoft Hypervisor if necessary (Mohammed Gamal) [1940926]
- asm-generic/hyperv: Add definitions for Get/SetVpRegister hypercalls (Mohammed Gamal) [1940926]
- drivers: hv: Fix EXPORT_SYMBOL and tab spaces issue (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Drop error message when 'No request id available' (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Move handling of VMbus interrupts (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Handle auto EOI quirk inline (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Move hyperv_report_panic_msg to arch neutral code (Mohammed Gamal) [1940926]
- Drivers: hv: Redo Hyper-V synthetic MSR get/set functions (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Move Hyper-V page allocator to arch neutral code (Mohammed Gamal) [1940926]
- x86/hyperv: allocate output arg pages if required (Mohammed Gamal) [1940926]
- drivers: hv: Fix whitespace errors (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: skip VMBus initialization if Linux is root (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Enforce 'VMBus version >= 5.2' on isolated guests (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Restrict vmbus_devices on isolated guests (Mohammed Gamal) [1940926]
- hv_utils: Fix spelling mistake "Hearbeat" -> "Heartbeat" (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Add /sys/bus/vmbus/hibernation (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Resolve race condition in vmbus_onoffer_rescind() (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Avoid use-after-free in vmbus_onoffer_rescind() (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Copy the hv_message in vmbus_on_msg_dpc() (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Reduce number of references to message in vmbus_on_msg_dpc() (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Initialize memory to be sent to the host (Mohammed Gamal) [1940926]
- hv_utils: Add validation for untrusted Hyper-V values (Mohammed Gamal) [1940926]
- drivers/hv: remove obsolete TODO and fix misleading typo in comment (Mohammed Gamal) [1940926]
- drivers: hv: vmbus: Fix checkpatch SPLIT_STRING (Mohammed Gamal) [1940926]
- drivers: hv: vmbus: Fix call msleep using < 20ms (Mohammed Gamal) [1940926]
- drivers: hv: vmbus: Fix checkpatch LINE_SPACING (Mohammed Gamal) [1940926]
- drivers: hv: vmbus: Replace symbolic permissions by octal permissions (Mohammed Gamal) [1940926]
- drivers: hv: Fix hyperv_record_panic_msg path on comment (Mohammed Gamal) [1940926]
- Drivers: hv: vmbus: Add vmbus_requestor data structure for VMBus hardening (Mohammed Gamal) [1940926]
- ena: revert removal of MODULE_VERSION from ena (Petr Oros) [1955712]
- Revert "[netdrv] net/intel: remove driver versions from Intel drivers" (Jonathan Toppins) [1955745]
- Revert "[netdrv] net/broadcom: Clean broadcom code from driver versions" (Jonathan Toppins) [1955721]
- net: core: add dev_get_tstats64 as a ndo_get_stats64 implementation (Josef Oskera) [1939453]

* Mon May 10 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.4.el8]
- igb: amend removal of MODULE_VERSION (Corinna Vinschen) [1955748]
- igc: amend removal of MODULE_VERSION (Corinna Vinschen) [1955755]
- i40e: amend removal of MODULE_VERSION (Stefan Assmann) [1955736]
- ixgbe: Amend commit acf03026ec5a to include a version string in module info. (Ken Cox) [1955759]
- i40e: Fix parameters in aq_get_phy_register() (Stefan Assmann) [1907852]
- initramfs: panic with memory information (Coiby Xu) [1936031]
- powercap/intel_rapl: add support for AlderLake (David Arcari) [1838605]
- xfs: restore shutdown check in mapped write fault path (Brian Foster) [1926089]
- xfs: consider shutdown in bmapbt cursor delete assert (Brian Foster) [1926077]
- iomap: Fix negative assignment to unsigned sis->pages in iomap_swapfile_activate (Carlos Maiolino) [1938210]
- scsi: scsi_dh_alua: Remove check for ASC 24h in alua_rtpg() (Ewan D. Milne) [1929878]
- perf/arm-cmn: Move IRQs when migrating context (Jeremy Linton) [1816850]
- perf/arm-cmn: Fix PMU instance naming (Jeremy Linton) [1816850]
- perf: arm-cmn: Fix conversion specifiers for node type (Jeremy Linton) [1816850]
- perf: arm-cmn: Fix unsigned comparison to less than zero (Jeremy Linton) [1816850]
- perf: Add Arm CMN-600 PMU driver (Jeremy Linton) [1816850]
- redhat/configs: Use CONFIG_VIRTIO_CONSOLE=m on s390x, too (Thomas Huth) [1954119]
- s390/config: do not select VIRTIO_CONSOLE via Kconfig (Thomas Huth) [1954119]
- x86/platform/uv: Fix an error code in uv_hubs_init() (Frank Ramsay) [1936605]
- x86/platform/uv: Add more to secondary CPU kdump info (Frank Ramsay) [1936605]
- x86/platform/uv: Use x2apic enabled bit as set by BIOS to indicate APIC mode (Frank Ramsay) [1936605]
- redhat/configs: Add CONFIG_UV_SYSFS (Frank Ramsay) [1936605]
- x86/platform/uv: Fix indentation warning in Documentation/ABI/testing/sysfs-firmware-sgi_uv (Frank Ramsay) [1936605]
- x86/platform/uv: Set section block size for hubless architectures (Frank Ramsay) [1936605]
- x86/platform/uv: Update sysfs documentation (Frank Ramsay) [1936605]
- x86/platform/uv: Add deprecated messages to /proc info leaves (Frank Ramsay) [1936605]
- x86/platform/uv: Add sysfs hubless leaves (Frank Ramsay) [1936605]
- x86/platform/uv: Add sysfs leaves to replace those in procfs (Frank Ramsay) [1936605]
- x86/platform/uv: Add kernel interfaces for obtaining system info (Frank Ramsay) [1936605]
- x86/platform/uv: Update MAINTAINERS for uv_sysfs driver (Frank Ramsay) [1936605]
- x86/platform/uv: Update ABI documentation of /sys/firmware/sgi_uv/ (Frank Ramsay) [1936605]
- x86/platform/uv: Add new uv_sysfs platform driver (Frank Ramsay) [1936605]
- x86/platform/uv: Add and export uv_bios_* functions (Frank Ramsay) [1936605]
- x86/platform/uv: Remove existing /sys/firmware/sgi_uv/interface (Frank Ramsay) [1936605]
- x86/platform/uv: Unexport symbols only used by x2apic_uv_x.c (Frank Ramsay) [1936605]
- x86/platform/uv: Unexport sn_coherency_id (Frank Ramsay) [1936605]
- x86/platform/uv: Mark uv_bios_call() and uv_bios_call_irqsave() static (Frank Ramsay) [1936605]
- UV: Add SPDX license identifier - Makefile/Kconfig (Frank Ramsay) [1936605]
- netdevsim: Only use sampling truncation length when valid (Ivan Vecera) [1955163]
- selftests: netdevsim: Test psample functionality (Ivan Vecera) [1955163]
- netdevsim: Add dummy psample implementation (Ivan Vecera) [1955163]
- psample: Add additional metadata attributes (Ivan Vecera) [1955163]
- psample: Encapsulate packet metadata in a struct (Ivan Vecera) [1955163]
- net: psample: fix build error when CONFIG_INET is not enabled (Ivan Vecera) [1955163]
- devlink: include <linux/const.h> for _BITUL (Petr Oros) [1935630]
- netdevsim: add support for flash_update overwrite mask (Petr Oros) [1935630]
- devlink: introduce flash update overwrite mask (Petr Oros) [1935630]
- devlink: convert flash_update to use params structure (Petr Oros) [1935630]
- devlink: check flash_update parameter support in net core (Petr Oros) [1935630]
- devlink: Enhance policy to validate port type input value (Petr Oros) [1935630]
- devlink: Enhance policy to validate eswitch mode value (Petr Oros) [1935630]
- net: devlink: region: Pass the region ops to the snapshot function (Petr Oros) [1935630]
- net: devlink: regions: Add a priv member to the regions ops struct (Petr Oros) [1935630]

* Thu May 06 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.3.el8]
- Enumerate AVX Vector Neural Network instructions (Steve Best) [1838616]
- net: fix skb use after free in netpoll (Ivan Vecera) [1913481]
- cipso,calipso: resolve a number of problems with the DOI refcounts (Guillaume Nault) [1950996]
- netfilter: rpfilter: mask ecn bits before fib lookup (Guillaume Nault) [1950996]
- netfilter: Fix rpfilter dropping vrf packets by mistake (Guillaume Nault) [1950996]
- redhat: enable CONFIG_DM_MULTIPATH_HST and CONFIG_DM_MULTIPATH_IOA (Mike Snitzer) [1949682]
- dm ioctl: fix out of bounds array access when no devices (Mike Snitzer) [1949682]
- dm table: Fix zoned model check and zone sectors check (Mike Snitzer) [1949682]
- dm: simplify target code conditional on CONFIG_BLK_DEV_ZONED (Mike Snitzer) [1949682]
- dm verity: fix DM_VERITY_OPTS_MAX value (Mike Snitzer) [1949682]
- dm verity fec: fix misaligned RS roots IO (Mike Snitzer) [1949682]
- dm verity: fix FEC for RS roots unaligned to block size (Mike Snitzer) [1949682]
- dm bufio: subtract the number of initial sectors in dm_bufio_get_device_size (Mike Snitzer) [1949682]
- dm: fix deadlock when swapping to encrypted device (Mike Snitzer) [1949682]
- dm era: only resize metadata in preresume (Mike Snitzer) [1949682]
- dm era: Use correct value size in equality function of writeset tree (Mike Snitzer) [1949682]
- dm era: Fix bitset memory leaks (Mike Snitzer) [1949682]
- dm era: Verify the data block size hasn't changed (Mike Snitzer) [1949682]
- dm era: Reinitialize bitset cache before digesting a new writeset (Mike Snitzer) [1949682]
- dm era: Update in-core bitset after committing the metadata (Mike Snitzer) [1949682]
- dm era: Recover committed writeset after crash (Mike Snitzer) [1949682]
- dm writecache: fix writing beyond end of underlying device when shrinking (Mike Snitzer) [1949682]
- dm table: remove needless request_queue NULL pointer checks (Mike Snitzer) [1949682]
- dm table: fix zoned iterate_devices based device capability checks (Mike Snitzer) [1949682]
- dm writecache: return the exact table values that were set (Mike Snitzer) [1949682]
- dm writecache: fix unnecessary NULL check warnings (Mike Snitzer) [1949682]
- dm writecache: fix performance degradation in ssd mode (Mike Snitzer) [1949682]
- dm integrity: introduce the "fix_hmac" argument (Mike Snitzer) [1949682]
- dm persistent data: fix return type of shadow_root() (Mike Snitzer) [1949682]
- dm: cleanup of front padding calculation (Mike Snitzer) [1949682]
- dm integrity: fix spelling mistake "flusing" -> "flushing" (Mike Snitzer) [1949682]
- dm crypt: Spelling s_cihper_cipher_ (Mike Snitzer) [1949682]
- dm: avoid filesystem lookup in dm_get_dev_t() (Mike Snitzer) [1949682]
- dm integrity: conditionally disable "recalculate" feature (Mike Snitzer) [1949682]
- dm integrity: fix a crash if "recalculate" used without "internal_hash" (Mike Snitzer) [1949682]
- dm integrity: fix the maximum number of arguments (Mike Snitzer) [1949682]
- dm integrity: fix flush with external metadata device (Mike Snitzer) [1949682]
- dm snapshot: flush merged data before committing metadata (Mike Snitzer) [1949682]
- dm zoned: select CONFIG_CRC32 (Mike Snitzer) [1949682]
- dm integrity: select CRYPTO_SKCIPHER (Mike Snitzer) [1949682]
- dm cache: simplify the return expression of load_mapping() (Mike Snitzer) [1949682]
- dm verity: skip verity work if I_O error when system is shutting down (Mike Snitzer) [1949682]
- dm ioctl: fix error return code in target_message (Mike Snitzer) [1949682]
- dm crypt: Constify static crypt_iv_operations (Mike Snitzer) [1949682]
- dm: add support for REQ_NOWAIT to various targets (Mike Snitzer) [1949682]
- dm: rename multipath path selector source files to have "dm-ps" prefix (Mike Snitzer) [1949682]
- dm mpath: add IO affinity path selector (Mike Snitzer) [1949682]
- dm verity: Add support for signature verification with 2nd keyring (Mike Snitzer) [1949682]
- dm: remove unnecessary current->bio_list check when submitting split bio (Mike Snitzer) [1949682]
- dm: remove invalid sparse __acquires and __releases annotations (Mike Snitzer) [1949682]
- dm: fix double RCU unlock in dm_dax_zero_page_range() error path (Mike Snitzer) [1949682]
- dm writecache: remove BUG() and fail gracefully instead (Mike Snitzer) [1949682]
- dm table: Remove BUG_ON(in_interrupt()) (Mike Snitzer) [1949682]
- dm: fix bug with RCU locking in dm_blk_report_zones (Mike Snitzer) [1949682]
- Revert "dm cache: fix arm link errors with inline" (Mike Snitzer) [1949682]
- vfs: remove lockdep bogosity in __sb_start_write (Brian Foster) [1926097]
- nbd: freeze the queue while we're adding connections (Ming Lei) [1927246]
- selftests/livepatch: Do not check order when using "comm" for dmesg checking (Joel Savitz) [1942056]
- RDMA/siw,rxe: Make emulated devices virtual in the device tree (Kamal Heib) [1931849]
- RDMA/core: remove use of dma_virt_ops (Kamal Heib) [1931849]
- RDMA/umem: Use ib_dma_max_seg_size instead of dma_get_max_seg_size (Kamal Heib) [1931849]
- RDMA/core: Fix ib_dma_max_seg_size() (Kamal Heib) [1931849]
- RDMA/umem: Move to allocate SG table from pages (Kamal Heib) [1931849]
- lib/scatterlist: Do not limit max_segment to PAGE_ALIGNED values (Kamal Heib) [1931849]
- lib/scatterlist: Add support in dynamic allocation of SG table from pages (Kamal Heib) [1931846]
- RDMA/srp: Increase max_segment_size (Kamal Heib) [1931849]
- RDMA/uverbs: Allow drivers to create a new HW object during rereg_mr (Kamal Heib) [1931849]
- RDMA/mlx5: Use ib_umem_find_best_pgoff() for SRQ (Kamal Heib) [1931849]
- RDMA/vmw_pvrdma: Fix network_hdr_type reported in WC (Kamal Heib) [1931849]
- RDMA/cma: Fix error flow in default_roce_mode_store (Kamal Heib) [1931849]
- RDMA/umem: Avoid undefined behavior of rounddown_pow_of_two() (Kamal Heib) [1931849]
- RDMA/restrack: Don't treat as an error allocation ID wrapping (Kamal Heib) [1931849]
- RDMA/ucma: Do not miss ctx destruction steps in some cases (Kamal Heib) [1931849]
- RDMA/cma: Don't overwrite sgid_attr after device is released (Kamal Heib) [1931849]
- RDMA/rxe: Use acquire/release for memory ordering (Kamal Heib) [1931849]
- RDMA/uverbs: Fix incorrect variable type (Kamal Heib) [1931849]
- RDMA/core: Update kernel documentation for ib_create_named_qp() (Kamal Heib) [1931849]
- RDMA/iser: Remove in_interrupt() usage (Kamal Heib) [1931849]
- IB: Fix kernel-doc markups (Kamal Heib) [1931849]
- RDMA/uverbs: Check ODP in ib_check_mr_access() as well (Kamal Heib) [1931849]
- RDMA/uverbs: Tidy input validation of ib_uverbs_rereg_mr() (Kamal Heib) [1931849]
- RDMA/efa: Use dma_set_mask_and_coherent() to simplify code (Kamal Heib) [1931849]
- RDMA/restrack: Support all QP types (Kamal Heib) [1931849]
- RDMA/core: Allow drivers to disable restrack DB (Kamal Heib) [1931849]
- RDMA/core: Track device memory MRs (Kamal Heib) [1931849]
- RDMA/cma: Fix deadlock on &lock in rdma_cma_listen_on_all() error unwind (Kamal Heib) [1931849]
- IB/hfi1: Fix fall-through warnings for Clang (Kamal Heib) [1931849]
- RDMA/ipoib: Distribute cq completion vector better (Kamal Heib) [1931849]
- RDMA/efa: Remove .create_ah callback assignment (Kamal Heib) [1931849]
- RDMA/cma: Add missing error handling of listen_id (Kamal Heib) [1931849]
- RDMA/restrack: Store all special QPs in restrack DB (Kamal Heib) [1931849]
- RDMA/counter: Combine allocation and bind logic (Kamal Heib) [1931849]
- RDMA/core: Remove ib_dma_{alloc,free}_coherent (Kamal Heib) [1931849]
- RDMA/core: Make FD destroy callback void (Kamal Heib) [1931849]
- RDMA/core: Postpone uobject cleanup on failure till FD close (Kamal Heib) [1931849]
- IB/isert: Do not excplicitly check == false for bool (Kamal Heib) [1931849]
- IB/core: Add support for NDR link speed (Kamal Heib) [1931849]
- RDMA/ipoib: Add 50Gb and 100Gb link speeds to ethtool (Kamal Heib) [1931849]
- RDMA/rxe,siw: Restore uverbs_cmd_mask IB_USER_VERBS_CMD_POST_SEND (Kamal Heib) [1931849]
- RDMA/siw: Fix typo of EAGAIN not -EAGAIN in siw_cm_work_handler() (Kamal Heib) [1931849]
- RDMA/rxe: Compute PSN windows correctly (Kamal Heib) [1931849]
- RDMA/core: Fix error return in _ib_modify_qp() (Kamal Heib) [1931849]
- IB/verbs: avoid nested container_of() (Kamal Heib) [1931849]
- RDMA/rxe: Remove unused RXE_MR_TYPE_FMR (Kamal Heib) [1931849]
- RDMA: Remove AH from uverbs_cmd_mask (Kamal Heib) [1931849]
- RDMA: Remove uverbs cmds from drivers that don't use them (Kamal Heib) [1931849]
- RDMA/core Remove uverbs_ex_cmd_mask (Kamal Heib) [1931849]
- RDMA: Check create_flags during create_qp (Kamal Heib) [1931849]
- RDMA: Check flags during create_cq (Kamal Heib) [1931849]
- RDMA: Check attr_mask during modify_qp (Kamal Heib) [1931849]
- RDMA: Check srq_type during create_srq (Kamal Heib) [1931849]
- RDMA: Move more uverbs_cmd_mask settings to the core (Kamal Heib) [1931849]
- RDMA: Remove elements in uverbs_cmd_mask that all drivers set (Kamal Heib) [1931849]
- RDMA: Remove uverbs_ex_cmd_mask values that are linked to functions (Kamal Heib) [1931849]
- RDMA/cm: Fix an attempt to use non-valid pointer when cleaning timewait (Kamal Heib) [1931846]
- RDMA/core: Fix empty gid table for non IB/RoCE devices (Kamal Heib) [1931846]
- RDMA/efa: Use the correct current and new states in modify QP (Kamal Heib) [1931846]
- RMDA/sw: Don't allow drivers using dma_virt_ops on highmem configs (Kamal Heib) [1931846]
- RDMA/srpt: Fix typo in srpt_unregister_mad_agent docstring (Kamal Heib) [1931846]
- RDMA/vmw_pvrdma: Fix the active_speed and phys_state value (Kamal Heib) [1931846]
- RDMA: Fix software RDMA drivers for dma mapping error (Kamal Heib) [1931846]
- IB/srpt: docs: add a description for cq_size member (Kamal Heib) [1931846]
- RDMA: Add rdma_connect_locked() (Kamal Heib) [1931846]
- RDMA/uverbs: Fix false error in query gid IOCTL (Kamal Heib) [1931846]
- RDMA/rxe: Fix small problem in network_type patch (Kamal Heib) [1931846]
- RDMA/ucma: Fix use after free in destroy id flow (Kamal Heib) [1931846]
- RDMA/rxe: Move the definitions for rxe_av.network_type to uAPI (Kamal Heib) [1931846]
- RDMA: Explicitly pass in the dma_device to ib_register_device (Kamal Heib) [1931846]
- RDMA/usnic: Remove the query_pkey callback (Kamal Heib) [1931846]
- RDMA/usnic: Fix spelling mistake "transistion" -> "transition" (Kamal Heib) [1931846]
- RDMA/usnic: switch from 'pci_' to 'dma_' API (Kamal Heib) [1931846]
- RDMA/usnic: Avoid overly large buffers on stack (Kamal Heib) [1931846]
- IB/usnic: Use dev_get_drvdata (Kamal Heib) [1931846]
- IB/usnic: Fix deadlock (Kamal Heib) [1931846]
- Revert "[infiniband] usnic_verbs: fix deadlock" (Kamal Heib) [1931846]
- RDMA/rxe: Remove duplicate entries in struct rxe_mr (Kamal Heib) [1931846]
- RDMA/uverbs: Expose the new GID query API to user space (Kamal Heib) [1931846]
- RDMA/core: Introduce new GID table query API (Kamal Heib) [1931846]
- RDMA/core: Modify enum ib_gid_type and enum rdma_network_type (Kamal Heib) [1931846]
- RDMA/core: Change rdma_get_gid_attr returned error code (Kamal Heib) [1931846]
- RDMA/core: Constify struct attribute_group (Kamal Heib) [1931846]
- RDMA/core: Remove ucontext->closing (Kamal Heib) [1931846]
- RDMA/drivers: Remove udata check from special QP (Kamal Heib) [1931846]
- RDMA/qedr: Add support for user mode XRC-SRQ's (Kamal Heib) [1931846]
- RDMA/mlx4: Prepare QP allocation to remove from the driver (Kamal Heib) [1931846]
- RDMA/mlx4: Embed GSI QP into general mlx4_ib QP (Kamal Heib) [1931846]
- RDMA/core: Align write and ioctl checks of QP types (Kamal Heib) [1931846]
- RDMA/efa: Drop double zeroing for sg_init_table() (Kamal Heib) [1931846]
- RDMA/efa: Add messages and RDMA read work requests HW stats (Kamal Heib) [1931846]
- RDMA/efa: Group keep alive received counter with other SW stats (Kamal Heib) [1931846]
- RDMA/restrack: Improve readability in task name management (Kamal Heib) [1931846]
- RDMA/restrack: Simplify restrack tracking in kernel flows (Kamal Heib) [1931846]
- RDMA/restrack: Count references to the verbs objects (Kamal Heib) [1931846]
- RDMA/cma: Delete from restrack DB after successful destroy (Kamal Heib) [1931846]
- RDMA/ucma: Rework ucma_migrate_id() to avoid races with destroy (Kamal Heib) [1931846]
- RDMA: Fix link active_speed size (Kamal Heib) [1931846]
- net/mlx5: Refactor query port speed functions (Kamal Heib) [1931846]
- RDMA: Convert RWQ table logic to ib_core allocation scheme (Kamal Heib) [1931846]
- RDMA: Clean MW allocation and free flows (Kamal Heib) [1931846]
- RDMA/cma: Fix use after free race in roce multicast join (Kamal Heib) [1931846]
- RDMA/cma: Consolidate the destruction of a cma_multicast in one place (Kamal Heib) [1931846]
- RDMA/cma: Remove dead code for kernel rdmacm multicast (Kamal Heib) [1931846]
- RDMA/cma: Combine cma_ndev_work with cma_work (Kamal Heib) [1931846]
- RDMA/cma: Remove cma_comp() (Kamal Heib) [1931846]
- RDMA/cma: Fix locking for the RDMA_CM_LISTEN state (Kamal Heib) [1931846]
- RDMA/cma: Make the locking for automatic state transition more clear (Kamal Heib) [1931846]
- RDMA/cma: Fix locking for the RDMA_CM_CONNECT state (Kamal Heib) [1931846]
- RDMA/core: Added missing WR and WC opcodes (Kamal Heib) [1931846]
- RDMA/qedr: Remove fbo and zbva from the MR (Kamal Heib) [1931846]
- RDMA/mlx4: Use ib_umem_num_dma_blocks() (Kamal Heib) [1931846]
- RDMA/pvrdma: Use ib_umem_num_dma_blocks() instead of ib_umem_page_count() (Kamal Heib) [1931846]
- RDMA/bnxt: Do not use ib_umem_page_count() or ib_umem_num_pages() (Kamal Heib) [1931846]
- RDMA/qedr: Use ib_umem_num_dma_blocks() instead of ib_umem_page_count() (Kamal Heib) [1931846]
- RDMA/qedr: Use rdma_umem_for_each_dma_block() instead of open-coding (Kamal Heib) [1931846]
- RDMA/i40iw: Use ib_umem_num_dma_pages() (Kamal Heib) [1931846]
- RDMA/efa: Use ib_umem_num_dma_pages() (Kamal Heib) [1931846]
- RDMA/umem: Split ib_umem_num_pages() into ib_umem_num_dma_blocks() (Kamal Heib) [1931846]
- RDMA/umem: Replace for_each_sg_dma_page with rdma_umem_for_each_dma_block (Kamal Heib) [1931846]
- RDMA/umem: Add rdma_umem_for_each_dma_block() (Kamal Heib) [1931846]
- RDMA/umem: Use simpler logic for ib_umem_find_best_pgsz() (Kamal Heib) [1931846]
- RDMA/umem: Fix ib_umem_find_best_pgsz() for mappings that cross a page boundary (Kamal Heib) [1931846]
- RDMA: Make counters destroy symmetrical (Kamal Heib) [1931846]
- RDMA: Restore ability to return error for destroy WQ (Kamal Heib) [1931846]
- RDMA: Change XRCD destroy return value (Kamal Heib) [1931846]
- RDMA: Allow fail of destroy CQ (Kamal Heib) [1931846]
- RDMA/core: Delete function indirection for alloc/free kernel CQ (Kamal Heib) [1931846]
- RDMA: Restore ability to fail on SRQ destroy (Kamal Heib) [1931846]
- RDMA/mlx5: Issue FW command to destroy SRQ on reentry (Kamal Heib) [1931846]
- RDMA: Restore ability to fail on AH destroy (Kamal Heib) [1931846]
- RDMA: Restore ability to fail on PD deallocate (Kamal Heib) [1931846]
- RDMA/core: Change how failing destroy is handled during uobj abort (Kamal Heib) [1931846]
- RDMA/ucma: Fix resource leak on error path (Kamal Heib) [1931846]
- RDMA/rxe: Address an issue with hardened user copy (Kamal Heib) [1931846]
- RDMA/rxe: Add SPDX hdrs to rxe source files (Kamal Heib) [1931846]
- RDMA/core: Trigger a WARN_ON if the driver causes uobjects to become leaked (Kamal Heib) [1931846]
- RDMA/rxe: Fix style warnings (Kamal Heib) [1931846]
- RDMA/ucma: Remove closing and the close_wq (Kamal Heib) [1931846]
- RDMA/ucma: Rework how new connections are passed through event delivery (Kamal Heib) [1931846]
- RDMA/ucma: Narrow file->mut in ucma_event_handler() (Kamal Heib) [1931846]
- RDMA/ucma: Change backlog into an atomic (Kamal Heib) [1931846]
- RDMA/ucma: Add missing locking around rdma_leave_multicast() (Kamal Heib) [1931846]
- RDMA/ucma: Fix locking for ctx->events_reported (Kamal Heib) [1931846]
- RDMA/ucma: Fix the locking of ctx->file (Kamal Heib) [1931846]
- RDMA/ucma: Do not use file->mut to lock destroying (Kamal Heib) [1931846]
- RDMA/cma: Add missing locking to rdma_accept() (Kamal Heib) [1931846]
- RDMA/ucma: Remove mc_list and rely on xarray (Kamal Heib) [1931846]
- RDMA/ucma: Fix error cases around ucma_alloc_ctx() (Kamal Heib) [1931846]
- RDMA/ucma: Consolidate the two destroy flows (Kamal Heib) [1931846]
- RDMA/ucma: Remove unnecessary locking of file->ctx_list in close (Kamal Heib) [1931846]
- RDMA/ucma: Fix refcount 0 incr in ucma_get_ctx() (Kamal Heib) [1931846]
- RDMA/cm: Add tracepoints to track MAD send operations (Kamal Heib) [1931846]
- RDMA/cm: Replace pr_debug() call sites with tracepoints (Kamal Heib) [1931846]
- RDMA/core: Move the rdma_show_ib_cm_event() macro (Kamal Heib) [1931846]
- RDMA/efa: Remove redundant udata check from alloc ucontext response (Kamal Heib) [1931846]
- RDMA/vmw_pvrdma: Fix kernel-doc documentation (Kamal Heib) [1931846]
- RDMA/rxe: prevent rxe creation on top of vlan interface (Kamal Heib) [1931846]
- RDMA/cm: Remove unused cm_class (Kamal Heib) [1931846]
- IB/isert: remove duplicated error prints (Kamal Heib) [1931846]
- RDMA/efa: Introduce SRD RNR retry (Kamal Heib) [1931846]
- RDMA/efa: Introduce SRD QP state machine (Kamal Heib) [1931846]
- RDMA/efa: Be consistent with modify QP bitmask (Kamal Heib) [1931846]
- RDMA/efa: Add a generic capability check helper (Kamal Heib) [1931846]
- RDMA: Remove constant domain argument from flow creation call (Kamal Heib) [1931846]
- RDMA/i40iw: Avoid typecast from void to pci_dev (Kamal Heib) [1931846]
- sched/uclamp: Add CPU's clamp buckets refcounting (Kamal Heib) [1931846]
- overflow: Include header file with SIZE_MAX declaration (Kamal Heib) [1931846]
- treewide: Use fallthrough pseudo-keyword (Kamal Heib) [1931846]
- IB/hfi1: Use fallthrough pseudo-keyword (Kamal Heib) [1931846]
- treewide: replace '---help---' in Kconfig files with 'help' (Kamal Heib) [1931846]
- remove ioremap_nocache and devm_ioremap_nocache (Kamal Heib) [1931846]

* Wed May 05 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.2.el8]
- ethtool: pause: make sure we init driver stats (Ivan Vecera) [1935611]
- ethtool: correct policy for ETHTOOL_MSG_CHANNELS_SET (Ivan Vecera) [1935611]
- ethtool: strset: allow ETHTOOL_A_STRSET_COUNTS_ONLY attr (Ivan Vecera) [1935611]
- ethtool: specify which header flags are supported per command (Ivan Vecera) [1935611]
- ethtool: link up ethnl_header_policy as a nested policy (Ivan Vecera) [1935611]
- ethtool: trim policy tables (Ivan Vecera) [1935611]
- ethtool: wire up set policies to ops (Ivan Vecera) [1935611]
- ethtool: wire up get policies to ops (Ivan Vecera) [1935611]
- netdevsim: fix duplicated debugfs directory (Ivan Vecera) [1935611]
- selftests: add a test for ethtool pause stats (Ivan Vecera) [1935611]
- netdevsim: add pause frame stats (Ivan Vecera) [1935611]
- docs: net: include the new ethtool pause stats in the stats doc (Ivan Vecera) [1935611]
- ethtool: add standard pause stats (Ivan Vecera) [1935611]
- net: tighten the definition of interface statistics (Ivan Vecera) [1935611]

* Fri Apr 30 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-305.1.el8]
- PCI: hv: Fix typo (Mohammed Gamal) [1940924]
- asm-generic/hyperv: change HV_CPU_POWER_MANAGEMENT to HV_CPU_MANAGEMENT (Mohammed Gamal) [1940925]
- x86/hyperv: detect if Linux is the root partition (Mohammed Gamal) [1940925]
- hyperv: hyperv.h: drop a duplicated word (Mohammed Gamal) [1940925]
- hyper-v: Remove internal types from UAPI header (Mohammed Gamal) [1940925]
- x86/hyperv: Load/save the Isolation Configuration leaf (Mohammed Gamal) [1940925]
- x86/hyperv: Initialize clockevents after LAPIC is initialized (Mohammed Gamal) [1940925]
- x86/hyperv: check cpu mask after interrupt has been disabled (Mohammed Gamal) [1940925]
- x86/hyperv: Fix kexec panic/hang issues (Mohammed Gamal) [1940925]
- video: hyperv_fb: Fix a double free in hvfb_probe (Mohammed Gamal) [1940922]
- uio: uio_hv_generic: use devm_kzalloc() for private data alloc (Mohammed Gamal) [1940922]
- Avoid macro redefinition in compiler-{clang,gcc}.h (Jerome Marchand) [1907271]
- x86/split_lock: Add Icelake microserver and Tigerlake CPU models (Prarit Bhargava) [1847576]
- tools/power/x86/intel-speed-select: Update version to 1.8 (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Add new command to get/set TRL (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Add new command turbo-mode (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Set higher of cpuinfo_max_freq or base_frequency (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Set scaling_max_freq to base_frequency (Prarit Bhargava) [1921801]
- platform/x86: ISST: Mark mmio_range_devid_0 and mmio_range_devid_1 with static keyword (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Update version for v5.11 (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Account for missing sysfs for die_id (Prarit Bhargava) [1921801]
- tools/power/x86/intel-speed-select: Read TRL from mailbox (Prarit Bhargava) [1921801]
- platform/x86: ISST: Change PCI device macros (Prarit Bhargava) [1921801]
- platform/x86: ISST: Allow configurable offset range (Prarit Bhargava) [1921801]
- platform/x86: ISST: Check for unaligned mmio address (Prarit Bhargava) [1921801]
- tools/power/turbostat: Fallback to an MSR read for EPB (Prarit Bhargava) [1926913]
- tools/power/turbostat: Read energy_perf_bias from sysfs (Prarit Bhargava) [1926913]
- Bluetooth: btusb: Add workaround for remote-wakeup issues with Barrot 8041a02 fake CSR controllers (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Fix detection of some fake CSR controllers with a bcdDevice val of 0x0134 (Gopal Tiwari) [1946951]
- Bluetooth: btusb: support download nvm with different board id for wcn6855 (Gopal Tiwari) [1946951]
- Bluetooth: btmtksdio: Add the missed release_firmware() in mtk_setup_firmware() (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Add the missed release_firmware() in btusb_mtk_setup_firmware() (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Support 0bda:c123 Realtek 8822CE device (Gopal Tiwari) [1946951]
- Bluetooth: hci_h5: Add OBDA0623 ACPI HID (Gopal Tiwari) [1946951]
- Bluetooth: revert: hci_h5: close serdev device and free hu in h5_close (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Wait for timeout during suspend (Gopal Tiwari) [1946951]
- Bluetooth: btrtl: fix incorrect skb allocation failure check (Gopal Tiwari) [1946951]
- Bluetooth: hci_ll: add a small delay for wl1271 enable bt_en (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Add support for 1358:c123 Realtek 8822CE device (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: resolve various warnings (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Enhance retry logic in qca_setup (Gopal Tiwari) [1946951]
- Bluetooth: btusb: btrtl: Add support for RTL8852A (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Add support for 13d3:3560 MediaTek MT7615E device (Gopal Tiwari) [1946951]
- Bluetooth: hci_h5: fix memory leak in h5_close (Gopal Tiwari) [1946951]
- Bluetooth: btrtl: Ask 8821C to drop old firmware (Gopal Tiwari) [1946951]
- Bluetooth: btrtl: Refine the ic_id_table for clearer and more regular (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Add the more support IDs for Realtek RTL8822CE (Gopal Tiwari) [1946951]
- Bluetooth: hci_h5: close serdev device and free hu in h5_close (Gopal Tiwari) [1946951]
- Bluetooth: btintel: Replace zero-length array with flexible-array member (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Add Qualcomm Bluetooth SoC WCN6855 support (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Enable wide band speech support for BTUSB_QCA_ROME (Gopal Tiwari) [1946951]
- Bluetooth: hci_serdev: Close UART port if NON_PERSISTENT_SETUP is set (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Remove duplicate power off in proto close (Gopal Tiwari) [1946951]
- Bluetooth: hci_intel: enable on new platform (Gopal Tiwari) [1946951]
- Bluetooth: btmtksdio: use NULL instead of zero (Gopal Tiwari) [1946951]
- Bluetooth: hci_intel: switch to list_for_each_entry() (Gopal Tiwari) [1946951]
- Bluetooth: hci_intel: drop strange le16_to_cpu() against u8 values (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: remove redundant null check (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Fix memleak in btusb_mtk_submit_wmt_recv_urb (Gopal Tiwari) [1946951]
- Bluetooth: hci_uart: Cancel init work before unregistering (Gopal Tiwari) [1946951]
- Bluetooth: hci_h5: Remove ignored flag HCI_UART_RESET_ON_INIT (Gopal Tiwari) [1946951]
- Bluetooth: btmrvl: eliminate duplicates introducing btmrvl_reg_89xx (Gopal Tiwari) [1946951]
- Revert "Bluetooth: btusb: Disable runtime suspend on Realtek devices" (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Stop collecting memdump again for command timeout during SSR (Gopal Tiwari) [1946951]
- Bluetooth: hci_serdev: Only unregister device if it was registered (Gopal Tiwari) [1946951]
- Bluetooth: hci_h5: Set HCI_UART_RESET_ON_INIT to correct flags (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Fix and detect most of the Chinese Bluetooth controllers (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Bug fixes for SSR (Gopal Tiwari) [1946951]
- Bluetooth: btusb: add Realtek 8822CE to usb_device_id table (Gopal Tiwari) [1946951]
- Bluetooth: btusb: USB alternate setting 1 for WBS (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Comment on unbalanced pm reference (Gopal Tiwari) [1946951]
- Bluetooth: btusb: BTUSB_WAKEUP_DISABLE prevents wake (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Reset port on cmd timeout (Gopal Tiwari) [1946951]
- Bluetooth: btmtksdio: fix up firmware download sequence (Gopal Tiwari) [1946951]
- Bluetooth: btusb: fix up firmware download sequence (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Disable SoC debug logging for WCN3991 (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Increase SoC idle timeout to 200ms (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Request Tx clock vote off only when Tx is pending (Gopal Tiwari) [1946951]
- Bluetooth: btmrvl_sdio: Refactor irq wakeup (Gopal Tiwari) [1946951]
- Bluetooth: btmrvl_sdio: Implement prevent_wake (Gopal Tiwari) [1946951]
- Bluetooth: btmrvl_sdio: Set parent dev to hdev (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Bug fix during SSR timeout (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Refactor error handling in qca_suspend() (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Skip serdev wait when no transfer is pending (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Only remove TX clock vote after TX is completed (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Simplify determination of serial clock on/off state from votes (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Fix an error pointer dereference (Gopal Tiwari) [1946951]
- btmrvl: Fix firmware filename for sd8977 chipset (Gopal Tiwari) [1946951]
- btmrvl: Fix firmware filename for sd8997 chipset (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Fix QCA6390 memdump failure (Gopal Tiwari) [1946951]
- Bluetooth: btmtkuart: Use serdev_device_write_buf() instead of serdev_device_write() (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Improve controller ID info log level (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Fix qca6390 enable failure after warm reboot (Gopal Tiwari) [1946951]
- Bluetooth: btmtkuart: Improve exception handling in btmtuart_probe() (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Fix suspend/resume functionality failure (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Added 003.006.007, changed 001.003.015 (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: Fix uninitialized access to hdev (Gopal Tiwari) [1946951]
- Bluetooth: serdev: Constify serdev_device_ops (Gopal Tiwari) [1946951]
- Bluetooth: Add hook for driver to prevent wake from suspend (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Implement hdev->prevent_wake (Gopal Tiwari) [1946951]
- Bluetooth: hci_h5: Add support for binding RTL8723BS with device tree (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: allow max-speed to be set for QCA9377 devices (Gopal Tiwari) [1946951]
- Bluetooth: hci_qca: add compatible for QCA9377 (Gopal Tiwari) [1946951]
- Bluetooth: btusb: Adding support for LE scatternet to Jfp and ThP (Gopal Tiwari) [1946951]
- Bluetooth: Adding driver and quirk defs for multi-role LE (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Add 2 missing models to subver tables (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Move setting of USE_BDADDR_PROPERTY quirk to hci_bcm.c (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Try multiple Patch filenames when loading the Patch firmware (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Bail sooner from btbcm_initialize() when not loading fw (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Drop upper nibble version check from btbcm_initialize() (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Make btbcm_setup_patchram use btbcm_finalize (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Make btbcm_initialize() print local-name on re-init too (Gopal Tiwari) [1946951]
- Bluetooth: btbcm: Fold Patch loading + applying into btbcm_initialize() (Gopal Tiwari) [1946951]
- Bluetooth: btrtl: Add support for RTL8761B (Gopal Tiwari) [1946951]
- Bluetooth: btusb: check for NULL in btusb_find_altsetting() (Gopal Tiwari) [1946951]
- Bluetooth: btusb: handle mSBC audio over USB Endpoints (Gopal Tiwari) [1946951]
- Bluetooth: add support to notify using SCO air mode (Gopal Tiwari) [1946951]
- Bluetooth: hci_bcm: respect IRQ polarity from DT (Gopal Tiwari) [1946951]
- Bluetooth: hci_bcm: fix freeing not-requested IRQ (Gopal Tiwari) [1946951]
- intel_idle: remove definition of DEBUG (David Arcari) [1926917]
- intel_idle: Build fix (David Arcari) [1926917]
- cpufreq: ACPI: Set cpuinfo.max_freq directly if max boost is known (Phil Auld) [1937103]
- cpufreq: ACPI: Update arch scale-invariance max perf ratio if CPPC is not there (Phil Auld) [1937103]
- cpufreq: ACPI: Extend frequency tables to cover boost frequencies (Phil Auld) [1937103]
- sched/uclamp: Add CPU's clamp buckets refcounting (Phil Auld) [1937103]
- x86: PM: Register syscore_ops for scale invariance (Phil Auld) [1937103]
- sched/fair: Reduce cases for active balance (Phil Auld) [1937103]
- sched/fair: Don't set LBF_ALL_PINNED unnecessarily (Phil Auld) [1937103]
- sched/fair: Skip idle cfs_rq (Phil Auld) [1937103]
- tick/sched: Make jiffies update quick check more robust (Phil Auld) [1937103]
- sched/fair: Trivial correction of the newidle_balance() comment (Phil Auld) [1937103]
- sched/fair: Clear SMT siblings after determining the core is not idle (Phil Auld) [1937103]
- sched: Fix kernel-doc markup (Phil Auld) [1937103]
- x86: Print ratio freq_max/freq_base used in frequency invariance calculations (Phil Auld) [1937103]
- x86, sched: Use midpoint of max_boost and max_P for frequency invariance on AMD EPYC (Phil Auld) [1937103]
- x86, sched: Calculate frequency invariance for AMD systems (Phil Auld) [1937103]
- sched: Limit the amount of NUMA imbalance that can exist at fork time (Phil Auld) [1937103]
- sched/numa: Allow a floating imbalance between NUMA nodes (Phil Auld) [1937103]
- sched: Avoid unnecessary calculation of load imbalance at clone time (Phil Auld) [1937103]
- sched/numa: Rename nr_running and break out the magic number (Phil Auld) [1937103]
- sched/topology: Condition EAS enablement on FIE support (Phil Auld) [1937103]
- sched/topology: Don't enable EAS on SMT systems (Phil Auld) [1937103]
- sched/topology,schedutil: Wrap sched domains rebuild (Phil Auld) [1937103]
- sched/core: Fix typos in comments (Phil Auld) [1937103]
- sched: Fix rq->nr_iowait ordering (Phil Auld) [1937103]
- sched: Fix data-race in wakeup (Phil Auld) [1937103]
- sched/fair: Fix overutilized update in enqueue_task_fair() (Phil Auld) [1937103]
- sched/fair: Dissociate wakeup decisions from SD flag value (Phil Auld) [1937103]
- sched: Remove select_task_rq()'s sd_flag parameter (Phil Auld) [1937103]
- sched: Add WF_TTWU, WF_EXEC wakeup flags (Phil Auld) [1937103]
- sched/fair: Remove superfluous lock section in do_sched_cfs_slack_timer() (Phil Auld) [1937103]
- sched/fair: Ensure tasks spreading in LLC during LB (Phil Auld) [1937103]
- sched/fair: Reorder throttle_cfs_rq() path (Phil Auld) [1937103]
- sched/fair: Check for idle core in wake_affine (Phil Auld) [1937103]
- sched: Reenable interrupts in do_sched_yield() (Phil Auld) [1937103]
- sched/fair: Improve the accuracy of sched_stat_wait statistics (Phil Auld) [1937103]
- sched/fair: Tweak pick_next_entity() (Phil Auld) [1937103]
- sched/debug: Add new tracepoint to track cpu_capacity (Phil Auld) [1937103]
- sched/fair: Remove the force parameter of update_tg_load_avg() (Phil Auld) [1937103]
- sched/rt: Disable RT_RUNTIME_SHARE by default (Phil Auld) [1937103]
- sched: Cache task_struct::flags in sched_submit_work() (Phil Auld) [1937103]
- sched/fair: Simplify the work when reweighting entity (Phil Auld) [1937103]
- sched/fair: Fix wrong negative conversion in find_energy_efficient_cpu() (Phil Auld) [1937103]
- sched/fair: Ignore cache hotness for SMT migration (Phil Auld) [1937103]
- sched: Use __always_inline on is_idle_task() (Phil Auld) [1937103]
- treewide: Use fallthrough pseudo-keyword (Phil Auld) [1937103]
- sched/debug: Fix the alignment of the show-state debug output (Phil Auld) [1937103]
- x86, sched: Bail out of frequency invariance if turbo_freq/base_freq gives 0 (Phil Auld) [1937103]
- x86, sched: Bail out of frequency invariance if turbo frequency is unknown (Phil Auld) [1937103]
- x86, sched: check for counters overflow in frequency invariant accounting (Phil Auld) [1937103]
- exit: Move preemption fixup up, move blocking operations down (Phil Auld) [1937103]
- net: bonding: remove repeated word (Jarod Wilson) [1936982]
- net: bonding: Correct function name bond_change_active_slave() in comment (Jarod Wilson) [1936982]
- bonding: Added -ENODEV interpret for slaves option (Jarod Wilson) [1936982]
- bonding: 3ad: Print an error for unknown speeds (Jarod Wilson) [1936982]
- bonding: 3ad: add support for 400G speed (Jarod Wilson) [1936982]
- bonding: 3ad: add support for 200G speed (Jarod Wilson) [1936982]
- net/bonding: Declare TLS RX device offload support (Jarod Wilson) [1936982]
- net/bonding: Implement TLS TX device offload (Jarod Wilson) [1936982]
- net/bonding: Take update_features call out of XFRM funciton (Jarod Wilson) [1936982]
- net/bonding: Implement ndo_sk_get_lower_dev (Jarod Wilson) [1936982]
- net/bonding: Take IP hash logic into a helper (Jarod Wilson) [1936982]
- net: bonding: Notify ports about their initial state (Jarod Wilson) [1936982]
- bonding: wait for sysfs kobject destruction before freeing struct slave (Jarod Wilson) [1936982]
- bonding: advertise NETIF_F_GSO_SOFTWARE (Jarod Wilson) [1936982]
- net/tls: Except bond interface from some TLS checks (Jarod Wilson) [1936982]
- net/tls: Device offload to use lowest netdevice in chain (Jarod Wilson) [1936982]
- ethtool: Add common function for filling out strings (Ivan Vecera) [1950987]
- selftests: forwarding: vxlan_bridge_1d: Fix vxlan ecn decapsulate value (Hangbin Liu) [1949349]
- selftests: forwarding: Fix race condition in mirror installation (Hangbin Liu) [1949349]
- selftests: txtimestamp: fix compilation issue (Hangbin Liu) [1949349]
- selftests: net: fib_tests: remove duplicate log test (Hangbin Liu) [1949349]
- selftests: xfrm: fix test return value override issue in xfrm_policy.sh (Hangbin Liu) [1949349]
- selftests: rtnetlink: load fou module for kci_test_encap_fou() test (Hangbin Liu) [1949349]
- vxlan: move debug check after netdev unregister (Guillaume Nault) [1949167]
- net: ip: always refragment ip defragmented packets (Guillaume Nault) [1949167]
- net: fix pmtu check in nopmtudisc mode (Guillaume Nault) [1949167]
- net: udp: make udp_tunnel_nic_info structure extensible (Ivan Vecera) [1948450]
- macvlan: macvlan_count_rx() needs to be aware of preemption (Antoine Tenart) [1950012]
- macvlan: remove redundant null check on data (Antoine Tenart) [1950012]
- net: fix dev_ifsioc_locked() race condition (Antoine Tenart) [1950234]
- ipv6: weaken the v4mapped source check (Hangbin Liu) [1949499]
- ipv6: set multicast flag on the multicast route (Hangbin Liu) [1949499]
- ipv6: create multicast route with RTPROT_KERNEL (Hangbin Liu) [1949499]
- net: ipv6: Validate GSO SKB before finish IPv6 processing (Hangbin Liu) [1949499]
- net: sit: unregister_netdevice on newlink's error path (Hangbin Liu) [1949499]
- net: ip6_gre: fix moving ip6gre between namespaces (Hangbin Liu) [1949499]
- gso: validate gso_type on ipip style tunnels (Hangbin Liu) [1949499]
- net: page_pool: simplify page recycling condition tests (Ivan Vecera) [1935698]
- net: use the new dev_page_is_reusable() instead of private versions (Ivan Vecera) [1935698]
- net: introduce common dev_page_is_reusable() (Ivan Vecera) [1935698]
- skbuff: constify skb_propagate_pfmemalloc() "page" argument (Ivan Vecera) [1935698]
- mm: constify page_is_pfmemalloc() argument (Ivan Vecera) [1935698]
- genetlink: allow dumping command-specific policy (Ivan Vecera) [1938919]
- genetlink: properly support per-op policy dumping (Ivan Vecera) [1938919]
- genetlink: factor skb preparation out of ctrl_dumppolicy() (Ivan Vecera) [1938919]
- netlink: rework policy dump to support multiple policies (Ivan Vecera) [1938919]
- netlink: compare policy more accurately (Ivan Vecera) [1938919]
- genetlink: switch control commands to per-op policies (Ivan Vecera) [1938919]
- genetlink: use parsed attrs in dumppolicy (Ivan Vecera) [1938919]
- taskstats: move specifying netlink policy back to ops (Ivan Vecera) [1938919]
- genetlink: bring back per op policy (Ivan Vecera) [1938919]
- genetlink: use .start callback for dumppolicy (Ivan Vecera) [1938919]
- genetlink: add a structure for dump state (Ivan Vecera) [1938919]
- genetlink: move to smaller ops wherever possible (Ivan Vecera) [1938919]
- genetlink: add small version of ops (Ivan Vecera) [1938919]
- netlink: fix policy dump leak (Ivan Vecera) [1938919]
- genetlink: get rid of family->attrbuf (Ivan Vecera) [1938919]
- genetlink: clean up family attributes allocations (Ivan Vecera) [1938919]
- genetlink: fix memory leaks in genl_family_rcv_msg_dumpit() (Ivan Vecera) [1938919]
- net: genetlink: return the error code when attribute parsing fails. (Ivan Vecera) [1938919]
- genetlink: do not parse attributes for families with zero maxattr (Ivan Vecera) [1938919]
- net: tipc: prepare attrs in __tipc_nl_compat_dumpit() (Ivan Vecera) [1938919]
- net: genetlink: always allocate separate attrs for dumpit ops (Ivan Vecera) [1938919]
- net: genetlink: remove unused genl_family_attrbuf() (Ivan Vecera) [1938919]
- net: tipc: allocate attrs locally instead of using genl_family_attrbuf in compat_dumpit() (Ivan Vecera) [1938919]
- net: tipc: have genetlink code to parse the attrs during dumpit (Ivan Vecera) [1938919]
- net: nfc: have genetlink code to parse the attrs during dumpit (Ivan Vecera) [1938919]
- net: ieee802154: have genetlink code to parse the attrs during dumpit (Ivan Vecera) [1938919]
- net: genetlink: parse attrs and store in contect info struct during dumpit (Ivan Vecera) [1938919]
- net: genetlink: push attrbuf allocation and parsing to a separate function (Ivan Vecera) [1938919]
- net: genetlink: introduce dump info struct to be available during dumpit op (Ivan Vecera) [1938919]
- net: genetlink: push doit/dumpit code from genl_family_rcv_msg (Ivan Vecera) [1938919]
- devlink: Use controller while building phys_port_name (Petr Oros) [1935615]
- devlink: Introduce controller number (Petr Oros) [1935615]
- devlink: Introduce external controller flag (Petr Oros) [1935615]
- devlink: Move structure comments outside of structure (Petr Oros) [1935615]
- devlink: Add comment block for missing port attributes (Petr Oros) [1935615]
- net/mlx5: E-switch, Read controller number from device (Petr Oros) [1935615]
- devlink: don't crash if netdev is NULL (Petr Oros) [1935615]
- vdpa/mlx5: Use write memory barrier after updating CQ index (Jason Wang) [1877270]
- vhost_vdpa: return -EFAULT if copy_to_user() fails (Jason Wang) [1877270]
- vdpa: mlx5: fix vdpa/vhost dependencies (Jason Wang) [1877270]
- vhost-vdpa: fix page pinning leakage in error path (rework) (Jason Wang) [1877270]
- vdpasim: fix "mac_pton" undefined error (Jason Wang) [1877270]
- vdpasim: allow to assign a MAC address (Jason Wang) [1877270]
- vdpasim: fix MAC address configuration (Jason Wang) [1877270]
- vdpa: handle irq bypass register failure case (Jason Wang) [1877270]
- vdpa_sim: Fix DMA mask (Jason Wang) [1877270]
- Revert "vhost-vdpa: fix page pinning leakage in error path" (Jason Wang) [1877270]
- vdpa/mlx5: Fix error return in map_direct_mr() (Jason Wang) [1877270]
- vhost_vdpa: Return -EFAULT if copy_from_user() fails (Jason Wang) [1877270]
- vdpa_sim: implement get_iova_range() (Jason Wang) [1877270]
- vhost: vdpa: report iova range (Jason Wang) [1877270]
- vdpa: introduce config op to get valid iova range (Jason Wang) [1877270]
- vhost_vdpa: remove unnecessary spin_lock in vhost_vring_call (Jason Wang) [1877270]
- vdpa/mlx5: Setup driver only if VIRTIO_CONFIG_S_DRIVER_OK (Jason Wang) [1877270]
- vhost_vdpa: Fix duplicate included kernel.h (Jason Wang) [1877270]
- vdpa/mlx5: Fix failure to bring link up (Jason Wang) [1877270]
- vdpa/mlx5: Make use of a specific 16 bit endianness API (Jason Wang) [1877270]
- vdpa/mlx5: Fix dependency on MLX5_CORE (Jason Wang) [1877270]
- vdpa/mlx5: should keep avail_index despite device status (Jason Wang) [1877270]
- vhost-vdpa: fix page pinning leakage in error path (Jason Wang) [1877270]
- vhost-vdpa: fix vhost_vdpa_map() on error condition (Jason Wang) [1877270]
- vhost vdpa: fix vhost_vdpa_open error handling (Jason Wang) [1877270]
- vhost-vdpa: fix backend feature ioctls (Jason Wang) [1877270]
- vdpa/mlx5: Avoid warnings about shifts on 32-bit platforms (Jason Wang) [1877270]
- vdpa: ifcvf: free config irq in ifcvf_free_irq() (Jason Wang) [1877270]
- vdpa: ifcvf: return err when fail to request config irq (Jason Wang) [1877270]
- vdpa/mlx5: fix up endian-ness for mtu (Jason Wang) [1877270]
- vdpa: Fix pointer math bug in vdpasim_get_config() (Jason Wang) [1877270]
- vdpa/mlx5: Fix pointer math in mlx5_vdpa_get_config() (Jason Wang) [1877270]
- mlx5: vdpa: fix possible uninitialized var (Jason Wang) [1877270]
- vdpa/mlx5: fix memory allocation failure checks (Jason Wang) [1877270]
- vdpa/mlx5: Fix uninitialised variable in core/mr.c (Jason Wang) [1877270]
- vdpa_sim: init iommu lock (Jason Wang) [1877270]
- redhat: enable mlx5e vDPA driver (Jason Wang) [1877270]
- vdpa/mlx5: Add VDPA driver for supported mlx5 devices (Jason Wang) [1877270]
- vdpa/mlx5: Add shared memory registration code (Jason Wang) [1877270]
- vdpa/mlx5: Add support library for mlx5 VDPA implementation (Jason Wang) [1877270]
- vdpa/mlx5: Add hardware descriptive header file (Jason Wang) [1877270]
- vdpa: Modify get_vq_state() to return error code (Jason Wang) [1877270]
- net/vdpa: Use struct for set/get vq state (Jason Wang) [1877270]
- vdpa: remove hard coded virtq num (Jason Wang) [1877270]
- vdpasim: support batch updating (Jason Wang) [1877270]
- vhost-vdpa: support IOTLB batching hints (Jason Wang) [1877270]
- vhost-vdpa: support get/set backend features (Jason Wang) [1877270]
- vhost: generialize backend features setting/getting (Jason Wang) [1877270]
- vhost-vdpa: refine ioctl pre-processing (Jason Wang) [1877270]
- vDPA: dont change vq irq after DRIVER_OK (Jason Wang) [1877270]
- ifcvf: implement vdpa_config_ops.get_vq_irq() (Jason Wang) [1877270]
- vhost_vdpa: implement IRQ offloading in vhost_vdpa (Jason Wang) [1877270]
- vDPA: add get_vq_irq() in vdpa_config_ops (Jason Wang) [1877270]
- vhost: introduce vhost_vring_call (Jason Wang) [1877270]
- vdpasim: protect concurrent access to iommu iotlb (Jason Wang) [1877270]
- vhost: vdpa: remove per device feature whitelist (Jason Wang) [1877270]
- vdpa_sim: fix endian-ness of config space (Jason Wang) [1877270]
- virtio_vdpa: legacy features handling (Jason Wang) [1877270]
- vhost/vdpa: switch to new helpers (Jason Wang) [1877270]
- vdpa: make sure set_features is invoked for legacy (Jason Wang) [1877270]
- vhost_vdpa: Fix potential underflow in vhost_vdpa_mmap() (Jason Wang) [1877270]
- vdpa: fix typos in the comments for __vdpa_alloc_device() (Jason Wang) [1877270]
- ifcvf: implement config interrupt in IFCVF (Jason Wang) [1877270]
- vhost: replace -1 with VHOST_FILE_UNBIND in ioctls (Jason Wang) [1877270]
- vhost_vdpa: Support config interrupt in vdpa (Jason Wang) [1877270]
- ifcvf: ignore continuous setting same status value (Jason Wang) [1877270]
- vdpasim: Fix some coccinelle warnings (Jason Wang) [1877270]
- ifcvf: move IRQ request/free to status change handlers (Jason Wang) [1877270]
- vhost_vdpa: disable doorbell mapping for !MMU (Jason Wang) [1877270]
- vhost_vdpa: support doorbell mapping via mmap (Jason Wang) [1877270]
- vdpa: introduce get_vq_notification method (Jason Wang) [1877270]
- vhost: use mmgrab() instead of mmget() for non worker device (Jason Wang) [1877270]
- vhost: allow device that does not depend on vhost worker (Jason Wang) [1877270]
- vhost: revert "vhost: disable for OABI" (Jason Wang) [1877270]
- vdpasim: remove unused variable 'ret' (Jason Wang) [1877270]
- vhost: remove set but not used variable 'status' (Jason Wang) [1877270]
- vhost: vdpa: remove unnecessary null check (Jason Wang) [1877270]
- virtio/test: fix up after IOTLB changes (Jason Wang) [1877270]
- vhost/test: fix build for vhost test (Jason Wang) [1877270]
- tools/virtio: option to build an out of tree module (Jason Wang) [1877270]
- vhost/test: fix build for vhost test (Jason Wang) [1877270]
- vhost: fix VHOST_GET_BACKEND_FEATURES ioctl request definition (Jason Wang) [1877270]
- perf/x86/intel/uncore: Remove uncore extra PCI dev HSWEP_PCI_PCU_3 (Michael Petlan) [1950388]

* Mon Apr 26 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.7.el8]
- redhat/configs/editconfig: Add support for a bugzilla entry (David Arcari)
- tools/power turbostat: Revert "[tools] tools/power turbostat: Enable accumulate RAPL display" (Prarit Bhargava) [1944699]
- mwifiex: Fix possible buffer overflows in mwifiex_cmd_802_11_ad_hoc_start (Jarod Wilson) [1914996] {CVE-2020-36158}
- net/mlx5e: Allow to match on MPLS parameters only for MPLS over UDP (Alaa Hleihel) [1932839 1936742]
- net/mlx5e: Reject tc rules which redirect from a VF to itself (Alaa Hleihel) [1932839]
- net/mlx5: CT: Add support for matching on ct_state inv and rel flags (Alaa Hleihel) [1932839 1942681]
- net: openvswitch: add log message for error case (Eelco Chaudron) [1937697]
- net: openvswitch: conntrack: simplify the return expression of ovs_ct_limit_get_default_limit() (Eelco Chaudron) [1937697]
- net: openvswitch: Be liberal in tcp conntrack. (Eelco Chaudron) [1937697]
- netfilter: conntrack: tcp: only close if RST matches exact sequence (Eelco Chaudron) [1937697]
- openvswitch: Use IS_ERR instead of IS_ERR_OR_NULL (Eelco Chaudron) [1937697]
- net: openvswitch: Fix kerneldoc warnings (Eelco Chaudron) [1937697]
- net: openvswitch: remove unnecessary ASSERT_OVSL in ovs_vport_del() (Eelco Chaudron) [1937697]
- cifs: revalidate mapping when we open files for SMB1 POSIX (Ronnie Sahlberg) [1933527]
- Revert "vfs: Allow userns root to call mknod on owned filesystems." (Alexey Gladkov) [1902543]
- mfd: intel-lpss: Add Intel Alder Lake PCH-S PCI IDs (David Arcari) [1840244]
- nvme: retrigger ANA log update if group descriptor isn't found (Gopal Tiwari) [1910493]
- locking/qrwlock: Fix ordering in queued_write_lock_slowpath() (Waiman Long) [1950110]
- PCI: switchtec: Add missing __iomem tag to fix sparse warnings (Myron Stowe) [1946645]
- PCI: switchtec: Add missing __iomem and __user tags to fix sparse warnings (Myron Stowe) [1946645]
- PCI: Release IVRS table in AMD ACS quirk (Myron Stowe) [1946645]
- PCI/MSI: Forward MSI-X error code in pci_alloc_irq_vectors_affinity() (Myron Stowe) [1946645]
- PCI: Remove unused pci_lost_interrupt() (Myron Stowe) [1946645]
- PCI: Move PCI_VENDOR_ID_REDHAT definition to pci_ids.h (Myron Stowe) [1946645]
- PCI: Fix error in panic message (Myron Stowe) [1946645]
- PCI: Replace lkml.org, spinics, gmane with lore.kernel.org (Myron Stowe) [1946645]
- PCI: Replace http:// links with https:// (Myron Stowe) [1946645]
- PCI: exynos: Rename Exynos to lowercase (Myron Stowe) [1946645]
- PCI: Align PCIe capability and PCI accessor return values (Myron Stowe) [1946645]
- PCI: Convert PCIe capability PCIBIOS errors to errno (Myron Stowe) [1946645]
- PCI: rpadlpar: Make functions static (Myron Stowe) [1946645]
- PCI: Fix pci_slot_release() NULL pointer dereference (Myron Stowe) [1946645]
- PCI: Fix pci_create_slot() reference count leak (Myron Stowe) [1946645]
- PCI: Announce device after early fixups (Myron Stowe) [1946645]
- PCI: Always enable ACS even if no ACS Capability (Myron Stowe) [1946645]
- PCI: Cache ACS capability offset in device (Myron Stowe) [1946645]
- PCI: Reorder pci_enable_acs() and dependencies (Myron Stowe) [1946645]
- PCI: Add device even if driver attach failed (Myron Stowe) [1946645]
- PCI: Fix pci_cfg_wait queue locking problem (Myron Stowe) [1946645]
- PCI/ASPM: Add missing newline in sysfs 'policy' (Myron Stowe) [1946645]

* Thu Apr 22 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.6.el8]
- gfs2: report "already frozen/thawed" errors (Bob Peterson) [1932236]
- gfs2: move freeze glock outside the make_fs_rw and _ro functions (Bob Peterson) [1932236]
- gfs2: Add common helper for holding and releasing the freeze glock (Bob Peterson) [1932236]
- gfs2: in signal_our_withdraw wait for unfreeze of _this_ fs only (Bob Peterson) [1932236]
- gfs2: Don't freeze the file system during unmount (Bob Peterson) [1932236]
- gfs2: Fix regression in freeze_go_sync (Bob Peterson) [1932236]
- gfs2: The freeze glock should never be frozen (Bob Peterson) [1932236]
- gfs2: When freezing gfs2, use GL_EXACT and not GL_NOCACHE (Bob Peterson) [1932236]
- gfs2: Abort gfs2_freeze if io error is seen (Bob Peterson) [1932236]
- gfs2: read-only mounts should grab the sd_freeze_gl glock (Bob Peterson) [1932236]
- gfs2: freeze should work on read-only mounts (Bob Peterson) [1932236]
- bpf: Mark LSM link with rh_mark_used_feature call (Jiri Olsa) [1901039]
- Revert "[tools] bpf: selftests: remove test_progs LSM test" (Ondrej Mosnacek) [1901039]
- configs: enable BPF LSM (Ondrej Mosnacek) [1901039]
- security: Fix hook iteration and default value for inode_copy_up_xattr (Ondrej Mosnacek) [1901039]
- security: Fix hook iteration for secid_to_secctx (Ondrej Mosnacek) [1901039]
- security: Fix the default value of secid_to_secctx hook (Ondrej Mosnacek) [1901039]
- security: Fix the default value of fs_context_parse_param hook (Ondrej Mosnacek) [1901039]
- bpf: lsm: Initialize the BPF LSM hooks (Ondrej Mosnacek) [1901039]
- security: Refactor declaration of LSM hooks (Ondrej Mosnacek) [1901039]
- LSM: fix documentation for the shm_* hooks (Ondrej Mosnacek) [1901039]
- LSM: fix documentation for the sem_* hooks (Ondrej Mosnacek) [1901039]
- LSM: fix documentation for the msg_queue_* hooks (Ondrej Mosnacek) [1901039]
- LSM: Revive CONFIG_DEFAULT_SECURITY_* for "make oldconfig" (Ondrej Mosnacek) [1901039]
- LSM: Ignore "security=" when "lsm=" is specified (Ondrej Mosnacek) [1901039]
- LSM: Update function documentation for cap_capable (Ondrej Mosnacek) [1901039]
- procfs: add smack subdir to attrs (Ondrej Mosnacek) [1901039]
- capability: Initialize as LSM_ORDER_FIRST (Ondrej Mosnacek) [1901039]
- LSM: Introduce enum lsm_order (Ondrej Mosnacek) [1901039]
- Yama: Initialize as ordered LSM (Ondrej Mosnacek) [1901039]
- LoadPin: Initialize as ordered LSM (Ondrej Mosnacek) [1901039]
- LSM: Split LSM preparation from initialization (Ondrej Mosnacek) [1901039]
- LSM: Add all exclusive LSMs to ordered initialization (Ondrej Mosnacek) [1901039]
- LSM: Separate idea of "major" LSM from "exclusive" LSM (Ondrej Mosnacek) [1901039]
- LSM: Refactor "security=" in terms of enable/disable (Ondrej Mosnacek) [1901039]
- LSM: Prepare for reorganizing "security=" logic (Ondrej Mosnacek) [1901039]
- LSM: Tie enabling logic to presence in ordered list (Ondrej Mosnacek) [1901039]
- LSM: Introduce "lsm=" for boottime LSM selection (Ondrej Mosnacek) [1901039]
- LSM: Introduce CONFIG_LSM (Ondrej Mosnacek) [1901039]
- LSM: Build ordered list of LSMs to initialize (Ondrej Mosnacek) [1901039]
- LSM: Lift LSM selection out of individual LSMs (Ondrej Mosnacek) [1901039]
- LSM: Plumb visibility into optional "enabled" state (Ondrej Mosnacek) [1901039]
- LSM: Provide separate ordered initialization (Ondrej Mosnacek) [1901039]
- LSM: Introduce LSM_FLAG_LEGACY_MAJOR (Ondrej Mosnacek) [1901039]
- LSM: Don't ignore initialization failures (Ondrej Mosnacek) [1901039]
- LSM: Provide init debugging infrastructure (Ondrej Mosnacek) [1901039]
- LSM: Record LSM name in struct lsm_info (Ondrej Mosnacek) [1901039]
- LSM: Convert security_initcall() into DEFINE_LSM() (Ondrej Mosnacek) [1901039]
- vmlinux.lds.h: Move LSM_TABLE into INIT_DATA (Ondrej Mosnacek) [1901039]
- LSM: Convert from initcall to struct lsm_info (Ondrej Mosnacek) [1901039]
- LSM: Remove initcall tracing (Ondrej Mosnacek) [1901039]
- LSM: Rename .security_initcall section to .lsm_info (Ondrej Mosnacek) [1901039]
- vmlinux.lds.h: Avoid copy/paste of security_init section (Ondrej Mosnacek) [1901039]
- LSM: Correctly announce start of LSM initialization (Ondrej Mosnacek) [1901039]
- proc: save 2 atomic ops on write to "/proc/*/attr/*" (Ondrej Mosnacek) [1901039]
- ALSA: usb-audio: fix NULL ptr dereference in usb_audio_probe (Jaroslav Kysela) [1870724]
- ALSA: usb-audio: fix use after free in usb_audio_disconnect (Jaroslav Kysela) [1870724]
- ALSA: usb-audio: Disable USB autosuspend properly in setup_disable_autosuspend() (Jaroslav Kysela) [1870724]
- Bluetooth: btusb: Fix the autosuspend enable and disable (Gopal Tiwari) [1927375]
- flow_dissector: fix TTL and TOS dissection on IPv4 fragments (Davide Caratti) [1882607]
- net: avoid infinite loop in mpls_gso_segment when mpls_hlen == 0 (Balazs Nemeth) [1922898]
- net: check if protocol extracted by virtio_net_hdr_set_proto is correct (Balazs Nemeth) [1922898]
- redhat/configs: Add CONFIG_PINCTRL_ALDERLAKE (David Arcari) [1840250]
- pinctrl: intel: Add Intel Alder Lake-S pin controller support (David Arcari) [1840250]
- cpufreq: intel_pstate: Remove repeated word (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Get per-CPU max freq via MSR_HWP_CAPABILITIES if available (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Rename two functions (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Change intel_pstate_get_hwp_max() argument (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Always read hwp_cap_cached with READ_ONCE() (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: remove obsolete functions (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Use HWP capabilities in intel_cpufreq_adjust_perf() (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Fix fast-switch fallback path (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Use most recent guaranteed performance values (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Implement the ->adjust_perf() callback (Puneet Sethi) [1926919]
- cpufreq: Add special-purpose fast-switching callback for drivers (Puneet Sethi) [1926919]
- cpufreq: schedutil: Add util to struct sg_cpu (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Simplify intel_cpufreq_update_pstate() (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Take CPUFREQ_GOV_STRICT_TARGET into account (Puneet Sethi) [1926919]
- cpufreq: Add strict_target to struct cpufreq_policy (Puneet Sethi) [1926919]
- cpufreq: Introduce CPUFREQ_GOV_STRICT_TARGET (Puneet Sethi) [1926919]
- cpufreq: Introduce governor flags (Puneet Sethi) [1926919]
- cpufreq: schedutil: Don't skip freq update if need_freq_update is set (Puneet Sethi) [1926919]
- cpufreq: schedutil: Always call driver if CPUFREQ_NEED_UPDATE_LIMITS is set (Puneet Sethi) [1926919]
- cpufreq: Introduce cpufreq_driver_test_flags() (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Avoid missing HWP max updates in passive mode (Puneet Sethi) [1926919]
- cpufreq: schedutil: restore cached freq when next_f is not changed (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Delete intel_pstate sysfs if failed to register the driver (Puneet Sethi) [1926919]
- cpufreq: intel_pstate: Fix missing return statement (Puneet Sethi) [1926919]
- cpufreq: Introduce CPUFREQ_NEED_UPDATE_LIMITS driver flag (Puneet Sethi) [1926919]
- ACPI: processor: Fix build when CONFIG_ACPI_PROCESSOR=m (Vitaly Kuznetsov) [1929266]
- ACPI: processor: Fix CPU0 wakeup in acpi_idle_play_dead() (Vitaly Kuznetsov) [1929266]
- x86/ioapic: Ignore IRQ2 again (Vitaly Kuznetsov) [1929266]

* Mon Apr 19 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.5.el8]
- selinux: fix deadlock in security_set_bools() (Ondrej Mosnacek) [1924230]
- sctp: move sk_route_caps check and set into sctp_outq_flush_transports (Xin Long) [1946733]
- sctp: bring inet(6)_skb_parm back to sctp_input_cb (Xin Long) [1946733]
- sctp: enable udp tunneling socks (Xin Long) [1946733]
- sctp: handle the init chunk matching an existing asoc (Xin Long) [1946733]
- sctp: add the error cause for new encapsulation port restart (Xin Long) [1946733]
- sctp: support for sending packet over udp6 sock (Xin Long) [1946733]
- sctp: support for sending packet over udp4 sock (Xin Long) [1946733]
- sctp: call sk_setup_caps in sctp_packet_transmit instead (Xin Long) [1946733]
- sctp: add udphdr to overhead when udp_port is set (Xin Long) [1946733]
- sctp: allow changing transport encap_port by peer packets (Xin Long) [1946733]
- sctp: add SCTP_REMOTE_UDP_ENCAPS_PORT sockopt (Xin Long) [1946733]
- sctp: add encap_port for netns sock asoc and transport (Xin Long) [1946733]
- sctp: add encap_err_lookup for udp encap socks (Xin Long) [1946733]
- sctp: create udp6 sock and set its encap_rcv (Xin Long) [1946733]
- sctp: create udp4 sock and add its encap_rcv (Xin Long) [1946733]
- udp: support sctp over udp in skb_udp_tunnel_segment (Xin Long) [1946733]
- udp6: move the mss check after udp gso tunnel processing (Xin Long) [1946733]
- udp: check udp sock encap_type in __udp_lib_err (Xin Long) [1946733]
- sctp: copy the optval from user space in sctp_setsockopt (Xin Long) [1946733]
- net: Convert protocol error handlers from void to int (Xin Long) [1946733]
- Enable CONFIG_ENERGY_MODEL (Phil Auld) [1938339]
- proc/sysctl: add shared variables for range check (Phil Auld) [1938339]
- Enable CONFIG_CPU_FREQ_GOV_SCHEDUTIL for all architectures (Phil Auld) [1938339]
- PM / hibernate: cast PAGE_SIZE to int when comparing with error code (Chris von Recklinghausen) [1934033]
- mm: revert fix false-positive OVERCOMMIT_GUESS failures (Rafael Aquini) [1913045 1908668]
- redhat/config: Enable CONFIG_PAGE_POISONING (Waiman Long) [1942149]
- mm, page_poison: remove CONFIG_PAGE_POISONING_ZERO (Waiman Long) [1942149]
- mm, page_poison: remove CONFIG_PAGE_POISONING_NO_SANITY (Waiman Long) [1942149]
- kernel/power: allow hibernation with page_poison sanity checking (Waiman Long) [1942149]
- mm, page_poison: use static key more efficiently (Waiman Long) [1942149]
- mm, page_alloc: do not rely on the order of page_poison and init_on_alloc/free parameters (Waiman Long) [1942149]
- mm/page_alloc: clear all pages in post_alloc_hook() with init_on_alloc=1 (Waiman Long) [1942149]
- arch, mm: make kernel_page_present() always available (Waiman Long) [1942149]
- arch, mm: restore dependency of __kernel_map_pages() on DEBUG_PAGEALLOC (Waiman Long) [1942149]
- PM: hibernate: make direct map manipulations more explicit (Waiman Long) [1942149]
- mm: introduce debug_pagealloc_{map,unmap}_pages() helpers (Waiman Long) [1942149]
- mm: rename page_order() to buddy_order() (Waiman Long) [1942149]
- mm/page_alloc: place pages to tail in __free_pages_core() (Waiman Long) [1942149]
- mm/page_alloc: move pages to tail in move_to_free_list() (Waiman Long) [1942149]
- mm/page_alloc: place pages to tail in __putback_isolated_page() (Waiman Long) [1942149]
- mm/page_alloc: convert "report" flag of __free_one_page() to a proper flag (Waiman Long) [1942149]
- mm/page_alloc: drop stale pageblock comment in memmap_init_zone*() (Waiman Long) [1942149]
- mm/memory_hotplug: simplify page onlining (Waiman Long) [1942149]
- mm/page_isolation: simplify return value of start_isolate_page_range() (Waiman Long) [1942149]
- mm/memory_hotplug: drop nr_isolate_pageblock in offline_pages() (Waiman Long) [1942149]
- mm/page_alloc: simplify __offline_isolated_pages() (Waiman Long) [1942149]
- mm/memory_hotplug: simplify page offlining (Waiman Long) [1942149]
- mm/memory_hotplug: enforce section granularity when onlining/offlining (Waiman Long) [1942149]
- mm/memory_hotplug: inline __offline_pages() into offline_pages() (Waiman Long) [1942149]
- mm/page_poison.c: replace bool variable with static key (Waiman Long) [1942149]
- mm/page_alloc.c: fix early params garbage value accesses (Waiman Long) [1942149]
- mm/memory_hotplug: document why shuffle_zone() is relevant (Waiman Long) [1942149]
- mm: replace '---help---' in Kconfig files with 'help' (Waiman Long) [1942149]
- mm/memory_hotplug: fix a typo in comment "recoreded"->"recorded" (Waiman Long) [1942149]
- mm: Allow to offline unmovable PageOffline() pages via MEM_GOING_OFFLINE (Waiman Long) [1942149]
- x86/mm/cpa: Flush direct map alias during cpa (Waiman Long) [1942149]
- mm/page_alloc: simplify page_is_buddy() for better code readability (Waiman Long) [1942149]
- mm/memory.c: add apply_to_existing_page_range() helper (Waiman Long) [1942149]
- x86/mm/pat: Move the memtype related files to arch/x86/mm/pat/ (Waiman Long) [1942149]
- x86/mm/pat: Rename pat_rbtree.c to pat_interval.c (Waiman Long) [1942149]
- mm/memory_hotplug: online_pages cannot be 0 in online_pages() (Waiman Long) [1942149]
- mm/memory_hotplug: make sure the pfn is aligned to the order when onlining (Waiman Long) [1942149]
- mm/memory_hotplug: simplify online_pages_range() (Waiman Long) [1942149]
- mm/memory_hotplug: drop PageReserved() check in online_pages_range() (Waiman Long) [1942149]
- mm/memory_hotplug.c: use PFN_UP / PFN_DOWN in walk_system_ram_range() (Waiman Long) [1942149]
- mm/page_poison.c: fix a typo in a comment (Waiman Long) [1942149]
- mm/slab: Remove store_stackinfo() (Waiman Long) [1942149]
- mm/resource: Let walk_system_ram_range() search child resources (Waiman Long) [1942149]
- mm/page_alloc.c: use a single function to free page (Waiman Long) [1942149]
- mm/page_alloc.c: free order-0 pages through PCP in page_frag_free() (Waiman Long) [1942149]
- x86/mm/cpa: Fix set_mce_nospec() (Waiman Long) [1942149]
- x86/mm/cpa: Rename @addrinarray to @numpages (Waiman Long) [1942149]
- x86/mm/cpa: Better use CLFLUSHOPT (Waiman Long) [1942149]
- x86/mm/cpa: Fold cpa_flush_range() and cpa_flush_array() into a single cpa_flush() function (Waiman Long) [1942149]
- x86/mm/cpa: Make cpa_data::numpages invariant (Waiman Long) [1942149]
- x86/mm/cpa: Optimize cpa_flush_array() TLB invalidation (Waiman Long) [1942149]
- x86/mm/cpa: Simplify the code after making cpa->vaddr invariant (Waiman Long) [1942149]
- x86/mm/cpa: Make cpa_data::vaddr invariant (Waiman Long) [1942149]
- x86/mm/cpa: Add __cpa_addr() helper (Waiman Long) [1942149]
- x86/mm/cpa: Add ARRAY and PAGES_ARRAY selftests (Waiman Long) [1942149]
- resource/docs: Complete kernel-doc style function documentation (Waiman Long) [1942149]
- resource/docs: Fix new kernel-doc warnings (Waiman Long) [1942149]
- resource: Clean it up a bit (Waiman Long) [1942149]
- mm: clarify CONFIG_PAGE_POISONING and usage (Waiman Long) [1942149]
- selftests: kvm: Raise the default timeout to 120 seconds (Emanuele Giuseppe Esposito) [1894828]
- KVM: Raise the maximum number of user memslots (Emanuele Giuseppe Esposito) [1894828]
- block: recalculate segment count for multi-segment discards correctly (Ming Lei) [1922370]
- i40e: Fix VFs not created (Stefan Assmann) [1875338]
- vfs: fix page locking deadlocks when deduping files (Gao Xiang) [1916242]

* Thu Apr 15 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.4.el8]
- tg3: improve PCI VPD access (Jonathan Toppins) [1921456]
- scsi: target: pscsi: Clean up after failure in pscsi_map_sg() (Maurizio Lombardi) [1939458]
- scsi: target: pscsi: Avoid OOM in pscsi_map_sg() (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Fix memory leak caused by wrong uio usage (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Move some functions without code change (Maurizio Lombardi) [1939458]
- scsi: target: core: Prevent underflow for service actions (Maurizio Lombardi) [1939458]
- scsi: target: core: Add cmd length set before cmd complete (Maurizio Lombardi) [1939458]
- scsi: target: sbp: Remove unneeded semicolon (Maurizio Lombardi) [1939458]
- scsi: target: core: Change ASCQ for residual write (Maurizio Lombardi) [1939458]
- scsi: target: core: Signal WRITE residuals (Maurizio Lombardi) [1939458]
- scsi: target: core: Set residuals for 4Kn devices (Maurizio Lombardi) [1939458]
- scsi: target: core: Remove in_interrupt() check in transport_handle_cdb_direct() (Maurizio Lombardi) [1939458]
- scsi: target: core: Replace in_interrupt() usage in target_submit_cmd_map_sgls() (Maurizio Lombardi) [1939458]
- scsi: target: alua: Remove in_interrupt() usage in core_alua_check_nonop_delay() (Maurizio Lombardi) [1939458]
- scsi: target: iscsi: Redo iscsit_check_session_usage_count() return code (Maurizio Lombardi) [1939458]
- scsi: target: iscsi: Avoid in_interrupt() usage in iscsit_check_session_usage_count() (Maurizio Lombardi) [1939458]
- scsi: target: iscsi: Avoid in_interrupt() usage in iscsit_close_session() (Maurizio Lombardi) [1939458]
- scsi: target: iscsi: Fix typo in comment (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Fix use-after-free of se_cmd->priv (Maurizio Lombardi) [1939458]
- scsi: target: core: Fix fall-through warnings for Clang (Maurizio Lombardi) [1939458]
- scsi: tcm_loop: Allow queues, can_queue and cmd_per_lun to be settable (Maurizio Lombardi) [1939458]
- scsi: target: Make state_list per CPU (Maurizio Lombardi) [1939458]
- scsi: target: Drop sess_cmd_lock from I/O path (Maurizio Lombardi) [1939458]
- scsi: target: Remove TARGET_SCF_LOOKUP_LUN_FROM_TAG (Maurizio Lombardi) [1939458]
- scsi: target: Fix cmd_count ref leak (Maurizio Lombardi) [1939458]
- scsi: target: Fix LUN ref count handling (Maurizio Lombardi) [1939458]
- scsi: target: Return COMPARE AND WRITE miscompare offsets (Maurizio Lombardi) [1939458]
- scsi: target: Split out COMPARE AND WRITE memcmp into helper (Maurizio Lombardi) [1939458]
- scsi: target: Rename cmd.bad_sector to cmd.sense_info (Maurizio Lombardi) [1939458]
- scsi: target: Rename struct sense_info to sense_detail (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: scatter_/gather_data_area() rework (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Replace zero-length array with flexible-array member (Maurizio Lombardi) [1939458]
- scsi: target: rd: Drop double zeroing (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Fix warning: 'page' may be used uninitialized (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Optimize scatter_data_area() (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Optimize queue_cmd_ring() (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Join tcmu_cmd_get_data_length() and tcmu_cmd_get_block_cnt() (Maurizio Lombardi) [1939458]
- scsi: target: tcmu: Add missing newline when printing parameters (Maurizio Lombardi) [1939458]
- scsi: target: Remove redundant assignment to variable 'ret' (Maurizio Lombardi) [1939458]
- x86/resctrl: Fix AMD L3 QOS CDP enable/disable (Wei Huang) [1868984]
- i2c: i801: Add support for Intel Alder Lake PCH-S (David Arcari) [1840242]
- esp: delete NETIF_F_SCTP_CRC bit from features for esp offload (Xin Long) [1815560]
- net/sched: act_ct: clear post_ct if doing ct_clear (Marcelo Ricardo Leitner) [1941889]
- net: Change dev parameter to const in netif_device_present() (Josef Oskera) [1941728]
- [x86] x86/mce: Increase maximum number of banks to 64 (Terry Bowman) [1931679]

* Mon Apr 12 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.3.el8]
- scsi: megaraid_sas: Fix a bunch of misnamed functions in their headers (Tomas Henzl) [1924687]
- scsi: megaraid_sas: Replace sdev_busy with local counter (Tomas Henzl) [1924687]
- scsi: megaraid: Fix ifnullfree.cocci warnings (Tomas Henzl) [1924687]
- scsi: megaraid_sas: Fix MEGASAS_IOC_FIRMWARE regression (Tomas Henzl) [1924687]
- Revert "Revert "scsi: megaraid_sas: Added support for shared host tagset for cpuhotplug"" (Tomas Henzl) [1924687]
- Revert "scsi: megaraid_sas: Added support for shared host tagset for cpuhotplug" (Tomas Henzl) [1924687]
- scsi: megaraid_sas: Update function description (Tomas Henzl) [1924687]
- scsi: megaraid_sas: Use generic power management (Tomas Henzl) [1924687]
- megaraid_sas(treewide): Use fallthrough pseudo-keyword (Tomas Henzl) [1924687]
- scsi: megaraid_sas: Drop PCI wakeup calls from .resume (Tomas Henzl) [1924687]
- scsi: megaraid_sas: Check user-provided offsets (Tomas Henzl) [1924687]
- scsi: mpt3sas: Update driver version to 37.101.00.00 (Tomas Henzl) [1922058]
- scsi: mpt3sas: Force reply post array allocations to be within same 4 GB region (Tomas Henzl) [1922058]
- scsi: mpt3sas: Force reply post buffer allocations to be within same 4 GB region (Tomas Henzl) [1922058]
- scsi: mpt3sas: Force reply buffer allocations to be within same 4 GB region (Tomas Henzl) [1922058]
- scsi: mpt3sas: Force sense buffer allocations to be within same 4 GB region (Tomas Henzl) [1922058]
- scsi: mpt3sas: Force chain buffer allocations to be within same 4 GB region (Tomas Henzl) [1922058]
- scsi: mpt3sas: Force PCIe scatterlist allocations to be within same 4 GB region (Tomas Henzl) [1922058]
- scsi: mpt3sas: Replace unnecessary dynamic allocation with a static one (Tomas Henzl) [1922058]
- scsi: mpt3sas: Fix some kernel-doc misnaming issues (Tomas Henzl) [1922058]
- scsi: mpt3sas: Fix a couple of misdocumented functions/params (Tomas Henzl) [1922058]
- scsi: mpt3sas: Fix a bunch of potential naming doc-rot (Tomas Henzl) [1922058]
- scsi: mpt3sas: Move a little data from the stack onto the heap (Tomas Henzl) [1922058]
- scsi: mpt3sas: Fix misspelling of _base_put_smid_default_atomic() (Tomas Henzl) [1922058]
- scsi: mpt3sas: Update driver version to 37.100.00.00 (Tomas Henzl) [1922058]
- scsi: mpt3sas: Additional diagnostic buffer query interface (Tomas Henzl) [1922058]
- scsi: mpt3sas: Add support for shared host tagset for CPU hotplug (Tomas Henzl) [1922058]
- scsi: mpt3sas: Fix ReplyPostFree pool allocation (Tomas Henzl) [1922058]
- scsi: mpt3sas: Simplify bool comparison (Tomas Henzl) [1922058]
- scsi: mpt3sas: Signedness bug in _base_get_diag_triggers() (Tomas Henzl) [1922058]
- scsi: mpt3sas: Update driver version to 36.100.00.00 (Tomas Henzl) [1922058]
- scsi: mpt3sas: Handle trigger page after firmware update (Tomas Henzl) [1922058]
- scsi: mpt3sas: Add persistent MPI trigger page (Tomas Henzl) [1922058]
- scsi: mpt3sas: Add persistent SCSI sense trigger page (Tomas Henzl) [1922058]
- scsi: mpt3sas: Add persistent Event trigger page (Tomas Henzl) [1922058]
- scsi: mpt3sas: Add persistent Master trigger page (Tomas Henzl) [1922058]
- scsi: mpt3sas: Add persistent trigger pages support (Tomas Henzl) [1922058]
- scsi: mpt3sas: Sync time periodically between driver and firmware (Tomas Henzl) [1922058]
- scsi: mpt3sas: Increase IOCInit request timeout to 30s (Tomas Henzl) [1922058]
- scsi: mpt3sas: Fix ioctl timeout (Tomas Henzl) [1922058]
- scsi: mpt3sas: Remove in_interrupt() (Tomas Henzl) [1922058]
- scsi: mpt3sas_scsih: Use generic power management (Tomas Henzl) [1922058]
- scsi: mpt3sas_scsih: Drop PCI Wakeup calls from .resume (Tomas Henzl) [1922058]
- scsi: mpt3sas: mpt3sas_scsih: Fix function documentation formatting (Tomas Henzl) [1922058]
- mpt3sas: Use fallthrough pseudo-keyword (Tomas Henzl) [1922058]
- net: add inline function skb_csum_is_sctp (Josef Oskera) [1939341]
- psample: Fix user API breakage (Ivan Vecera) [1939499]
- net: psample: Fix netlink skb length with tunnel info (Ivan Vecera) [1939499]
- net: psample: Add tunnel support (Ivan Vecera) [1939499]
- net: core: introduce struct netdev_nested_priv for nested interface infrastructure (Ivan Vecera) [1939402]
- net: add function dev_fetch_sw_netstats for fetching pcpu_sw_netstats (Josef Oskera) [1935717]
- net: core: add devm_netdev_alloc_pcpu_stats (Josef Oskera) [1935717]
- net: core: add dev_sw_netstats_tx_add (Josef Oskera) [1935717]
- net: netdevice.h: sw_netstats_rx_add helper (Josef Oskera) [1935717]
- net: netdevice: Add operation ndo_sk_get_lower_dev (Josef Oskera) [1935709]
- genirq: Provide irq_get_effective_affinity() (Josef Oskera) [1935670]

* Thu Apr 08 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.2.el8]
- locking/locktorture: Fix incorrect use of ww_acquire_ctx in ww_mutex test (Waiman Long) [1871851]
- locking/locktorture: Pass thread id to lock/unlock functions (Waiman Long) [1871851]
- locking/ww_mutex: Remove DEFINE_WW_MUTEX() macro (Waiman Long) [1871851]
- locking/locktorture: Fix false positive circular locking splat in ww_mutex test (Waiman Long) [1871851]
- locking/ww_mutex: Fix acquire/release imbalance in ww_acquire_init()/ww_acquire_fini() (Waiman Long) [1871851]
- locking/ww_mutex: Simplify use_ww_ctx & ww_ctx handling (Waiman Long) [1871851]
- locking: Remove duplicate include of percpu-rwsem.h (Waiman Long) [1871851]
- locktorture: Invoke percpu_free_rwsem() to do percpu-rwsem cleanup (Waiman Long) [1871851]
- locktorture: Prevent hangs for invalid arguments (Waiman Long) [1871851]
- locktorture: Ignore nreaders_stress if no readlock support (Waiman Long) [1871851]
- locktorture: Track time of last ->writeunlock() (Waiman Long) [1871851]
- locktorture: Make function torture_percpu_rwsem_init() static (Waiman Long) [1871851]
- sched,locktorture: Convert to sched_set_fifo() (Waiman Long) [1871851]
- locktorture: Use true and false to assign to bool variables (Waiman Long) [1871851]
- locktorture: Print ratio of acquisitions, not failures (Waiman Long) [1871851]
- locktorture: NULL cxt.lwsa and cxt.lrsa to allow bad-arg detection (Waiman Long) [1871851]
- locking/locktorture: Convert to SPDX license identifier (Waiman Long) [1871851]
- tty: Fix ->session locking (Chris von Recklinghausen) [1908059] {CVE-2020-29660}
- net: skbext: fix secpath use-after-free with ip fragmentation (Sabrina Dubroca) [1901454]

* Wed Apr 07 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-304.1.el8]
- nfs: we don't support removing system.nfs4_acl (Scott Mayhew) [1944659]
- redhat/configs: Disable CONFIG_INFINIBAND_HNS* (Kamal Heib) [1941259]
- mm: Revert "remove the account_page_dirtied export" (Waiman Long) [1941257]
- Revert "[netdrv] net/broadcom: Clean broadcom code from driver versions" (Jonathan Toppins) [1940842]

* Thu Apr 01 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-303.1.el8]
- geneve: do not modify the shared tunnel info when PMTU triggers an ICMP reply (Antoine Tenart) [1941753]
- vxlan: do not modify the shared tunnel info when PMTU triggers an ICMP reply (Antoine Tenart) [1941753]
- net: Add netif_rx_any_context() (Josef Oskera) [1939466]
- bitfield.h: add FIELD_MAX() and field_max() (Ivan Vecera) [1939478]
- md/raid5: cast chunk_sectors to sector_t value (Nigel Croxon) [1921468]
- md: Set prev_flush_start and flush_bio in an atomic way (Nigel Croxon) [1921468]
- md/cluster: fix deadlock when node is doing resync job (Nigel Croxon) [1921468]
- md/cluster: block reshape with remote resync job (Nigel Croxon) [1921468]
- md: use current request time as base for ktime comparisons (Nigel Croxon) [1921468]
- md: add comments in md_flush_request() (Nigel Croxon) [1921468]
- md: improve variable names in md_flush_request() (Nigel Croxon) [1921468]
- md/raid10: initialize r10_bio->read_slot before use. (Nigel Croxon) [1921468]
- md: fix a warning caused by a race between concurrent md_ioctl()s (Nigel Croxon) [1921468]
- Revert "md: improve variable names in md_flush_request()" (Nigel Croxon) [1921468]
- Revert "md: Set prev_flush_start and flush_bio in an atomic way" (Nigel Croxon) [1921468]
- KVM: nSVM: fix running nested guests when npt=0 (Emanuele Giuseppe Esposito) [1799073]
- fork: fix copy_process(CLONE_PARENT) race with the exiting ->real_parent (Julia Denham) [1908311] {CVE-2020-35508}
- Revert "redhat: switch secureboot kernel image signing to release keys" (Bruno Meneguele)
- redhat: switch secureboot kernel image signing to release keys (Jan Stancek)
- Revert "[md] md/raid5: add a new member of offset into r5dev" (Nigel Croxon) [1936903]
- Revert "[md] md/raid5: make async_copy_data() to support different page offset" (Nigel Croxon) [1936903]
- Revert "[crypto] md/raid5: add new xor function to support different page offset" (Nigel Croxon) [1936903]
- Revert "[md] md/raid5: convert to new xor compution interface" (Nigel Croxon) [1936903]
- Revert "[crypto] md/raid6: let syndrome computor support different page offset" (Nigel Croxon) [1936903]
- Revert "[crypto] md/raid6: let async recovery function support different page offset" (Nigel Croxon) [1936903]
- Revert "[md] md/raid5: let multiple devices of stripe_head share page" (Nigel Croxon) [1936903]
- Revert "[md] md/raid5: resize stripe_head when reshape array" (Nigel Croxon) [1936903]
- Revert "[md] md/raid5: reallocate page array after setting new stripe_size" (Nigel Croxon) [1936903]
- ACPI: PNP: compare the string length in the matching_id() (Mark Langsdorf) [1933702]
- ceph: add missing break when parsing "nowsync" mount option (Jeff Layton) [1932753]
- get_maintainer.conf: Update with new location of RHMAINTAINERS (Prarit Bhargava)
- redhat: make pathspec exclusion compatible with old git versions (Herton R. Krzesinski)
- redhat/scripts: Update merge-subtrees.sh with new subtree location (Prarit Bhargava)
- tree: Add RHMAINTAINERS soft link in 8.4 (Prarit Bhargava)
- tree: remove existing redhat/rhdocs subtree in 8.4 (Prarit Bhargava)

* Tue Mar 30 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-302.1.el8]
- ntp: Use freezable workqueue for RTC synchronization (Phil Auld) [1793880]
- ntp: Fix RTC synchronization on 32-bit platforms (Phil Auld) [1793880]
- ntp: Make the RTC synchronization more reliable (Phil Auld) [1793880]
- PCI: rpadlpar: Fix potential drc_name corruption in store functions (Gustavo Luiz Duarte) [1938116]
- selftests: kvm: Add basic Hyper-V clocksources tests (Vitaly Kuznetsov) [1931782]
- KVM: x86: hyper-v: Don't touch TSC page values when guest opted for re-enlightenment (Vitaly Kuznetsov) [1931782]
- KVM: x86: hyper-v: Track Hyper-V TSC page status (Vitaly Kuznetsov) [1931782]
- KVM: x86: hyper-v: Prevent using not-yet-updated TSC page by secondary CPUs (Vitaly Kuznetsov) [1931782]
- KVM: x86: hyper-v: Limit guest to writing zero to HV_X64_MSR_TSC_EMULATION_STATUS (Vitaly Kuznetsov) [1931782]
- drm/i915/guc: Update to use firmware v49.0.1 (Dave Airlie) [1935281] {CVE-2020-12362}
- time: Enable __kernel_timespec for 32-bit vdso build (Waiman Long) [1936282]
- lib/idr.c: document calling context for IDA APIs mustn't use locks (Chris von Recklinghausen) [1917764]
- ida: Free allocated bitmap in error path (Chris von Recklinghausen) [1917764]
- radix tree test suite: Fix compilation (Chris von Recklinghausen) [1917764]
- vmalloc: convert to XArray (Chris von Recklinghausen) [1917764]
- mm: pass addr as unsigned long to vb_free (Chris von Recklinghausen) [1917764]
- radix tree: Remove multiorder support (Chris von Recklinghausen) [1917764]
- radix tree test: Convert multiorder tests to XArray (Chris von Recklinghausen) [1917764]
- radix tree tests: Convert item_delete_rcu to XArray (Chris von Recklinghausen) [1917764]
- radix tree tests: Convert item_kill_tree to XArray (Chris von Recklinghausen) [1917764]
- radix tree tests: Move item_insert_order (Chris von Recklinghausen) [1917764]
- radix tree test suite: Remove multiorder benchmarking (Chris von Recklinghausen) [1917764]
- radix tree test suite: Remove __item_insert (Chris von Recklinghausen) [1917764]
- radix tree: Remove radix_tree_clear_tags (Chris von Recklinghausen) [1917764]
- radix tree: Remove split/join code (Chris von Recklinghausen) [1917764]
- radix tree: Remove radix_tree_update_node_t (Chris von Recklinghausen) [1917764]
- mm: Convert truncate to XArray (Chris von Recklinghausen) [1917764]
- copy rh_kabi.h to tools/testing/radix-tree/linux (Chris von Recklinghausen) [1917764]

* Mon Mar 29 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-301.1.el8]
- tick: Get rid of tick_period (Phil Auld) [1936504]
- tick/sched: Release seqcount before invoking calc_load_global() (Phil Auld) [1936504]
- tick/sched: Optimize tick_do_update_jiffies64() further (Phil Auld) [1936504]
- tick/sched: Reduce seqcount held scope in tick_do_update_jiffies64() (Phil Auld) [1936504]
- tick/sched: Use tick_next_period for lockless quick check (Phil Auld) [1936504]
- tick: Document protections for tick related data (Phil Auld) [1936504]
- tick/broadcast: Serialize access to tick_next_period (Phil Auld) [1936504]
- timekeeping: Split jiffies seqlock (Phil Auld) [1936504]
- tick/sched: Annotate lockless access to last_jiffies_update (Phil Auld) [1936504]
- net, sctp, filter: remap copy_from_user failure error (Hangbin Liu) [1929476] {CVE-2021-20239}
- tty: serial_core: Set port active bit in uart_port_activate (Artem Savkov) [1915177]
- cgroup: fix psi monitor for root cgroup (Waiman Long) [1936868]
- cgroup-v1: add disabled controller check in cgroup1_parse_param() (Waiman Long) [1936868]
- cgroup: cgroup.{procs,threads} factor out common parts (Waiman Long) [1936868]
- cpuset: fix typos in comments (Waiman Long) [1936868]
- kernel: cgroup: Mundane spelling fixes throughout the file (Waiman Long) [1936868]
- cgroup/cgroup.c: replace 'of->kn->priv' with of_cft() (Waiman Long) [1936868]
- cgroup: Zero sized write should be no-op (Waiman Long) [1936868]
- cgroup: remove redundant kernfs_activate in cgroup_setup_root() (Waiman Long) [1936868]
- cgroup: Use generic ns_common::count (Waiman Long) [1936868]
- ns: Add a common refcount into ns_common (Waiman Long) [1936868]
- cgroup: add cpu.stat file to root cgroup (Waiman Long) [1936868]
- cgroup: Remove stale comments (Waiman Long) [1936868]
- cgroup: Restructure release_agent_path handling (Waiman Long) [1936868]
- cgroup: add cgroup_may_write() helper (Waiman Long) [1936868]
- cgroup: refactor fork helpers (Waiman Long) [1936868]
- cgroup: add cgroup_get_from_file() helper (Waiman Long) [1936868]
- cgroup: unify attach permission checking (Waiman Long) [1936868]
- cpuset: Make cpuset hotplug synchronous (Waiman Long) [1936868]
- cgroup: Clean up css_set task traversal (Waiman Long) [1936868]
- cgroup.c: Use built-in RCU list checking (Waiman Long) [1936868]
- fork: record start_time late (Waiman Long) [1936868]
- sched/deadline: Reduce rq lock contention in dl_add_task_root_domain() (Phil Auld) [1936501]
- sched/deadline: Fix sched_dl_global_validate() (Phil Auld) [1936501]
- sched/deadline: Optimize sched_dl_global_validate() (Phil Auld) [1936501]
- sched/deadline: Fix a typo in a comment (Phil Auld) [1936501]
- sched/deadline: Implement fallback mechanism for !fit case (Phil Auld) [1936501]
- sched/deadline: Make DL capacity-aware (Phil Auld) [1936501]
- sched/deadline: Improve admission control for asymmetric CPU capacities (Phil Auld) [1936501]
- sched/deadline: Add dl_bw_capacity() (Phil Auld) [1936501]
- sched/deadline: Optimize dl_bw_cpus() (Phil Auld) [1936501]
- sched/deadline: Impose global limits on sched_attr::sched_period (Phil Auld) [1936501]
- ibmvnic: fix a race between open and reset (Diego Domingos) [1940042]
- ibmvnic: Set to CLOSED state even on error (Diego Domingos) [1940042]
- ibmvnic: device remove has higher precedence over reset (Diego Domingos) [1940042]
- ibmvnic: merge do_change_param_reset into do_reset (Diego Domingos) [1940042]
- ibmvfc: disable MQ channelization by default (Gustavo Luiz Duarte) [1939359]
- pNFS/NFSv4: Fix a layout segment leak in pnfs_layout_process() (Steve Dickson) [1926945]
- scsi: iscsi: Verify lengths on passthrough PDUs (Chris Leech) [1930833] {CVE-2021-27365}
- scsi: iscsi: Ensure sysfs attributes are limited to PAGE_SIZE (Chris Leech) [1930856] {CVE-2021-27363}
- scsi: iscsi: Restrict sessions and handles to admin capabilities (Chris Leech) [1930809] {CVE-2021-27364}
- futex: Handle faults correctly for PI futexes (Waiman Long) [1924635]
- futex: Simplify fixup_pi_state_owner() (Waiman Long) [1924635]
- futex: Use pi_state_update_owner() in put_pi_state() (Waiman Long) [1924635]
- rtmutex: Remove unused argument from rt_mutex_proxy_unlock() (Waiman Long) [1924635]
- futex: Provide and use pi_state_update_owner() (Waiman Long) [1924635]
- futex: Replace pointless printk in fixup_owner() (Waiman Long) [1924635]
- futex: Ensure the correct return value from futex_lock_pi() (Waiman Long) [1924635]
- futex: Don't enable IRQs unconditionally in put_pi_state() (Waiman Long) [1924635]
- futex: Fix incorrect should_fail_futex() handling (Waiman Long) [1924635]
- futex: Consistently use fshared as boolean (Waiman Long) [1924635]
- futex: Remove needless goto's (Waiman Long) [1924635]
- futex: Remove put_futex_key() (Waiman Long) [1924635]
- NFS: Correct size calculation for create reply length (Benjamin Coddington) [1934903]
- SUNRPC: Set memalloc_nofs_save() for sync tasks (Benjamin Coddington) [1934098]
- net/mlx5: CT: Add support for matching on ct_state reply flag (Alaa Hleihel) [1919651]
- net/mlx5e: CT: manage the lifetime of the ct entry object (Alaa Hleihel) [1919651]
- net/mlx5e: CT: Use per flow counter when CT flow accounting is enabled (Alaa Hleihel) [1919651]
- net/mlx5e: Fix a use after free on error in mlx5_tc_ct_shared_counter_get() (Alaa Hleihel) [1919651]
- net/mlx5e: CT: Use the same counter for both directions (Alaa Hleihel) [1919651]
- ethtool: fix the check logic of at least one channel for RX/TX (Ivan Vecera) [1907406]

* Wed Mar 24 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-300.1.el8]
- [scsi] scsi: qedi: Correct max length of CHAP secret (Nilesh Javali) [1909180]
- redhat: use tags from git notes for zstream to generate changelog (Frantisek Hrbata)
- redhat: add CI file for kernel-private (Bruno Meneguele)
- CI: Drop unused variable (Bruno Meneguele)
- CI: Enable RT verification (Bruno Meneguele)
- KVM: SVM: Clear the CR4 register on reset (Vitaly Kuznetsov) [1920788]
- net: flow_offload: Add original direction flag to ct_metadata (Marcelo Ricardo Leitner) [1921946]
- net/sched: cls_flower: Add match on the ct_state reply flag (Marcelo Ricardo Leitner) [1921946]
- net/sched: cls_flower add CT_FLAGS_INVALID flag support (Marcelo Ricardo Leitner) [1921946]
- net/sched: cls_flower: Reject invalid ct_state flags rules (Marcelo Ricardo Leitner) [1921946]
- netlink: add mask validation (Marcelo Ricardo Leitner) [1921946]
- netlink: create helpers for checking type is an int (Marcelo Ricardo Leitner) [1921946]
- netlink: policy: correct validation type check (Marcelo Ricardo Leitner) [1921946]
- netlink: make NLA_BINARY validation more flexible (Marcelo Ricardo Leitner) [1921946]

* Mon Mar 22 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-299.1.el8]
- md: Set prev_flush_start and flush_bio in an atomic way (Xiao Ni) [1901598]
- md: improve variable names in md_flush_request() (Xiao Ni) [1901598]
- hpsa: fix regression issue for old controllers (Joseph Szczypek) [1925711]
- scsi: hpsa: Correct dev cmds outstanding for retried cmds (Joseph Szczypek) [1925711]
- vt: Disable KD_FONT_OP_COPY (Dave Airlie) [1903937] {CVE-2020-28974}
- drm/i915/rkl: Remove require_force_probe protection (Lyude Paul) [1937558]
- drm/i915/tgl/psr: Disable PSR on Tigerlake for now (Lyude Paul) [1924702]
- dm raid: fix discard limits for raid0 and raid10 (Mike Snitzer) [1934274]
- dm: fix __send_changing_extent_only to avoid duplicate dm_target_offset() (Mike Snitzer) [1934274]
- mm/hugetlb.c: fix unnecessary address expansion of pmd sharing (Waiman Long) [1934212]
- mm: memcontrol: fix slub memory accounting (Waiman Long) [1934212]
- mm: memcontrol: fix swap undercounting in cgroup2 (Waiman Long) [1934212]
- mm: memcontrol: fix NR_ANON_THPS accounting in charge moving (Waiman Long) [1934212]
- mm, slub: better heuristic for number of cpus when calculating slab order (Waiman Long) [1934212]
- Revert "mm: memcontrol: avoid workload stalls when lowering memory.high" (Waiman Long) [1934212]
- selftests/bpf: Set gopt opt_class to 0 if get tunnel opt failed (Hangbin Liu) [1931732]
- selftests/bpf: No need to drop the packet when there is no geneve opt (Hangbin Liu) [1931732]

* Tue Mar 16 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-298.1.el8]
- drm/i915/gen11+: Only load DRAM information from pcode (Lyude Paul) [1934537]
- drm/i915/dg1: Wait for pcode/uncore handshake at startup (Lyude Paul) [1934537]
- powercap/intel_rapl: add support for TigerLake Desktop (David Arcari) [1932457]
- powerpc/perf: Fix handling of privilege level checks in perf interrupt context (Gustavo Luiz Duarte) [1918411]
- NFSv4.2: fix error return on memory allocation failure (Scott Mayhew) [1917689]
- NFSv4.2: improve page handling for GETXATTR (Scott Mayhew) [1917689]
- NFSv4.2: Fix up the get/listxattr calls to rpc_prepare_reply_pages() (Scott Mayhew) [1917689]
- NFS: Fix rpcrdma_inline_fixup() crash with new LISTXATTRS operation (Scott Mayhew) [1917689]
- SUNRPC: Fix up xdr_set_page() (Benjamin Coddington) [1917689]
- NFSv4: Fix open coded xdr_stream_remaining() (Benjamin Coddington) [1917689]
- SUNRPC: Clean up the handling of page padding in rpc_prepare_reply_pages() (Benjamin Coddington) [1917689]
- SUNRPC: Fix up xdr_read_pages() to take arbitrary object lengths (Benjamin Coddington) [1917689]
- SUNRPC: Clean up helpers xdr_set_iov() and xdr_set_page_base() (Benjamin Coddington) [1917689]
- SUNRPC: Split out a function for setting current page (Benjamin Coddington) [1917689]
- SUNRPC: Fix up typo in xdr_init_decode() (Benjamin Coddington) [1917689]
- NFSv4: Fix the alignment of page data in the getdeviceinfo reply (Benjamin Coddington) [1917689]
- net: fix pos incrementment in ipv6_route_seq_next (Lorenzo Bianconi) [1926608]
- ipv6_route_seq_next should increase position index (Lorenzo Bianconi) [1926608]
- bpf: Clear subreg_def for global function return values (Yauheni Kaliuta) [1934062]
- igc: Fix returning wrong statistics (Corinna Vinschen) [1910873]

* Fri Mar 12 2021 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-297.1.el8]
- KVM: nSVM: prepare guest save area while is_guest_mode is true (Vitaly Kuznetsov) [1860223]
- redhat: add CI file for kernel-private (Bruno Meneguele)
- CI: Drop unused variable (Veronika Kabatova)
- CI: Enable RT verification (Veronika Kabatova)
- redhat: use tags from git notes for zstream to generate changelog (Frantisek Hrbata)
- redhat: open the RHEL-8.5 development (Bruno Meneguele) [1930504]

* Thu Mar 11 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-297.el8]
- KVM: SVM: Make symbol 'svm_gp_erratum_intercept' static (Paolo Bonzini) [1769283]
- KVM: SVM: Fix #GP handling for doubly-nested virtualization (Paolo Bonzini) [1769283]
- KVM: SVM: Add support for SVM instruction address check change (Paolo Bonzini) [1769283]
- KVM: SVM: Add emulation support for #GP triggered by SVM instructions (Paolo Bonzini) [1769283]
- KVM: x86: Factor out x86 instruction emulation with decoding (Paolo Bonzini) [1769283]
- gfs2: In gfs2_ail1_start_one unplug the IO when needed (Bob Peterson) [1648446]
- gfs2: Free rd_bits later in gfs2_clear-rgrpd to fix use-after-free (Bob Peterson) [1648446]
- gfs2: Only access gl_delete for iopen glocks (Bob Peterson) [1648446]
- gfs2: Fix case in which ail writes are done to jdata holes (Bob Peterson) [1648446]
- gfs2: simplify gfs2_block_map (Bob Peterson) [1648446]
- gfs2: Only set PageChecked if we have a transaction (Bob Peterson) [1648446]
- gfs2: don't lock sd_ail_lock in gfs2_releasepage (Bob Peterson) [1648446]
- gfs2: make gfs2_ail1_empty_one return the count of active items (Bob Peterson) [1648446]
- gfs2: Wipe jdata and ail1 in gfs2_journal_wipe, formerly gfs2_meta_wipe (Bob Peterson) [1648446]
- gfs2: enhance log_blocks trace point to show log blocks free (Bob Peterson) [1648446]
- gfs2: rename gfs2_write_full_page to gfs2_write_jdata_page, remove parm (Bob Peterson) [1648446]
- PM: hibernate: flush swap writer after marking (Lenny Szubowicz) [1898677]
- cpufreq: Avoid cpufreq_suspend() deadlock on system shutdown (Lenny Szubowicz) [1898677]
- PM / hibernate: memory_bm_find_bit(): Tighten node optimisation (Lenny Szubowicz) [1898677]
- bpf, devmap: Use GFP_KERNEL for xdp bulk queue allocation (Jiri Benc) [1882215]
- ice, xsk: clear the status bits for the next_to_use descriptor (Jiri Benc) [1906820]
- net/mlx4_en: Handle TX error CQE (Alaa Hleihel) [1925690]
- net/mlx4_en: Avoid scheduling restart task if it is already running (Alaa Hleihel) [1925690]
- blk-mq: test QUEUE_FLAG_HCTX_ACTIVE for sbitmap_shared in hctx_may_queue (Ming Lei) [1922013]
- blk-mq: Improve performance of non-mq IO schedulers with multiple HW queues (Ming Lei) [1922013]
- Revert "blk-mq, elevator: Count requests per hctx to improve performance" (Ming Lei) [1922013]
- bpftool: Disable CAP_BPF check for feature command (Jiri Olsa) [1921542]
- RDMA/siw: Fix calculation of tx_valid_cpus size (Kamal Heib) [1919502]
- net/mlx5e: Disable performance optimization for IPv4/IPv6 ethertype (Alaa Hleihel) [1928671 1919807]
- IB/mlx5: Return appropriate error code instead of ENOMEM (Alaa Hleihel) [1928671]
- net/mlx5: Disable devlink reload for lag devices (Alaa Hleihel) [1928671 1929166]
- net/mlx5: Disable devlink reload for multi port slave device (Alaa Hleihel) [1928671 1929166]
- net/mlx5: Disallow RoCE on lag device (Alaa Hleihel) [1928671 1929166]
- net/mlx5: Disallow RoCE on multi port slave device (Alaa Hleihel) [1928671 1929166]
- net/mlx5: Fix health error state handling (Alaa Hleihel) [1928671]
- net/mlx5e: Change interrupt moderation channel params also when channels are closed (Alaa Hleihel) [1928671]
- net/mlx5e: Don't change interrupt moderation params when DIM is enabled (Alaa Hleihel) [1928671]
- net/mlx5e: E-switch, Fix rate calculation for overflow (Alaa Hleihel) [1928671]
- net/mlx5e: Release skb in case of failure in tc update skb (Alaa Hleihel) [1928671 1929119]
- net/mlx5e: Check tunnel offload is required before setting SWP (Alaa Hleihel) [1928671 1925439]
- net/mlx5e: kTLS, Use refcounts to free kTLS RX priv context (Alaa Hleihel) [1928671 1928706]
- net/mlx5e: Fix CQ params of ICOSQ and async ICOSQ (Alaa Hleihel) [1928671 1928706]
- net/mlx5e: Replace synchronize_rcu with synchronize_net (Alaa Hleihel) [1928671 1913616]
- net/mlx5e: Enable XDP for Connect-X IPsec capable devices (Alaa Hleihel) [1928671 1856795]
- net/mlx5e: Enable striding RQ for Connect-X IPsec capable devices (Alaa Hleihel) [1928671 1926120]
- fix regression in "epoll: Keep a reference on files added to the check list" (Carlos Maiolino) [1920776] {CVE-2020-0466}
- do_epoll_ctl(): clean the failure exits up a bit (Carlos Maiolino) [1920776] {CVE-2020-0466}
- epoll: Keep a reference on files added to the check list (Carlos Maiolino) [1920776] {CVE-2020-0466}

* Tue Mar 09 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-296.el8]
- perf/x86/intel/uncore: With > 8 nodes, get pci bus die id from NUMA info (Prarit Bhargava) [1766743]
- perf/x86/intel/uncore: Store the logical die id instead of the physical die id. (Prarit Bhargava) [1766743]
- mm: fix page reference leak in soft_offline_page() (Aristeu Rozanski) [1768372]
- mm,hwpoison: try to narrow window race for free pages (Aristeu Rozanski) [1768372]
- mm,hwpoison: double-check page count in __get_any_page() (Aristeu Rozanski) [1768372]
- mm,hwpoison: introduce MF_MSG_UNSPLIT_THP (Aristeu Rozanski) [1768372]
- mm,hwpoison: return 0 if the page is already poisoned in soft-offline (Aristeu Rozanski) [1768372]
- mm,hwpoison: refactor soft_offline_huge_page and __soft_offline_page (Aristeu Rozanski) [1768372]
- mm,hwpoison: rework soft offline for in-use pages (Aristeu Rozanski) [1768372]
- mm,hwpoison: rework soft offline for free pages (Aristeu Rozanski) [1768372]
- mm,hwpoison: unify THP handling for hard and soft offline (Aristeu Rozanski) [1768372]
- mm,hwpoison: kill put_hwpoison_page (Aristeu Rozanski) [1768372]
- mm,hwpoison: refactor madvise_inject_error (Aristeu Rozanski) [1768372]
- mm,hwpoison: unexport get_hwpoison_page and make it static (Aristeu Rozanski) [1768372]
- mm,hwpoison-inject: don't pin for hwpoison_filter (Aristeu Rozanski) [1768372]
- mm, hwpoison: remove recalculating hpage (Aristeu Rozanski) [1768372]
- mm,hwpoison: cleanup unused PageHuge() check (Aristeu Rozanski) [1768372]
- mm/madvise.c: replace with page_size() in madvise_inject_error() (Aristeu Rozanski) [1768372]
- mm, soft-offline: convert parameter to pfn (Aristeu Rozanski) [1768372]
- tick/nohz: Revert "Narrow down noise while setting current task's tick dependency" (Waiman Long) [1931004]
- kvm: Add kvm_stat.service file and kvm_stat logrotate config to the tools (Thomas Huth) [1919930]
- igc: fix link speed advertising (Corinna Vinschen) [1769701]
- [crypto] crypto: qat - add capability detection logic in qat_4xxx (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add AES-XTS support for QAT GEN4 devices (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add AES-CTR support for QAT GEN4 devices (Vladis Dronov) [1833004]
- [crypto] crypto: qat - fix excluded_middle.cocci warnings (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add qat_4xxx driver (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add hook to initialize vector routing table (Vladis Dronov) [1833004]
- [crypto] crypto: qat - target fw images to specific AEs (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add gen4 firmware loader (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add support for broadcasting mode (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add support for shared ustore (Vladis Dronov) [1833004]
- [crypto] crypto: qat - allow to target specific AEs (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add FCU CSRs to chip info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add CSS3K support (Vladis Dronov) [1833004]
- [crypto] crypto: qat - use ae_mask (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add check for null pointer (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add misc control CSR to chip info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add wake up event to chip info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add clock enable CSR to chip info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add reset CSR and mask to chip info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add local memory size to chip info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add support for lm2 and lm3 (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add next neighbor to chip_info (Vladis Dronov) [1833004]
- [crypto] crypto: qat - replace check based on DID (Vladis Dronov) [1833004]
- [crypto] crypto: qat - introduce chip info structure (Vladis Dronov) [1833004]
- [crypto] crypto: qat - refactor long expressions (Vladis Dronov) [1833004]
- [crypto] crypto: qat - refactor qat_uclo_set_ae_mode() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - move defines to header files (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove global CSRs helpers (Vladis Dronov) [1833004]
- [crypto] crypto: qat - refactor AE start (Vladis Dronov) [1833004]
- [crypto] crypto: qat - change micro word data mask (Vladis Dronov) [1833004]
- [crypto] crypto: qat - change type for ctx_mask (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add support for relative FW ucode loading (Vladis Dronov) [1833004]
- [crypto] crypto: qat - rename qat_uclo_del_uof_obj() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - introduce additional parenthesis (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove unnecessary parenthesis (Vladis Dronov) [1833004]
- [crypto] crypto: qat - fix error message (Vladis Dronov) [1833004]
- [crypto] crypto: qat - fix CSR access (Vladis Dronov) [1833004]
- [crypto] crypto: qat - fix status check in qat_hal_put_rel_rd_xfer() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - support for mof format in fw loader (Vladis Dronov) [1833004]
- [crypto] crypto: qat - replace pci with PCI in comments (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove cast for mailbox CSR (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove unneeded semicolon (Vladis Dronov) [1833004]
- [crypto] crypto: qat - extend ae_mask (Vladis Dronov) [1833004]
- [crypto] crypto: qat - allow for instances in different banks (Vladis Dronov) [1833004]
- [crypto] crypto: qat - refactor qat_crypto_dev_config() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - refactor qat_crypto_create_instances() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - change return value in adf_cfg_key_val_get() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - change return value in adf_cfg_add_key_value_param() (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove unnecessary void* casts (Vladis Dronov) [1833004]
- [crypto] crypto: qat - call functions in adf_sriov if available (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove hardcoded bank irq clear flag mask (Vladis Dronov) [1833004]
- [crypto] crypto: qat - abstract writes to arbiter enable (Vladis Dronov) [1833004]
- [crypto] crypto: qat - use BIT_ULL() - 1 pattern for masks (Vladis Dronov) [1833004]
- [crypto] crypto: qat - replace constant masks with GENMASK (Vladis Dronov) [1833004]
- [crypto] crypto: qat - abstract build ring base (Vladis Dronov) [1833004]
- [crypto] crypto: qat - enable ring after pair is programmed (Vladis Dronov) [1833004]
- [crypto] crypto: qat - register crypto instances based on capability (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add support for capability detection (Vladis Dronov) [1833004]
- [crypto] crypto: qat - abstract arbiter access (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove unused macros in arbiter module (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove writes into WQCFG (Vladis Dronov) [1833004]
- [crypto] crypto: qat - update constants table (Vladis Dronov) [1833004]
- [crypto] crypto: qat - use admin mask to send fw constants (Vladis Dronov) [1833004]
- [crypto] crypto: qat - change admin sequence (Vladis Dronov) [1833004]
- [crypto] crypto: qat - rename ME in AE (Vladis Dronov) [1833004]
- [crypto] crypto: qat - add packed to init admin structures (Vladis Dronov) [1833004]
- [crypto] crypto: qat - abstract admin interface (Vladis Dronov) [1833004]
- [crypto] crypto: qat - relocate GEN2 CSR access code (Vladis Dronov) [1833004]
- [crypto] crypto: qat - split transport CSR access logic (Vladis Dronov) [1833004]
- [crypto] crypto: qat - fix configuration of iov threads (Vladis Dronov) [1833004]
- [crypto] crypto: qat - num_rings_per_bank is device dependent (Vladis Dronov) [1833004]
- [crypto] crypto: qat - mask device capabilities with soft straps (Vladis Dronov) [1833004]
- [crypto] crypto: qat - update IV in software (Vladis Dronov) [1833004]
- [crypto] crypto: qat - remove unused function (Vladis Dronov) [1833004]

* Fri Mar 05 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-295.el8]
- mptcp: send ack for every add_addr (Davide Caratti) [1929280]
- Revert "[net] tcp: change pingpong threshold to 3" (Davide Caratti) [1929280]
- powerpc/pseries: Don't enforce MSI affinity with kdump (Greg Kurz) [1919427]
- rtc: disallow update interrupts when time is invalid (Waiman Long) [1918288]
- rtc: disable uie before setting time and enable after (Waiman Long) [1918288]
- rtc: don't reference bogus function pointer in kdoc (Waiman Long) [1918288]
- KVM: x86/mmu: Expand collapsible SPTE zap for TDP MMU to ZONE_DEVICE and HugeTLB pages (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Allow parallel page faults for the TDP MMU (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Mark SPTEs in disconnected pages as removed (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Flush TLBs after zap in TDP MMU PF handler (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Use atomic ops to set SPTEs in TDP MMU map (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Factor out functions to add/remove TDP MMU pages (Paolo Bonzini) [1897366]
- i915: kvmgt: the KVM mmu_lock is now an rwlock (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Use an rwlock for the x86 MMU (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Protect TDP MMU page table memory with RCU (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Clear dirtied pages mask bit before early break (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Skip no-op changes in TDP MMU functions (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Yield in TDU MMU iter even if no SPTES changed (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Ensure forward progress when yielding in TDP MMU iter (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Rename goal_gfn to next_last_level_gfn (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Merge flush and non-flush tdp_mmu_iter_cond_resched (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Fix braces in kvm_recover_nx_lpages (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Factor out handling of removed page tables (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Don't redundantly clear TDP MMU pt memory (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Add lockdep when setting a TDP MMU SPTE (Paolo Bonzini) [1897366]
- KVM: x86/mmu: Add comment on __tdp_mmu_set_spte (Paolo Bonzini) [1897366]
- KVM: x86/mmu: change TDP MMU yield function returns to match cond_resched (Paolo Bonzini) [1897366]
- locking/arch: Move qrwlock.h include after qspinlock.h (Paolo Bonzini) [1897366]
- sched: Add cond_resched_rwlock (Paolo Bonzini) [1897366]
- sched: Add needbreak for rwlocks (Paolo Bonzini) [1897366]
- locking/rwlocks: Add contention detection for rwlocks (Paolo Bonzini) [1897366]
- RDMA/srp: Fix support for unpopulated and unbalanced NUMA nodes (Kamal Heib) [1919395]
- net/vmw_vsock: fix NULL pointer dereference (Jon Maloy) [1925600] {CVE-2021-26708}
- net/vmw_vsock: improve locking in vsock_connect_timeout() (Jon Maloy) [1925600] {CVE-2021-26708}
- vsock: fix locking in vsock_shutdown() (Jon Maloy) [1925600] {CVE-2021-26708}
- vsock: fix the race conditions in multi-transport support (Jon Maloy) [1925600] {CVE-2021-26708}
- ahci: Add missing Intel Emmitsburg PCH RAID PCI IDs (David Arcari) [1928789]
- KVM: x86: Allow guests to see MSR_IA32_TSX_CTRL even if tsx=off (Paolo Bonzini) [1912448]
- [sound] ALSA: hda/via: Fix runtime PM for Clevo W35xSS (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machines (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Enable mute and micmute LED on HP EliteBook 850 G7 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Add two "Intel Reference board" SSID in the ALC256 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Add mute LED quirk for more HP laptops (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Modify Dell platform name (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Fix speaker volume control on Lenovo C940 (Jaroslav Kysela) [1916102]
- [sound] ALSA: ALSA/hda: apply jack fixup for the Acer Veriton N4640G/N6640G/N2510G (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Apply jack fixup for Quanta NL3 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Add quirk for MSI-GP73 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Supported Dell fixed type headset (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Remove dummy lineout on Acer TravelMate P648/P658 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Add supported for more Lenovo ALC285 Headset Button (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Enable headset mic of ASUS Q524UQK with ALC255 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Enable headset mic of ASUS X430UN with ALC256 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: make bass spk volume adjustable on a yoga laptop (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/hdmi: Fix incorrect mutex unlock in silent_stream_disable() (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/hdmi: packet buffer index must be set before reading value (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/hdmi: always print pin NIDs as hexadecimal (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/hdmi: fix silent stream for first playback to DP (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/conexant: add a new hda codec CX11970 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda: Fix regressions on clear and reconfig sysfs (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/proc - print DP-MST connections (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda - Fix the return value if cb func is already registered (Jaroslav Kysela) [1916102]
- [sound] ALSA: mixart: Fix mutex deadlock (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Add mute LED quirk to yet another HP x360 model (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Fix bass speaker DAC assignment on Asus Zephyrus G14 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Add new codec supported for ALC897 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Enable headset of ASUS UX482EG & B9400CEA with ALC294 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Fixed Dell AIO wrong sound tone (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - HP Headset Mic can't detect after boot (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Add supported mute Led for HP (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek: Add some Clove SSID in the ALC293(ALC1220) (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Add supported for Lenovo ThinkPad Headset Button (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Enable headphone for ASUS TM420 (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/realtek - Fixed HP headset Mic can't be detected (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda: Add Alderlake-S PCI ID and HDMI codec vid (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda/generic: Add option to enforce preferred_dacs pairs (Jaroslav Kysela) [1916102]
- [sound] ALSA: hda: prevent undefined shift in snd_hdac_ext_bus_get_link() (Jaroslav Kysela) [1916102]
- [sound] ALSA: seq: oss: Avoid mutex lock for a long-time ioctl (Jaroslav Kysela) [1916102]
- [fs] gfs2: Recursive gfs2_quota_hold in gfs2_iomap_end (Andreas Grunbacher) [1926852]
- [net] netfilter: nf_tables: coalesce multiple notifications into one skbuff (Phil Sutter) [1855207]
- [drm] drm/i915/rkl: new rkl ddc map for different PCH (Lyude Paul) [1910761]
- [drm] drm/nouveau: fix dma syncing warning with debugging on (Lyude Paul) [1915548]
- [drm] drm/i915: Update TGL and RKL HuC firmware versions (Lyude Paul) [1924209]
- [drm] drm/i915/tgl, rkl: Make Wa_1606700617/22010271021 permanent (Lyude Paul) [1924209]
- [drm] drm/i915: Update gen12 forcewake table (Lyude Paul) [1924209]
- [drm] drm/i915: Rename FORCEWAKE_BLITTER to FORCEWAKE_GT (Lyude Paul) [1924209]
- [drm] drm/i915/display/fbc: Implement WA 22010751166 (Lyude Paul) [1924209]
- [drm] drm/i915: Tweaked Wa_14010685332 for PCHs used on gen11 platforms (Lyude Paul) [1924209]
- [drm] drm/i915: Reorder hpd init vs. display resume (Lyude Paul) [1921868]
- [drm] drm/i915/dp: Don't use DPCD backlights that need PWM enable/disable (Lyude Paul) [1885406]
- [drm] drm/dp: Revert "drm/dp: Introduce EDID-based quirks" (Lyude Paul) [1885406]
- [drm] drm/i915/dp: Allow forcing specific interfaces through enable_dpcd_backlight (Lyude Paul) [1885406]
- [drm] drm/i915/dp: Enable Intel's HDR backlight interface (only SDR for now) (Lyude Paul) [1885406]
- [drm] drm/i915: Keep track of pwm-related backlight hooks separately (Lyude Paul) [1885406]
- [drm] drm/i915: Pass port to intel_panel_bl_funcs.get() (Lyude Paul) [1885406]
- [drm] drm/i915/dp: Add register definitions for Intel HDR backlight interface (Lyude Paul) [1885406]
- [drm] drm/i915/dp: Rename eDP VESA backlight interface functions (Lyude Paul) [1885406]
- [drm] drm/i915: Pass down brightness values to enable/disable backlight callbacks (Lyude Paul) [1885406]
- [drm] drm/i915: Rename pwm_* backlight callbacks to ext_pwm_* (Lyude Paul) [1885406]
- [drm] drm/i915/dp: Program source OUI on eDP panels (Lyude Paul) [1885406]
- [drm] drm/i915: refactor panel backlight control functions. (v2) (Lyude Paul) [1885406]
- [drm] drm/i915/backlight: fix CPU mode backlight takeover on LPT (Lyude Paul) [1885406]
- [drm] drm/i915/dpcd_bl: uncheck PWM_PIN_CAP when detect eDP backlight capabilities (Lyude Paul) [1885406]
- [drm] drm/i915: panel: Add get_vbt_pwm_freq() helper (Lyude Paul) [1885406]
- [drm] drm/i915/dp: Tweak initial dpcd backlight.enabled value (Lyude Paul) [1885406]
- [drm] kms: handle mDP connectors (Lyude Paul) [1876992]
- [drm] drm/i915/tgl: Fix Combo PHY DPLL fractional divider for 38.4MHz ref clock (Lyude Paul) [1876992]
- [drm] drm/i915/rkl: Add new cdclk table (Lyude Paul) [1876992]
- [drm] drm/i915/rkl: Handle HTI (Lyude Paul) [1876992]
- [drm] drm/i915/rkl: Add DPLL4 support (Lyude Paul) [1876992]
- [drm] drm/i915/rkl: Add initial workarounds (Lyude Paul) [1876992]
- [drm] drm/i915/rkl: Handle new DPCLKA_CFGCR0 layout (Lyude Paul) [1876992]
- [drm] drm/i915: Update TGL and RKL DMC firmware versions (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Program mocs:63 for cache eviction on gen9 (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Limit frequency drop to RPe on parking (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Retain default context state across shrinking (Lyude Paul) [1876992]
- [drm] drm/amdgpu/vcn3.0: remove old DPG workaround (Lyude Paul) [1876992]
- [drm] drm/amdgpu/vcn3.0: stall DPG when WPTR/RPTR reset (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Fixup tgl mocs for PTE tracking (Lyude Paul) [1876992]
- [drm] drm/amdgpu: add rlc iram and dram firmware support (Lyude Paul) [1876992]
- [drm] drm/nouveau: fix relocations applying logic and a double-free (Lyude Paul) [1876992]
- [drm] drm/amd/display: Avoid HDCP initialization in devices without output (Lyude Paul) [1876992]
- [drm] drm/amd/amdgpu: fix null pointer in runtime pm (Lyude Paul) [1876992]
- [drm] drm/amdgpu: update golden setting for sienna_cichlid (Lyude Paul) [1876992]
- [drm] drm/amdgpu: fix a page fault (Lyude Paul) [1876992]
- [drm] drm/amdgpu: fix SI UVD firmware validate resume fail (Lyude Paul) [1876992]
- [drm] drm/i915/tgl: Fix Media power gate sequence (Lyude Paul) [1876992]
- [drm] drm/i915: Handle max_bpc==16 (Lyude Paul) [1876992]
- [drm] drm/amd/display: Add missing pflip irq for dcn2.0 (Lyude Paul) [1876992]
- [drm] drm/gma500: Fix out-of-bounds access to struct drm_device.vblank (Lyude Paul) [1876992]
- [drm] drm/i915: Correctly set SFC capability for video engines (Lyude Paul) [1876992]
- [drm] drm/amd/display: Add missing pflip irq (Lyude Paul) [1876992]
- [drm] drm/amd/pm: do not use ixFEATURE_STATUS for checking smc running (Lyude Paul) [1876992]
- [drm] drm/amd/pm: perform SMC reset on suspend/hibernation (Lyude Paul) [1876992]
- [drm] drm/amd/pm: correct the baco reset sequence for CI ASICs (Lyude Paul) [1876992]
- [drm] drm/amdgpu: perform srbm soft reset always on SDMA resume (Lyude Paul) [1876992]
- [drm] drm/i915/gem: Flush coherency domains on first set-domain-ioctl (Lyude Paul) [1876992]
- [drm] drm/i915: Hold onto an explicit ref to i915_vma_work.pinned (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Use the local HWSP offset during submission (Lyude Paul) [1876992]
- [drm] drm/i915: Fix encoder lookup during PSR atomic check (Lyude Paul) [1876992]
- [drm] drm/nouveau/gem: fix "refcount_t: underflow; use-after-free" (Lyude Paul) [1876992]
- [drm] drm/nouveau/nouveau: fix the start/end range for migration (Lyude Paul) [1876992]
- [drm] drm/amd/display: adding ddc_gpio_vga_reg_list to ddc reg def'ns (Lyude Paul) [1876992]
- [drm] drm/amd/display: Fixed panic during seamless boot (Lyude Paul) [1876992]
- [drm] drm/amdgpu: add DID for navi10 blockchain SKU (Lyude Paul) [1876992]
- [drm] drm/amdgpu: disable DCN and VCN for navi10 blockchain SKU(v3) (Lyude Paul) [1876992]
- [drm] drm/amdgpu: resolved ASD loading issue on sienna (Lyude Paul) [1876992]
- [drm] drm/amdgpu: update golden setting for sienna_cichlid (Lyude Paul) [1876992]
- [drm] drm/nouveau/device: fix changing endianess code to work on older GPUs (Lyude Paul) [1876992]
- [drm] drm/nouveau/kms/nv50-: Program notifier offset before requesting disp caps (Lyude Paul) [1876992]
- [drm] drm/i915: Restore ILK-M RPS support (Lyude Paul) [1876992]
- [drm] drm/i915: Reject 90/270 degree rotated initial fbs (Lyude Paul) [1876992]
- [drm] drm/i915: Use the active reference on the vma while capturing (Lyude Paul) [1876992]
- [drm] drm/i915: Mark ininitial fb obj as WT on eLLC machines to avoid rcu lockup during fbdev init (Lyude Paul) [1876992]
- [drm] drm/i915: Exclude low pages (128KiB) of stolen from use (Lyude Paul) [1876992]
- [drm] drm/i915: Drop runtime-pm assert from vgpu io accessors (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Delay execlist processing for tgl (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Undo forced context restores after trivial preemptions (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Initialize reserved and unspecified MOCS indices (Lyude Paul) [1876992]
- [drm] drm/i915: Fix TGL DKL PHY DP vswing handling (Lyude Paul) [1876992]
- [drm] drm/i915: Avoid mixing integer types during batch copies (Lyude Paul) [1876992]
- [drm] drm/i915: Cancel outstanding work after disabling heartbeats on an engine (Lyude Paul) [1876992]
- [drm] drm/i915: Break up error capture compression loops with cond_resched() (Lyude Paul) [1876992]
- [drm] drm/i915/gt: Always send a pulse down the engine after disabling heartbeat (Lyude Paul) [1876992]
- [drm] drm/i915/gem: Always test execution status on closing the context (Lyude Paul) [1876992]
- [drm] drm/i915/gem: Prevent using pgprot_writecombine() if PAT is not supported (Lyude Paul) [1876992]
- [drm] drm/i915/gem: Avoid implicit vmap for highmem on x86-32 (Lyude Paul) [1876992]
- [drm] drm/amdgpu: correct the cu and rb info for sienna cichlid (Lyude Paul) [1876992]
- [drm] drm/amd/psp: Fix sysfs: cannot create duplicate filename (Lyude Paul) [1876992]
- [drm] drm/amd/swsmu: add missing feature map for sienna_cichlid (Lyude Paul) [1876992]
- [drm] drm/amd/pm: fix pp_dpm_fclk (Lyude Paul) [1876992]
- [drm] drm/amd/pm: increase mclk switch threshold to 200 us (Lyude Paul) [1876992]
- [drm] drm/amdgpu/swsmu: drop smu i2c bus on navi1x (Lyude Paul) [1876992]
- [drm] drm/ttm: fix eviction valuable range check (Lyude Paul) [1876992]
- [drm] drm/amd/display: Fix kernel panic by dal_gpio_open() error (Lyude Paul) [1876992]
- [drm] drm/amd/display: Don't invoke kgdb_breakpoint() unconditionally (Lyude Paul) [1876992]
- [drm] drm/amdgpu: increase the reserved VM size to 2MB (Lyude Paul) [1876992]
- [drm] drm/amdgpu: add function to program pbb mode for sienna cichlid (Lyude Paul) [1876992]
- [drm] drm/amd/display: Avoid MST manager resource leak (Lyude Paul) [1876992]
- [drm] drm/amdkfd: Use same SQ prefetch setting as amdgpu (Lyude Paul) [1876992]
- [drm] drm/amdgpu: correct the gpu reset handling for job != NULL case (Lyude Paul) [1876992]
- [drm] drm/amdgpu: update golden setting for sienna_cichlid (Lyude Paul) [1876992]
- [drm] drm/amdgpu: vcn and jpeg ring synchronization (Lyude Paul) [1876992]
- [drm] drm/amd/display: Increase timeout for DP Disable (Lyude Paul) [1876992]
- [drm] drm/amd/display: Fix incorrect backlight register offset for DCN (Lyude Paul) [1876992]
- [drm] drm/amdgpu: don't map BO in reserved region (Lyude Paul) [1876992]
- [drm] drm/shme-helpers: Fix dma_buf_mmap forwarding bug (Lyude Paul) [1876992]
- [drm] drm/i915: Force VT'd workarounds when running as a guest OS (Lyude Paul) [1876992]
- [drm] drm/amd/display: Avoid set zero in the requested clk (Lyude Paul) [1876992]
- [drm] drm/amd/display: HDMI remote sink need mode validation for Linux (Lyude Paul) [1876992]
- [drm] drm/amdgpu: No sysfs, not an error condition (Lyude Paul) [1876992]
- [drm] drm/amd/display: Check clock table return (Lyude Paul) [1876992]
- [drm] drm/bridge/synopsys: dsi: add support for non-continuous HS clock (Lyude Paul) [1876992]
- [drm] drm/vkms: avoid warning in vkms_get_vblank_timestamp (Lyude Paul) [1876992]
- [drm] drm/bridge_connector: Set default status connected for eDP connectors (Lyude Paul) [1876992]
- [drm] drm/scheduler: Scheduler priority fixes (v2) (Lyude Paul) [1876992]
- [drm] drm/amdgpu: restore ras flags when user resets eeprom(v2) (Lyude Paul) [1876992]
- [drm] drm/i915/gem: Serialise debugfs i915_gem_objects with ctx->mutex (Lyude Paul) [1876992]
- [drm] drm/amd/display: Disconnect pipe separetely when disable pipe split (Lyude Paul) [1876992]
- [drm] drm/hisilicon: Code refactoring for hibmc_drv_de (Lyude Paul) [1876992]
- [drm] drm/amd/display: Screen corruption on dual displays (DP+USB-C) (Lyude Paul) [1876992]
- [drm] drm: fix double free for gbo in drm_gem_vram_init and drm_gem_vram_create (Lyude Paul) [1876992]
- [drm] drm/amdgpu: Fix invalid number of character '{' in amdgpu_acpi_init (Lyude Paul) [1876992]
- [drm] drm/amdgpu: fix max_entries calculation v4 (Lyude Paul) [1876992]
- [drm] drm/crc-debugfs: Fix memleak in crc_control_write (Lyude Paul) [1876992]
- [drm] drm/gma500: fix error check (Lyude Paul) [1876992]
- [drm] drm/amd/display: fix potential integer overflow when shifting 32 bit variable bl_pwm (Lyude Paul) [1876992]
- [drm] drm/vkms: add missing platform_device_unregister() in vkms_init() (Lyude Paul) [1876992]
- [drm] drm/vgem: add missing platform_device_unregister() in vgem_init() (Lyude Paul) [1876992]
- [drm] drm/amd/display: Fix wrong return value in dm_update_plane_state() (Lyude Paul) [1876992]
- [drm] drm/vkms: fix xrgb on compute crc (Lyude Paul) [1876992]
- [iommu] iommu/amd: Set iommu->int_enabled consistently when interrupts are set up (Vitaly Kuznetsov) [1915038]
- [iommu] iommu/amd: Fix IOMMU interrupt generation in X2APIC mode (Vitaly Kuznetsov) [1915038]
- [iommu] iommu/amd: Fix union of bitfields in intcapxt support (Vitaly Kuznetsov) [1915038]
- [iommu] iommu/amd: Fix kerneldoc comments (Vitaly Kuznetsov) [1915038]
- [x86] x86/irq: Prepare consolidation of irq_alloc_info (Vitaly Kuznetsov) [1915038]
- [iommu] iommu/amd: Use msi_msg shadow structs (Vitaly Kuznetsov) [1915038]
- [iommu] x86_irq_Rename_X86_IRQ_ALLOC_TYPE_MSI_to_reflect_PCI_dependency (Vitaly Kuznetsov) [1915038]
- [netdrv] Revert "e1000e: disable s0ix entry and exit flows for ME systems" (Ken Cox) [1872412]
- [netdrv] e1000e: fix S0ix flow to allow S0i3.2 subset entry (Ken Cox) [1872412]

* Wed Mar 03 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-294.el8]
- dm table: fix DAX iterate_devices based device capability checks (Mike Snitzer) [1905679]
- dm table: fix various whitespace issues with recent DAX code (Mike Snitzer) [1905679]
- dm table: fix dax_dev NULL dereference in device_synchronous() (Mike Snitzer) [1905679]
- dm: enable synchronous dax (Mike Snitzer) [1905679]
- dm table: fix iterate_devices based device capability checks (Mike Snitzer) [1905679]
- dm: remove special-casing of bio-based immutable singleton target on NVMe (Mike Snitzer) [1905679]
- [s390] s390/dasd: Fix inconsistent kobject removal (Philipp Rudo) [1928106]
- [powerpc] powerpc/perf/hv-24x7: Dont create sysfs event files for dummy events (Steve Best) [1927730]
- [powerpc] powerpc/pseries/dlpar: handle ibm, configure-connector delay status (Steve Best) [1927371]
- [x86] x86/kvm: Increase KVM_MAX_VCPUS to 2048 (Eduardo Habkost) [1840923]

* Mon Mar 01 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-293.el8]
- Unbreak mount_capable() (Scott Mayhew) [1903983]

* Thu Feb 25 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-292.el8]
- [powerpc] powerpc: fix wrong backport on Kernel lockdown for power (Diego Domingos) [1928778]
- [powerpc] powerpc/kexec_file: fix FDT size estimation for kdump kernel (Steve Best) [1928105]
- [kernel] sched/features: Distinguish between NORMAL and DEADLINE hrtick (Juri Lelli) [1912118]
- [kernel] sched/features: Fix hrtick reprogramming (Juri Lelli) [1912118]
- [scsi] scsi: lpfc: Fix EEH encountering oops with NVMe traffic (Dick Kennedy) [1854776]
- [scsi] scsi: lpfc: Prevent duplicate requests to unregister with cpuhp framework (Dick Kennedy) [1894960]
- [target] scsi: target: iscsi: Fix cmd abort fabric stop race (Maurizio Lombardi) [1908215]

* Sun Feb 21 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-291.el8]
- [net] netfilter: nft_dynset: add timeout extension to template (Florian Westphal) [1906915]
- [net] netfilter: nftables: fix possible UAF over chains from packet path in netns (Florian Westphal) [1906915]
- [net] netfilter: flowtable: fix tcp and udp header checksum update (Florian Westphal) [1906915]
- [net] netfilter: xt_recent: Fix attempt to update deleted entry (Florian Westphal) [1906915]
- [net] netfilter: conntrack: connection timeout after re-register (Florian Westphal) [1906915]
- [netdrv] ice: Fix MSI-X vector fallback logic (Jonathan Toppins) [1896639 1877645]
- [netdrv] ice: Don't allow more channels than LAN MSI-X available (Jonathan Toppins) [1896639 1877645]
- [net] netfilter: nf_nat: Fix memleak in nf_nat_init (Florian Westphal) [1906915]
- [net] netfilter: xt_RATEEST: reject non-null terminated string from userspace (Florian Westphal) [1906915]
- [include] net: flow_dissector: Wrap unionized VLAN fields in a struct (Florian Westphal) [1906915]
- [net] netfilter: x_tables: Switch synchronization to RCU (Florian Westphal) [1906915]
- [net] netfilter: nftables_offload: build mask based from the matching bytes (Florian Westphal) [1906915]
- [net] netfilter: nft_payload: add C-VLAN offload support (Florian Westphal) [1906915]
- [net] netfilter: nft_payload: add VLAN offload support (Florian Westphal) [1906915]
- [net] netfilter: nf_tables_offload: allow ethernet interface type only (Florian Westphal) [1906915]
- [net] netfilter: nftables_offload: set address type in control dissector (Florian Westphal) [1906915]
- [net] netfilter: nf_tables: avoid false-postive lockdep splat (Florian Westphal) [1906915]
- [net] netfilter: nf_tables: missing validation from the abort path (Florian Westphal) [1906915]
- [net] netfilter: nftables: fix netlink report logic in flowtable and genid (Florian Westphal) [1906915]
- [include] netfilter: nf_tables: constify nft_reg_load{8, 16, 64}() (Florian Westphal) [1906915]
- [net] netfilter: nf_tables: Introduce new 64-bit helper register functions (Florian Westphal) [1906915]
- [include] netfilter: nf_tables: drop include of module.h from nf_tables.h (Florian Westphal) [1906915]
- [net] netfilter: nf_fwd_netdev: clear timestamp in forwarding path (Florian Westphal) [1906915]
- [net] netfilter: ipset: prevent uninit-value in hash_ip6_add (Florian Westphal) [1906915]
- [net] netfilter: use actual socket sk rather than skb sk when routing harder (Florian Westphal) [1906915]
- [net] netfilter: ipv4: remove useless export_symbol (Florian Westphal) [1906915]
- [net] netfilter: conntrack: don't set related state for different outer address (Florian Westphal) [1906915]
- [fs] xfs: don't catch dax+reflink inodes as corruption in verifier (Bill O'Donnell) [1915510]

* Sat Feb 20 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-290.el8]
- [powerpc] powerpc: Don't enable FSCR_SCV in init_FSCR_power9() (Gustavo Duarte) [1928399]
- [netdrv] ibmvnic: Clear failover_pending if unable to schedule (Steve Best) [1926365]
- [netdrv] ibmvnic: change IBMVNIC_MAX_IND_DESCS to 16 (Steve Best) [1928243]
- [tools] perf powerpc: Fix printf conversion specifier for IP addresses (Steve Best) [1928209]
- [tools] perf powerpc: Fix gap between kernel end and module start (Steve Best) [1928209]
- [netdrv] i40e: Revert "i40e: don't report link up for a VF who hasn't enabled queues" (Stefan Assmann) [1838733]
- [netdrv] i40e: acquire VSI pointer only after VF is initialized (Stefan Assmann) [1838733]
- [netdrv] i40e: fix potential NULL pointer dereferencing (Stefan Assmann) [1838733]
- [netdrv] i40e: Fix Error I40E_AQ_RC_EINVAL when removing VFs (Stefan Assmann) [1838733]
- [netdrv] i40e, xsk: clear the status bits for the next_to_use descriptor (Stefan Assmann) [1838733]
- [netdrv] i40e: avoid premature Rx buffer reuse (Stefan Assmann) [1838733]
- [netdrv] i40e: Remove unnecessary sw_ring access from xsk Tx (Stefan Assmann) [1838733]
- [netdrv] i40e: Fix removing driver while bare-metal VFs pass traffic (Stefan Assmann) [1838733]
- [netdrv] i40e: report correct VF link speed when link state is set to enable (Stefan Assmann) [1838733]
- [netdrv] i40e: remove redundant assignment (Stefan Assmann) [1838733]
- [netdrv] i40e: Fix MAC address setting for a VF via Host/VM (Stefan Assmann) [1838733]
- [netdrv] i40e: Allow changing FEC settings on X722 if supported by FW (Stefan Assmann) [1838733]
- [netdrv] net: intel: Remove in_interrupt() warnings (Stefan Assmann) [1838733]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Stefan Assmann) [1838733]
- [netdrv] i40e, xsk: uninitialized variable in i40e_clean_rx_irq_zc() (Stefan Assmann) [1838733]
- [netdrv] i40e, xsk: move buffer allocation out of the Rx processing loop (Stefan Assmann) [1838733]
- [netdrv] i40e: use 16B HW descriptors instead of 32B (Stefan Assmann) [1838733]
- [netdrv] i40e, xsk: remove HW descriptor prefetch in AF_XDP path (Stefan Assmann) [1838733]
- [netdrv] i40e: optimise prefetch page refcount (Stefan Assmann) [1838733]
- [netdrv] i40e: not compute affinity_mask for IRQ (Stefan Assmann) [1838733]
- [netdrv] i40e: Fix crash during removing i40e driver (Stefan Assmann) [1838733]
- [netdrv] i40e: Set RX_ONLY mode for unicast promiscuous on VLAN (Stefan Assmann) [1838733]
- [netdrv] PCI: Use 'pci_channel_state_t' instead of 'enum pci_channel_state' (Stefan Assmann) [1838733]
- [netdrv] i40e: introduce new dump desc XDP command (Stefan Assmann) [1838733]
- [netdrv] i40e: add XDP ring statistics to dump VSI debug output (Stefan Assmann) [1838733]
- [netdrv] i40e: add XDP ring statistics to VSI stats (Stefan Assmann) [1838733]
- [netdrv] i40e: move check of full Tx ring to outside of send loop (Stefan Assmann) [1838733]
- [netdrv] i40e: eliminate division in napi_poll data path (Stefan Assmann) [1838733]
- [netdrv] i40e: optimize AF_XDP Tx completion path (Stefan Assmann) [1838733]
- [netdrv] i40e: Add support for a new feature Total Port Shutdown (Stefan Assmann) [1838733]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Stefan Assmann) [1838733]
- [netdrv] i40e: Add support for 5Gbps cards (Stefan Assmann) [1838733]
- [netdrv] net/intel: remove driver versions from Intel drivers (Stefan Assmann) [1838733]
- [netdrv] i40e: Add a check to see if MFS is set (Stefan Assmann) [1838733]
- [netdrv] i40e: detect and log info about pre-recovery mode (Stefan Assmann) [1838733]
- [netdrv] i40e: make PF wait reset loop reliable (Stefan Assmann) [1838733]
- [netdrv] i40e: remove unused defines (Stefan Assmann) [1838733]
- [netdrv] i40e: Move client header location (Stefan Assmann) [1838733]
- [netdrv] i40e: protect ring accesses with READ- and WRITE_ONCE (Stefan Assmann) [1838733]
- [netdrv] i40e: Make i40e_shutdown_adminq() return void (Stefan Assmann) [1838733]
- [netdrv] i40e: trivial fixup of comments in i40e_xsk.c (Stefan Assmann) [1838733]
- [netdrv] i40e: Use scnprintf() for avoiding potential buffer overflow (Stefan Assmann) [1838733]
- [netdrv] team: protect features update by RCU to avoid deadlock (Josef Oskera) [1909593]
- [tools] bpf: selftests: remove test_progs LSM test (Yauheni Kaliuta) [1925911]
- [net] bpf: Fix a verifier failure with xor (Yauheni Kaliuta) [1925911]
- [tools] selftests: Remove fmod_ret from test_overhead (Jiri Olsa) [1925911]
- [s390] s390/kdump: fix out-of-memory with PCI (Philipp Rudo) [1927744]
- [x86] x86/intel_split_lock: Really Disable split lock detector by default in RHEL8 (Prarit Bhargava) [1924578]
- [scsi] megaraid_sas: re-add certain pci-ids as unsupported (Tomas Henzl) [1761485]
- [scsi] megaraid_sas: mark unsupported devices (Tomas Henzl) [1761485]
- [pci] rh_taint: add support function (Tomas Henzl) [1761485]
- [powerpc] powerpc/xmon: Restrict when kernel is locked down (Diego Domingos) [1853307]
- [powerpc] powerpc/xmon: add read-only mode (Diego Domingos) [1853307]
- [powerpc] powerpc: lock down kernel in secure boot mode (Diego Domingos) [1853307]
- [net] fix iteration for sctp transport seq_files (Xin Long) [1916824]
- [tools] x86: xen: insn: Decode Xen and KVM emulate-prefix signature (Michael Petlan) [1867733]
- [tools] objtool: Ignore intentional differences for the x86 insn decoder (Michael Petlan) [1867733]
- [x86] x86/insn: Add Control-flow Enforcement (CET) instructions to the opcode map (Michael Petlan) [1867733]
- [x86] x86/decoder: Add TEST opcode to Group3-2 (Michael Petlan) [1867733]
- [x86] x86/insn: Add some more Intel instructions to the opcode map (Michael Petlan) [1867733]
- [x86] x86/insn: Add some Intel instructions to the opcode map (Michael Petlan) [1867733]
- [net] udp: call udp_encap_enable for v6 sockets when enabling encap (Xin Long) [1907754]
- [fs] close_range: unshare all fds for CLOSE_RANGE_UNSHARE | CLOSE_RANGE_CLOEXEC (Pavel Reichl) [1900674]
- [fs] fs, close_range: add flag CLOSE_RANGE_CLOEXEC (Pavel Reichl) [1900674]
- [tools] tests: close_range - Replace clone3 with clone (Pavel Reichl) [1900674]
- [tools] selftests: core: use SKIP instead of XFAIL in close_range_test.c (Pavel Reichl) [1900674]
- [tools] tools headers API: Update close_range affected files (Pavel Reichl) [1900674]
- [tools] tests: add CLOSE_RANGE_UNSHARE tests (Pavel Reichl) [1900674]
- [fs] close_range: add CLOSE_RANGE_UNSHARE (Pavel Reichl) [1900674]
- [tools] tests: add close_range() tests (Pavel Reichl) [1900674]
- [powerpc] arch: wire-up close_range() (Pavel Reichl) [1900674]
- [fs] open: add close_range() (Pavel Reichl) [1900674]
- [x86] x86/sgx: mark tech preview (Vladis Dronov) [1660337]
- [tools] tools headers cpufeatures: Sync with the kernel sources (Vladis Dronov) [1660337]
- [tools] tools arch x86: Sync the msr-index.h copy with the kernel sources (Vladis Dronov) [1660337]
- [tools] tools arch x86: Sync the msr-index.h copy with the kernel sources (Vladis Dronov) [1660337]
- [x86] x86/sgx: Drop racy follow_pfn() check (Vladis Dronov) [1660337]
- [x86] x86/sgx: Fix the return type of sgx_init() (Vladis Dronov) [1660337]
- [x86] x86/sgx: Return -EINVAL on a zero length buffer in sgx_ioc_enclave_add_pages() (Vladis Dronov) [1660337]
- [x86] x86/sgx: Fix a typo in kernel-doc markup (Vladis Dronov) [1660337]
- [x86] x86/sgx: Fix sgx_ioc_enclave_provision() kernel-doc comment (Vladis Dronov) [1660337]
- [x86] x86/sgx: Return -ERESTARTSYS in sgx_ioc_enclave_add_pages() (Vladis Dronov) [1660337]
- [tools] selftests/sgx: Use a statically generated 3072-bit RSA key (Vladis Dronov) [1660337]
- [x86] x86/sgx: Clarify 'laundry_list' locking (Vladis Dronov) [1660337]
- [documentation] Documentation/x86: Document SGX kernel architecture (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add ptrace() support for the SGX driver (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add a page reclaimer (Vladis Dronov) [1660337]
- [tools] selftests/x86: Add a selftest for SGX (Vladis Dronov) [1660337]
- [x86] x86/vdso: Implement a vDSO for Intel SGX enclave call (Vladis Dronov) [1660337]
- [mm] x86/traps: Attempt to fixup exceptions in vDSO before signaling (Vladis Dronov) [1660337]
- [mm] x86/fault: Add a helper function to sanitize error code (Vladis Dronov) [1660337]
- [x86] x86/vdso: Add support for exception fixup in vDSO functions (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add SGX_IOC_ENCLAVE_PROVISION (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add SGX_IOC_ENCLAVE_INIT (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add SGX_IOC_ENCLAVE_ADD_PAGES (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add SGX_IOC_ENCLAVE_CREATE (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add an SGX misc driver interface (Vladis Dronov) [1660337]
- [mm] mm: Add 'mprotect' hook to struct vm_operations_struct (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add SGX page allocator functions (Vladis Dronov) [1660337]
- [x86] x86/cpu/intel: Add a nosgx kernel parameter (Vladis Dronov) [1660337]
- [x86] x86/cpu/intel: Detect SGX support (Vladis Dronov) [1660337]
- [mm] x86/mm: Signal SIGSEGV with PF_SGX (Vladis Dronov) [1660337]
- [x86] x86/sgx: Initialize metadata for Enclave Page Cache (EPC) sections (Vladis Dronov) [1660337]
- [x86] x86/{cpufeatures, msr}: Add Intel SGX Launch Control hardware bits (Vladis Dronov) [1660337]
- [x86] x86/cpufeatures: Add Intel SGX hardware bits (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add wrappers for ENCLS functions (Vladis Dronov) [1660337]
- [x86] x86/sgx: Add SGX architectural data structures (Vladis Dronov) [1660337]
- [mm] x86/fault: Make error_code sanitization more robust (Vladis Dronov) [1660337]
- [video] vgacon: remove software scrollback support (Chris von Recklinghausen) [1883596]
- [tools] libbpf: fix backport of "libbpf: Remove any use of reallocarray() in libbpf" (Jiri Benc) [1924711]
- [net] bpf: Prevent double bpf_prog_put call from bpf_tracing_prog_attach (Jiri Benc) [1924711]
- [tools] selftests/bpf: Adding test for arg dereference in extension trace (Jiri Benc) [1924711]
- [tools] selftests: Add selftest for disallowing modify_return attachment to freplace (Jiri Benc) [1924711]
- [tools] selftests: Add test for multiple attachments of freplace program (Jiri Benc) [1924711]
- [tools] selftests/bpf: Turn fexit_bpf2bpf into test with subtests (Jiri Benc) [1924711]
- [tools] libbpf: Add support for freplace attachment in bpf_link_create (Jiri Benc) [1924711]
- [net] bpf: Fix context type resolving for extension programs (Jiri Benc) [1924711]
- [net] bpf: Support attaching freplace programs to multiple attach points (Jiri Benc) [1924711]
- [net] bpf: Move prog->aux->linked_prog and trampoline into bpf_link on attach (Jiri Benc) [1924711]
- [net] bpf: verifier: refactor check_attach_btf_id() (Jiri Benc) [1924711]
- [net] bpf: change logging calls from verbose() to bpf_log() and use log pointer (Jiri Benc) [1924711]
- [net] bpf: disallow attaching modify_return tracing functions to other BPF programs (Jiri Benc) [1924711]
- [mm] kasan: fix incorrect arguments passing in kasan_add_zero_shadow (Waiman Long) [1921394]
- [mm] kasan: fix unaligned address is unhandled in kasan_remove_zero_shadow (Waiman Long) [1921394]
- [mm] mm: memcg/slab: optimize objcg stock draining (Waiman Long) [1921394]
- [mm] mm: don't wake kswapd prematurely when watermark boosting is disabled (Waiman Long) [1921394]
- [mm] mm/vmalloc.c: fix kasan shadow poisoning size (Waiman Long) [1921394]
- [mm] mm/vmalloc: Fix unlock order in s_stop() (Waiman Long) [1921394]
- [mm] mm/swapfile: do not sleep with a spin lock held (Waiman Long) [1921394]
- [mm] mm: list_lru: set shrinker map bit when child nr_items is not zero (Waiman Long) [1921394]
- [mm] mm: mempolicy: fix potential pte_unmap_unlock pte error (Waiman Long) [1921394]
- [mm] mm/mmu_notifier: fix mmget() assert in __mmu_interval_notifier_insert (Waiman Long) [1921394]
- [mm] mm/swapfile.c: fix potential memory leak in sys_swapon (Waiman Long) [1921394]
- [mm] mm: validate pmd after splitting (Waiman Long) [1921394]
- [mm] hugetlb_cgroup: convert comma to semicolon (Waiman Long) [1921394]
- [mm] mm/memory_hotplug: fix unpaired mem_hotplug_begin/done (Waiman Long) [1921394]
- [mm] khugepaged: adjust VM_BUG_ON_MM() in __khugepaged_enter() (Waiman Long) [1921394]
- [mm] khugepaged: khugepaged_test_exit() check mmget_still_valid() (Waiman Long) [1921394]
- [mm] mm/hugetlb: fix calculation of adjust_range_if_pmd_sharing_possible (Waiman Long) [1921394]
- [mm] mm/hugetlb.c: clean code by removing unnecessary initialization (Waiman Long) [1921394]
- [mm] mm/sparse: never partially remove memmap for early section (Waiman Long) [1921394]
- [mm] mm/sparse: fix kernel crash with pfn_section_valid check (Waiman Long) [1921394]
- [mm] mm/shuffle: don't move pages between zones and don't read garbage memmaps (Waiman Long) [1921394]
- [mm] mm/sparse: rename pfn_present() to pfn_in_present_section() (Waiman Long) [1921394]
- [powerpc] powerpc/pseries: Advance pfn if section is not present in lmb_is_removable() (Waiman Long) [1921394]
- [powerpc] powerpc/pseries/hotplug-memory: Change rc variable to bool (Waiman Long) [1921394]
- [mm] mm/gup: fix fixup_user_fault() on multiple retries (Waiman Long) [1921394]
- [mm] mm/gup: Let __get_user_pages_locked() return -EINTR for fatal signal (Waiman Long) [1921394]
- [mm] mm/mempolicy: Allow lookup_node() to handle fatal signal (Waiman Long) [1921394]
- [include] include/linux/memremap.h: remove stale comments (Waiman Long) [1921394]
- [mm] mm/sparsemem: get address to page struct instead of address to pfn (Waiman Long) [1921394]
- [fs] hibernate: Allow uswsusp to write to swap (Waiman Long) [1921394]
- [mm] mm/hotplug: fix hot remove failure in SPARSEMEM|!VMEMMAP case (Waiman Long) [1921394]
- [mm] mm/hmm: add missing call to hmm_pte_need_fault in HMM_PFN_SPECIAL handling (Waiman Long) [1921394]
- [mm] mm/hmm: add missing unmaps of the ptep during hmm_vma_handle_pte() (Waiman Long) [1921394]
- [mm] mm/hmm: allow snapshot of the special zero page (Waiman Long) [1921394]
- [mm] mm/hmm: a few more C style and comment clean ups (Waiman Long) [1921394]
- [mm] mm/sparse.c: do not waste pre allocated memmap space (Waiman Long) [1921394]
- [mm] mm/sparse: consistently do not zero memmap (Waiman Long) [1921394]
- [mm] mm/gup: fix a misnamed "write" argument, and a related bug (Waiman Long) [1921394]
- [powerpc] treewide: add checks for the return value of memblock_alloc*() (Waiman Long) [1921394]
- [kvm] KVM: x86: Expose AVX512_FP16 for supported CPUID (Paul Lai) [1838734]
- [x86] x86: Enumerate AVX512 FP16 CPUID feature flag (Paul Lai) [1838734]
- [kvm] x86/kvm: Expose TSX Suspend Load Tracking feature (Paul Lai) [1838734]
- [net] sched: act_ct: enable stats for HW offloaded entries (Marcelo Leitner) [1909257]
- [scsi] scsi: fnic: Validate io_req before others (Govindarajulu Varadarajan) [1845720]
- [scsi] scsi: fnic: Set scsi_set_resid() only for underflow (Govindarajulu Varadarajan) [1845720]
- [scsi] scsi: fnic: Change shost_printk() to FNIC_MAIN_DBG() (Govindarajulu Varadarajan) [1845720]
- [scsi] scsi: fnic: Avoid looping in TRANS ETH on unload (Govindarajulu Varadarajan) [1845720]
- [scsi] scsi: fnic: Change shost_printk() to FNIC_FCS_DBG() (Govindarajulu Varadarajan) [1845720]
- [scsi] scsi: fnic: Simplify the return expression of vnic_wq_copy_alloc() (Govindarajulu Varadarajan) [1845720]
- [scsi] scsi: fnic: Fix inconsistent format argument type in fnic_debugfs.c (Govindarajulu Varadarajan) [1845720]
- [x86] perf/x86/intel/uncore: Fix the scale of the IMC free-running events (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Reduce the number of CBOX counters (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Update Ice Lake uncore units (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Split the Ice Lake and Tiger Lake MSR uncore support (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Support PCIe3 unit on Snow Ridge (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Generic support for the PCI sub driver (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Factor out uncore_pci_pmu_unregister() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Factor out uncore_pci_pmu_register() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Factor out uncore_pci_find_dev_pmu() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/uncore: Factor out uncore_pci_get_dev_die_info() (Michael Petlan) [1884818 1908305]

* Wed Feb 17 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-289.el8]
- [mmc] mmc: sdhci-acpi: For amd device set driver type as MMC_SET_DRIVER_TYPE_A (David Arcari) [1906067]
- [pinctrl] pinctrl: Added IRQF_SHARED flag for amd-pinctrl driver (David Arcari) [1906067]
- [block] block: export blk_mq_make_request (Ming Lei) [1917913]
- [platform] platform/x86: dell-wmi-sysman: fix a NULL pointer dereference (Perry Yuan) [1922587]
- [platform] platform/x86: dell-wmi-sysman: work around for BIOS bug (Juan Martinez) [1504859]
- [platform] platform/x86: dell-wmi-sysman: fix init_bios_attributes() error handling (Juan Martinez) [1504859]
- [platform] platform/x86/dell-wmi-sysman: Make some symbols static (Juan Martinez) [1504859]
- [platform] platform/x86/dell-wmi-sysman: Make wmi_sysman_kobj_sysfs_ops static (Juan Martinez) [1504859]
- [documentation] docs: ABI: sysfs-class-firmware-attributes: solve some warnings (Juan Martinez) [1504859]
- [platform] platform/x86: Use appropriate module alias macro for this kernel (Juan Martinez) [1504859]
- [platform] platform/x86: Introduce support for Systems Management Driver over WMI for Dell Systems (Juan Martinez) [1504859]
- [md] dm: eliminate potential source of excessive kernel log noise (Mike Snitzer) [1876840]
- [scsi] scsi: sd: Suppress spurious errors when WRITE SAME is being disabled (Ewan Milne) [1871060]
- [net] libceph, ceph: disambiguate ceph_connection_operations handlers (Jeff Layton) [1893177]
- [net] libceph: zero out session key and connection secret (Jeff Layton) [1893177]
- [include] libceph: add __maybe_unused to DEFINE_MSGR2_FEATURE (Jeff Layton) [1893177]
- [net] libceph: align session_key and con_secret to 16 bytes (Jeff Layton) [1893177]
- [net] libceph: fix auth_signature buffer allocation in secure mode (Jeff Layton) [1893177]
- [fs] ceph: reencode gid_list when reconnecting (Jeff Layton) [1893177]
- [net] libceph: drop ceph_auth_{create, update}_authorizer() (Jeff Layton) [1893177]
- [fs] libceph, ceph: make use of __ceph_auth_get_authorizer() in msgr1 (Jeff Layton) [1893177]
- [net] libceph, ceph: implement msgr2.1 protocol (crc and secure modes) (Jeff Layton) [1893177]
- [net] libceph: introduce connection modes and ms_mode option (Jeff Layton) [1893177]
- [block] libceph, rbd: ignore addr->type while comparing in some cases (Jeff Layton) [1893177]
- [net] libceph, ceph: get and handle cluster maps with addrvecs (Jeff Layton) [1893177]
- [net] libceph: factor out finish_auth() (Jeff Layton) [1893177]
- [net] libceph: drop ac->ops->name field (Jeff Layton) [1893177]
- [net] libceph: amend cephx init_protocol() and build_request() (Jeff Layton) [1893177]
- [net] libceph, ceph: incorporate nautilus cephx changes (Jeff Layton) [1893177]
- [net] libceph: safer en/decoding of cephx requests and replies (Jeff Layton) [1893177]
- [net] libceph: more insight into ticket expiry and invalidation (Jeff Layton) [1893177]
- [net] libceph: move msgr1 protocol specific fields to its own struct (Jeff Layton) [1893177]
- [net] libceph: move msgr1 protocol implementation to its own file (Jeff Layton) [1893177]
- [net] libceph: use sendpage_ok() in ceph_tcp_sendpage() (Jeff Layton) [1893177]
- [net] net: introduce helper sendpage_ok() in include/linux/net.h (Jeff Layton) [1893177]
- [net] libceph: separate msgr1 protocol implementation (Jeff Layton) [1893177]
- [net] libceph: export remaining protocol independent infrastructure (Jeff Layton) [1893177]
- [net] libceph: export zero_page (Jeff Layton) [1893177]
- [net] libceph: rename and export con->flags bits (Jeff Layton) [1893177]
- [net] libceph: rename and export con->state states (Jeff Layton) [1893177]
- [net] libceph: make con->state an int (Jeff Layton) [1893177]
- [net] libceph: don't export ceph_messenger_{init_fini}() to modules (Jeff Layton) [1893177]
- [net] libceph: make sure our addr->port is zero and addr->nonce is non-zero (Jeff Layton) [1893177]
- [net] libceph: factor out ceph_con_get_out_msg() (Jeff Layton) [1893177]
- [net] libceph: change ceph_con_in_msg_alloc() to take hdr (Jeff Layton) [1893177]
- [net] libceph: change ceph_msg_data_cursor_init() to take cursor (Jeff Layton) [1893177]
- [net] libceph: handle discarding acked and requeued messages separately (Jeff Layton) [1893177]
- [net] libceph: drop msg->ack_stamp field (Jeff Layton) [1893177]
- [net] libceph: remove redundant session reset log message (Jeff Layton) [1893177]
- [net] libceph: clear con->peer_global_seq on RESETSESSION (Jeff Layton) [1893177]
- [net] libceph: rename reset_connection() to ceph_con_reset_session() (Jeff Layton) [1893177]
- [net] libceph: split protocol reset bits out of reset_connection() (Jeff Layton) [1893177]
- [net] libceph: don't call reset_connection() on version/feature mismatches (Jeff Layton) [1893177]
- [net] libceph: lower exponential backoff delay (Jeff Layton) [1893177]
- [net] libceph: include middle_len in process_message() dout (Jeff Layton) [1893177]
- [fs] ceph: implement updated ceph_mds_request_head structure (Jeff Layton) [1893177]
- [fs] ceph: clean up argument lists to __prepare_send_request and __send_request (Jeff Layton) [1893177]
- [fs] ceph: take a cred reference instead of tracking individual uid/gid (Jeff Layton) [1893177]
- [fs] ceph: don't reach into request header for readdir info (Jeff Layton) [1893177]
- [fs] ceph: set osdmap epoch for setxattr (Jeff Layton) [1893177]
- [fs] ceph: remove redundant assignment to variable i (Jeff Layton) [1893177]
- [fs] ceph: add ceph.caps vxattr (Jeff Layton) [1893177]
- [fs] ceph: when filling trace, call ceph_get_inode outside of mutexes (Jeff Layton) [1893177]
- [fs] Revert "ceph: allow rename operation under different quota realms" (Jeff Layton) [1893177]
- [fs] ceph: fix inode refcount leak when ceph_fill_inode on non-I_NEW inode fails (Jeff Layton) [1893177]
- [fs] ceph: downgrade warning from mdsmap decode to debug (Jeff Layton) [1893177]
- [fs] ceph: fix race in concurrent __ceph_remove_cap invocations (Jeff Layton) [1893177]
- [fs] ceph: pass down the flags to grab_cache_page_write_begin (Jeff Layton) [1893177]
- [fs] ceph: add ceph.{cluster_fsid/client_id} vxattrs (Jeff Layton) [1893177]
- [fs] ceph: add status debugfs file (Jeff Layton) [1893177]
- [include] libceph: remove unused port macros (Jeff Layton) [1893177]
- [fs] ceph: ensure we have Fs caps when fetching dir link count (Jeff Layton) [1893177]
- [fs] ceph: send dentry lease metrics to MDS daemon (Jeff Layton) [1893177]
- [fs] ceph: acquire Fs caps when getting dir stats (Jeff Layton) [1893177]
- [fs] ceph: fix up some warnings on W=1 builds (Jeff Layton) [1893177]
- [fs] ceph: queue MDS requests to REJECTED sessions when CLEANRECOVER is set (Jeff Layton) [1893177]
- [fs] ceph: remove timeout on allowing reconnect after blocklisting (Jeff Layton) [1893177]
- [fs] ceph: add new RECOVER mount_state when recovering session (Jeff Layton) [1893177]
- [fs] ceph: make fsc->mount_state an int (Jeff Layton) [1893177]
- [fs] ceph: don't WARN when removing caps due to blocklisting (Jeff Layton) [1893177]
- [fs] ceph: check session state after bumping session->s_seq (Jeff Layton) [1893177]
- [net] libceph: clear con->out_msg on Policy::stateful_server faults (Jeff Layton) [1893177]
- [net] libceph: format ceph_entity_addr nonces as unsigned (Jeff Layton) [1893177]
- [include] libceph: fix ENTITY_NAME format suggestion (Jeff Layton) [1893177]
- [net] libceph: move a dout in queue_con_delay() (Jeff Layton) [1893177]
- [fs] ceph: comment cleanups and clarifications (Jeff Layton) [1893177]
- [fs] ceph: break up send_cap_msg (Jeff Layton) [1893177]
- [fs] ceph: drop separate mdsc argument from __send_cap (Jeff Layton) [1893177]
- [fs] ceph: promote to unsigned long long before shifting (Jeff Layton) [1893177]
- [fs] ceph: don't SetPageError on readpage errors (Jeff Layton) [1893177]
- [fs] ceph: mark ceph_fmt_xattr() as printf-like for better type checking (Jeff Layton) [1893177]
- [fs] ceph: fold ceph_update_writeable_page into ceph_write_begin (Jeff Layton) [1893177]
- [fs] ceph: fold ceph_sync_writepages into writepage_nounlock (Jeff Layton) [1893177]
- [fs] ceph: fold ceph_sync_readpages into ceph_readpage (Jeff Layton) [1893177]
- [fs] ceph: don't call ceph_update_writeable_page from page_mkwrite (Jeff Layton) [1893177]
- [fs] ceph: break out writeback of incompatible snap context to separate function (Jeff Layton) [1893177]
- [fs] ceph: add a note explaining session reject error string (Jeff Layton) [1893177]
- [net] libceph: switch to the new "osd blocklist add" command (Jeff Layton) [1893177]
- [fs] libceph, rbd, ceph: "blacklist" -> "blocklist" (Jeff Layton) [1893177]
- [fs] ceph: have ceph_writepages_start call pagevec_lookup_range_tag (Jeff Layton) [1893177]
- [fs] ceph: use kill_anon_super helper (Jeff Layton) [1893177]
- [fs] ceph: metrics for opened files, pinned caps and opened inodes (Jeff Layton) [1893177]
- [fs] ceph: add ceph_sb_to_mdsc helper support to parse the mdsc (Jeff Layton) [1893177]
- [fs] ceph: drop special-casing for ITER_PIPE in ceph_sync_read (Jeff Layton) [1893177]
- [fs] ceph: add column 'mds' to show caps in more user friendly (Jeff Layton) [1893177]
- [include] libceph: multiple workspaces for CRUSH computations (Jeff Layton) [1893177]
- [fs] ceph: remove unnecessary return in switch statement (Jeff Layton) [1893177]
- [fs] ceph: encode inodes' parent/d_name in cap reconnect message (Jeff Layton) [1893177]
- [include] libceph: add __maybe_unused to DEFINE_CEPH_FEATURE (Jeff Layton) [1893177]
- [fs] ceph: use frag's MDS in either mode (Jeff Layton) [1893177]
- [fs] ceph: move sb->wb_pagevec_pool to be a global mempool (Jeff Layton) [1893177]
- [fs] ceph: remove redundant initialization of variable mds (Jeff Layton) [1893177]
- [fs] ceph: fix use-after-free for fsc->mdsc (Jeff Layton) [1893177]
- [fs] ceph: remove unused variables in ceph_mdsmap_decode() (Jeff Layton) [1893177]
- [fs] ceph: delete repeated words in fs/ceph/ (Jeff Layton) [1893177]
- [fs] ceph: send client provided metric flags in client metadata (Jeff Layton) [1893177]
- [fs] ceph: periodically send perf metrics to MDSes (Jeff Layton) [1893177]
- [fs] ceph: check the sesion state and return false in case it is closed (Jeff Layton) [1893177]
- [net] libceph: replace HTTP links with HTTPS ones (Jeff Layton) [1893177]
- [fs] ceph: remove unnecessary cast in kfree() (Jeff Layton) [1893177]
- [net] libceph: just have osd_req_op_init() return a pointer (Jeff Layton) [1893177]
- [fs] ceph: do not access the kiocb after aio requests (Jeff Layton) [1893177]
- [fs] ceph: clean up and optimize ceph_check_delayed_caps() (Jeff Layton) [1893177]
- [fs] ceph: fix potential mdsc use-after-free crash (Jeff Layton) [1893177]
- [fs] ceph: switch to WARN_ON_ONCE in encode_supported_features() (Jeff Layton) [1893177]
- [fs] ceph: add global total_caps to count the mdsc's total caps number (Jeff Layton) [1893177]
- [fs] ceph: add check_session_state() helper and make it global (Jeff Layton) [1893177]
- [net] libceph: dump class and method names on method calls (Jeff Layton) [1893177]
- [net] libceph: use target_copy() in send_linger() (Jeff Layton) [1893177]
- [fs] ceph: add metadata perf metric support (Jeff Layton) [1893177]
- [fs] ceph: add read/write latency metric support (Jeff Layton) [1893177]
- [fs] ceph: add caps perf metric for each superblock (Jeff Layton) [1893177]
- [fs] ceph: add dentry lease metric support (Jeff Layton) [1893177]
- [include] math64: New DIV64_U64_ROUND_CLOSEST helper (Jeff Layton) [1893177]
- [tty] tty: Fix ->pgrp locking in tiocspgrp() (Waiman Long) [1908197] {CVE-2020-29661}

* Mon Feb 15 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-288.el8]
- [mm] Revert "powerpc: Ensure that swiotlb buffer is allocated from low memory" (Diego Domingos) [1907131]
- [fs] xfs: use ENOTBLK for direct I/O to buffered I/O fallback (Carlos Maiolino) [1922953]
- [nvme] nvme-multipath: Early exit if no path is available (Gopal Tiwari) [1880508]
- [scsi] scsi: lpfc: Add support for eh_should_retry_cmd() (Ewan Milne) [1801585]
- [scsi] scsi: scsi_transport_fc: Add store capability to rport port_state in sysfs (Ewan Milne) [1801585]
- [scsi] scsi: scsi_transport_fc: Add a new rport state FC_PORTSTATE_MARGINAL (Ewan Milne) [1801585]
- [scsi] scsi: core: No retries on abort success (Ewan Milne) [1801585]
- [scsi] scsi: core: Add a new error code DID_TRANSPORT_MARGINAL in scsi.h (Ewan Milne) [1801585]
- [scsi] scsi: core: Add limitless cmd retry support (Ewan Milne) [1801585]
- [fs] gfs2: Fix deadlock between gfs2_{create_inode, inode_lookup} and delete_work_func (Andreas Grunbacher) [1903190]
- [fs] gfs2: Don't call cancel_delayed_work_sync from within delete work function (Andreas Grunbacher) [1903190]
- [cpufreq] acpi-cpufreq: Honor _PSD table setting on new AMD CPUs (Terry Bowman) [1886943]
- [x86] x86/cpufeatures: Enumerate TSX suspend load address tracking instructions (Josh Poimboeuf) [1836980]
- [powerpc] powerpc/pseries/svm: Allocate SWIOTLB buffer anywhere in memory (Diego Domingos) [1869184]
- [mm] powerpc: Ensure that swiotlb buffer is allocated from low memory (Diego Domingos) [1869184]
- [fs] debugfs: Fix module state check condition (Vladis Dronov) [1866285]
- [fs] debugfs: Check module state before warning in {full/open}_proxy_open() (Vladis Dronov) [1866285]

* Thu Feb 11 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-287.el8]
- [firmware] efi: Don't attempt to map RCI2 config table if it doesn't exist (Lenny Szubowicz) [1779590]
- [firmware] efi: Make CONFIG_EFI_RCI2_TABLE selectable on x86 only (Lenny Szubowicz) [1779590]
- [firmware] efi: Make unexported efi_rci2_sysfs_init() static (Lenny Szubowicz) [1779590]
- [iommu] iommu: use the __iommu_attach_device() directly for deferred attach (Lianbo Jiang) [1904658]
- [iommu] dma-iommu: use static-key to minimize the impact in the fast-path (Lianbo Jiang) [1904658]
- [x86] x86/PCI: sta2x11: use default DMA address translation (Jerry Snitselaar) [1887546]
- [powerpc] powerpc: use the generic dma_ops_bypass mode (Jerry Snitselaar) [1887546]
- [dma] dmaengine: fix error codes in channel_register() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: off by one in cleanup code (Jerry Snitselaar) [1837187]
- [documentation] dmaengine: idxd: Add ABI documentation for shared wq (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: Clean up descriptors with fault error (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: Add shared workqueue support (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: fix mapping of portal size (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: fix wq config registers offset programming (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: Allocate correct size for descriptor chunk (Jerry Snitselaar) [1837187]
- [uapi] dmaengine: idxd: add missing invalid flags field to completion (Jerry Snitselaar) [1837187]
- [uapi] dmaengine: idxd: fix hw descriptor fields for delta record (Jerry Snitselaar) [1837187]
- [uapi] dmaengine: idxd: Merge definition of dsa_batch_desc into dsa_hw_desc (Jerry Snitselaar) [1838386 1837187]
- [dma] dmaengine: dmatest: Return boolean result directly in filter() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Check list for emptiness before access its last entry (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: Make two symbols static (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Print error codes as signed value (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: add command status to idxd sysfs attribute (Jerry Snitselaar) [1893465 1837187]
- [dma] dmaengine: idxd: add support for configurable max wq batch size (Jerry Snitselaar) [1893468 1837187]
- [dma] dmaengine: idxd: add support for configurable max wq xfer size (Jerry Snitselaar) [1893468 1837187]
- [documentation] dmaengine: idxd: add leading / for sysfspath in ABI documentation (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: clear misc interrupt cause after read (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Prevent to run on misconfigured channel (Jerry Snitselaar) [1837187]
- [dma] dmaengine: acpi: Put the CSRT table after using it (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: reset states after device disable or reset (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: move idxd interrupt handling to mask instead of ignore (Jerry Snitselaar) [1872374 1837187]
- [dma] dmaengine: idxd: add work queue drain support (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: move submission to sbitmap_queue (Jerry Snitselaar) [1837187]
- [dma] dmaengine: cookie bypass for out of order completion (Jerry Snitselaar) [1838893 1837187]
- [dma] dmaengine: ioat setting ioat timeout as module parameter (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: stop completed threads when running without set channel (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: fix misc interrupt handler thread unmasking (Jerry Snitselaar) [1877126 1837187]
- [dma] dmaengine: idxd: cleanup workqueue config after disabling (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: fix cdev locking for open and release (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Replace zero-length array with flexible-array (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Fix doc strings to satisfy validation script (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Include dmaengine.h into dmaengine.c (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Describe members of struct dmatest_info (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Describe members of struct dmatest_params (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Allow negative timeout value to specify infinite wait (Jerry Snitselaar) [1837187]
- [dma] Revert "dmaengine: dmatest: timeout value of -1 should specify infinite wait" (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: adding missed issue_pending to timeout handler (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: remove unnesesery double complition timer modification (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: removing duplicate code from timeout handler (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: Decreasing allocation chunk size 2M->512K (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: fixing chunk sizing macros dependency (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: export hw version through sysfs (Jerry Snitselaar) [1838888 1837187]
- [dma] dmaengine: dmatest: Restore default for channel (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: fix interrupt completion after unmasking (Jerry Snitselaar) [1838895 1837187]
- [dma] dmaengine: dmatest: Fix process hang when reading 'wait' parameter (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Fix iteration non-stop logic (Jerry Snitselaar) [1837187]
- [dma] dmaengine: fix channel index enumeration (Jerry Snitselaar) [1838390 1837187]
- [include] include/linux/dmaengine: Typos fixes in API documentation (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: remove global token limit check (Jerry Snitselaar) [1838385 1837187]
- [dma] dmaengine: idxd: reflect shadow copy of traffic class programming (Jerry Snitselaar) [1838381 1837187]
- [dma] dmaengine: Create debug directories for DMA devices (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Add basic debugfs support (Jerry Snitselaar) [1837187]
- [include] dmaengine: consistently return string literal from switch-case (Jerry Snitselaar) [1837187]
- [include] dmaengine: Drop redundant 'else' keyword (Jerry Snitselaar) [1837187]
- [include] dmaengine: Use negative condition for better readability (Jerry Snitselaar) [1837187]
- [include] dmaengine: Refactor dmaengine_check_align() to be bit operations only (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: expose general capabilities register in sysfs (Jerry Snitselaar) [1837187 1836532]
- [dma] dmaengine: idxd: check return result from check_vma() in cdev (Jerry Snitselaar) [1837187 1836530]
- [dma] dmanegine: ioat/dca: Replace zero-length array with flexible-array member (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: remove set but not used variable 'idxd_cdev' (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: remove set but not used variable 'group' (Jerry Snitselaar) [1837187]
- [documentation] dmaengine: idxd: add sysfs ABI for idxd driver (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: fix off by one on cdev dwq refcount (Jerry Snitselaar) [1838366 1837187]
- [dma] dmaengine: idxd: wq size configuration needs to check global max size (Jerry Snitselaar) [1837187 1836579]
- [dma] dmaengine: idxd: sysfs input of wq incorrect wq type should return error (Jerry Snitselaar) [1837187 1836585]
- [dma] dmaengine: idxd: correct reserved token calculation (Jerry Snitselaar) [1837187 1836647]
- [dma] dmaengine: idxd: Fix error handling in idxd_wq_cdev_dev_setup() (Jerry Snitselaar) [1838354 1837187]
- [dma] dmaengine: idxd: fix runaway module ref count on device driver bind (Jerry Snitselaar) [1837187 1836649]
- [dma] dmaengine: idxd: fix boolconv.cocci warnings (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: add char driver to expose submission portal to userland (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: connect idxd to dmaengine subsystem (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: add descriptor manipulation routines (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: add configuration component of driver (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idxd: Init and probe for Intel data accelerators (Jerry Snitselaar) [1837187]
- [include] io-64-nonatomic: add io{read|write}64{_lo_hi|_hi_lo} macros (Jerry Snitselaar) [1837187]
- [powerpc] iomap: introduce io{read|write}64_{lo_hi|hi_lo} (Jerry Snitselaar) [1837187]
- [lib] iomap: Use non-raw io functions for io{read|write}XXbe (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: use vchan_vdesc_fini() to free descriptors (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: Add missing locking around list operations (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: Do not call desc_free() under a spin_lock (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: remove debug message (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: Add missing locking (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: Support in-use unbind (Jerry Snitselaar) [1837187]
- [dma] dmaengine: move .device_release missing log warning to debug level (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Cleanups for the slave <-> channel symlink support (Jerry Snitselaar) [1837187]
- [dma] dmaengine: fix null ptr check for __dma_async_device_channel_register() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Fix return value for dma_request_chan() in case of failure (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Create symlinks between DMA channels and slaves (Jerry Snitselaar) [1837187]
- [dma] dmaengine: add support to dynamic register/unregister of channels (Jerry Snitselaar) [1837187]
- [dma] dmaengine: break out channel registration (Jerry Snitselaar) [1837187]
- [x86] x86/asm: Carve out a generic movdir64b() helper for general usage (Jerry Snitselaar) [1837187]
- [x86] x86/asm: add iosubmit_cmds512() based on MOVDIR64B CPU instruction (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Move dma_get_{, any_}slave_channel() to private dmaengine.h (Jerry Snitselaar) [1837187]
- [include] dmaengine: Remove dma_request_slave_channel_compat() wrapper (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Remove dma_device_satisfies_mask() wrapper (Jerry Snitselaar) [1837187]
- [include] dmaengine: Add helper function to convert direction value to text (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Add support for reporting DMA cached data amount (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Add metadata_ops for dma_async_tx_descriptor (Jerry Snitselaar) [1837187]
- [dma] dmaengine: print more meaningful error message (Jerry Snitselaar) [1837187]
- [dma] dmaengine: move module_/dma_device_put() after route free (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Add reference counting to dma_device struct (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Move dma_channel_rebalance() infrastructure up in code (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Call module_put() after device_free_chan_resources() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Store module owner in dma_device struct (Jerry Snitselaar) [1837187]
- [include] dmaengine: Remove spaces before TABs (Jerry Snitselaar) [1837187]
- [dma] ioat: ioat_alloc_ring() failure handling (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: Fix access after free in vchan_complete() (Jerry Snitselaar) [1837187]
- [include] dmaengine: Fix access to uninitialized dma_slave_caps (Jerry Snitselaar) [1837187]
- [dma] dmanegine: ioat/dca: Use struct_size() helper (Jerry Snitselaar) [1837187]
- [dma] dmaengine: acpi: Add kernel doc parameter descriptions (Jerry Snitselaar) [1837187]
- [dma] dmaengine: acpi: Set up DMA mask based on CSRT (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Add support for completion polling (Jerry Snitselaar) [1837187]
- [dma] dmaengine: virt-dma: store result on dma descriptor (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: timeout value of -1 should specify infinite wait (Jerry Snitselaar) [1837187]
- [dma] dmaengine: Grammar s/the its/its/, s/need/needs/ (Jerry Snitselaar) [1837187]
- [dma] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 284 (Jerry Snitselaar) [1837187]
- [dma] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 291 (Jerry Snitselaar) [1837187]
- [dma] treewide: Add SPDX license identifier - Makefile/Kconfig (Jerry Snitselaar) [1837187]
- [dma] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jerry Snitselaar) [1837187]
- [dma] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 7 (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: move test data alloc & free into functions (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: add short-hand `buf_size` var in dmatest_func() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: wrap src & dst data into a struct (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Abort test in case of mapping error (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Add transfer_size parameter (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Add alignment parameter (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Use fixed point div to calculate iops (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: Add support for multi channel testing (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: fix a small memory leak in dmatest_func() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: move size checks earlier in function (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: use dmaengine_terminate_sync() instead (Jerry Snitselaar) [1837187]
- [dma] dmaengine: dmatest: unmap data on a single code-path when xfer done (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idma64: replace spin_lock_irqsave with spin_lock (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idma: remove dma_slave_config direction usage (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioat: fix prototype of ioat_enumerate_channels (Jerry Snitselaar) [1837187]
- [dma] dmaengine: ioatdma: set the completion address register after channel reset (Jerry Snitselaar) [1837187]
- [dma] dmaengine: idma64: Support dmaengine_terminate_sync() (Jerry Snitselaar) [1837187]
- [dma] dmaengine: add a new helper dmaenginem_async_device_register (Jerry Snitselaar) [1837187]
- [documentation] Documentation/x86: Add documentation for SVA (Shared Virtual Addressing) (Jerry Snitselaar) [1836777]
- [iommu] iommu/vt-d: Change flags type to unsigned int in binding mm (Jerry Snitselaar) [1836777]
- [drm] drm, iommu: Change type of pasid to u32 (Jerry Snitselaar) [1836777]
- [x86] x86/asm: Add an enqcmds() wrapper for the ENQCMDS instruction (Jerry Snitselaar) [1837187]
- [x86] x86/mmu: Allocate/free a PASID (Jerry Snitselaar) [1836777]
- [x86] x86/cpufeatures: Mark ENQCMD as disabled when configured out (Jerry Snitselaar) [1836777]
- [mm] mm: Add a pasid member to struct mm_struct (Jerry Snitselaar) [1836777]
- [x86] x86/msr-index: Define an IA32_PASID MSR (Jerry Snitselaar) [1836777]
- [x86] x86/fpu/xstate: Add supervisor PASID state for ENQCMD (Jerry Snitselaar) [1836777]
- [x86] x86/cpufeatures: Enumerate ENQCMD and ENQCMDS instructions (Jerry Snitselaar) [1836777]
- [x86] x86/fpu/xstate: Restore supervisor states for signal return (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Preserve supervisor states for the slow path in __fpu__restore_sig() (Jerry Snitselaar) [1837178]
- [x86] x86/fpu: Introduce copy_supervisor_to_kernel() (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Update copy_kernel_to_xregs_err() for supervisor states (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Update sanitize_restored_xstate() for supervisor xstates (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Define new functions for clearing fpregs and xstates (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Introduce XSAVES supervisor states (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Separate user and supervisor xfeatures mask (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Define new macros for supervisor and user xstates (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Rename validate_xstate_header() to validate_user_xstate_header() (Jerry Snitselaar) [1837178]
- [x86] copy_xstate_to_kernel: Fix typo which caused GDB regression (Jerry Snitselaar) [1837178]
- [x86] copy_xstate_to_kernel(): don't leave parts of destination uninitialized (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Warn when checking alignment of disabled xfeatures (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Fix XSAVES offsets in setup_xstate_comp() (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Fix last_good_offset in setup_xstate_features() (Jerry Snitselaar) [1837178]
- [x86] x86/fpu: Shrink space allocated for xstate_comp_offsets (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Make xfeature_is_supervisor()/xfeature_is_user() return bool (Jerry Snitselaar) [1837178]
- [x86] x86/fpu/xstate: Fix small issues (Jerry Snitselaar) [1837178]
- [x86] x86/fpu: Use XFEATURE_FP/SSE enum values instead of hardcoded numbers (Jerry Snitselaar) [1837178]
- [x86] x86/fpu: Use unsigned long long shift in xfeature_uncompacted_offset() (Jerry Snitselaar) [1837178]
- [iommu] iommu/vt-d: Fix sid not set issue in intel_svm_bind_gpasid() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix kernel NULL pointer dereference in find_domain() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: include conditionally on CONFIG_INTEL_IOMMU_SVM (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix misuse of ALIGN in qi_flush_piotlb() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Don't read VCCAP register unless it exists (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Add SMMUv3.2 range invalidation support (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Batch ATC invalidation commands (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Add command queue batching helpers (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Add sanity check for interrupt remapping table length macros (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix lockdep splat in iommu_flush_dev_iotlb() (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Restore IRTE.RemapEn bit for amd_iommu_activate_guest_mode (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Fix potential @entry null deref (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Handle 36bit addressing for x86-32 (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Do not use IOMMUv2 functionality when SME is active (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Do not force direct mapping when SME is active (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Use cmpxchg_double() when updating 128-bit IRTE (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Restore IRTE.RemapEn bit after programming IRTE (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix NULL pointer dereference in dev_iommu_priv_set() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Serialize IOMMU GCMD register modifications (Jerry Snitselaar) [1887546]
- [dma] dma-pool: Fix an uninitialized variable bug in atomic_pool_expand() (Jerry Snitselaar) [1887546]
- [dma] dma-pool: Only allocate from CMA when in same memory zone (Jerry Snitselaar) [1887546]
- [dma] dma-pool: fix coherent pool allocations for IOMMU mappings (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Move Kconfig and Makefile bits down into amd directory (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Move Kconfig and Makefile bits down into intel directory (Jerry Snitselaar) [1887546]
- [iommu] iommu: Add gfp parameter to io_pgtable_ops->map() (Jerry Snitselaar) [1887546]
- [iommu] iommu: Mark __iommu_map_sg() as static (Jerry Snitselaar) [1887546]
- [iommu] iommu: Tidy up Kconfig for SoC IOMMUs (Jerry Snitselaar) [1887546]
- [iommu] iommu: Make some functions static (Jerry Snitselaar) [1887546]
- [include] iommu: Move sg_table wrapper out of CONFIG_IOMMU_SUPPORT (Jerry Snitselaar) [1887546]
- [powerpc] powerpc/dma: Remove dev->archdata.iommu_domain (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Remove double zero check (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Rename intel-pasid.h to pasid.h (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add page response ops support (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Report page request faults for guest SVA (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add a helper to get svm and sdev for pasid (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Refactor device_to_iommu() helper (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Disable multiple GPASID-dev bind (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Warn on out-of-range invalidation address (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix devTLB flush for vSVA (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Handle non-page aligned address (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix PASID devTLB invalidation (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Remove global page support in devTLB flush (Jerry Snitselaar) [1887546]
- [include] iommu/vt-d: Enforce PASID devTLB field mask (Jerry Snitselaar) [1887546]
- [iommu] iommu: Remove unused IOMMU_SYS_CACHE_ONLY flag (Jerry Snitselaar) [1887546]
- [iommu] PCI/ATS: Add pci_pri_supported() to check device or associated PF (Jerry Snitselaar) [1887546]
- [pci] PCI: Treat "external-facing" devices themselves as internal (Jerry Snitselaar) [1887546]
- [documentation] docs: fix references for DMA*.txt files (Jerry Snitselaar) [1887546]
- [dma] dma-contiguous: cleanup dma_alloc_contiguous (Jerry Snitselaar) [1887546]
- [dma] dma-debug: use named initializers for dir2name (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: add a dma_ops_bypass flag to struct device (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: inline the fast path dma-direct calls (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: move the remaining DMA API calls out of line (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: don't BUG when calling dma_map_resource on RAM (Jerry Snitselaar) [1887546]
- [of] of: Allow the iommu-map property to omit untranslated devices (Jerry Snitselaar) [1887546]
- [iommu] treewide: Remove uninitialized_var() usage (Jerry Snitselaar) [1887546]
- [dma] dma-pool: do not allocate pool memory from CMA (Jerry Snitselaar) [1887546]
- [dma] dma-pool: make sure atomic pool suits device (Jerry Snitselaar) [1887546]
- [dma] dma-pool: introduce dma_guess_pool() (Jerry Snitselaar) [1887546]
- [dma] dma-pool: get rid of dma_in_atomic_pool() (Jerry Snitselaar) [1887546]
- [dma] dma-direct: provide function to check physical memory area validity (Jerry Snitselaar) [1887546]
- [documentation] docs: move DMA kAPI to Documentation/core-api (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: remove dma_mark_declared_memory_occupied (Jerry Snitselaar) [1887546]
- [documentation] docs: DMA-API-HOWTO.txt: fix an unmarked code block (Jerry Snitselaar) [1887546]
- [documentation] Documentation: DMA-API: fix a function name of max_mapping_size (Jerry Snitselaar) [1887546]
- [documentation] docs: DMA-API-HOWTO: add a missing "=" (Jerry Snitselaar) [1887546]
- [documentation] Documentation/DMA-API-HOWTO: update dma_mask sections (Jerry Snitselaar) [1887546]
- [documentation] Documentation/DMA-ISA-LPC: fix an incorrect reference (Jerry Snitselaar) [1887546]
- [documentation] Documentation: DMA-API: fix two typos (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: warn when coherent pool is depleted (Jerry Snitselaar) [1887546]
- [dma] dma-remap: align the size in dma_common_*_remap() (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: DMA_COHERENT_POOL should select GENERIC_ALLOCATOR (Jerry Snitselaar) [1887546]
- [dma] dma-direct: add missing set_memory_decrypted() for coherent mapping (Jerry Snitselaar) [1887546]
- [dma] dma-direct: check return value when encrypting or decrypting memory (Jerry Snitselaar) [1887546]
- [dma] dma-direct: re-encrypt memory if dma_direct_alloc_pages() fails (Jerry Snitselaar) [1887546]
- [dma] dma-direct: always align allocation size in dma_direct_alloc_pages() (Jerry Snitselaar) [1887546]
- [dma] dma-direct: mark __dma_direct_alloc_pages static (Jerry Snitselaar) [1887546]
- [dma] dma-direct: re-enable mmap for !CONFIG_MMU (Jerry Snitselaar) [1887546]
- [dma] dma-pool: decouple DMA_REMAP from DMA_COHERENT_POOL (Jerry Snitselaar) [1887546]
- [message] scsi: mptfusion: Don't use GFP_ATOMIC for larger DMA allocations (Jerry Snitselaar) [1887546]
- [dma] dma-pool: fix too large DMA pools on medium memory size systems (Jerry Snitselaar) [1887546]
- [iommu] treewide: replace '---help---' in Kconfig files with 'help' (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Make remove callback message more informative (Jerry Snitselaar) [1887546]
- [include] iommu: add generic helper for mapping sgtable objects (Jerry Snitselaar) [1887546]
- [dma] dma-contiguous: fix comment for dma_release_from_contiguous (Jerry Snitselaar) [1887546]
- [dma] dma-pool: scale the default DMA coherent pool size with memory capacity (Jerry Snitselaar) [1887546]
- [x86] x86/mm: unencrypted non-blocking DMA allocations use coherent pools (Jerry Snitselaar) [1887546]
- [dma] dma-pool: add pool sizes to debugfs (Jerry Snitselaar) [1887546]
- [dma] dma-direct: atomic allocations must come from atomic coherent pools (Jerry Snitselaar) [1887546]
- [dma] dma-pool: dynamically expanding atomic pools (Jerry Snitselaar) [1887546]
- [dma] dma-pool: add additional coherent pools to map to gfp mask (Jerry Snitselaar) [1887546]
- [dma] dma-remap: separate DMA atomic pools from direct remap code (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: use vmap insted of reimplementing it (Jerry Snitselaar) [1887546]
- [dma] dma-debug: make __dma_entry_alloc_check_leak() static (Jerry Snitselaar) [1887546]
- [dma] dma: debug: no need to check return value of debugfs_create functions (Jerry Snitselaar) [1887546]
- [dma] dma-debug: Batch dma_debug_entry allocation (Jerry Snitselaar) [1887546]
- [dma] dma/debug: Remove dma_debug_resize_entries() (Jerry Snitselaar) [1887546]
- [dma] dma-debug: Make leak-like behaviour apparent (Jerry Snitselaar) [1887546]
- [dma] dma-debug: Dynamically expand the dma_debug_entry pool (Jerry Snitselaar) [1887546]
- [dma] dma-debug: Use pr_fmt() (Jerry Snitselaar) [1887546]
- [dma] dma-debug: Expose nr_total_entries in debugfs (Jerry Snitselaar) [1887546]
- [dma] dma-debug: fix displaying of dma allocation type (Jerry Snitselaar) [1887546]
- [dma] dma-direct: fix data truncation in dma_direct_get_required_mask() (Jerry Snitselaar) [1887546]
- [dma] dma-direct: provide a arch_dma_clear_uncached hook (Jerry Snitselaar) [1887546]
- [dma] dma-direct: make uncached_kernel_address more general (Jerry Snitselaar) [1887546]
- [include] dma-direct: remove the cached_kernel_address hook (Jerry Snitselaar) [1887546]
- [dma] dma-direct: consolidate the error handling in dma_direct_alloc_pages (Jerry Snitselaar) [1887546]
- [dma] dma-coherent: fix integer overflow in the reserved-memory dma allocation (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix misuse of iommu_domain_identity_map() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Update scalable mode paging structure coherency (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Enable PCI ACS for platform opt in hint (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Set U/S bit in first level page table by default (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Make Intel SVM code 64-bit only (Jerry Snitselaar) [1887546]
- [arm64] arm64: Remove dev->archdata.iommu pointer (Jerry Snitselaar) [1887546]
- [x86] x86: Remove dev->archdata.iommu pointer (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Use dev_iommu_priv_get/set() (Jerry Snitselaar) [1887546]
- [iommu] iommu: Allow page responses without PASID (Jerry Snitselaar) [1887546]
- [iommu] iommu/iova: Don't BUG on invalid PFNs (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Add helper functions to update domain->pt_root (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Print extended features in one line to fix divergent log levels (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Make amd_iommu_apply_ivrs_quirks() static inline (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Move Intel IOMMU driver into subdirectory (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Move AMD IOMMU driver into subdirectory (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Remove redundant devid checks (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Store dev_data as device iommu private data (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Merge private header files (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Remove PD_DMA_OPS_MASK (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Consolidate domain allocation/freeing (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Free page-table in protection_domain_free() (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Allocate page-table in protection_domain_init() (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Let free_pagetable() not rely on domain->pt_root (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Unexport get_dev_data() (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Unify format of the printed messages (Jerry Snitselaar) [1887546]
- [iommu] iommu: Remove iommu_sva_ops::mm_exit() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Use pci_ats_supported() (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Use pci_ats_supported() (Jerry Snitselaar) [1887546]
- [iommu] iommu/amd: Use pci_ats_supported() (Jerry Snitselaar) [1887546]
- [pci] PCI/ATS: Only enable ATS for trusted devices (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Implement iommu_ops->def_domain_type call-back (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Don't reserve implementation defined register space (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: remove set but not used variable 'smmu' (Jerry Snitselaar) [1887546]
- [uapi] iommu/virtio: Fix sparse warning (Jerry Snitselaar) [1887546]
- [pci] PCI/ATS: Export symbols of PASID functions (Jerry Snitselaar) [1887546]
- [iommu] iommu/mediatek: Fix MTK_IOMMU dependencies (Jerry Snitselaar) [1887546]
- [iommu] iommu: spapr_tce: Disable compile testing to fix build on book3s_32 config (Jerry Snitselaar) [1887546]
- [iommu] iommu: Enable compile testing for some of drivers (Jerry Snitselaar) [1887546]
- [x86] x86: Hide the archdata.iommu field behind generic IOMMU_API (Jerry Snitselaar) [1887546]
- [iommu] iommu/hyper-v: Constify hyperv_ir_domain_ops (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix compile warning (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: fix a GCC warning (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Fix pointer cast warnings on 32 bit (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Remove IOVA handling code from the non-dma_ops path (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Remove duplicated check in intel_svm_bind_mm() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Remove redundant IOTLB flush (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add page request draining support (Jerry Snitselaar) [1887546 1847060]
- [iommu] iommu/vt-d: Disable non-recoverable fault processing before unbind (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: debugfs: Add support to show inv queue internals (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Multiple descriptors per qi_submit_sync() (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Replace intel SVM APIs with generic SVA APIs (Jerry Snitselaar) [1887546 1836578]
- [include] iommu/vt-d: Fix compile warning from intel-svm.h (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Report SVA feature with generic flag (Jerry Snitselaar) [1887546 1836578]
- [iommu] iommu/vt-d: Add custom allocator for IOASID (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Enlightened PASID allocation (Jerry Snitselaar) [1887546 1837167]
- [iommu] iommu/vt-d: Add svm/sva invalidate function (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Support flushing more translation cache types (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add bind guest PASID support (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add nested translation helper function (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Use a helper function to skip agaw for SL (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Move domain helper to header (Jerry Snitselaar) [1887546]
- [iommu] iommu: Remove functions that support private domain (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Unify format of the printed messages (Jerry Snitselaar) [1887546]
- [iommu] iommu: Introduce guest PASID bind function (Jerry Snitselaar) [1887546]
- [iommu] iommu: Introduce cache_invalidate API (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: debugfs: Add support to show page table internals (Jerry Snitselaar) [1887546 1835059]
- [iommu] iommu/vt-d: Use iova over first level (Jerry Snitselaar) [1887546 1837160]
- [iommu] iommu/vt-d: Update first level super page capability (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Make first level IOVA canonical (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Flush PASID-based iotlb for iova over first level (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Setup pasid entries for iova over first level (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add PASID_FLAG_FL5LP for first-level pasid setup (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add set domain DOMAIN_ATTR_NESTING attr (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Identify domains using first level page table (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Misc macro clean up for SVM (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add build dependency on IOASID (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Replace Intel specific PASID allocator with IOASID (Jerry Snitselaar) [1887546]
- [iommu] iommu/ioasid: Add custom allocators (Jerry Snitselaar) [1887546]
- [iommu] iommu: Add I/O ASID allocator (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Use right Kconfig option name (Jerry Snitselaar) [1887546]
- [iommu] iommu/vt-d: Add Kconfig option to enable/disable scalable mode (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Convert to probe/release_device() call-backs (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Reverse arguments to list_add (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Use accessor functions for iommu private data (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Reject IOMMU page granule larger than PAGE_SIZE (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Fix freeing of incomplete domains (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Build virtio-iommu as module (Jerry Snitselaar) [1887546]
- [iommu] iommu: virtio: Use generic_iommu_put_resv_regions() (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Remove unused variable (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Update to most recent specification (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Add event queue (Jerry Snitselaar) [1887546]
- [iommu] iommu/virtio: Add probe request (Jerry Snitselaar) [1887546]
- [iommu] iommu: Add virtio-iommu driver (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Remove duplicate error message (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Fix uninitilized variable warning (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Rename IOMMU_QCOM_SYS_CACHE and improve doc (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Restore naming of driver parameter prefix (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Use WRITE_ONCE() when changing validity of an STE (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Improve SMR mask test (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Fix IOVA validation for 32-bit (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Prepare for TTBR1 usage (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Rationalise VTCR handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Rename public #defines under ARM_SMMU_ namespace (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Rationalise TCR handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Ensure ARM_64_LPAE_S2_TCR_RES1 is unsigned (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Improve attribute handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Support non-coherent stage-2 page tables (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Fix -Wunused-const-variable warning (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Remove useless of_match_ptr() (Jerry Snitselaar) [1887546]
- [iommu] drivers/iommu: Initialise module 'owner' field in iommu_device_set_ops() (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Update my email address in MODULE_AUTHOR() (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Allow building as a module (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Unregister IOMMU and bus ops on device removal (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Allow building as a module (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Support SMMU module probing from the IORT (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu-v3: Unregister IOMMU and bus ops on device removal (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Prevent forced unbinding of Arm SMMU drivers (Jerry Snitselaar) [1887546]
- [iommu] Revert "iommu/arm-smmu: Make arm-smmu explicitly non-modular" (Jerry Snitselaar) [1887546]
- [iommu] Revert "iommu/arm-smmu: Make arm-smmu-v3 explicitly non-modular" (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Rationalise TTBRn handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Rationalise MAIR handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Simplify level indexing (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Simplify PGD size handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Simplify start level lookup (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Simplify bounds checks (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm: Rationalise size check (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable: Make selftest gubbins consistently __init (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Avoid pathological RPM behaviour for unmaps (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable: Move some initialization data to .init.rodata (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Report USF more clearly (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Remove arm_smmu_flush_ops (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Move .tlb_sync method to implementation (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Remove "leaf" indirection (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Remove .tlb_inv_range indirection (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm-v7s: Use ias/oas to check the valid iova/pa (Jerry Snitselaar) [1887546]
- [iommu] iommu/io-pgtable-arm-v7s: Add paddr_to_iopte and iopte_to_paddr helpers (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Ensure 64-bit I/O accessors are available on 32-bit CPU (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Make private implementation details static (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Add context init implementation hook (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Add reset implementation hook (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Add configuration implementation hook (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Move Secure access quirk to implementation (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: ioremap smmu mmio region before implementation init (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Add implementation infrastructure (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Rename arm-smmu-regs.h (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Abstract GR0 accesses (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Abstract context bank accesses (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Abstract GR1 accesses (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Get rid of weird "atomic" write (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Split arm_smmu_tlb_inv_range_nosync() (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Rework cb_base handling (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Convert context bank registers to bitfields (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Convert GR1 registers to bitfields (Jerry Snitselaar) [1887546]
- [iommu] iommu/arm-smmu: Convert GR0 registers to bitfields (Jerry Snitselaar) [1887546]
- [iommu] iommu: Remove IOMMU_OF_DECLARE (Jerry Snitselaar) [1887546]
- [iommu] iommu: Stop deferring probe at end of initcalls (Jerry Snitselaar) [1887546]
- [iommu] iommu: Fix use-after-free in iommu_release_device (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: Fix dma_pgprot() for unencrypted coherent pages (Jerry Snitselaar) [1887546]
- [x86] x86: Don't let pgprot_modify() change the page encryption bit (Jerry Snitselaar) [1887546]
- [x86] x86/PCI: Remove X86_DEV_DMA_OPS (Jerry Snitselaar) [1887546]
- [pci] PCI: vmd: Remove dma_map_ops overrides (Jerry Snitselaar) [1887546]
- [pci] x86/pci: Clean up usage of X86_DEV_DMA_OPS (Jerry Snitselaar) [1887546]
- [x86] x86/Kconfig: Remove the unused X86_DMA_REMAP KConfig symbol (Jerry Snitselaar) [1887546]
- [dma] dma-direct: avoid a forward declaration for phys_to_dma (Jerry Snitselaar) [1887546]
- [dma] dma-mapping: Add vmap checks to dma_map_single() (Jerry Snitselaar) [1887546]
- [x86] x86/platform/uv: Fix UV4 hub revision adjustment (Frank Ramsay) [1908507]
- [ata] ahci: Add Intel Rocket Lake PCH-H RAID PCI IDs (Steve Best) [1868308]

* Wed Feb 10 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-286.el8]
- [mfd] mfd: intel-lpss: Fix Intel Elkhart Lake LPSS I2C input clock (Steve Best) [1783586]
- [mfd] mfd: intel-lpss: Add Intel Elkhart Lake PCH PCI IDs (Steve Best) [1783586]
- [i2c] i2c: i801: Add support for Intel Elkhart Lake (Steve Best) [1783586]
- [fs] fuse: fix bad inode (Miklos Szeredi) [1906908]
- [fs] virtiofs: calculate number of scatter-gather elements accurately (Vivek Goyal) [1783467]
- [fs] virtiofs: add logic to free up a memory range (Vivek Goyal) [1783467]
- [fs] virtiofs: maintain a list of busy elements (Vivek Goyal) [1783467]
- [fs] virtiofs: serialize truncate/punch_hole and dax fault path (Vivek Goyal) [1783467]
- [fs] virtiofs: define dax address space operations (Vivek Goyal) [1783467]
- [fs] virtiofs: add DAX mmap support (Vivek Goyal) [1783467]
- [fs] virtiofs: implement dax read/write operations (Vivek Goyal) [1783467]
- [uapi] virtiofs: introduce setupmapping/removemapping commands (Vivek Goyal) [1783467]
- [fs] virtiofs: implement FUSE_INIT map_alignment field (Vivek Goyal) [1783467]
- [fs] virtiofs: keep a list of free dax memory ranges (Vivek Goyal) [1783467]
- [fs] virtiofs: add a mount option to enable dax (Vivek Goyal) [1783467]
- [fs] virtiofs: set up virtio_fs dax_device (Vivek Goyal) [1783467]
- [fs] virtiofs: get rid of no_mount_options (Vivek Goyal) [1783467]
- [fs] virtiofs: provide a helper function for virtqueue initialization (Vivek Goyal) [1783467]
- [fs] dax: Create a range version of dax_layout_busy_page() (Vivek Goyal) [1783467]
- [dax] dax: Modify bdev_dax_pgoff() to handle NULL bdev (Vivek Goyal) [1783467]
- [virtio] virtio: Implement get_shm_region for MMIO transport (Vivek Goyal) [1783467]
- [virtio] virtio: Implement get_shm_region for PCI transport (Vivek Goyal) [1783467]
- [include] virtio: Add get_shm_region method (Vivek Goyal) [1783467]
- [fs] virtiofs: do not use fuse_fill_super_common() for device installation (Vivek Goyal) [1783467]
- [uapi] fuse: reserve values for mapping protocol (Vivek Goyal) [1783467]
- [fs] virtiofs: Convert virtiofs to use new mount API (Vivek Goyal) [1783467]
- [fs] fuse: reject options on reconfigure via fsconfig(2) (Vivek Goyal) [1783467]
- [fs] fuse: ignore 'data' argument of mount(..., MS_REMOUNT) (Vivek Goyal) [1783467]
- [fs] fuse: use ->reconfigure() instead of ->remount_fs() (Vivek Goyal) [1783467]
- [fs] fuse: switch to use errorfc() et.al (Vivek Goyal) [1783467]
- [fs] fs_parse: fold fs_parameter_desc/fs_parameter_spec (Vivek Goyal) [1783467]
- [fs] fs_parser: remove fs_parameter_description name field (Vivek Goyal) [1783467]
- [fs] vfs: subtype handling moved to fuse (Vivek Goyal) [1783467]
- [fs] fuse: convert to use the new mount API (Vivek Goyal) [1783467]
- [lib] lib/zlib: fix inflating zlib streams on s390 (Philipp Rudo) [1908011]
- [scsi] scsi: ibmvfc: Set default timeout to avoid crash during migration (Diego Domingos) [1890710]
- [net] Bluetooth: Fix null pointer dereference in hci_event_packet() (Gopal Tiwari) [1921475]
- [tools] selftests: fix poll error in udpgro.sh (Hangbin Liu) [1922213]
- [net] mptcp: fix length of MP_PRIO suboption (Davide Caratti) [1923156]
- [powerpc] powerpc/sstep: Fix array out of bound warning (Desnes Augusto Nunes do Rosario) [1908739]
- [powerpc] powerpc/watchpoint: Workaround P10 DD1 issue with VSX-32 byte instructions (Desnes Augusto Nunes do Rosario) [1908739]
- [powerpc] powerpc/sstep: Add testcases for VSX vector paired load/store instructions (Desnes Augusto Nunes do Rosario) [1908739]
- [powerpc] powerpc/ppc-opcode: Add encoding macros for VSX vector paired instructions (Desnes Augusto Nunes do Rosario) [1908739]
- [powerpc] powerpc/sstep: Support VSX vector paired storage access instructions (Desnes Augusto Nunes do Rosario) [1908739]
- [powerpc] powerpc/sstep: Cover new VSX instructions under CONFIG_VSX (Desnes Augusto Nunes do Rosario) [1908739]
- [powerpc] powerpc/sstep: Emulate prefixed instructions only when CPU_FTR_ARCH_31 is set (Desnes Augusto Nunes do Rosario) [1908739]
- [net] fix setsockopt(SO_REUSEADDR) for MPTCP sockets (Paolo Abeni) [1922500]
- [net] net_sched: avoid shift-out-of-bounds in tcindex_set_parms() (Davide Caratti) [1917366]
- [net] net_sched: reject silly cell_log in qdisc_get_rtab() (Davide Caratti) [1917366]
- [net] sched: prevent invalid Scell_log shift count (Davide Caratti) [1917366]
- [net] netem: fix zero division in tabledist (Davide Caratti) [1917366]
- [net] protect tcf_block_unbind with block lock (Davide Caratti) [1917366]
- [pinctrl] pinctrl: intel: Add Intel Elkhart Lake pin controller support (Steve Best) [1783600]
- [fs] dlm: fix invalid cluster name warning (Alexander Aring) [1655771]
- [mm] arm64: acpi: Make apei_claim_sea() synchronise with APEI's irq work (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Fix doc warnings in iort.c (Al Stone) [1865698 1851555]
- [acpi] ACPI, APEI, Fix error return value in apei_map_generic_address() (Al Stone) [1865698 1851555]
- [acpi] ACPI: fan: Initialize performance state sysfs attribute (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Support Alder Lake (Al Stone) [1865698 1851555]
- [acpi] ACPI: button: Add DMI quirk for Medion Akoya E2228T (Al Stone) [1865698 1851555]
- [acpi] ACPI: Fix whitespace inconsistencies (Al Stone) [1865698 1851555]
- [acpi] ACPI: button: Drop no longer necessary Acer SW5-012 lid_init_state quirk (Al Stone) [1865698 1851555]
- [acpi] ACPI: dock: fix enum-conversion warning (Al Stone) [1865698 1851555]
- [acpi] ACPI: utils: remove unreachable breaks (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Add missing type casts in GPE register access code (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Add ACPI_DPTF Kconfig menu (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Fix participant driver names (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: remove comment regarding string _UID support (Al Stone) [1865698 1851555]
- [acpi] ACPI: reboot: Avoid racing after writing to ACPI RESET_REG (Al Stone) [1865698 1851555]
- [acpi] ACPI: debug: don't allow debugging when ACPI is disabled (Al Stone) [1865698 1851555]
- [dax] ACPI: HMAT: refactor hmat_register_target_device to hmem_register_device (Al Stone) [1865698 1851555]
- [acpi] x86/numa: add 'nohmat' option (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Update version to 20200925 Version 20200925 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Remove unnecessary semicolon (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Debugger: Add a new command: "ALL <NameSeg>" (Al Stone) [1865698 1851555]
- [acpi] ACPICA: iASL: Return exceptions for string-to-integer conversions (Al Stone) [1865698 1851555]
- [acpi] ACPICA: acpi_help: Update UUID list (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Add predefined names found in the SMBus sepcification (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Tree-wide: fix various typos and spelling mistakes (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Drop the repeated word "an" in a comment (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Add support for 64 bit risc-v compilation (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: PM: Drop ec_no_wakeup check from acpi_ec_dispatch_gpe() (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: PM: Flush EC work unconditionally after wakeup (Al Stone) [1865698 1851555]
- [acpi] ACPI: button: fix handling lid state changes when input device closed (Al Stone) [1865698 1851555]
- [acpi] ACPI: scan: Replace ACPI_DEBUG_PRINT() with pr_debug() (Al Stone) [1865698 1851555]
- [acpi] ACPI: memhotplug: Remove 'state' from struct acpi_memory_device (Al Stone) [1865698 1851555]
- [acpi] ACPI / extlog: Check for RDMSR failure (Al Stone) [1865698 1851555]
- [acpi] node: Add access1 class to represent CPU to memory characteristics (Al Stone) [1865698 1851555]
- [acpi] ACPI: HMAT: Fix handling of changes from ACPI 6.2 to ACPI 6.3 (Al Stone) [1865698 1851555]
- [acpi] ACPI: Let ACPI know we support Generic Initiator Affinity Structures (Al Stone) [1865698 1851555]
- [acpi] ACPI: Support Generic Initiator only domains (Al Stone) [1865698 1851555]
- [acpi] ACPI / NUMA: Add stub function for pxm_to_node() (Al Stone) [1865698 1851555]
- [acpi] virtio-mem: Allow to specify an ACPI PXM as nid (Al Stone) [1865698 1851555]
- [acpi] ACPI: battery: include linux/power_supply.h (Al Stone) [1865698 1851555]
- [acpi] ACPI: wakeup: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: video: Remove leftover ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: tiny-power-button: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: proc: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: PCI: Remove unused ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: event: Remove leftover ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: dock: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: debugfs: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: custom_method: Remove dead ACPICA debug code (Al Stone) [1865698 1851555]
- [acpi] ACPI: container: Remove leftover ACPICA debug functionality (Al Stone) [1865698 1851555]
- [acpi] ACPI: platform: Remove ACPI_MODULE_NAME() (Al Stone) [1865698 1851555]
- [acpi] ACPI: memhotplug: Remove leftover ACPICA debug functionality (Al Stone) [1865698 1851555]
- [acpi] ACPI: LPSS: Remove ACPI_MODULE_NAME() (Al Stone) [1865698 1851555]
- [acpi] ACPI: cmos_rtc: Remove leftover ACPI_MODULE_NAME() (Al Stone) [1865698 1851555]
- [acpi] ACPI: PCI: update kernel-doc line comments (Al Stone) [1865698 1851555]
- [acpi] PNP: ACPI: Fix missing-prototypes in acpi_pnp.c (Al Stone) [1865698 1851555]
- [acpi] ACPI: configfs: Add missing config_item_put() to fix refcount leak (Al Stone) [1865698 1851555]
- [acpi] ACPI: video: use ACPI backlight for HP 635 Notebook (Al Stone) [1865698 1851555]
- [acpi] ACPI: APD: Clean up header file include statements (Al Stone) [1865698 1851555]
- [acpi] ACPI: APD: Remove unnecessary APD_ADDR() macro stub (Al Stone) [1865698 1851555]
- [acpi] ACPI: APD: Remove ACPI_MODULE_NAME() (Al Stone) [1865698 1851555]
- [acpi] ACPI: APD: Remove flags from struct apd_device_desc (Al Stone) [1865698 1851555]
- [acpi] ACPI: APD: Add kerneldoc for properties in struct apd_device_desc (Al Stone) [1865698 1851555]
- [acpi] ACPI: Remove side effect of partly creating a node in acpi_get_node() (Al Stone) [1865698 1851555]
- [acpi] ACPI: Rename acpi_map_pxm_to_online_node() to pxm_to_online_node() (Al Stone) [1865698 1851555]
- [acpi] ACPI: Do not create new NUMA domains from ACPI static tables that are not SRAT (Al Stone) [1865698 1851555]
- [acpi] ACPI: Add out of bounds and numa_off protections to pxm_to_node() (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: Print more information when acpi_processor_evaluate_cst() fails (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Add PCH FIVR participant driver (Al Stone) [1865698 1851555]
- [acpi] PCI/ACPI: Add Ampere Altra SOC MCFG quirk (Al Stone) [1865698 1851555]
- [acpi] ACPI / APEI: Add a notifier chain for unknown (vendor) CPER records (Al Stone) [1865698 1851555]
- [acpi] ACPI / PMIC: Move TPS68470 OpRegion driver to drivers/acpi/pmic/ (Al Stone) [1865698 1851555]
- [acpi] ACPI / PMIC: Split out Kconfig and Makefile specific for ACPI PMIC (Al Stone) [1865698 1851555]
- [acpi] PCI/ACPI: Tone down missing MCFG message (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Make ACPICA use logical addresses of GPE blocks (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Change the type of acpi_os_map_generic_address() return value (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Add support for using logical addresses of GPE blocks (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Remove the unused inline functions (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Drop the unused @ops of iort_add_device_replay() (Al Stone) [1865698 1851555]
- [acpi] ACPI / LPSS: Save Cherry Trail PWM ctx registers only once (at activation) (Al Stone) [1865698 1851555]
- [acpi] ACPI / LPSS: Resume Cherry Trail PWM controller in no-irq phase (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Introduce special struct type for GPE register addresses (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Introduce acpi_hw_gpe_read() and acpi_hw_gpe_write() (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Validate GPE blocks at init time (Al Stone) [1865698 1851555]
- [acpi] ACPI: Export acpi_get_first_physical_node() to modules (Al Stone) [1865698 1851555]
- [kernel] rcu/tree: Export rcu_idle_{enter, exit} to modules (Al Stone) [1865698 1851555]
- [acpi] ACPI: GED: fix -Wformat (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: Fix build for ARCH_APICTIMER_STOPS_ON_C3 unset (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: Take over RCU-idle for C3-BM idle (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: Use CPUIDLE_FLAG_TLB_FLUSHED (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: Use CPUIDLE_FLAG_TIMER_STOP (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Prevent acpi_release_memory() from returning too early (Al Stone) [1865698 1851555]
- [acpi] ACPI: ioremap: avoid redundant rounding to OS page size (Al Stone) [1865698 1851555]
- [acpi] ACPI: SoC: APD: Check return value of acpi_dev_get_property() (Al Stone) [1865698 1851555]
- [acpi] ACPI: APD: Add a fmw property is_raven (Al Stone) [1865698 1851555]
- [include] ACPI: APD: Change name from ST to FCH (Al Stone) [1865698 1851555]
- [acpi] i2c: designware: Add device HID for Hygon I2C controller (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Add an input ID to acpi_dma_configure() (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Remove useless PCI bus walk (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Make iort_msi_map_rid() PCI agnostic (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Make iort_get_device_domain IRQ domain agnostic (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Make iort_match_node_callback walk the ACPI namespace for NC (Al Stone) [1865698 1851555]
- [acpi] ACPI: APEI: remove redundant assignment to variable rc (Al Stone) [1865698 1851555]
- [acpi] ACPI: NUMA: Remove the useless 'node >= MAX_NUMNODES' check (Al Stone) [1865698 1851555]
- [acpi] ACPI: NUMA: Remove the useless sub table pointer check (Al Stone) [1865698 1851555]
- [acpi] ACPI: tables: Remove the duplicated checks for acpi_parse_entries_array() (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Update version to 20200717 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Do not increment operation_region reference counts for field units (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Replace one-element array with flexible-array (Al Stone) [1865698 1851555]
- [acpi] ACPI: acpi_pad: initialize preferred_cpu (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Clean up the removal of unused memory mappings (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Use deferred unmapping in acpi_os_unmap_iomem() (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Use deferred unmapping in acpi_os_unmap_generic_address() (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Preserve memory opregion mappings (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Implement deferred unmapping of ACPI memory (Al Stone) [1865698 1851555]
- [acpi] ACPI: Use fallthrough pseudo-keyword (Al Stone) [1865698 1851555]
- [acpi] acpi: thermal: Don't call thermal_zone_device_is_enabled() (Al Stone) [1865698 1851555]
- [acpi] ACPI: fan: Fix Tiger Lake ACPI device ID (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Add battery participant for TigerLake (Al Stone) [1865698 1851555]
- [acpi] ACPI: tables: avoid relocations for table signature array (Al Stone) [1865698 1851555]
- [acpi] ACPI: PAD: Eliminate usage of uninitialized_var() macro (Al Stone) [1865698 1851555]
- [acpi] ACPI: sysfs: add newlines when printing module parameters (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: add newline when printing 'ec_event_clearing' module parameter (Al Stone) [1865698 1851555]
- [acpi] ACPI: sysfs: Fix pm_profile_attr type (Al Stone) [1865698 1851555]
- [acpi] ACPI: property: use cached name in acpi_fwnode_get_named_child_node() (Al Stone) [1865698 1851555]
- [acpi] sched,acpi_pad: Convert to sched_set_fifo*() (Al Stone) [1865698 1851555]
- [acpi] ACPI: PM: Avoid using power resources if there are none for D0 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Update version to 20200528 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: iASL: add new OperationRegion subtype keyword PlatformRtMechanism (Al Stone) [1865698 1851555]
- [acpi] ACPI: CPPC: Fix reference count leak in acpi_cppc_processor_probe() (Al Stone) [1865698 1851555]
- [acpi] ACPI: sysfs: Fix reference count leak in acpi_sysfs_add_hotplug_profile() (Al Stone) [1865698 1851555]
- [acpi] ACPI: GED: use correct trigger type field in _Exx / _Lxx handling (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Remove the unused __get_pci_rid() (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: PM: s2idle: Extend GPE dispatching debug message (Al Stone) [1865698 1851555]
- [acpi] ACPI: PM: s2idle: Print type of wakeup debug messages (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Add battery participant driver (Al Stone) [1865698 1851555]
- [acpi] ACPI: DPTF: Additional sysfs attributes for power participant driver (Al Stone) [1865698 1851555]
- [acpi] ACPI: video: Use native backlight on Acer TravelMate 5735Z (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: Fix PMCG node single ID mapping handling (Al Stone) [1865698 1851555]
- [acpi] ACPI: APEI: Kick the memory_failure() queue for synchronous errors (Al Stone) [1865698 1851555]
- [mm] mm/memory-failure: Add memory_failure_queue_kick() (Al Stone) [1865698 1851555]
- [acpi] ACPI: IORT: Add comments for not calling acpi_put_table() (Al Stone) [1865698 1851555]
- [acpi] ACPI: GTDT: Put GTDT table after parsing (Al Stone) [1865698 1851555]
- [acpi] ACPI / PMIC: Add i2c address for thermal control (Al Stone) [1865698 1851555]
- [acpi] ACPI: GED: add support for _Exx / _Lxx handler methods (Al Stone) [1865698 1851555]
- [acpi] ACPI: Delete unused proc filename macros (Al Stone) [1865698 1851555]
- [acpi] ACPI: IORT: Add extra message "applying workaround" for off-by-1 issue (Al Stone) [1865698 1851555]
- [acpi] ACPI: utils: Add acpi_evaluate_reg() helper (Al Stone) [1865698 1851555]
- [acpi] ACPI: debug: Make two functions static (Al Stone) [1865698 1851555]
- [acpi] ACPI: sleep: Put the FACS table after using it (Al Stone) [1865698 1851555]
- [acpi] ACPI: scan: Put SPCR and STAO table after using it (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Put the ACPI table after using it (Al Stone) [1865698 1851555]
- [acpi] ACPI: APEI: Put the HEST table for error path (Al Stone) [1865698 1851555]
- [acpi] ACPI: APEI: Put the error record serialization table for error path (Al Stone) [1865698 1851555]
- [acpi] ACPI: APEI: Put the error injection table for error path and module exit (Al Stone) [1865698 1851555]
- [acpi] ACPI: APEI: Put the boot error record table after parsing (Al Stone) [1865698 1851555]
- [acpi] ACPI: watchdog: Put the watchdog action table after parsing (Al Stone) [1865698 1851555]
- [acpi] ACPI: LPIT: Put the low power idle table after using it (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Update version to 20200430 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Fix required parameters for _NIG and _NIH (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Dispatcher: add status checks (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Disassembler: ignore AE_ALREADY_EXISTS status when parsing create operators (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Move acpi_gbl_next_cmd_num definition to acglobal.h (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Make acpi_protocol_lengths static (Al Stone) [1865698 1851555]
- [acpi] ACPI/IORT: work around num_ids ambiguity (Al Stone) [1865698 1851555]
- [acpi] Revert "ACPI/IORT: Fix 'Number of IDs' handling in iort_id_map()" (Al Stone) [1865698 1851555]
- [pci] PCI: Constify struct pci_ecam_ops (Al Stone) [1865698 1851555]
- [acpi] PM: ACPI: Output correct message on target power state (Al Stone) [1865698 1851555]
- [acpi] ACPI: CPPC: Make some symbols static (Al Stone) [1865698 1851555]
- [acpi] ACPI: processor: idle: Allow probing on platforms with one ACPI C-state (Al Stone) [1865698 1851555]
- [documentation] PM: sleep: core: Rename DPM_FLAG_LEAVE_SUSPENDED (Al Stone) [1865698 1851555]
- [acpi] PM: sleep: core: Rename dev_pm_smart_suspend_and_suspended() (Al Stone) [1865698 1851555]
- [acpi] PM: sleep: core: Rename dev_pm_may_skip_resume() (Al Stone) [1865698 1851555]
- [acpi] PM: sleep: core: Rework the power.may_skip_resume handling (Al Stone) [1865698 1851555]
- [acpi] PM: sleep: core: Do not skip callbacks in the resume phase (Al Stone) [1865698 1851555]
- [base] PM: sleep: core: Switch back to async_schedule_dev() (Al Stone) [1865698 1851555]
- [base] PM: sleep: core: Fold functions into their callers (Al Stone) [1865698 1851555]
- [base] PM: sleep: core: Simplify the SMART_SUSPEND flag handling (Al Stone) [1865698 1851555]
- [base] PM: sleep: core: Use built-in RCU list checking (Al Stone) [1865698 1851555]
- [base] PM: core: Fix handling of devices deleted during system-wide resume (Al Stone) [1865698 1851555]
- [base] PM: sleep: Drop dpm_noirq_begin() and dpm_noirq_end() (Al Stone) [1865698 1851555]
- [kernel] PM: sleep: Integrate suspend-to-idle with generig suspend flow (Al Stone) [1865698 1851555]
- [base] PM: sleep: Drop dev_pm_skip_next_resume_phases() (Al Stone) [1865698 1851555]
- [acpi] ACPI: button: Drop no longer necessary Asus T200TA lid_init_state quirk (Al Stone) [1865698 1851555]
- [acpi] ACPI/PCI: pci_link: use extended_irq union member when setting ext-irq shareable (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Fix up fast path check in acpi_ec_add() (Al Stone) [1865698 1851555]
- [x86] ACPI, x86/boot: make acpi_nobgrt static (Al Stone) [1865698 1851555]
- [x86] acpi/x86: add a kernel parameter to disable ACPI BGRT (Al Stone) [1865698 1851555]
- [acpi] x86: ACPI: fix CPU hotplug deadlock (Al Stone) [1865698 1851555]
- [x86] acpi/x86: ignore unspecified bit positions in the ACPI global lock field (Al Stone) [1865698 1851555]
- [x86] x86/acpi: make "asmlinkage" part first thing in the function definition (Al Stone) [1865698 1851555]
- [x86] x86/ACPI/sleep: Move acpi_get_wakeup_address() into sleep.c, remove <asm/realmode.h> from <asm/acpi.h> (Al Stone) [1865698 1851555]
- [x86] x86/ACPI/sleep: Remove an unnecessary include of asm/realmode.h (Al Stone) [1865698 1851555]
- [x86] x86/efi: Explicitly include realmode.h to handle RM trampoline quirk (Al Stone) [1865698 1851555]
- [acpi] ACPI: video: Use native backlight on Acer Aspire 5783z (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Update version 20200326 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Fixes for acpiExec namespace init file (Al Stone) [1865698 1851555]
- [acpi] ACPICA: WSMT: Fix typo, no functional change (Al Stone) [1865698 1851555]
- [acpi] ACPICA: utilities: fix sprintf() (Al Stone) [1865698 1851555]
- [acpi] ACPICA: acpiexec: remove redeclaration of acpi_gbl_db_opt_no_region_support (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Change PlatformCommChannel ASL keyword to PCC (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Fix IVRS IVHD type 10h reserved field name (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Implement IVRS IVHD type 11h parsing (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Fix a typo in a comment field (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Update version to 20200214 (Al Stone) [1865698 1851555]
- [acpi] ACPI: CPPC: clean up acpi_get_psd_map() (Al Stone) [1865698 1851555]
- [acpi] ACPI: PCI: Use scnprintf() for avoiding potential buffer overflow (Al Stone) [1865698 1851555]
- [acpi] ACPI: fan: Use scnprintf() for avoiding potential buffer overflow (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Eliminate EC_FLAGS_QUERY_HANDSHAKE (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add() (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Simplify acpi_ec_ecdt_start() and acpi_ec_init() (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Consolidate event handler installation code (Al Stone) [1865698 1851555]
- [acpi] ACPI: list_for_each_safe() -> list_for_each_entry_safe() (Al Stone) [1865698 1851555]
- [acpi] ACPI: video: remove redundant assignments to variable result (Al Stone) [1865698 1851555]
- [acpi] ACPI: OSL: Add missing __acquires/__releases annotations (Al Stone) [1865698 1851555]
- [acpi] ACPI / battery: Cleanup Lenovo Ideapad Miix 320 DMI table entry (Al Stone) [1865698 1851555]
- [acpi] ACPI / AC: Cleanup DMI quirk table (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Use fast path in acpi_ec_add() for DSDT boot EC (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Simplify acpi_ec_add() (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Drop AE_NOT_FOUND special case from ec_install_handlers() (Al Stone) [1865698 1851555]
- [acpi] ACPI: EC: Avoid passing redundant argument to functions (Al Stone) [1865698 1851555]
- [include] ACPI: NUMA: Up-level "map to online node" functionality (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Fix a couple of typos (Al Stone) [1865698 1851555]
- [acpi] ACPICA: use acpi_size instead of u32 for prefix_path_length (Al Stone) [1865698 1851555]
- [acpi] ACPICA: cast length arguement to acpi_ns_build_normalized_path() as u32 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: cast the result of the pointer difference to u32 (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Table Manager: Update comments in a function header (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Enable sleep button on ACPI legacy wake (Al Stone) [1865698 1851555]
- [acpi] ACPICA: Fix a comment "enable" fixed events -> "disable" all fixed events (Al Stone) [1865698 1851555]
- [acpi] ACPICA: ASL-ASL+ converter: make root file a parameter for cv_init_file_tree (Al Stone) [1865698 1851555]
- [acpi] ACPICA: ASL-ASL+ converter: remove function parameters from cv_init_file_tree() (Al Stone) [1865698 1851555]
- [acpi] ACPI: Add new tiny-power-button driver to directly signal init (Al Stone) [1865698 1851555]
- [acpi] ACPI: button: move HIDs to acpi/button.h (Al Stone) [1865698 1851555]
- [acpi] ACPI: treewide: remove redundant IS_ERR() before error code check (Al Stone) [1865698 1851555]
- [dma] dmaengine: idma64: Use actual device for DMA transfers (Steve Best) [1784118]
- [platform] platform/x86: dell-smbios-wmi: Correct a memory leak (David Arcari) [1898516]
- [x86] x86/{mce,mm}: Unmap the entire page if the whole page is affected and poisoned (Aristeu Rozanski) [1850800]

* Tue Feb 09 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-285.el8]
- [x86] kvm: x86: fix CPUID entries returned by KVM_GET_CPUID2 ioctl (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: use kvm_complete_insn_gp in emulating RDMSR/WRMSR (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: remove bogus #GP injection (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: de-allocate svm_cpu_data for all cpus in svm_cpu_uninit() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: Fix split-irqchip vs interrupt injection window request (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: handle !lapic_in_kernel case in kvm_cpu_*_extint (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: fix error return code in svm_create_vcpu() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: Fix offset computation bug in __sev_dbg_decrypt() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Use cpuid to determine max gfn (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: mmu: Fix SPTE encoding of MMIO generation upper half (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: nvmx: Sync unsync'd vmcs02 state to vmcs12 on migration (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: tracing: Fix unmatched kvm_entry and kvm_exit events (Paolo Bonzini) [1904054 1906893 1904128]
- [documentation] kvm: documentation: Update description of KVM_{GET, CLEAR}_DIRTY_LOG (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: get smi pending status correctly (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/pmu: Fix HW_REF_CPU_CYCLES event pseudo-encoding in intel_arch_events[] (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/pmu: Fix UBSAN shift-out-of-bounds warning in intel_pmu_refresh() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: Add more protection against undefined behavior in rsvd_bits() (Paolo Bonzini) [1904054 1906893 1904128]
- [documentation] kvm: documentation: Fix spec for KVM_CAP_ENABLE_CAP_VM (Paolo Bonzini) [1904054 1906893 1904128]
- [documentation] kvm: Forbid the use of tagged userspace addresses for memslots (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: allow KVM_REQ_GET_NESTED_STATE_PAGES outside guest mode for VMX (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: nsvm: cancel KVM_REQ_GET_NESTED_STATE_PAGES on nested vmexit (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: nsvm: mark vmcb as dirty when forcingly leaving the guest mode (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: nsvm: correctly restore nested_run_pending on migration (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Clarify TDP MMU page list invariants (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Ensure TDP MMU roots are freed after yield (Paolo Bonzini) [1904054 1906893 1904128]
- [security] apparmor: remove duplicate macro list_entry_is_head() (Paolo Bonzini) [1904054 1906893 1904128]
- [kernel] linux/list.h: add a macro to test if entry is pointing to the head (Paolo Bonzini) [1904054 1906893 1904128]
- [virt] kvm: check tlbs_dirty directly (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: change in pv_eoi_get_pending() to make code more readable (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: fix shift out of bounds reported by UBSAN (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Optimize not-present/MMIO SPTE check in get_mmio_spte() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Use raw level to index into MMIO walks' sptes array (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Get root level from walkers when retrieving MMIO SPTE (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Use -1 to flag an undefined spte in get_mmio_spte() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: Remove the call to sev_platform_status() during setup (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: Don't flush cache if hardware enforces cache coherency across encryption domains (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] cpu: Add hardware-enforced cache coherency as a CPUID feature (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] Remove X86_FEATURE_MFENCE_RDTSC (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: reinstate vendor-agnostic check on SPEC_CTRL cpuid bits (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm/vmx: Use TEST REG, REG instead of CMP $0, REG in vmenter.S (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: ignore SIPIs that are received while not in wait-for-sipi state (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: nsvm: set fixed bits by hand (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Add TDP MMU SPTE changed trace point (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86/mmu: Add existing trace points to TDP MMU (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: check CR4 changes against vcpu->arch (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: adjust SEV for commit 7e8e6eed75e (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: Move asid to vcpu_svm (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: remove unused macro HV_CLOCK_SIZE (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: Sink cpuid update into vendor-specific set_cr4 functions (Paolo Bonzini) [1904054 1906893 1904128]
- [virt] kvm: remove kvm_clear_guest_page (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: Don't track dirty for KVM_SET_[TSS_ADDR|IDENTITY_MAP_ADDR] (Paolo Bonzini) [1904054 1906893 1904128]
- [tools] kvm: selftests: test KVM_GET_SUPPORTED_HV_CPUID as a system ioctl (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: hyper-v: allow KVM_GET_SUPPORTED_HV_CPUID as a system ioctl (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: emulate wait-for-SIPI and SIPI-VMExit (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: fix apic_accept_events vs check_nested_events (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: Return bool instead of int for CR4 and SREGS validity checks (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: x86: Move vendor CR4 validity check to dedicated kvm_x86_ops hook (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: svm: Drop VMXE check from svm_set_cr4() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: vmx: Drop explicit 'nested' check from vmx_set_cr4() (Paolo Bonzini) [1904054 1906893 1904128]
- [x86] kvm: vmx: Drop guest CPUID check for VMXE in vmx_set_cr4() (Paolo Bonzini) [1904054 1906893 1904128]
- [netdrv] net/mlx5e: Update max_opened_tc also when channels are closed (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5: Fix leak upon failure of rule creation (Alaa Hleihel) [1918379 1914766]
- [netdrv] net/mlx5: Fix function calculation for page trees (Alaa Hleihel) [1918379]
- [infiniband] RDMA/mlx5: Allow creating all QPs even when non RDMA profile is used (Alaa Hleihel) [1918379]
- [netdrv] mlx5: Mark BlueField-3 as unsupported device (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5: Update the list of the PCI supported devices (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5: Enable host PF HCA after eswitch is initialized (Alaa Hleihel) [1923760 1918379]
- [netdrv] net/mlx5: Rename peer_pf to host_pf (Alaa Hleihel) [1923760 1918379]
- [netdrv] net/mlx5: Make API mlx5_core_is_ecpf accept const pointer (Alaa Hleihel) [1923760 1918379]
- [netdrv] net/mlx5: simplify the return expression of mlx5_ec_init() (Alaa Hleihel) [1918379]
- [infiniband] IB/mlx5: Add mutex destroy call to cap_mask_mutex mutex (Alaa Hleihel) [1918379]
- [infiniband] RDMA/mlx5: Use strict get/set operations for obj_id (Alaa Hleihel) [1918379]
- [infiniband] RDMA/mlx5: Use the correct obj_id upon DEVX TIR creation (Alaa Hleihel) [1918379]
- [include] net/mlx5: Expose ifc bits for query modify header (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5: CT: Fix incorrect removal of tuple_nat_node from nat rhashtable (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Revert parameters on errors when changing MTU and LRO state without reset (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Revert parameters on errors when changing trust state without reset (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Correctly handle changing the number of queues when the interface is down (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Fix CT rule + encap slow path offload and deletion (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Disable hw-tc-offload when MLX5_CLS_ACT config is disabled (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5: Maintain separate page trees for ECPF and PF functions (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Fix IPSEC stats (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Reduce tc unsupported key print level (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: free page before return (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: E-switch, Fix rate calculation for overflow (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5: Fix memory leak on flow table creation error flow (Alaa Hleihel) [1918379]
- [infiniband] Revert "RDMA/mlx5: Fix devlink deadlock on net namespace deletion" (Alaa Hleihel) [1918379]
- [infiniband] RDMA/mlx5: Fix wrong free of blue flame register on error (Alaa Hleihel) [1918379]
- [infiniband] IB/mlx5: Fix error unwinding when set_has_smi_cap fails (Alaa Hleihel) [1918379]
- [netdrv] net/mlx5e: Add missing capability check for uplink follow (Alaa Hleihel) [1918379]
- [netdrv] iavf: Use kzalloc for allocating only one thing (Stefan Assmann) [1838735]
- [netdrv] iavf: fix double-release of rtnl_lock (Stefan Assmann) [1838735]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Stefan Assmann) [1838735]
- [netdrv] iavf: Fix updating statistics (Stefan Assmann) [1838735]
- [netdrv] iavf: fix error return code in iavf_init_get_resources() (Stefan Assmann) [1838735]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Stefan Assmann) [1838735]
- [netdrv] net/intel: remove driver versions from Intel drivers (Stefan Assmann) [1838735]
- [net] Bluetooth: Fix null pointer dereference in amp_read_loc_assoc_final_data (Gopal Tiwari) [1916057]
- [fs] fs/fs-writeback.c: fix kernel-doc warning (Waiman Long) [1918047]
- [include] memcg: only record foreign writebacks with dirty pages when memcg is not disabled (Waiman Long) [1918047]
- [trace] writeback: don't access page->mapping directly in track_foreign_dirty TP (Waiman Long) [1918047]
- [fs] writeback: add tracepoints for cgroup foreign writebacks (Waiman Long) [1918047]
- [mm] writeback, memcg: Implement foreign dirty flushing (Waiman Long) [1918047]
- [mm] mm: remove the account_page_dirtied export (Waiman Long) [1918047]
- [fs] writeback, memcg: Implement cgroup_writeback_by_id() (Waiman Long) [1918047]
- [mm] writeback: Separate out wb_get_lookup() from wb_get_create() (Waiman Long) [1918047]
- [include] bdi: Add bdi->id (Waiman Long) [1918047]
- [mm] mm/page-writeback: introduce tracepoint for wait_on_page_writeback() (Waiman Long) [1918047]
- [fs] kernfs: fix barrier usage in __kernfs_new_node() (Waiman Long) [1918047]
- [fs] kernfs: Allocating memory for kernfs_iattrs with kmem_cache (Waiman Long) [1918047]
- [fs] fs: Convert writeback to XArray (Waiman Long) [1918047]
- [mm] mm: Convert page-writeback to XArray (Waiman Long) [1918047]
- [mm] mm/filemap: add missing mem_cgroup_uncharge() to __add_to_page_cache_locked() (Waiman Long) [1917681]
- [mm] mm/slub: fix panic in slab_alloc_node() (Oleksandr Natalenko) [1921056]
- [net] xfrm: interface: fix the priorities for ipip and ipv6 tunnels (Sabrina Dubroca) [1923269]
- [net] netfilter: ipset: fix shift-out-of-bounds in htable_bits() (Antoine Tenart) [1918684]
- [net] tcp: refine tcp_pacing_delay() for very low pacing rates (Antoine Tenart) [1905897]
- [net] ensure correct skb->tstamp in various fragmenters (Antoine Tenart) [1905897]
- [net] tcp: repaired skbs must init their tso_segs (Antoine Tenart) [1905897]
- [net] tcp: address problems caused by EDT misshaps (Antoine Tenart) [1905897]
- [net] net_sched: sch_fq: ensure maxrate fq parameter applies to EDT flows (Antoine Tenart) [1905897]
- [net] tcp: refine tcp_tso_should_defer() after EDT adoption (Antoine Tenart) [1905897]
- [net] tcp_bbr: update comments to reflect pacing_margin_percent (Antoine Tenart) [1905897]
- [net] tcp: add tcp_reset_xmit_timer() helper (Antoine Tenart) [1905897]
- [net] tcp: fix TCP_REPAIR xmit queue setup (Antoine Tenart) [1905897]
- [net] tcp_bbr: adjust TCP BBR for departure time pacing (Antoine Tenart) [1905897]
- [net] tcp_bbr: fix typo in bbr_pacing_margin_percent (Antoine Tenart) [1905897]
- [net] tcp: optimize tcp internal pacing (Antoine Tenart) [1905897]
- [net] net_sched: sch_fq: no longer use skb_is_tcp_pure_ack() (Antoine Tenart) [1905897]
- [net] tcp: mitigate scheduling jitter in EDT pacing model (Antoine Tenart) [1905897]
- [net] tcp: do not change tcp_wstamp_ns in tcp_mstamp_refresh (Antoine Tenart) [1905897]
- [net] tcp/fq: move back to CLOCK_MONOTONIC (Antoine Tenart) [1905897]
- [net] tcp: switch tcp_internal_pacing() to tcp_wstamp_ns (Antoine Tenart) [1905897]
- [net] tcp: switch tcp and sch_fq to new earliest departure time model (Antoine Tenart) [1905897]
- [net] tcp: switch internal pacing timer to CLOCK_TAI (Antoine Tenart) [1905897]
- [net] tcp: provide earliest departure time in skb->tstamp (Antoine Tenart) [1905897]
- [net] tcp: add tcp_wstamp_ns socket field (Antoine Tenart) [1905897]
- [net] net_sched: sch_fq: switch to CLOCK_TAI (Antoine Tenart) [1905897]
- [net] tcp: introduce tcp_skb_timestamp_us() helper (Antoine Tenart) [1905897]
- [net] tcp: switch tcp_clock_ns() to CLOCK_TAI base (Antoine Tenart) [1905897]
- [drm] drm/nouveau/disp/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/dmaobj/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/i2c/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/gpio/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/bar/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/mmu/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/timer/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/fb/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/imem/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/privring/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/mc/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/devinit/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/bios/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/pci/ga10: initial support (Ben Skeggs) [1916583]
- [drm] drm/nouveau/core: recognise GA10 (Ben Skeggs) [1916583]
- [drm] drm/nouveau/kms/nv50-: fix case where notifier buffer is at offset 0 (Ben Skeggs) [1916583]
- [drm] drm/nouveau/mmu: fix vram heap sizing (Ben Skeggs) [1916583]
- [drm] drm/nouveau/i2c/gm200: increase width of aux semaphore owner fields (Ben Skeggs) [1916583]
- [drm] drm/nouveau/i2c/gk110-: disable hw-initiated dpcd reads (Ben Skeggs) [1916583]
- [drm] drm/nouveau/i2c/gk110: split out from i2c/gk104 (Ben Skeggs) [1916583]
- [drm] drm/nouveau/privring: ack interrupts the same way as RM (Ben Skeggs) [1916583]
- [drm] drm/nouveau/bios: fix issue shadowing expansion ROMs (Ben Skeggs) [1916583]
- [netdrv] net/mlx5e: Fix memleak in mlx5e_create_l2_table_groups (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5e: Fix two double free cases (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5e: ethtool, Fix restriction of autoneg with 56G (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5e: In skb build skip setting mark in switchdev mode (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5: E-Switch, fix changing vf VLANID (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5e: Fix SWP offsets when vlan inserted by driver (Alaa Hleihel) [1899457 1819580]
- [netdrv] net/mlx5: Use port_num 1 instead of 0 when delete a RoCE address (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5: Check if lag is supported before creating one (Alaa Hleihel) [1899457]
- [infiniband] RDMA/mlx5: Fix MR cache memory leak (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5: Fix passing zero to 'PTR_ERR' (Alaa Hleihel) [1899457]
- [netdrv] net/mlx5e: remove unnecessary memset (Alaa Hleihel) [1899457]
- [infiniband] RDMA/mlx5: Assign dev to DM MR (Alaa Hleihel) [1899457]
- [infiniband] RDMA/mlx5: Remove mlx5_ib_mr->npages (Alaa Hleihel) [1899457]
- [documentation] scsi: fc: Update documentation of sysfs nodes for FPIN stats (Ewan Milne) [1859967]
- [scsi] scsi: fc: Add mechanism to update FPIN signal statistics (Ewan Milne) [1859967]
- [scsi] scsi: fc: Parse FPIN packets and update statistics (Ewan Milne) [1859967]
- [scsi] scsi: fc: Add FPIN statistics to fc_host and fc_rport objects (Ewan Milne) [1859967]
- [uapi] scsi: fc: Update formal FPIN descriptor definitions (Ewan Milne) [1859967]
- [scsi] scsi: smartpqi: Update version to 1.2.16-012 (Don Brace) [1890727 1889844]
- [scsi] scsi: smartpqi: Correct pqi_sas_smp_handler busy condition (Don Brace) [1890727 1889844]
- [scsi] scsi: smartpqi: Correct driver removal with HBA disks (Don Brace) [1890727 1889844]
- [target] scsi: target: Fix XCOPY NAA identifier lookup (Maurizio Lombardi) [1900463] {CVE-2020-28374}
- [x86] perf/x86/intel/uncore: Add Comet Lake support (Michael Petlan) [1873271]

* Mon Feb 08 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-284.el8]
- [net] bridge: Fix a warning when del bridge sysfs (Davide Caratti) [1917518]
- [net] bridge: Avoid infinite loop when suppressing NS messages with invalid options (Davide Caratti) [1917518]
- [net] bridge: fix stale eth hdr pointer in br_dev_xmit (Davide Caratti) [1917518]
- [net] SUNRPC: Handle 0 length opaque XDR object data properly (Dave Wysochanski) [1906400]
- [net] SUNRPC: Move simple_get_bytes and simple_get_netobj into private header (Dave Wysochanski) [1906400]
- [block] nbd: make the config put is called before the notifying the waiter (Ming Lei) [1743857]
- [block] nbd: restore default timeout when setting it to zero (Ming Lei) [1743857]
- [kernel] rcu/tree: Defer kvfree_rcu() allocation to a clean context (Waiman Long) [1922453]
- [kernel] cgroup: Fix memory leak when parsing multiple source parameters (Waiman Long) [1922453]
- [kernel] cpuset: fix race between hotplug work and later CPU offline (Waiman Long) [1922453]
- [kernel] cgroup: freezer: call cgroup_enter_frozen() with preemption disabled in ptrace_stop() (Waiman Long) [1922453]
- [kernel] cgroup: freezer: fix frozen state inheritance (Waiman Long) [1922453]
- [kernel] locking/lockdep: Cure noinstr fail (Waiman Long) [1922453]
- [kernel] tick/nohz: Narrow down noise while setting current task's tick dependency (Waiman Long) [1922453]
- [fs] fs: Kill DCACHE_DONTCACHE dentry even if DCACHE_REFERENCED is set (Eric Sandeen) [1921903]
- [fs] fs: Handle I_DONTCACHE in iput_final() instead of generic_drop_inode() (Eric Sandeen) [1921903]
- [netdrv] ice: update dev_addr in ice_set_mac_address even if HW filter exists (Jonathan Toppins) [1879318]
- [tools] libbpf: Fix uninitialized variable in btf_parse_type_sec (Jiri Olsa) [1922197]
- [tools] libbpf: Support BTF loading and raw data output in both endianness (Jiri Olsa) [1922197]
- [tools] selftests/bpf: Test BTF writing APIs (Jiri Olsa) [1922197]
- [tools] libbpf: Add btf__str_by_offset() as a more generic variant of name_by_offset (Jiri Olsa) [1922197]
- [tools] libbpf: Add BTF writing APIs (Jiri Olsa) [1922197]
- [tools] libbpf: Add btf__new_empty() to create an empty BTF object (Jiri Olsa) [1922197]
- [tools] libbpf: Allow modification of BTF and add btf__add_str API (Jiri Olsa) [1922197]
- [tools] libbpf: Extract generic string hashing function for reuse (Jiri Olsa) [1922197]
- [tools] libbpf: Generalize common logic for managing dynamically-sized arrays (Jiri Olsa) [1922197]
- [tools] libbpf: Remove assumption of single contiguous memory for BTF data (Jiri Olsa) [1922197]
- [tools] libbpf: Refactor internals of BTF type index (Jiri Olsa) [1922197]
- [tools] libbpf: Remove any use of reallocarray() in libbpf (Jiri Olsa) [1922197]
- [tools] libbpf: Clean up and improve CO-RE reloc logging (Jiri Olsa) [1922197]
- [tools] libbpf: Improve error logging for mismatched BTF kind cases (Jiri Olsa) [1922197]
- [scsi] scsi: qla2xxx: Fix mailbox Ch erroneous error (Nilesh Javali) [1894578]
- [sound] ALSA: ASoC: Intel: tgl: remove sof_fw_filename set for tgl_3_in_1_default (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: allow soundwire use desc->default_fw_filename (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: sof_sdw: set proper flags for Dell TGL-H SKU 0A5E (Jaroslav Kysela) [1783462]
- [sound] ALSA: hda: intel-dsp-config: add PCI id for TGL-H (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Properly unregister DAI on removal (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Fix memory corruption in soc_tplg_denum_create_values() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Add missing size check (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Fix wrong size check (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Simplify remove_widget function (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Remove empty functions (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Change allocations to resource managed (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Unify all device references (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Remove unused functions from topology API (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98926: drop driver pm=NULL assignment (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98925: drop driver pm=NULL assignment (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98926: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98925: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max9867: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: codecs: max98373-sdw: align regmap use with other codecs (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98371: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98390: Fix error codes in max98390_dsm_init() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98371: drop driver pm=NULL assignment (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98095: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98373: don't access volatile registers in bias level off (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: max98090: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: pcm: DRAIN support reactivation (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt711: mutex between calibration and power state changes (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt711: remove warnings (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt5660: skip of_device_id table when !CONFIG_OF (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: codecs: rt*.c: remove useless pointer cast (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015p: delay 300ms after SDB pulling high for calibration (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015p: move SDB control from trigger to DAPM (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015: check the return value of regmap_read during i2c probe (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015: modification for calibration to get better performance (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015: support TDM slot configuration (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: qcom: Fix build failure when slimbus is module (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: Fix DEBUG_LOCKS_WARN_ON for uninitialized attribute (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: master: use pm_runtime_set_active() on add (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: intel: fix another unused-function warning (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: bus: only clear valid DPN interrupts (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: bus: only clear valid DP0 interrupts (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: registers: add definitions for clearable interrupt fields (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: bus: reset slave_notify status at each loop (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: bus: add comments to explain interrupt loop filter (Jaroslav Kysela) [1783462]
- [sound] ALSA: soundwire: SDCA: detect sdca_cascade interrupt (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_max98927: Fix kabylake_ssp_fixup function (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: Boards: tgl_max98373: update TDM slot_width (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: intel: sof_rt5682: Add support for tgl_rt1011_rt5682 (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: Boards: tgl_max98373: add dpcm_capture flag for speaker_smart_amp (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: intel: sof_rt5682: Add quirk for Dooly (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: intel: sof_rt5682: Add support for cml_rt1015_rt5682 (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: sof_sdw: add quirk for new TigerLake-SDCA device (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Intel: add hw specific PCM constraints (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: loader: do not warn about unknown firmware headers (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: Remove multistep topology loading (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: sof-audio: remove goto used for force-nocodec support (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: ops: modify the signature of stall op (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: topology: remove const in sizeof() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: use inclusive language for bclk and fsync (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: topology: use inclusive language for bclk and fsync (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: ops: add parse_platform_ext_manifest() op (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: relax PCM period and buffer size constraints (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: nocodec: modify DAI link definitions (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: trace: Add runtime trace filtering mechanism (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Add `memory_info` file to debugfs (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Change section comment for SOF_IPC_TEST_ (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Improve code alignment in header.h (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: IPC: fix implicit type overflow (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: ext_manifest: Parse firmware config dictionary (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix the condition passed to sof_dev_dbg_or_err (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: modify the SOF_DBG flags (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove duplicated status dump (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse cavs extra config data elem (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Intel: hda: define parse_platform_ext_manifest op (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: control: override volume info callback (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: control: remove const in sizeof() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Add .prepare/.complete callbacks (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: SOF: Activate runtime PM with SOF OF device (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-pcm: add missing ret=0 at soc_pcm_open() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-pcm: ignore un-needed mutex_unlock() case on soc_pcm_open() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-pcm: remove unneeded dev_err() for snd_soc_component_module/open() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-pcm: remove unneeded dev_err() for snd_soc_dai_startup() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-pcm: add soc_pcm_clean() and call it from soc_pcm_open/close() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-link: add mark for snd_soc_link_startup/shutdown() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-dai: add mark for snd_soc_dai_startup/shutdown() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-component: add mark for snd_soc_pcm_component_pm_runtime_get/put() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: soc-component: add mark for soc_pcm_components_open/close() (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: KMB: Fix S24_LE configuration (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASOC: Intel: kbl_rt5663_rt5514_max98927: Do not try to disable disabled clock (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 Detachable quirks (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt5682: change SAR voltage threshold (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015: increase the time to detect BCLK (Jaroslav Kysela) [1783462]
- [sound] ALSA: ASoC: rt1015: add delay to fix pop noise from speaker (Jaroslav Kysela) [1783462]
- [powerpc] powerpc/tm: Avoid machine crash on rt_sigreturn() (Gustavo Duarte) [1860550]
- [net] udp: Prevent reuseport_select_sock from reading uninitialized socks (Guillaume Nault) [1917953]
- [net] flow_offload: Fix memory leak for indirect flow block (Guillaume Nault) [1917953]
- [net] sock: set sk_err to ee_errno on dequeue from errq (Guillaume Nault) [1917953]
- [net] devlink: Make sure devlink instance and port are in same net namespace (Guillaume Nault) [1917953]
- [net] devlink: Hold rtnl lock while reading netdev attributes (Guillaume Nault) [1917953]
- [net] devlink: Add missing genlmsg_cancel() in devlink_nl_sb_port_pool_fill() (Guillaume Nault) [1917953]
- [net] tipc: fix NULL deref in tipc_link_xmit() (Xin Long) [1918657]
- [net] tipc: prevent possible null deref of link (Xin Long) [1918657]
- [net] tipc: fix incompatible mtu of transmission (Xin Long) [1918657]
- [net] tipc: fix memory leak in tipc_topsrv_start() (Xin Long) [1918657]
- [net] tipc: add stricter control of reserved service types (Xin Long) [1918657]
- [tools] selftests/bpf/test_offload.py: Filter bpftool internal map when counting maps (Jiri Benc) [1882709]
- [tools] selftests/bpf/test_offload.py: Reset ethtool features after failed setting (Jiri Benc) [1882709]
- [tools] selftests/bpf/test_offload.py: Fix expected case of extack messages (Jiri Benc) [1882709]
- [tools] selftests/bpf/test_offload.py: Only check verifier log on verification fails (Jiri Benc) [1882709]
- [netdrv] netdevsim: Add debugfs toggle to reject BPF programs in verifier (Jiri Benc) [1882709]
- [tools] selftests/bpf/test_offload.py: Remove check for program load flags match (Jiri Benc) [1882709]
- [net] xdp: Remove the xdp_attachment_flags_ok() callback (Jiri Benc) [1882709]
- [net] net, xsk: Avoid taking multiple skbuff references (Jiri Benc) [1882709]
- [net] increment xmit_recursion level in dev_direct_xmit() (Jiri Benc) [1882709]
- [kernel] usermodehelper: reset umask to default before executing user process (Jiri Benc) [1882709]
- [net] xsk: Do not discard packet when NETDEV_TX_BUSY (Jiri Benc) [1882709]
- [net] xsk: Fix number of pinned pages/umem size discrepancy (Jiri Benc) [1882709]
- [include] netdevice.h: fix xdp_state kernel-doc warning (Jiri Benc) [1882709]
- [net] bpf: xdp: Fix XDP mode when no mode flags specified (Jiri Benc) [1882709]
- [net] bpf: Fix XDP FD-based attach/detach logic around XDP_FLAGS_UPDATE_IF_NOEXIST (Jiri Benc) [1882709]
- [kernel] add a kernel_wait helper (Jiri Benc) [1882709]
- [tools] selftests/bpf: Add link detach tests for cgroup, netns, and xdp bpf_links (Jiri Benc) [1882709]
- [net] bpf: Add support for forced LINK_DETACH command (Jiri Benc) [1882709]
- [kernel] bpf: Fix build without CONFIG_NET when using BPF XDP link (Jiri Benc) [1882709]
- [net] xdp: Prevent kernel-infoleak in xsk_getsockopt() (Jiri Benc) [1882709]
- [net] udp, bpf: Ignore connections in reuseport group after BPF sk lookup (Jiri Benc) [1882709]
- [net] Revert "net: optimize the sockptr_t for unified kernel/user address spaces" (Jiri Benc) [1882709]
- [net] improve the user pointer check in init_user_sockptr (Jiri Benc) [1882709]
- [include] net: remove sockptr_advance (Jiri Benc) [1882709]
- [include] net: make sockptr_is_null strict aliasing safe (Jiri Benc) [1882709]
- [net] optimize the sockptr_t for unified kernel/user address spaces (Jiri Benc) [1882709]
- [net] bpfilter: switch bpfilter_ip_set_sockopt to sockptr_t (Jiri Benc) [1882709]
- [net] switch copy_bpf_fprog_from_user to sockptr_t (Jiri Benc) [1882709]
- [include] net: add a new sockptr_t type (Jiri Benc) [1882709]
- [net] bpfilter: reject kernel addresses (Jiri Benc) [1882709]
- [net] bpfilter: split __bpfilter_process_sockopt (Jiri Benc) [1882709]
- [net] bpfilter: fix up a sparse annotation (Jiri Benc) [1882709]
- [net] udp: Don't discard reuseport selection when group has connections (Jiri Benc) [1882709]
- [net] bpf, xdp: Remove XDP_QUERY_PROG and XDP_QUERY_PROG_HW XDP commands (Jiri Benc) [1882709]
- [tools] selftests/bpf: Add BPF XDP link selftests (Jiri Benc) [1882709]
- [net] bpf: Implement BPF XDP link-specific introspection APIs (Jiri Benc) [1882709]
- [net] bpf, xdp: Implement LINK_UPDATE for BPF XDP link (Jiri Benc) [1882709]
- [net] bpf, xdp: Add bpf_link-based XDP attachment API (Jiri Benc) [1882709]
- [net] bpf, xdp: Extract common XDP program attachment logic (Jiri Benc) [1882709]
- [net] bpf, xdp: Maintain info on attached XDP BPF programs in net_device (Jiri Benc) [1882709]
- [kernel] bpf, netns: Fix build without CONFIG_INET (Jiri Benc) [1882709]
- [net] udp6: Run SK_LOOKUP BPF program on socket lookup (Jiri Benc) [1882709]
- [net] udp6: Extract helper for selecting socket from reuseport group (Jiri Benc) [1882709]
- [net] udp: Run SK_LOOKUP BPF program on socket lookup (Jiri Benc) [1882709]
- [net] udp: Extract helper for selecting socket from reuseport group (Jiri Benc) [1882709]
- [net] ipv6: remove unused arg exact_dif in compute_score (Jiri Benc) [1882709]
- [net] ipv4: remove unused arg exact_dif in compute_score (Jiri Benc) [1882709]
- [net] udp: Remove unused variable/function (exact_dif) (Jiri Benc) [1882709]
- [net] udp: Remove unused parameter (exact_dif) (Jiri Benc) [1882709]
- [net] udp: only choose unbound UDP socket for multicast when not in a VRF (Jiri Benc) [1882709]
- [net] ensure unbound datagram socket to be chosen when not in a VRF (Jiri Benc) [1882709]
- [net] ensure unbound stream socket to be chosen when not in a VRF (Jiri Benc) [1882709]
- [net] allow binding socket in a VRF when there's an unbound socket (Jiri Benc) [1882709]
- [net] udp6: drop unneeded likely() call around IS_ERR() (Jiri Benc) [1882709]
- [net] udp: drop unneeded likely() call around IS_ERR() (Jiri Benc) [1882709]
- [net] inet6: Run SK_LOOKUP BPF program on socket lookup (Jiri Benc) [1882709]
- [net] inet6: Extract helper for selecting socket from reuseport group (Jiri Benc) [1882709]
- [net] inet: Run SK_LOOKUP BPF program on socket lookup (Jiri Benc) [1882709]
- [net] inet: Extract helper for selecting socket from reuseport group (Jiri Benc) [1882709]
- [net] simplify cBPF setsockopt compat handling (Jiri Benc) [1882709]
- [net] explicitly include <linux/compat.h> in net/core/sock.c (Jiri Benc) [1882709]
- [include] compat: provide compat_ptr() on all architectures (Jiri Benc) [1882709]
- [net] socket: move compat timeout handling into sock.c (Jiri Benc) [1882709]
- [include] xdp: introduce xdp_get_shared_info_from_{buff, frame} utility routines (Jiri Benc) [1882709]
- [net] xsk: Add xdp statistics to xsk_diag (Jiri Benc) [1882709]
- [net] xsk: Add new statistics (Jiri Benc) [1882709]
- [net] bpfilter: Initialize pos variable (Jiri Benc) [1882709]
- [kernel] umd: Stop using split_argv (Jiri Benc) [1882709]
- [kernel] umd: Remove exit_umh (Jiri Benc) [1882709]
- [net] bpfilter: Take advantage of the facilities of struct pid (Jiri Benc) [1882709]
- [kernel] exit: Factor thread_group_exited out of pidfd_poll (Jiri Benc) [1882709]
- [kernel] umd: Track user space drivers with struct pid (Jiri Benc) [1882709]
- [net] bpfilter: Move bpfilter_umh back into init data (Jiri Benc) [1882709]
- [fs] exec: Remove do_execve_file (Jiri Benc) [1882709]
- [kernel] umh: Stop calling do_execve_file (Jiri Benc) [1882709]
- [kernel] umd: Transform fork_usermode_blob into fork_usermode_driver (Jiri Benc) [1882709]
- [kernel] umd: Rename umd_info.cmdline umd_info.driver_name (Jiri Benc) [1882709]
- [kernel] umd: For clarity rename umh_info umd_info (Jiri Benc) [1882709]
- [kernel] umh: Separate the user mode driver and the user mode helper support (Jiri Benc) [1882709]
- [kernel] umh: Move setting PF_UMH into umh_pipe_setup (Jiri Benc) [1882709]
- [kernel] umh: Remove call_usermodehelper_setup_file. (Jiri Benc) [1882709]
- [kernel] umh: Rename the user mode driver helpers for clarity (Jiri Benc) [1882709]
- [kernel] umh: Capture the pid in umh_pipe_setup (Jiri Benc) [1882709]
- [net] bpf: Add SO_KEEPALIVE and related options to bpf_setsockopt (Jiri Benc) [1882709]
- [net] tcp: Expose tcp_sock_set_keepidle_locked (Jiri Benc) [1882709]
- [net] tcp: add tcp_sock_set_keepidle (Jiri Benc) [1882709]
- [net] sock: Move sock_valbool_flag to header (Jiri Benc) [1882709]
- [net] spread "enum sock_flags" (Jiri Benc) [1882709]
- [tools] bpf: Use local copy of headers including uapi/linux/filter.h (Jiri Benc) [1882709]
- [net] bpfilter: fix iptables failure if bpfilter_umh is disabled (Jiri Benc) [1882709]
- [s390] s390/crypto: add arch_get_random_long() support (Vladis Dronov) [1904274]
- [net] net/smc: Add support for obtaining SMCR device list (Philipp Rudo) [1868684]
- [net] net/smc: Add support for obtaining SMCD device list (Philipp Rudo) [1868684]
- [net] net/smc: Add SMC-D Linkgroup diagnostic support (Philipp Rudo) [1868684]
- [net] net/smc: Introduce SMCR get link command (Philipp Rudo) [1868684]
- [net] net/smc: Introduce SMCR get linkgroup command (Philipp Rudo) [1868684]
- [net] net/smc: Add support for obtaining system information (Philipp Rudo) [1868684]
- [net] net/smc: Introduce generic netlink interface for diagnostic purposes (Philipp Rudo) [1868684]
- [net] net/smc: Refactor smc ism v2 capability handling (Philipp Rudo) [1868684]
- [net] net/smc: Add diagnostic information to link structure (Philipp Rudo) [1868684]
- [net] net/smc: Add diagnostic information to smc ib-device (Philipp Rudo) [1868684]
- [net] net/smc: Add link counters for IB device ports (Philipp Rudo) [1868684]
- [net] net/smc: Add connection counters for links (Philipp Rudo) [1868684]
- [net] net/smc: Use active link of the connection (Philipp Rudo) [1868684]
- [net] net/smc: use helper smc_conn_abort() in listen processing (Philipp Rudo) [1868684]
- [net] sched: sch_frag: add generic packet fragment support. (Marcelo Leitner) [1909262]
- [net] sched: act_mirred: refactor the handle of xmit (Marcelo Leitner) [1909262]
- [net] sched: fix miss init the mru in qdisc_skb_cb (Marcelo Leitner) [1909262]
- [net] openvswitch: using ip6_fragment in ipv6_stub (Marcelo Leitner) [1909262]
- [net] ipv6: add ipv6_fragment hook in ipv6_stub (Marcelo Leitner) [1909262]
- [x86] x86/resctrl: Fix spelling in user-visible warning messages (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Enable user to view thread or core throttling mode (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Enumerate per-thread MBA controls (Puneet Sethi) [1717078]
- [x86] cacheinfo: Move resctrl's get_cache_id() to the cacheinfo header file (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Add struct rdt_cache::arch_has_{sparse, empty}_bitmaps (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Merge AMD/Intel parse_bw() calls (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Add struct rdt_membw::arch_needs_linear to explain AMD/Intel MBA difference (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Use is_closid_match() in more places (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Use container_of() in delayed_work handlers (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Fix stale comment (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Remove struct rdt_membw::max_delay (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Remove unused struct mbm_state::chunks_bw (Puneet Sethi) [1717078]
- [x86] x86/resctrl: Fix memory bandwidth counter width for AMD (Puneet Sethi) [1845633 1717078]
- [documentation] Documentation: x86: fix some typos (Puneet Sethi) [1717078]
- [documentation] Documentation: x86: Clarify MBA takes MB as referring to mba_sc (Puneet Sethi) [1717078]
- [documentation] Documentation: x86: Remove cdpl2 unspported statement and fix capitalisation (Puneet Sethi) [1717078]
- [documentation] Documentation: x86: Contiguous cbm isn't all X86 (Puneet Sethi) [1717078]
- [documentation] Documentation: x86: convert resctrl_ui.txt to reST (Puneet Sethi) [1717078]
- [kernel] livepatch: Make klp_apply_object_relocs static (Yannick Cote) [1866433]
- [kernel] livepatch: Prevent module-specific KLP rela sections from referencing vmlinux symbols (Yannick Cote) [1866433]
- [x86] livepatch: Remove .klp.arch (Yannick Cote) [1866433]
- [kernel] livepatch: Apply vmlinux-specific KLP relocations early (Yannick Cote) [1866433]
- [kernel] livepatch: Disallow vmlinux.ko (Yannick Cote) [1866433]

* Thu Feb 04 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-283.el8]
- [sound] ALSA: hda: Add Cometlake-R PCI ID (Jaroslav Kysela) [1915650]
- [fs] xfs: don't drain buffer lru on freeze and read-only remount (Brian Foster) [1903387]
- [fs] xfs: rename xfs_wait_buftarg() to xfs_buftarg_drain() (Brian Foster) [1903387]
- [net] mptcp: implement delegated actions (Paolo Abeni) [1892375]
- [net] mptcp: schedule work for better snd subflow selection (Paolo Abeni) [1892375]
- [net] mptcp: do not queue excessive data on subflows (Paolo Abeni) [1892375]
- [net] mptcp: re-enable sndbuf autotune (Paolo Abeni) [1892375]
- [net] mptcp: always graft subflow socket to parent (Paolo Abeni) [1892375]
- [include] lockdep: Introduce in_softirq lockdep assert (Paolo Abeni) [1892375]
- [net] selinux: handle MPTCP consistently with TCP (Paolo Abeni) [1892375]
- [net] mptcp: fix locking in mptcp_disconnect() (Paolo Abeni) [1892375]
- [net] mptcp: better msk-level shutdown. (Paolo Abeni) [1892375]
- [net] mptcp: more strict state checking for acks (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add the MP_PRIO testcases (Paolo Abeni) [1892375]
- [net] mptcp: add the mibs for MP_PRIO (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add set_flags command in pm_nl_ctl (Paolo Abeni) [1892375]
- [net] mptcp: add set_flags command in PM netlink (Paolo Abeni) [1892375]
- [net] mptcp: add the incoming MP_PRIO support (Paolo Abeni) [1892375]
- [net] mptcp: add the outgoing MP_PRIO support (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add testcases for setting the address ID (Paolo Abeni) [1892375]
- [net] mptcp: add the address ID assignment bitmap (Paolo Abeni) [1892375]
- [net] mptcp: cap forward allocation to 1M (Paolo Abeni) [1892375]
- [net] mptcp: fix pending data accounting (Paolo Abeni) [1892375]
- [net] mptcp: push pending frames when subflow has free space (Paolo Abeni) [1892375]
- [net] mptcp: properly annotate nested lock (Paolo Abeni) [1892375]
- [net] mptcp: fix security context on server socket (Paolo Abeni) [1892375]
- [net] mptcp: clear use_ack and use_map when dropping other suboptions (Paolo Abeni) [1892375]
- [net] mptcp: let MPTCP create max size skbs (Paolo Abeni) [1892375]
- [net] mptcp: pm: simplify select_local_address() (Paolo Abeni) [1892375]
- [net] mptcp: parse and act on incoming FASTCLOSE option (Paolo Abeni) [1892375]
- [net] mptcp: hold mptcp socket before calling tcp_done (Paolo Abeni) [1892375]
- [net] mptcp: use MPTCPOPT_HMAC_LEN macro (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add the flush addrs testcase (Paolo Abeni) [1892375]
- [net] mptcp: remove address when netlink flushes addrs (Paolo Abeni) [1892375]
- [net] mptcp: attach subflow socket to parent cgroup (Paolo Abeni) [1892375]
- [net] mptcp: be careful on subflows shutdown (Paolo Abeni) [1892375]
- [net] mptcp: plug subflow context memory leak (Paolo Abeni) [1892375]
- [net] mptcp: link MPC subflow into msk only after accept (Paolo Abeni) [1892375]
- [net] mptcp: use the variable sk instead of open-coding (Paolo Abeni) [1892375]
- [net] mptcp: rename add_addr_signal and mptcp_add_addr_status (Paolo Abeni) [1892375]
- [net] mptcp: drop rm_addr_signal flag (Paolo Abeni) [1892375]
- [net] mptcp: print out port and ahmac when receiving ADD_ADDR (Paolo Abeni) [1892375]
- [net] mptcp: add port parameter for mptcp_pm_announce_addr (Paolo Abeni) [1892375]
- [net] mptcp: send out dedicated packet for ADD_ADDR using port (Paolo Abeni) [1892375]
- [net] mptcp: add the outgoing ADD_ADDR port support (Paolo Abeni) [1892375]
- [net] mptcp: use adding up size to get ADD_ADDR length (Paolo Abeni) [1892375]
- [net] mptcp: add port support for ADD_ADDR suboption writing (Paolo Abeni) [1892375]
- [net] mptcp: unify ADD_ADDR and ADD_ADDR6 suboptions writing (Paolo Abeni) [1892375]
- [net] mptcp: unify ADD_ADDR and echo suboptions writing (Paolo Abeni) [1892375]
- [net] mptcp: print new line in mptcp_seq_show() if mptcp isn't in use (Paolo Abeni) [1892375]
- [net] mptcp: emit tcp reset when a join request fails (Paolo Abeni) [1892375]
- [net] tcp: merge 'init_req' and 'route_req' functions (Paolo Abeni) [1892375]
- [net] security: add const qualifier to struct sock in various places (Paolo Abeni) [1892375]
- [net] mptcp: avoid potential infinite loop in mptcp_recvmsg() (Paolo Abeni) [1892375]
- [net] mptcp: use mptcp release_cb for delayed tasks (Paolo Abeni) [1892375]
- [net] mptcp: avoid a few atomic ops in the rx path (Paolo Abeni) [1892375]
- [net] mptcp: allocate TX skbs in msk context (Paolo Abeni) [1892375]
- [net] mptcp: protect the rx path with the msk socket spinlock (Paolo Abeni) [1892375]
- [net] mptcp: implement wmem reservation (Paolo Abeni) [1892375]
- [net] mptcp: open code mptcp variant for lock_sock (Paolo Abeni) [1892375]
- [net] mptcp: fix NULL ptr dereference on bad MPJ (Paolo Abeni) [1892375]
- [net] mptcp: be careful on MPTCP-level ack. (Paolo Abeni) [1892375]
- [net] mptcp: put reference in mptcp timeout timer (Paolo Abeni) [1892375]
- [net] mptcp: refine MPTCP-level ack scheduling (Paolo Abeni) [1892375]
- [net] mptcp: track window announced to peer (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add ADD_ADDR IPv6 test cases (Paolo Abeni) [1892375]
- [net] mptcp: send out dedicated ADD_ADDR packet (Paolo Abeni) [1892375]
- [net] mptcp: change add_addr_signal type (Paolo Abeni) [1892375]
- [net] mptcp: keep unaccepted MPC subflow into join list (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add link failure test case (Paolo Abeni) [1892375]
- [net] mptcp: skip to next candidate if subflow has unacked data (Paolo Abeni) [1892375]
- [net] mptcp: fix state tracking for fallback socket (Paolo Abeni) [1892375]
- [net] mptcp: drop WORKER_RUNNING status bit (Paolo Abeni) [1892375]
- [net] mptcp: update rtx timeout only if required. (Paolo Abeni) [1892375]
- [net] mptcp: send explicit ack on delayed ack_seq incr (Paolo Abeni) [1892375]
- [net] mptcp: keep track of advertised windows right edge (Paolo Abeni) [1892375]
- [net] mptcp: rework poll+nospace handling (Paolo Abeni) [1892375]
- [net] mptcp: try to push pending data on snd una updates (Paolo Abeni) [1892375]
- [net] mptcp: move page frag allocation in mptcp_sendmsg() (Paolo Abeni) [1892375]
- [net] mptcp: refactor shutdown and close (Paolo Abeni) [1892375]
- [net] mptcp: introduce MPTCP snd_nxt (Paolo Abeni) [1892375]
- [net] mptcp: add accounting for pending data (Paolo Abeni) [1892375]
- [net] mptcp: reduce the arguments of mptcp_sendmsg_frag (Paolo Abeni) [1892375]
- [net] mptcp: introduce mptcp_schedule_work (Paolo Abeni) [1892375]
- [net] tcp: factor out __tcp_close() helper (Paolo Abeni) [1892375]
- [net] mptcp: use tcp_build_frag() (Paolo Abeni) [1892375]
- [net] tcp: factor out tcp_build_frag() (Paolo Abeni) [1892375]
- [net] tcp: schedule EPOLLOUT after a partial sendmsg (Paolo Abeni) [1892375]
- [net] tcp: annotate tp->write_seq lockless reads (Paolo Abeni) [1892375]
- [net] mptcp: fix static checker warnings in mptcp_pm_add_timer (Paolo Abeni) [1892375]
- [tools] selftests: mptcp: add ADD_ADDR timeout test case (Paolo Abeni) [1892375]
- [documentation] networking: mptcp: Add MPTCP sysctl entries (Paolo Abeni) [1892375]
- [net] mptcp: add a new sysctl add_addr_timeout (Paolo Abeni) [1892375]
- [net] mptcp: split mptcp_clean_una function (Paolo Abeni) [1892375]
- [net] tcp: propagate MPTCP skb extensions on xmit splits (Paolo Abeni) [1892375]
- [net] mptcp: use _fast lock version in __mptcp_move_skbs (Paolo Abeni) [1892375]
- [net] mptcp: adjust mptcp receive buffer limit if subflow has larger one (Paolo Abeni) [1892375]
- [net] tcp: fix compile error if !CONFIG_SYSCTL (Paolo Abeni) [1892375]
- [net] tcp: add tcp_tx_skb_cache sysctl (Paolo Abeni) [1892375]
- [net] tcp: do not recycle cloned skbs (Paolo Abeni) [1892375]
- [net] tcp: properly reset skb->truesize for tx recycling (Paolo Abeni) [1892375]
- [net] tcp: cleanup sk_tx_skb_cache before reuse (Paolo Abeni) [1892375]
- [net] tcp: fix zerocopy and notsent_lowat issues (Paolo Abeni) [1892375]
- [net] tcp: add one skb cache for tx (Paolo Abeni) [1892375]
- [include] include: fpga: adi-axi-common.h: fixup whitespace tab -> space (Luis Goncalves) [1494702]
- [include] include: fpga: adi-axi-common.h: add version helper macros (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: afu: convert get_user_pages() --> pin_user_pages() (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: fix bug in port reset handshake (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: pci: reduce the scope of variable 'ret' (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: pci: add device id for Intel FPGA PAC N3000 (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: afu: add AFU interrupt support (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: fme: add interrupt support for global error reporting (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: afu: add interrupt support for port error reporting (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: introduce interrupt trigger setting API (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: pci: add irq info for feature devices enumeration (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: parse interrupt info for feature devices on enumeration (Luis Goncalves) [1494702]
- [fpga] fpga manager: xilinx-spi: check INIT_B pin during write_init (Luis Goncalves) [1494702]
- [fpga] fpga: Fix dead store in fpga-bridge.c (Luis Goncalves) [1494702]
- [fpga] fpga: Fix dead store fpga-mgr.c (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: Use struct_size() in kzalloc() (Luis Goncalves) [1494702]
- [fpga] fpga manager: xilinx-spi: remove unneeded, mistyped variables (Luis Goncalves) [1494702]
- [fpga] fpga manager: xilinx-spi: valid for the 7 Series too (Luis Goncalves) [1494702]
- [fpga] fpga: zynqmp: fix modular build (Luis Goncalves) [1494702]
- [fpga] drivers/fpga/dfl-afu-dma-region.c: get rid of pointless access_ok() (Luis Goncalves) [1494702]
- [fpga] drivers/fpga/dfl-fme-pr.c: get rid of pointless access_ok() (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: afu: Corrected error handling levels (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: afu: support debug access to memory-mapped afu regions (Luis Goncalves) [1494702]
- [fpga] fpga: dfl.h: Replace zero-length array with flexible-array member (Luis Goncalves) [1494702]
- [fpga] fpga: stratix10-soc: add compatible property value for intel agilex (Luis Goncalves) [1494702]
- [fpga] fpga: machxo2-spi: Use new structure for SPI transfer delays (Luis Goncalves) [1494702]
- [fpga] fpga: ice40-spi: Use new structure for SPI transfer delays (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: support multiple opens on feature device node (Luis Goncalves) [1494702]
- [fpga] fpga: dfl: fme: add performance reporting support (Luis Goncalves) [1494702]
- [firmware] firmware: fpga: replace the error codes with the standard ones (Luis Goncalves) [1494702]
- [net] sched: act_mpls: ensure LSE is pullable before reading it (Guillaume Nault) [1917918]
- [net] openvswitch: ensure LSE is pullable before reading it (Guillaume Nault) [1917918]
- [net] skbuff: ensure LSE is pullable before decrementing the MPLS ttl (Guillaume Nault) [1917918]
- [net] sched: act_mpls: Add softdep on mpls_gso.ko (Guillaume Nault) [1917918]
- [net] mpls: load mpls_gso after mpls_iptunnel (Guillaume Nault) [1917918]
- [net] netfilter: nf_tables: handle nft_object lookups via rhltable (Phil Sutter) [1848816]
- [arm64] kvm: arm64: Remove PMU RAZ/WI handling (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Inject UNDEF on PMU access when no PMU configured (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Set ID_AA64DFR0_EL1.PMUVer to 0 when no PMU support (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Add kvm_vcpu_has_pmu() helper (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Refactor PMU attribute error handling (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Introduce handling of AArch32 TTBCR2 traps (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: pmu: Make overflow handler NMI safe (Auger Eric) [1890373 1907826]
- [tools] kvm: selftests: Also build dirty_log_perf_test on AArch64 (Auger Eric) [1890373 1907826]
- [tools] selftests: kvm/set_memory_region_test: Fix race in move region test (Auger Eric) [1890373 1907826]
- [tools] kvm: arm64: selftests: Filter out DEMUX registers (Auger Eric) [1890373 1907826]
- [tools] kvm: selftests: Add blessed SVE registers to get-reg-list (Auger Eric) [1890373 1907826]
- [tools] kvm: selftests: Add aarch64 get-reg-list test (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Don't access PMCR_EL0 when no PMU is available (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: vgic-v3: Drop the reporting of GICR_TYPER.Last for userspace (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Don't hide ID registers from userspace (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Force PTE mapping on fault resulting in a device mapping (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Fix AArch32 handling of DBGD{CCINT, SCRext} and DBGVCR (Auger Eric) [1890373 1907826]
- [kernel] kvm: arm64: ARM_SMCCC_ARCH_WORKAROUND_1 doesn't return SMCCC_RET_NOT_REQUIRED (Auger Eric) [1890373 1907826]
- [kernel] smccc: Make constants available to assembly (Auger Eric) [1890373 1907826]
- [kernel] firmware: smccc: Add the definition for SMCCCv1.2 version/error codes (Auger Eric) [1890373 1907826]
- [arm64] kvm: arm64: Ensure user_mem_abort() return value is initialised (Auger Eric) [1890373 1907826]
- [] ASoC: SOF: Intel: fix page fault at probe if i915 init fails (Jaroslav Kysela) [1906665]
- [include] powerpc: fix the backport macros of hv_24x7 and hv_gpci (Diego Domingos) [1915159]
- [net] tcp: Prevent low rmem stalls with SO_RCVLOWAT. (Davide Caratti) [1917976]
- [net] tcp: fix to update snd_wl1 in bulk receiver fast path (Davide Caratti) [1917976]
- [net] tcp: md5: refine tcp_md5_do_add()/tcp_md5_hash_key() barriers (Davide Caratti) [1917976]
- [net] tcp: md5: add missing memory barriers in tcp_md5_do_add()/tcp_md5_hash_key() (Davide Caratti) [1917976]
- [net] sunrpc: clean-up cache downcall (J. Bruce Fields) [1887178]
- [net] sunrpc: raise kernel RPC channel buffer size (J. Bruce Fields) [1887178]
- [netdrv] mlx5: Remove the unsupported mark from ConnectX-6 Lx and BlueField-2 (Alaa Hleihel) [1802118 1790541]
- [s390] s390/qeth: make af_iucv TX notification call more robust (Philipp Rudo) [1915919]
- [s390] s390/dasd: fix list corruption of lcu list (Philipp Rudo) [1915918]
- [s390] s390/dasd: fix list corruption of pavgroup group list (Philipp Rudo) [1915918]
- [s390] s390/dasd: prevent inconsistent LCU device data (Philipp Rudo) [1915918]
- [s390] s390/dasd: fix hanging device offline processing (Philipp Rudo) [1915918]
- [block] Revert "block: Fix a lockdep complaint triggered by request queue flushing" (Ming Lei) [1897404]
- [nvme] nvme-loop: use blk_mq_hctx_set_fq_lock_class to set loop's lock class (Ming Lei) [1897404]
- [block] blk-mq: add new API of blk_mq_hctx_set_fq_lock_class (Ming Lei) [1897404]
- [scsi] scsi: core: Fix race between handling STS_RESOURCE and completion (Ming Lei) [1897404]

* Tue Feb 02 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-282.el8]
- [fs] inotify: Increase default inotify.max_user_watches limit to 1048576 (Waiman Long) [1888617]
- [kernel] cgroup: fix psi_show() crash on 32bit ino archs (Waiman Long) [1920288]
- [kernel] cgroup: fix incorrect WARN_ON_ONCE() in cgroup_setup_root() (Waiman Long) [1920288]
- [netdrv] net: bareudp: add missing error handling for bareudp_link_config() (Guillaume Nault) [1920194]
- [netdrv] bareudp: Fix use of incorrect min_headroom size (Guillaume Nault) [1920194]
- [netdrv] bareudp: set NETIF_F_LLTX flag (Guillaume Nault) [1920194]
- [netdrv] vxlan: fix error return code in __vxlan_dev_create() (Guillaume Nault) [1920194]
- [netdrv] ip_tunnels: Set tunnel option flag when tunnel metadata is present (Guillaume Nault) [1920194]
- [net] vsock/virtio: discard packets only when socket is really closed (Stefano Garzarella) [1920004]
- [net] vsock: fix the error return when an invalid ioctl command is used (Stefano Garzarella) [1920004]
- [net] vsock: remove ratelimit unknown ioctl message (Stefano Garzarella) [1920004]
- [net] vsock: use ns_capable_noaudit() on socket create (Stefano Garzarella) [1920004]
- [net] vsock: fix potential null pointer dereference in vsock_poll() (Stefano Garzarella) [1920004]
- [net] vsock/vmci: make vmci_vsock_transport_cb() static (Stefano Garzarella) [1920004]
- [block] block: add blk_queue_make_request declaration back (Ming Lei) [1919764]
- [net] erspan: fix version 1 check in gre_parse_header() (Guillaume Nault) [1919388]
- [net] ipv4: Ignore ECN bits for fib lookups in fib_compute_spec_dst() (Guillaume Nault) [1919388]
- [net] ipv4: Fix tos mask in inet_rtm_getroute() (Guillaume Nault) [1919388]
- [net] inet_diag: Fix error path to cancel the meseage in inet_req_diag_fill() (Guillaume Nault) [1919388]
- [mm] usercopy: mark dma-kmalloc caches as usercopy caches (Waiman Long) [1660290]
- [mm] mm, slab_common: use enum kmalloc_cache_type to iterate over kmalloc caches (Waiman Long) [1660290]
- [mm] mm, slab: remove unused kmalloc_size() (Waiman Long) [1660290]
- [mm] mm, slab: make kmalloc_infocontain all types of names (Waiman Long) [1660290]
- [netdrv] net: stmmac: fix taprio configuration when base_time is in the past (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac-sunxi: Provide TX and RX fifo sizes (Mark Salter) [1870102]
- [netdrv] net: stmmac: delete the eee_ctrl_timer after napi disabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: free tx skb buffer in stmmac_resume() (Mark Salter) [1870102]
- [netdrv] net: stmmac: start phylink instance before stmmac_hw_setup() (Mark Salter) [1870102]
- [netdrv] net: stmmac: increase the timeout for dma reset (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix incorrect merge of patch upstream (Mark Salter) [1870102]
- [netdrv] net: stmmac: Use rtnl_lock/unlock on netif_set_real_num_rx_queues() call (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac_lib: enlarge dma reset timeout (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix channel lock initialization (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add option for VLAN filter fail queue enable (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support to Ethtool get/set ring parameters (Mark Salter) [1870102]
- [netdrv] net: stmmac: use netif_tx_start|stop_all_queues() function (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix incorrect location to set real_num_rx|tx_queues (Mark Salter) [1870102]
- [netdrv] net: stmmac: add ethtool support for get/set channels (Mark Salter) [1870102]
- [netdrv] net: stmmac: set get_rx_header_len() as void for it didn't have any error code to return (Mark Salter) [1870102]
- [netdrv] net: stmmac: remove redundant null check before clk_disable_unprepare() (Mark Salter) [1870102]
- [netdrv] net: phylink: avoid oops during initialisation (Mark Salter) [1870102]
- [netdrv] net: stmmac: Modify configuration method of EEE timers (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: provide multicast filter fallback (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix failed to suspend if phy based WOL is enabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: Speed down the PHY if WoL to save energy (Mark Salter) [1870102]
- [netdrv] net: stmmac: Support WOL with phy (Mark Salter) [1870102]
- [netdrv] net: stmmac: only call pmt() during suspend/resume if HW enables PMT (Mark Salter) [1870102]
- [netdrv] net: stmmac: Move device_can_wakeup() check earlier in set_wol (Mark Salter) [1870102]
- [netdrv] net: stmmac: Remove WAKE_MAGIC if HW shows no pmt_magic_frame (Mark Salter) [1870102]
- [netdrv] net: stmmac: Remove unused inline function stmmac_rx_threshold_count (Mark Salter) [1870102]
- [include] net: pylink.h: add kernel-doc descriptions for new fields at phylink_config (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for VLAN promiscuous mode (Mark Salter) [1870102]
- [netdrv] net: stmmac: removed enabling eee in EEE set callback (Mark Salter) [1870102]
- [documentation] net: phy: add PHY_INTERFACE_MODE_10GBASER (Mark Salter) [1870102]
- [include] net: mii: convert mii_lpa_to_ethtool_lpa_x() to linkmode variant (Mark Salter) [1870102]
- [base] driver core: platform: Add platform_get_irq_byname_optional() (Mark Salter) [1870102]
- [netdrv] net: stmmac: enable timestamp snapshot for required PTP packets in dwmac v5.10a (Mark Salter) [1870102]
- [netdrv] net: stmmac: don't attach interface until resume finishes (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac5+: fix potential integer overflow on 32 bit multiply (Mark Salter) [1870102]
- [netdrv] stmmac: fix pointer check after utilization in stmmac_interrupt (Mark Salter) [1870102]
- [netdrv] stmmac: intel: Fix kernel crash due to wrong error path (Mark Salter) [1870102]
- [netdrv] net: stmmac: Enable SERDES power up/down sequence (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix sub-second increment (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: fix out-of-bounds mac address reg setting (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix VLAN register handling (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix VLAN filtering when HW does not support it (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for VLAN Rx filtering (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac_lib: remove unnecessary checks in dwmac_dma_reset() (Mark Salter) [1870102]
- [netdrv] net: rename flow_action_hw_stats_types* -> flow_action_hw_stats* (Mark Salter) [1870102]
- [netdrv] net: stmmac: use readl_poll_timeout() function in dwmac4_dma_reset() (Mark Salter) [1870102]
- [netdrv] net: stmmac: use readl_poll_timeout() function in init_systime() (Mark Salter) [1870102]
- [netdrv] net: stmmac: platform: convert to devm_platform_ioremap_resource (Mark Salter) [1870102]
- [netdrv] net: stmmac: Integrate it with DesignWare XPCS (Mark Salter) [1870102]
- [netdrv] net: phy: Add Synopsys DesignWare XPCS MDIO module (Mark Salter) [1870102]
- [netdrv] net: stmmac: Use resolved link config in mac_link_up() (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fallback to dev_fwnode() if needed (Mark Salter) [1870102]
- [netdrv] net: stmmac: Switch to linkmode_and()/linkmode_andnot() (Mark Salter) [1870102]
- [netdrv] flow_offload: check for basic action hw stats type (Mark Salter) [1870102]
- [netdrv] stmmac: let core reject the unsupported coalescing parameters (Mark Salter) [1870102]
- [netdrv] net: phylink: propagate resolved link config via mac_link_up() (Mark Salter) [1870102]
- [netdrv] net: ethernet: stmmac: demote warnings about missing optional clocks (Mark Salter) [1870102]
- [netdrv] net: stmmac: platform: Fix misleading interrupt error msg (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: Disable ACS if enhanced descs are not used (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix notifier registration (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: fix missing IFF_MULTICAST checki in dwxgmac2_set_filter (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix missing IFF_MULTICAST check in dwmac4_set_filter (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: fix incorrect XGMAC_VLAN_TAG register writting (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix incorrect GMAC_VLAN_TAG register writting in GMAC4+ (Mark Salter) [1870102]
- [netdrv] net: stmmac: Delete txtimer in suspend() (Mark Salter) [1870102]
- [netdrv] net: stmmac: modified pcs mode support for RGMII (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add missing information in DebugFS capabilities file (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac4+: Add TBS support (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Add TBS support (Mark Salter) [1870102]
- [netdrv] net: stmmac: tc: Add support for ETF Scheduler using TBS (Mark Salter) [1870102]
- [netdrv] net: stmmac: Initial support for TBS (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac5+: Fix missing return (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix missing return (Mark Salter) [1870102]
- [netdrv] net: stmmac: tc: Fix TAPRIO division operation (Mark Salter) [1870102]
- [netdrv] net: stmmac: mmc: Add Frame Preemption counters on GMAC5+ cores (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac3+: Add support for Frame Preemption (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac5+: Add support for Frame Preemption (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add Frame Preemption support using TAPRIO API (Mark Salter) [1870102]
- [netdrv] net: stmmac: Integrate EST with TAPRIO scheduler API (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add basic EST support for XGMAC (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add basic EST support for GMAC5+ (Mark Salter) [1870102]
- [netdrv] net: stmmac: Always use TX coalesce timer value when rescheduling (Mark Salter) [1870102]
- [netdrv] net: stmmac: Let TX and RX interrupts be independently enabled/disabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: Print more information in DebugFS DMA Capabilities file (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwc-qos: avoid clk and reset for acpi device (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwc-qos: use generic device api (Mark Salter) [1870102]
- [netdrv] net: stmmac: platform: fix probe for ACPI devices (Mark Salter) [1870102]
- [netdrv] net: stmmac: tc: Do not setup flower filtering if RSS is enabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fixed link does not need MDIO Bus (Mark Salter) [1870102]
- [netdrv] stmmac: debugfs entry name is not be changed when udev rename device name (Mark Salter) [1870102]
- [netdrv] net: stmmac: platform: Fix MDIO init for platforms without PHY (Mark Salter) [1870102]
- [netdrv] net: stmmac: Always arm TX Timer at end of transmission start (Mark Salter) [1870102]
- [netdrv] net: stmmac: Enable 16KB buffer size (Mark Salter) [1870102]
- [netdrv] net: stmmac: 16KB buffer must be 16 byte aligned (Mark Salter) [1870102]
- [netdrv] net: stmmac: RX buffer size must be 16 byte aligned (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Clear previous RX buffer size (Mark Salter) [1870102]
- [netdrv] net: stmmac: Only the last buffer has the FCS field (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not accept invalid MTU values (Mark Salter) [1870102]
- [netdrv] net: stmmac: Determine earlier the size of RX buffer (Mark Salter) [1870102]
- [netdrv] treewide: Use sizeof_field() macro (Mark Salter) [1870102]
- [netdrv] net: stmmac: reset Tx desc base address before restarting Tx (Mark Salter) [1870102]
- [netdrv] net: phylink: rename mac_link_state() op to mac_pcs_get_state() (Mark Salter) [1870102]
- [netdrv] page_pool: do not release pool until inflight == 0 (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Do not enable TBU interrupt (Mark Salter) [1870102]
- [netdrv] net: stmmac: Rework TX Coalesce logic (Mark Salter) [1870102]
- [netdrv] net: stmmac: Tune-up default coalesce settings (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Remove uneeded computation for RFA/RFD (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac4+: Remove uneeded computation for RFA/RFD (Mark Salter) [1870102]
- [netdrv] net: stmmac: Setup a default RX Coalesce value instead of the minimum (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not set RX IC bit if RX Coalesce is zero (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement UDP Segmentation Offload (Mark Salter) [1870102]
- [netdrv] net: stmmac: Rework stmmac_rx() (Mark Salter) [1870102]
- [netdrv] net: stmmac: tc: Remove the speed dependency (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Add C45 PHY support in the MDIO callbacks (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac4+: Add Split Header support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix sparse warning (Mark Salter) [1870102]
- [netdrv] net: stmmac: Remove break after a return (Mark Salter) [1870102]
- [netdrv] net: stmmac: add flexible PPS to dwmac 4.10a (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement L3/L4 Filters in GMAC4+ (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fallback to VLAN Perfect filtering if HASH is not available (Mark Salter) [1870102]
- [netdrv] net: stmmac: Support enhanced addressing mode for DWMAC 4.10 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Only enable enhanced addressing mode when needed (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix the TX IOC in xmit path (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix TSO descriptor with Enhanced Addressing (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix the packet count in stmmac_rx() (Mark Salter) [1870102]
- ethernet: Delete unnecessary checks before the macro call “dev_kfree_skb” (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Disable MMC interrupts by default (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Disable Flow Control when 1 or more queues are in AV (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix AV Feature detection (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix TSA selection (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Only get SPH header len if available (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: bitrev32 returns u32 (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac4: bitrev32 returns u32 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix the problem of tso_xmit (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix argument to stmmac_pcs_ctrl_ane() (Mark Salter) [1870102]
- [netdrv] net: stmmac: disable/enable ptp_ref_clk in suspend/resume flow (Mark Salter) [1870102]
- [netdrv] net: stmmac: make tc_flow_parsers static (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix disabling flexible PPS output (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix length of PTP clock's name string (Mark Salter) [1870102]
- [netdrv] net: stmmac: gmac4+: Not all Unicast addresses may be available (Mark Salter) [1870102]
- [netdrv] net: stmmac: Avoid deadlock on suspend/resume (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix RSS writing wrong keys (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix RSS not writing all Keys to HW (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Disable the Timestamp interrupt by default (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not stop PHY if WoL is enabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: Correctly take timestamp for PTPv2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4: Always update the MAC Hash Filter (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Detect Hash Table size dinamically (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Not all Unicast addresses may be available (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix page pool size (Mark Salter) [1870102]
- [netdrv] net: stmmac: selftest: avoid large stack usage (Mark Salter) [1870102]
- [netdrv] net: stmmac: Hold rtnl lock in suspend/resume callbacks (Mark Salter) [1870102]
- [netdrv] net: stmmac: implement support for passive mode converters via dt (Mark Salter) [1870102]
- [netdrv] net: stmmac: ARP Offload for GMAC4+ Cores (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for VLAN Insertion Offload in GMAC4+ (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for SA Insertion/Replacement in GMAC4+ (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Reinitialize correctly a variable (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add VLAN HASH filtering support in GMAC4+ (Mark Salter) [1870102]
- [netdrv] net: stmmac: Prevent divide-by-zero (Mark Salter) [1870102]
- [netdrv] net: stmmac: Limit max speeds of XGMAC if asked to (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4: Enable RX Jumbo frame support (Mark Salter) [1870102]
- [netdrv] stmmac: platform: adjust messages and move to dev level (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Enable RX Jumbo frame support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Correctly assing MAX MTU in XGMAC cores case (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Correct RAVSEL field interpretation (Mark Salter) [1870102]
- [netdrv] net: stmmac: ethtool: Let user configure TX coalesce without RIWT (Mark Salter) [1870102]
- [netdrv] net: stmmac: Only consider RX error when HW Timestamping is not enabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Implement ARP Offload (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement L3/L4 Filters using TC Flower (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not return error code in TC Initialization (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Add RBU handling in DMA interrupt (Mark Salter) [1870102]
- [netdrv] net: stmmac: depend on COMMON_CLK (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwc-qos: use devm_platform_ioremap_resource() to simplify code (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for VLAN Insertion Offload (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Add EEE support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for SA Insertion/Replacement in XGMAC cores (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add ethtool register dump for XGMAC cores (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac: Add Flexible PPS support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add a counter for Split Header packets (Mark Salter) [1870102]
- [netdrv] net: page_pool: API cleanup and comments (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add Split Header support and enable it in XGMAC cores (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Correctly return that RX descriptor is not last one (Mark Salter) [1870102]
- [netdrv] net: stmmac: Prepare to add Split Header support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Get correct timestamp values from XGMAC (Mark Salter) [1870102]
- [netdrv] stmmac: no need to check return value of debugfs_create functions (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add Flexible RX Parser support in XGMAC (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement Safety Features in XGMAC core (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement VLAN Hash Filtering in XGMAC (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement RSS and enable it in XGMAC core (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Implement tx_queue_prio() (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Implement set_mtl_tx_queue_weight() (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Implement MMC counters (Mark Salter) [1870102]
- [netdrv] net: Remove dev_err() usage after platform_get_irq() (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not request stmmaceth clock (Mark Salter) [1870102]
- [netdrv] net: stmmac: Make MDIO bus reset optional (Mark Salter) [1870102]
- [netdrv] net: stmmac: tc: Do not return a fragment entry (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix issues when number of Queues >= 4 (Mark Salter) [1870102]
- [netdrv] net: stmmac: xgmac: Fix XGMAC selftests (Mark Salter) [1870102]
- [netdrv] net: stmmac: manage errors returned by of_get_mac_address() (Mark Salter) [1870102]
- [netdrv] net: stmmac: Use netif_tx_napi_add() for TX polling function (Mark Salter) [1870102]
- [netdrv] net: stmmac: Sync RX Buffer upon allocation (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not cut down 1G modes (Mark Salter) [1870102]
- [netdrv] net: stmmac: Use kcalloc() instead of kmalloc_array() (Mark Salter) [1870102]
- [netdrv] net: stmmac: RX Descriptors need to be clean before setting buffers (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix misuses of GENMASK macro (Mark Salter) [1870102]
- [netdrv] net: stmmac: add support for hash table size 128/256 in dwmac4 (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4: mac address array boudary violation issue (Mark Salter) [1870102]
- [netdrv] net: stmmac: Introducing support for Page Pool (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix descriptors address being in > 32 bits address space (Mark Salter) [1870102]
- [netdrv] net: stmmac: Implement RX Coalesce Frames setting (Mark Salter) [1870102]
- [netdrv] net: stmmac: Re-work the queue selection for TSO packets (Mark Salter) [1870102]
- [netdrv] net: stmmac: Enable dwmac4 jumbo frame more than 8KiB (Mark Salter) [1870102]
- [netdrv] net: stmmac: make "snps, reset-delays-us" optional again (Mark Salter) [1870102]
- [netdrv] net: stmmac: Re-word Kconfig entry (Mark Salter) [1870102]
- [netdrv] net: stmmac: Update Kconfig entry (Mark Salter) [1870102]
- [netdrv] net: stmmac: Only disable interrupts if NAPI is scheduled (Mark Salter) [1870102]
- [netdrv] net: stmmac: Update RX Tail Pointer to last free entry (Mark Salter) [1870102]
- [netdrv] net: stmmac: Enable support for > 32 Bits addressing in XGMAC (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not disable interrupts when cleaning TX (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add the missing speeds that XGMAC supports (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac: Fix the undefined burst setting (Mark Salter) [1870102]
- [netdrv] net: stmmac: Decrease default RX Watchdog value (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not try to enable PHY EEE if MAC does not support it (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac: Enable EDMA by default (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix case when PHY handle is not present (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix crash observed if PHY does not support EEE (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix possible deadlock when disabling EEE support (Mark Salter) [1870102]
- [netdrv] net: stmmac: initialize the reset delay array (Mark Salter) [1870102]
- [netdrv] net: stmmac: add sanity check to device_property_read_u32_array call (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix unused-variable warning (Mark Salter) [1870102]
- [netdrv] net: stmmac: drop the phy_reset hook from struct stmmac_mdio_bus_data (Mark Salter) [1870102]
- [netdrv] net: stmmac: drop the reset delays from struct stmmac_mdio_bus_data (Mark Salter) [1870102]
- [netdrv] net: stmmac: drop the reset GPIO from struct stmmac_mdio_bus_data (Mark Salter) [1870102]
- [netdrv] net: stmmac: use device_property_read_u32_array to read the reset delays (Mark Salter) [1870102]
- [netdrv] net: stmmac: drop redundant check in stmmac_mdio_reset (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix wrapper drivers not detecting PHY (Mark Salter) [1870102]
- [netdrv] net: stmmac: use GPIO descriptors in stmmac_mdio_reset (Mark Salter) [1870102]
- [netdrv] net: stmmac: Convert to phylink and remove phylib logic (Mark Salter) [1870102]
- [netdrv] net: stmmac: Start adding phylink support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Prepare to convert to phylink (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4: fix flow control issue (Mark Salter) [1870102]
- [netdrv] net: stmmac: modify default value of tx-frames (Mark Salter) [1870102]
- [netdrv] net: stmmac: Switch to devm_alloc_etherdev_mqs (Mark Salter) [1870102]
- [netdrv] net: stmmac: use dev_info() before netdev is registered (Mark Salter) [1870102]
- [netdrv] net: stmmac: Prevent missing interrupts when running NAPI (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4/5: Clear unused address entries (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac2: Do not disable whole RX in dma_stop_rx() (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4/5: Do not disable whole RX in dma_stop_rx() (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4/5: Fix Hash Filter (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: Clear unused address entries (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: Fix Hash Filter (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac2: Also pass control frames while in promisc mode (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4/5: Also pass control frames while in promisc mode (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: Also pass control frames while in promisc mode (Mark Salter) [1870102]
- [netdrv] net: stmmac: Switch MMC functions to HWIF callbacks (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac2: Add MAC loopback support (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4/5: Add MAC loopback support (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac1000: Add MAC loopback support (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac100: Add MAC loopback support (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add MAC loopback callback to HWIF (Mark Salter) [1870102]
- [netdrv] net: stmmac: set IC bit when transmitting frames with HW timestamp (Mark Salter) [1870102]
- [netdrv] net: stmmac: fixed new system time seconds value calculation (Mark Salter) [1870102]
- [netdrv] net: stmmac: Do not output error on deferred probe (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix csr_clk can't be zero issue (Mark Salter) [1870102]
- [netdrv] net: stmmac: update rx tail pointer register to fix rx dma hang issue (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix reset gpio free missing (Mark Salter) [1870102]
- [netdrv] net: stmmac: dma channel control register need to be init first (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix ethtool flow control not able to get/set (Mark Salter) [1870102]
- [netdrv] dwmac4_prog_mtl_tx_algorithms() missing write operation (Mark Salter) [1870102]
- [netdrv] net: stmmac: Set Flow Control to automatic mode in the driver (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac: Finish the Flow Control implementation (Mark Salter) [1870102]
- [netdrv] net: stmmac: move stmmac_check_ether_addr() to driver probe (Mark Salter) [1870102]
- [netdrv] net: stmmac: Use bfsize1 in ndesc_init_rx_desc (Mark Salter) [1870102]
- [netdrv] net: stmmac: don't log oversized frames (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix dropping of multi-descriptor RX frames (Mark Salter) [1870102]
- [netdrv] net: stmmac: don't overwrite discard_frame status (Mark Salter) [1870102]
- [netdrv] net: stmmac: don't stop NAPI processing when dropping a packet (Mark Salter) [1870102]
- [netdrv] net: stmmac: ratelimit RX error logs (Mark Salter) [1870102]
- [netdrv] net: stmmac: use correct DMA buffer size in the RX descriptor (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix memory corruption with large MTUs (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix jumbo frame sending with non-linear skbs (Mark Salter) [1870102]
- [netdrv] net: stmmac: don't set own bit too early for jumbo frames (Mark Salter) [1870102]
- [netdrv] net: stmmac: Avoid one more sometimes uninitialized Clang warning (Mark Salter) [1870102]
- [netdrv] net: ethernet: stmmac: add management of clk_csr property (Mark Salter) [1870102]
- [netdrv] net: stmmac: Avoid sometimes uninitialized Clang warnings (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac2: Also use TBU interrupt to clean TX path (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwmac4: Also use TBU interrupt to clean TX path (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix NAPI poll in TX path when in multi-queue (Mark Salter) [1870102]
- [netdrv] net: stmmac: use correct define to get rx timestamp on GMAC4 (Mark Salter) [1870102]
- [netdrv] net: stmmac: fix ptp timestamping on Rx on gmac4 (Mark Salter) [1870102]
- [netdrv] net: stmmac: implement the SIOCGHWTSTAMP ioctl (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix a race in EEE enable callback (Mark Salter) [1870102]
- [netdrv] net: stmmac: handle endianness in dwmac4_get_timestamp (Mark Salter) [1870102]
- [netdrv] net: stmmac: Disable EEE mode earlier in XMIT callback (Mark Salter) [1870102]
- [netdrv] net: stmmac: Send TSO packets always from Queue 0 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fallback to Platform Data clock in Watchdog conversion (Mark Salter) [1870102]
- [netdrv] net: stmmac: Prevent RX starvation in stmmac_napi_poll() (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix the logic of checking if RX Watchdog must be enabled (Mark Salter) [1870102]
- [netdrv] net: stmmac: Check if CBS is supported before configuring (Mark Salter) [1870102]
- [netdrv] net: stmmac: dwxgmac2: Only clear interrupts that are active (Mark Salter) [1870102]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Mark Salter) [1870102]
- [netdrv] net: stmmac: convert to DEFINE_SHOW_ATTRIBUTE (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix an error code in probe() (Mark Salter) [1870102]
- [netdrv] net: stmmac: Move debugfs init/exit to ->probe()/->remove() (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix RX packet size > 8191 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fix stmmac_mdio_reset() when building stmmac as modules (Mark Salter) [1870102]
- [netdrv] net: stmmac: Set OWN bit for jumbo frames (Mark Salter) [1870102]
- [netdrv] net: stmmac: Enable TC Ops for GMAC >= 4 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add CBS support in XGMAC2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Fixup the tail addr setting in xmit path (Mark Salter) [1870102]
- [netdrv] stmmac: fix valid numbers of unicast filter entries (Mark Salter) [1870102]
- [netdrv] net: stmmac: Rework coalesce timer and fix multi-queue races (Mark Salter) [1870102]
- [netdrv] Revert "net: stmmac: Do not keep rearming the coalesce timer in stmmac_xmit" (Mark Salter) [1870102]
- [netdrv] Revert "net: stmmac: fix build failure due to missing COMMON_CLK dependency" (Mark Salter) [1870102]
- [netdrv] net: stmmac: Integrate XGMAC into main driver flow (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add PTP support for XGMAC2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add MDIO related functions for XGMAC2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add descriptor related callbacks for XGMAC2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add DMA related callbacks for XGMAC2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add MAC related callbacks for XGMAC2 (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add XGMAC 2.10 HWIF entry (Mark Salter) [1870102]
- [netdrv] stmmac: fix signed 64-bit division (Mark Salter) [1870102]
- [netdrv] net: stmmac_tc: use 64-bit arithmetic instead of 32-bit (Mark Salter) [1870102]
- [netdrv] net: stmmac: Add support for CBS QDISC (Mark Salter) [1870102]
- [tty] serial: 8250_tegra: Create Tegra specific 8250 driver (Mark Salter) [1870103]
- [pci] PCI: Disable MSI for Tegra root ports (Mark Salter) [1870101]
- [pci] PCI: Add MCFG quirks for Tegra194 host controllers (Mark Salter) [1870101]
- [netdrv] tun: fix return value when the number of iovs exceeds MAX_SKB_FRAGS (Antoine Tenart) [1919364 1917563] {CVE-2021-0342}
- [netdrv] tun: correct header offsets in napi frags mode (Antoine Tenart) [1919364 1917563] {CVE-2021-0342}
- [netdrv] tun: Don't put_page() for all negative return values from XDP program (Antoine Tenart) [1919364]
- [netdrv] tun: add mutex_unlock() call and napi.skb clearing in tun_get_user() (Antoine Tenart) [1919364]
- [netdrv] tun: fix data-race in gro_normal_list() (Antoine Tenart) [1919364]
- [netdrv] tun: fix use-after-free when register netdev failed (Antoine Tenart) [1919364]
- [netdrv] tun: mark small packets as owned by the tap sock (Antoine Tenart) [1919364]
- [netdrv] tun: use netdev_alloc_frag() in tun_napi_alloc_frags() (Antoine Tenart) [1919364]
- [scsi] scsi: ibmvfc: Fix error return in ibmvfc_probe() (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Provide modules parameters for MQ settings (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Enable MQ and set reasonable defaults (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Purge SCSI channels after transport loss/reset (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Send Cancel MAD down each hw SCSI channel (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add cancel mad initialization helper (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Register Sub-CRQ handles with VIOS during channel setup (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Send commands down HW Sub-CRQ when channelized (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Set and track hw queue in ibmvfc_event struct (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Advertise client support for using hardware channels (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Implement channel enquiry and setup commands (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Map/request irq and register Sub-CRQ interrupt handler (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Define Sub-CRQ interrupt handler routine (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add handlers to drain and complete Sub-CRQ responses (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add Sub-CRQ IRQ enable/disable routine (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add alloc/dealloc routines for SCSI Sub-CRQ Channels (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add Subordinate CRQ definitions (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Define hcall wrapper for registering a Sub-CRQ (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add size parameter to ibmvfc_init_event_pool() (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Init/free event pool during queue allocation/free (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Move event pool init/free routines (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add vhost fields and defaults for MQ enablement (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Fix missing cast of ibmvfc_event pointer to u64 handle (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Relax locking around ibmvfc_queuecommand() (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Complete commands outside the host/queue lock (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Define per-queue state/list locks (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Make command event pool queue specific (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Define generic queue structure for CRQs (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Advertise client support for targetWWPN using v2 commands (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add support for target_wwpn field in v2 MADs and vfcFrame (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add FC payload retrieval routines for versioned vfcFrames (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add helper for testing capability flags (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Add new fields for version 2 of several MADs (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Deduplicate common ibmvfc_cmd init code (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Use correlation token to tag commands (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Remove trailing semicolon (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Byte swap login_buf.resp values in attribute show functions (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Interface updates for future FPIN and MQ support (Desnes Augusto Nunes do Rosario) [1868055]
- [scsi] scsi: ibmvfc: Protect vhost->task_set increment by the host lock (Desnes Augusto Nunes do Rosario) [1868055]
- [net] tcp: Fix potential use-after-free due to double kfree() (Florian Westphal) [1915164]
- [nvdimm] libnvdimm/region: Enable MAP_SYNC for volatile regions (Steve Best) [1916650]
- [net] bpf: Permit cond_resched for some iterators (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Fix PID fetching with a lot of results (Yauheni Kaliuta) [1874005]
- [net] bpf: verifier: Use target program's type for access verifications (Yauheni Kaliuta) [1874005]
- [tools] selftests: bpf: Test sockmap update from BPF (Yauheni Kaliuta) [1874005]
- [net] bpf: sockmap: Allow update from BPF (Yauheni Kaliuta) [1874005]
- [net] bpf: Override the meaning of ARG_PTR_TO_MAP_VALUE for sockmap and sockhash (Yauheni Kaliuta) [1874005]
- [net] bpf: sockmap: Call sock_map_update_elem directly (Yauheni Kaliuta) [1874005]
- [net] bpf: sockmap: Merge sockmap and sockhash update functions (Yauheni Kaliuta) [1874005]
- [net] net: sk_msg: Simplify sk_psock initialization (Yauheni Kaliuta) [1874005]
- [net] bpf: Enforce id generation for all may-be-null register type (Yauheni Kaliuta) [1874005]
- [samples] samples: bpf: Cleanup bpf_load.o from Makefile (Yauheni Kaliuta) [1874005]
- [include] bpf: Plug hole in struct bpf_sk_lookup_kern (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix endianness issues in sk_lookup/ctx_narrow_access (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Fix build slowdown (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix scalar32_min_max_or bounds tracking (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix "unresolved symbol" build error with resolve_btfids (Yauheni Kaliuta) [1874005]
- [powerpc] bpf, powerpc: Fix misuse of fallthrough in bpf_jit_comp() (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix XDP program load regression for old kernels (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix native endian assumption when parsing BTF (Yauheni Kaliuta) [1874005]
- [include] bpf: Prevent .BTF section elimination (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix sysfs export of empty BTF section (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Support passing BPFTOOL_VERSION to make (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix a rcu warning for bpffs map pretty-print (Yauheni Kaliuta) [1874005]
- [net] bpf: Bpf_skc_to_* casting helpers require a NULL check on sk (Yauheni Kaliuta) [1874005]
- [documentation] docs/bpf: Remove source code links (Yauheni Kaliuta) [1874005]
- [documentation] docs/bpf: Fix ringbuf documentation (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix VERSIONED_SYM_COUNT number parsing (Yauheni Kaliuta) [1874005]
- [tools] tools/libbpf: Avoid counting local symbols in ABI check (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix clobbering of r2 in bpf_gen_ld_abs (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add bpf_{update, delete}_map_elem in hashmap iter program (Yauheni Kaliuta) [1874005]
- [net] bpf: Do not use bucket_lock for hashmap iterator (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Remove arch-specific include path in Makefile (Yauheni Kaliuta) [1874005]
- [tools] tools/bpf: build: Make sure resolve_btfids cleans up after itself (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix build failure from uninitialized variable warning (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix massive output from test_maps (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix test_progs-flavor run getting number of tests (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix a buffer out-of-bound access when filling raw_tp link_info (Yauheni Kaliuta) [1874005]
- [tools] bpf: Fix two typos in uapi/linux/bpf.h (Yauheni Kaliuta) [1874005]
- [tools] tools/resolve_btfids: Fix sections with wrong alignment (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix map index used in error message (Yauheni Kaliuta) [1874005]
- [tools] bpftool: Handle EAGAIN error code properly in pids collection (Yauheni Kaliuta) [1874005]
- [net] bpf: Avoid visit same object multiple times (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix a rcu_sched stall issue with bpf task/task_file iterator (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix build on ppc64le architecture (Yauheni Kaliuta) [1874005]
- [net] bpf: Use get_file_rcu() instead of get_file() for task_file iterator (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Make test_varlen work with 32-bit user-space arch (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Generate data section struct with conservative alignment (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Correct various core_reloc 64-bit assumptions (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Enforce 64-bitness of BTF for BPF object files (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix btf_dump test cases on 32-bit arches (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Handle BTF pointer sizes more carefully (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix BTF-defined map-in-map initialization on 32-bit host arches (Yauheni Kaliuta) [1874005]
- [tools] selftest/bpf: Fix compilation warnings in 32-bit mode (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Fix compilation warnings in 32-bit mode (Yauheni Kaliuta) [1874005]
- [documentation] doc: Add link to bpf helpers man page (Yauheni Kaliuta) [1874005]
- [tools] bpf, selftests: Add tests to sock_ops for loading sk (Yauheni Kaliuta) [1874005]
- [tools] bpf, selftests: Add tests for sock_ops load with r9, r8.r7 registers (Yauheni Kaliuta) [1874005]
- [tools] bpf, selftests: Add tests for ctx access in sock_ops with single register (Yauheni Kaliuta) [1874005]
- [net] bpf: sock_ops sk access may stomp registers when dst_reg = src_reg (Yauheni Kaliuta) [1874005]
- [net] bpf: sock_ops ctx access may stomp registers in corner case (Yauheni Kaliuta) [1874005]
- [net] net/core/filter.c: Use sizeof_field() macro (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Prevent overriding errno when logging errors (Yauheni Kaliuta) [1874005]
- [net] bpf: Iterate through all PT_NOTE sections when looking for build id (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Handle GCC built-in types for Arm NEON (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Make skeleton code C++17-friendly by dropping typeof() (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix v4_to_v6 in sk_lookup (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Do not use __builtin_offsetof for offsetof (Yauheni Kaliuta) [1874005]
- [net] bpf: Delete repeated words in comments (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix silent Makefile output (Yauheni Kaliuta) [1874005]
- [documentation] bpf, doc: Remove references to warning message when using bpf_trace_printk() (Yauheni Kaliuta) [1874005]
- [tools] bpf: Fix compilation warning of selftests (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Remove inline from bpf_do_trace_printk (Yauheni Kaliuta) [1874005]
- [tools] bpf: Add missing return to resolve_btfids (Yauheni Kaliuta) [1874005]
- [tools] tools/bpf: Support new uapi for map element bpf iterator (Yauheni Kaliuta) [1874005]
- [net] bpf: Change uapi for bpf iterator map elements (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Prevent runqslower from racing on building bpftool (Yauheni Kaliuta) [1874005]
- [net] bpf: Allow to specify ifindex for skb in bpf_prog_test_run_skb (Yauheni Kaliuta) [1874005]
- [net] bpf: Setup socket family and addresses in bpf_prog_test_run_skb (Yauheni Kaliuta) [1874005]
- [tools] tools/resolve_btfids: Use libbpf's btf__parse() API (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Use libbpf's btf__parse() API for parsing BTF from file (Yauheni Kaliuta) [1874005]
- [tools] libbf: Fix uninitialized pointer at btf__parse_raw() (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add btf__parse_raw() and generic btf__parse() APIs (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Fix wrong return value in do_dump() (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix spurious test failures in core_retro selftest (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Add documentation and bash-completion for `link detach` (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Add `link detach` subcommand (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add bpf_link detach APIs (Yauheni Kaliuta) [1874005]
- [tools] bpf, selftests: Use single cgroup helpers for both test_sockmap/progs (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix register in PT_REGS MIPS macros (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Make destructors more robust by handling ERR_PTR(err) cases (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Omit nodad flag when adding addresses to loopback (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Don't destroy failed link (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add xdpdrv mode for test_xdp_redirect (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Verify socket storage in cgroup/sock_{create, release} (Yauheni Kaliuta) [1874005]
- [net] bpf: Expose socket storage to BPF_PROG_TYPE_CGROUP_SOCK (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test bpf_iter buffer access with negative offset (Yauheni Kaliuta) [1874005]
- [net] bpf: Add missing newline characters in verifier error messages (Yauheni Kaliuta) [1874005]
- [arm64] bpf, arm64: Add BPF exception tables (Yauheni Kaliuta) [1874005]
- [tools] bpf, selftests: use :: 1 for localhost in tcp_server.py (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix swapped arguments in calls to check_buffer_access (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add new bpf_iter context structs to fix build on old kernels (Yauheni Kaliuta) [1874005]
- [tools] bpf: Fix bpf_ringbuf_output() signature to return long (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Add LSM type to array of prog names (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Skip type probe if name is not found (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add support for BPF XDP link (Yauheni Kaliuta) [1874005]
- [include] bpf: Make bpf_link API available indepently of CONFIG_BPF_SYSCALL (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix build on architectures with special bpf_user_pt_regs_t (Yauheni Kaliuta) [1874005]
- [net] bpf/local_storage: Fix build without CONFIG_CGROUP (Yauheni Kaliuta) [1874005]
- [documentation] Documentation/bpf: Document CGROUP_STORAGE map type (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test CGROUP_STORAGE behavior on shared egress + ingress (Yauheni Kaliuta) [1874005]
- [net] bpf: Make cgroup storages shared between programs on the same cgroup (Yauheni Kaliuta) [1874005]
- [net] cgroup: use cgrp->kn->id as the cgroup ID (Yauheni Kaliuta) [1874005]
- [net] netprio: use css ID instead of cgroup ID (Yauheni Kaliuta) [1874005]
- [fs] kernfs: convert kernfs_node->id from union kernfs_node_id to u64 (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add get_stackid_cannot_attach (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test CGROUP_STORAGE map can't be used by multiple progs (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add callchain_stackid (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add test for CGROUP_STORAGE map on multiple attaches (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Print hint when PERF_EVENT_IOC_SET_BPF returns -EPROTO (Yauheni Kaliuta) [1874005]
- [net] bpf: Fail PERF_EVENT_IOC_SET_BPF when bpf_get_cannot work (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add a test for out of bound rdonly buf access (Yauheni Kaliuta) [1874005]
- [net] bpf: Separate bpf_get_for perf events BPF (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add a test for bpf sk_storage_map iterator (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add test for bpf array map iterators (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add test for bpf hash map iterators (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Add bpftool support for bpf map element iterator (Yauheni Kaliuta) [1874005]
- [tools] tools/libbpf: Add support for bpf map element iterator (Yauheni Kaliuta) [1874005]
- [net] bpf: Implement bpf iterator for sock local storage map (Yauheni Kaliuta) [1874005]
- [net] bpf: Implement bpf iterator for array maps (Yauheni Kaliuta) [1874005]
- [net] bpf: Implement bpf iterator for hash maps (Yauheni Kaliuta) [1874005]
- [net] bpf: Implement bpf iterator for map elements (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix pos computation for bpf_iter seq_ops->start() (Yauheni Kaliuta) [1874005]
- [net] bpf: Support readonly/readwrite buffers in verifier (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test BPF socket lookup and reuseport with connections (Yauheni Kaliuta) [1874005]
- [net] bpf: Refactor to provide aux info to bpf_iter_init_seq_priv_t (Yauheni Kaliuta) [1874005]
- [net] bpf: Refactor bpf_iter_reg to have separate seq_info member (Yauheni Kaliuta) [1874005]
- [net] bpf: Add bpf_prog iterator (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Strip BPF .o files before skeleton generation (Yauheni Kaliuta) [1874005]
- [documentation] docs: bpf/bpf_devel_QA.rst: fix reference to nonexistent document (Yauheni Kaliuta) [1874005]
- [documentation] docs: bpf/index.rst: Add ringbuf.rst (Yauheni Kaliuta) [1874005]
- [tools] bpftool: Use only nftw for file tree parsing (Yauheni Kaliuta) [1874005]
- [net] bpf: net: Use precomputed btf_id for bpf iterators (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix test_lwt_seg6local.sh hangs (Yauheni Kaliuta) [1874005]
- [net] bpf: Make btf_sock_ids global (Yauheni Kaliuta) [1874005]
- [tools] bpf: Add BTF_ID_LIST_GLOBAL in btf_ids.h (Yauheni Kaliuta) [1874005]
- [tools] tools/bpf: Sync btf_ids.h to tools (Yauheni Kaliuta) [1874005]
- [net] bpf: Compute bpf_skc_to_*() helper socket btf ids at build time (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Fix error handing in do_skeleton() (Yauheni Kaliuta) [1874005]
- [tools] libbpf bpf_helpers: Use __builtin_offsetof for offsetof (Yauheni Kaliuta) [1874005]
- [s390] s390/bpf: Use bpf_skip() in bpf_jit_prologue() (Yauheni Kaliuta) [1874005]
- [net] bpf: cpumap: Fix possible rcpu kthread hung (Yauheni Kaliuta) [1874005]
- [s390] s390/bpf: implement BPF_PROBE_MEM (Yauheni Kaliuta) [1874005 1868273]
- [s390] s390/kernel: expand exception table logic to allow new handling options (Yauheni Kaliuta) [1874005 1868273]
- [s390] s390: fix __EMIT_BUG() macro (Yauheni Kaliuta) [1874005 1868273]
- [s390] s390/bug: add entry size to the __bug_table section (Yauheni Kaliuta) [1874005 1868273]
- [s390] s390/kernel: unify EX_TABLE* implementations (Yauheni Kaliuta) [1874005 1868273]
- [tools] selftests/bpf: Tests for BPF_SK_LOOKUP attach point (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add verifier tests for bpf_sk_lookup context access (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Add name mappings for SK_LOOKUP prog and attach type (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add support for SK_LOOKUP program type (Yauheni Kaliuta) [1874005]
- [tools] bpf: Sync linux/bpf.h to tools/ (Yauheni Kaliuta) [1874005]
- [include] bpf: Introduce SK_LOOKUP program type with a dedicated attach point (Yauheni Kaliuta) [1874005]
- [net] bpf, netns: Handle multiple link attachments (Yauheni Kaliuta) [1874005]
- [tools] bpf: Drop duplicated words in uapi helper comments (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix possible hang in sockopt_inherit (Yauheni Kaliuta) [1874005]
- [tools] selftest: Add tests for XDP programs in CPUMAP entries (Yauheni Kaliuta) [1874005]
- [samples] samples/bpf: xdp_redirect_cpu: Load a eBPF program on cpumap (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add SEC name for xdp programs attached to CPUMAP (Yauheni Kaliuta) [1874005]
- [net] bpf: cpumap: Implement XDP_REDIRECT for eBPF programs attached to map entries (Yauheni Kaliuta) [1874005]
- [net] bpf: cpumap: Add the possibility to attach an eBPF program to cpumap (Yauheni Kaliuta) [1874005]
- [net] net: Refactor xdp_convert_buff_to_frame (Yauheni Kaliuta) [1874005]
- [net] cpumap: Formalize map value as a named struct (Yauheni Kaliuta) [1874005]
- [samples] samples/bpf: xdp_redirect_cpu_user: Do not update bpf maps in option loop (Yauheni Kaliuta) [1874005]
- [net] cpumap: Use non-locked version __ptr_ring_consume_batched (Yauheni Kaliuta) [1874005]
- [powerpc] powerpc/ppc-opcode: Consolidate powerpc instructions from bpf_jit.h (Yauheni Kaliuta) [1874005]
- [powerpc] powerpc/bpf_jit: Reuse instruction macros from ppc-opcode.h (Yauheni Kaliuta) [1874005]
- [powerpc] powerpc/ppc-opcode: Move ppc instruction encoding from test_emulate_step (Yauheni Kaliuta) [1874005]
- [powerpc] powerpc/lib: Fix emulate_step() std test (Yauheni Kaliuta) [1874005]
- [powerpc] powerpc/ppc-opcode: Introduce PPC_RAW_* macros for base instruction encoding (Yauheni Kaliuta) [1874005]
- [tools] bpf: Fix cross build for CONFIG_DEBUG_INFO_BTF option (Yauheni Kaliuta) [1874005]
- [include] bpf: Fix build for disabled CONFIG_DEBUG_INFO_BTF option (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Strip away modifiers from global variables (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Support stripping modifiers for btf_dump (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add selftests verifying bpf_trace_printk() behaviour (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Use dedicated bpf_trace_printk event instead of trace_printk() (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Remove warning about PID iterator support (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add test for resolve_btfids (Yauheni Kaliuta) [1874005]
- [tools] tools headers: Adopt verbatim copy of btf_ids.h from kernel sources (Yauheni Kaliuta) [1874005]
- [documentation] bpf: Add info about .BTF_ids section to btf.rst (Yauheni Kaliuta) [1874005]
- [net] bpf: Use BTF_ID to resolve bpf_ctx_convert struct (Yauheni Kaliuta) [1874005]
- [net] bpf: Remove btf_id helpers resolving (Yauheni Kaliuta) [1874005]
- [net] bpf: Resolve BTF IDs in vmlinux image (Yauheni Kaliuta) [1874005]
- [include] bpf: Add BTF_ID_LIST/BTF_ID/BTF_ID_UNUSED macros (Yauheni Kaliuta) [1874005]
- [net] bpf: Support llvm-objcopy for vmlinux BTF (Yauheni Kaliuta) [1874005]
- [powerpc] powerpc: Include .BTF section (Yauheni Kaliuta) [1874005]
- [scripts] kbuild: Remove debug info from kallsyms linking (Yauheni Kaliuta) [1874005]
- [scripts] kbuild: Parameterize kallsyms generation and correct reporting (Yauheni Kaliuta) [1874005]
- [tools] bpf: Compile resolve_btfids tool at kernel compilation start (Yauheni Kaliuta) [1874005]
- [kernel] tracing: Make struct ring_buffer less ambiguous (Yauheni Kaliuta) [1874005]
- [kernel] tracing: Rename trace_buffer to array_buffer (Yauheni Kaliuta) [1874005]
- [tools] tools headers: Synchronize linux/bits.h with the kernel sources (Yauheni Kaliuta) [1874005]
- [tools] tools headers: Update linux/vdso.h and grab a copy of vdso/const.h (Yauheni Kaliuta) [1874005]
- [tools] tools headers: Adopt verbatim copy of compiletime_assert() from kernel sources (Yauheni Kaliuta) [1874005]
- [tools] objtool: Query pkg-config for libelf location (Yauheni Kaliuta) [1874005]
- [tools] bpf: Add resolve_btfids tool to resolve BTF IDs in ELF object (Yauheni Kaliuta) [1874005]
- [samples] bpf: Fix fds_example SIGSEGV error (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix memory leak and optimize BTF sanitization (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Switch perf_buffer test to tracepoint and skeleton (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Handle missing BPF_OBJ_GET_INFO_BY_FD gracefully in perf_buffer (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add test relying only on CO-RE and no recent kernel features (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Improve BTF sanitization handling (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add btf__set_fd() for more control over loaded BTF FD (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Make BTF finalization strict (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: test_progs avoid minus shell exit codes (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: test_progs use another shell exit on non-actions (Yauheni Kaliuta) [1874005]
- [tools] bpf: Fix another bpftool segfault without skeleton code enabled (Yauheni Kaliuta) [1874005]
- [tools] selftests: bpf: Remove unused bpf_map_def_legacy struct (Yauheni Kaliuta) [1874005]
- [samples] samples: bpf: Refactor BPF map performance test with libbpf (Yauheni Kaliuta) [1874005]
- [samples] samples: bpf: Refactor BPF map in map test with libbpf (Yauheni Kaliuta) [1874005]
- [samples] samples: bpf: Fix bpf programs with kprobe/sys_connect event (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test BPF_CGROUP_INET_SOCK_RELEASE (Yauheni Kaliuta) [1874005]
- [tools] bpftool: Add support for BPF_CGROUP_INET_SOCK_RELEASE (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add support for BPF_CGROUP_INET_SOCK_RELEASE (Yauheni Kaliuta) [1874005]
- [net] bpf: Add BPF_CGROUP_INET_SOCK_RELEASE hook (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Fix compilation error of bpf_iter_task_stack.c (Yauheni Kaliuta) [1874005]
- [tools] bpf: Fix bpftool without skeleton code enabled (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix build without CONFIG_STACKTRACE (Yauheni Kaliuta) [1874005]
- [tools] bpf: selftests: Restore netns after each test (Yauheni Kaliuta) [1874005]
- [tools] bpf: selftests: A few improvements to network_helpers.c (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test_progs option for listing test names (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test_progs option for getting number of tests (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test_progs indicate to shell on non-actions (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Turn off -Wnested-externs warning (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Switch test_vmlinux to use hrtimer_range_start_ns (Yauheni Kaliuta) [1874005]
- [net] bpf: Fix net/core/filter build errors when INET is not enabled (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add bpf_iter test with bpf_get_task_stack() (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Allow pB in bpf_seq_printf() and bpf_trace_printk() (Yauheni Kaliuta) [1874005]
- [net] bpf: Introduce helper bpf_get_task_stack() (Yauheni Kaliuta) [1874005]
- [net] bpf: Remove redundant synchronize_rcu (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add byte swapping selftest (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Make bpf_endian co-exist with vmlinux.h (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Allow substituting custom vmlinux.h for selftests build (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Allow substituting custom vmlinux.h for the build (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test auto-load disabling logic for BPF programs (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Support disabling auto-loading BPF programs (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Define attach_type_name array only once (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Define prog_type_name array only once (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add tcp/udp iterator programs to selftests (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Implement sample udp/udp6 bpf_iter programs (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Implement sample tcp/tcp6 bpf_iter programs (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add more common macros to bpf_tracing_net.h (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Refactor some net macros to bpf_tracing_net.h (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Add bpf_skc_to_udp6_sock() helper (Yauheni Kaliuta) [1874005]
- [net] net: bpf: Implement bpf iterator for udp (Yauheni Kaliuta) [1874005]
- [net] net: bpf: Add bpf_seq_afinfo in udp_iter_state (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Add bpf_skc_to_{tcp, tcp_timewait, tcp_request}_sock() helpers (Yauheni Kaliuta) [1874005]
- [net] bpf: Add bpf_skc_to_tcp6_sock() helper (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Allow tracing programs to use bpf_jiffies64() helper (Yauheni Kaliuta) [1874005]
- [kernel] bpf: Support 'X' in bpf_seq_printf() helper (Yauheni Kaliuta) [1874005]
- [net] net: bpf: Implement bpf iterator for tcp (Yauheni Kaliuta) [1874005]
- [net] net: bpf: Add bpf_seq_afinfo in tcp_iter_state (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Workaround for get_stack_rawtp test (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Prevent loading vmlinux BTF twice (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Fix spelling mistake "kallasyms" -> "kallsyms" (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Fix variable shadowing in emit_obj_refs_json() (Yauheni Kaliuta) [1874005]
- [tools] tools, bpftool: Correctly evaluate $(BUILD_BPF_SKELS) in Makefile (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add variable-length data concat pattern less than test (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add variable-length data concatenation pattern test (Yauheni Kaliuta) [1874005]
- [tools] bpf: Switch most helper return values from 32-bit int to 64-bit long (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Add documentation and sample output for process info (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Show info for processes holding BPF map/prog/link/btf FDs (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Wrap source argument of BPF_CORE_READ macro in parentheses (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Generalize BPF skeleton support and generate vmlinux.h (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Minimize bootstrap bpftool (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Move map/prog parsing logic into common (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Add __ksym extern selftest (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add support for extracting kernel symbol addresses (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Generalize libbpf externs support (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Add a bunch of attribute getters/setters for map definitions (Yauheni Kaliuta) [1874005]
- [tools] selftests/bpf: Test access to bpf map pointer (Yauheni Kaliuta) [1874005]
- [net] bpf: Set map_btf_{name, id} for all map types (Yauheni Kaliuta) [1874005]
- [net] bpf: Support access to bpf map fields (Yauheni Kaliuta) [1874005]
- [net] bpf: Rename bpf_htab to bpf_shtab in sock_map (Yauheni Kaliuta) [1874005]
- [net] bpf: Switch btf_parse_vmlinux to btf_find_by_name_kind (Yauheni Kaliuta) [1874005]
- [tools] tools/bpftool: Relicense bpftool's BPF profiler prog as dual-license GPL/BSD (Yauheni Kaliuta) [1874005]
- [tools] tools/bpf: Add verifier tests for 32bit pointer/scalar arithmetic (Yauheni Kaliuta) [1874005]
- [net] bpf: Avoid verifier failure for 32bit pointer arithmetic (Yauheni Kaliuta) [1874005]
- [net] bpf: sk_storage: Prefer to get a free cache_idx (Yauheni Kaliuta) [1874005]
- [tools] libbpf: Bump version to 0.1.0 (Yauheni Kaliuta) [1874005]
- [s390] s390/pci: fix hot-plug of PCI function missing bus (Philipp Rudo) [1915916]
- [net] tcp: fix race condition when creating child sockets from syncookies (Florian Westphal) [1915164]
- [netdrv] bonding: set xfrm feature flags more sanely (Jarod Wilson) [1893979]
- [netdrv] bonding: fix feature flag setting at init time (Jarod Wilson) [1893979]

* Mon Feb 01 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-281.el8]
- [fs] cifs: handle -EINTR in cifs_setattr (Leif Sahlberg) [1848178]
- [tty] serial: 8250: drop the printk from serial8250_interrupt() (Vitaly Kuznetsov) [1919745]
- [fs] cifs: do not fail __smb_send_rqst if non-fatal signals are pending (Leif Sahlberg) [1848178]
- [netdrv] ibmvnic: continue fatal error reset after passive init (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix: NULL pointer dereference (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix login buffer memory leak (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix rx buffer tracking and index management in replenish_rx_pool partial success (Diego Domingos) [1901513]
- [netdrv] ibmvnic: add some debugs (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Fix TX completion error handling (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Ensure that SCRQ entry reads are correctly ordered (Diego Domingos) [1901513]
- [netdrv] ibmvnic: reduce wait for completion time (Diego Domingos) [1901513]
- [netdrv] ibmvnic: no reset timeout for 5 seconds after reset (Diego Domingos) [1901513]
- [netdrv] ibmvnic: send_login should check for crq errors (Diego Domingos) [1901513]
- [netdrv] ibmvnic: track pending login (Diego Domingos) [1901513]
- [netdrv] ibmvnic: delay next reset if hard reset fails (Diego Domingos) [1901513]
- [netdrv] ibmvnic: restore adapter state on failed reset (Diego Domingos) [1901513]
- [netdrv] ibmvnic: avoid memset null scrq msgs (Diego Domingos) [1901513]
- [netdrv] ibmvnic: stop free_all_rwi on failed reset (Diego Domingos) [1901513]
- [netdrv] ibmvnic: handle inconsistent login with reset (Diego Domingos) [1901513]
- [netdrv] ibmvnic: enhance resetting status check during module exit (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix NULL pointer dereference in ibmvic_reset_crq (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix NULL pointer dereference in reset_sub_crq_queues (Diego Domingos) [1901513]
- [netdrv] ibmvnic: skip tx timeout reset while in resetting (Diego Domingos) [1901513]
- [netdrv] ibmvnic: notify peers when failover and migration happen (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix call_netdevice_notifiers in do_reset (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Do not replenish RX buffers after every polling loop (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Use netdev_alloc_skb instead of alloc_skb to replenish RX buffers (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Correctly re-enable interrupts in NAPI polling routine (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Ensure that device queue memory is cache-line aligned (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Remove send_subcrq function (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Clean up TX code and TX buffer data structure (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Introduce xmit_more support using batched subCRQ hcalls (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Introduce batched RX buffer descriptor transmission (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Introduce indirect subordinate Command Response Queue buffer (Diego Domingos) [1901513]
- [netdrv] ibmvnic: fix ibmvnic_set_mac (Diego Domingos) [1901513]
- [netdrv] ibmvnic: save changed mac address to adapter->mac_addr (Diego Domingos) [1901513]
- [netdrv] ibmvnic: create send_control_ip_offload (Diego Domingos) [1901513]
- [netdrv] ibmvnic: create send_query_ip_offload (Diego Domingos) [1901513]
- [netdrv] ibmvnic: rename send_map_query to send_query_map (Diego Domingos) [1901513]
- [netdrv] ibmvnic: rename ibmvnic_send_req_caps to send_request_cap (Diego Domingos) [1901513]
- [netdrv] ibmvnic: rename send_cap_queries to send_query_cap (Diego Domingos) [1901513]
- [netdrv] ibmvnic: set up 200GBPS speed (Diego Domingos) [1901513]
- [netdrv] Revert "ibmvnic: remove never executed if statement" (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Harden device Command Response Queue handshake (Diego Domingos) [1901513]
- [netdrv] ibmvnic: Fix use-after-free of VNIC login response buffer (Diego Domingos) [1901513]
- [netdrv] ibmvnic: merge ibmvnic_reset_init and ibmvnic_init (Diego Domingos) [1901513]
- [netdrv] ibmvnic: remove never executed if statement (Diego Domingos) [1901513]
- [netdrv] ibmvnic: improve ibmvnic_init and ibmvnic_reset_init (Diego Domingos) [1901513]
- [netdrv] ibmvnic: compare adapter->init_done_rc with more readable ibmvnic_rc_codes (Diego Domingos) [1901513]
- [netdrv] ibmvnic: store RX and TX subCRQ handle array in ibmvnic_adapter struct (Diego Domingos) [1901513]
- [netdrv] net: ibm: fix return type of ndo_start_xmit function (Diego Domingos) [1901513]
- [tools] tools arch x86: Sync asm/cpufeatures.h with the kernel sources (David Arcari) [1916478]
- [x86] x86/cpu/amd: Call init_amd_zn() om Family 19h processors too (David Arcari) [1916478]
- [ata] ahci: Add Intel Emmitsburg PCH RAID PCI IDs (David Arcari) [1894284]
- [vfio] vfio iommu: Add dma available capability (Philipp Rudo) [1903970]
- [x86] x86/entry/64: Do not include inst.h in calling.h (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Fix GS == 1, 2, and 3 tests (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Test PTRACE_PEEKUSER for GSBASE with invalid LDT GS (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Reap a forgotten child (Scott Wood) [1490498]
- [x86] x86/fsgsbase: Replace static_cpu_has() with boot_cpu_has() (Scott Wood) [1490498]
- [x86] x86/entry/64: Correct the comment over SAVE_AND_SET_GSBASE (Scott Wood) [1490498]
- [x86] x86/entry/64: Do not use RDPID in paranoid entry to accomodate KVM (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Fix NULL deref in 86_fsgsbase_read_task (Scott Wood) [1490498]
- [x86] x86/fsgsbase: Fix Xen PV support (Scott Wood) [1490498]
- [x86] x86/ptrace: Fix 32-bit PTRACE_SETREGS vs fsbase and gsbase (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Add a missing memory constraint (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Fix a comment in the ptrace_write_gsbase test (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Test GS selector on ptracer-induced GS base write (Scott Wood) [1490498]
- [documentation] Documentation/x86/64: Add documentation for GS/FS addressing mode (Scott Wood) [1490498]
- [x86] x86/elf: Enumerate kernel FSGSBASE capability in AT_HWCAP2 (Scott Wood) [1490498]
- [x86] x86/cpu: Enable FSGSBASE on 64bit by default and add a chicken bit (Scott Wood) [1490498]
- [x86] x86/entry/64: Handle FSGSBASE enabled paranoid entry/exit (Scott Wood) [1490498]
- [x86] x86/entry/64: Remove TRACE_IRQS_*_DEBUG (Scott Wood) [1490498]
- [x86] x86/entry/64: Introduce the FIND_PERCPU_BASE macro (Scott Wood) [1490498]
- [x86] x86/entry/64: Switch CR3 before SWAPGS in paranoid entry (Scott Wood) [1490498]
- [x86] x86/speculation/swapgs: Check FSGSBASE in enabling SWAPGS mitigation (Scott Wood) [1490498]
- [x86] x86/process/64: Use FSGSBASE instructions on thread copy and ptrace (Scott Wood) [1490498]
- [x86] x86/process: Unify copy_thread_tls() (Scott Wood) [1490498]
- [x86] x86/process/64: Use FSBSBASE in switch_to() if available (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Enable FSGSBASE instructions in helper functions (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Add intrinsics for FSGSBASE instructions (Scott Wood) [1490498]
- [x86] x86/cpu: Add 'unsafe_fsgsbase' to enable CR4.FSGSBASE (Scott Wood) [1490498]
- [x86] x86/ptrace: Prevent ptrace from clearing the FS/GS selector (Scott Wood) [1490498]
- [x86] x86/ptrace: Document FSBASE and GSBASE ABI oddities (Scott Wood) [1490498]
- [x86] Revert "x86/ptrace: Prevent ptrace from clearing the FS/GS selector" and fix the test (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Fix some test case bugs (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Test ptracer-induced GSBASE write with FSGSBASE (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Test RD/WRGSBASE (Scott Wood) [1490498]
- [documentation] kbuild: Raise the minimum required binutils version to 2.21 (Scott Wood) [1490498]
- [tools] selftests/x86/fsgsbase: Test ptracer-induced GSBASE write (Scott Wood) [1490498]
- [x86] x86/ptrace: Prevent ptrace from clearing the FS/GS selector (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Fix the base write helper functions (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Clean up various details (Scott Wood) [1490498]
- [x86] x86/segments: Introduce the 'CPUNODE' naming to better document the segment limit CPU/node NR trick (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Factor out FS/GS segment loading from __switch_to() (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Convert the ELF core dump code to the new FSGSBASE helpers (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Make ptrace use the new FS/GS base helpers (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Introduce FS/GS base helper functions (Scott Wood) [1490498]
- [x86] x86/fsgsbase/64: Fix ptrace() to read the FS/GS base accurately (Scott Wood) [1490498]
- [net] esp: select CRYPTO_SEQIV (Vladis Dronov) [1905088]
- [crypto] treewide: Use fallthrough pseudo-keyword (Vladis Dronov) [1905088]
- [crypto] crypto: drbg - always try to free Jitter RNG instance (Vladis Dronov) [1905088]
- [crypto] crypto: drbg - should select CTR (Vladis Dronov) [1905088]
- [crypto] crypto: ctr - no longer needs CRYPTO_SEQIV (Vladis Dronov) [1905088]
- [crypto] crypto: drbg - always seeded with SP800-90B compliant noise source (Vladis Dronov) [1905088]
- [crypto] crypto: jitter - SP800-90B compliance (Vladis Dronov) [1905088]
- [crypto] crypto: jitter - add header to fix buildwarnings (Vladis Dronov) [1905088]
- [crypto] crypto: jitter - fix comments (Vladis Dronov) [1905088]
- [crypto] crypto: jitter - update implementation to 2.1.2 (Vladis Dronov) [1905088]
- [crypto] crypto: drbg - in-place cipher operation for CTR (Vladis Dronov) [1905088]
- [crypto] crypto: drbg - eliminate constant reinitialization of SGL (Vladis Dronov) [1905088]
- [vfio] vfio/pci: Implement ioeventfd thread handler for contended memory lock (Alex Williamson) [1861560]
- [vfio] vfio iommu type1: Fix memory leak in vfio_iommu_type1_pin_pages (Alex Williamson) [1896568]
- [vfio] vfio/pci: Clear token on bypass registration failure (Alex Williamson) [1896568]
- [vfio] vfio/type1: fix dirty bitmap calculation in vfio_dma_rw (Alex Williamson) [1497898]
- [vfio] vfio: fix a missed vfio group put in vfio_pin_pages (Alex Williamson) [1497898]
- [vfio] vfio: add a singleton check for vfio_group_pin_pages (Alex Williamson) [1497898]
- [vfio] vfio/pci: Don't regenerate vconfig for all BARs if !bardirty (Alex Williamson) [1896568]
- [vfio] vfio/pci: Remove redundant declaration of vfio_pci_driver (Alex Williamson) [1896568]
- [uapi] vfio: Fix typo of the device_state (Alex Williamson) [1497898]
- [vfio] vfio/type1: Add proper error unwind for vfio_iommu_replay() (Alex Williamson) [1866141]
- [vfio] vfio-pci: Avoid recursive read-lock usage (Alex Williamson) [1861560]
- [vfio] vfio/type1: Refactor vfio_iommu_type1_ioctl() (Alex Williamson) [1896568]
- [vfio] vfio/pci: Add QAT devices to denylist (Alex Williamson) [1896565]
- [vfio] vfio/pci: Add device denylist (Alex Williamson) [1896565]
- [vfio] vfio/pci: Hold igate across releasing eventfd contexts (Alex Williamson) [1896568]
- [vfio] vfio/type1: Add conditional rescheduling after iommu map failed (Alex Williamson) [1896568]
- [vfio] vfio/pci: Add Intel X550 to hidden INTx devices (Alex Williamson) [1896567]
- [vfio] vfio: Cleanup allowed driver naming (Alex Williamson) [1896568]
- [uapi] vfio/type1: Fix migration info capability ID (Alex Williamson) [1497898]
- [vfio] vfio iommu: typecast corrections (Alex Williamson) [1497898]
- [vfio] vfio iommu: Use shift operation for 64-bit integer division (Alex Williamson) [1497898]
- [vfio] vfio/mdev: Fix reference count leak in add_mdev_supported_type (Alex Williamson) [1896568]
- [vfio] vfio: Selective dirty page tracking if IOMMU backed device pins pages (Alex Williamson) [1497898]
- [vfio] vfio iommu: Add migration capability to report supported features (Alex Williamson) [1497898]
- [vfio] vfio iommu: Update UNMAP_DMA ioctl to get dirty bitmap before unmap (Alex Williamson) [1497898]
- [vfio] vfio iommu: Implementation of ioctl for dirty pages tracking (Alex Williamson) [1497898]
- [uapi] vfio iommu: Add ioctl definition for dirty pages tracking (Alex Williamson) [1497898]
- [vfio] vfio iommu: Cache pgsize_bitmap in struct vfio_iommu (Alex Williamson) [1497898]
- [vfio] vfio iommu: Remove atomicity of ref_count of pinned pages (Alex Williamson) [1497898]
- [uapi] vfio: UAPI for migration interface for device state (Alex Williamson) [1497898]
- [vfio] vfio/pci: Remove dev_fmt definition (Alex Williamson) [1896568]
- [vfio] vfio: Use dev_printk() when possible (Alex Williamson) [1896568]
- [drm] drm: allow limiting the scatter list size (Lyude Paul) [1876018 1851790]
- [drm] drm/nouveau/kms/nv50-: Fix clock checking algorithm in nv50_dp_mode_valid() (Lyude Paul) [1876018]
- [drm] drm/nouveau/kms/nv50-: Get rid of bogus nouveau_conn_mode_valid() (Lyude Paul) [1876018]
- [drm] DRM Backport 5.8 -> 5.9 (Lyude Paul) [1876018]
- [drm] drm/edid: Fix uninitialized variable in drm_cvt_modes() (Lyude Paul) [1876018]
- [of] of_graph: add of_graph_is_present() (Lyude Paul) [1876018]
- [drm] virtio: virtio_has_iommu_quirk -> virtio_has_dma_quirk (Lyude Paul) [1876018]
- [vhost] virtio: VIRTIO_F_IOMMU_PLATFORM -> VIRTIO_F_ACCESS_PLATFORM (Lyude Paul) [1876018]
- [include] virtio_config: LE config space accessors (Lyude Paul) [1876018]
- [kernel] sched: Remove sched_set_*() return value (Lyude Paul) [1876018]
- [include] scatterlist: protect parameters of the sg_table related macros (Lyude Paul) [1876018]
- [include] scatterlist: add generic wrappers for iterating over sgtable objects (Lyude Paul) [1876018]
- [dma] dma-mapping: add generic helpers for mapping sgtable objects (Lyude Paul) [1876018]
- [drm] DRM Backport 5.7 -> 5.8 (Lyude Paul) [1876018]
- [drm] drm/fb-helper: Fix vt restore (Lyude Paul) [1876018]
- [tty] tty/sysrq: constify the the sysrq_key_op(s) (Lyude Paul) [1876018]
- [tools] augmented rbtree: rework the RB_DECLARE_CALLBACKS macro definition (Lyude Paul) [1876018]
- [mm] augmented rbtree: add new RB_DECLARE_CALLBACKS_MAX macro (Lyude Paul) [1876018]
- [tools] augmented rbtree: add comments for RB_DECLARE_CALLBACKS macro (Lyude Paul) [1876018]
- [tools] rbtree: avoid generating code twice for the cached versions (tools copy) (Lyude Paul) [1876018]
- [tty] tty/sysrq: constify the sysrq API (Lyude Paul) [1876018]
- [tty] tty/sysrq: alpha: export and use __sysrq_get_key_op() (Lyude Paul) [1876018]
- [include] uaccess: Add user_read_access_begin/end and user_write_access_begin/end (Lyude Paul) [1876018]
- [PATCH] [drm] DRM Backport 5.6 -> 5.7 (Lyude Paul) [1876018]
- [vfio] vfio: avoid inefficient operations on VFIO group in vfio_pin/unpin_pages (Lyude Paul) [1876018]
- [vfio] vfio: allow external user to get vfio group from device (Lyude Paul) [1876018]
- [drm] drm/fbdev-helper: don't force restores (Lyude Paul) [1876018]
- [include] vgaswitcheroo: call fbcon_remap_all directly (Lyude Paul) [1876018]
- [video] fbcon: Do not takeover the console from atomic context (Lyude Paul) [1878805 1876018]
- [video] fbcon: Only defer console takeover if the current console driver is the dummycon (Lyude Paul) [1878805 1876018]
- [video] fbcon: Only allow FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER if fbdev is builtin (Lyude Paul) [1878805 1876018]
- [video] console/fbcon: Add support for deferred console takeover (Lyude Paul) [1878805 1876018]
- [video] fbcon: Call WARN_CONSOLE_UNLOCKED() where applicable (Lyude Paul) [1878805 1876018]
- [mm] mm: Split huge pages on write-notify or COW (Chris von Recklinghausen) [1913692]
- [mm] mm: Introduce vma_is_special_huge (Chris von Recklinghausen) [1913692]

* Fri Jan 29 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-280.el8]
- [tools] kselftests: set rx/txtimestamp.sh to correct permission (Hangbin Liu) [1908269]
- [tools] kselftests: set udpgro.sh, udpgro_bench.sh, reuseport_addr_any.sh to correct permission (Hangbin Liu) [1908269]
- [net] DCB: Validate DCB_ATTR_DCB_BUFFER argument (Balazs Nemeth) [1891595]
- [net] netlabel: remove unused param from audit_log_format() (Balazs Nemeth) [1891595]
- [net] netlabel: fix problems with mapping removal (Balazs Nemeth) [1891595]
- [net] af_key: pfkey_dump needs parameter validation (Balazs Nemeth) [1891595]
- [tools] perf tools: Add 'evlist' control command (Jiri Olsa) [1844111]
- [tools] perf tools: Allow to enable/disable events via control file (Jiri Olsa) [1844111]
- [tools] perf tools: Add evlist__disable_evsel/evlist__enable_evsel (Jiri Olsa) [1844111]
- [tools] perf tools: Reformat record's control fd man text (Jiri Olsa) [1844111]
- [tools] perf evlist: Use the right prefix for 'struct evlist' 'find' methods (Jiri Olsa) [1844111]
- [tools] perf evlist: Use the right prefix for 'struct evlist' enable event methods (Jiri Olsa) [1844111]
- [tools] perf evlist: Use the right prefix for 'struct evlist' 'toggle' methods (Jiri Olsa) [1844111]
- [x86] perf/amd/uncore: Inform the user how many counters each uncore PMU has (Michael Petlan) [1884816]
- [powercap] powercap: RAPL: Add AMD Fam19h RAPL support (Michael Petlan) [1884816]
- [powercap] powercap: Add AMD Fam17h RAPL support (Michael Petlan) [1884816]
- [powercap] powercap/intel_rapl_msr: Convert rapl_msr_priv into pointer (Michael Petlan) [1884816]
- [x86] x86/msr-index: sort AMD RAPL MSRs by address (Michael Petlan) [1884816]
- [thunderbolt] thunderbolt: Add support for Intel Maple Ridge (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Add USB4 router operation proxy for firmware connection manager (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Move constants for USB4 router operations to tb_regs.h (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Add connection manager specific hooks for USB4 router operations (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Pass TX and RX data directly to usb4_switch_op() (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Pass metadata directly to usb4_switch_op() (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Perform USB4 router NVM upgrade in two phases (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Return -ENOTCONN when ERR_CONN is received (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Keep the parent runtime resumed for a while on device disconnect (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Log adapter numbers in decimal in path activation/deactivation (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Log which connection manager implementation is used (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Move max_boot_acl field to correct place in struct icm (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Fix use-after-free in remove_unplugged_switch() (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Add DMA traffic test driver (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Add support for end-to-end flow control (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Make it possible to allocate one directional DMA tunnel (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Create debugfs directory automatically for services (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Add functions for enabling and disabling lane bonding on XDomain (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Add link_speed and link_width to XDomain (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Create XDomain devices for loops back to the host (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Find XDomain by route instead of UUID (Torez Smith) [1782721]
- [thunderbolt] thunderbolt: Do not clear USB4 router protocol adapter IFC and ISE bits (Torez Smith) [1782721]
- [net] ipv6: fib: flush exceptions when purging route (Hangbin Liu) [1916084]
- [net] ipv6: addrlabel: fix possible memory leak in ip6addrlbl_net_init (Hangbin Liu) [1916084]
- [net] ipv6: remove unused function ipv6_skb_idev() (Hangbin Liu) [1916084]
- [net] ipv6: Fix error path to cancel the meseage (Hangbin Liu) [1916084]
- [tools] selftests/net/fib_tests: update addr_metric_test for peer route testing (Hangbin Liu) [1916084]
- [net] net/ipv6: remove the old peer route if change it to a new one (Hangbin Liu) [1916084]
- [tools] selftests/net: remove not backported tests (Hangbin Liu) [1908340]
- [netdrv] bonding: add a vlan+srcmac tx hashing option (Jarod Wilson) [1724795]
- [security] selinux: mark selinux_xfrm_refcount as __read_mostly (Ondrej Mosnacek) [1904940]
- [net] udp: fix integer overflow while computing available space in sk_rcvbuf (Xin Long) [1916997]
- [fs] NFSv4: make cache consistency bitmask dynamic (Steve Dickson) [1881647]
- [include] NFSv4: Save a few bytes in the nfs_pgio_args/res (Steve Dickson) [1881647]
- [tools] tools headers UAPI: Update tools's copy of linux/perf_event.h (Michael Petlan) [1884818 1908305]
- [tools] perf test: Use generic event for expand_libpfm_events() (Michael Petlan) [1884818 1908305]
- [tools] perf probe: Change function definition check due to broken DWARF (Michael Petlan) [1884818 1908305]
- [tools] perf probe: Fix to die_entrypc() returns error correctly (Michael Petlan) [1884818 1908305]
- [tools] perf stat: Use proper cpu for shadow stats (Michael Petlan) [1884818 1908305]
- [tools] perf record: Synthesize cgroup events only if needed (Michael Petlan) [1884818 1908305]
- [tools] perf diff: Fix error return value in __cmd_diff() (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Update copy of libbpf's hashmap.c (Michael Petlan) [1884818 1908305]
- [tools] perf test: Avoid an msan warning in a copied stack (Michael Petlan) [1884818 1908305]
- [tools] perf inject: Fix file corruption due to event deletion (Michael Petlan) [1884818 1908305]
- [tools] perf test: Update branch sample pattern for cs-etm (Michael Petlan) [1884818 1908305]
- [tools] perf test: Fix a typo in cs-etm testing (Michael Petlan) [1884818 1908305]
- [tools] perf lock: Don't free "lock_seq_stat" if read_count isn't zero (Michael Petlan) [1884818 1908305]
- [tools] perf lock: Correct field name "flags" (Michael Petlan) [1884818 1908305]
- [tools] tools feature: Fixup fast path feature detection (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add missing swap for cgroup events (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add missing swap for ino_generation (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Initialize output buffer in build_id__sprintf (Michael Petlan) [1884818 1908305]
- [tools] perf hists browser: Increase size of 'buf' in perf_evsel__hists_browse() (Michael Petlan) [1884818 1908305]
- [tools] tools headers UAPI: Update tools's copy of linux/perf_event.h (Michael Petlan) [1884818 1908305]
- [tools] perf scripting python: Avoid declaring function pointers with a visibility attribute (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Remove broken __no_tail_call attribute (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events: Fix DRAM_BW_Use 0 issue for CLX/SKX (Michael Petlan) [1884818 1908305]
- [tools] perf trace: Fix segfault when trying to trace events by cgroup (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Fix crash with non-jited bpf progs (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Update copy of libbpf's hashmap.c (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Remove LTO compiler options when building perl support (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Update documentation for metrics reorganization (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Add metrics "RMT Load Hit" (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Correct LLC load hit metrics (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Change header for LLC local hit (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Use more explicit headers for HITM (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Change header from "LLC Load Hitm" to "Load Hitm" (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Organize metrics based on memory hierarchy (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Display "Total Stores" as a standalone metrics (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Display the total numbers continuously (Michael Petlan) [1884818 1908305]
- [tools] perf bench: Use condition variables in numa (Michael Petlan) [1884818 1908305]
- [tools] perf jevents: Fix event code for events referencing std arch events (Michael Petlan) [1884818 1908305]
- [tools] perf diff: Support hot streams comparison (Michael Petlan) [1884818 1908305]
- [tools] perf streams: Report hot streams (Michael Petlan) [1884818 1908305]
- [tools] perf streams: Calculate the sum of total streams hits (Michael Petlan) [1884818 1908305]
- [tools] perf streams: Link stream pair (Michael Petlan) [1884818 1908305]
- [tools] perf streams: Compare two streams (Michael Petlan) [1884818 1908305]
- [tools] perf streams: Get the evsel_streams by evsel_idx (Michael Petlan) [1884818 1908305]
- [tools] perf streams: Introduce branch history "streams" (Michael Petlan) [1884818 1908305]
- [tools] perf intel-pt: Improve PT documentation slightly (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add support for exclusive groups/events (Michael Petlan) [1884818 1908305]
- [tools] perf test: Add build id shell test (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Align buildid list output for short build ids (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add size to 'struct perf_record_header_build_id' (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Pass build_id object to dso__build_id_equal() (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Pass build_id object to dso__set_build_id() (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Pass build_id object to build_id__sprintf() (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Pass build id object to sysfs__read_build_id() (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Pass build_id object to filename__read_build_id() (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Use build_id object in dso (Michael Petlan) [1884818 1908305]
- [tools] perf config: Export the perf_config_from_file() function (Michael Petlan) [1884818 1908305]
- [tools] perf python: Autodetect python3 binary (Michael Petlan) [1884818 1908305]
- [tools] perf tests: Show python test script in verbose mode (Michael Petlan) [1884818 1908305]
- [tools] perf c2c: Update usage for showing memory events (Michael Petlan) [1884818 1908305]
- [tools] perf stat: Fix out of bounds CPU map access when handling armv8_pmu events (Michael Petlan) [1884818 1908305]
- [tools] perf python scripting: Fix printable strings in python3 scripts (Michael Petlan) [1884818 1908305]
- [tools] perf metricgroup: Fix uncore metric expressions (Michael Petlan) [1884818 1908305]
- [tools] perf parse-event: Release cpu_map refcount if evsel alloc failed (Michael Petlan) [1884818 1908305]
- [tools] perf parse-event: Fix cpu map refcounting (Michael Petlan) [1884818 1908305]
- [tools] tools lib traceevent: Hide non API functions (Michael Petlan) [1884818 1908305]
- [tools] perf sched: Show start of latency as well (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events: Fix typos in power8 PMU events (Michael Petlan) [1884818 1908305]
- [tools] perf bench: Run inject-build-id with --buildid-all option too (Michael Petlan) [1884818 1908305]
- [tools] perf inject: Add --buildid-all option (Michael Petlan) [1884818 1908305]
- [tools] perf inject: Do not load map/dso when injecting build-id (Michael Petlan) [1884818 1908305]
- [tools] perf inject: Enter namespace when reading build-id (Michael Petlan) [1884818 1908305]
- [tools] perf inject: Add missing callbacks in perf_tool (Michael Petlan) [1884818 1908305]
- [tools] perf bench: Add build-id injection benchmark (Michael Petlan) [1884818 1908305]
- [tools] perf trace: Use the autogenerated mmap 'prot' string/id table (Michael Petlan) [1884818 1908305]
- [tools] tools beauty: Add script to generate table of mmap's 'prot' argument (Michael Petlan) [1884818 1908305]
- [tools] perf beauty mmap_flags: Conditionaly define the mmap flags (Michael Petlan) [1884818 1908305]
- [tools] perf trace beauty: Add script to autogenerate mremap's flags args string/id table (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Separate the checking of headers only used to build beautification tables (Michael Petlan) [1884818 1908305]
- [tools] perf parse-events: Reduce casts around bp_addr (Michael Petlan) [1884818 1908305]
- [tools] perf test: Add expand cgroup event test (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Allow creation of cgroup without open (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Copy metric events properly when expand cgroups (Michael Petlan) [1884818 1908305]
- [tools] perf stat: Add --for-each-cgroup option (Michael Petlan) [1884818 1908305]
- [tools] perf evsel: Add evsel__clone() function (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events: Update SkylakeX events to v1.21 (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events intel: Update CascadelakeX events to v1.08 (Michael Petlan) [1884818 1908305]
- [tools] perf script: Add min, max to futex-contention output, in addition to avg (Michael Petlan) [1884818 1908305]
- [tools] perf script: Autopep8 futex-contention (Michael Petlan) [1884818 1908305]
- [tools] perf stat: Skip duration_time in setup_system_wide (Michael Petlan) [1884818 1908305]
- [tools] perf tsc: Support cap_user_time_short for event TIME_CONV (Michael Petlan) [1884818 1908305]
- [tools] perf tsc: Calculate timestamp with cap_user_time_short (Michael Petlan) [1884818 1908305]
- [tools] perf tsc: Add rdtsc() for Arm64 (Michael Petlan) [1884818 1908305]
- [tools] perf tsc: Move out common functions from x86 (Michael Petlan) [1884818 1908305]
- [tools] perf probe: Fall back to debuginfod query if debuginfo and source not found locally (Michael Petlan) [1884818 1908305]
- [tools] perf probe: Fix to adjust symbol address with correct reloc_sym address (Michael Petlan) [1884818 1908305]
- [tools] perf intel-pt: Fix "context_switch event has no tid" error (Michael Petlan) [1884818 1908305]
- [tools] perf script: Display negative tid in non-sample events (Michael Petlan) [1884818 1908305]
- [tools] perf docs: Improve help information in perf.txt (Michael Petlan) [1884818 1908305]
- [tools] perf metric: Remove duplicate include (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add documentation for topdown metrics (Michael Petlan) [1884818 1908305]
- [tools] perf stat: Support new per thread TopDown metrics (Michael Petlan) [1884818 1908305]
- [tools] perf record: Support sample-read topdown metric group (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Rename group to topdown (Michael Petlan) [1884818 1908305]
- [tools] perf machine: Add machine__for_each_dso() function (Michael Petlan) [1884818 1908305]
- [tools] perf tests: Call test_attr__open() directly (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events power9: Add hv_24x7 core level metric events (Michael Petlan) [1884818 1908305]
- [tools] perf metricgroup: Pass pmu_event structure as a parameter for arch_get_runtimeparam() (Michael Petlan) [1884818 1908305]
- [tools] perf jevents: Add support for parsing perchip/percore events (Michael Petlan) [1884818 1908305]
- [tools] perf jevents: Add new structure to pass json fields (Michael Petlan) [1884818 1908305]
- [tools] perf jevents: Make json_events() static and ditch jevents.h file (Michael Petlan) [1884818 1908305]
- [tools] perf test: Introduce script for Arm CoreSight testing (Michael Petlan) [1884818 1908305]
- [tools] perf metricgroup: Fix typo in comment (Michael Petlan) [1884818 1908305]
- [tools] perf stat: Remove dead code: no need to set os.evsel twice (Michael Petlan) [1884818 1908305]
- [tools] perf list: Do not print 'Metric Groups:' unnecessarily (Michael Petlan) [1884818 1908305]
- [tools] perf list: Remove dead code in argument check (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add build test with GTK+ (Michael Petlan) [1884818 1908305]
- [tools] tools feature: Add missing -lzstd to the fast path feature detection (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Make GTK2 support opt-in (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events amd: Enable Family 19h users by matching Zen2 events (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events amd: Add recommended events (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events amd: Add ITLB Instruction Fetch Hits event for zen1 (Michael Petlan) [1884818 1908305]
- [tools] perf vendor events amd: Add L2 Prefetch events for zen1 (Michael Petlan) [1884818 1908305]
- [tools] perf: ftrace: Add filter support for option -F/--funcs (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Consolidate close_control_option()'s into one function (Michael Petlan) [1884818 1908305]
- [tools] perf intel-pt: Document snapshot control command (Michael Petlan) [1884818 1908305]
- [tools] perf annotate: Add 'ret' (intel disasm style) as an alias for 'retq' (Michael Petlan) [1884818 1908305]
- [tools] perf annotate: Allow configuring the 'disassembler_style' knob via 'perf config' (Michael Petlan) [1884818 1908305]
- [tools] perf record: Add 'snapshot' control command (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Add FIFO file names as alternative options to --control (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Use AsciiDoc formatting for --control option documentation (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Handle read errors from ctl_fd (Michael Petlan) [1884818 1908305]
- [tools] perf tools: Consolidate --control option parsing into one function (Michael Petlan) [1884818 1908305]
- [tools] perf tests: Add test for PE binary format support (Michael Petlan) [1884818 1908305]
- [tools] perf symbols: Try reading the symbol table with libbfd (Michael Petlan) [1884818 1908305]
- [tools] perf dso: Use libbfd to read build_id and .gnu_debuglink section (Michael Petlan) [1884818 1908305]
- [tools] tools features: Add feature test to check if libbfd has buildid support (Michael Petlan) [1884818 1908305]
- [tools] tools: Remove feature-libelf-mmap feature detection (Michael Petlan) [1884818 1908305]
- [tools] perf build: Allow nested externs to enable BUILD_BUG() usage (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Check PEBS status correctly (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Fix a warning on x86_pmu_stop() with large PEBS (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: fix sysfs type mismatches (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Make anythread filter support conditional (Michael Petlan) [1884818 1908305]
- [kernel] perf: Tweak perf_event_attr::exclusive semantics (Michael Petlan) [1884818 1908305]
- [kernel] perf: Fix event multiplexing for exclusive groups (Michael Petlan) [1884818 1908305]
- [kernel] perf: Simplify group_sched_in() (Michael Petlan) [1884818 1908305]
- [kernel] perf: Simplify group_sched_out() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: Make dummy_iregs static (Michael Petlan) [1884818 1908305]
- [include] perf/arch: Remove perf_sample_data::regs_user_copy (Michael Petlan) [1884818 1908305]
- [kernel] perf: Optimize get_recursion_context() (Michael Petlan) [1884818 1908305]
- [kernel] perf: Fix get_recursion_context() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: Reduce stack usage for x86_pmu::drain_pebs() (Michael Petlan) [1884818 1908305]
- [kernel] perf: Reduce stack usage of perf_output_begin() (Michael Petlan) [1884818 1908305]
- [kernel] perf/core: Fix a memory leak in perf_event_parse_addr_filter() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: Fix n_metric for cancelled txn (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: Fix n_pair for cancelled txn (Michael Petlan) [1884818 1908305]
- [x86] x86/events/amd/iommu: Fix sizeof mismatch (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Check perf metrics feature for each CPU (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Fix Ice Lake event constraint table (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/msr: Add Jasper Lake support (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Add Jasper Lake support (Michael Petlan) [1884818 1908305]
- [x86] perf/amd/uncore: Allow F19h user coreid, threadmask, and sliceid specification (Michael Petlan) [1884818 1908305]
- [x86] perf/amd/uncore: Allow F17h user threadmask and slicemask specification (Michael Petlan) [1884818 1908305]
- [x86] perf/amd/uncore: Prepare to scale for more attributes that vary per family (Michael Petlan) [1884818 1908305]
- [x86] arch/x86/amd/ibs: Fix re-arming IBS Fetch (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/rapl: Add AMD Fam19h RAPL support (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/amd/ibs: Support 27-bit extended Op/cycle counter (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/amd/ibs: Fix raw sample data accumulation (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/amd/ibs: Don't include randomized bits in get_ibs_op_count() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/amd: Fix sampling Large Increment per Cycle events (Michael Petlan) [1884818 1908305]
- [x86] perf/amd/uncore: Set all slices and threads to restore perf stat -a behaviour (Michael Petlan) [1884818 1908305]
- [kernel] perf/core: Pull pmu::sched_task() into perf_event_context_sched_out() (Michael Petlan) [1884818 1908305]
- [kernel] perf/core: Pull pmu::sched_task() into perf_event_context_sched_in() (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel/ds: Fix x86_pmu_stop warning for large PEBS (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Support per-thread RDPMC TopDown metrics (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Support TopDown metrics on Ice Lake (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: Add a macro for RDPMC offset of fixed counters (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Generic support for hardware TopDown metrics (Michael Petlan) [1884818 1908305]
- [kernel] perf/core: Add a new PERF_EV_CAP_SIBLING event capability (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Use switch in intel_pmu_disable/enable_event (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Fix the name of perf METRICS (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Move BTS index to 47 (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Introduce the fourth fixed counter (Michael Petlan) [1884818 1908305]
- [x86] perf/x86/intel: Name the global status bit in NMI handler (Michael Petlan) [1884818 1908305]
- [x86] perf/x86: Use event_base_rdpmc for the RDPMC userspace support (Michael Petlan) [1884818 1908305]
- [powerpc] powerpc/cacheinfo: Print correct cache-sibling map/list for L2 cache (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Add support detecting thread-groups sharing L2 cache (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Rename init_thread_group_l1_cache_map() to make it generic (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Rename cpu_l1_cache_map as thread_group_l1_cache_map (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Parse ibm, thread-groups with multiple properties (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Use GFP_ATOMIC while allocating tmp mask (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Remove unnecessary variable (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Optimize update_coregroup_mask (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Move coregroup mask updation to a new function (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Optimize update_mask_by_l2 (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Check for duplicate topologies and consolidate (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Depend on cpu_l1_cache_map when adding CPUs (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Stop passing mask to update_mask_by_l2 (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Limit CPUs traversed to within a node (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Optimize remove_cpu_from_masks (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Remove get_physical_package_id (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Stop updating cpu_core_mask (Diego Domingos) [1906504]
- [powerpc] powerpc/topology: Update topology_core_cpumask (Diego Domingos) [1906504]
- [powerpc] powerpc/topology: Override cpu_smt_mask (Diego Domingos) [1906504]
- [include] sched/topology: Allow archs to override cpu_smt_mask (Diego Domingos) [1906504]
- [powerpc] powerpc/cacheinfo: Add per cpu per index shared_cpu_list (Diego Domingos) [1906504]
- [powerpc] powerpc/cacheinfo: Make cpumap_show code reusable (Diego Domingos) [1906504]
- [powerpc] powerpc/cacheinfo: Use cpumap_print to print cpumap (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Use IS_ENABLED() to avoid #ifdef (Diego Domingos) [1906504]
- [powerpc] powerpc/smp: Drop superfluous NULL check (Diego Domingos) [1906504]
- [vfio] pci: Cleanup .probe() exit paths (Clark Williams) [1860192]
- [vfio] pci: Add sriov_configure support (Clark Williams) [1860192]
- [vfio] Introduce VFIO_DEVICE_FEATURE ioctl and first user (Clark Williams) [1860192]
- [vfio] pci: Introduce VF token (Clark Williams) [1860192]
- [vfio] pci: Implement match ops (Clark Williams) [1860192]
- [vfio] Include optional device match in vfio_device_ops callbacks (Clark Williams) [1860192]
- [infiniband] IB/hfi1: Ensure correct mm is used at all times (Kamal Heib) [1879586] {CVE-2020-27835}
- [block] rbd: require global CAP_SYS_ADMIN for mapping and unmapping (Ming Lei) [1887327] {CVE-2020-25284}

* Tue Jan 26 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-279.el8]
- [tools] kunit: tool: unmark test_data as binary blobs (Nico Pache) [1900119]
- [tools] kunit: tools: fix kunit_tool tests for parsing test plans (Nico Pache) [1900119]
- [documentation] Documentation: kunit: Update Kconfig parts for KUNIT's module support (Nico Pache) [1900119]
- [tools] kunit: Don't fail test suites if one of them is empty (Nico Pache) [1900119]
- [tools] kunit: Fix kunit.py --raw_output option (Nico Pache) [1900119]
- [tools] kunit: tool: fix improper treatment of file location (Nico Pache) [1900119]
- [tools] kunit: tool: fix broken default args in unit tests (Nico Pache) [1900119]
- [tools] kunit: capture stderr on all make subprocess calls (Nico Pache) [1900119]
- [documentation] Documentation: kunit: Remove references to --defconfig (Nico Pache) [1900119]
- [kernel] kcsan: Add test suite (Nico Pache) [1900119]
- [documentation] Documentation: kunit: Add some troubleshooting tips to the FAQ (Nico Pache) [1900119]
- [tools] kunit: kunit_tool: Fix invalid result when build fails (Nico Pache) [1900119]
- [tools] kunit: show error if kunit results are not present (Nico Pache) [1900119]
- [tools] kunit: kunit_config: Fix parsing of CONFIG options with space (Nico Pache) [1900119]
- [lib] kunit: add support for named resources (Nico Pache) [1900119]
- [lib] kunit: generalize kunit_resource API beyond allocated resources (Nico Pache) [1900119]
- [security] security: apparmor: default KUNIT_* fragments to KUNIT_ALL_TESTS (Nico Pache) [1900119]
- [fs] fs: ext4: default KUNIT_* fragments to KUNIT_ALL_TESTS (Nico Pache) [1900119]
- [base] drivers: base: default KUNIT_* fragments to KUNIT_ALL_TESTS (Nico Pache) [1900119]
- [lib] lib: Kconfig.debug: default KUNIT_* fragments to KUNIT_ALL_TESTS (Nico Pache) [1900119]
- [lib] kunit: default KUNIT_* fragments to KUNIT_ALL_TESTS (Nico Pache) [1900119]
- [lib] kunit: Kconfig: enable a KUNIT_ALL_TESTS fragment (Nico Pache) [1900119]
- [tools] kunit: Fix TabError, remove defconfig code and handle when there is no kunitconfig (Nico Pache) [1900119]
- [tools] kunit: use KUnit defconfig by default (Nico Pache) [1900119]
- [tools] kunit: use --build_dir=.kunit as default (Nico Pache) [1900119]
- [tools] kunit: kunit_tool: Separate out config/build/exec/parse (Nico Pache) [1900119]
- [lib] lib/test_linear_ranges: add a test for the 'linear_ranges' (Nico Pache) [1900119]
- [lib] kunit: Add missing newline in summary message (Nico Pache) [1900119]
- [tools] kunit: tool: add missing test data file content (Nico Pache) [1900119]
- [documentation] kunit: update documentation to describe debugfs representation (Nico Pache) [1900119]
- [lib] kunit: subtests should be indented 4 spaces according to TAP (Nico Pache) [1900119]
- [lib] kunit: add log test (Nico Pache) [1900119]
- [lib] kunit: add debugfs /sys/kernel/debug/kunit/<suite>/results display (Nico Pache) [1900119]
- [documentation] Documentation: kunit: Make the KUnit documentation less UML-specific (Nico Pache) [1900119]
- [lib] Fix linked-list KUnit test when run multiple times (Nico Pache) [1900119]
- [tools] kunit: kunit_tool: Allow .kunitconfig to disable config items (Nico Pache) [1900119]
- [lib] kunit: Always print actual pointer values in asserts (Nico Pache) [1900119]
- [tools] kunit: add --make_options (Nico Pache) [1900119]
- [tools] kunit: Run all KUnit tests through allyesconfig (Nico Pache) [1900119]
- [tools] kunit: kunit_parser: make parser more robust (Nico Pache) [1900119]
- [of] of: unittest: annotate warnings triggered by unittest (Nico Pache) [1900119]
- [of] of: unittest: Disable interrupt node tests for old world MAC systems (Nico Pache) [1900119]
- [of] of: unittest: add overlay gpio test to catch gpio hog problem (Nico Pache) [1900119]
- [tools] kunit: run kunit_tool from any directory (Nico Pache) [1900119]
- [tools] kunit: test: Improve error messages for kunit_tool when kunitconfig is invalid (Nico Pache) [1900119]
- [documentation] Documentation: kunit: fixed sphinx error in code block (Nico Pache) [1900119]
- [base] software node: introduce CONFIG_KUNIT_DRIVER_PE_TEST (Nico Pache) [1900119]
- [base] kunit: building kunit as a module breaks allmodconfig (Nico Pache) [1900119]
- [documentation] kunit: update documentation to describe module-based build (Nico Pache) [1900119]
- [lib] kunit: allow kunit to be loaded as a module (Nico Pache) [1900119]
- [lib] kunit: remove timeout dependence on sysctl_hung_task_timeout_seconds (Nico Pache) [1900119]
- [lib] kunit: allow kunit tests to be loaded as a module (Nico Pache) [1900119]
- [lib] kunit: hide unexported try-catch interface in try-catch-impl.h (Nico Pache) [1900119]
- [lib] kunit: move string-stream.h to lib/kunit (Nico Pache) [1900119]
- [security] apparmor: add AppArmor KUnit tests for policy unpack (Nico Pache) [1900119]
- [tools] kunit/kunit_tool_test: Test '--build_dir' option run (Nico Pache) [1900119]
- [tools] kunit: Rename 'kunitconfig' to '.kunitconfig' (Nico Pache) [1900119]
- [tools] kunit: Place 'test.log' under the 'build_dir' (Nico Pache) [1900119]
- [tools] kunit: Create default config in '--build_dir' (Nico Pache) [1900119]
- [tools] kunit: Remove duplicated defconfig creation (Nico Pache) [1900119]
- [documentation] docs/kunit/start: Use in-tree 'kunit_defconfig' (Nico Pache) [1900119]
- [documentation] Documentation: kunit: add documentation for kunit_tool (Nico Pache) [1900119]
- [documentation] Documentation: kunit: fix typos and gramatical errors (Nico Pache) [1900119]
- [tools] kunit: testing kunit: Bug fix in test_run_timeout function (Nico Pache) [1900119]
- [base] PM / QoS: Initial kunit test (Nico Pache) [1900119]
- [lib] lib/list-test: add a test for the 'list' doubly linked list (Nico Pache) [1900119]
- [fs] ext4: add kunit test for decoding extended timestamps (Nico Pache) [1900119]
- [documentation] Documentation: kunit: Fix verification command (Nico Pache) [1900119]
- [tools] kunit: Fix '--build_dir' option (Nico Pache) [1900119]
- [lib] kunit: fix failure to build without printk (Nico Pache) [1900119]
- [kernel] kernel/sysctl-test: Add null pointer test for sysctl.c:proc_dointvec() (Nico Pache) [1900119]
- [documentation] Documentation: kunit: add documentation for KUnit (Nico Pache) [1900119]
- [tools] kunit: defconfig: add defconfigs for building KUnit tests (Nico Pache) [1900119]
- [tools] kunit: tool: add Python wrappers for running KUnit tests (Nico Pache) [1900119]
- [lib] kunit: test: add tests for KUnit managed resources (Nico Pache) [1900119]
- [lib] kunit: test: add the concept of assertions (Nico Pache) [1900119]
- [lib] kunit: test: add tests for kunit test abort (Nico Pache) [1900119]
- [lib] kunit: test: add support for test abort (Nico Pache) [1900119]
- [tools] objtool: add kunit_try_catch_throw to the noreturn list (Nico Pache) [1900119]
- [tools] objtool: Add rewind_stack_do_exit() to the noreturn list (Nico Pache) [1900119]
- [lib] kunit: test: add initial tests (Nico Pache) [1900119]
- [lib] lib: enable building KUnit in lib/ (Nico Pache) [1900119]
- [lib] kunit: test: add the concept of expectations (Nico Pache) [1900119]
- [lib] kunit: test: add assertion printing library (Nico Pache) [1900119]
- [lib] kunit: test: add string_stream a std::stream like string builder (Nico Pache) [1900119]
- [lib] kunit: test: add test resource management API (Nico Pache) [1900119]
- [lib] kunit: test: add KUnit test runner core (Nico Pache) [1900119]
- [watchdog] watchdog/hpwdt: Reflect changes (Joseph Szczypek) [1905293]
- [watchdog] watchdog/hpwdt: Disable NMI in Crash Kernel (Joseph Szczypek) [1905293]
- [idle] intel_idle: add SnowRidge C-state table (Steve Best) [1838554]
- [mm] mm: memcg/slab: fix use after free in obj_cgroup_charge (Waiman Long) [1916962]
- [mm] mm: memcg/slab: fix return of child memcg objcg for root memcg (Waiman Long) [1916962]
- [mm] mm: memcg/slab: fix obj_cgroup_charge() return value handling (Waiman Long) [1916962]
- [mm] mm: kmem: move memcg_kmem_bypass() calls to get_mem/obj_cgroup_from_current() (Waiman Long) [1916962]
- [s390] s390/kexec_file: fix diag308 subcode when loading crash kernel (Philipp Rudo) [1897184]
- [net] ethtool: fix error paths in ethnl_set_channels() (Ivan Vecera) [1906682]
- [powerpc] powerpc/pci: Remove LSI mappings on device teardown (Diego Domingos) [1909722]
- [powerpc] Revert "powerpc/pci: unmap legacy INTx interrupts of passthrough IO adapters" (Diego Domingos) [1909722]
- [block] block: add blk_alloc_queue declaration back (Ming Lei) [1911343]
- [net] tcp: only postpone PROBE_RTT if RTT is < current min_rtt estimate (Antoine Tenart) [1901863]
- [net] tcp_bbr: improve arithmetic division in bbr_update_bw() (Antoine Tenart) [1901863]
- [net] tcp_bbr: clarify that bbr_bdp() rounds up in comments (Antoine Tenart) [1901863]
- [net] tcp_bbr: adapt cwnd based on ack aggregation estimation (Antoine Tenart) [1901863]
- [net] tcp_bbr: fix bbr pacing rate for internal pacing (Antoine Tenart) [1901863]

* Sat Jan 23 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-278.el8]
- [wireless] iwlwifi: fw: acpi: Demote non-conformant function headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: fw: dbg: Fix misspelling of 'reg_data' in function header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-phy-db: Add missing struct member description for 'trans' (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-eeprom-parse: Fix 'struct iwl_eeprom_enhanced_txpwr's header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-eeprom-read: Demote one nonconformant function header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: rs: Demote non-conformant function documentation headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-drv: Fix fall-through warnings for Clang (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: Fix fall-through warnings for Clang (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: Fix fall-through warnings for Clang (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: validate notification size when waiting (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: purge the BSS table upon firmware load (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: check that statistics TLV version match struct version (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add size checks for range response notification (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: hook up missing RX handlers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: tighten RX MPDU bounds checks (Jarod Wilson) [1857772]
- [wireless] iwlwifi: Add a new card for MA family (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: disconnect if channel switch delay is too long (Jarod Wilson) [1857772]
- [wireless] iwlwifi: support firmware reset handshake (Jarod Wilson) [1857772]
- [wireless] iwlwifi: add an extra firmware state in the transport (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: fix a race in CSA that caused assert 0x3420 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: validate firmware sync response size (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: clean up some rx code (Jarod Wilson) [1857772]
- [wireless] iwlwifi: use SPDX tags (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dbg-tlv: fix old length in is_trig_data_contained() (Jarod Wilson) [1857772]
- [wireless] iwlwifi: trans: consider firmware dead after errors (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: remove unnecessary setting of inta_mask (Jarod Wilson) [1857772]
- [wireless] iwlwifi: fw: file: fix documentation for SAR flag (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: remove MSIX_HW_INT_CAUSES_REG_IML handling (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: clean up scan state on failure (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: do more useful queue sync accounting (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: fix 22000 series driver NMI (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: change 12k A-MSDU config to use 16k buffers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: move iwl_mvm_stop_device() out of line (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: clear up iwl_mvm_notify_rx_queue() argument type (Jarod Wilson) [1857772]
- [wireless] iwlwifi: remove sw_csum_tx (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: validate RX descriptor length (Jarod Wilson) [1857772]
- [wireless] iwlwifi: validate MPDU length against notification length (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: iterate active stations when updating statistics (Jarod Wilson) [1857772]
- [wireless] iwlwifi: sort out the NVM offsets (Jarod Wilson) [1857772]
- [wireless] iwlwifi: fix typo in comment (Jarod Wilson) [1857772]
- [wireless] iwlwifi: follow the new inclusive terminology (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: remove the read_nvm from iwl_run_unified_mvm_ucode (Jarod Wilson) [1857772]
- [wireless] iwlwifi: avoid endless HW errors at assert time (Jarod Wilson) [1857772]
- [wireless] iwlwifi: enable sending/setting debug host event (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add support for 6GHz (Jarod Wilson) [1857772]
- [wireless] iwlwifi: copy iwl_he_capa for modifications (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: remove obsolete pre-release support code (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: remove the read_nvm from iwl_run_init_mvm_ucode (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: Init error table memory to zero (Jarod Wilson) [1857772]
- [wireless] iwlwifi: d3: do not send the WOWLAN_CONFIGURATION command for netdetect (Jarod Wilson) [1857772]
- [wireless] iwlwifi: move reclaim flows to the queue file (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: fix sar profile printing issue (Jarod Wilson) [1857772]
- [wireless] iwlwifi: yoyo: align the write pointer to DWs (Jarod Wilson) [1857772]
- [wireless] iwlwifi: yoyo: add the ability to dump phy periphery (Jarod Wilson) [1857772]
- [wireless] iwlwifi: remove all queue resources before free (Jarod Wilson) [1857772]
- [wireless] wireless: remove unneeded break (Jarod Wilson) [1857772]
- [net] nl80211/cfg80211: fix potential infinite loop (Jarod Wilson) [1857772]
- [net] cfg80211: select CONFIG_CRC32 (Jarod Wilson) [1857772]
- [net] nl80211/cfg80211: support 6 GHz scanning (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: add some missing entries for AX210 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: invert values of NO_160 device config entries (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: add one missing entry for AX210 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: fix kernel panic in case of assert during CSA (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: set LTR to avoid completion timeout (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: write queue_sync_state only for sync (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: properly cancel a session protection for P2P (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: use the HOT_SPOT_CMD to cancel an AUX ROC (Jarod Wilson) [1857772]
- [wireless] iwlwifi: sta: set max HE max A-MPDU according to HE capa (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: limit memory read spin time (Jarod Wilson) [1857772]
- [wireless] Revert "iwlwifi: remove wide_cmd_header field" (Jarod Wilson) [1857772]
- [wireless] iwlwifi: bump FW API to 59 for AX devices (Jarod Wilson) [1857772]
- [wireless] iwlwifi: read and parse PNVM file (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: implement set_pnvm op (Jarod Wilson) [1857772]
- [wireless] iwlwifi: add trans op to set PNVM (Jarod Wilson) [1857772]
- [wireless] iwlwifi: move PNVM implementation to common code (Jarod Wilson) [1857772]
- [wireless] iwlwifi: rs: align to new TLC config command API (Jarod Wilson) [1857772]
- [wireless] iwlwifi: fix sar geo table initialization (Jarod Wilson) [1857772]
- [wireless] iwlwifi: stats: add new api fields for statistics cmd/ntfy (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: fix suspicious rcu usage warnings (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: remove memset of kek_kck command (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: don't send a CSA command the firmware doesn't know (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: fix the xtal latency value for a few qu devices (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: fix xtal latency for 9560 devices (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: fix 0x271B and 0x271C trans cfg struct (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: avoid possible NULL pointer dereference (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: support ADD_STA_CMD_API_S ver 12 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add a get lmac id function (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: prepare roc_done_wk to work sync (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: re-enable TX after channel switch (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: don't send RFH_QUEUE_CONFIG_CMD with no queues (Jarod Wilson) [1857772]
- [wireless] iwlwifi: support an additional Qu subsystem id (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: stop claiming NL80211_EXT_FEATURE_SET_SCAN_DWELL (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: ring the doorbell and wait for PNVM load completion (Jarod Wilson) [1857772]
- [wireless] iwlwifi: update prph scratch structure to include PNVM data (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: read and parse SKU ID if available (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: get number of stations from TLV (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-drv: Provide descriptions debugfs dentries (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: devices: Fix function documentation formatting issues (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: tx: Demote misuse of kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: rxon: Demote non-conformant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: scan: Demote a few nonconformant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: utils: Fix some doc-rot (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: Demote a couple of nonconformant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: ops: Remove unused static struct 'iwl_mvm_debug_names' (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: sta: Demote a bunch of nonconformant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: calib: Demote seemingly unintentional kerneldoc header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: lib: Demote non-compliant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: tx: Demote non-compliant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: rs: Demote non-compliant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dvm: Demote non-compliant kernel-doc headers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: bump FW API to 57 for AX devices (Jarod Wilson) [1857772]
- [wireless] iwlwifi: yoyo: add support for internal buffer allocation in D3 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: api: fix u32 -> __le32 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: use correct group for alive notification (Jarod Wilson) [1857772]
- [wireless] iwlwifi: support version 5 of the alive notification (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: ignore the scan duration parameter (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dbg: add debug host notification (DHN) time point (Jarod Wilson) [1857772]
- [wireless] iwlwifi: pcie: make iwl_pcie_txq_update_byte_cnt_tbl bus independent (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: clear all scan UIDs (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: d3: parse wowlan status version 11 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: align RX status flags with firmware (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: remove redundant log in iwl_mvm_tvqm_enable_txq() (Jarod Wilson) [1857772]
- [wireless] iwlwifi: phy-ctxt: add new API VER 3 for phy context cmd (Jarod Wilson) [1857772]
- [wireless] iwlwifi: thermal: support new temperature measurement API (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add d3 prints (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: d3: support GCMP ciphers (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: support more GTK rekeying algorithms (Jarod Wilson) [1857772]
- [wireless] iwlwifi: move all bus-independent TX functions to common code (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: initiator: add option for adding a PASN responder (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: responder: allow to set only the HLTK for an associated station (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: location: set the HLTK when PASN station is added (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: Add FTM initiator RTT smoothing logic (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add support for responder dynamic config command version 3 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add support for range request command ver 11 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: remove wide_cmd_header field (Jarod Wilson) [1857772]
- [wireless] iwlwifi: fw: add default value for iwl_fw_lookup_cmd_ver (Jarod Wilson) [1857772]
- [wireless] iwlwifi: acpi: in non acpi compilations remove iwl_sar_geo_init (Jarod Wilson) [1857772]
- [wireless] iwlwifi: rs: set RTS protection for all non legacy rates (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: support new KEK KCK api (Jarod Wilson) [1857772]
- [wireless] iwlwifi: support version 3 of GEO_TX_POWER_LIMIT (Jarod Wilson) [1857772]
- [wireless] iwlwifi: acpi: rename geo structs to contain versioning (Jarod Wilson) [1857772]
- [wireless] iwlwifi: support REDUCE_TX_POWER_CMD version 6 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: acpi: prepare SAR profile selection code for multiple sizes (Jarod Wilson) [1857772]
- [wireless] iwlwifi: add a common struct for all iwl_tx_power_cmd versions (Jarod Wilson) [1857772]
- [wireless] iwlwifi: add new card for MA family (Jarod Wilson) [1857772]
- [wireless] iwlwifi: acpi: remove dummy definition of iwl_sar_set_profile() (Jarod Wilson) [1857772]
- [wireless] iwlwifi: remove iwl_validate_sar_geo_profile() export (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: use CHECKSUM_COMPLETE (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: remove redundant support_umac_log field (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add support for new WOWLAN_TSC_RSC_PARAM version (Jarod Wilson) [1857772]
- [wireless] iwlwifi: don't export acpi functions unnecessarily (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: process ba-notifications also when sta rcu is invalid (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add support for new version of WOWLAN_TKIP_SETTING_API_S (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: Don't install CMAC/GMAC key in AP mode (Jarod Wilson) [1857772]
- [wireless] iwl-trans: move dev_cmd_offs, page_offs to a common trans header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: regulatory: regulatory capabilities api change (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dbg: add dumping special device memory (Jarod Wilson) [1857772]
- [wireless] iwlwifi: dbg: remove IWL_FW_INI_TIME_POINT_WDG_TIMEOUT (Jarod Wilson) [1857772]
- [wireless] iwlwifi: acpi: support ppag table command v2 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: add new cards for MA family (Jarod Wilson) [1857772]
- [wireless] iwlwifi: move bc_table_dword to a common trans header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-trans: move tfd to trans layer (Jarod Wilson) [1857772]
- [wireless] iwlwifi: move bc_pool to a common trans header (Jarod Wilson) [1857772]
- [wireless] iwlwifi: iwl-trans: move all txcmd init to trans alloc (Jarod Wilson) [1857772]
- [wireless] iwlwifi: enable twt by default (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add an option to add PASN station (Jarod Wilson) [1857772]
- [wireless] iwlwifi: add new cards for AX201 family (Jarod Wilson) [1857772]
- [wireless] iwlwifi: fw: move assert descriptor parser to common code (Jarod Wilson) [1857772]
- [wireless] iwlwifi: wowlan: adapt to wowlan status API version 10 (Jarod Wilson) [1857772]
- [wireless] iwlwifi: acpi: evaluate dsm to disable 5.8GHz channels (Jarod Wilson) [1857772]
- [wireless] iwlwifi: msix: limit max RX queues for 9000 family (Jarod Wilson) [1857772]
- [wireless] iwlwifi: sta: defer ADDBA transmit in case reclaimed SN != next SN (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: set PROTECTED_TWT feature if supported by firmware (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: set PROTECTED_TWT in MAC data policy (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: add PROTECTED_TWT firmware API (Jarod Wilson) [1857772]
- [wireless] iwlwifi: mvm: rs-fw: handle VHT extended NSS capability (Jarod Wilson) [1857772]
- [x86] sev-es: Use new for_each_insn_prefix() macro to loop over prefixes bytes (Vitaly Kuznetsov) [1915453]
- [x86] insn-eval: Use new for_each_insn_prefix() macro to loop over prefixes bytes (Vitaly Kuznetsov) [1915453]
- [tools] x86/uprobes: Do not use prefixes.nbytes when looping over prefixes.bytes (Vitaly Kuznetsov) [1915453]
- [powercap] powercap/intel_rapl: add support for ElkhartLake (Steve Best) [1847054]
- [char] tpm: efi: Don't create binary_bios_measurements file for an empty log (Jerry Snitselaar) [1887536 1855183]
- [char] tpm_tis: Add a check for invalid status (Jerry Snitselaar) [1887536 1855183]
- [char] tpm: use *ph to print small buffer (Jerry Snitselaar) [1887536 1855183]
- [char] tpm: Add support for event log pointer found in TPM2 ACPI table (Jerry Snitselaar) [1887536 1855183]
- [acpi] acpi: Extend TPM2 ACPI table with missing log fields (Jerry Snitselaar) [1887536]
- [char] tpm: Unify the mismatching TPM space buffer sizes (Jerry Snitselaar) [1887536 1855183]
- [include] tpm: Require that all digests are present in TCG_PCR_EVENT2 structures (Jerry Snitselaar) [1887536 1855183]
- [char] tpm_tis_spi: Prefer async probe (Jerry Snitselaar) [1887536 1855183]
- [char] tpm/st33zp24: fix spelling mistake "drescription" -> "description" (Jerry Snitselaar) [1887536]
- [char] tpm_tis: extra chip->ops check on error path in tpm_tis_core_init (Jerry Snitselaar) [1887536 1855183]
- [char] tpm_tis_spi: Don't send anything during flow control (Jerry Snitselaar) [1887536 1855183]
- [include] efi/tpm: Verify event log header before parsing (Jerry Snitselaar) [1887536 1855183]
- [char] tpm: eventlog: Replace zero-length array with flexible-array member (Jerry Snitselaar) [1887536 1855183]
- [char] tpm: fix wrong return value in tpm_pcr_extend (Jerry Snitselaar) [1887536 1855183]
- [include] tpm_eventlog.h: Replace zero-length array with flexible-array member (Jerry Snitselaar) [1887536 1855183]
- [include] phylink: <linux/phylink.h>: fix function prototype kernel-doc warning (Petr Oros) [1878147]
- [netdrv] net: phy: call phy_disable_interrupts() in phy_attach_direct() instead (Petr Oros) [1878147]
- [net] net: ethtool: Handle missing cable test TDR parameters (Petr Oros) [1878147]
- [documentation] docs: networking: fix extra spaces in ethtool-netlink (Petr Oros) [1878147]
- [documentation] dt-bindings: net: mvusb: Fix example errors (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: fix null pointer dereference (Petr Oros) [1878147]
- [netdrv] net: phy: fix memory leak in device-create error path (Petr Oros) [1878147]
- [netdrv] net: mdio device: use flexible sleeping in reset function (Petr Oros) [1878147]
- [netdrv] net: mdiobus: add reset-post-delay-us handling (Petr Oros) [1878147]
- [netdrv] net: mdiobus: use flexible sleeping for reset-delay-us (Petr Oros) [1878147]
- [netdrv] net: phylink: add interface to configure clause 22 PCS PHY (Petr Oros) [1878147]
- [netdrv] net: phylink: add struct phylink_pcs (Petr Oros) [1878147]
- [netdrv] net: phylink: re-implement interface configuration with PCS (Petr Oros) [1878147]
- [netdrv] net: phylink: in-band pause mode advertisement update for PCS (Petr Oros) [1878147]
- [netdrv] net: phylink: simplify fixed-link case for ksettings_set method (Petr Oros) [1878147]
- [netdrv] net: phylink: use config.an_enabled in ksettings_set method (Petr Oros) [1878147]
- [netdrv] net: phylink: simplify phy case for ksettings_set method (Petr Oros) [1878147]
- [netdrv] net: phylink: simplify ksettings_set() implementation (Petr Oros) [1878147]
- [netdrv] net: phylink: avoid mac_config calls (Petr Oros) [1878147]
- [netdrv] net: phylink: update PCS when changing interface during resolution (Petr Oros) [1878147]
- [netdrv] net: phylink: ensure link is down when changing interface (Petr Oros) [1878147]
- [netdrv] net: phylink: rearrange resolve mac_config() call (Petr Oros) [1878147]
- [netdrv] net: phylink: rejig link state tracking (Petr Oros) [1878147]
- [netdrv] net: phylink: update ethtool reporting for fixed-link modes (Petr Oros) [1878147]
- [netdrv] net: phy: fix check in get_phy_c45_ids (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: add mdix configuration support for AR9331 and AR8035 (Petr Oros) [1878147]
- [netdrv] net: dp83640: fix SIOCSHWTSTAMP to update the struct with actual configuration (Petr Oros) [1878147]
- [netdrv] net: phy: continue searching for C45 MMDs even if first returned ffff:ffff (Petr Oros) [1878147]
- [netdrv] net: phy: dp83640: Fixup cast to restricted __be16 warning (Petr Oros) [1878147]
- [netdrv] net: phy: Make phy_10gbit_fec_features_array static (Petr Oros) [1878147]
- [netdrv] net: phy: Properly define genphy_c45_driver (Petr Oros) [1878147]
- [netdrv] net: phy: Fixup parameters in kerneldoc (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: Avoid comparison is always false warning (Petr Oros) [1878147]
- [netdrv] net: phy: mdio: reset MDIO devices even if probe() is not implemented (Petr Oros) [1878147]
- [netdrv] net: phy: reset the PHY even if probe() is not implemented (Petr Oros) [1878147]
- [include] net: mdio: add a forward declaration for reset_control to mdio.h (Petr Oros) [1878147]
- [netdrv] net: phy: arrange headers in phy_device.c alphabetically (Petr Oros) [1878147]
- [netdrv] net: phy: arrange headers in mdio_device.c alphabetically (Petr Oros) [1878147]
- [netdrv] net: phy: arrange headers in mdio_bus.c alphabetically (Petr Oros) [1878147]
- [netdrv] net: phylink: only restart AN if the link mode is using in-band AN (Petr Oros) [1878147]
- [netdrv] net: phylink: add phylink_speed_(up|down) interface (Petr Oros) [1878147]
- [netdrv] net: phy: call phy_disable_interrupts() in phy_init_hw() (Petr Oros) [1878147]
- [netdrv] net: phy: make phy_disable_interrupts() non-static (Petr Oros) [1878147]
- [netdrv] net: phylink: ensure manual pause mode configuration takes effect (Petr Oros) [1878147]
- [netdrv] net: phylink: fix ethtool -A with attached PHYs (Petr Oros) [1878147]
- [include] net: phy: add support for a common probe between shared PHYs (Petr Oros) [1878147]
- [netdrv] net: phy: Allow mdio buses to auto-probe c45 devices (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: Add Marvell 88E1548P support (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: Add Marvell 88E1340S support (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: use a single style for referencing functions (Petr Oros) [1878147]
- [netdrv] net: phy: smsc: fix printing too many logs (Petr Oros) [1878147]
- [netdrv] net: phy: Check harder for errors in get_phy_id() (Petr Oros) [1878147]
- [of] of: of_mdio: Correct loop scanning logic (Petr Oros) [1878147]
- [of] of: mdio: preserve phy dev_flags in of_phy_connect() (Petr Oros) [1878147]
- [netdrv] net: phy: read MMD ID from all present MMDs (Petr Oros) [1878147]
- [netdrv] net: phy: split devices_in_package (Petr Oros) [1878147]
- [netdrv] net: phy: set devices_in_package only after validation (Petr Oros) [1878147]
- [netdrv] net: phy: add support for probing MMDs >= 8 for devices-in-package (Petr Oros) [1878147]
- [netdrv] net: phy: reword get_phy_device() kerneldoc (Petr Oros) [1878147]
- [netdrv] net: phy: clean up get_phy_c22_id() invalid ID handling (Petr Oros) [1878147]
- [netdrv] net: phy: clean up get_phy_c45_ids() failure handling (Petr Oros) [1878147]
- [netdrv] net: phy: clean up PHY ID reading (Petr Oros) [1878147]
- [netdrv] net: phy: clean up cortina workaround (Petr Oros) [1878147]
- [netdrv] net: dp83869: Reset return variable if PHY strap is read (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: don't export RDB/legacy access methods (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: unlock after phy_select_page() failure (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: add cable diagnostics support for ATH9331 and ATH8032 (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: Configure TDR pulse based on measurement length (Petr Oros) [1878147]
- [netdrv] net : phy: marvell: Speedup TDR data retrieval by only changing page once (Petr Oros) [1878147]
- [netdrv] net: ethtool: Allow PHY cable test TDR data to configured (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: Add support for amplitude graph (Petr Oros) [1878147]
- [net] net: ethtool: Add helpers for cable test TDR data (Petr Oros) [1878147]
- [net] net: ethtool: Add generic parts of cable test TDR (Petr Oros) [1878147]
- [uapi] net: ethtool: Add attributes for cable test TDR data (Petr Oros) [1878147]
- [netdrv] net: phy: mscc-miim: read poll when high resolution timers are disabled (Petr Oros) [1878147]
- [netdrv] net: phy: mscc-miim: improve waiting logic (Petr Oros) [1878147]
- [netdrv] net: phy: mscc-miim: remove redundant timeout check (Petr Oros) [1878147]
- [netdrv] net: phy: mscc-miim: use more reasonable delays (Petr Oros) [1878147]
- [netdrv] net: mdiobus: add clause 45 mdiobus accessors (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: fix PHY ID masks (Petr Oros) [1878147]
- [netdrv] net: phy: dp83869: Set opmode from straps (Petr Oros) [1878147]
- [netdrv] net: phy: dp83869: Update port-mirroring to read straps (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: add SQI support (Petr Oros) [1878147]
- [netdrv] net: phy: simplify phy_link_change arguments (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: fix checkpatch complains about tabs (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: add support for BCM54811 PHY (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: execute cable test on link up (Petr Oros) [1878147]
- [netdrv] net: phy: mdio-moxart: remove unneeded include (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: add cable diagnostics support (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: add cable diagnostics support (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: add cable test support (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: add bcm_phy_modify_exp() (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: add exp register access methods without buslock (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: add cable-test support (Petr Oros) [1878147]
- [netdrv] net: phy: fix aneg restart in phy_ethtool_set_eee (Petr Oros) [1878147]
- [net] net: phy: Send notifier when starting the cable test (Petr Oros) [1878147]
- [netdrv] net: phy: Put interface into oper testing during cable test (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: Add cable test support (Petr Oros) [1878147]
- [include] net: ethtool: Add helpers for reporting test results (Petr Oros) [1878147]
- [include] net: ethtool: Add infrastructure for reporting cable test results (Petr Oros) [1878147]
- [uapi] net: ethtool: Add attributes for cable test reports (Petr Oros) [1878147]
- [net] net: ethtool: netlink: Add support for triggering a cable test (Petr Oros) [1878147]
- [netdrv] net: phy: Add support for polling cable test (Petr Oros) [1878147]
- [netdrv] net: phy: Add cable test support to state machine (Petr Oros) [1878147]
- [net] net: ethtool: self_test: Mark interface in testing operative status (Petr Oros) [1878147]
- [net] net: Add testing sysfs attribute (Petr Oros) [1878147]
- [net] net: Add IF_OPER_TESTING (Petr Oros) [1878147]
- [netdrv] net: phy: fix less than zero comparison with unsigned variable val (Petr Oros) [1878147]
- [netdrv] net: phy: Make iproc_mdio_resume static (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: use phy_package_shared (Petr Oros) [1878147]
- [netdrv] net: phy: add concept of shared storage for PHYs (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: add support for master-slave configuration (Petr Oros) [1878147]
- [uapi] ethtool: provide UAPI for PHY master/slave configuration (Petr Oros) [1878147]
- [netdrv] dp83640: reverse arguments to list_add_tail (Petr Oros) [1878147]
- [documentation] dt-bindings: add Qualcomm IPQ4019 MDIO bindings (Petr Oros) [1878147]
- [netdrv] net: phy: mdio: add IPQ4019 MDIO driver (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: add second PHY ID (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: apply the workaround on b0 chips (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: fix phy_id_mask (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: use genphy_soft_reset() (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: add downshift support (Petr Oros) [1878147]
- [netdrv] net: phy: DP83TC811: Fix WoL in config init to be disabled (Petr Oros) [1878147]
- [netdrv] net: phy: DP83822: Fix WoL in config init to be disabled (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: Make a bunch of functions static (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: fix temperature sensor on 2110 (Petr Oros) [1878147]
- [gpio] gpiolib: Rename "chip" variables to "gc" in core header file (Petr Oros) [1878147]
- [netdrv] net: phy: dp83867: Remove unneeded semicolon (Petr Oros) [1878147]
- [netdrv] net: phy: clear phydev->suspended after soft reset (Petr Oros) [1878147]
- [netdrv] net: phy: remove genphy_no_soft_reset (Petr Oros) [1878147]
- [netdrv] net: phy: make phy_suspend a no-op if PHY is suspended already (Petr Oros) [1878147]
- [netdrv] net: phylink, dsa: eliminate phylink_fixed_state_cb() (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: fix less than zero comparison on an unsigned (Petr Oros) [1878147]
- [netdrv] net: phy: bcm84881: clear settings on link down (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: add delayed registration of TJA1102 PHY1 (Petr Oros) [1878147]
- [of] net: mdio: of: export part of of_mdiobus_register_phy() (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: add initial TJA1102 support (Petr Oros) [1878147]
- [documentation] dt-bindings: net: phy: Add support for NXP TJA11xx (Petr Oros) [1878147]
- [netdrv] net: phy: Use IS_ERR() to check and simplify code (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: limit soft reset to 88x3310 (Petr Oros) [1878147]
- [netdrv] net: phy: bcm54140: add hwmon support (Petr Oros) [1878147]
- [netdrv] net: phy: add Broadcom BCM54140 support (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: add helper to write/read RDB registers (Petr Oros) [1878147]
- [netdrv] net: phy: microchip_t1: add lan87xx_phy_init to initialize the lan87xx phy (Petr Oros) [1878147]
- [netdrv] net: phy: Propagate error from bus->reset (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: Add support for BCM53125 internal PHYs (Petr Oros) [1878147]
- [netdrv] net: phy: mdio-bcm-iproc: Do not show kernel pointer (Petr Oros) [1878147]
- [netdrv] net: phy: at803x: add support for AR8032 PHY (Petr Oros) [1878147]
- [netdrv] net: marvell10g: soft-reset the PHY when coming out of low power (Petr Oros) [1878147]
- [netdrv] net: marvell10g: report firmware version (Petr Oros) [1878147]
- [netdrv] net: phy: micrel: use genphy_read_status for KSZ9131 (Petr Oros) [1878147]
- [netdrv] net: phy: micrel: kszphy_resume(): add delay after genphy_resume() before accessing PHY registers (Petr Oros) [1878147]
- [netdrv] net: phylink: add separate pcs operations structure (Petr Oros) [1878147]
- [netdrv] net: phylink: rename 'ops' to 'mac_ops' (Petr Oros) [1878147]
- [netdrv] net: phylink: change phylink_mii_c22_pcs_set_advertisement() prototype (Petr Oros) [1878147]
- [ptp] ptp: Avoid deadlocks in the programmable pin code (Petr Oros) [1878147]
- [netdrv] net: phy: probe PHY drivers synchronously (Petr Oros) [1878147]
- [netdrv] net: phy: don't touch suspended flag if there's no suspend/resume callback (Petr Oros) [1878147]
- [netdrv] net: phy: micrel.c: add rgmii interface delay possibility to ksz9131 (Petr Oros) [1878147]
- [netdrv] net: phy: mdio-mux-bcm-iproc: use readl_poll_timeout() to simplify code (Petr Oros) [1878147]
- [netdrv] net: phy: tja11xx: use phy_read_poll_timeout() to simplify the code (Petr Oros) [1878147]
- [netdrv] net: phy: smsc: use phy_read_poll_timeout() to simplify the code (Petr Oros) [1878147]
- [netdrv] net: phy: use phy_read_poll_timeout() to simplify the code (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: use phy_read_mmd_poll_timeout() to simplify the code (Petr Oros) [1878147]
- [netdrv] net: phy: aquantia: use phy_read_mmd_poll_timeout() to simplify the code (Petr Oros) [1878147]
- [netdrv] net: phy: bcm84881: use phy_read_mmd_poll_timeout() to simplify the code (Petr Oros) [1878147]
- [netdrv] net: phy: add marvell usb to mdio controller (Petr Oros) [1878147]
- [documentation] dt-bindings: net: add marvell usb to mdio bindings (Petr Oros) [1878147]
- [netdrv] net: phy: aquantia: remove downshift warning now that phylib takes care (Petr Oros) [1878147]
- [netdrv] net: phy: marvell: remove downshift warning now that phylib takes care (Petr Oros) [1878147]
- [netdrv] net: phy: add and use phy_check_downshift (Petr Oros) [1878147]
- [netdrv] net: phylink: pcs: add 802.3 clause 45 helpers (Petr Oros) [1878147]
- [netdrv] net: phylink: pcs: add 802.3 clause 22 helpers (Petr Oros) [1878147]
- [netdrv] net: mdiobus: add APIs for modifying a MDIO device register (Petr Oros) [1878147]
- [netdrv] net: mdiobus: avoid BUG_ON() in mdiobus accessors (Petr Oros) [1878147]
- [netdrv] net: phy: improve phy_driver callback handle_interrupt (Petr Oros) [1878147]
- [netdrv] net: phylink: Add XLGMII support (Petr Oros) [1878147]
- [include] net: phy: Add XLGMII interface define (Petr Oros) [1878147]
- [netdrv] net: phylink: Test if MAC/PCS support Autoneg (Petr Oros) [1878147]
- [netdrv] net: phylink: Add missing Backplane speeds (Petr Oros) [1878147]
- [netdrv] net: mdio: add ipq8064 mdio driver (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: place in powersave mode at probe (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: add energy detect power down tunable (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: add mdix control (Petr Oros) [1878147]
- [netdrv] net: phy: mscc: add constants for used interrupt mask bits (Petr Oros) [1878147]
- [netdrv] net: phy: marvell10g: read copper results from CSSR1 (Petr Oros) [1878147]
- [netdrv] net: phy: mscc: add missing shift for media operation mode selection (Petr Oros) [1878147]
- [netdrv] net: phylink: propagate resolved link config via mac_link_up() (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: Wire suspend/resume for BCM54810 (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: Have bcm54xx_adjust_rxrefclk() check for flags (Petr Oros) [1878147]
- [netdrv] net: phy: broadcom: Allow BCM54810 to use bcm54xx_adjust_rxrefclk() (Petr Oros) [1878147]
- [netdrv] net: phy: dp83867: Add speed optimization feature (Petr Oros) [1878147]
- [netdrv] net: phy: allow bcm84881 to be a module (Petr Oros) [1878147]
- [include] net: phylink: clarify flow control settings in documentation (Petr Oros) [1878147]
- [netdrv] net: phylink: improve initial mac configuration (Petr Oros) [1878147]
- [netdrv] net: phylink: allow ethtool -A to change flow control advertisement (Petr Oros) [1878147]
- [netdrv] net: phylink: resolve fixed link flow control (Petr Oros) [1878147]
- [netdrv] net: phylink: use phylib resolved flow control modes (Petr Oros) [1878147]
- [netdrv] net: phylink: ensure manual flow control is selected appropriately (Petr Oros) [1878147]
- [netdrv] net: phylink: remove pause mode ethtool setting for fixed links (Petr Oros) [1878147]
- [netdrv] net: add linkmode helper for setting flow control advertisement (Petr Oros) [1878147]
- [netdrv] net: add helpers to resolve negotiated flow control (Petr Oros) [1878147]
- [include] net: linkmode: make linkmode_test_bit() take const pointer (Petr Oros) [1878147]
- [include] net: phylink: further documentation clarifications (Petr Oros) [1878147]
- [include] net: phylink: further mac_config documentation improvements (Petr Oros) [1878147]
- [netdrv] net: phylink: rename mac_link_state() op to mac_pcs_get_state() (Petr Oros) [1878147]
- [md] md/raid5: fix oops during stripe resizing (Nigel Croxon) [1898617]
- [md] md/bitmap: fix memory leak of temporary bitmap (Nigel Croxon) [1898617]
- [md] md: fix the checking of wrong work queue (Nigel Croxon) [1898617]
- [md] md/bitmap: md_bitmap_get_counter returns wrong blocks (Nigel Croxon) [1898617]
- [md] md/bitmap: md_bitmap_read_sb uses wrong bitmap blocks (Nigel Croxon) [1898617]
- [md] md/raid0: remove unused function is_io_in_chunk_boundary() (Nigel Croxon) [1898617]
- [md] md: don't detour through bd_contains for the gendisk (Nigel Croxon) [1898617]
- [md] md: compare bd_disk instead of bd_contains (Nigel Croxon) [1898617]
- [md] md: Simplify code with existing definition RESYNC_SECTORS in raid10.c (Nigel Croxon) [1898617]
- [md] md/raid5: reallocate page array after setting new stripe_size (Nigel Croxon) [1898617]
- [md] md/raid5: resize stripe_head when reshape array (Nigel Croxon) [1898617]
- [md] md/raid5: let multiple devices of stripe_head share page (Nigel Croxon) [1898617]
- [crypto] md/raid6: let async recovery function support different page offset (Nigel Croxon) [1898617]
- [crypto] md/raid6: let syndrome computor support different page offset (Nigel Croxon) [1898617]
- [md] md/raid5: convert to new xor compution interface (Nigel Croxon) [1898617]
- [crypto] md/raid5: add new xor function to support different page offset (Nigel Croxon) [1898617]
- [md] md/raid5: make async_copy_data() to support different page offset (Nigel Croxon) [1898617]
- [md] md/raid5: add a new member of offset into r5dev (Nigel Croxon) [1898617]
- [md] md: only calculate blocksize once and use i_blocksize() (Nigel Croxon) [1898617]
- [md] md: update the optimal I/O size on reshape (Nigel Croxon) [1898617]
- [md] md/raid5: make sure stripe_size as power of two (Nigel Croxon) [1898617]
- [md] md-cluster: Fix potential error pointer dereference in resize_bitmaps() (Nigel Croxon) [1898617]
- [md] md: get sysfs entry after redundancy attr group create (Nigel Croxon) [1898617]
- [kernel] lockdep: Fix preemption WARN for spurious IRQ-enable (Waiman Long) [1908640]
- [powerpc] powerpc/smp: Call rcu_cpu_starting() earlier (Waiman Long) [1908640]
- [include] seqlock: Fix multiple kernel-doc warnings (Waiman Long) [1908640]
- [kernel] lockdep: Fix usage_traceoverflow (Waiman Long) [1908640]
- [kernel] locking/lockdep: Remove more raw_cpu_read() usage (Waiman Long) [1908640]
- [include] lockdep: Revert "lockdep: Use raw_cpu_*() for per-cpu variables" (Waiman Long) [1908640]
- [kernel] lockdep: Fix lockdep recursion (Waiman Long) [1908640]
- [kernel] lockdep,trace: Expose tracepoints (Waiman Long) [1908640]
- [x86] locking/lockdep: Fix TRACE_IRQFLAGS vs. NMIs (Waiman Long) [1908640]
- [s390] s390: don't trace preemption in percpu macros (Waiman Long) [1908640]
- [fs] blkdev: avoid migration stalls for blkdev pages (Chris von Recklinghausen) [1876502]
- [netdrv] ionic: account for vlan tag len in rx buffer len (Jonathan Toppins) [1908642]
- [netdrv] net/mlx5e: Fix refcount leak on kTLS RX resync (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Avoid kzalloc(GFP_KERNEL) under spinlock (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Fix leak on resync error flow (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Add missing dma_unmap in RX resync (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Fix napi sync and possible use-after-free (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Improve rx handler function call (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Cleanup redundant capability check (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: Increase Async ICO SQ size (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Add kTLS RX stats (Alaa Hleihel) [1866808]
- [netdrv] net/mlx5e: kTLS, Add kTLS RX resync support (Alaa Hleihel) [1866808]
- [infiniband] RDMA/siw: Fix handling of zero-sized Read and Receive Queues (Kamal Heib) [1900985 1875703]
- [fs] ext4: fix bogus warning in ext4_update_dx_flag() (Lukas Czerner) [1908714]
- [fs] ext4: handle dax mount option collision (Lukas Czerner) [1908714]
- [fs] jbd2: fix up sparse warnings in checkpoint code (Lukas Czerner) [1908714]
- [fs] ext4: unlock xattr_sem properly in ext4_inline_data_truncate() (Lukas Czerner) [1908714]
- [fs] ext4: do not use extent after put_bh (Lukas Czerner) [1908714]
- [fs] ext4: fix invalid inode checksum (Lukas Czerner) [1908714]
- [fs] ext4: clear buffer verified flag if read meta block from disk (Lukas Czerner) [1908714]
- [fs] ext4: treat buffers contining write errors as valid in ext4_sb_bread() (Lukas Czerner) [1908714]
- [fs] ext4: treat buffers with write errors as containing valid data (Lukas Czerner) [1908714]
- [fs] ext4: limit entries returned when counting fsmap records (Lukas Czerner) [1908714]
- [fs] ext4: fix error handling code in add_new_gdb (Lukas Czerner) [1908714]
- [fs] ext4: fix leaking sysfs kobject after failed mount (Lukas Czerner) [1908714]
- [fs] ext4: fix checking of directory entry validity for inline directories (Lukas Czerner) [1908714]
- [fs] ext4: correctly restore system zone info when remount fails (Lukas Czerner) [1908714]
- [fs] ext4: handle add_system_zone() failure in ext4_setup_system_zone() (Lukas Czerner) [1908714]
- [fs] ext4: fold ext4_data_block_valid_rcu() into the caller (Lukas Czerner) [1908714]
- [fs] ext4: check journal inode extents more carefully (Lukas Czerner) [1908714]
- [fs] ext4: don't allow overlapping system zones (Lukas Czerner) [1908714]
- [fs] ext4: handle error of ext4_setup_system_zone() on remount (Lukas Czerner) [1908714]
- [fs] jbd2: add the missing unlock_buffer() in the error path of jbd2_write_superblock() (Lukas Czerner) [1908714]
- [fs] ext4: fix mount failure with quota configured as module (Lukas Czerner) [1908714]
- [fs] ext4: improve explanation of a mount failure caused by a misconfigured kernel (Lukas Czerner) [1908714]
- [include] jbd2: fix kernel-doc notation warning (Lukas Czerner) [1908714]
- [base] mm: don't panic when links can't be created in sysfs (Baoquan He) [1890171]
- [base] mm: don't rely on system state to detect hot-plug operations (Baoquan He) [1890171]
- [mm] mm: replace memmap_context by meminit_context (Baoquan He) [1890171]
- [net] Update window_clamp if SOCK_RCVBUF is set (Balazs Nemeth) [1905985]
- [cpufreq] cpufreq: acpi-cpufreq: Mark sometimes used ID structs as __maybe_unused (David Arcari) [1857102]
- [cpufreq] cpufreq: acpi-cpufreq: Mark 'dummy' variable as __always_unused (David Arcari) [1857102]
- [cpufreq] cpufreq: Replace HTTP links with HTTPS ones (David Arcari) [1857102]
- [cpufreq] cpufreq: change '.set_boost' to act on one policy (David Arcari) [1857102]
- [cpufreq] cpufreq: Fix up cpufreq_boost_set_sw() (David Arcari) [1857102]
- [cpufreq] cpufreq: Convert to new X86 CPU match macros (David Arcari) [1857102]
- [cpufreq] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (David Arcari) [1857102]

* Wed Jan 20 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-277.el8]
- [platform] platform/x86: ISST: Add new PCI device ids (Prarit Bhargava) [1836722]
- [net] net-sysfs: take the rtnl lock when accessing xps_rxqs_map and num_tc (Antoine Tenart) [1912253]
- [net] net-sysfs: take the rtnl lock when storing xps_rxqs (Antoine Tenart) [1912253]
- [net] net-sysfs: take the rtnl lock when accessing xps_cpus_map and num_tc (Antoine Tenart) [1912253]
- [net] net-sysfs: take the rtnl lock when storing xps_cpus (Antoine Tenart) [1912253]
- [fs] gfs2: Improve mmap write vs. punch_hole consistency (Andreas Grunbacher) [1872043]
- [netdrv] bnx2x: fix spelling mistake "occurd" -> "occurred" (Manish Chopra) [1853224]
- [netdrv] bnx2x: Perform Idlechk dump during the debug collection (Manish Chopra) [1853224]
- [netdrv] bnx2x: Add support for idlechk tests (Manish Chopra) [1853224]
- [netdrv] bnx2x: Add Idlechk related register definitions (Manish Chopra) [1853224]
- [netdrv] bnx2x: use generic power management (Manish Chopra) [1853224]
- [netdrv] bnx2x: allow bnx2x_bsc_read() to schedule (Manish Chopra) [1853224]
- [netdrv] bnx2x: Remove unused inline function bnx2x_vf_vlan_credit (Manish Chopra) [1853224]
- [netdrv] bnx2x: Remove Comparison to bool in bnx2x_dcb.c (Manish Chopra) [1853224]
- [netdrv] bnx2x: correct a comment mistake in grammar (Manish Chopra) [1853224]
- [netdrv] net: bnx2x: reject unsupported coalescing params (Manish Chopra) [1853224]
- [net] tls: Implement getsockopt SOL_TLS TLS_RX (Sabrina Dubroca) [1889664]
- [net] tls: Protect from calling tls_dev_del for TLS RX twice (Sabrina Dubroca) [1889664]
- [net] tls: missing received data after fast remote close (Sabrina Dubroca) [1889664]
- [net] tls: Fix wrong record sn in async mode of device resync (Sabrina Dubroca) [1889664]
- [net] tls: fix corrupted data in recvmsg (Sabrina Dubroca) [1889664]
- [net] tls: sendfile fails with ktls offload (Sabrina Dubroca) [1889664]
- [net] tls: race causes kernel panic (Sabrina Dubroca) [1889664]
- [net] tls: Fix kmap usage (Sabrina Dubroca) [1889664]
- [net] tls: allow MSG_CMSG_COMPAT in sendmsg (Sabrina Dubroca) [1889664]
- [net] tls: fix sign extension issue when left shifting u16 value (Sabrina Dubroca) [1889664]
- [net] tls: Add asynchronous resync (Sabrina Dubroca) [1889664]
- [net] revert "net/tls: Add force_resync for driver resync" (Sabrina Dubroca) [1889664]
- [net] net/tls: Add force_resync for driver resync (Sabrina Dubroca) [1889664]
- [net] tls: Avoid assigning 'const' pointer to non-const pointer (Sabrina Dubroca) [1889664]
- [net] tls: move mark_tech_preview to tls_init (Sabrina Dubroca) [1907477]
- [mm] mm/hmm: do not call hmm_vma_walk_hole() while holding a spinlock (Chris von Recklinghausen) [1890943]
- [mm] mm: pagewalk: add 'depth' parameter to pte_hole (Chris von Recklinghausen) [1890943]
- [mm] mm: pagewalk: don't lock PTEs for walk_page_range_novma() (Chris von Recklinghausen) [1890943]
- [mm] mm: pagewalk: allow walking without vma (Chris von Recklinghausen) [1890943]
- [mm] mm: pagewalk: add p4d_entry() and pgd_entry() (Chris von Recklinghausen) [1890943]
- [x86] x86: mm: add p?d_leaf() definitions (Chris von Recklinghausen) [1890943]
- [s390] s390: mm: add p?d_leaf() definitions (Chris von Recklinghausen) [1890943]
- [powerpc] powerpc: mm: add p?d_leaf() definitions (Chris von Recklinghausen) [1890943]
- [arm64] arm64: mm: add p?d_leaf() definitions (Chris von Recklinghausen) [1890943]
- [mm] mm: add generic p?d_leaf() macros (Chris von Recklinghausen) [1890943]
- [mm] mm: move_pages: report the number of non-attempted pages (Chris von Recklinghausen) [1890943]
- [mm] autonuma: fix watermark checking in migrate_balanced_pgdat() (Chris von Recklinghausen) [1890943]
- [mm] mm/migrate.c: handle freed page at the first place (Chris von Recklinghausen) [1890943]
- [mm] mm: pagewalk: Take the pagetable lock in walk_pte_range() (Chris von Recklinghausen) [1890943]
- [mm] mm: untag user pointers passed to memory syscalls (Chris von Recklinghausen) [1890943]
- [mm] mm: page cache: store only head pages in i_pages (Chris von Recklinghausen) [1890943]
- [mm] mm: migrate: fix reference check race between __find_get_block() and migration (Chris von Recklinghausen) [1890943]
- [fs] mm: migrate: remove unused mode argument (Chris von Recklinghausen) [1890943]
- [mm] powerpc/book3s: Use config independent helpers for page table walk (Chris von Recklinghausen) [1890943]
- [mm] mm/mmu_notifier: use correct mmu_notifier events for each invalidation (Chris von Recklinghausen) [1890943]
- [mm] mm/mmu_notifier: contextual information for event triggering invalidation (Chris von Recklinghausen) [1890943]
- [mm] powerpc/mm: move __find_linux_pte() out of hugetlbpage.c (Chris von Recklinghausen) [1890943]
- [mm] mm/filemap.c: remove redundant test from find_get_pages_contig (Chris von Recklinghausen) [1890943]
- [mm] mm/hugetlb: distinguish between migratability and movability (Chris von Recklinghausen) [1890943]
- [mm] numa: change get_mempolicy() to use nr_node_ids instead of MAX_NUMNODES (Chris von Recklinghausen) [1890943]
- [mm] mm: migrate: make buffer_migrate_page_norefs() actually succeed (Chris von Recklinghausen) [1890943]
- [mm] mm: treewide: remove unused address argument from pte_alloc functions (Chris von Recklinghausen) [1890943]
- [fs] mm: migrate: drop unused argument of migrate_page_move_mapping() (Chris von Recklinghausen) [1890943]
- [mm] mm: migrate: provide buffer_migrate_page_norefs() (Chris von Recklinghausen) [1890943]
- [mm] mm: migrate: move migrate_page_lock_buffers() (Chris von Recklinghausen) [1890943]
- [mm] mm: migrate: lock buffers before migrate_page_move_mapping() (Chris von Recklinghausen) [1890943]
- [mm] mm: Convert huge_memory to XArray (Chris von Recklinghausen) [1890943]
- [mm] mm: Convert page migration to XArray (Chris von Recklinghausen) [1890943]
- [mm] powerpc/mm/book3s: Check for pmd_large instead of pmd_trans_huge (Chris von Recklinghausen) [1890943]
- [x86] x86/pgtable: Move two more functions from pgtable_64.h to pgtable.h (Chris von Recklinghausen) [1890943]
- [x86] x86/pgtable: Move pti_set_user_pgtbl() to pgtable.h (Chris von Recklinghausen) [1890943]
- [x86] x86/pgtable: Move pgdp kernel/user conversion functions to pgtable.h (Chris von Recklinghausen) [1890943]
- [mm] x86/pgtable: Rename pti_set_user_pgd() to pti_set_user_pgtbl() (Chris von Recklinghausen) [1890943]
- [mm] mm: memcg/slab: fix root memcg vmstats (Waiman Long) [1877019]
- [mm] mm/slub: let number of online CPUs determine the slub page order (Waiman Long) [1877019]
- [mm] mm, debug_pagealloc: don't rely on static keys too early (Waiman Long) [1877019]
- [mm] mm: memcg: link page counters to root if use_hierarchy is false (Waiman Long) [1877019]
- [mm] mm/memcg: unify swap and memsw page counters (Waiman Long) [1877019]
- [mm] mm: memcontrol: correct the NR_ANON_THPS counter of hierarchical memcg (Waiman Long) [1877019]
- [mm] mlock: fix unevictable_pgs event counts on THP (Waiman Long) [1877019]
- [mm] mm/filemap: fix storing to a THP shadow entry (Waiman Long) [1877019]
- [lib] XArray: add xas_split (Waiman Long) [1877019]
- [lib] XArray: add xa_get_order (Waiman Long) [1877019]
- [lib] XArray: Add private interface for workingset node deletion (Waiman Long) [1877019]
- [include] XArray: Fix xas_reload for multi-index entries (Waiman Long) [1877019]
- [include] xarray.h: correct return code documentation for xa_store_{bh, irq}() (Waiman Long) [1877019]
- [mm] mm: memcg/slab: uncharge during kmem_cache_free_bulk() (Waiman Long) [1877019]
- [mm] mm: memcg/slab: fix racy access to page->mem_cgroup in mem_cgroup_from_obj() (Waiman Long) [1877019]
- [mm] mm: memcontrol: fix missing suffix of workingset_restore (Waiman Long) [1877019]
- [mm] mm: memcontrol: fix warning when allocating the root cgroup (Waiman Long) [1877019]
- [mm] mm: replace hpage_nr_pages with thp_nr_pages (Waiman Long) [1877019]
- [mm] mm: add thp_size (Waiman Long) [1877019]
- [include] mm: add thp_order (Waiman Long) [1877019]
- [include] include/linux/huge_mm.h: check PageTail in hpage_nr_pages even when !THP (Waiman Long) [1877019]
- [mm] mm/page_vma_mapped.c: explicitly compare pfn for normal, hugetlbfs and THP page (Waiman Long) [1877019]
- [mm] mm/vmscan: restore active/inactive ratio for anonymous LRU (Waiman Long) [1877019]
- [mm] mm/swap: implement workingset detection for anonymous LRU (Waiman Long) [1877019]
- [mm] mm/swapcache: support to handle the shadow entries (Waiman Long) [1877019]
- [mm] mm: fix swap cache node allocation mask (Waiman Long) [1877019]
- [include] include/linux/swap.h: delete meaningless __add_to_swap_cache() declaration (Waiman Long) [1877019]
- [mm] mm/swap_state.c: use the same way to count page in_swap_cache (Waiman Long) [1877019]
- [mm] mm: shmem: use proper gfp flags for shmem_writepage() (Waiman Long) [1877019]
- [mm] mm/workingset: prepare the workingset detection infrastructure for anon LRU (Waiman Long) [1877019]
- [mm] mm/vmscan: protect the workingset on anonymous LRU (Waiman Long) [1877019]
- [mm] mm/vmscan: make active/inactive ratio as 1:1 for anon lru (Waiman Long) [1877019]
- [tools] kselftests: cgroup: add perpcu memory accounting test (Waiman Long) [1877019]
- [mm] mm: memcg: charge memcg percpu memory to the parent cgroup (Waiman Long) [1877019]
- [mm] mm: memcg/percpu: per-memcg percpu memory statistics (Waiman Long) [1877019]
- [mm] mm: memcg/percpu: account percpu memory to memory cgroups (Waiman Long) [1877019]
- [mm] percpu: return number of released bytes from pcpu_free_area() (Waiman Long) [1877019]
- [mm] percpu: make pcpu_alloc() aware of current gfp context (Waiman Long) [1877019]
- [mm] mm/khugepaged: fix filemap page_to_pgoff(page) != offset (Waiman Long) [1877019]
- [mm] mm, slub: restore initial kmem_cache flags (Waiman Long) [1877019]
- [include] mm: memcg/slab: fix slab statistics in !SMP configuration (Waiman Long) [1877019]
- [mm] mm: slab: fix potential double free in ___cache_free (Waiman Long) [1877019]
- [mm] ksm: reinstate memcg charge on copied pages (Waiman Long) [1877019]
- [mm] mm: slub: fix conversion of freelist_corrupted() (Waiman Long) [1877019]
- [mm] memcg: fix use-after-free in uncharge_batch (Waiman Long) [1877019]
- [mm] mm/memory: fix IO cost for anonymous page (Waiman Long) [1877019]
- [mm] mm: workingset: age nonresident information alongside anonymous pages (Waiman Long) [1877019]
- [mm] slub: cure list_slab_objects() from double fix (Waiman Long) [1877019]
- [mm] mm: do_swap_page(): fix up the error code (Waiman Long) [1877019]
- [misc] lkdtm/heap: Avoid edge and middle of slabs (Waiman Long) [1877019]
- [mm] mm: slub: really fix slab walking for init_on_free (Waiman Long) [1877019]
- [mm] mm/slab.c: fix kernel-doc warning for __ksize() (Waiman Long) [1877019]
- [mm] mm: memcontrol: restore proper dirty throttling when memory.high changes (Waiman Long) [1877019]
- [mm] memcg, oom: check memcg margin for parallel oom (Waiman Long) [1877019]
- [mm] mm, memcg: avoid stale protection values when cgroup is above protection (Waiman Long) [1877019]
- [mm] mm, memcg: unify reclaim retry limits with page allocator (Waiman Long) [1877019]
- [mm] mm, memcg: reclaim more aggressively before high allocator throttling (Waiman Long) [1877019]
- [mm] mm: memcontrol: avoid workload stalls when lowering memory.high (Waiman Long) [1877019]
- [include] mm: kmem: switch to static_branch_likely() in memcg_kmem_enabled() (Waiman Long) [1877019]
- [mm] mm: slab: rename (un)charge_slab_page() to (un)account_slab_page() (Waiman Long) [1877019]
- [mm] mm: memcg/slab: remove unused argument by charge_slab_page() (Waiman Long) [1877019]
- [tools] tools/cgroup: add memcg_slabinfo.py tool (Waiman Long) [1877019]
- [tools] kselftests: cgroup: add kernel memory accounting tests (Waiman Long) [1877019]
- [mm] mm: memcg/slab: use a single set of kmem_caches for all allocations (Waiman Long) [1877019]
- [mm] mm: memcg/slab: remove redundant check in memcg_accumulate_slabinfo() (Waiman Long) [1877019]
- [mm] mm: memcg/slab: deprecate slab_root_caches (Waiman Long) [1877019]
- [mm] mm: memcg/slab: remove memcg_kmem_get_cache() (Waiman Long) [1877019]
- [mm] mm: memcg/slab: simplify memcg cache creation (Waiman Long) [1877019]
- [mm] mm: memcg/slab: use a single set of kmem_caches for all accounted allocations (Waiman Long) [1877019]
- [mm] mm, slab_common: fix a typo in comment "eariler"->"earlier" (Waiman Long) [1877019]
- [mm] mm: memcg/slab: fix memory leak at non-root kmem_cache destroy (Waiman Long) [1877019]
- [mm] mm: memcg/slab: fix panic in __free_slab() caused by premature memcg pointer release (Waiman Long) [1877019]
- [mm] mm: memcg/slab: move memcg_kmem_bypass() to memcontrol.h (Waiman Long) [1877019]
- [mm] mm: memcg/slab: deprecate memory.kmem.slabinfo (Waiman Long) [1877019]
- [mm] mm, memcg: fix build error around the usage of kmem_caches (Waiman Long) [1877019]
- [mm] mm: memcg/slab: charge individual slab objects instead of pages (Waiman Long) [1877019]
- [mm] mm: memcg/slab: save obj_cgroup for non-root slab objects (Waiman Long) [1877019]
- [mm] mm: memcg/slab: allocate obj_cgroups for non-root slab pages (Waiman Long) [1877019]
- [mm] mm: memcg/slab: obj_cgroup API (Waiman Long) [1877019]
- [mm] mm: memcontrol: decouple reference counting from page accounting (Waiman Long) [1877019]
- [mm] mm: slub: implement SLUB version of obj_to_index() (Waiman Long) [1877019]
- [mm] mm: memcg: convert vmstat slab counters to bytes (Waiman Long) [1877019]
- [mm] mm: memcg: prepare for byte-sized vmstat items (Waiman Long) [1877019]
- [mm] mm: memcg: factor out memcg- and lruvec-level changes out of __mod_lruvec_state() (Waiman Long) [1877019]
- [mm] mm: kmem: make memcg_kmem_enabled() irreversible (Waiman Long) [1877019]
- [mm] mm, slab/slub: improve error reporting and overhead of cache_from_obj() (Waiman Long) [1877019]
- [mm] mm, slab/slub: move and improve cache_from_obj() (Waiman Long) [1877019]
- [mm] mm, slub: extend checks guarded by slub_debug static key (Waiman Long) [1877019]
- [mm] mm, slub: introduce kmem_cache_debug_flags() (Waiman Long) [1877019]
- [mm] mm, slub: introduce static key for slub_debug() (Waiman Long) [1877019]
- [mm] mm, slub: make reclaim_account attribute read-only (Waiman Long) [1877019]
- [mm] mm, slub: make remaining slub_debug related attributes read-only (Waiman Long) [1877019]
- [mm] mm, slub: remove runtime allocation order changes (Waiman Long) [1877019]
- [mm] mm, slub: make some slub_debug related attributes read-only (Waiman Long) [1877019]
- [documentation] mm, slub: extend slub_debug syntax for multiple blocks (Waiman Long) [1877019]
- [mm] mm/slab.c: update outdated kmem_list3 in a comment (Waiman Long) [1877019]
- [mm] mm, slab: check GFP_SLAB_BUG_MASK before alloc_pages in kmalloc_order (Waiman Long) [1877019]
- [mm] mm/slab: add naive detection of double free (Waiman Long) [1877019]
- [init] mm/slab: expand CONFIG_SLAB_FREELIST_HARDENED to include SLAB (Waiman Long) [1877019]
- [mm] mm: ksize() should silently accept a NULL pointer (Waiman Long) [1877019]
- [include] include/linux/vmstat.h: remove unused page state adjustment macro (Waiman Long) [1877019]
- [include] mm, memcg: fix inconsistent oom event behavior (Waiman Long) [1877019]
- [mm] mm/memcg: fix refcount error while moving and swapping (Waiman Long) [1877019]
- [mm] mm/memcontrol: fix OOPS inside mem_cgroup_get_nr_swap_pages() (Waiman Long) [1877019]
- [mm] mm/memcontrol.c: add missed css_put() (Waiman Long) [1877019]
- [mm] mm: memcontrol: handle div0 crash race condition in memory.low (Waiman Long) [1877019]
- [kernel] mm: memcontrol: recursive memory.low protection (Waiman Long) [1877019]
- [include] mm, memcg: consider subtrees in memory.events (Waiman Long) [1877019]
- [net] mm, treewide: rename kzfree() to kfree_sensitive() (Waiman Long) [1877019]
- [mm] mm/slab: use memzero_explicit() in kzfree() (Waiman Long) [1877019]
- [mm] mm: swap: memcg: fix memcg stats for huge pages (Waiman Long) [1877019]
- [mm] mm: swap: fix vmstats for huge pages (Waiman Long) [1877019]
- [mm] mm: vmscan: limit the range of LRU type balancing (Waiman Long) [1877019]
- [mm] mm: vmscan: reclaim writepage is IO cost (Waiman Long) [1877019]
- [mm] mm: vmscan: determine anon/file pressure balance at the reclaim root (Waiman Long) [1877019]
- [mm] mm: balance LRU lists based on relative thrashing (Waiman Long) [1877019]
- [mm] mm: only count actual rotations as LRU reclaim cost (Waiman Long) [1877019]
- [mm] mm: deactivations shouldn't bias the LRU balance (Waiman Long) [1877019]
- [mm] mm: base LRU balancing on an explicit cost model (Waiman Long) [1877019]
- [mm] mm: vmscan: drop unnecessary div0 avoidance rounding in get_scan_count() (Waiman Long) [1877019]
- [mm] mm: remove use-once cache bias from LRU balancing (Waiman Long) [1877019]
- [mm] mm: workingset: let cache workingset challenge anon (Waiman Long) [1877019]
- [mm] mm: fold and remove lru_cache_add_anon() and lru_cache_add_file() (Waiman Long) [1877019]
- [kernel] mm: allow swappiness that prefers reclaiming anon over the file workingset (Waiman Long) [1877019]
- [mm] mm: keep separate anon and file statistics on page reclaim activity (Waiman Long) [1877019]
- [mm] mm: fix LRU balancing effect of new transparent huge pages (Waiman Long) [1877019]
- [mm] mm: replace list_move_tail() with add_page_to_lru_list_tail() (Waiman Long) [1877019]
- [mm] mm: memcontrol: update page->mem_cgroup stability rules (Waiman Long) [1877019]
- [mm] mm: memcontrol: delete unused lrucare handling (Waiman Long) [1877019]
- [documentation] mm: memcontrol: document the new swap control behavior (Waiman Long) [1877019]
- [mm] mm: memcontrol: charge swapin pages on instantiation (Waiman Long) [1877019]
- [mm] mm: memcontrol: make swap tracking an integral part of memory control (Waiman Long) [1877019]
- [mm] mm: memcontrol: prepare swap controller setup for integration (Waiman Long) [1877019]
- [mm] mm: memcontrol: drop unused try/commit/cancel charge API (Waiman Long) [1877019]
- [mm] mm: memcontrol: convert anon and file-thp to new mem_cgroup_charge() API (Waiman Long) [1877019]
- [mm] mm: memcontrol: switch to native NR_ANON_THPS counter (Waiman Long) [1877019]
- [mm] mm: memcontrol: switch to native NR_ANON_MAPPED counter (Waiman Long) [1877019]
- [mm] mm: memcontrol: switch to native NR_FILE_PAGES and NR_SHMEM counters (Waiman Long) [1877019]
- [mm] mm: memcontrol: prepare cgroup vmstat infrastructure for native anon counters (Waiman Long) [1877019]
- [mm] mm: memcontrol: prepare move_account for removal of private page type counters (Waiman Long) [1877019]
- [mm] mm: memcontrol: prepare uncharging for removal of private page type counters (Waiman Long) [1877019]
- [mm] mm: memcontrol: convert page cache to a new mem_cgroup_charge() API (Waiman Long) [1877019]
- [mm] mm: memcontrol: move out cgroup swaprate throttling (Waiman Long) [1877019]
- [mm] mm: shmem: remove rare optimization when swapin races with hole punching (Waiman Long) [1877019]
- [mm] mm: memcontrol: drop @compound parameter from memcg charging API (Waiman Long) [1877019]
- [mm] mm: memcontrol: fix stat-corrupting race in charge moving (Waiman Long) [1877019]
- [mm] mm: fix NUMA node file count error in replace_page_cache() (Waiman Long) [1877019]
- [mm] mm/slub: fix stack overruns with SLUB_STATS (Waiman Long) [1877019]
- [mm] slub: remove kmalloc under list_lock from list_slab_objects() V2 (Waiman Long) [1877019]
- [mm] slub: Remove userspace notifier for cache add/remove (Waiman Long) [1877019]
- [mm] mm/slub.c: fix corrupted freechain in deactivate_slab() (Waiman Long) [1877019]
- [mm] mm/slub: fix incorrect interpretation of s->offset (Waiman Long) [1877019]
- [mm] slub: avoid redzone when choosing freepointer location (Waiman Long) [1877019]
- [mm] slub: relocate freelist pointer to middle of object (Waiman Long) [1877019]
- [mm] slub: improve bit diffusion for freelist ptr obfuscation (Waiman Long) [1877019]
- [mm] mm, slb: improve memory accounting (Waiman Long) [1877019]
- [mm] thp: change CoW semantics for anon-THP (Waiman Long) [1877019]
- [mm] khugepaged: allow to collapse PTE-mapped compound pages (Waiman Long) [1877019]
- [mm] khugepaged: allow to collapse a page shared across fork (Waiman Long) [1877019]
- [mm] khugepaged: drain LRU add pagevec after swapin (Waiman Long) [1877019]
- [mm] khugepaged: drain all LRU caches before scanning pages (Waiman Long) [1877019]
- [mm] khugepaged: do not stop collapse if less than half PTEs are referenced (Waiman Long) [1877019]
- [tools] khugepaged: add self test (Waiman Long) [1877019]
- [mm] mm: code cleanup for MADV_FREE (Waiman Long) [1877019]
- [mm] mm, thp: track fallbacks due to failed memcg charges separately (Waiman Long) [1877019]
- [mm] mm, shmem: add vmstat for hugepage fallback (Waiman Long) [1877019]
- [mm] autonuma: reduce cache footprint when scanning page tables (Waiman Long) [1877019]
- [trace] mm/vmscan: simplify trace_reclaim_flags and trace_shrink_flags (Waiman Long) [1877019]
- [mm] mm/memcg: optimize memory.numa_stat like memory.stat (Waiman Long) [1877019]
- [mm] memcg: fix memcg_kmem_bypass() for remote memcg charging (Waiman Long) [1877019]
- [mm] mm/memcg: automatically penalize tasks with high swap use (Waiman Long) [1877019]
- [include] mm/memcg: move cgroup high memory limit setting into struct page_counter (Waiman Long) [1877019]
- [mm] mm/memcg: move penalty delay clamping out of calculate_high_delay() (Waiman Long) [1877019]
- [mm] mm/memcg: prepare for swap over-high accounting and penalty calculation (Waiman Long) [1877019]
- [mm] memcg: expose root cgroup's memory.stat (Waiman Long) [1877019]
- [mm] mm, memcg: add workingset_restore in memory.stat (Waiman Long) [1877019]
- [documentation] doc: cgroup: improve formatting of mem stats (Waiman Long) [1877019]
- [documentation] docs: cgroup: mm: Fix spelling of "list" (Waiman Long) [1877019]
- [mm] mm, memcg: fix error return value of mem_cgroup_css_alloc() (Waiman Long) [1877019]
- [include] memcontrol.h: Replace zero-length array with flexible-array member (Waiman Long) [1877019]
- [mm] mm, memcg: bypass high reclaim iteration for cgroup hierarchy root (Waiman Long) [1877019]
- [mm] mm: memcg: make memory.oom.group tolerable to task migration (Waiman Long) [1877019]
- [mm] mm, memcg: prevent memory.swap.max load tearing (Waiman Long) [1877019]
- [mm] mm, memcg: prevent memory.low load/store tearing (Waiman Long) [1877019]
- [mm] mm, memcg: prevent memory.max load tearing (Waiman Long) [1877019]
- [mm] mm, memcg: prevent memory.high load/store tearing (Waiman Long) [1877019]
- [mm] mm/memcontrol.c: make mem_cgroup_id_get_many() __maybe_unused (Waiman Long) [1877019]
- [mm] memcg: css_tryget_online cleanups (Waiman Long) [1877019]
- [mm] mm/memcontrol.c: cleanup some useless code (Waiman Long) [1877019]
- [mm] mm/memcontrol.c: fix a -Wunused-function warning (Waiman Long) [1877019]
- [mm] mm: memcontrol: switch to rcu protection in drain_all_stock() (Waiman Long) [1877019]
- [mm] mm/khugepaged.c: fix khugepaged's request size in collapse_file (Waiman Long) [1877019]
- [mm] khugepaged: fix null-pointer dereference due to race (Waiman Long) [1877019]
- [mm] mm, thp: stop leaking unreleased file pages (Waiman Long) [1877019]
- [trace] mm: khugepaged: add trace status description for SCAN_PAGE_HAS_PRIVATE (Waiman Long) [1877019]
- [mm] mm, thp: recheck each page before collapsing file THP (Waiman Long) [1877019]
- [mm] mm/thp: allow dropping THP from page cache (Waiman Long) [1877019]
- [mm] mm/vmscan.c: support removing arbitrary sized pages from mapping (Waiman Long) [1877019]
- [mm] mm/thp: fix node page state in split_huge_page_to_list() (Waiman Long) [1877019]
- [fs] proc/meminfo: fix output alignment (Waiman Long) [1877019]
- [mm] mm: shmem: disable interrupt when acquiring info->lock in userfaultfd_copy path (Waiman Long) [1877019]
- [fs] mm, thp: avoid writes to file with THP in pagecache (Waiman Long) [1877019]
- [mm] mm, thp: add read-only THP support for (non-shmem) FS (Waiman Long) [1877019]
- [mm] khugepaged: rename collapse_shmem() and khugepaged_scan_shmem() (Waiman Long) [1877019]
- [fs] mm,thp: stats for file backed THP (Waiman Long) [1877019]
- [mm] filemap: update offset check in filemap_fault() (Waiman Long) [1877019]
- [mm] filemap: check compound_head(page)->mapping in pagecache_get_page() (Waiman Long) [1877019]
- [mm] filemap: check compound_head(page)->mapping in filemap_fault() (Waiman Long) [1877019]
- [mm] mm: mempolicy: fix the wrong return value and potential pages leak of mbind (Waiman Long) [1877019]
- [mm] mm: thp: fix false negative of shmem vma's THP eligibility (Waiman Long) [1877019]
- [mm] mm: thp: make transhuge_vma_suitable available for anonymous THP (Waiman Long) [1877019]
- [mm] mm, thp, proc: report THP eligibility for each vma (Waiman Long) [1877019]
- [documentation] mm, proc: be more verbose about unstable VMA flags in /proc/<pid>/smaps (Waiman Long) [1877019]
- [mm] mm: thp: pass correct vm_flags to hugepage_vma_check() (Waiman Long) [1877019]
- [fs] mm: /proc/pid/smaps_rollup: convert to single value seq_file (Waiman Long) [1877019]
- [fs] mm: /proc/pid/smaps: factor out common stats printing (Waiman Long) [1877019]
- [fs] mm: /proc/pid/smaps: factor out mem stats gathering (Waiman Long) [1877019]
- [fs] mm: /proc/pid/*maps remove is_pid and related wrappers (Waiman Long) [1877019]
- [mm] mm: workingset: fix vmstat counters for shadow nodes (Waiman Long) [1877019]
- [mm] mm: workingset: add vmstat counter for shadow nodes (Waiman Long) [1877019]
- [include] mm/memcg: Document access rule regarding mem_cgroup structure (Waiman Long) [1877019]
- [mm] mm/page_alloc: silence a KASAN false positive (Waiman Long) [1877019]
- [s390] s390/setup: init jump labels before command line parsing (Waiman Long) [1877019]
- [mm] s390/maccess: add no DAT mode to kernel_write (Waiman Long) [1877019]
- [mm] s390: Change s390_kernel_write() return type to match memcpy() (Waiman Long) [1877019]
- [kernel] PM: hibernate: fix crashes with init_on_free=1 (Waiman Long) [1877019]
- [mm] mm/slub.c: init_on_free=1 should wipe freelist ptr for bulk allocations (Waiman Long) [1877019]
- [mm] mm/page_alloc.c: fix a crash in free_pages_prepare() (Waiman Long) [1877019]
- [mm] mm: slub: Fix slab walking for init_on_free (Waiman Long) [1877019]
- [mm] mm, slab: move memcg_cache_params structure to mm/slab.h (Waiman Long) [1877019]
- [mm] mm, slab: extend slab/shrink to shrink all memcg caches (Waiman Long) [1877019]
- [mm] mm: mempolicy: handle vma with unmovable pages mapped correctly in mbind (Waiman Long) [1877019]
- [mm] mm: mempolicy: make the behavior consistent when MPOL_MF_MOVE* and MPOL_MF_STRICT were specified (Waiman Long) [1877019]
- [init] init/Kconfig: fix neighboring typos (Waiman Long) [1877019]
- [mm] mm: security: introduce init_on_alloc=1 and init_on_free=1 boot options (Waiman Long) [1877019]
- [mm] memcg, oom: no oom-kill for __GFP_RETRY_MAYFAIL (Waiman Long) [1877019]
- [mm] mm/kasan: add object validation in ksize() (Waiman Long) [1877019]
- [mm] mm/slab: refactor common ksize KASAN logic into slab_common.c (Waiman Long) [1877019]
- [mm] mm/slub.c: avoid double string traverse in kmem_cache_flags() (Waiman Long) [1877019]
- [mm] mm/slab: sanity-check page type when looking up cache (Waiman Long) [1877019]
- [mm] mm/slab: validate cache membership under freelist hardening (Waiman Long) [1877019]
- [mm] mm/migrate: add stable check in migrate_vma_insert_page() (Waiman Long) [1877019]
- [mm] mm/migrate: clean up some minor coding style (Waiman Long) [1877019]
- [mm] mm/migrate: remove useless mask of start address (Waiman Long) [1877019]
- [kernel] uprobe: use original page when all uprobes are removed (Waiman Long) [1877019]
- [mm] mm: move memcmp_pages() and pages_identical() (Waiman Long) [1877019]
- [mm] mm, thp: do not queue fully unmapped pages for deferred split (Waiman Long) [1877019]
- [mm] mm/khugepaged: fix the xas_create_range() error path (Waiman Long) [1877019]
- [mm] mm/khugepaged: collapse_shmem() do not crash on Compound (Waiman Long) [1877019]
- [mm] mm/khugepaged: collapse_shmem() without freezing new_page (Waiman Long) [1877019]
- [mm] mm/khugepaged: minor reorderings in collapse_shmem() (Waiman Long) [1877019]
- [mm] mm/khugepaged: collapse_shmem() remember to clear holes (Waiman Long) [1877019]
- [mm] mm/khugepaged: collapse_shmem() stop if punched or truncated (Waiman Long) [1877019]
- [mm] mm: Convert khugepaged_scan_shmem to XArray (Waiman Long) [1877019]
- [mm] mm: Convert collapse_shmem to XArray (Waiman Long) [1877019]
- [mm] mm: thp: inc counter for collapsed shmem THP (Waiman Long) [1877019]
- [mm] mm: thp: register mm for khugepaged when merging vma for shmem (Waiman Long) [1877019]
- [mm] mm: swapoff: shmem_unuse() stop eviction without igrab() (Waiman Long) [1877019]
- [mm] mm: swapoff: take notice of completion sooner (Waiman Long) [1877019]
- [mm] mm: swapoff: remove too limiting SWAP_UNUSE_MAX_TRIES (Waiman Long) [1877019]
- [mm] mm: swapoff: shmem_find_swap_entries() filter out other types (Waiman Long) [1877019]
- [mm] mm: rid swapoff of quadratic complexity (Waiman Long) [1877019]
- [mm] shmem: Comment fixups (Waiman Long) [1877019]
- [mm] memfd: Convert memfd_tag_pins to XArray (Waiman Long) [1877019]
- [mm] memfd: Convert memfd_wait_for_pins to XArray (Waiman Long) [1877019]
- [mm] shmem: Convert shmem_partial_swap_usage to XArray (Waiman Long) [1877019]
- [mm] shmem: Convert shmem_free_swap to XArray (Waiman Long) [1877019]
- [lib] shmem: Convert shmem_alloc_hugepage to XArray (Waiman Long) [1877019]
- [tools] shmem: Convert find_swap_entry to XArray (Waiman Long) [1877019]
- [mm] shmem: Convert shmem_confirm_swap to XArray (Waiman Long) [1877019]

* Tue Jan 19 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-276.el8]
- [infiniband] RDMA/core: Do not indicate device ready when device enablement fails (Kamal Heib) [1902144]
- [infiniband] RDMA/core: Clean up cq pool mechanism (Kamal Heib) [1902144]
- [pci] PCI/ASPM: Disable ASPM on ASMedia ASM1083/1085 PCIe-to-PCI bridge (Myron Stowe) [1897927]
- [pci] PCI: Make pcie_find_root_port() work for Root Ports (Myron Stowe) [1897927]
- [pci] PCI: Add ACS quirk for Intel Root Complex Integrated Endpoints (Myron Stowe) [1897927]
- [pci] PCI: Avoid FLR for AMD Starship USB 3.0 (Myron Stowe) [1897927]
- [pci] PCI: Avoid FLR for AMD Matisse HD Audio & USB 3.0 (Myron Stowe) [1897927]
- [pci] PCI/switchtec: Correct bool variable type assignment (Myron Stowe) [1897927]
- [pci] PCI: Allow pci_resize_resource() for devices on root bus (Myron Stowe) [1897927]
- [pci] PCI/PM: Adjust pcie_wait_for_link_delay() for caller delay (Myron Stowe) [1897927]
- [pci] PCI: Avoid Pericom USB controller OHCI/EHCI PME# defect (Myron Stowe) [1897927]
- [tty] serial: 8250_pci: Move Pericom IDs to pci_ids.h (Myron Stowe) [1897927]
- [pci] PCI/PM: Call .bridge_d3() hook only if non-NULL (Myron Stowe) [1897927]
- [pci] PCI: Rename _DSM constants to align with spec (Myron Stowe) [1897927]
- [pci] PCI/PME: Fix kernel-doc of pcie_pme_resume() and pcie_pme_remove() (Myron Stowe) [1897927]
- [pci] PCI: Unify pcie_find_root_port() and pci_find_pcie_root_port() (Myron Stowe) [1897927]
- [pci] PCI: Replace zero-length array with flexible-array (Myron Stowe) [1897927]
- [pci] PCI: shpchp: Make shpchp_unconfigure_device() void (Myron Stowe) [1897927]
- [pci] PCI: Use of_node_name_eq() for node name comparisons (Myron Stowe) [1897927]
- [pci] PCI: pciehp: Remove unused EMI() and HP_SUPR_RM() macros (Myron Stowe) [1897927]
- [pcmcia] pcmcia: Use CardBus window names (PCI_CB_BRIDGE_IO_0_WINDOW etc) when freeing (Myron Stowe) [1897927]
- [pci] PCI: Use bridge window names (PCI_BRIDGE_IO_WINDOW etc) (Myron Stowe) [1897927]
- [pci] PCI/PTM: Inherit Switch Downstream Port PTM settings from Upstream Port (Myron Stowe) [1897927]
- [pci] PCI: Program MPS for RCiEP devices (Myron Stowe) [1897927]
- [pci] PCI: Fix pci_host_bridge struct device release/free handling (Myron Stowe) [1897927]
- [pci] PCI: Fix pci_register_host_bridge() device_register() error handling (Myron Stowe) [1897927]
- [pci] PCI/ASPM: Allow ASPM on links to PCIe-to-PCI/PCI-X Bridges (Myron Stowe) [1897927]
- [x86] x86/tboot: Don't disable swiotlb when iommu is forced on (Tony Camuso) [1883395]
- [iommu] iommu/vt-d: Avoid panic if iommu init fails in tboot system (Tony Camuso) [1883395]
- [pci] PCI/ERR: Clear PCIe Device Status errors only if OS owns AER (Myron Stowe) [1838358]
- [pci] PCI/ERR: Rename pci_aer_clear_device_status() to pcie_clear_device_status() (Myron Stowe) [1838358]
- [pci] PCI/AER: Log correctable errors as warning, not error (Myron Stowe) [1838358]
- [pci] PCI/AER: Simplify __aer_print_error() (Myron Stowe) [1838358]
- [misc] mei: hdcp: fix mei_hdcp_verify_mprime() input parameter (Tony Camuso) [1874577]
- [misc] mei: add device kind to sysfs (Tony Camuso) [1874577]
- [misc] mei: hw: don't use one element arrays (Tony Camuso) [1874577]
- [misc] mei: hw: use sizeof of variable instead of struct type (Tony Camuso) [1874577]
- [misc] mei: client: use sizeof of variable instead of struct type (Tony Camuso) [1874577]
- [misc] mei: bus: use sizeof of variable instead of struct type (Tony Camuso) [1874577]
- [misc] mei: ioctl: use sizeof of variable instead of struct type (Tony Camuso) [1874577]
- [misc] mei: hbm: use sizeof of variable instead of struct type (Tony Camuso) [1874577]
- [misc] Revert "mei: Avoid the use of one-element arrays" (Tony Camuso) [1874577]
- [misc] mei: Avoid the use of one-element arrays (Tony Camuso) [1874577]
- [misc] mei: Replace HTTP links with HTTPS ones (Tony Camuso) [1874577]
- [misc] mei: hdcp: Replace one-element array with flexible-array member (Tony Camuso) [1874577]
- [misc] mei: bus: don't clean driver pointer (Tony Camuso) [1874577]
- [misc] mei: me: add MEI device for KBP with ITPS capability (Tony Camuso) [1874577]
- [misc] mei: me: add MEI device for SPT with ITPS capability (Tony Camuso) [1874577]
- [misc] mei: me: add kdoc for mei_me_fw_type_nm() (Tony Camuso) [1874577]
- [misc] mei: me: make mei_me_fw_sku_sps_4() less cryptic (Tony Camuso) [1874577]
- [misc] mei: me: constify the device parameter to the probe quirk (Tony Camuso) [1874577]
- [misc] mei: hdcp: Constify struct mei_cl_device_id (Tony Camuso) [1874577]
- [misc] mei: me: add tiger lake point device ids for H platforms (Tony Camuso) [1874577]
- [misc] mei: me: disable mei interface on Mehlow server platforms (Tony Camuso) [1874577]
- [misc] mei: release me_cl object reference (Tony Camuso) [1874577]
- [misc] mei: me: disable mei interface on LBG servers (Tony Camuso) [1874577]
- [fs] NFS4: Fix use-after-free in trace_event_raw_event_nfs4_set_lock (Dave Wysochanski) [1906306]
- [fs] NFS: Adjust fs_context error logging (Scott Mayhew) [1907711]
- [mm] powerpc/book3s64/pkeys: Fix pkey_access_permitted() for execute disable pkey (Steve Best) [1912294]
- [infiniband] IB/isert: add module param to set sg_tablesize for IO cmd (Kamal Heib) [1887359]
- [infiniband] IB/isert: allocate RW ctxs according to max IO size (Kamal Heib) [1887359]
- [net] sched: flower: Mark MPLS multilabel match as Tech Preview (Guillaume Nault) [1814836]
- [net] sched: Fix dump of MPLS_OPT_LSE_LABEL attribute in cls_flower (Guillaume Nault) [1814836]
- [net] cls_flower: remove mpls_opts_policy (Guillaume Nault) [1814836]
- [net] flow_dissector: work around stack frame size warning (Guillaume Nault) [1814836]
- [net] cls_flower: Support filtering on multiple MPLS Label Stack Entries (Guillaume Nault) [1814836]
- [net] flow_dissector: Parse multiple MPLS Label Stack Entries (Guillaume Nault) [1814836]
- [netdrv] net/mlx5e: Use generic API to build MPLS label (Alaa Hleihel) [1790220]
- [netdrv] net/mlx5e: Support pedit on mpls over UDP decap (Alaa Hleihel) [1790220]
- [netdrv] net/mlx5e: Add support for hw decapsulation of MPLS over UDP (Alaa Hleihel) [1790220]
- [netdrv] net/mlx5e: Allow to match on mpls parameters (Alaa Hleihel) [1790220]
- [netdrv] net/mlx5e: Add support for hw encapsulation of MPLS over UDP (Alaa Hleihel) [1790220]

* Fri Jan 15 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-275.el8]
- [netdrv] net: intel: Remove in_interrupt() warnings (Ken Cox) [1838731]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Ken Cox) [1838731]
- [netdrv] ixgbe: use eth_zero_addr() to clear mac address (Ken Cox) [1838731]
- [netdrv] ixgbe: Remove unnecessary usages of memset (Ken Cox) [1838731]
- [netdrv] ixgbe: use generic power management (Ken Cox) [1838731]
- [netdrv] ixgbe: convert to new udp_tunnel_nic infra (Ken Cox) [1838731]
- [netdrv] ixgbe: don't clear UDP tunnel ports when RXCSUM is disabled (Ken Cox) [1838731]
- [netdrv] ixgbe: Cleanup unneeded delay in ethtool test (Ken Cox) [1838731]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Ken Cox) [1838731]
- [netdrv] net: ethernet: ixgbe: don't call devm_mdiobus_free() (Ken Cox) [1838731]
- [netdrv] net: ethernet: ixgbe: check the return value of ixgbe_mii_bus_init() (Ken Cox) [1838731]
- [netdrv] net/intel: remove driver versions from Intel drivers (Ken Cox) [1838731]
- [netdrv] ixgbe: protect ring accesses with READ- and WRITE_ONCE (Ken Cox) [1838731]
- [netdrv] ixgbe: Remove unused inline function ixgbe_irq_disable_queues (Ken Cox) [1838731]
- [netdrv] ixgbe: Use true, false for bool variable in __ixgbe_enable_sriov() (Ken Cox) [1838731]
- [netdrv] ixgbe: Remove conversion to bool in ixgbe_device_supports_autoneg_fc() (Ken Cox) [1838731]
- [netdrv] ixgbe: fix signed-integer-overflow warning (Ken Cox) [1838731]
- [netdrv] ixgbe: Fix XDP redirect on archs with PAGE_SIZE above 4K (Ken Cox) [1838731]
- [netdrv] ionic: use mc sync for multicast filters (Jonathan Toppins) [1909329]
- [fs] xfs: always return -ENOSPC on project quota reservation failure (Carlos Maiolino) [1908612]
- [fs] xfs: group quota should return EDQUOT when prj quota enabled (Carlos Maiolino) [1908612]
- [pwm] pwm: Add DesignWare PWM Controller Driver (Steve Best) [1783562]
- [pwm] pwm: Ensure pwm_apply_state() doesn't modify the state argument (Steve Best) [1783562]
- [net] sched: Mark VLAN_ACT_{POP,PUSH}_ETH as Tech Preview (Guillaume Nault) [1909345]
- [vfio] vfio/pci: Decouple PCI_COMMAND_MEMORY bit checks from is_virtfn (Claudio Imbrenda) [1903972]
- [s390] s390/pci: Mark all VFs as not implementing PCI_COMMAND_MEMORY (Claudio Imbrenda) [1903972]
- [pci] PCI/IOV: Mark VFs as not implementing PCI_COMMAND_MEMORY (Claudio Imbrenda) [1903972]
- [iommu] s390/pci: adaptation of iommu to multifunction (Claudio Imbrenda) [1903972]
- [s390] s390/pci: fix leak of DMA tables on hard unplug (Claudio Imbrenda) [1853312]
- [s390] s390/pci: fix PF/VF linking on hot plug (Claudio Imbrenda) [1853312]
- [s390] s390/pci: re-introduce zpci_remove_device() (Claudio Imbrenda) [1853312]
- [s390] s390/pci: fix zpci_bus_link_virtfn() (Claudio Imbrenda) [1853312]
- [s390] s390/pci: ignore stale configuration request event (Claudio Imbrenda) [1853312]
- [s390] s390/pci: fix enabling a reserved PCI function (Claudio Imbrenda) [1853312]
- [s390] s390/pci: create links between PFs and VFs (Claudio Imbrenda) [1853312]
- [pci] PCI/IOV: Introduce pci_iov_sysfs_link() function (Claudio Imbrenda) [1853312]
- [s390] s390/pci: removes wrong PCI multifunction assignment (Claudio Imbrenda) [1853312]
- [s390] s390/pci: Handling multifunctions (Claudio Imbrenda) [1853312]
- [s390] s390/pci: Adding bus resource (Claudio Imbrenda) [1853312]
- [s390] s390/pci: adapt events for zbus (Claudio Imbrenda) [1853312]
- [s390] s390/pci: create zPCI bus (Claudio Imbrenda) [1853312]
- [s390] s390/pci: define RID and RID available (Claudio Imbrenda) [1853312]
- [s390] s390/pci: define kernel parameters for PCI multifunction (Claudio Imbrenda) [1853312]
- [pci] s390/pci: embedding hotplug_slot in zdev (Claudio Imbrenda) [1853312]
- [s390] s390/pci: Expose new port attribute for PCIe functions (Claudio Imbrenda) [1853312]
- [s390] s390/pci: Improve handling of unset UID (Claudio Imbrenda) [1853312]
- [s390] s390/pci: Fix zpci_alloc_domain() over allocation (Claudio Imbrenda) [1853312]
- [arm64] arm64: insn: Fix two bugs in encoding 32-bit logical immediates (Yauheni Kaliuta) [1900977]
- [iommu] iommu/amd: Set DTEto represent 512 IRTEs (Jerry Snitselaar) [1897492 1894769]
- [iommu] iommu/amd: Increase interrupt remapping table limit to 512 entries (Jerry Snitselaar) [1897492 1894769]
- [tools] selftests: forwarding: Add MPLS L2VPN test (Guillaume Nault) [1861261]
- [net] sched: act_mpls: Add action to push MPLS LSE before Ethernet header (Guillaume Nault) [1861261]
- [net] sched: act_vlan: Add {POP,PUSH}_ETH actions (Guillaume Nault) [1861261]
- [fs] cifs: Fix incomplete memory allocation on setxattr path (Leif Sahlberg) [1903883]
- [fs] cifs: Fix leak when handling lease break for cached root fid (Leif Sahlberg) [1903883]
- [fs] Revert "cifs: Fix the target file was deleted when rename failed." (Leif Sahlberg) [1903883]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1903883]
- [fs] cifs: fix reference leak for tlink (Leif Sahlberg) [1903883]
- [fs] smb3: fix unneeded error message on change notify (Leif Sahlberg) [1903883]
- [fs] cifs: remove the retry in cifs_poxis_lock_set (Leif Sahlberg) [1903883]
- [fs] smb3: fix access denied on change notify request to some servers (Leif Sahlberg) [1903883]
- [fs] Replace HTTP links with HTTPS ones: CIFS (Leif Sahlberg) [1903883]
- [fs] cifs: prevent truncation from long to int in wait_for_free_credits (Leif Sahlberg) [1903883]
- [fs] cifs: Fix the target file was deleted when rename failed (Leif Sahlberg) [1903883]
- [fs] SMB3: Honor 'posix' flag for multiuser mounts (Leif Sahlberg) [1903883]
- [fs] SMB3: Honor 'handletimeout' flag for multiuser mounts (Leif Sahlberg) [1903883]
- [fs] SMB3: Honor lease disabling for multiuser mounts (Leif Sahlberg) [1903883]
- [fs] SMB3: Honor persistent/resilient handle flags for multiuser mounts (Leif Sahlberg) [1903883]
- [fs] SMB3: Honor 'seal' flag for multiuser mounts (Leif Sahlberg) [1903883]
- [fs] cifs: Display local UID details for SMB sessions in DebugData (Leif Sahlberg) [1903883]
- [fs] cifs: misc: Use array_size() in if-statement controlling expression (Leif Sahlberg) [1903883]
- [fs] cifs: update ctime and mtime during truncate (Leif Sahlberg) [1903883]
- [fs] cifs/smb3: Fix data inconsistent when punch hole (Leif Sahlberg) [1903883]
- [fs] cifs/smb3: Fix data inconsistent when zero file range (Leif Sahlberg) [1903883]
- [fs] cifs: Fix double add page to memcg when cifs_readpages (Leif Sahlberg) [1903883]
- [fs] cifs: Fix cached_fid refcnt leak in open_shroot (Leif Sahlberg) [1903883]
- [fs] smb3: Add debug message for new file creation with idsfromsid mount option (Leif Sahlberg) [1903883]
- [fs] cifs: fix chown and chgrp when idsfromsid mount option enabled (Leif Sahlberg) [1903883]
- [fs] smb3: allow uid and gid owners to be set on create with idsfromsid mount option (Leif Sahlberg) [1903883]
- [fs] smb311: Add tracepoints for new compound posix query info (Leif Sahlberg) [1903883]
- [fs] smb311: add support for using info level for posix extensions query (Leif Sahlberg) [1903883]
- [fs] smb311: Add support for lookup with posix extensions query info (Leif Sahlberg) [1903883]
- [fs] smb311: Add support for SMB311 query info (non-compounded) (Leif Sahlberg) [1903883]
- [fs] SMB311: Add support for query info using posix extensions (level 100) (Leif Sahlberg) [1903883]
- [fs] smb3: add indatalen that can be a non-zero value to calculation of credit charge in smb2 ioctl (Leif Sahlberg) [1903883]
- [fs] smb3: fix typo in mount options displayed in /proc/mounts (Leif Sahlberg) [1903883]
- [fs] cifs: Add get_security_type_str function to return sec type (Leif Sahlberg) [1903883]
- [fs] smb3: extend fscache mount volume coherency check (Leif Sahlberg) [1903883]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1903883]
- [fs] smb3: fix incorrect number of credits when ioctl MaxOutputResponse > 64K (Leif Sahlberg) [1903883]
- [fs] smb3: remove static checker warning (Leif Sahlberg) [1903883]
- [fs] cifs: fix minor typos in comments and log messages (Leif Sahlberg) [1903883]
- [fs] smb3: minor update to compression header definitions (Leif Sahlberg) [1903883]
- [fs] cifs: minor fix to two debug messages (Leif Sahlberg) [1903883]
- [fs] cifs: Standardize logging output (Leif Sahlberg) [1903883]
- [fs] smb3: Add new parm "nodelete" (Leif Sahlberg) [1903883]
- [fs] cifs: get rid of unused parameter in reconn_setup_dfs_targets() (Leif Sahlberg) [1903883]
- [fs] cifs: handle hostnames that resolve to same ip in failover (Leif Sahlberg) [1903883]
- [fs] cifs: set up next DFS target before generic_ip_connect() (Leif Sahlberg) [1903883]
- [fs] cifs: remove redundant initialization of variable rc (Leif Sahlberg) [1903883]
- [fs] cifs: handle "nolease" option for vers=1.0 (Leif Sahlberg) [1903883]
- [fs] cifs: fix leaked reference on requeued write (Leif Sahlberg) [1903883]
- [fs] cifs: Fix null pointer check in cifs_read (Leif Sahlberg) [1903883]
- [fs] CIFS: Spelling s/EACCESS/EACCES/ (Leif Sahlberg) [1903883]
- [fs] cifs: fix uninitialised lease_key in open_shroot() (Leif Sahlberg) [1903883]
- [fs] cifs: ensure correct super block for DFS reconnect (Leif Sahlberg) [1903883]
- [fs] cifs: do not share tcons with DFS (Leif Sahlberg) [1903883]
- [fs] cifs: minor update to comments around the cifs_tcp_ses_lock mutex (Leif Sahlberg) [1903883]
- [fs] cifs: protect updating server->dstaddr with a spinlock (Leif Sahlberg) [1903883]
- [fs] smb3: remove overly noisy debug line in signing errors (Leif Sahlberg) [1903883]
- [fs] cifs: improve read performance for page size 64KB & cache=strict & vers=2.1+ (Leif Sahlberg) [1903883]
- [fs] cifs: dump the session id and keys also for SMB2 sessions (Leif Sahlberg) [1903883]
- [fs] smb3: enable swap on SMB3 mounts (Leif Sahlberg) [1903883]
- [fs] smb3: change noisy error message to FYI (Leif Sahlberg) [1903883]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1903883]
- [fs] smb3: use SMB2_SIGNATURE_SIZE define (Leif Sahlberg) [1903883]
- [fs] CIFS: Fix bug which the return value by asynchronous read is error (Leif Sahlberg) [1903883]
- [fs] CIFS: check new file size when extending file by fallocate (Leif Sahlberg) [1903883]
- [fs] SMB3: Minor cleanup of protocol definitions (Leif Sahlberg) [1903883]
- [fs] SMB3: Additional compression structures (Leif Sahlberg) [1903883]
- [fs] SMB3: Add new compression flags (Leif Sahlberg) [1903883]
- [fs] cifs: smb2pdu.h: Replace zero-length array with flexible-array member (Leif Sahlberg) [1903883]
- [fs] cifs: clear PF_MEMALLOC before exiting demultiplex thread (Leif Sahlberg) [1903883]
- [fs] cifs: cifspdu.h: Replace zero-length array with flexible-array member (Leif Sahlberg) [1903883]
- [fs] CIFS: Warn less noisily on default mount (Leif Sahlberg) [1903883]
- [fs] fs/cifs: fix gcc warning in sid_to_id (Leif Sahlberg) [1903883]
- [fs] cifs: allow unlock flock and OFD lock across fork (Leif Sahlberg) [1903883]
- [fs] cifs: do d_move in rename (Leif Sahlberg) [1903883]
- [fs] cifs: add SMB2_open() arg to return POSIX data (Leif Sahlberg) [1903883]
- [fs] cifs: plumb smb2 POSIX dir enumeration (Leif Sahlberg) [1903883]
- [fs] cifs: add smb2 POSIX info level (Leif Sahlberg) [1903883]
- [fs] cifs: rename posix create rsp (Leif Sahlberg) [1903883]
- [fs] cifs: print warning mounting with vers=1.0 (Leif Sahlberg) [1903883]
- [fs] smb3: fix performance regression with setting mtime (Leif Sahlberg) [1903883]
- [fs] cifs: make use of cap_unix(ses) in cifs_reconnect_tcon() (Leif Sahlberg) [1903883]
- [fs] cifs: use mod_delayed_work() for &server->reconnect if already queued (Leif Sahlberg) [1903883]
- [fs] cifs: call wake_up(&server->response_q) inside of cifs_reconnect() (Leif Sahlberg) [1903883]
- [fs] cifs: do not ignore the SYNC flags in getattr (Leif Sahlberg) [1903883]
- [tools] tools/power/x86/intel-speed-select: Update version for v5.10 (Prarit Bhargava) [1896211]
- [tools] tools/power/x86/intel-speed-select: Fix missing base-freq core IDs (Prarit Bhargava) [1896211]
- [tools] tools/power/x86/intel-speed-select: Update version for v5.9 (Prarit Bhargava) [1896211]
- [tools] tools/power/x86/intel-speed-select: Add retries for mail box commands (Prarit Bhargava) [1896211]
- [tools] tools/power/x86/intel-speed-select: Add option to delay mbox commands (Prarit Bhargava) [1896211]
- [tools] tools/power/x86/intel-speed-select: Ignore -o option processing on error (Prarit Bhargava) [1896211]
- [tools] tools/power/x86/intel-speed-select: Change path for caching topology info (Prarit Bhargava) [1896211]
- [kernel] perf/core: Fix race in the perf_mmap_close() function (Michael Petlan) [1869925] {CVE-2020-14351}
- [kernel] perf: Make struct ring_buffer less ambiguous (Michael Petlan) [1869925] {CVE-2020-14351}
- [arm64] arm64: bpf: Fix branch offset in JIT (Yauheni Kaliuta) [1875342]

* Thu Jan 14 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-274.el8]
- [hwmon] hwmon: (amd_energy) fix allocation of hwmon_channel_info config (David Arcari) [1911220]
- [hwmon] hwmon: (amd_energy) Add AMD family 19h model 01h x86 match (David Arcari) [1911220]
- [hwmon] hwmon: (amd_energy) modify the visibility of the counters (David Arcari) [1911220]
- [hwmon] hwmon: (amd_energy) Improve the accumulation logic (David Arcari) [1911220]
- [hwmon] hwmon: (amd_energy) optimize accumulation interval (David Arcari) [1911220]
- [hwmon] hwmon: (amd_energy) Move label out of accumulation structure (David Arcari) [1911220]
- [powerpc] powerpc/64s: Remove TM from Power10 features (Gustavo Duarte) [1892471]
- [netdrv] ionic: start queues before announcing link up (Jonathan Toppins) [1906250]
- [fs] NFSD: fix missing refcount in nfsd4_copy by nfsd4_do_async_copy (Benjamin Coddington) [1873897]
- [bluetooth] Bluetooth: btusb: Map Typhoon peak controller to BTUSB_INTEL_NEWGEN (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Add support for Intel Bluetooth Device Typhoon Peak (8087:0032) (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Helper function to download firmware to Intel adapters (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Define a function to construct firmware filename (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Add *setup* function for new generation Intel controllers (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btintel: Fix endianness issue for TLV version information (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btintel: Functions to send firmware header / payload (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btintel: Add infrastructure to read controller information (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btintel: Refactor firmware download function (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Update boot parameter specific to SKU (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Refactor of firmware download flow for Intel conrollers (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Enable Intel events even if already in operational mode (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Configure Intel debug feature based on available support (Gopal Tiwari) [1900356]
- [bluetooth] Bluetooth: btusb: Add support to read Intel debug feature (Gopal Tiwari) [1900356]
- [kernel] rcuwait: avoid lockdep splats from rcuwait_active() (Auger Eric) [1903095]
- [net] udp: fix the proto value passed to ip_protocol_deliver_rcu for the segments (Xin Long) [1879403]
- [net] udp: fix IP header access and skb lookup on Fast/frag0 UDP GRO (Xin Long) [1879403]
- [net] udp: fix UDP header access on Fast/frag0 UDP GRO (Xin Long) [1879403]
- [net] ethtool: add missing NETIF_F_GSO_FRAGLIST feature string (Xin Long) [1879403]
- [net] fix fraglist segmentation reference count leak (Xin Long) [1879403]
- [net] udp: initialize is_flist with 0 in udp_gro_receive (Xin Long) [1879403]
- [include] udp: segment looped gso packets correctly (Xin Long) [1879403]
- [net] udp: Support UDP fraglist GRO/GSO. (Xin Long) [1879403]
- [net] Support GRO/GSO fraglist chaining. (Xin Long) [1879403]
- [net] Add a netdev software feature set that defaults to off. (Xin Long) [1879403]
- [net] Add fraglist GRO/GSO feature flags (Xin Long) [1879403]
- [include] udp: Avoid post-GRO UDP checksum recalculation (Xin Long) [1879403]
- [net] udp: fix GRO packet of death (Xin Long) [1879403]
- [net] udp: fix GRO reception in case of length mismatch (Xin Long) [1879403]
- [net] udp: cope with UDP GRO packet misdirection (Xin Long) [1879403]
- [net] ipv6: factor out protocol delivery helper (Xin Long) [1879403]
- [net] ip: factor out protocol delivery helper (Xin Long) [1879403]
- [net] udp: add support for UDP_GRO cmsg (Xin Long) [1879403]
- [net] udp: implement GRO for plain UDP sockets. (Xin Long) [1879403]

* Wed Jan 13 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-273.el8]
- [powerpc] powerpc/perf: Fix Threshold Event Counter Multiplier width for P10 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Exclude kernel samples while counting events in user space (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Invoke per-CPU variable access with disabled interrupts (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: MMCR0 control for PMU registers under PMCC=00 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/64s: Convert some cpu_setup() and cpu_restore() functions to C (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/64: Set up a kernel stack for secondaries before cpu_restore() (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc: Wire up memtest (Desnes Augusto Nunes do Rosario) [1906084]
- [mm] powerpc/mm: Don't report hugepage tables as memory leaks when using kmemleak (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Fix to update cache events with l2l3 events in power10 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Fix to update generic event codes for power10 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Add generic and cache event list for power10 DD1 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Fix the PMU group constraints for threshold events in power10 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Update the PMU group constraints for l2l3 events in power10 (Desnes Augusto Nunes do Rosario) [1906084]
- [powerpc] powerpc/perf: Fix to update radix_scope_qual in power10 (Desnes Augusto Nunes do Rosario) [1906084]
- [nvme] nvme-pci: mark Samsung PM1725a as IGNORE_DEV_SUBNQN (Gopal Tiwari) [1903513]
- [base] driver: core: Fix list corruption after device_del() (Torez Smith) [1900751]
- [base] device property: Don't clear secondary pointer for shared primary firmware node (Torez Smith) [1900751]
- [base] device property: Keep secondary firmware node secondary by type (Torez Smith) [1900751]
- [of] of: property: Fix create device links for all child-supplier dependencies (Torez Smith) [1900751]
- [base] drivers/base/test: fix global-out-of-bounds error (Torez Smith) [1900751]
- [base] driver core: Fix use-after-free and double free on glue directory (Torez Smith) [1900751]
- [thunderbolt] thunderbolt: Add uaccess dependency to debugfs interface (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Use "if USB4" instead of "depends on" in Kconfig (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Allow KUnit tests to be built also when CONFIG_USB4=m (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: debugfs: Fix uninitialized return in counters_write() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add debugfs interface (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: cdc-acm: Add DISABLE_ECHO for Renesas USB Download mode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Report power supply changes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: hisilicon: fix refercence leak in xhci_histb_probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add support for Intel Tiger Lake-H (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: apple-mfi-fastcharge: fix reference leak in apple_mfi_fc_set_property (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Only configure USB4 wake for lane 0 adapters (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Fix memory leak if ida_simple_get() fails in enumerate_services() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Telit FN980 composition 0x1055 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add LE910Cx compositions 0x1203, 0x1230, 0x1231 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cyberjack: fix write-URB completion race (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Add NO_LPM quirk for Kingston flash drive (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Don't create stream debugfs files with spinlock held (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Workaround for S3 issue on AMD SNPS 3.0 xHC (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix sizeof() mismatch (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: stusb160x: fix signedness comparison issue with enum variables (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: add missing MODULE_DEVICE_TABLE() to stusb160x (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usbcore: Check both id_table and match() when both available (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: stusb160x: fix an IS_ERR() vs NULL check in probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: reset hard_reset_count for any disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: cdc-acm: fix cooldown mechanism (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: fix kernel-doc markups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: stusb160x: fix some signedness bugs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Quectel EC200T module support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add the missed ida_simple_remove() in ring_request_msix() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [documentation] usb: docs: document altmode register/unregister functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Add QCOM PMIC typec detection driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Cellient MPL200 card (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci_maxim: Add support for Sink FRS (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: Implement callbacks for FRS (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: tcpm: Add support for Sink Fast Role SWAP(FRS) (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci_maxim: Chip level TCPC driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: Add set_vbus tcpci callback (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: Add a getter method to retrieve tcpm_port reference (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: cdc-acm: add quirk to blacklist ETAS ES58X devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: use cur_altsetting for consistency (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: Add Telit FT980-KS composition (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: remove polling for /sys/kernel/debug/usb/devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: add support for STUSB160x Type-C controller family (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: add typec_find_pwr_opmode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: hd3ss3220: Use OF graph API to get the connector fwnode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-wdm: Make wdm_flush() interruptible and add wdm_fsync() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: displayport: Reduce noise from the driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: hub: Add Kconfig option to reduce number of port initialization retries (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: hub: Clean up use of port initialization schemes and retries (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: qcserial: fix altsetting probing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: clean up jtag quirks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: pl2303: add device-id for HP GC device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: add support for FreeCalypso JTAG+UART adapters (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: clean up no-union-descriptor handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: use common data-class define (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: handle broken union descriptors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] Revert "cdc-acm: hardening against malicious devices" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usbcore/driver: Accommodate usbip (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] PM: core: introduce pm_ptr() macro (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [kernel] sched: Provide sched_set_fifo() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usbcore/driver: Fix incorrect downcast (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usbcore/driver: Fix specific driver selection (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [sound] USB: correct API of usb_control_msg_send/recv in sound driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: correct API of usb_control_msg_send/recv (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] Revert "USB: legousbtower: use usb_control_msg_recv()" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] Revert "USB: core: hub.c: use usb_control_msg_send() in a few places" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: pci-quirks: convert to readl_poll_timeout_atomic() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: early: ehci-dbgp: convert to readl_poll_timeout_atomic() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: early: convert to readl_poll_timeout_atomic() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: appledisplay: use module_usb_driver to simplify the code (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: add debugfs support for ep with stream (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: don't create endpoint debugfs entry before ring buffer is set (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Tune interrupt blocking for isochronous transfers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: omit duplicate actions when suspending a runtime suspended host (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: improve the comments for xhci_plat_suspend (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: add wakeup entry at sysfs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: add priv quirk for skip PHY initialization (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: delete the unnecessary code (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: add .suspend_quirk for struct xhci_plat_priv (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: add platform data support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: cleanup of data structures (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: adutux: fix debugging (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usblp: fix race between disconnect() and read() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: don't inherity DMA properties for USB devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] ehci-hcd: Move include to keep CRC stable (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Only stop control channel when entering freeze (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Capitalize comment on top of QUIRK_FORCE_POWER_LINK_CONTROLLER (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Correct tb_check_quirks() kernel-doc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Log correct zeroX entries in decode_error() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Handle ERR_LOCK notification (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Handle SCU IPC error conditions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: quirks: Add USB_QUIRK_IGNORE_REMOTE_WAKEUP quirk for BYD zhaoxin notebook (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: update ROLE_CONTROL for DRP (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: Add support when hidden tx registers are inaccessible (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: Add register definitions to tcpci (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: UAS: use macro for reporting results (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Pass correct USB Type-C port number to SoC (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Add dependency on ACPI (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: microtek: use set_host_byte() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: UAS: fix disconnect by unplugging a hub (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Prevent mode overrun (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: acpi: Increase command completion timeout value (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: use usb_control_msg_recv() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: hub.c: use usb_control_msg_send() in a few places (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: message.c: use usb_control_msg_send() in a few places (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb typec: mt6360: Add support for mt6360 Type-C driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: ehci-sched: Remove ununsed function tt_start_uframe() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: ohci: Make distrust_firmware param default to false (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: ohci: Default to per-port over-current protection (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Retry DROM read once if parsing fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Support for device role (UFP) (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Check the port status before connect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Do not configure SBU and HSL Orientation in Alternate modes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Do not configure Altmode HPD High (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] device connection: Remove struct device_connection (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] uas: bump hw_max_sectors to 2048 blocks for SS or faster drives (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] uas: fix sdev->host->dma_dev (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: fix sdev->host->dma_dev (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb/host: ehci-npcm7xx: Use pm_ptr() macro (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb/misc: usb3503: Use pm_ptr() macro (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb/misc: usb4604: Use pm_ptr() macro (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: driver: fix stray tabs in error messages (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: acpi: Check the _DEP dependencies (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: fix slab-out-of-bounds Read in read_descriptors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: Fix out of sync data toggle if a configured device is reconfigured (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Un-register the USB role switch (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Introduce tb_switch_is_ice_lake() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Introduce tb_switch_is_tiger_lake() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Check for Intel vendor ID when identifying controller (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Introduce tb_port_is_nhi() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Create device links from ACPI description (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: No need to warn in TB_CFG_ERROR_INVALID_CONFIG_SPACE (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Introduce tb_switch_next_cap() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Introduce tb_port_next_cap() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Move struct tb_cap_any to tb_regs.h (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add runtime PM for Software CM (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [pci] PCI / thunderbolt: Switch to use device links instead of PCI quirk (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Enable wakes from system suspend (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Tear down DP tunnels when suspending (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Disable lane 1 for XDomain connection (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Configure port for XDomain (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Set port configured for both ends of the link (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Configure link after lane bonding is enabled (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Do not change default USB4 router notification timeout (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Initialize TMU again on resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Send reset only to first generation routers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Do not program NFC buffers for USB4 router protocol adapters (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Optimize NHI LC mailbox command processing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Optimize Force Power logic (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Software CM only should set force power in Tiger Lake (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Use bit 31 to check if Firmware CM is running in Tiger Lake (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: No need to log an error if tb_switch_lane_bonding_enable() fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Use kobj_to_dev() instead of container_of() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: support dynamic Quectel USB compositions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add support for SIM7070/SIM7080/SIM7090 modules (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Migrate workqueue to RT priority for processing events (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: pd: Fix formatting in pd.h header (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: During PR_SWAP, source caps should be sent only after tSwapSourceStart (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblcd: Remove the superfluous break (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: storage: Add unusual_uas entry for Sony PSZ drives (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Ignore UAS for JMicron JMS567 ATA/ATAPI Bridge (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: quirks: Ignore duplicate endpoint on Sound Devices MixPre-D (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: atm: don't use snprintf() for sysfs attrs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Fix Fix source hard reset response for TDA 2.3.1.1 and TDA 2.3.1.2 failures (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Use maximum USB3 link rate when reclaiming if link is not up (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add USB3 bandwidth management (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Disable ports that are not implemented (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: add IDs for Xsens Mti USB converter (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Always restore EP_SOFT_CLEAR_TOGGLE even if ep reset failed (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Do warm-reset when both CAS and XDEV_RESUME are set (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci: fix ep context print mismatch in debugfs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: uas: Add quirk for PNY Pro Elite (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Better name for __check_usb_generic() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Fix device driver race (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Also match device drivers using the ->match vfunc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: fix tegra_xusb_get_phy() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: otg usb2/usb3 port init (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: pci-quirks: Bypass xHCI quirks for Raspberry Pi 4 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [firmware] Revert "USB: pci-quirks: Add Raspberry Pi 4 quirk" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci-pci: Add support for reset controllers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: Solve race condition in anchor cleanup functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: usb-conn-gpio: Print error on failure to get VBUS (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: usb-conn-gpio: Make VBUS supply optional (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: yurex: remove needless check before usb_free_coherent() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: remove a duplicated entry (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: storage: isd200: fix spelling mistake "removeable" -> "removable" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci-mtk: Fix typo (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: hcd: Fix use after free in usb_hcd_pci_remove() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Hold con->lock for the entire duration of ucsi_register_port() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Rework ppm_lock handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Fix 2 unlocked ucsi_run_command calls (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Fix AB BA lock inversion (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: lvtest: return proper error code in probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: rework notification_buffer resizing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: quirks: Add no-lpm quirk for another Raydium touchscreen (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: yurex: Fix bad gfp argument (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: merge fix for kunix_resource changes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: usb-conn-gpio: Register charger (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Fix ASMedia ASM1142 DMA addressing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: define IDs for various ASMedia host controllers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Simplify USB ID table match (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Add WARN_ON ensure we are not trying to send 2 VDM packets at the same time (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Fix AB BA lock inversion between tcpm code and the alt-mode drivers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Refactor tcpm_handle_vdm_request (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Refactor tcpm_handle_vdm_request payload handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Add tcpm_queue_vdm_unlocked() helper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Move mod_delayed_work(&port->vdm_state_machine) call into tcpm_queue_vdm() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Make function xhci_dbc_ring_alloc() static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbgtty: Make some functions static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for pinctrl-0 through pinctrl-8 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for multiple DT bindings (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: fix up report size handling for some devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: remove tty specific port structure from struct xhci_dbc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbgcap: remove dbc dependency on dbctty specific flag (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Add a operations structure to access driver functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbctty: split dbc tty driver registration and unregistration functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: remove endpoint pointers from dbc_port structure (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: simplify dbc requests allocation and queueing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Pass dbc pointer to dbc start and stop functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Pass dbc pointer to dbc memory init and cleanup functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: don't use generic xhci ring allocation functions for dbc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Don't use generic xhci context allocation for dbc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Use dbc structure in the request completion instead of xhci_hcd (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Pass dbc pointer to get_in/out_ep() helper functions to get endpoints (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbgtty: Pass dbc pointer when registering a dbctty device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Pass dbc pointer to dbc_handle_xfer_event() instead of xhci_hcd pointer (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Change to pass dbc pointer to xhci_do_dbc_stop() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Pass dbc pointer to endpoint init and exit functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Get the device pointer from dbc structure in dbc_ep_do_queue() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Don't pass the xhci pointer as a parameter to xhci_dbc_init_context() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Don't use xhci_write_64() as it takes xhci as a parameter (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Use dev_info() and similar instead of xhci_info() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Add device pointer to dbc structure (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Remove dbc_dma_free_coherent() wrapper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Remove dbc_dma_alloc_coherent() wrapper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Don't use generic xhci erst allocation and free functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Don't pass struct xhci_hcd pointer to xhci_link_seg() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: dbc: Don't use generic xhci inc_deq() function for dbc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Make debug message consistent with bus and port number (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: tegra: Fix allocation for the FPCI context (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usbfs: stop using compat_alloc_user_space (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Fix ASM2142/ASM3142 DMA addressing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci-mtk: fix the failure of bandwidth allocation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: appledisplay: remove needless check before usb_free_coherent() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usbtest: reduce stack usage in test_queue (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Stay in BIST mode till hardreset or unattached (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: Support BIST test data mode for compliance (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Support bist test data mode for compliance (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Error handling for tcpm_register_partner_altmodes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Comment correction for typec_partner_register_altmode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Avoid connect request on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: fix quirks_param_set() writing to a const pointer (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: hcd: Try MSI interrupts on PCI devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: qcserial: add EM7305 QDL product ID (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: iuu_phoenix: fix led-activity helpers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: iuu_phoenix: fix memory corruption (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: sisusbvga: Move static const tables out to different include file (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: sisusbvga: sisusb_init: Remove genunine unused static const arrays (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: class: cdc-wdm: Provide description for usb_cdc_wdm_register()'s manage_power arg (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: linux/usb/serial.h: drop duplicated word in comment (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: linux/usb/pd_vdo.h: drop duplicated word in comment (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: linux/usb.h: drop duplicated word in comment (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Remove pci-dma-compat wrapper APIs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: sisusbvga: Fix a potential UB casued by left shifting a negative value (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ohci: Replace HTTP links with HTTPS ones (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Replace HTTP links with HTTPS ones (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: Replace HTTP links with HTTPS ones (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: sierra: clean up special-interface handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: use in-kernel types in port data (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: drop unnecessary packed attributes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: add support for TIOCGICOUNT (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: add support for line-status events (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: disable interface on errors in open (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: OHCI: Use fallthrough pseudo-keyword (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: Use fallthrough pseudo-keyword (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: Use fallthrough pseudo-keyword (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: storage: replace HTTP links with HTTPS ones (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: Do not define 'struct acpi_device_id' when !CONFIG_ACPI (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: early: xhci-dbc: File headers are not good candidates for kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: early: xhci-dbc: Supply missing 'xhci-dbgp.h' headerfile (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: early: ehci-dbgp: Remove set but never checked variable 'ret' (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: ucsi: Staticify and stop export of ucsi_init() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: legousbtower: Demote function header which is clearly not kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: legousbtower: Demote obvious misuse of kerneldoc to standard comment blocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: ldusb: Demote obvious misuse of kerneldoc to standard comment blocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: iowarrior: Demote obvious misuse of kerneldoc to standard comment blocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: iowarrior: Fix odd corruption issue in the file header (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: fusb302: Use 'gnu_printf' format notation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: altmodes: displayport: Supply missing displayport.h include file (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: altmodes: displayport: File headers are not good candidates for kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: storage: alauda: Remove set but unchecked variable (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-debugfs: Use 'gnu_printf' format notation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-dbgtty: File headers are not good candidates for kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-dbgcap: File headers are not good candidates for kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-mem: Demote obvious misuse of kerneldoc to standard comment block (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci: Demote obvious misuse of kerneldoc to standard comment block (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: adutux: Demote obvious misuse of kerneldoc to standard comment blocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: atm: ueagle-atm: Demote obvious misuse of kerneldoc to standard comment blocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: ledtrig-usbport: Demote obvious misuse of kerneldoc to standard comment blocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: drop redundant transfer-buffer casts (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] USB: serial: drop extern keyword from function declarations (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] USB: serial: drop unnecessary sysrq include (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: add sysrq break-handler dummy (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: inline sysrq dummy function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: only process sysrq when enabled (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: only set sysrq timestamp for consoles (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: fix break and sysrq handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: clean up receive processing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: make process-packet buffer unsigned (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: use fallthrough pseudo-keyword (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Quectel EG95 LTE modem (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: fix missing simulated-break margin (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: re-enable auto-RTS on open (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cp210x: enable usb generic throttle/unthrottle (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: simulate break condition if not supported (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: class: usbtmc: File headers are not good candidates for kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: ohci: Mark cc_to_error as __maybe_unused (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: ulpi: Fix a few kerneldoc related issues (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: usb-conn-gpio: Demote comment block which is clearly not kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: debug: Demote comment blocks which are obviously not kerneldoc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: pci-quirks: Demote function header from kerneldoc to comment block (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] USB: Fix up terminology in include files (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Fix old style declaration warning (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: console: add support for flow control (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: quatech2: drop two stub functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: kobil_sct: log failure to update line settings (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: keyspan_pda: drop unused firmware reset status (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: iuu_phoenix: drop unused URB submission results (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: garmin_gps: don't compile unused packet definitions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Add support for USB4 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Definitions for response status bits (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Add data structure for Enter_USB message (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Combine the definitions for Accessory and USB modes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Fix up terminology (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: fix kernel-doc warnings and formatting in <linux/usb.h> (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add support for authenticate on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add support for separating the flush to SPI and authenticate (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Ensure left shift of 512 does not overflow a 32 bit int (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: add min and max line-speed macros (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: name prescaler, divisor registers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Poll for U0 after disabling USB2 LPM (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Return if xHCI doesn't support LPM (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-mtk: avoid runtime suspend when removing hcd (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix enumeration issue when setting max packet size for FS devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix incorrect EP_STATE_MASK (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: add new Product ID for CH340 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add GosunCn GM500 series (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cypress_m8: enable Simply Automated UPB PIM (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add support for on-board retimers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Implement USB4 port sideband operations for retimer access (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Split common NVM functionality into a separate file (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Retry USB4 block read operation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Generalize usb4_switch_do__data() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add Intel USB-IF ID to the NVM upgrade supported list (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Increase DP DPRX wait timeout (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Make tb_port_get_link_speed() available to other files (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Handle incomplete PCIe/USB3 paths correctly in discovery (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Increase path length in discovery (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add KUnit tests for tunneling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add KUnit tests for path walking (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add DP IN resources for all routers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Report consumed bandwidth in both directions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Make usb4_switch_map_pcie_down() also return enabled ports (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Make usb4_switch_map_usb3_down() also return enabled ports (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Do not tunnel USB3 if link is not USB4 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Implement USB3 bandwidth negotiation routines (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Check that both ports are reachable when allocating path (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Make tb_path_alloc() work with tree topologies (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Make tb_next_port_on_path() work with tree topologies (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Fix path indices used in USB3 tunnel discovery (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [netdrv] thunderbolt: Get rid of E2E workaround (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: NHI can use HopIDs 1-7 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: No need to warn if NHI hop_count != 12 or hop_count != 32 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Build initial XDomain property block upon first connect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: OTG: rename product list of devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: storage: scsi: fix up comment to be more specific (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: storage: fix wording in error message (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: sierra: unify quirk handling logic (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: qcserial: fix up wording in a comment (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: OHCI: remove obsolete FIXME comment (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: rename USB OTG hub configuration option (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: rename USB quirk to USB_QUIRK_ENDPOINT_IGNORE (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [uapi] USB: replace hardcode maximum usb string length by definition (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci_rt1711h: avoid screaming irq causing boot hangs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usbtest: fix missing kfree(dev->buf) in usbtest_disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ehci: reopen solution for Synopsys HC bug (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] cdc-acm: Add DISABLE_ECHO quirk for Microchip/SMSC chip (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: add USB_QUIRK_DELAY_INIT for Logitech C922 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: intel_pmc_mux: Fix DP alternate mode entry (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: sisusbvga: change char to u8 for sisusb_copy_memory (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: sisusb_con: Use array_size() helper in memcpy() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: tegra: Remove PLL power supplies (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] drivers: usb: Fix trivial spelling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: additional Device Classes to debug/usb/devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Improve USB4 config symbol help text (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: kcov: collect coverage from usb complete callback (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: get rid of pointless access_ok() calls (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: fix lockup of devices with limited prescaler (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: add basis for quirk detection (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] CDC-ACM: heed quirk also in error handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Telit LE910C1-EUX compositions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: qcserial: add DW5816e QDL support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add trivial .shutdown (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Ensure USB_ROLE_SWITCH is set as a dependency for tps6598x (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: make symbols static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: usb_wwan: do not resubmit rx urb on fatal errors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb/xhci-plat: Set PM runtime as active on resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Add support for Renesas controller with memory (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: renesas-xhci: Add the renesas xhci driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: hci: add hc_driver as argument for usb_hcd_pci_probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: hub: limit HUB_QUIRK_DISABLE_AUTOSUSPEND to USB5534B (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbfs: fix mmap dma mismatch (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: keep runtime active when removing host (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Fix NULL pointer dereference when enqueuing trbs from urb sg list (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Update Kconfig to allow building on other architectures (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: intel: Fix DP_HPD_LVL bit field (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: ehci: Add new EHCI driver for Broadcom STB SoC's (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: xhci-plat: Add support for Broadcom STB SoC's (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tps6598x: Add USB role switching logic (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tps6598x: Add OF probe binding (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: Switch on role-switch uevent reporting (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: intel_pmc_mux: Support for static SBU/HSL orientation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Add typec_find_orientation() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usblp: poison URBs upon disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] sierra-ms: do not call scsi_get_host_dev() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [firmware] USB: pci-quirks: Add Raspberry Pi 4 quirk (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] thunderbolt: Replace zero-length array with flexible-array (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usbfs: correct kernel->user page attribute mismatch (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: intel_pmc_mux: Fix the property names (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: intel: Handle alt mode HPD_HIGH (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: Fix misleading driver bug report (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: qcserial: Add DW5816e support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: uas: add quirk for LaCie 2Big Quadra (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Do not link to disabled devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Check return value of tb_sw_read() in usb4_switch_op() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: hub: use true, false for bool variable (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Fix the stub for ucsi_register_port_psy() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: Convert the Intel PMC Mux driver to use new SCU IPC API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: register with power_supply class (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: save power data objects in PD mode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Correct bit-mask for CCI (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: replace magic numbers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Workaround for missed op_mode change (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: set USB data role when partner type is power cable/ufp (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Storage: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: Replace an empty statement with a debug message (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb/early: remove unused including <linux/version.h> (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: pci-quirks: use true, false for bool variables (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: typec: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: sisusbvga: Change port variable from signed to unsigned (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: Add unusual_devs entry for JMicron JMS566 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: hub: Revert commit bd0e6c9614b9 ("usb: hub: try old enumeration scheme first for high speed devices") (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: hub: Fix handling of connect changes during sleep (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add support for Intel Tiger Lake (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: altmode: Fix typec_altmode_get_partner sometimes returning an invalid pointer (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: garmin_gps: add sanity checking for data length (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Don't clear hub TT buffer on ep0 protocol stall (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: prevent bus suspend if a roothub port detected a over-current condition (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix handling halted endpoint even if endpoint ring appears empty (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [gpio] usb: fusb302: Convert to use GPIO descriptors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Add USB_QUIRK_DELAY_CTRL_MSG and USB_QUIRK_DELAY_INIT for Corsair K70 RGB RAPIDFIRE (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Ignore CC and vbus changes in PORT_RESET change (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] cdc-acm: introduce a cool down (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] cdc-acm: close race betrween suspend() and acm_softint (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] UAS: fix deadlock in error handling and PM flushing work (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] UAS: no use logging any details in case of ENODEV (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: pi3usb30532: Set switch_ / mux_desc name field to NULL (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: early: Handle AMD's spec-compliant identifiers, too (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: Fix free-while-in-use bug in the USB S-Glibrary (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: misc: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: host: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: early: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] Revert "thunderbolt: Prevent crash if non-active NVMem file is read" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for extcon (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: restore capability check order (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Correct the documentation for typec_cable_put() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: io_edgeport: fix slab-out-of-bounds read in edge_interrupt_callback (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Wistron Neweb D19Q1 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add BroadMobi BM806U (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add support for ASKEY WWHC050 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: Add ACPI support for USB interface devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci-tegra: Add OTG support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: add control driver for F81534A (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: fix rounding error in TIOCSSERIAL (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cdc-acm: fix close_delay and closing_wait units in TIOCSSERIAL (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: quirks: add NO_LPM quirk for RTL8153 based ethernet adapters (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: atm: Use the correct style for SPDX License Identifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci-pci: Allow host runtime PM as default for Intel Tiger Lake xHCI (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Finetune host initiated USB3 rootport link suspend and resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Wait until link state trainsits to U0 after setting USB_SS_PORT_LS_U0 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Ensure link state is U3 after setting USB_SS_PORT_LS_U3 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Tegra186/Tegra194 LPM (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Enable LPM for VIA LABS VL805 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Show host status when watchdog triggers and host is assumed dead (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Add a separate debug message for split transaction errors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: bail out early if driver can't accress host in resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: pl2303: add device-id for HP LD381 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add ME910G1 ECM composition 0x110b (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: mon: Use scnprintf() for avoiding potential buffer overflow (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi_ccg: workaround for NVIDIA test device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: add a shutdown (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: displayport: Fix a potential race during registration (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: displayport: Fix NULL pointer dereference (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Disable LPM on WD19's Realtek Hub (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Use scnprintf() for avoiding potential buffer overflow (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: fix tty cleanup-op kernel-doc (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: clean up carrier-detect helper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: apply XHCI_SUSPEND_DELAY to AMD XHCI controller 1022:145c (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Delete of_devlink kernel commandline option (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: driver for Intel PMC mux control (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Add definitions for Thunderbolt 3 Alternate Mode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: Allow the role switches to be named (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: Provide the switch drivers handle to the switch in the API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: Leave the private driver data pointer to the drivers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: Allow the mux handles to be requested with fwnode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: Add helpers for setting the mux state (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: Allow the muxes to be named (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: port: do error out if usb_autopm_get_interface() fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: hub: do error out if usb_autopm_get_interface() fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: hub: fix unhandled return by employing a void function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: storage: Add quirk for Samsung Fit flash (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: quirks: add NO_LPM quirk for Logitech Screen Share (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb251xb: fix regulator probe and error handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Add sysfs node to show cc orientation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: move to SNK_UNATTACHED if sink removed for DRP (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for power-domains and hwlocks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: set F81534A serial port with RS232 mode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: add F81534A support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: use devm_kzalloc for port data (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: add tx_empty function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: extract LSR handler (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-pci: remove useless cast for driver.name (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: uhci-pci: remove useless cast for driver.name (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: ohci-pci: remove useless cast for driver.name (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: ehci-pci: remove useless cast for driver.name (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: Use ACPI_SUCCESS() at appropriate places (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: Make use of acpi_evaluate_object() status (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: Use const to reduce object data size (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: ucsi: ccg: disable runtime pm during fw flashing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: register DP only for NVIDIA DP VDO (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: misc: iowarrior: add support for the 100 device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Add missing annotation for xhci_enter_test_mode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Add missing annotation for xhci_set_port_power() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Do not open code __print_symbolic() in xhci trace events (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: use kobj_to_dev() API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: Add missing kernel-doc parameter descriptions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: set correct data role for non-DRD (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: icm: Replace zero-length array with flexible-array member (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [thunderbolt] thunderbolt: eeprom: Replace zero-length array with flexible-array member (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: apple-mfi-fastcharge: don't probe unhandled devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: apple-mfi-fastcharge: fix endianess issue in probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Add driver to control USB fast charge for iOS devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Fallback to generic driver when specific driver fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Select better matching USB drivers when available (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Implement usb_device_match_id() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Make it possible to "subclass" usb_device_driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Export generic USB device driver functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: atm: Replace zero-length array with flexible-array member (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: Drop support for device name matching (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: altmode: Remove the notification chain (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Fix the description of struct typec_capability (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Allow power role swapping even without USB PD (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Hide the port_type attribute when it's not supported (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Make the attributes read-only when writing is not possible (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: misc: iowarrior: add support for the 28 and 28L devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: misc: iowarrior: add support for 2 OEMed devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Fix novation SourceControl XL after suspend (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix memory leak when caching protocol extended capability PSI tables - take 2 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] Revert "xhci: Fix memory leak when caching protocol extended capability PSI tables" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: remove redundant assignment to variable num (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: host: ehci-platform: add a quirk to avoid stuck (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: clean up endpoint-descriptor parsing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: quirks: blacklist duplicate ep on Sound Devices USBPre2 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: add endpoint-blacklist quirk (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [uapi] usb: charger: assign specific number for enum value (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: hub: Don't record a connect-change event during reset-resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: uas: fix a plug & unplug racing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: hub: Fix the broken detection of USB3 device in SMSC hub (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: apply XHCI_PME_STUCK_QUIRK to Intel Comet Lake platforms (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: fix runtime pm enabling for quirky Intel hosts (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix memory leak when caching protocol extended capability PSI tables (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Force Maximum Packet size for Full-speed bulk devices to valid range (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: digi_acceleport: remove redundant assignment to pointer priv (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: relax unthrottle memory barrier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: fix receiver regression (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ir-usb: Silence harmless uninitialized variable warning (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: cyberjack: fix spelling mistake "To" -> "Too" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ir-usb: simplify endpoint check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ir-usb: make set_termios synchronous (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ir-usb: fix IrLAP framing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ir-usb: fix link-speed handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ir-usb: add missing endpoint sanity check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fusb302: fix "op-sink-microwatt" default that was in mW (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: wcove: fix "op-sink-microwatt" default that was in mW (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpci: mask event interrupts when remove driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: set MODULE_FIRMWARE for tegra186 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbfs: Always unlink URBs in reverse order (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: quatech2: handle unbound ports (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: keyspan: handle unbound ports (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: io_edgeport: add missing active-port sanity check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: io_edgeport: handle unbound ports on URB completion (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: handle unbound port at reset_resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: garmin_gps: Use flexible-array member (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: opticon: stop all I/O on close() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: opticon: add chars_in_buffer() implementation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: suppress driver bind attributes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add support for Quectel RM500Q in QDL mode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: hub: Improved device recognition on remote wakeup (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: phy-generic: Delete unused platform data (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: opticon: fix control-message timeouts (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: Add support for Quectel RM500Q (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: simple: Add Motorola Solutions TETRA MTP3xxx and MTP85xx (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: ulpi: Add resource-managed variant of otg_ulpi_create() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Provide definitions for the USB modes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Give the mux drivers all the details regarding the port state (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Add definitions for the latest specification releases (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Add the Product Type VDOs to struct usb_pd_identity (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: pd: Add definition for DFP and UFP1 VDOs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: pd: Add definitions for the Enter_USB message (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: More API for cable handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Add parameter for the VDO to typec_altmode_enter() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Block mode entry if the port has the mode disabled (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: fix spelling mistake "connetor" -> "connector" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: missing parentheses in USE_NEW_SCHEME (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Fix the notification bit offsets (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Actually enable all the interface notifications (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fix non-kernel-doc comments (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Fix: Don't skip endpoint descriptors with maxpacket=0 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB-PD tcpm: bad warning+size, PPS adapters (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb3503: Convert to use GPIO descriptors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: add support for separate DP altmode devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Store the notification mask (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: mtk-xhci: Do not explicitly set the DMA mask (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: fix check for duplicate endpoints (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add ZLP support for 0x1bc7/0x9010 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: Fix build warning seen with CONFIG_PM=n (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fusb302: Fix an undefined reference to 'extcon_get_state' (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: EHCI: Do not return -EPIPE when hub is disconnected (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Telit ME910G1 0x110a composition (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: make sure interrupts are restored to correct state (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: handle some XHCI_TRUST_TX_LENGTH quirks cases as default behaviour (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Increase STS_HALT timeout in xhci_suspend() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: only set D3hot for pci device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: fix USB3 device initiated resume race with roothub autosuspend (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix memory leak in xhci_add_in_port() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Fix incorrect DMA allocations for local memory pool drivers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: idmouse: fix interface sanity checks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: adutux: fix interface sanity check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: atm: ueagle-atm: add missing endpoint check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: io_edgeport: fix epic endpoint lookup (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: mon: Fix a deadlock in usbmon between mmap and read (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: usb-conn-gpio: Don't log an error on probe deferral (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: urb: fix URB structure initialization function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fix use after free in typec_register_port() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: fix a potential use after free (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Implement basic ELPG support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Add XUSB controller context (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Add support for XUSB context save/restore (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Enable runtime PM as late as possible (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Reuse stored register base address (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Extract firmware enable helper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Use CNR as firmware ready indicator (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Avoid a fixed duration sleep (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Separate firmware request and load (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Fix "tega" -> "tegra" typo (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: drop comment about 2 uhci drivers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb, kcov: collect coverage from hub_event (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for interrupt-parent, dmas and -gpio(s) (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: serial: Fix Kconfig indentation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: misc: Fix Kconfig indentation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for "iommu-map" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Fix the semantics of of_is_ancestor_of() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: Disable UAS on JMicron SATA enclosure (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: uas: heed CAPACITY_HEURISTICS (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: uas: honor flag to avoid CAPACITY16 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Correct phy enable sequence (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-serial: cp201x: support Mark-10 digital force gauge (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Remove tcpc_config configuration mechanism (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci-pci: Allow host runtime PM as default also for Intel Ice Lake xHCI (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci: Support running urb giveback in tasklet context (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Add tracing for xhci doorbell register writes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci: update event ring dequeue pointer on purpose (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Fix documentation for out values (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: add device IDs for U-Blox C099-F9P (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add support for Foxconn T77W968 LTE modules (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] driver core: Clarify documentation for fwnode_operations.add_links() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop port open flag (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop read-urb check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop port driver data accessors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop serial struct accessor (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop paranoid serial checks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop paranoid port checks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: drop redundant urb context check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: rip out broken interrupt handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: fix probe error handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: document MCS7810 detection hack (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: clean up device-type handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: fix remote wakeup (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7720: fix remote wakeup (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: chaoskey: fix error case of a timeout (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add support for DW5821e with eSIM support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] appledisplay: fix error handling in the scheduled work (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop superfluous newlines (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop superfluous brackets (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: clean up runaway white space (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop redundant endianness comments (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop unnecessary packed attributes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: clean up pointer declarations in driver data (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: remove tower_abort_transfers() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: stop interrupt-out URB unconditionally (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop redundant interrupt-in running flag (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop noisy disconnect messages (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop redundant open_count check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: zero driver data at allocation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop redundant NULL check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: drop redundant MODULE_LICENSE ifdef (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: idmouse: clean up runaway white space (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: idmouse: drop redundant open-count check from release (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: idmouse: simplify disconnect handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: Allow USB device to be warm reset in suspended state (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add device link support for iommus, mboxes and io-channels (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Make it easy to add device links from DT properties (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: mos7840: add USB ID to support Moxa UPort 2210 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Optimise ucsi_unregister() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: New error codes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Remove all bit-fields (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Remove struct ucsi_control (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Remove the old API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: ccg: Move to the new API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: acpi: Move to the new API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Simplified registration and I/O API (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: hd3ss3220: Give the connector fwnode to the port device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: typec: Remove unused members from struct typec_capability (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Remove the callback members from struct typec_capability (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: hd3ss3220: Start using struct typec_operations (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: Start using struct typec_operations (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tps6598x: Start using struct typec_operations (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Start using struct typec_operations (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Separate the operations vector (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Introduce typec_get_drvdata() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Copy everything from struct typec_capability during registration (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb251xb: Add support for USB2422 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb251xb: Drop some unused defines (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: Add usb_role_switch_find_by_fwnode() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ch341: reimplement line-speed handling (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: Remove redundant vmap checks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: whiteheat: fix line-speed endianness (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: whiteheat: fix potential slab corruption (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] UAS: Revert commit 3ae62a42090f ("UAS: fix alignment of scatter/gather segments") (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: Revert commit 747668dbc061 ("usb-storage: Set virt_boundary_mask to avoid SG overflows") (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: fix __le32/__le64 accessors in debugfs code (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: fix Immediate Data Transfer endianness (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix use-after-free regression in xhci clear hub TT implementation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ldusb: fix control-message timeout (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ldusb: use unsigned size format specifiers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ldusb: fix ring-buffer locking (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Skip endpoints with 0 maxpacket length (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: pl2303: add support for PL2303HXN (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ldusb: fix read info leaks (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] driver: core: Improve documentation for fwnode_operations.add_links() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Minor code formatting/style clean ups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ti_usb_3410_5052: clean up serial data access (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ti_usb_3410_5052: fix port-close races (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usbfs: Suppress problematic bind and unbind uevents (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblp: fix use-after-free on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix a signedness bug in tower_probe() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix memleak on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ldusb: fix memleak on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fix an IS_ERR() vs NULL bug in hd3ss3220_probe() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] device property: Fix the description of struct fwnode_operations (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: yurex: fix NULL-derefs on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: use pr_err() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: drop redundant iowarrior mutex (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: drop redundant disconnect mutex (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: fix use-after-free after driver unbind (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: fix use-after-free on release (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: iowarrior: fix use-after-free on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: chaoskey: fix use-after-free on release (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: adutux: fix use-after-free on release (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix use-after-free on release (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ldusb: fix NULL-derefs on driver unbind (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usb-skeleton: drop redundant in-urb check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usb-skeleton: fix use-after-free after driver unbind (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usb-skeleton: fix NULL-deref on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: remove duplicated include from hd3ss3220.c (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: drop OOM message (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: devio.c: Fix assignment of 0/1 to bool variables (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: hd3ss3220: hd3ss3220_probe() warn: passing zero to 'PTR_ERR' (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: hub: Check device descriptor before resusciation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: add dependency for TYPEC_HD3SS3220 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: Add Tegra194 XHCI support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: tegra: Parameterize mailbox register addresses (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: image: microtek.c: Remove unused variable (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: hd3ss3220_irq() can be static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] kcov: remote coverage support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Create device links for all child-supplier depencencies (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Add functional dependency link from DT bindings (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: fix runtime PM after driver unbind (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblp: fix runtime PM after driver unbind (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usb-skeleton: fix runtime PM after driver unbind (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci-ext-caps.c: Add missing platform_device_put() on error in xhci_create_intel_xhci_sw_pdev() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix NULL pointer dereference in xhci_clear_tt_buffer_complete() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Increase STS_SAVE timeout in xhci_suspend() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Prevent deadlock when xhci adapter breaks during init (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: wait for CNR controller not ready bit in xhci resume (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix USB 3.1 capability detection on early xHCI 1.1 spec based hosts (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Check all endpoints for LPM timeout (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Prevent device initiated U1/U2 link pm if exit latency is too long (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: Fix false warning message about wrong bounce buffer write length (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb251xb: add pm_ops (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb251xb: simplify reset helper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb251xb: add vdd supply support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: driver for TI HD3SS3220 USB Type-C DRP port controller (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: use regulator_bulk_set_supply_names() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: ftdi-elan: move a couple of statements to next line (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: Fix Kconfig indentation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-tegra: use devm_platform_ioremap_resource() to simplify code (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix open after failed reset request (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix potential NULL-deref on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix deadlock on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: legousbtower: fix slab info leak at probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: displayport: Fix for the mode entering routine (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: ucsi: ccg: Remove run_isr flag (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblcd: use pr_err() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblcd: drop redundant lcd mutex (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblcd: drop redundant disconnect mutex (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblcd: fix I/O after disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: usb: typec: tcpm: Fix a signedness bug in tcpm_fw_get_caps() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: adutux: fix NULL-derefs on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: adutux: fix use-after-free on disconnect (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: yurex: Don't retry on unexpected errors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: microtek: fix info-leak at probe (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: keyspan: fix NULL-derefs on open() and write() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add support for Cinterion CLS8 devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: SCSI glue: use dev_err instead of printk (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: option: add Telit FN980 compositions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: add device IDs for Sienna and Echelon PL-20 (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbcore: Fix slab-out-of-bounds bug during device reset (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: rio500: Fix lockdep violation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: rio500: simplify locking (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: add USB GPIO based connection detection driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: create Kconfig file (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: get usb-role-switch from parent (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: Add fwnode_usb_role_switch_get() function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: roles: Introduce stubs for the exiting functions in role.h (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usbip: Implement SG support to vhci-hcd and stub driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: intel: Enable static DRD mode for role switch (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci-ext-caps.c: Add property to disable Intel SW switch (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: core: phy: add support for PHY calibration (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-rcar: Add a helper macro to set xhci_plat_priv (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: add quirks member into struct xhci_plat_priv (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: fix possible memleak on setup address fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] xhci: add TSP bitflag to TRB tracing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: dbc: Use GFP_KERNEL instead of GFP_ATOMIC in 'xhci_dbc_alloc_requests()' (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci: dbc: Simplify error handling in 'xhci_dbc_alloc_requests()' (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tps6598x: Fix build error without CONFIG_REGMAP_I2C (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: remove commented out dma wrappers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: remove a stale comment in hcd_alloc_coherent (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: use hcd_uses_dma to check for DMA capabilities (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: Simplify usb_decode_get_set_descriptor function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: Patch simplify usb_decode_set_clear_feature function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: common: Separated decoding functions from dwc3 driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: xhci-mtk: add an optional xhci_ck clock (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ftdi_sio: add support for FT232H CBUS gpios (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] device property: Remove duplicate test for NULL (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: roles: intel_xhci: Supplying software node for the role mux (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [phy] phy: core: document phy_calibrate() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usb-skeleton: make comment block in line with coding style (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: usbfs: only account once for mmap()'ed usb memory usage (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fusb302: Call fusb302_debugfs_init earlier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fusb302: Use usb_debug_root as root for our debugfs entry (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Use usb_debug_root as root for our debugfs entry (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: ohci-nxp: enable compile-testing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: storage: isd200: remove redundant assignment to variable sendToTransport (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fusb302: Always provide fwnode for the port (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: fusb302: Remove unused properties (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbfs: Add a capability flag for runtime suspend (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-storage: remove single-use define for debugging (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: Add definitions for the USB2.0 hub TT requests (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: remove ehci-w90x900 driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usbfs: Add ioctls for runtime power management (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbsevseg: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: trancevibrator: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: atm: cxacru: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: lvstest: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cytherm: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: cypress_cy7c63: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbtmc: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usblp: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: ueagle-atm: convert to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: typec: ucsi_ccg: convert i2c driver to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: add support for dev_groups to struct usb_device_driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: add support for dev_groups to struct usb_driver (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: usbip: convert platform driver to use dev_groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: Disable USB2 LPM at shutdown (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-plat: Prevent an abnormally restrictive PHY init skipping (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: Remove dev_err() usage after platform_get_irq() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: xhci-hub: fix extra endianness conversion (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: host: Remove call to memset after dma_alloc_coherent (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: mux: Switch to use fwnode_property_count_uXX() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: tcpm: Switch to use fwnode_property_count_uXX() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] usb: host: oxu210hp-hcd: remove include/linux/oxu210hp.h (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: core: hcd-pci: Use dev_get_drvdata where possible (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: resume ccgx i2c client (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: add runtime pm support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: refactor master_xfer (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb: typec: Registering real device entries for the muxes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: implement break control (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: f81232: add high baud rate support (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: serial: ark3116: drop redundant init_termios (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: Supply CCGx driver the fw build info (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [phy] phy: core: Invoke pm_runtime_get_*/pm_runtime_put_* before invoking reset callback (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: property: Document that of_graph_get_endpoint_by_regs needs of_node_put (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [phy] phy: make phy-core explicitly non-modular (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] OF: properties: add missing of_node_put (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] USB: xhci: fix 'broken_suspend' placement in struct xchi_hcd (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: mark resume function as __maybe_unused (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [of] of: Use of_node_name_eq for node name comparisons (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: limit reads also for combined messages (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: adhere to I2C fault codes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: nvidia-gpu: make pm_ops static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [i2c] i2c: add i2c bus driver for NVIDIA GPU (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [tty] complete ->et_serial() switchover (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb_wwan: switch to ->et_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] whiteheat: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] ti_usb_3410_5052: switch to ->et_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] ssu100: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] quatech2: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] pl2303: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] opticon: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] mos7840: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] mos7720: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] io_ti: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] io_edgeport: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] fdti_sio: switch to ->et_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] f81232: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] ark3116: switch to ->get_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] cdc-acm: switch to ->et_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [usb] usb-serial: begin switching to ->et_serial() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [tty] tty_ioctl(): start taking TIOCSERIAL into separate methods (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device connection: Remove device_connection_add() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device connection: Remove device_connection_find() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix device_pm_lock() locking for device links (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver code: print symbolic error code (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Fix the secondary firmware node handling in set_primary_fwnode() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: add device probe log helper (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Change delimiter in devlink device's name to "--" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Avoid NULL pointer dereference in device_get_next_child_node() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix sleeping in invalid context during device link deletion (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add waiting_for_supplier sysfs file for devices (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add state_synced sysfs file for devices that support it (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [documentation] driver core: Expose device link details in sysfs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Avoid deferred probe due to fw_devlink_pause/resume() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Rename dev_links_info.defer_sync to defer_hook (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Don't do deferred probe in parallel with kernel_init thread (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Use software_node_unregister() when unregistering group of nodes (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add device_is_dependent() to linux/device.h (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Update device link status correctly for SYNC_STATE_ONLY links (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: implement software_node_unregister() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [lib] lib/test_printf: Add tests for pfw printk modifier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Remove unnecessary is_fwnode_dev variable in device_add() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers property: When no children in primary, try secondary (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix handling of SYNC_STATE_ONLY + STATELESS device links (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix SYNC_STATE_ONLY device link implementation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Remove check in driver_deferred_probe_force_trigger() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: fw_devlink: Add support for batching fwnode parsing (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Look for waiting consumers only for a fwnode's primary device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Move code to the right part of the file (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add device links from fwnode only for the primary device (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] Revert "Revert "driver core: Set fw_devlink to "permissive" behavior by default"" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix handling of fw_devlink=permissive (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: fw_devlink_flags can be static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add fw_devlink kernel commandline option (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Reevaluate dev->links.need_for_probe as suppliers are added (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Skip unnecessary work when device doesn't have sync_state() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] driver core: Add dev_has_sync_state() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Call sync_state() even if supplier has no consumers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Allow device link operations inside sync_state() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add sync_state driver/bus callback (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add device link support for SYNC_STATE_ONLY flag (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix creation of device links with PM-runtime flags (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Remove device link creation limitation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] driver core: Add missing description of new struct device_link field (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add device link flag DL_FLAG_AUTOPROBE_CONSUMER (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Make driver core own stateful device links (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Fix adding device links to probing suppliers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: core: Remove glue dirs from sysfs earlier (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Remove the link if there is no driver with AUTO flag (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: silence device link messages unless debugging (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] base: core: Remove WARN_ON from link dependencies check (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: export set_secondary_fwnode() to modules (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Allow register and unregister software node groups (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Export fwnode_get_name() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] Revert "software node: Simplify software_node_release() function" (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: add basic tests for property entries (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: remove separate handling of references (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: implement reference properties (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: allow embedding of small arrays into property_entry (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: replace is_array with is_inline (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] software node: unify PROPERTY_ENTRY_XXX macros (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: simplify property_entry_read_string_array() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: remove property_entry_read_uNN_array functions (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: get rid of property_set_pointer() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [firmware] efi/apple-properties: use PROPERTY_ENTRY_U8_ARRAY_LEN (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] software node: mark internal macros with double underscores (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] software node: introduce PROPERTY_ENTRY_XXX_ARRAY_LEN() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] software node: remove DEV_PROP_MAX (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: clean up property_copy_string_array() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Allow fwnode_operations.add_links to differentiate errors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Allow a device to wait on optional suppliers (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Add a function to obtain a node's prefix (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Add fwnode_get_name for returning the name of a node (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Add functions for accessing node's parents (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Move fwnode_get_parent() up (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Make argument to to_software_node const (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Get reference to parent swnode in get_parent op (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [include] driver core: Add support for linking devices during device addition (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: Add fwnode_to_dev() to look up device from fwnode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Initialize the return value in software_node_find_by_name() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Initialize the return value in software_node_to_swnode() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device connection: Add fwnode_connection_find_match() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Add software_node_find_by_name() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: Introduce device lookup variants by device type (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: Introduce device lookup variants by fwnode (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device connection: Find connections also by checking the references (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Introduce fwnode_find_reference() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Add software_node_get_reference_args() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Use kobject name when finding child nodes by name (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Add support for static node descriptors (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Simplify software_node_release() function (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Allow node creation without properties (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Add fwnode_graph_get_endpoint_by_id() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: base: swnode: Make two functions static (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] software node: Implement get_named_child_node fwnode callback (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device connection: Find device connections also from device graphs (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device connection: Prepare support for firmware described connections (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: drop use of BUS_ATTR() (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] driver core: bus: convert to use BUS_ATTR_WO and RW (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: base: swnode: check if swnode is NULL before dereferencing it (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: base: swnode: check if pointer p is NULL before dereferencing it (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] sysfs: Disable lockdep for driver bind/unbind files (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: fix fwnode_graph_get_next_endpoint() documentation (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: base: swnode: remove need for a temporary string for the node name (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] kobject: return error code if writing /sys/.../uevent fails (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Remove struct property_set (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] device property: Move device_add_properties() to swnode.c (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [base] drivers: base: Introducing software nodes to the firmware node framework (Torez Smith) [1900751 1856683 1838295 1837563 1783493]
- [mm] powerpc/64s/radix: Fix mm_cpumask trimming race vs kthread_use_mm (Chris von Recklinghausen) [1862347]
- [powerpc] powerpc: select ARCH_WANT_IRQS_OFF_ACTIVATE_MM (Chris von Recklinghausen) [1862347]
- [fs] mm: fix exec activate_mm vs TLB shootdown and lazy tlb switching race (Chris von Recklinghausen) [1862347]
- [arm64] arm64: pgtable: Ensure dirty bit is preserved across pte_wrprotect() (Andrew Jones) [1908439]
- [arm64] arm64: pgtable: Fix pte_accessible() (Andrew Jones) [1908439]
- [kernel] kernel: fork: properly initialize task_struct->task_struct_rh (Rafael Aquini) [1895892]
- [s390] s390/dasd: Process FCES path event notification (Philipp Rudo) [1723823]
- [s390] s390/dasd: Prepare for additional path event handling (Philipp Rudo) [1723823]
- [s390] s390/dasd: Display FC Endpoint Security information via sysfs (Philipp Rudo) [1723823]
- [s390] s390/dasd: Fix operational path inconsistency (Philipp Rudo) [1723823]
- [s390] s390/dasd: Store path configuration data during path handling (Philipp Rudo) [1723823]
- [s390] s390/dasd: Move duplicate code to separate function (Philipp Rudo) [1723823]
- [s390] s390/dasd: Remove unused parameter from dasd_generic_probe() (Philipp Rudo) [1723823]
- [s390] s390/cio: Add support for FCES status notification (Philipp Rudo) [1723823]
- [s390] s390/cio: Provide Endpoint-Security Mode per CU (Philipp Rudo) [1723823]
- [s390] s390/cio: Export information about Endpoint-Security Capability (Philipp Rudo) [1723823]
- [net] net/af_iucv: fix null pointer dereference on shutdown (Philipp Rudo) [1903966]
- [s390] s390/dasd: fix null pointer dereference for ERP requests (Philipp Rudo) [1903965]
- [tools] selftests: netfilter: add command usage (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: simplify command testing (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: remove unused variable in make_file() (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: exit on invalid parameters (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: fix header example (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: kill running process only (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add MTU arguments to flowtables (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add checktool function (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add test case for conntrack helper assignment (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: extend nfqueue test case (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add nfqueue test case (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add ipvs tunnel test case (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add ipvs nat test case (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: add ipvs test script (Hangbin Liu) [1899374]
- [tools] selftests: netfilter: check icmp pkttoobig errors are set as related (Hangbin Liu) [1899374]
- [hwtracing] intel_th: pci: Add Emmitsburg PCH support (Jiri Olsa) [1838703]
- [hwtracing] intel_th: pci: Add Tiger Lake PCH-H support (Jiri Olsa) [1783492 1782729]
- [hwtracing] intel_th: pci: Add Jasper Lake CPU support (Jiri Olsa) [1783097]
- [hwtracing] intel_th: pci: Add Elkhart Lake CPU support (Jiri Olsa) [1783596]
- [hwtracing] intel_th: pci: Add Elkhart Lake SOC support (Jiri Olsa) [1783596]
- [hwtracing] intel_th: pci: Add Ice Lake CPU support (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: Fix a NULL dereference when hub driver is not loaded (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: msu: Make stopping the trace optional (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: Fix user-visible error codes (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: msu: Fix the unexpected state warning (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: Disallow multi mode on devices where it's broken (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: msu: Fix window switching without windows (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: Fix freeing IRQs (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]
- [hwtracing] intel_th: Fix a double put_device() in error path (Jiri Olsa) [1838703 1783596 1783492 1783097 1782729]

* Sat Jan 09 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-272.el8]
- [idle] intel_idle: Fix intel_idle() vs tracing (David Arcari) [1903307]
- [idle] intel_idle: Fix max_cstate for processor models without C-state tables (David Arcari) [1903307]
- [idle] intel_idle: Ignore _CST if control cannot be taken from the platform (David Arcari) [1903307]
- [idle] intel_idle: mention assumption that WBINVD is not needed (David Arcari) [1903307]
- [idle] intel_idle: Remove uninitialized_var() usage (David Arcari) [1903307]
- [idle] intel_idle: cleanup code to address out of order commits (David Arcari) [1903307]
- [s390] Revert "s390/qeth: phase out OSN support" (Philipp Rudo) [1903962]
- [net] net/smc: fix matching of existing link groups (Philipp Rudo) [1903961]
- [netdrv] mlxsw: core: Use variable timeout for EMAD retries (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Fix firmware flashing (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Fix use-after-free in mlxsw_emad_trans_finish() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Fix memory leak on module removal (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Only advertise link modes supported by both driver and device (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Add a PFC test (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Add headroom handling test (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: qos_lib: Add a wrapper for running mlnx_qos (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: devlink_lib: Support port-less topologies (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: devlink_lib: Add devlink_cell_size_get() (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: devlink_lib: Split devlink_..._set() into save & set (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ethtool: Expose transceiver_overheat counter (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Update module's settings when module is plugged in (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Initialize netdev's module overheat counter (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Enable temperature event for all supported port module sensors (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Update transceiver_overheat counter according to MTWE (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Add an infrastructure to track transceiver overheat counter (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_hwmon: Query MTMP before writing to set only relevant fields (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Ports Module Administrative and Operational Status Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Port Module Plug/Unplug Event Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Management Temperature Warning Event Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_acl: Fix mlxsw_sp_acl_tcam_group_add()'s error path (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: simplify the return expression of __mlxsw_sp_router_init() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_qdisc: Disable port buffer autoresize with qdiscs (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_dcb: Implement dcbnl_setbuffer / getbuffer (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Support two headroom modes (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Manage internal buffer in the hdroom code (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Introduce shared buffer ops (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Convert mlxsw_sp_port_headroom_init() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Inline mlxsw_sp_sb_max_headroom_cells() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Move here the new headroom code (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Move here the three-step headroom configuration from DCB (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_dcb: Convert mlxsw_sp_port_pg_prio_map() to hdroom code (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_dcb: Convert ETS handler fully to mlxsw_sp_hdroom_configure() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Split headroom autoresize out of buffer configuration (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Track buffer sizes in struct mlxsw_sp_hdroom (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Track lossiness in struct mlxsw_sp_hdroom (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Track priorities in struct mlxsw_sp_hdroom (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Track MTU in struct mlxsw_sp_hdroom (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Unify delay handling between PFC and pause (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Add struct mlxsw_sp_hdroom (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Introduce fw_fatal health reporter (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Monitoring FW General Debug Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Monitoring FW Debug Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Move fw_load_policy devlink param into core.c (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Push code doing params register/unregister into separate helpers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Move fw flashing code into core.c (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Bump firmware version to XX.2008.1310 (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Derive SBIB from maximum port speed & MTU (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Keep maximum speed around (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Keep maximum MTU around (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ethtool: Introduce ptys_max_speed callback (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ethtool: Extract a helper to get Ethernet attributes (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_hwmon: Extend hwmon interface with critical and emergency alarms (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_hwmon: Calculate MLXSW_HWMON_ATTR_COUNT more accurately (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_hwmon: Split temperature querying from show functions (Ivan Vecera) [1857594]
- [netdrv] treewide: Use fallthrough pseudo-keyword (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ethtool: Remove internal speeds from PTYS register (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Reduce runtime of tc-police scale test (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: Fix mausezahn delay parameter in mirror_test() (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Increase burst size for burst test (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Increase burst size for rate test (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Decrease required rate accuracy (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Adjust default policer burst size for Spectrum-{2, 3} (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ptp: Use generic helper function (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: RED: Test offload of trapping on RED qevents (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_qdisc: Offload action trap for qevents (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Add early_drop trap (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Allow for per-ASIC traps initialization (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Allow for per-ASIC trap groups initialization (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: On policer_id_base_ref_count, use dec_and_test (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Use 'size_t' for array sizes (Ivan Vecera) [1857594]
- [netdrv] devlink: Pass extack when setting trap's action and group's parameters (Ivan Vecera) [1857594]
- [net] devlink: Add early_drop trap (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_cnt: Use flex_array_size() helper in memcpy() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: Fix use-after-free in router init / de-init (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Free EMAD transactions using kfree_rcu() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Increase scope of RCU read-side critical section (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use different trap group for externally routed packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: Allow programming link-local host routes (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Add support for temperature thresholds reading for QSFP-DD transceivers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Add ethtool support for QSFP-DD transceivers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: destroy workqueue when trap_register in mlxsw_emad_init (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Fix wrong SFP EEPROM reading for upper pages 1-3 (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Test policers' occupancy (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Add scale test for tc-police (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: tc_restrictions: Test tc-police restrictions (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: Add tc-police tests (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_acl: Offload FLOW_ACTION_POLICE (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_acl_flex_actions: Add police action (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_acl_flex_actions: Work around hardware limitation (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_policer: Add devlink resource support (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_policer: Add policer core (Ivan Vecera) [1857594]
- [netdrv] mlxsw: resources: Add resource identifier for global policers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add policer bandwidth limits (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Use mirror reason during Rx listener lookup (Ivan Vecera) [1857594]
- [netdrv] mlxsw: pci: Retrieve mirror reason from CQE during receive (Ivan Vecera) [1857594]
- [netdrv] mlxsw: pci: Add mirror reason field to CQEv2 (Ivan Vecera) [1857594]
- [netdrv] mlxsw: trap: Add trap identifiers for mirrored packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Increase trap identifier to 10 bits (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Allow setting policer on a SPAN agent (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Allow passing parameters to SPAN agents (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add support for mirroring towards CPU port (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Do not dereference destination netdev (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add driver private info to parms_set() callback (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add per-ASIC SPAN agent operations (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: add mirroring_pid_base to MOGCR register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add session_id and pid to MPAT register (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: RED: Test offload of mirror on RED early_drop qevent (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_qdisc: Offload mirroring on RED qevent early_drop (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_flow: Promote binder-type dispatch to spectrum.c (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Publish matchall data structures (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_flow: Drop an unused field (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_flow: Convert a goto to a return (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add APIs to enable / disable global mirroring triggers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add support for global mirroring triggers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Prepare for global mirroring triggers (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Move SPAN operations out of global file (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Monitoring Port Analyzer Global Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Add Monitoring Mirror Trigger Enable Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: pci: Fix use-after-free in case of failed devlink reload (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: Remove inappropriate usage of WARN_ON() (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: Add tests for ethtool extended state (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: forwarding.config.sample: Add port with no cable connected (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: ethtool: Move different_speeds_get() to ethtool_lib (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ethtool: Add link extended state (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Port Diagnostics Database Register (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_ethtool: Move mlxsw_sp_port_type_speed_ops structs (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Move ethtool_ops to spectrum_ethtool.c (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_dcb: Rename mlxsw_sp_port_headroom_set() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Enforce firmware version for Spectrum-3 (Ivan Vecera) [1857594]
- [netdrv] mlxsw: Bump firmware version to XX.2007.1168 (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_dcb: Fix a spelling typo in spectrum_dcb.c (Ivan Vecera) [1857594]
- [tools] selftests: forwarding: Add a test for pedit munge tcp, udp sport, dport (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_acl: Support FLOW_ACTION_MANGLE for TCP, UDP ports (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core_acl_flex_actions: Add L4_PORT_ACTION (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Split handling of pedit mangle by chip type (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Do not rely on machine endianness (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Adjust headroom buffers for 8x ports (Ivan Vecera) [1857594]
- [netdrv] mlxsw: core: Use different get_trend() callbacks for different thermal zones (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Add test for control packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Register ACL control traps (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Register layer 3 control traps (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Register layer 2 control traps (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Factor out common Rx listener function (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Move layer 3 exceptions to exceptions trap group (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: remove redundant initialization of pointer br_dev (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: Allow programming link-local prefix routes (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Add packet traps for BFD packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Treat IPv6 link-local SIP as an exception (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Share one group for all locally delivered packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Move all trap groups under the same enum (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Do not hard code "thin" policer identifier (Ivan Vecera) [1857594]
- [netdrv] mlxsw: switchx2: Move SwitchX-2 trap groups out of main enum (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Reduce priority of locally delivered packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use same trap group for local routes and link-local destination (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use separate trap group for FID miss (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use same trap group for various IPv6 packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Rename IPv6 ND trap group (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use same switch case for identical groups (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use dedicated trap group for ACL trap (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Fix spelling mistake in trap's name (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use dedicated trap group for sampled packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use same trap group for IPv6 ND and ARP packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Rename ARP trap group (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Remove unnecessary field (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Align TC and trap priority (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_buffers: Assign non-zero quotas to TC 0 of the CPU port (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Change default rate and priority of DHCP packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Trap IPv4 DHCP packets in router (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Use same trap group for MLD and IGMP packets (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Rename IGMP trap group (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: Do not hard code trap group name (Ivan Vecera) [1857594]
- [tools] selftests: devlink_lib: Remove double blank line (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Store all trap data in one array (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Store all trap group data in one array (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Store all trap policer data in one array (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_trap: Move struct definition out of header file (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: tc_restrictions: add couple of test for the correct matchall-flower ordering (Ivan Vecera) [1857594]
- [tools] selftests: mlxsw: tc_restrictions: add test to check sample action restrictions (Ivan Vecera) [1857594]
- [] selftests: mlxsw: rename tc_flower_restrictions.sh to tc_restrictions.sh (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_flower: Forbid to insert flower rules in collision with matchall rules (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Forbid to insert matchall rules in collision with flower rules (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Expose a function to get min and max rule priority (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Put matchall list into substruct of flow struct (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_flower: Expose a function to get min and max rule priority (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Restrict sample action to be allowed only on ingress (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Remove old SPAN API (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Use new analyzed ports list during speed / MTU change (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_acl: Convert flower-based mirroring to new SPAN API (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Convert matchall-based mirroring to new SPAN API (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add APIs to bind / unbind a SPAN agent (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Wrap buffer change in a function (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Rename function (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add APIs to get / put an analyzed port (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Add APIs to get / put a SPAN agent (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Move flow offload binding into spectrum_flow.c (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Process matchall events from the same cb as flower (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Avoid copying sample values and use RCU pointer direcly instead (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Push per-port rule add/del into separate functions (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Move ingress indication into mall_entry (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Pass mall_entry as arg to mlxsw_sp_mall_port_sample_add() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_matchall: Pass mall_entry as arg to mlxsw_sp_mall_port_mirror_add() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_acl: Use block variable in mlxsw_sp_acl_rule_del() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Push matchall bits into a separate file (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Push flow_block related functions into a separate file (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum: Rename acl_block to flow_block (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_acl: Move block helpers into inline header functions (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Replace zero-length array with flexible-array member (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Use 'refcount_t' for reference counting (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Remove unnecessary debug prints (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Rename parms() to parms_set() (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_span: Reduce nesting in mlxsw_sp_span_entry_configure() (Ivan Vecera) [1857594]
- [netdrv] net/mlxfw: Remove unneeded semicolon (Ivan Vecera) [1857594]
- [netdrv] mlxsw: reg: Increase register field length to 13 bits (Ivan Vecera) [1857594]
- [netdrv] mlxsw: spectrum_router: Re-increase scale of IPv6 nexthop groups (Ivan Vecera) [1857594]
- [net] ipv6: Fix use of anycast address with loopback (Ivan Vecera) [1899591]
- [net] ipv6: addrconf_f6i_alloc - fix non-null pointer check to !IS_ERR() (Ivan Vecera) [1899591]
- [net] ipv6: fix excessive RTF_ADDRCONF flag on ::1/128 local route (and others) (Ivan Vecera) [1899591]
- [net] ipv6: Change addrconf_f6i_alloc to use ip6_route_info_create (Ivan Vecera) [1899591]
- [net] ipv6: Move setting default metric for routes (Ivan Vecera) [1899591]
- [net] Add extack argument to ip_fib_metrics_init (Ivan Vecera) [1899591]
- [net] ipv6: do not leave garbage in rt->fib6_metrics (Ivan Vecera) [1899591]
- [net] Move free of dst_metrics to helper (Ivan Vecera) [1899591]
- [net] common metrics init helper for dst_entry (Ivan Vecera) [1899591]
- [net] Move free of fib_metrics to helper (Ivan Vecera) [1899591]
- [net] common metrics init helper for FIB entries (Ivan Vecera) [1899591]
- [net] rtmsg_to_fib6_config() - use new style struct initializer instead of memset (Ivan Vecera) [1899591]
- [powercap] powercap/intel_rapl: enumerate Psys RAPL domain together with package RAPL domain (Puneet Sethi) [1893463]
- [powercap] powercap/intel_rapl: Fix domain detection (Puneet Sethi) [1893463]

* Fri Jan 08 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-271.el8]
- [net] openvswitch: fix TTL decrement exception action execution (Eelco Chaudron) [1902610]
- [net] openvswitch: fix error return code in validate_and_copy_dec_ttl() (Eelco Chaudron) [1902610]
- [net] openvswitch: fix TTL decrement action netlink message format (Eelco Chaudron) [1902610]
- [x86] hyperv: Enable 15-bit APIC ID if the hypervisor supports it (Vitaly Kuznetsov) [1903823]
- [x86] kvm: Enable 15-bit extension when KVM_FEATURE_MSI_EXT_DEST_ID detected (Vitaly Kuznetsov) [1903823]
- [documentation] x86/kvm: Reserve KVM_FEATURE_MSI_EXT_DEST_ID (Vitaly Kuznetsov) [1903823]
- [iommu] hyper-v: Disable IRQ pseudo-remapping if 15 bit APIC IDs are available (Vitaly Kuznetsov) [1903823]
- [x86] apic: Support 15 bits of APIC ID in MSI where available (Vitaly Kuznetsov) [1903823]
- [x86] msi: Provide msi message shadow structs (Vitaly Kuznetsov) [1903823]
- [kernel] genirq/msi: allow shadow declarations of msi_msg:: $member (Vitaly Kuznetsov) [1903823]
- [x86] ioapic: Handle Extended Destination ID field in RTE (Vitaly Kuznetsov) [1903823]
- [x86] apic: Always provide irq_compose_msi_msg() method for vector domain (Vitaly Kuznetsov) [1903823]
- [x86] apic: Cleanup delivery mode defines (Vitaly Kuznetsov) [1903823]
- [x86] apic/uv: Fix inconsistent destination mode (Vitaly Kuznetsov) [1903823]
- [x86] msi: Only use high bits of MSI address for DMAR unit (Vitaly Kuznetsov) [1903823]
- [x86] msi: Move compose message callback where it belongs (Vitaly Kuznetsov) [1903823]
- [kernel] genirq/chip: Use the first chip in irq_chip_compose_msi_msg() (Vitaly Kuznetsov) [1903823]
- [x86] apic: Fix x2apic enablement without interrupt remapping (Vitaly Kuznetsov) [1903823]
- [tools] perf test: Fix msan uninitialized use (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Fix the ratio comments of miss-events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Free formats for perf pmu parse test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Do not free metric when failed to resolve (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Free metric when it failed to resolve (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Release expr_parse_ctx after testing (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Fix memory leaks in parse-metric test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-event: Fix memory leak in evsel->unit (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Fix cpu/thread map leak (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Fix some memory leaks - part 2 (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Fix some memory leaks (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Free aliases for PMU event map aliases test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf vendor events amd: Remove trailing commas (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Leader sampling shouldn't clear sample period (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record: Prevent override of attr->sample_period for libpfm4 events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record: Set PERF_RECORD_PERIOD if attr->freq is set (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench: Fix 2 memory sanitizer warnings (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Fix the "signal" test inline assembly (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record/stat: Explicitly call out event modifiers in the documentation (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Fix build warning on 32-bit arches (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf jevents: Fix suspicious code in fixregex() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Use uintptr_t when casting numbers to pointers (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf report: Disable ordered_events for raw dump (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Correct SNOOPX field offset (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Fix corrupt data after perf inject from (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf cs-etm: Fix corrupt data after perf inject from (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Avoid an uninitialized read when using fake PMUs (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Fix out of bounds array access in the print_counters() evlist method (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Set NULL sentinel in pmu_events table in "Parse and process metrics" test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Set exclude_guest=1 for user-space counting (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record: Correct the help info of option "--no-bpf-event" (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Use zd for size_t printf formats on 32-bit (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf: arm-spe: Fix check error when synthesizing events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf symbols: Add mwait_idle_with_hints.constprop.0 to the list of idle symbols (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf sched timehist: Fix use of CPU list with summary option (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Fix basic bpf filtering test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Make option description initials all capital letters (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf build-ids: Fall back to debuginfod query if debuginfo not found (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench numa: Remove dead code in parse_nodes_opt() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Update POWER9 metrics to utilize other metrics (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add change log (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf: ftrace: Add set_tracing_options() to set all trace options (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add option --tid to filter by thread id (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add option -D/--delay to delay tracing (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf: ftrace: Allow set graph depth by '--graph-opts' (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add support for trace option tracing_thresh (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add option 'verbose' to show more info for graph tracer (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add support for tracing option 'irq-info' (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add support for trace option funcgraph-irqs (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add support for trace option sleep-time (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add support for tracing option 'func_stack_trace' (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add general function to parse sublevel options (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add option '--inherit' to trace children processes (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Show trace column header (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add option '-m/--buffer-size' to set per-cpu buffer size (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Factor out function write_tracing_file_int() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Add option '-F/--funcs' to list available functions (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf ftrace: Select function/function_graph tracer automatically (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench numa: Use numa_node_to_cpus() to bind tasks to nodes (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench numa: Fix cpumask memory leak in node_has_cpus() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools build feature: Quote CC and CXX for their arguments (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Fix module symbol processing (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Rename 'enum dso_kernel_type' to 'enum dso_space_type' (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libperf: Fix man page typos (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Allow multiple probes in record+script_probe_vfs_getname.sh (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench mem: Always memset source before memcpy (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf sched: Prefer sched_waking event when it exists (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench: Fix a couple of spelling mistakes in options text (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench numa: Fix benchmark names (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench numa: Fix number of processes in "2x3-convergence" test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf trace beauty: Use the autogenerated protocol family table (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf trace beauty: Add script to autogenerate socket families table (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf script: Add 'tod' field to display time of day (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf script: Change the 'enum perf_output_field' enumerators to be 64 bits (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf data: Add support to store time of day in CTF data conversion (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Move clockid_res_ns under clock struct (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf header: Store clock references for -k/--clockid option (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add clockid_name function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf clockid: Move parse_clockid() to new clockid object (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Handle possible strdup() error in tep_add_plugin_path() API (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Fixed description of tep_add_plugin_path() API (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Fixed type in PRINT_FMT_STING (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Fixed broken indentation in parse_ip4_print_args() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Improve error handling of tep_plugin_add_option() API (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Fix typo in tep_plugin_add_option() description (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Handle strdup() error in parse_option_name() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libtraceevent: Document tep_load_plugins_hook() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evsel: Extend message to mention CAP_SYS_PTRACE and perf security doc link (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Add support for decoding PSB+ only (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Add support for decoding FUP/TIP only (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf auxtrace: Add itrace 'q' option for quicker, less detailed decoding (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Time filter logged perf events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Use itrace debug log flags to suppress some messages (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf auxtrace: Add optional log flags to the itrace 'd' option (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Use itrace error flags to suppress some errors (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf auxtrace: Add optional error flags to the itrace 'e' option (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf auxtrace: Add missing itrace options to help text (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Improve aux_output not supported error (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Fix duplicate branch after CBR (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Fix FUP packet state (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record: Introduce --control fd:ctl-fdoptions (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record: Implement control commands handling (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf record: Extend -D, --delay option with -1 value (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Introduce --control fd:ctl-fdoptions (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench: Add benchmark of find_next_bit (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools build feature: Use CC and CXX from parent (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Rename group_list to metric_list (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Rename struct egroup to metric (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add metric group test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Make compute_single function more precise (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add recursion check when processing nested metrics (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add DCache_L2 to metric parse test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add cache_miss_cycles to metric parse test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add events for the current list (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Compute referenced metrics (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add referenced metrics to hash data (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Collect referenced metrics in struct metric_expr (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Collect referenced metrics in struct metric_ref_node (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Rename __metricgroup__add_metric to __add_metric (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add add_metric function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add macros for iterating map events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add expr__del_id function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Change expr__get_id to return struct expr_id_data (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add expr__add_id function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Fix memory leak in expr__add_id function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf test: Ensure sample_period is set libpfm4 events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Fix term parsing for raw syntax (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Allow r0x<HEX> event syntax (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: No need to cache the PMUs in ARM SPE auxtrace init routine (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf bench: Add basic syscall benchmark (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Implement control commands handling (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: extend -D, --delay option with -1 value (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Factor out event handling loop into dispatch_events() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Factor out body of event handling loop for fork case (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Move target check to loop control statement (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf stat: Factor out body of event handling loop for system wide (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Implement control command handling functions (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Introduce control file descriptors (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libperf: Avoid counting of nonfilterable fdarray fds (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libperf: Add flags to fdarray fds objects (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] libperf: Avoid internal moving of fdarray fds (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Add 'struct expr_id_data' to keep expr value (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf metric: Rename expr__add_id() to expr__add_val() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf probe: Warn if the target function is a GNU indirect function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf probe: Fix memory leakage when the probe point is not found (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf probe: Fix wrong variable warning when the probe point is not found (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf probe: Avoid setting probes on the same address for the same event (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf kmem: Pass additional arguments to 'perf record' (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Report BPF errors (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf script: Show text poke address symbol (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf script: Add option --show-text-poke-events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf intel-pt: Add support for text poke events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add support for PERF_RECORD_TEXT_POKE (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf annotate: Fix non-null terminated buffer returned by readlink() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf inject jit: Remove //anon mmap events (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf symbols: Add s390 idle functions 'psw_idle' and 'psw_idle_exit' to list of idle symbols (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Fix reporting of unknown SVM exit reasons (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Change to SPDX License format (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add builtin handler for trace_marker_raw (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Move kernel_stack event handler to "function" plugin (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add plugin for decoding syscalls/sys_enter_futex (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add offset option for function plugin (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add more SVM exit reasons (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add plugin for tlb_flush (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Optimize pretty_print() function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add support for more printk format specifiers (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Introduced new traceevent API, for adding new plugins directories (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add interface for options to plugins (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools lib traceevent: Add tep_load_plugins_hook() API (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Disable a subset of bison warnings (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Disable a subset of flex warnings (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Declare bison header file output (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf expr: Add missing headers noticed when building with NO_LIBBPF=1 (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Declare flex header file output (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf pmu: Add flex debug build flag (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf pmu: Add bison debug build flag (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Use automatic variable for yacc input (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse-events: Use automatic variable for flex input (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Fix the class prefix for 'struct evlist' branch_type methods (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Fix the class prefix for 'struct evlist' sample_id_all methods (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Fix the class prefix for 'struct evlist' sample_type methods (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Fix the class prefix for 'struct evlist' strerror methods (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf evlist: Fix the class prefix for 'struct evlist' 'add' evsel methods (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf pmu: Improve CPU core PMU HW event list ordering (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf pmu: List kernel supplied event aliases for arm64 (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf cs-etm: Allow no CoreSight sink to be specified on command line (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf expr: Add < and > operators (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf expr: Add d_ratio operation (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf script: Fixup some evsel/evlist method names (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tests: Add parse metric test for frontend metric (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tests: Add parse metric test for ipc metric (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add test_generic_metric function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Release metric_events rblist (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Factor out prepare_metric function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add metricgroup__parse_groups_test function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add map to parse_groups() function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add fake_pmu to parse_group() function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse: Factor out parse_groups() function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tests: Add another metric parsing test (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf pmu: Add a perf_pmu__fake object to use with __parse_events() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf parse: Provide a way to pass a fake_pmu to parse_events() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tests: Factor check_parse_id function (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf tools: Add fake pmu support (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] perf annotate: Remove unneeded conversion to bool (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools/: replace HTTP links with HTTPS ones (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [tools] tools, build: Propagate build failures from tools/build/Makefile.build (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] x86/cpufeatures: Add Architectural LBRs feature bit (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/rapl: Add support for Intel SPR platform (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/rapl: Support multiple RAPL unit quirks (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/rapl: Fix missing psys sysfs attributes (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [kernel] perf/core: Take over CAP_SYS_PTRACE creds to CAP_PERFMON capability (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [kernel] perf: Expose get/put_callchain_entry() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [include] perf: <linux/perf_event.h>: drop a duplicated word (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86: Remove task_ctx_size (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Create kmem_cache for the LBR context data (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [kernel] perf/core: Use kmem_cache to allocate the PMU specific data (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [kernel] perf/core: Factor out functions to allocate/free the task_ctx_data (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Support Architectural LBR (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Factor out intel_pmu_store_lbr (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Factor out rdlbr_all() and wrlbr_all() (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Mark the {rd, wr}lbr_{to, from} wrappers __always_inline (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Unify the stored format of LBR information (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Support LBR_CTL (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] x86/msr-index: Add bunch of MSRs for Arch LBR (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86: Expose CPUID enumeration bits for arch LBR (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Use dynamic data structure for task_ctx (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Factor out a new struct for generic optimization (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Add the function pointers for LBR save and restore (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Add a function pointer for LBR read (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/intel/lbr: Add a function pointer for LBR reset (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86: Keep LBR records unchanged in host context for guest usage (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86: Add constraint to create guest LBR event without hw counter (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/lbr: Add interface to get LBR information (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86: Provide stubs of KVM helpers for non-Intel CPUs (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86/core: Refactor hw->idx checks and cleanup (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] perf/x86: Fix variable types for LBR registers (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [kernel] perf: Add perf text poke event (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [uapi] perf: Add perf_event_mmap_page::cap_user_time_short ABI (Michael Petlan) [1811839 1731571 1838555 1838896 1873271]
- [x86] sev-es: Do not support MMIO to/from encrypted memory (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Check SEV encryption before switching to kernel page-table (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Sanity-check CPUID results in the early #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Check SEV encryption in 64-bit boot-path (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Introduce sev_status (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Use GHCB accessor for setting the MMIO scratch buffer (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Disable stack protection for head$(BITS).o (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Check required CPU features for SEV-ES (Vitaly Kuznetsov) [1868080]
- [x86] efi: Add GHCB mappings when SEV-ES is active (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle NMI State (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Support CPU offline/online (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Don't call verify_cpu() on starting APs (Vitaly Kuznetsov) [1868080]
- [x86] smpboot: Load TSS and getcpu GDT entry before loading IDT (Vitaly Kuznetsov) [1868080]
- [x86] realmode: Setup AP jump table (Vitaly Kuznetsov) [1868080]
- [x86] realmode: Add SEV-ES specific trampoline entry point (Vitaly Kuznetsov) [1868080]
- [x86] vmware: Add VMware-specific handling for VMMCALL under SEV-ES (Vitaly Kuznetsov) [1868080]
- [x86] kvm: Add KVM-specific VMMCALL handling under SEV-ES (Vitaly Kuznetsov) [1868080]
- [x86] paravirt: Allow hypervisor-specific VMMCALL handling under SEV-ES (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle #DB Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle #AC Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle VMMCALL Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle MWAIT/MWAITX Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle MONITOR/MONITORX Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle INVD Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle RDPMC Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle RDTSC(P) Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle WBINVD Events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle DR7 read/write events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle MSR events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle MMIO String Instructions (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle MMIO events (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Handle instruction fetches from user-space (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Wire up existing #VC exit-code handlers (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Add a Runtime #VC Exception Handler (Vitaly Kuznetsov) [1868080]
- [x86] entry/64: Add entry code for #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] dumpstack/64: Add noinstr version of get_stack_info() (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Adjust #VC IST Stack on entering NMI handler (Vitaly Kuznetsov) [1868080]
- [x86] boot/64: Explicitly map boot_params and command line (Vitaly Kuznetsov) [1868080]
- [x86] boot/64: Initialize 5-level paging variables earlier (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Allocate and map an IST stack for #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] debug: Allow a single level of #DB recursion (Vitaly Kuznetsov) [1868080]
- [x86] entry: Remove DBn stacks (Vitaly Kuznetsov) [1868080]
- [x86] entry, nmi: Disable #DB (Vitaly Kuznetsov) [1868080]
- [x86] nmi: Protect NMI entry against instrumentation (Vitaly Kuznetsov) [1868080]
- [x86] entry: Introduce local_db_{save, restore}() (Vitaly Kuznetsov) [1868080]
- [x86] db: Split out dr6/7 handling (Vitaly Kuznetsov) [1868080]
- [x86] Replace ist_enter() with nmi_enter() (Vitaly Kuznetsov) [1868080]
- [x86] traps: Stop using ist_enter/exit() in do_int3() (Vitaly Kuznetsov) [1868080]
- [x86] entry: Get rid of ist_begin/end_non_atomic() (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Setup per-CPU GHCBs for the runtime handler (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Setup GHCB-based boot #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Setup an early #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Compile early handler code into kernel image (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Print SEV-ES info into the kernel log (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Add SEV-ES Feature Detection (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Move early exception dispatch to C code (Vitaly Kuznetsov) [1868080]
- [x86] idt: Make IDT init functions static inlines (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Install a CPU bringup IDT (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Switch to initial stack earlier (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Load segment registers earlier (Vitaly Kuznetsov) [1868080]
- [x86] irq/64: Update stale comment (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Load GDT after switch to virtual addresses (Vitaly Kuznetsov) [1868080]
- [x86] head/64: Install startup GDT (Vitaly Kuznetsov) [1868080]
- [x86] idt: Split idt_data setup out of set_intr_gate() (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Add CPUID handling to #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] fpu: Move xgetbv()/xsetbv() into a separate header (Vitaly Kuznetsov) [1868080]
- [x86] cpu: Use XGETBV and XSETBV mnemonics in fpu/internal.h (Vitaly Kuznetsov) [1868080]
- [x86] fpu: Reset MXCSR to default in kernel_fpu_begin() (Vitaly Kuznetsov) [1868080]
- [x86] sev-es: Add support for handling IOIO exceptions (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Unmap GHCB page before booting the kernel (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Setup a GHCB-based VC Exception handler (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Add set_page_en/decrypted() helpers (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Check return value of kernel_ident_mapping_init() (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Call set_sev_encryption_mask() earlier (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Add stage1 #VC handler (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Change add_identity_map() to take start and end (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Don't pre-map memory in KASLR code (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Always switch to own page table (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Add page-fault handler (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Rename kaslr_64.c to ident_map_64.c (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Add IDT Infrastructure (Vitaly Kuznetsov) [1868080]
- [x86] traps: Split trap numbers out in a separate header (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Disable red-zone usage (Vitaly Kuznetsov) [1868080]
- [x86] insn: Add insn_has_rep_prefix() helper (Vitaly Kuznetsov) [1868080]
- [x86] insn: Add insn_get_modrm_reg_off() (Vitaly Kuznetsov) [1868080]
- [x86] umip: Factor out instruction decoding (Vitaly Kuznetsov) [1868080]
- [x86] umip: Factor out instruction fetch (Vitaly Kuznetsov) [1868080]
- [tools] x86/insn: Make inat-tables.c suitable for pre-decompression code (Vitaly Kuznetsov) [1868080]
- [x86] traps: Move pf error codes to <asm/trap_pf.h> (Vitaly Kuznetsov) [1868080]
- [x86] cpufeatures: Add SEV-ES CPU feature (Vitaly Kuznetsov) [1868080]
- [x86] kvm: svm: Use __packed shorthand (Vitaly Kuznetsov) [1868080]
- [x86] kvm: svm: Add GHCB Accessor functions (Vitaly Kuznetsov) [1868080]
- [x86] cpu: Unify cpu_init() (Vitaly Kuznetsov) [1868080]
- [x86] insn-eval: Add support for 64-bit kernel mode (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed: Get rid of GOT fixup code (Vitaly Kuznetsov) [1868080]
- [kernel] x86/boot/compressed: Force hidden visibility for all symbol references (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed: Move .got.plt entries out of the .got section (Vitaly Kuznetsov) [1868080]
- [x86] boot: Correct relocation destination on old linkers (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed/64: Switch to __KERNEL_CS after GDT is loaded (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed: Fix reloading of GDTR post-relocation (Vitaly Kuznetsov) [1868080]
- [x86] boot: Reload GDTR after copying to the end of the buffer (Vitaly Kuznetsov) [1868080]
- [x86] boot/compressed: Don't declare __force_order in kaslr_64.c (Vitaly Kuznetsov) [1868080]
- [mm] mm/userfaultfd: do not access vma->vm_mm after calling handle_userfault() (Philipp Rudo) [1903968]
- [s390] s390/ap: fix ap devices reference counting (Philipp Rudo) [1903967]
- [infiniband] RDMA/cxgb4: Validate the number of CQEs (Kamal Heib) [1894720]
- [net] treewide: Use fallthrough pseudo-keyword (Petr Oros) [1892748]
- [net] devlink: Remove overzealous WARN_ON with snapshots (Petr Oros) [1892748]
- [net] devlink: ignore -EOPNOTSUPP errors on dumpit (Petr Oros) [1892748]
- [net] devlink: Always use user_ptr[0] for devlink and simplify post_doit (Petr Oros) [1892748]
- [net] devlink: Constify devlink instance pointer (Petr Oros) [1892748]
- [net] devlink: Add comment for devlink instance lock (Petr Oros) [1892748]
- [net] devlink: Do not hold devlink mutex when initializing devlink fields (Petr Oros) [1892748]
- [docs] ice: add documentation for device-caps region (Petr Oros) [1892748]
- [net] devlink: remove new uninitialized_var() usage (Petr Oros) [1892748]
- [docs] networking: convert sja1105's devlink info to RTS (Petr Oros) [1892748]
- [net] devlink: refactor end checks in devlink_nl_cmd_region_read_dumpit (Petr Oros) [1892748]
- [docs] ice: cleanup language in ice.rst for fw.app (Petr Oros) [1892748]
- [docs] devlink: don't wrap commands in rST shell blocks (Petr Oros) [1892748]
- [net] devlink: Protect devlink port list traversal (Petr Oros) [1895042]
- [net] devlink: Fix per port reporter fields initialization (Petr Oros) [1895042]
- [net] devlink: Fix use-after-free when destroying health reporters (Petr Oros) [1895042]
- [net] devlink: introduce the health reporter test command (Petr Oros) [1895042]
- [net] devlink: Add devlink health port reporters API (Petr Oros) [1895042]
- [net] devlink: Implement devlink health reporters on per-port basis (Petr Oros) [1895042]
- [net] devlink: Create generic devlink health reporter search function (Petr Oros) [1895042]
- [net] devlink: Rework devlink health reporter destructor (Petr Oros) [1895042]
- [net] devlink: Refactor devlink health reporter constructor (Petr Oros) [1895042]

* Wed Jan 06 2021 Jan Stancek <jstancek@redhat.com> [4.18.0-270.el8]
- [md] dm writecache: fix the maximum number of arguments (Mike Snitzer) [1895117]
- [md] dm writecache: advance the number of arguments when reporting max_age (Mike Snitzer) [1895117]
- [x86] x86/cpu/amd: Make erratum #1054 a legacy erratum (Michael Petlan) [1791459]
- [x86] x86/cpu/amd: Enable the fixed Instructions Retired counter IRPERF (Michael Petlan) [1791459]
- [s390] s390/early: improve machine detection (Claudio Imbrenda) [1896307]
- [infiniband] IB/mlx5: Fix fall-through warnings for Clang (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Fix corruption of reg_pages in mlx5_ib_rereg_user_mr() (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Properly convey driver version to firmware (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: DR, Proper handling of unsupported Connect-X6DX SW steering (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: kTLS, Enforce HW TX csum offload with kTLS (Alaa Hleihel) [1858561]
- [netdrv] net: mlx5e: fix fs_tcp.c build when IPV6 is not enabled (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Fix wrong address reclaim when command interface is down (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-Switch, Fail mlx5_esw_modify_vport_rate if qos disabled (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Disable QoS when min_rates on all VFs are zero (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Clear bw_share upon VF disable (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Add handling of port type in rule deletion (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix check if netdev is bond slave (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Set IPsec WAs only in IP's non checksum partial case (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix incorrect access of RCU-protected xdp_prog (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix VXLAN synchronization after function reload (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-switch, Avoid extack error log for disabled vport (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Fix deletion of duplicate rules (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Protect encap route dev from concurrent release (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix modify header actions memory leak (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Fix devlink deadlock on net namespace deletion (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Fix type warning of sizeof in __mlx5_ib_alloc_counters() (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Clarify what the UMR is for when creating MRs (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Disable IB_DEVICE_MEM_MGT_EXTENSIONS if IB_WR_REG_MR can't work (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Make mkeys always owned by the kernel's PD when not enabled (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Use set_mkc_access_pd_addr_fields() in reg_create() (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Remove dead check for EAGAIN after alloc_mr_from_cache() (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Fix potential race between destroy and CQE poll (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: IPsec: Use kvfree() for memory allocated with kvzalloc() (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: TC: Remove unused parameter from mlx5_tc_ct_add_no_trk_match() (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-Switch, Setup all vports' metadata to support peer miss rule (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-Switch, Dedicated metadata for uplink vport (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-Switch, Check and enable metadata support flag before using (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Don't call timecounter cyc2time directly from 1PPS flow (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Release clock lock before scheduling a PPS work (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Rename ptp clock info (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Always use container_of to find mdev pointer from clock struct (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Fix uninitialized variable warning (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: IPsec: Add Connect-X IPsec Tx data path offload (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5e: IPsec: Add TX steering rule per IPsec state (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5: Add NIC TX domain namespace (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5e: Enhanced TX MPWQE for SKBs (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move TX code into functions to be used by MPWQE (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Rename xmit-related structs to generalize them (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Generalize TX MPWQE checks for full session (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Support multiple SKBs in a TX WQE (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move the TLS resync check out of the function (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Unify constants for WQE_EMPTY_DS_COUNT (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Small improvements for XDP TX MPWQE logic (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Refactor xmit functions (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move mlx5e_tx_wqe_inline_mode to en_tx.c (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Use struct assignment to initialize mlx5e_tx_wqe_info (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Refactor inline header size calculation in the TX path (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add IPv6 traffic class (DSCP) header rewrite support (Alaa Hleihel) [1889981 1858561]
- [netdrv] net/mlx5e: Add LAG warning if bond slave is not lag master (Alaa Hleihel) [1858561 1851709]
- [netdrv] net/mlx5e: Add LAG warning for unsupported tx type (Alaa Hleihel) [1858561 1851709]
- [netdrv] net/mlx5e: Return a valid errno if can't get lag device index (Alaa Hleihel) [1858561 1851709]
- [netdrv] net/mlx5e: Fix race condition on nhe->n pointer in neigh update (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix VLAN create flow (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix VLAN cleanup flow (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix return status when setting unsupported FEC mode (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix driver's declaration to support GRE offload (Alaa Hleihel) [1858561 1819619]
- [netdrv] net/mlx5e: CT, Fix coverity issue (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add resiliency in Striding RQ mode for packets larger than MTU (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix error path for RQ alloc (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Fix request_irqs error flow (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: cmdif, Avoid skipping reclaim pages if FW is not accessible (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Add retry mechanism to the command entry index allocation (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: poll cmd EQ in case of command timeout (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Avoid possible free of command entry while timeout comp handler (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Fix a race when moving command interface to polling mode (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: mlx5e_fec_in_caps() returns a boolean (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: TLS, Do not expose FPGA TLS counter if not supported (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix using wrong stats_grps in mlx5e_update_ndo_stats() (Alaa Hleihel) [1870593 1858561]
- [netdrv] net/mlx5e: Fix multicast counter not up-to-date in "ip -s" (Alaa Hleihel) [1858561 1693130]
- [netdrv] net/mlx5e: Fix endianness when calculating pedit mask first bit (Alaa Hleihel) [1889981 1858561]
- [netdrv] net/mlx5e: Enable adding peer miss rules only if merged eswitch is supported (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: CT: Fix freeing ct_label mapping (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix memory leak of tunnel info when rule under multipath not ready (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Use synchronize_rcu to sync with NAPI (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Use RCU to protect rq->xdp_prog (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Fix FTE cleanup (Alaa Hleihel) [1858561]
- [infiniband] mlx5: Use fallthrough pseudo-keyword (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Fix flow destination setting for RDMA TX flow table (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Delete extra dump stack that gives nothing (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: convert to new udp_tunnel infrastructure (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: DR, Change push vlan action sequence (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Enable users to change VF/PF representors carrier state (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Delete unreachable code (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: drop unnecessary list_empty (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Use fallthrough pseudo-keyword (Alaa Hleihel) [1858583 1858561]
- [netdrv] net/mlx5: DR, Reduce print level for matcher print (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add support for PCI relaxed ordering (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Use indirect call wrappers for RX post WQEs functions (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move exposure of datapath function to txrx header (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: RX, Re-work initializaiton of RX function pointers (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-switch, Use eswitch total_vports (Alaa Hleihel) [1858583 1858561]
- [netdrv] net/mlx5: E-switch, Reuse total_vports and avoid duplicate nvports (Alaa Hleihel) [1858583 1858561]
- [netdrv] net/mlx5: E-switch, Consider maximum vf vports for steering init (Alaa Hleihel) [1858583 1858561]
- [netdrv] net/mlx5: Add function ID to reclaim pages debug log (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Hold pages RB tree per VF (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Set mkey relaxed ordering by UMR with ConnectX-7 (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Use MLX5_SET macro instead of local structure (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Add missing srcu_read_lock in ODP implicit flow (Alaa Hleihel) [1858561]
- [include] RDMA/mlx5: ConnectX-7 new capabilities to set relaxed ordering by UMR (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Allow SQ modification (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Do not request completion on every single UMR WQE (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: RX, Avoid indirect call in representor CQE handling (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: XDP, Avoid indirect call in TX flow (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: IPsec: Add Connect-X IPsec ESN update offload support (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5e: IPsec: Add Connect-X IPsec Rx data path offload (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5e: IPsec: Add IPsec steering in local NIC RX (Alaa Hleihel) [1858561 1790222]
- [include] net/mlx5: Add IPsec related Flow steering entry's fields (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5: IPsec: Add HW crypto offload support (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5: Accel, Add core IPsec support for the Connect-X family (Alaa Hleihel) [1858561 1790222]
- [netdrv] net/mlx5: E-switch, Reduce dependency on num_vfs during mode set (Alaa Hleihel) [1858583 1858561]
- [netdrv] net/mlx5: E-switch, Avoid function change handler for non ECPF (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Make MLX5_EN_TLS non-prompt (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Enable count action for rules with allow action (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Add interface changes required for VDPA (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Add VDPA interface type to supported enumerations (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Support setting access rights of dma addresses (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move devlink port register and unregister calls (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Remove unused to_mibmr function (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-switch, When eswitch is unsupported, return -EOPNOTSUPP (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Added support for 100Gbps per lane link modes (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Delete one-time used functions (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Cleanup DEVX initialization flow (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Separate flow steering logic from main.c (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Separate counters from main.c (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Separate restrack callbacks initialization from main.c (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Limit the scope of mlx5_ib_enable_driver function (Alaa Hleihel) [1858561]
- [infiniband] RDMA: Move XRCD to be under ib_core responsibility (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Introduce UAPI to query PD attributes (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Implement the query ucontext functionality (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Refactor mlx5_ib_alloc_ucontext() response (Alaa Hleihel) [1858561]
- [infiniband] RDMA/core: Optimize XRC target lookup (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Get XRCD number directly for the internal use (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Enable QP number request when creating IPoIB underlay QP (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Introduce ODP prefetch counter (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Enhance TX timeout recovery (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Enhance ICOSQ data on RX reporter's diagnose (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add EQ info to TX/RX reporter's diagnose (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Enhance CQ data on diagnose output (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Rename reporter's helpers (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add helper to get the RQ WQE counter (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add helper to get RQ WQE's head (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move RQ helpers to txrx.h (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Align RX/TX reporters diagnose output format (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Remove redundant RQ state query (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Add a flush timeout define (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Change reporters create functions to return void (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: fix memory leak of tls (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Fix build break when CONFIG_XPS is not set (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: kTLS, Add kTLS RX HW offload support (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: kTLS, Use kernel API to extract private offload context (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: kTLS, Improve TLS feature modularity (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Accel, Expose flow steering API for rules add/del (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Receive flow steering framework for accelerated TCP flows (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: API to manipulate TTC rules destinations (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Refactor build channel params (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Turn XSK ICOSQ into a general asynchronous one (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: kTLS, Improve TLS params layout structures (Alaa Hleihel) [1858561]
- [include] net/mlx5: Avoid RDMA file inclusion in core driver (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: vxlan: Return bool instead of opaque ptr in port_lookup() (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5e: Move TC-specific function definitions into MLX5_CLS_ACT (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Use kfree(ft->g) in arfs_create_groups() (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: FWTrace: Add missing space (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Add support to get MR resource in RAW format (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Add support to get CQ resource in RAW format (Alaa Hleihel) [1858561]
- [infiniband] RDMA/mlx5: Add support to get QP resource in RAW format (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Add support in query QP, CQ and MKEY segments (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Export resource dump interface (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-switch, Supporting setting devlink port function mac address (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Split mac address setting function for using state_lock (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-switch, Support querying port function mac address (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: Move helper to eswitch layer (Alaa Hleihel) [1858561]
- [netdrv] net/mlx5: E-switch, Introduce and use eswitch support check helper (Alaa Hleihel) [1858583 1858561]
- [netdrv] net/mlx5: Constify mac address pointer (Alaa Hleihel) [1858561]
- [tty] serial: 8250: export serial8250_do_set_divisor() (Steve Best) [1784119]
- [tty] serial: 8250: introduce get_divisor() and set_divisor() hook (Steve Best) [1784119]
- [tty] serial: 8250: let serial8250_get_divisor() get uart_port * as param (Steve Best) [1784119]
- [tty] serial: 8250_lpss: Add ->setup() for Elkhart Lake ports (Steve Best) [1784119]
- [tty] serial: 8250_lpss: Switch over to MSI interrupts (Steve Best) [1784119]
- [tty] serial: 8250_lpss: Enable HS UART on Elkhart Lake (Steve Best) [1784119]
- [tty] serial: 8250_lpss: Get rid of custom LPSS_DEVICE() macro (Steve Best) [1784119]
- [tty] serial: 8250_lpss: register DMA IRQ and pool with instance ID (Steve Best) [1784119]
- [tty] serial: 8250_lpss: add fractional divisor support (Steve Best) [1784119]
- [tty] serial: 8250_lpss: switch to use 8250_dwlib library (Steve Best) [1784119]
- [tty] tty: serial: Use the correct style for SPDX License Identifier (Steve Best) [1784119]
- [tty] serial: 8250_dw: split Synopsys DesignWare 8250 common functions (Steve Best) [1784119]
- [tty] 8250_lpss: check null return when calling pci_ioremap_bar (Steve Best) [1784119]
- [dma] dmaengine: dw: Remove misleading is_private property (Steve Best) [1784119]
- [tty] serial: 8250: fix null-ptr-deref in serial8250_start_tx() (John Linville) [1903272] {CVE-2020-15437}
- [i2c] i2c: designware-pci: Fix BUG_ON during device removal (Steve Best) [1784122]
- [i2c] i2c: designware-pci: Add support for Elkhart Lake PSE I2C (Steve Best) [1784122]
- [i2c] i2c: designware-pci: Switch over to MSI interrupts (Steve Best) [1784122]
- [mmc] mmc: sdhci: Add LTR support for some Intel BYT based controllers (Steve Best) [1906791]
- [mmc] mmc: sdhci-pci: Add max-frequency device property for Intel controllers (Steve Best) [1906791]
- [powerpc] powerpc/64s: Trim offlined CPUs from mm_cpumasks (Steve Best) [1905892]
- [kernel] kernel/cpu: add arch override for clear_tasks_mm_cpumask() mm handling (Steve Best) [1905892]
- [mm] powerpc/64s/pseries: Fix hash tlbiel_all_isa300 for guest kernels (Steve Best) [1905892]
- [mm] powerpc/64s: Fix hash ISA v3.0 TLBIEL instruction generation (Steve Best) [1905892]
- [mm] powerpc/64s: Add cp_abort after tlbiel to invalidate copy-buffer address (Steve Best) [1905892]
- [powerpc] powerpc: untangle cputable mce include (Steve Best) [1905892]
- [mmc] mmc: sdhci-pci: Add support for Intel EHL (Steve Best) [1783588]
- [scsi] qla2xxx: Update version to 10.02.00.104-k (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix device loss on 4G and older HBAs (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: If fcport is undergoing deletion complete I/O with retry (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix the call trace for flush workqueue (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix flash update in 28XX adapters on big endian machines (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Handle aborts correctly for port undergoing deletion (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix N2N and NVMe connect retry failure (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix FW initialization error on big endian machines (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix crash during driver load on big endian machines (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Fix compilation issue in PPC systems (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Don't check for fw_started while posting NVMe command (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Tear down session if FW say it is down (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Limit interrupt vectors to number of CPUs (Nilesh Javali) [1905493]
- [scsi] scsi: qla2xxx: Change post del message from debug level to log level (Nilesh Javali) [1905493]
- [s390] s390/qeth: Remove pnso workaround (Philipp Rudo) [1903964]
- [s390] s390/purgatory: do not build purgatory with kcov, kasan and friends (Philipp Rudo) [1900550]
- [fs] iomap: Fix misplaced page flushing (Carlos Maiolino) [1868429]
- [fs] iomap: Use round_down/round_up macros in __iomap_write_begin (Carlos Maiolino) [1868429]
- [fs] iomap: Mark read blocks uptodate in write_begin (Carlos Maiolino) [1868429]
- [fs] iomap: Clear page error before beginning a write (Carlos Maiolino) [1868429]
- [fs] iomap: fix WARN_ON_ONCE() from unprivileged users (Carlos Maiolino) [1868429]
- [fs] iomap: fall back to buffered writes for invalidation failures (Carlos Maiolino) [1868429]
- [fs] iomap: Only invalidate page cache pages on direct IO writes (Carlos Maiolino) [1868429]
- [fs] iomap: Make sure iomap_end is called after iomap_begin (Carlos Maiolino) [1868429]
- [fs] iomap: Fix unsharing of an extent >2GB on a 32-bit machine (Carlos Maiolino) [1868429]
- [fs] iomap: fix the iomap_fiemap prototype (Carlos Maiolino) [1868429]
- [fs] iomap: remove lockdep_assert_held() (Carlos Maiolino) [1868429]
- [mm] powerpc/numa: Fix a regression on memoryless node 0 (Steve Best) [1903613]
- [mm] powerpc/numa: Offline memoryless cpuless node 0 (Steve Best) [1903613]
- [mm] powerpc/numa: Prefer node id queried from vphn (Steve Best) [1903613]
- [mm] powerpc/numa: Set numa_node for all possible cpus (Steve Best) [1903613]
- [powerpc] powerpc/numa: Remove late request for home node associativity (Steve Best) [1903613]
- [mm] powerpc/numa: Early request for home node associativity (Steve Best) [1903613]
- [mm] powerpc/numa: Use cpu node map of first sibling thread (Steve Best) [1903613]
- [x86] xen: don't unbind uninitialized lock_kicker_irq (Brian Masney) [1896786]
- [net] Bluetooth: Acquire sk_lock.slock without disabling interrupts (Ivan Vecera) [1889859]
- [wireless] mwifiex: fix double free (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dbg: run init_cfg function once per driver load (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dbg: remove no filter condition (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: split a print to avoid a WARNING in ROC (Jarod Wilson) [1860496]
- [wireless] qtnfmac: fix resource leaks on unsupported iftype error return path (Jarod Wilson) [1860496]
- [net] nl80211: fix OBSS PD min and max offset validation (Jarod Wilson) [1860496]
- [wireless] rtw88: Fix potential probe error handling race with wow firmware loading (Jarod Wilson) [1860496]
- [wireless] rtw88: Fix probe error handling race with firmware loading (Jarod Wilson) [1860496]
- [wireless] ath6kl: wmi: prevent a shift wrapping bug in ath6kl_wmi_delete_pstream_cmd() (Jarod Wilson) [1860496]
- [wireless] ath11k: Add checked value for ath11k_ahb_remove (Jarod Wilson) [1860496]
- [wireless] mwifiex: remove function pointer check (Jarod Wilson) [1860496]
- [wireless] ath11k: fix uninitialized return in ath11k_spectral_process_data() (Jarod Wilson) [1860496]
- [wireless] ath11k: fix a double free and a memory leak (Jarod Wilson) [1860496]
- [wireless] rtw88: fix compile warning: (Jarod Wilson) [1860496]
- [wireless] mwifiex: Remove unnecessary braces from HostCmd_SET_SEQ_NO_BSS_INFO (Jarod Wilson) [1860496]
- [wireless] rtw88: don't treat NULL pointer as an array (Jarod Wilson) [1860496]
- [wireless] mwifiex: Do not use GFP_KERNEL in atomic context (Jarod Wilson) [1860496]
- [wireless] brcmfmac: check ndev pointer (Jarod Wilson) [1860496]
- [wireless] ath11k: Fix possible memleak in ath11k_qmi_init_service (Jarod Wilson) [1860496]
- [wireless] ath10k: Fix the size used in a 'dma_free_coherent()' call in an error handling path (Jarod Wilson) [1860496]
- [wireless] ath9k: Fix potential out of bounds in ath9k_htc_txcompletion_cb() (Jarod Wilson) [1860496]
- [wireless] ath9k_htc: Use appropriate rs_datalen type (Jarod Wilson) [1860496]
- [wireless] ath6kl: prevent potential array overflow in ath6kl_add_new_sta() (Jarod Wilson) [1860496]
- [net] net: wireless: nl80211: fix out-of-bounds access in nl80211_del_key() (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: reduce maximum VHT MPDU length to 7991 (Jarod Wilson) [1860496]
- [net] mac80211: fix 80 MHz association to 160/80+80 AP on 6 GHz (Jarod Wilson) [1860496]
- [net] mac80211: do not allow bigger VHT MPDUs than the hardware supports (Jarod Wilson) [1860496]
- [net] cfg80211: fix 6 GHz channel conversion (Jarod Wilson) [1860496]
- [net] mac80211: do not disable HE if HT is missing on 2.4 GHz (Jarod Wilson) [1860496]
- [net] mac80211: Fix radiotap header channel flag for 6GHz band (Jarod Wilson) [1860496]
- [net] lib80211: fix unmet direct dependendices config warning when !CRYPTO (Jarod Wilson) [1860496]
- [net] mac80211: add AQL support for VHT160 tx rates (Jarod Wilson) [1860496]
- [net] mac80211: extend AQL aggregation estimation to HE and fix unit mismatch (Jarod Wilson) [1860496]
- [wireless] mwifiex: Increase AES key storage size to 256 bits (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: use ieee80211_free_txskb to free tx skbs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: use v1 MCU API on MT7615 to fix issues with adding/removing stations (Jarod Wilson) [1860496]
- [net] cfg80211: Adjust 6 GHz frequency to channel conversion (Jarod Wilson) [1860496]
- [net] mac80211: reduce packet loss event false positives (Jarod Wilson) [1860496]
- [net] cfg80211: regulatory: reject invalid hints (Jarod Wilson) [1860496]
- [net] wireless: fix wrong 160/80+80 MHz setting (Jarod Wilson) [1860496]
- [net] mac80211: improve AQL aggregation estimation for low data rates (Jarod Wilson) [1860496]
- [net] mac80211: factor out code to look up the average packet length duration for a rate (Jarod Wilson) [1860496]
- [net] mac80211: use rate provided via status->rate on ieee80211_tx_status_ext for AQL (Jarod Wilson) [1860496]
- [net] nl80211: fix NL80211_ATTR_HE_6GHZ_CAPABILITY usage (Jarod Wilson) [1860496]
- [wireless] brcmfmac: reserve tx credit only when txctl is ready to send (Jarod Wilson) [1860496]
- [net] wireless: Use fallthrough pseudo-keyword (Jarod Wilson) [1860496]
- [wireless] rtl818x: constify ioreadX() iomem argument (as in generic implementation) (Jarod Wilson) [1860496]
- [net] mac80211: Do not report beacon loss if beacon filtering enabled (Jarod Wilson) [1860496]
- [net] mac80211: fix misplaced while instead of if (Jarod Wilson) [1860496]
- [net] nl80211: use eth_zero_addr() to clear mac address (Jarod Wilson) [1860496]
- [net] mac80211: use eth_zero_addr() to clear mac address (Jarod Wilson) [1860496]
- [net] mac8211: fix struct initialisation (Jarod Wilson) [1860496]
- [net] mac80211: Handle special status codes in SAE commit (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Set timeout value when configuring power save (Jarod Wilson) [1860496]
- [wireless] hostap: use generic power management (Jarod Wilson) [1860496]
- [wireless] rt2x00: pci: use generic power management (Jarod Wilson) [1860496]
- [wireless] mt7601u: add missing release on skb in mt7601u_mcu_msg_send (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: don't print failure if debug firmware is missing (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: coex: add functions and parameters (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: make symbol 'rtw8821c_rtw_pwr_track_tbl' static (Jarod Wilson) [1860496]
- [wireless] rtw88: add h2c command in debugfs (Jarod Wilson) [1860496]
- [wireless] rtw88: allows driver to enable/disable beacon (Jarod Wilson) [1860496]
- [wireless] rtw88: add ieee80211_ops::change_interface (Jarod Wilson) [1860496]
- [wireless] rtw88: coex: only skip coex triggered by BT info (Jarod Wilson) [1860496]
- [wireless] rtw88: update tx descriptor of mgmt and reserved page packets (Jarod Wilson) [1860496]
- [wireless] rtw88: fix short GI capability based on current bandwidth (Jarod Wilson) [1860496]
- [wireless] rtw88: fix LDPC field for RA info (Jarod Wilson) [1860496]
- [wireless] prism54: switch from 'pci_' to 'dma_' API (Jarod Wilson) [1860496]
- [wireless] prism54: islpci_hotplug: use generic power management (Jarod Wilson) [1860496]
- [wireless] prism54: Replace HTTP links with HTTPS ones (Jarod Wilson) [1860496]
- [wireless] p54: switch from 'pci_' to 'dma_' API (Jarod Wilson) [1860496]
- [wireless] mwifiex: 11n_rxreorder: Remove unnecessary cast in kfree() (Jarod Wilson) [1860496]
- [wireless] rtlwifi: btcoex: use *ph to print small buffer (Jarod Wilson) [1860496]
- [wireless] rtlwifi: btcoex: remove redundant initialization of variables ant_num and single_ant_path (Jarod Wilson) [1860496]
- [net] mac80211: warn only once in check_sdata_in_driver() at each caller (Jarod Wilson) [1860496]
- [net] nl80211: support 4-way handshake offloading for WPA/WPA2-PSK in AP mode (Jarod Wilson) [1860496]
- [net] cfg80211: invert HE BSS color 'disabled' to 'enabled' (Jarod Wilson) [1860496]
- [net] mac80211: add a function for running rx without passing skbs to the stack (Jarod Wilson) [1860496]
- [net] mac80211: parse radiotap header when selecting Tx queue (Jarod Wilson) [1860496]
- [net] mac80211: remove unused flags argument in transmit functions (Jarod Wilson) [1860496]
- [net] mac80211: use same flag everywhere to avoid sequence number overwrite (Jarod Wilson) [1860496]
- [net] mac80211: do not overwrite the sequence number if requested (Jarod Wilson) [1860496]
- [net] mac80211: add radiotap flag to prevent sequence number overwrite (Jarod Wilson) [1860496]
- [net] mac80211: never drop injected frames even if normally not allowed (Jarod Wilson) [1860496]
- [uapi] cfg80211: Add support to advertize OCV support (Jarod Wilson) [1860496]
- [net] cfg80211/mac80211: avoid bss color setting in non-HE modes (Jarod Wilson) [1860496]
- [net] mac80211: calculate skb hash early when using itxq (Jarod Wilson) [1860496]
- [net] mac80211: improve AQL tx airtime estimation (Jarod Wilson) [1860496]
- [net] cfg80211/mac80211: add connected to auth server to station info (Jarod Wilson) [1860496]
- [net] cfg80211/mac80211: add connected to auth server to meshconf (Jarod Wilson) [1860496]
- [net] cfg80211/mac80211: add mesh_param "mesh_nolearn" to skip path discovery (Jarod Wilson) [1860496]
- [net] cfg80211: allow the low level driver to flush the BSS table (Jarod Wilson) [1860496]
- [net] mac80211: Use fallthrough pseudo-keyword (Jarod Wilson) [1860496]
- [net] nl80211: Simplify error handling path in 'nl80211_trigger_scan()' (Jarod Wilson) [1860496]
- [net] nl80211: Remove a misleading label in 'nl80211_trigger_scan()' (Jarod Wilson) [1860496]
- [uapi] net/wireless: wireless.h: drop duplicate word in comments (Jarod Wilson) [1860496]
- [uapi] net/wireless: nl80211.h: drop duplicate words in comments (Jarod Wilson) [1860496]
- [net] cfg80211: allow vendor dumpit to terminate by returning 0 (Jarod Wilson) [1860496]
- [net] mac80211: remove the need for variable rates_idx (Jarod Wilson) [1860496]
- [net] nl80211: S1G band and channel definitions (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add missing release on skb in __mt76x02u_mcu_send_msg (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix possible memory leak in mt7615_mcu_wtbl_sta_add (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix potential memory leak in mcu message handler (Jarod Wilson) [1860496]
- [wireless] mt76: mt76s: move queue accounting in mt76s_tx_queue_skb (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7663s support (Jarod Wilson) [1860496]
- [wireless] mt76: introduce mt76_sdio module (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7663-usb-sdio-common module (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: sdio code must access rate/key regs in preocess context (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add mt76_skb_adjust_pad utility routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: take into account sdio bus configuring txwi (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add missing CONFIG_MAC80211_DEBUGFS (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: potential array overflow in mt7915_mcu_tx_rate_report() (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix potential memory leak in mcu message handler (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: fix potential memory leak in mcu message handler (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: fix memory leak in set key (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: reschedule ps work according to last activity (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: avoid scheduling runtime-pm during hw scan (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: sync probe sampling with rate configuration (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: improve mt7615_driver_own reliability (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add idle-timeout knob in mt7615 debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: enable beacon hw filter for runtime-pm (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add runtime-pm knob in mt7615 debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: do not request {driver, fw}_own if already granted (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: check MT76_STATE_PM flag before accessing the device (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: run mt7615_pm_wake in mt7615_mac_sta_{add, remove} (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: wake device before pushing frames in mt7615_tx (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: wake device before pulling packets from mac80211 queues (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: run mt7615_mcu_set_roc holding mt76 mutex (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: run mt7615_mcu_set_wmm holding mt76 mutex (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add missing lock in mt7615_regd_notifier (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: wake device before performing freq scan (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: acquire driver_own before configuring device for suspend (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: wake device in mt7615_update_channel before access regmap (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce pm_power_save delayed work (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: wake device before configuring hw keys (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: wake device before accessing regmap in debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mutex_{acquire, release} utilities (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add mt7615_pm_wake utility routine (Jarod Wilson) [1860496]
- [wireless] mt76: move mt76 workqueue in common code (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: avoid polling in fw_own for mt7663 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: avoid memcpy in rxv operation (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2u: enable HC-M7662BU1 (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2: fix pci suspend/resume on mt7612e (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: update HE capabilities (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: implement testmode support (Jarod Wilson) [1860496]
- [wireless] mt76: add API for testmode support (Jarod Wilson) [1860496]
- [wireless] mt76: vif_mask to struct mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: use full on-chip memory address for WF_PHY registers (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for accessing RF registers via MCU (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for accessing mapped registers via bus ops (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: schedule tx tasklet and sta poll on mac tx free (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2e: rename routines in pci.c (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: overwrite qid for non-bufferable mgmt frames (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: use ieee80211_tx_queue_params to avoid open coded (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add MU-MIMO support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add a fixed AC queue mapping (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add .set_tsf callback (Jarod Wilson) [1860496]
- [wireless] mt76: add U-APSD support on AP side (Jarod Wilson) [1860496]
- [wireless] mt76: rely on register macros (Jarod Wilson) [1860496]
- [wireless] mt76: fix include in pci.h (Jarod Wilson) [1860496]
- [wireless] mt76: allow more channels, allowed in ETSI domain (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix up typo in Kconfig for MT7663U (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: introduce ARP filter offload (Jarod Wilson) [1860496]
- [wireless] mt76: usb: rely on mt76_for_each_q_rx (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: re-enable offloading of sequence number assignment (Jarod Wilson) [1860496]
- [wireless] wireless: Fix trivial spelling (Jarod Wilson) [1860496]
- [wireless] rtlwifi: 8821ae: remove unused path B parameters from swing table (Jarod Wilson) [1860496]
- [wireless] rtlwifi: Use const in 8188ee/8723be/8821ae swing_table declarations (Jarod Wilson) [1860496]
- [wireless] rtl818x_pci: use generic power management (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8192cu: Free ieee80211_hw if probing fails (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8192cu: Prevent leaking urb (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8192cu: Fix deadlock (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8192cu: Remove uninitialized_var() usage (Jarod Wilson) [1860496]
- [wireless] orinoco_usb: fix spelling mistake (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8188ee: Fix endian issue (Jarod Wilson) [1860496]
- [wireless] rtlwifi: Fix endian issue in ps.c (Jarod Wilson) [1860496]
- [wireless] broadcom: fix wiki website url (Jarod Wilson) [1860496]
- [wireless] wireless: fix wiki website url in main Kconfig (Jarod Wilson) [1860496]
- [wireless] rtw88: coex: Fix ACL Tx pause during BT inquiry/page (Jarod Wilson) [1860496]
- [wireless] mwifiex: Prevent memory corruption handling keys (Jarod Wilson) [1860496]
- [wireless] mwifiex: Fix reporting 'operation not supported' error code (Jarod Wilson) [1860496]
- [wireless] mwifiex: Use macro MWIFIEX_MAX_BSS_NUM for specifying limit of interfaces (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: add new RFE type 6 (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822ce: add support for device ID 0xc82f (Jarod Wilson) [1860496]
- [wireless] rtw88: pci: disable aspm for platform inter-op with module parameter (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: Add 8821CE to Kconfig and Makefile (Jarod Wilson) [1860496]
- [wireless] rtw88: single rf path chips don't support TX STBC (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add beamformee support (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add power tracking (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add cck pd settings (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add phy calibration (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add false alarm statistics (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add query rx desc support (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add set channel support (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add dig related settings (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add set tx power index (Jarod Wilson) [1860496]
- [wireless] rtw88: 8821c: add basic functions (Jarod Wilson) [1860496]
- [wireless] brcm80211: brcmsmac: Move LEDs to GPIO descriptors (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Transform compatible string for FW loading (Jarod Wilson) [1860496]
- [wireless] brcmfmac: set pacing shift before transmitting skb to bus (Jarod Wilson) [1860496]
- [wireless] brcmfmac: set state of hanger slot to FREE when flushing PSQ (Jarod Wilson) [1860496]
- [wireless] brcmfmac: reset SDIO bus on a firmware crash (Jarod Wilson) [1860496]
- [wireless] brcmfmac: do not disconnect for disassoc frame from unconnected AP (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Fix for wrong disconnection event source information (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Fix for unable to return to visible SSID (Jarod Wilson) [1860496]
- [wireless] brcmfmac: initialize the requested dwell time (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix throughput zero stalls on PM 1 mode due to credit map (Jarod Wilson) [1860496]
- [wireless] brcmfmac: update tx status flags to sync with firmware (Jarod Wilson) [1860496]
- [wireless] brcmfmac: reserve 2 credits for host tx control path (Jarod Wilson) [1860496]
- [wireless] brcmfmac: increase message buffer size for control packets (Jarod Wilson) [1860496]
- [wireless] brcmfmac: allow credit borrowing for all access categories (Jarod Wilson) [1860496]
- [wireless] brcmfmac: To fix Bss Info flag definition Bug (Jarod Wilson) [1860496]
- [wireless] brcmfmac: reduce maximum station interface from 2 to 1 in RSDB mode (Jarod Wilson) [1860496]
- [wireless] brcmfmac: keep SDIO watchdog running when console_interval is non-zero (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix invalid permanent MAC address in wiphy (Jarod Wilson) [1860496]
- [wireless] brcmfmac: To fix kernel crash on out of boundary access (Jarod Wilson) [1860496]
- [net] net: wireless: kerneldoc fixes (Jarod Wilson) [1860496]
- [net] net: mac80211: kerneldoc fixes (Jarod Wilson) [1860496]
- [wireless] ath11k: fix wmi peer flags in peer assoc command (Jarod Wilson) [1860496]
- [wireless] ath11k: Add support for ring backpressure stats (Jarod Wilson) [1860496]
- [wireless] ath11k: Add dp tx err stats (Jarod Wilson) [1860496]
- [wireless] ath11k: removing redundant reo unlock followed by immediate lock (Jarod Wilson) [1860496]
- [wireless] ath11k: add support for spectral scan (Jarod Wilson) [1860496]
- [wireless] ath11k: Add direct buffer ring support (Jarod Wilson) [1860496]
- [wireless] ath11k: build HE 6 GHz capability (Jarod Wilson) [1860496]
- [wireless] ath11k: Add support for 6g scan hint (Jarod Wilson) [1860496]
- [wireless] ath11k: Send multiple scan_chan_list messages if required (Jarod Wilson) [1860496]
- [wireless] ath11k: Add 6G scan dwell time parameter in scan request command (Jarod Wilson) [1860496]
- [wireless] ath11k: set psc channel flag when sending channel list to firmware (Jarod Wilson) [1860496]
- [wireless] ath11k: extend peer_assoc_cmd for 6GHz band (Jarod Wilson) [1860496]
- [wireless] ath11k: Use freq instead of channel number in rx path (Jarod Wilson) [1860496]
- [wireless] ath11k: add support for 6GHz radio in driver (Jarod Wilson) [1860496]
- [wireless] ath11k: add 6G frequency list supported by driver (Jarod Wilson) [1860496]
- [wireless] net: wireless: intel: fix wiki website url (Jarod Wilson) [1860496]
- [wireless] iwlwifi: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: Remove unused inline function iwl_mvm_tid_to_ac_queue (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: fix gcc-10 zero-length-bounds warning (Jarod Wilson) [1860496]
- [wireless] ath: fix wiki website url (Jarod Wilson) [1860496]
- [wireless] ath10k: Acquire tx_lock in tx error paths (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: remove redundant assignment to variable ret (Jarod Wilson) [1860496]
- [wireless] iwlwifi: fix config variable name in comment (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: Fix avg-power report (Jarod Wilson) [1860496]
- [wireless] iwlwifi: Don't IWL_WARN on FW reconfiguration (Jarod Wilson) [1860496]
- [wireless] iwlwifi: Extended Key ID support for mvm and dvm (Jarod Wilson) [1860496]
- [wireless] mwifiex: Fix firmware filename for sd8997 chipset (Jarod Wilson) [1860496]
- [wireless] mwifiex: Fix firmware filename for sd8977 chipset (Jarod Wilson) [1860496]
- [net] mac80211: remove STA txq pending airtime underflow warning (Jarod Wilson) [1860496]
- [net] mac80211: Fix bug in Tx ack status reporting in 802.3 xmit path (Jarod Wilson) [1860496]
- [net] cfg80211: check vendor command doit pointer before use (Jarod Wilson) [1860496]
- [net] mac80211: mesh: Free pending skb when destroying a mpath (Jarod Wilson) [1860496]
- [net] mac80211: mesh: Free ie data when leaving mesh (Jarod Wilson) [1860496]
- [net] mac80211: fix warning in 6 GHz IE addition in mesh mode (Jarod Wilson) [1860496]
- [wireless] ath10k: Fix NULL pointer dereference in AHB device probe (Jarod Wilson) [1860496]
- [wireless] iwlwifi: Make some Killer Wireless-AC 1550 cards work again (Jarod Wilson) [1860496]
- [wireless] ath9k: Fix regression with Atheros 9271 (Jarod Wilson) [1860496]
- [net] nl80211: fix memory leak when parsing NL80211_ATTR_HE_BSS_COLOR (Jarod Wilson) [1860496]
- [net] nl80211: don't return err unconditionally in nl80211_start_ap() (Jarod Wilson) [1860496]
- [net] mac80211: allow rx of mesh eapol frames with default rx key (Jarod Wilson) [1860496]
- [net] mac80211: skip mpath lookup also for control port tx (Jarod Wilson) [1860496]
- [net] mac80211: Fix dropping broadcast packets in 802.11 encap (Jarod Wilson) [1860496]
- [net] mac80211: simplify mesh code (Jarod Wilson) [1860496]
- [net] mac80211: fix control port tx status check (Jarod Wilson) [1860496]
- [include] ieee80211: Add missing and new AKM suite selector definitions (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix EEPROM buffer size (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: fix memory leaks in mt7663u_probe (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: do not access uninitialized NAPI structs (Jarod Wilson) [1860496]
- [wireless] iwlwifi: fix crash in iwl_dbg_tlv_alloc_trigger (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: don't call iwl_mvm_free_inactive_queue() under RCU (Jarod Wilson) [1860496]
- [wireless] wireless: replace '---help---' in Kconfig files with 'help' (Jarod Wilson) [1860496]
- [net] net: fix wiki website url mac80211 and wireless files (Jarod Wilson) [1860496]
- [uapi] include: fix wiki website url in netlink interface header (Jarod Wilson) [1860496]
- [wireless] mt76: overwrite qid for non-bufferable mgmt frames (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix hw queue mapping (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix lmac queue debugsfs entry (Jarod Wilson) [1860496]
- [wireless] mt76: add missing lock configuring coverage class (Jarod Wilson) [1860496]
- [net] mac80211: initialize return flags in HE 6 GHz operation parsing (Jarod Wilson) [1860496]
- [net] cfg80211: fix management registrations deadlock (Jarod Wilson) [1860496]
- [net] cfg80211: support bigger kek/kck key length (Jarod Wilson) [1860496]
- [net] mac80211: set short_slot for 6 GHz band (Jarod Wilson) [1860496]
- [net] mac80211: Consider 6 GHz band when handling power constraint (Jarod Wilson) [1860496]
- [net] mac80211: accept aggregation sessions on 6 GHz (Jarod Wilson) [1860496]
- [net] cfg80211: require HE capabilities for 6 GHz band (Jarod Wilson) [1860496]
- [net] cfg80211: reject HT/VHT capabilities on 6 GHz band (Jarod Wilson) [1860496]
- [net] cfg80211: treat 6 GHz channels as valid regardless of capability (Jarod Wilson) [1860496]
- [net] mac80211: Add HE 6GHz capabilities element to probe request (Jarod Wilson) [1860496]
- [net] mac80211: use HE 6 GHz band capability and pass it to the driver (Jarod Wilson) [1860496]
- [net] mac80211: check the correct bit for EMA AP (Jarod Wilson) [1860496]
- [net] mac80211: determine chandef from HE 6 GHz operation (Jarod Wilson) [1860496]
- [net] mac80211: avoid using ext NSS high BW if not supported (Jarod Wilson) [1860496]
- [net] mac80211: do not allow HT/VHT IEs in 6 GHz mesh mode (Jarod Wilson) [1860496]
- [net] mac80211: build HE operation with 6 GHz oper information (Jarod Wilson) [1860496]
- [net] mac80211: add HE 6 GHz Band Capability element (Jarod Wilson) [1860496]
- [net] cfg80211: add and expose HE 6 GHz band capabilities (Jarod Wilson) [1860496]
- [net] mac80211: add HE 6 GHz Band Capabilities into parse extension (Jarod Wilson) [1860496]
- [net] cfg80211: handle 6 GHz capability of new station (Jarod Wilson) [1860496]
- [include] ieee80211: add HE ext EIDs and 6 GHz capability defines (Jarod Wilson) [1860496]
- [include] ieee80211: add code to obtain and parse 6 GHz operation field (Jarod Wilson) [1860496]
- [include] ieee80211: definitions for reduced neighbor reports (Jarod Wilson) [1860496]
- [net] cfg80211: add a helper to identify 6 GHz PSCs (Jarod Wilson) [1860496]
- [net] nl80211: really allow client-only BIGTK support (Jarod Wilson) [1860496]
- [net] cfg80211: adapt to new channelization of the 6GHz band (Jarod Wilson) [1860496]
- [net] cfg80211: fix 6 GHz frequencies to kHz (Jarod Wilson) [1860496]
- [wireless] ath11k: clear DCM max constellation tx value (Jarod Wilson) [1860496]
- [wireless] ath11k: reset trigger frame MAC padding duration (Jarod Wilson) [1860496]
- [wireless] ath10k: Remove ath10k_qmi_register_service_notifier() declaration (Jarod Wilson) [1860496]
- [wireless] ath9k_htc: Set RX filter based to allow broadcast Action frame RX (Jarod Wilson) [1860496]
- [wireless] ath9k: Set RX filter based to allow broadcast Action frame RX (Jarod Wilson) [1860496]
- [wireless] mwifiex: Add support for NL80211_ATTR_MAX_AP_ASSOC_STA (Jarod Wilson) [1860496]
- [wireless] mwifiex: Parse all API_VER_ID properties (Jarod Wilson) [1860496]
- [wireless] brcmfmac: 43012 Update MES Watermark (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix 43455 CRC error under SDIO 3.0 SDR104 mode (Jarod Wilson) [1860496]
- [wireless] brcmfmac: set F2 blocksize and watermark for 4354/4356 SDIO (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix 4339 CRC error under SDIO 3.0 SDR104 mode (Jarod Wilson) [1860496]
- [wireless] brcmfmac: set F2 blocksize for 4373 (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: remove CCK TX setting when switch channel (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: fix missing brace warning for old compilers (Jarod Wilson) [1860496]
- [wireless] rtw88: fix EAPOL 4-way failure by finish IQK earlier (Jarod Wilson) [1860496]
- [wireless] rtw88: coex: 8723d: handle BT inquiry cases (Jarod Wilson) [1860496]
- [wireless] rtw88: coex: 8723d: set antanna control owner (Jarod Wilson) [1860496]
- [wireless] Revert "rtw88: no need to set registers for SDIO" (Jarod Wilson) [1860496]
- [wireless] rt2800: enable MFP support unconditionally (Jarod Wilson) [1860496]
- [wireless] mmc: sdio: Fix Cypress SDIO IDs macros in common include file (Jarod Wilson) [1860496]
- [wireless] mmc: sdio: Move SDIO IDs from b43-sdio driver to common include file (Jarod Wilson) [1860496]
- [wireless] mmc: sdio: Move SDIO IDs from ath10k driver to common include file (Jarod Wilson) [1860496]
- [wireless] mmc: sdio: Move SDIO IDs from mwifiex driver to common include file (Jarod Wilson) [1860496]
- [wireless] mmc: sdio: Change macro names for Marvell 8688 modules (Jarod Wilson) [1860496]
- [mmc] mmc: sdio: Fix macro name for Marvell device with ID 0x9134 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: bump FW API to 56 for AX devices (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add support for range request version 10 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: fix aux station leak (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move txq-specific from trans_pcie to common trans (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move iwl_txq and substructures to a common trans header (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: gen3: indicate 8k/12k RB size to device (Jarod Wilson) [1860496]
- [wireless] iwlwifi: acpi: evaluate dsm to enable 5.2 bands in Indonesia (Jarod Wilson) [1860496]
- [wireless] iwlwifi: acpi: support device specific method (DSM) (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: keep trans instead of trans_pcie in iwl_txq (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: don't count on the FW to set persistence mode (Jarod Wilson) [1860496]
- [wireless] iwlwifi: set NO_HE if the regulatory domain forbids it (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: remove set but not used variable 'msta' (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: Use kmemdup in mt7615_queue_key_update() (Jarod Wilson) [1860496]
- [wireless] mt76: only iterate over initialized rx queues (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for MT7611N (Jarod Wilson) [1860496]
- [wireless] mt76: fix wcid allocation issues (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix possible NULL pointer dereference in mt7915_register_ext_phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix hw_scan with ssid_type for specified SSID only (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix a handful of spelling mistakes (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: switch to per-vif power_save support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix some sparse warnings (Jarod Wilson) [1860496]
- [wireless] mt76: fix per-driver wcid range checks after wcid array size bump (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix decoded radiotap HE flags (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix NULL pointer deref in mt7615_register_ext_phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix sparse warnings: incorrect type initializer (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix some sparse warnings (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add spatial reuse support (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: remove check in mt76x02_mcu_msg_send (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce remain_on_channel support (Jarod Wilson) [1860496]
- [net] mac80211: support control port TX status reporting (Jarod Wilson) [1860496]
- [net] mac80211: fix HT-Control field reception for management frames (Jarod Wilson) [1860496]
- [net] cfg80211: fix CFG82011_CRDA_SUPPORT still mentioning internal regdb (Jarod Wilson) [1860496]
- [net] nl80211: Add support to configure TID specific Tx rate configuration (Jarod Wilson) [1860496]
- [net] mac80211: allow SA-QUERY processing in userspace (Jarod Wilson) [1860496]
- [net] nl80211: add ability to report TX status for control port TX (Jarod Wilson) [1860496]
- [net] mac80211: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [net] cfg80211: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [include] mac80211: Add new AMPDU factor macro for HE peer caps (Jarod Wilson) [1860496]
- [include] ieee80211: S1G defines (Jarod Wilson) [1860496]
- [net] nl80211: support scan frequencies in KHz (Jarod Wilson) [1860496]
- [net] nl80211: add KHz frequency offset for most wifi commands (Jarod Wilson) [1860496]
- [net] cfg80211: add KHz variants of frame RX API (Jarod Wilson) [1860496]
- [net] nl80211: simplify peer specific TID configuration (Jarod Wilson) [1860496]
- [net] cfg80211: add support for TID specific AMSDU configuration (Jarod Wilson) [1860496]
- [net] mac80211: fix variable names in TID config methods (Jarod Wilson) [1860496]
- [net] cfg80211: fix mask type in cfg80211_tid_cfg structure (Jarod Wilson) [1860496]
- [net] cfg80211: fix debugfs rename crash (Jarod Wilson) [1860496]
- [include] ieee80211: Fix incorrect mask for default PE duration (Jarod Wilson) [1860496]
- [net] mac80211: mesh: fix discovery timer re-arming issue / crash (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: Fix build error (Jarod Wilson) [1860496]
- [wireless] ath11k: Fix some resource leaks in error path in 'ath11k_thermal_register()' (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8192ee: remove redundant for-loop (Jarod Wilson) [1860496]
- [wireless] mwifiex: Fix memory corruption in dump_station (Jarod Wilson) [1860496]
- [wireless] rtw88: no need to set registers for SDIO (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: fix incorrect setting of ldo_pwr (Jarod Wilson) [1860496]
- [wireless] rtw88: rename rtw88.ko/rtwpci.ko to rtw88_core.ko/rtw88_pci.ko (Jarod Wilson) [1860496]
- [wireless] rtw88: extract: remove the unused after extracting (Jarod Wilson) [1860496]
- [wireless] rtw88: extract: make 8723d an individual kernel module (Jarod Wilson) [1860496]
- [wireless] rtw88: extract: make 8822b an individual kernel module (Jarod Wilson) [1860496]
- [wireless] rtw88: extract: make 8822c an individual kernel module (Jarod Wilson) [1860496]
- [wireless] rtw88: extract: export symbols about pci interface (Jarod Wilson) [1860496]
- [wireless] rtw88: extract: export symbols used in chip functionalities (Jarod Wilson) [1860496]
- [wireless] rtlwifi: Fix a double free in _rtl_usb_tx_urb_setup() (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix typo defining ps work (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: configure bss info adding the interface (Jarod Wilson) [1860496]
- [wireless] mt76: enable p2p support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: reduce hw scan timeout (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: do not report scan_complete twice to mac80211 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: fix the usage WoW with net detect support (Jarod Wilson) [1860496]
- [wireless] ath11k: fix htt stats module not handle multiple skbs (Jarod Wilson) [1860496]
- [wireless] rtl8187: Remove unused variable rtl8225z2_tx_power_ofdm (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: fix sparse warnings for power tracking (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add 8723DE to Kconfig and Makefile (Jarod Wilson) [1860496]
- [wireless] rtw88: fill zeros to words 0x06 and 0x07 of security cam entry (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add coex support (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: set ltecoex register address in chip_info (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: implement flush queue (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add shutdown callback to disable BT USB suspend (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add power tracking (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: add IQ calibration (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add LC calibration (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix WPA/WPA2-PSK 4-way handshake offload and SAE offload failures (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: fix possible deadlock in mt7915_stop (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: allocate proper size for tlv tags (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add debugfs to track TxBF status (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add TxBF capabilities (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add Tx beamformee support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add Tx beamformer support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: introduce mt7915_get_he_phy_cap (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: usb: cancel ps work stopping the vif (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: add missing register definitions (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: copy key pointer in mt7663u_mac_write_txwi (Jarod Wilson) [1860496]
- [wireless] mt76: set runtime stream caps by mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: enable firmware module debug support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add tsf related callbacks (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: set peer Tx fixed rate through debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add .sta_statistics support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add .sta_add_debugfs support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add Rx radiotap header support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add HE capabilities support for peers (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: add HE bss_conf support for interfaces (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: register per-phy HE capabilities for each interface (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: implement HE per-rate tx power support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7915: enable Rx HE rate reporting (Jarod Wilson) [1860496]
- [wireless] mt76: add mac80211 driver for MT7915 PCIe-based chipsets (Jarod Wilson) [1860496]
- [wireless] mt76: add HE phy modes and hardware queue (Jarod Wilson) [1860496]
- [wireless] mt76: adjust wcid size to support new 802.11ax generation (Jarod Wilson) [1860496]
- [wireless] mt76: add Rx stats support for radiotap (Jarod Wilson) [1860496]
- [wireless] mt76: add support for HE RX rate reporting (Jarod Wilson) [1860496]
- [wireless] mt76: avoid rx reorder buffer overflow (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: scan all channels if not specified (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: add support to sched scan with randomise addr (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: introduce WoW with net detect support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix delta tx power for mt7663 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: fix target power parsing (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix ibss mode for mt7663 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: check return value of mt7615_eeprom_get_power_index (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: read tx streams from eeprom (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce beacon_loss mcu event (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add gtk rekey offload support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce PM support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: introduce suspend/resume to mt7663u (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add WoW support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mcu_set_hif_suspend mcu command (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce support for hardware beacon filter (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: free pci_vector if mt7615_pci_probe fails (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add passive mode for hw scan (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: do not mark sched_scan disabled in mt7615_scan_work (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_check_offload_capability routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix ssid configuration in mt7615_mcu_hw_scan (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: remove duplicate error message (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix getting maximum tx power from eeprom (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: set spatial extension index (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: remove check in mt7663_load_n9 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: add the possibility to load firmware v2 (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x0: enable MCS 8 and MCS9 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix event report in mt7615_mcu_bss_event (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add sta pointer to mt7615_mcu_add_bss_info signature (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: fix up BMC entry indicated to unicmd firmware (Jarod Wilson) [1860496]
- [wireless] mt76: enable TDLS support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move mcu bss upload before creating the sta (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: fix tx status rate index calculation (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix tx status rate index calculation (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: do not adjust MAC timings if the device is not running (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: adjust timing in mt7615_mac_set_timing to match fw/hw values (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: never use an 802.11b CF-End rate on 5GHz (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: never use an 802.11b CF-End rate on 5GHz (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: use larger rx buffers if VHT is supported (Jarod Wilson) [1860496]
- [wireless] mt76: fix A-MPDU density handling (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix sta ampdu factor for VHT (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663u: enable AirTimeFairness (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework mt7615_mac_sta_poll for usb code (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix aid configuration in mt7615_mcu_wtbl_generic_tlv (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix mt7615_driver_own routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix max wtbl size for 7663 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix mt7615_firmware_own for mt7663e (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: parse mcu return code for unified commands (Jarod Wilson) [1860496]
- [wireless] mt76: add rx queues info to mt76 debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: make Kconfig entry obvious for MT7663E (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: introduce 802.11 PS support in sta mode (Jarod Wilson) [1860496]
- [wireless] mt76: remove PS_NULLFUNC_STACK capability (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: provide aid info to the mcu (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: disable aspm by default (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: enable scs for mt7663 driver (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7663u support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move core shared code in mt7615-common module (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix possible deadlock in mt7615_stop (Jarod Wilson) [1860496]
- [wireless] mt76: remove unnecessary annotations (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: enable MSI by default (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework IRQ handling to prepare for MSI support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: fix DMA unmap length (Jarod Wilson) [1860496]
- [wireless] mt76: mt7622: fix DMA unmap length (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: set hw scan limits only for firmware with offload support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: disable hw/sched scan ops for non-offload firmware (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: fix aggr range entry in debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix possible division by 0 in mt7615_mac_update_mib_stats (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2: disable merge of OTP ROM data by default (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: disable merge of OTP ROM data by default (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for applying tx DPD calibration from EEPROM (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for applying DC offset calibration from EEPROM (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: disable merge of OTP ROM data by default (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: Delete an error message in mt7622_wmac_probe() (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: do not always reset the dfs state setting the channel (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: correct the name of the rom patch (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add address parameter to mt7615_eeprom_init (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_wtbl_desc data structure (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework wtbl key configuration (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: rely on mt7622 queue scheme for mt7663u (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move mt7615_mac_wtbl_addr in mac.h (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce __mt7663_load_firmware routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mac_update_rate_desc routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7663u support to mt7615_write_txwi (Jarod Wilson) [1860496]
- [wireless] mt76: add headroom and tailroom to mt76_mcu_ops data structure (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: remove unnecessary register operations (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce rlm tlv in bss_info mcu command (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce BSS absence event (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce scheduled scan support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce hw scan support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: keep Rx filters as the default (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mcu_set_channel_domain mcu command (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add ethool support to mt7663 driver (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: disable RDD commands (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: make scs configurable per phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: enable nf estimation (Jarod Wilson) [1860496]
- [wireless] mt76: mt7663: fix mt7615_mac_cca_stats_reset routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add more useful Tx mib counters (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: cleanup mib related defines and structs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: enable aggr_stats for both phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: modify mt7615_ampdu_stat_read for each phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x0: pci: add mt7610 PCI ID (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2u: introduce Mercury UD13 support (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02u: Add support for newer versions of the XBox One wifi adapter (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: fix handling MCU timeouts during hw restart (Jarod Wilson) [1860496]
- [wireless] rndis_wlan: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [wireless] mwl8k: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [wireless] rndis_wlan: Remove logically dead code (Jarod Wilson) [1860496]
- [wireless] brcmfmac: remove Comparison to bool in brcmf_p2p_send_action_frame() (Jarod Wilson) [1860496]
- [wireless] brcmfmac: make non-global functions static (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Use seq/seq_len and set iv_initialize when plumbing of rxiv in (GTK) keys (Jarod Wilson) [1860496]
- [wireless] brcmfmac: use actframe_abort to cancel ongoing action frame (Jarod Wilson) [1860496]
- [wireless] brcmfmac: set security after reiniting interface (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix 802.1d priority to ac mapping for pcie dongles (Jarod Wilson) [1860496]
- [wireless] brcmfmac: map 802.1d priority to precedence level based on AP WMM params (Jarod Wilson) [1860496]
- [wireless] ath11k: convert to devm_platform_get_and_ioremap_resource (Jarod Wilson) [1860496]
- [wireless] ath11k: remove redundant initialization of pointer info (Jarod Wilson) [1860496]
- [wireless] ath10k: fix ath10k_pci struct layout (Jarod Wilson) [1860496]
- [wireless] ath10k: fix gcc-10 zero-length-bounds warnings (Jarod Wilson) [1860496]
- [wireless] ath10k: remove experimental tag from SDIO and SNOC busses in Kconfig (Jarod Wilson) [1860496]
- [wireless] ath10k: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [wireless] ath11k: Remove bus layer includes from upper layer (Jarod Wilson) [1860496]
- [wireless] ath11k: Add drv private for bus opaque struct (Jarod Wilson) [1860496]
- [wireless] ath11k: Add support for multibus support (Jarod Wilson) [1860496]
- [wireless] ath10k: fix __le32 warning in ath10k_wmi_tlv_op_gen_request_peer_stats_info() (Jarod Wilson) [1860496]
- [wireless] ath10k: Remove msdu from idr when management pkt send fails (Jarod Wilson) [1860496]
- [wireless] ath10k: Skip handling del_server during driver exit (Jarod Wilson) [1860496]
- [wireless] ath11k: remove stale monitor status descriptor (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dbg_ini: differentiate ax210 hw with same hw type (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: skip fragmented receive buffers (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove outdated copyright print/module statement (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: don't transmit on unallocated queue (Jarod Wilson) [1860496]
- [wireless] iwlwifi: tx: enable A-MSDU in low latency mode (Jarod Wilson) [1860496]
- [wireless] iwlwifi: use longer queues for 256-BA (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: gen2: use DMA pool for byte-count tables (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: remove some dead code (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dbg: mark a variable __maybe_unused (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: attempt to allocate smaller queues (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: allocate much smaller byte-count table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dump api version in yaml format (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: convert all AX101 devices to the device tables (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: remove occurrences of 22000 in the FW name defines (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: convert QnJ with Hr to the device table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: remove mangling for iwl_ax101_cfg_qu_hr (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: remove outdated comment about PCI RTPM reference (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add IML/ROM information to the assertion dumps (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move iwl_set_soc_latency to iwl-drv to be used by other op_modes (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: remove magic number (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: initialize iwl_dev_tx_power_cmd to zero (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dbg: set debug descriptor to NULL outside of iwl_fw_free_dump_desc (Jarod Wilson) [1860496]
- [wireless] iwlwifi: bump FW API to 55 for AX devices (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: add D3 resume timepoint (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: set properly station flags in STA_HE_CTXT_CMD (Jarod Wilson) [1860496]
- [wireless] iwlwifi: avoid debug max amsdu config overwriting itself (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: remove iwlmvm's tfd_q_hang_detect module parameter (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: stop supporting swcrypto and bt_coex_active module parameters (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add support for range request command version 9 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: don't access TLV before verifying len (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove antenna_coupling module parameter (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: use hweight_long instead of bit manipulating (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: add support for parsing SHARED_MEM_ALLOC version 4 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: fw api: fix PHY data 2/3 position (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8188ee: remove Comparison to bool in rf.c (Jarod Wilson) [1860496]
- [wireless] mwifiex: avoid -Wstringop-overflow warning (Jarod Wilson) [1860496]
- [wireless] rtlwifi: remove comparison of 0/1 to bool variable (Jarod Wilson) [1860496]
- [wireless] brcmsmac: remove Comparison to bool in brcms_b_txstatus() (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Add P2P Action Frame retry delay to fix GAS Comeback Response failure issue (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Fix P2P Group Formation failure via Go-neg method (Jarod Wilson) [1860496]
- [wireless] brcmfmac: support the second p2p connection (Jarod Wilson) [1860496]
- [wireless] rtw88: fix an issue about leak system resources (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: add interface configurations table (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Set IG register for CCK rate (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add chip_ops::false_alarm_statistics (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: some chips don't support LDPC (Jarod Wilson) [1860496]
- [wireless] rtw88: handle C2H_CCX_TX_RPT to know if packet TX'ed successfully (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add set_channel (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add query_rx_desc (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add DIG parameter (Jarod Wilson) [1860496]
- [wireless] rtlwifi: use true, false for bool variable in rtl_init_rfkill() (Jarod Wilson) [1860496]
- [wireless] rtw88: Use udelay instead of usleep in atomic context (Jarod Wilson) [1860496]
- [wireless] ath11k: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [wireless] ath9k_htc: Silence undersized packet warnings (Jarod Wilson) [1860496]
- [wireless] ath6kl: Replace zero-length array with flexible-array (Jarod Wilson) [1860496]
- [wireless] ath11k: fix kernel panic by freeing the msdu received with invalid length (Jarod Wilson) [1860496]
- [wireless] ath11k: Add support to reset htt peer stats (Jarod Wilson) [1860496]
- [wireless] ath11k: add tx hw 802.11 encapsulation offloading support (Jarod Wilson) [1860496]
- [wireless] ath11k: fix resource unavailability for htt stats after peer stats display (Jarod Wilson) [1860496]
- [wireless] ath11k: use true,false for bool variables (Jarod Wilson) [1860496]
- [wireless] ath10k: Add support for targets without trustzone (Jarod Wilson) [1860496]
- [wireless] ath10k: Setup the msa resources before qmi init (Jarod Wilson) [1860496]
- [wireless] ath10k: remove the max_sched_scan_reqs value (Jarod Wilson) [1860496]
- [wireless] ath10k: Avoid override CE5 configuration for QCA99X0 chipsets (Jarod Wilson) [1860496]
- [wireless] brcmfmac: no need to check return value of debugfs_create functions (Jarod Wilson) [1860496]
- [wireless] brcmfmac: remove comparison to bool in brcmf_fws_attach() (Jarod Wilson) [1860496]
- [wireless] brcmfmac: add vendor ie for association responses (Jarod Wilson) [1860496]
- [wireless] brcmfmac: only generate random p2p address when needed (Jarod Wilson) [1860496]
- [wireless] brcmfmac: p2p cert 6.1.9-support GOUT handling p2p presence request (Jarod Wilson) [1860496]
- [wireless] brcmfmac: remove arp_hostip_clear from brcmf_netdev_stop (Jarod Wilson) [1860496]
- [wireless] brcmfmac: keep apsta enabled when AP starts with MCHAN feature (Jarod Wilson) [1860496]
- [wireless] rtw88: fix spelling mistake "fimrware" -> "firmware" (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: update phy parameter tables to v50 (Jarod Wilson) [1860496]
- [wireless] ath11k: add DBG_MAC prints to track vdev events (Jarod Wilson) [1860496]
- [wireless] ath11k: fix mgmt_tx_wmi cmd sent to FW for deleted vdev (Jarod Wilson) [1860496]
- [wireless] ath11k: fix error return code in ath11k_dp_alloc() (Jarod Wilson) [1860496]
- [wireless] ath10k: fix possible memory leak in ath10k_bmi_lz_data_large() (Jarod Wilson) [1860496]
- [wireless] mac80211: fix memory overlap due to variable length param (Jarod Wilson) [1860496]
- [net] mac80211: TX legacy rate control for Beacon frames (Jarod Wilson) [1860496]
- [wireless] ath11k: use GFP_ATOMIC under spin lock (Jarod Wilson) [1860496]
- [wireless] ath10k: correct tx bitrate of iw for SDIO (Jarod Wilson) [1860496]
- [wireless] ath10k: add bitrate parse for peer stats info (Jarod Wilson) [1860496]
- [wireless] ath10k: add rx bitrate report for SDIO (Jarod Wilson) [1860496]
- [wireless] ath10k: enable firmware peer stats info for wmi tlv (Jarod Wilson) [1860496]
- [wireless] ath5k: remove conversion to bool in ath5k_ani_calibration() (Jarod Wilson) [1860496]
- [wireless] ath9k: add calibration timeout for AR9002 (Jarod Wilson) [1860496]
- [wireless] ath9k: invalidate all calibrations at once (Jarod Wilson) [1860496]
- [wireless] ath9k: interleaved NF calibration on AR9002 (Jarod Wilson) [1860496]
- [wireless] ath9k: do not miss longcal on AR9002 (Jarod Wilson) [1860496]
- [wireless] ath9k: remove needless NFCAL_PENDING flag setting (Jarod Wilson) [1860496]
- [wireless] ath9k: fix AR9002 ADC and NF calibrations (Jarod Wilson) [1860496]
- [wireless] rtw88: fix sparse warnings for download firmware routine (Jarod Wilson) [1860496]
- [wireless] ath10k: add statistics of tx retries and tx failed when tx complete disable (Jarod Wilson) [1860496]
- [wireless] ath10k: enable rx duration report default for wmi tlv (Jarod Wilson) [1860496]
- [wireless] ath11k: fix reo flush send (Jarod Wilson) [1860496]
- [wireless] iwlwifi: debug: set NPK buffer in context info (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: add new structs for So devices with long latency (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: add new structure for Qu devices with medium latency (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: tell firmware about required LTR delay (Jarod Wilson) [1860496]
- [wireless] iwlwifi: update few product names in AX family (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: add cfgs for SoCs with device ID 0x4FD0 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add new cards for AX family (Jarod Wilson) [1860496]
- [wireless] iwlwifi: acpi: read TAS table from ACPI and send it to the FW (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove fw_monitor module parameter (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove deprecated and unused iwl_mvm_keyinfo struct (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add framework for specific phy configuration (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: move iwl_pcie_ctxt_info_alloc_dma() to user (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: support IWL_FW_INI_TIME_POINT_HOST_ALIVE_TIMEOUT time point (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add DCM flag to rate pretty-print (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: gen2: minor code cleanups in byte table update (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: add n_window/ampdu to tx_queue debugfs (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: use seq_file for tx_queue debugfs file (Jarod Wilson) [1860496]
- [wireless] iwlwifi: support version 9 of WOWLAN_GET_STATUS notification (Jarod Wilson) [1860496]
- [wireless] iwlwifi: dbg: support multiple dumps in legacy dump flow (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move API version lookup to common code (Jarod Wilson) [1860496]
- [wireless] iwlwifi: nvm: use iwl_nl80211_band_from_channel_idx (Jarod Wilson) [1860496]
- [net] mac80211: fix two missing documentation entries (Jarod Wilson) [1860496]
- [net] cfg80211: reject channels/chandefs with KHz offset >= 1000 (Jarod Wilson) [1860496]
- [net] mac80211: add freq_offset to RX status (Jarod Wilson) [1860496]
- [net] mac80211: handle channel frequency offset (Jarod Wilson) [1860496]
- [net] cfg80211: express channels with a KHz component (Jarod Wilson) [1860496]
- [net] ieee80211: share 802.11 unit conversion helpers (Jarod Wilson) [1860496]
- [net] mac80211: minstrel_ht_assign_best_tp_rates: remove redundant test (Jarod Wilson) [1860496]
- [net] mac80211: Fail association when AP has no legacy rates (Jarod Wilson) [1860496]
- [net] mac80211: agg-tx: add an option to defer ADDBA transmit (Jarod Wilson) [1860496]
- [net] mac80211: agg-tx: refactor sending addba (Jarod Wilson) [1860496]
- [net] mac80211: Skip entries with HE membership selector (Jarod Wilson) [1860496]
- [net] cfg80211: Parse HE membership selector (Jarod Wilson) [1860496]
- [net] mac80211: Don't destroy auth data in case of anti-clogging (Jarod Wilson) [1860496]
- [net] mac80211: add twt_protected flag to the bss_conf structure (Jarod Wilson) [1860496]
- [net] mac80211: implement Operating Mode Notification extended NSS support (Jarod Wilson) [1860496]
- [net] mac80211: Process multicast RX registration for Action frames (Jarod Wilson) [1860496]
- [net] nl80211: allow client-only BIGTK support (Jarod Wilson) [1860496]
- [net] cfg80211: support multicast RX registration (Jarod Wilson) [1860496]
- [net] cfg80211: change internal management frame registration API (Jarod Wilson) [1860496]
- [net] mac80211: Report beacon protection failures to user space (Jarod Wilson) [1860496]
- [net] cfg80211: Unprotected Beacon frame RX indication (Jarod Wilson) [1860496]
- [wireless] iwlwifi: scan: remove support for fw scan api v13 (Jarod Wilson) [1860496]
- [net] mac80211: fix drv_config_iface_filter() behaviour (Jarod Wilson) [1860496]
- [net] mac80211: mlme: remove duplicate AID bookkeeping (Jarod Wilson) [1860496]
- [wireless] ath10k: drop the TX packet which size exceed credit size for sdio (Jarod Wilson) [1860496]
- [wireless] ath10k: Fix the invalid tx/rx chainmask configuration (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: initialize mac/bb/rf basic functions (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Organize chip TX/RX FIFO (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: implement set_tx_power_index ops (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: 11N chips don't support H2C queue (Jarod Wilson) [1860496]
- [wireless] rtw88: decompose while(1) loop of power sequence polling command (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add mac power-on/-off function (Jarod Wilson) [1860496]
- [wireless] rtw88: no need to send additional information to legacy firmware (Jarod Wilson) [1860496]
- [wireless] rtw88: add legacy firmware download for 8723D devices (Jarod Wilson) [1860496]
- [wireless] ath10k: add flush tx packets for SDIO chip (Jarod Wilson) [1860496]
- [wireless] ath10k: enable alt data of TX path for sdio (Jarod Wilson) [1860496]
- [wireless] ath10k: add htt TX bundle for sdio (Jarod Wilson) [1860496]
- [wireless] ath11k: remove conversion to bool in ath11k_debug_fw_stats_process() (Jarod Wilson) [1860496]
- [wireless] ath11k: remove conversion to bool in ath11k_dp_rxdesc_mpdu_valid() (Jarod Wilson) [1860496]
- [wireless] rtw88: set power trim according to efuse PG values (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add read_efuse to recognize efuse info from map (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add new chip op efuse_grant() to control efuse access (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add cfg_ldo25 to control LDO25 (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add mac/bb/rf/agc/power_limit tables (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add RF read/write ops (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add power sequence (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: add beamform wrapper functions (Jarod Wilson) [1860496]
- [wireless] rtw88: 8723d: Add basic chip capabilities (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8723ae: fix warning comparison to bool (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8821ae: use true, false for bool variables (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8723be: use true, false for bool variables (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8192ee: use true, false for bool variables (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8723ae: use true, false for bool variables (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8188ee: use true, false for bool variables (Jarod Wilson) [1860496]
- [wireless] ath10k: hif: make send_complete_check op optional (Jarod Wilson) [1860496]
- [wireless] ath10k: sdio: remove _hif_ prefix from functions not part of hif interface (Jarod Wilson) [1860496]
- [wireless] ath10k: improve power save performance for sdio (Jarod Wilson) [1860496]
- [wireless] ath10k: rename ath10k_hif_swap_mailbox() to ath10k_hif_start_post() (Jarod Wilson) [1860496]
- [wireless] brcmfmac: remove leading space (Jarod Wilson) [1860496]
- [wireless] brcmsmac: make brcms_c_stf_ss_update() void (Jarod Wilson) [1860496]
- [wireless] brcmsmac: Add missing annotation for brcms_down() (Jarod Wilson) [1860496]
- [wireless] brcmsmac: Add missing annotation for brcms_rfkill_set_hw_state() (Jarod Wilson) [1860496]
- [wireless] hostap: Add missing annotations for prism2_bss_list_proc_start() and prism2_bss_list_proc_stop (Jarod Wilson) [1860496]
- [wireless] rtw88: add support for set/get antennas (Jarod Wilson) [1860496]
- [wireless] rtw88: make rtw_chip_ops::set_antenna return int (Jarod Wilson) [1860496]
- [wireless] ath11k: Add dynamic tcl ring selection logic with retry mechanism (Jarod Wilson) [1860496]
- [wireless] ath11k: cleanup reo command error code overwritten (Jarod Wilson) [1860496]
- [wireless] ath10k: Fix typo in warning messages (Jarod Wilson) [1860496]
- [wireless] ath11k: Fix rx_filter flags setting for per peer rx_stats (Jarod Wilson) [1860496]
- [wireless] ath11k: Fix fw assert by setting proper vht cap (Jarod Wilson) [1860496]
- [wireless] ath11k: Cleanup in pdev destroy and mac register during crash on recovery (Jarod Wilson) [1860496]
- [wireless] brcmsmac: make brcms_c_set_mac() void (Jarod Wilson) [1860496]
- [wireless] rtw88: Add delay on polling h2c command status bit (Jarod Wilson) [1860496]
- [wireless] brcm80211: remove redundant pointer 'address' (Jarod Wilson) [1860496]
- [wireless] rtlwifi: rtl8723ae: fix spelling mistake "chang" -> "change" (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix wrong location to get firmware feature (Jarod Wilson) [1860496]
- [wireless] rtw88: Make two functions static (Jarod Wilson) [1860496]
- [net] cfg80211: fix kernel-doc notation (Jarod Wilson) [1860496]
- [wireless] ath11k: rx path optimizations (Jarod Wilson) [1860496]
- [wireless] ath11k: set IRQ_DISABLE_UNLAZY flag for DP interrupts (Jarod Wilson) [1860496]
- [wireless] ath11k: Fix TWT radio count (Jarod Wilson) [1860496]
- [wireless] ath11k: Modify the interrupt timer threshold (Jarod Wilson) [1860496]
- [wireless] ath11k: fix duplication peer create on same radio (Jarod Wilson) [1860496]
- [wireless] ath10k: change ATH10K_SDIO_BUS_REQUEST_MAX_NUM from 64 to 1024 (Jarod Wilson) [1860496]
- [wireless] ath10k: disable TX complete indication of htt for sdio (Jarod Wilson) [1860496]
- [wireless] ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb (Jarod Wilson) [1860496]
- [wireless] ath9x: Fix stack-out-of-bounds Write in ath9k_hif_usb_rx_cb (Jarod Wilson) [1860496]
- [wireless] ath9k: Fix use-after-free Write in ath9k_htc_rx_msg (Jarod Wilson) [1860496]
- [wireless] ath9k: Fix use-after-free Read in ath9k_wmi_ctrl_rx (Jarod Wilson) [1860496]
- [wireless] ath9k: Fix use-after-free Read in htc_connect_service (Jarod Wilson) [1860496]
- [wireless] ath10k: fix kernel null pointer dereference (Jarod Wilson) [1860496]
- [wireless] ath10k: enable radar detection in secondary segment (Jarod Wilson) [1860496]
- [wireless] ath10k: enable VHT160 and VHT80+80 modes (Jarod Wilson) [1860496]
- [wireless] ath11k: Avoid mgmt tx count underflow (Jarod Wilson) [1860496]
- [wireless] ath11k: Increase the tx completion ring size (Jarod Wilson) [1860496]
- [wireless] ath11k: fix error message to correctly report the command that failed (Jarod Wilson) [1860496]
- [wireless] ath11k: add pktlog checksum in trace events to support pktlog (Jarod Wilson) [1860496]
- [wireless] ath10k: Fix the race condition in firmware dump work queue (Jarod Wilson) [1860496]
- [wireless] ath11k: Add sta debugfs support to configure ADDBA and DELBA (Jarod Wilson) [1860496]
- [wireless] ath11k: fix compiler warnings without CONFIG_THERMAL (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: remove newline from rs_pretty_print_rate() (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: make iwl_pcie_cmdq_reclaim static (Jarod Wilson) [1860496]
- [wireless] iwlwifi: bump FW API to 53 for 22000 series (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove IWL_FW_DBG_DOMAIN macro (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: enable yoyo by default (Jarod Wilson) [1860496]
- [wireless] iwlwifi: scan: support FW APIs with variable number of profiles (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: don't block dumping internal memory when not in SRAM mode (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove support for QnJ HR FPGA (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove support for QnJ Hr STEP A (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add trans_cfg for devices with long latency (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add support for version 2 of SOC_CONFIGURATION_CMD (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add support for non EDCA based measurements (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove unnecessary cfg mangling for Qu C and QuZ with Jf (Jarod Wilson) [1860496]
- [wireless] iwlwifi: convert QnJ with Jf devices to new config table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: convert all Qu with Jf devices to the new config table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add HW step to new cfg device table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove some unused extern declarations from iwl-config.h (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move integrated, extra_phy and soc_latency to trans_cfg (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: enable SF also when we have HE (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove redundant iwl9560_2ac_cfg struct (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: rs-fw: fix some indentation (Jarod Wilson) [1860496]
- [wireless] iwlwifi: scan: support scan req cmd ver 14 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pass trans and NVM data to HE capability parsing (Jarod Wilson) [1860496]
- [wireless] iwlwifi: pcie: implement read_config32 (Jarod Wilson) [1860496]
- [wireless] iwlwifi: yoyo: add PCI config space region type (Jarod Wilson) [1860496]
- [wireless] iwlwifi: mvm: add soc latency support (Jarod Wilson) [1860496]
- [wireless] hostap: convert to struct proc_ops (Jarod Wilson) [1860496]
- [wireless] rtw88: fix non-increase management packet sequence number (Jarod Wilson) [1860496]
- [wireless] brcmfmac: add USB autosuspend feature support (Jarod Wilson) [1860496]
- [wireless] brcmfmac: increase max hanger slots from 1K to 3K in fws layer (Jarod Wilson) [1860496]
- [wireless] brcmfmac: fix the incorrect return value in brcmf_inform_single_bss() (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Fix double freeing in the fmac usb data path (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Fix driver crash on USB control transfer timeout (Jarod Wilson) [1860496]
- [wireless] rtl8xxxu: Feed current txrate information for mac80211 (Jarod Wilson) [1860496]
- [wireless] rtl8xxxu: add enumeration for channel bandwidth (Jarod Wilson) [1860496]
- [wireless] rtw88: add a debugfs entry to enable/disable coex mechanism (Jarod Wilson) [1860496]
- [wireless] rtw88: add a debugfs entry to dump coex's info (Jarod Wilson) [1860496]
- [wireless] rtl8xxxu: Fix sparse warning: cast from restricted __le16 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add missing declaration in mt7615.h (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix endianness in unified command (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix mt7663e firmware struct endianness (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: config RF table path B before path A (Jarod Wilson) [1860496]
- [wireless] rtw88: kick off TX packets once for higher efficiency (Jarod Wilson) [1860496]
- [wireless] rtw88: pci: define a mask for TX/RX BD indexes (Jarod Wilson) [1860496]
- [wireless] rtw88: associate reserved pages with each vif (Jarod Wilson) [1860496]
- [wireless] rtw88: extract alloc rsvd_page and h2c skb routines (Jarod Wilson) [1860496]
- [wireless] brcmfmac: Replace zero-length array with flexible-array member (Jarod Wilson) [1860496]
- [wireless] wireless: marvell: Replace zero-length array with flexible-array member (Jarod Wilson) [1860496]
- [wireless] hostap: Replace zero-length array with flexible-array member (Jarod Wilson) [1860496]
- [wireless] wireless: ti: Replace zero-length array with flexible-array member (Jarod Wilson) [1860496]
- [wireless] wireless: realtek: Replace zero-length array with flexible-array member (Jarod Wilson) [1860496]
- [wireless] ath10k: Fill GCMP MIC length for PMF (Jarod Wilson) [1860496]
- [net] mac80211: driver can remain on channel if not using chan_ctx (Jarod Wilson) [1860496]
- [net] nl80211: clarify code in nl80211_del_station() (Jarod Wilson) [1860496]
- [net] cfg80211: Configure PMK lifetime and reauth threshold for PMKSA entries (Jarod Wilson) [1860496]
- [net] mac80211: Read rx_stats with perCPU pointers (Jarod Wilson) [1860496]
- [net] mac80211: Allow deleting stations in ibss mode to reset their state (Jarod Wilson) [1860496]
- [net] cfg80211: Add support for userspace to reset stations in IBSS mode (Jarod Wilson) [1860496]
- [net] mac80211: consider WLAN_EID_EXT_HE_OPERATION for parsing CRC (Jarod Wilson) [1860496]
- [uapi] nl80211: add PROTECTED_TWT nl80211 extended feature (Jarod Wilson) [1860496]
- [net] mac80211: HE: set missing bss_conf fields in AP mode (Jarod Wilson) [1860496]
- [net] nl80211: pass HE operation element to the driver (Jarod Wilson) [1860496]
- [net] nl80211/cfg80211: add support for non EDCA based ranging measurement (Jarod Wilson) [1860496]
- [net] mac80211: don't leave skb->next/prev pointing to stack (Jarod Wilson) [1860496]
- [net] mac80211: update documentation about tx power (Jarod Wilson) [1860496]
- [net] mac80211: handle no-preauth flag for control port (Jarod Wilson) [1860496]
- [net] nl80211: add no pre-auth attribute and ext. feature flag for ctrl. port (Jarod Wilson) [1860496]
- [net] cfg80211: fix documentation format (Jarod Wilson) [1860496]
- [wireless] ath11k: Perform per-msdu rx processing (Jarod Wilson) [1860496]
- [wireless] ath11k: Configure hash based reo destination ring selection (Jarod Wilson) [1860496]
- [wireless] ath11k: Adding proper validation before accessing tx_stats (Jarod Wilson) [1860496]
- [wireless] ath11k: dump SRNG stats during FW assert (Jarod Wilson) [1860496]
- [wireless] ath11k: fill channel info from rx channel (Jarod Wilson) [1860496]
- [wireless] ath11k: Supporting RX ring backpressure HTT event and stats handling (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move AX200 devices to the new table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove trans entries from COMMON 9260 macro (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move shared clock entries to new table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move pu devices to new table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: remove 9260 devices with 0x1010 and 0x1210 subsytem IDs (Jarod Wilson) [1860496]
- [wireless] iwlwifi: convert the 9260-1x1 device to use the new parameters (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move TH1 devices to the new table (Jarod Wilson) [1860496]
- [wireless] iwlwifi: map 9461 and 9462 using RF type and RF ID (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add Pu/PnJ/Th device values to differentiate them (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add GNSS differentiation to the device tables (Jarod Wilson) [1860496]
- [wireless] iwlwifi: add mac/rf types and 160MHz to the device tables (Jarod Wilson) [1860496]
- [wireless] iwlwifi: combine 9260 cfgs that only change names (Jarod Wilson) [1860496]
- [wireless] iwlwifi: move the remaining 0x2526 configs to the new table (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7663e support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: get rid of sta_rec_wtbl data structure (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce set_ba uni command (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add more uni mcu commands (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce set_bmc and st_sta for uni commands (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce uni cmd command types (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_init_mac_chain routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_eeprom_parse_hw_band_cap routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add mt7663e support to mt7615_mcu_set_eeprom (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add mt7663e support to mt7615_{driver, firmware}_own (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add mt7663e support to mt7615_reg_map (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_register_map (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce MCU_FW_PREFIX for fw mcu commands (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move more mcu commands in mt7615_mcu_ops data structure (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework mt7615_mcu_set_bss_info using skb APIs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rely on skb API for mt7615_mcu_set_eeprom (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move mt7615_mcu_set_sta in mt7615_mcu_ops (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move mt7615_mcu_set_bmc to mt7615_mcu_ops (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add mt7615_mcu_ops data structure (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mcu_send_message routine (Jarod Wilson) [1860496]
- [wireless] mt76: always init to 0 mcu messages (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_init_device routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: cleanup fw queue just for mmio devices (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mcu_wait_response (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce mt7615_mcu_fill_msg (Jarod Wilson) [1860496]
- [wireless] mt76: remove variable 'val' set but not used (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: remove a stray if statement (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: reset MCU timeout counter earlier in watchdog reset (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix monitor injection of beacon frames (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: make dynamic sensitivity adjustment configurable via debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: add upper limit for dynamic sensitivity minimum receive power (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix antenna mask initialization in DBDC mode (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: rely only on data buffer for usb control messagges (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: fix a possible memory leak in mt76u_init (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: loop over all possible rx queues in mt76u_rx_tasklet (Jarod Wilson) [1860496]
- [wireless] ath11k: add handling for BSS color (Jarod Wilson) [1860496]
- [wireless] ath11k: add WMI calls required for handling BSS color (Jarod Wilson) [1860496]
- [wireless] ath11k: set queue_len to 4096 (Jarod Wilson) [1860496]
- [wireless] ath11k: enable PN offload (Jarod Wilson) [1860496]
- [wireless] ath11k: handle RX fragments (Jarod Wilson) [1860496]
- [wireless] rtw88: remove unused member of struct rtw_hal (Jarod Wilson) [1860496]
- [wireless] ath5k: Use scnprintf() for avoiding potential buffer overflow (Jarod Wilson) [1860496]
- [wireless] ath11k: Use scnprintf() for avoiding potential buffer overflow (Jarod Wilson) [1860496]
- [wireless] ath10k: allow qca988x family to support ack rssi of tx data packets (Jarod Wilson) [1860496]
- [wireless] ath5k: Add proper dependency for ATH5K_AHB (Jarod Wilson) [1860496]
- [wireless] ath11k: add thermal sensor device support (Jarod Wilson) [1860496]
- [wireless] ath11k: add thermal cooling device support (Jarod Wilson) [1860496]
- [wireless] ath10k: fix not registering airtime of 11a station with WMM disable (Jarod Wilson) [1860496]
- [wireless] ath11k: config reorder queue for all tids during peer setup (Jarod Wilson) [1860496]
- [wireless] ath10k: fix unsupported chip reset debugs file write (Jarod Wilson) [1860496]
- [wireless] ath10k: use kzalloc to read for ath10k_sdio_hif_diag_read (Jarod Wilson) [1860496]
- [wireless] ath10k: start recovery process when read int status fail for sdio (Jarod Wilson) [1860496]
- [wireless] ath10k: add QCA9377 sdio hw_param item (Jarod Wilson) [1860496]
- [wireless] ath10k: avoid consecutive OTP download to reduce boot time (Jarod Wilson) [1860496]
- [net] mac80211: Add api to support configuring TID specific configuration (Jarod Wilson) [1860496]
- [net] nl80211: Add support to configure TID specific RTSCTS configuration (Jarod Wilson) [1860496]
- [net] nl80211: Add support to configure TID specific AMPDU configuration (Jarod Wilson) [1860496]
- [net] nl80211: Add support to configure TID specific retry configuration (Jarod Wilson) [1860496]
- [net] nl80211: modify TID-config API (Jarod Wilson) [1860496]
- [net] nl80211: Add NL command to support TID speicific configurations (Jarod Wilson) [1860496]
- [net] mac80211: Beacon protection using the new BIGTK (STA) (Jarod Wilson) [1860496]
- [net] mac80211: Beacon protection using the new BIGTK (AP) (Jarod Wilson) [1860496]
- [net] mac80211: Update BIP to support Beacon frames (Jarod Wilson) [1860496]
- [net] mac80211: Support BIGTK configuration for Beacon protection (Jarod Wilson) [1860496]
- [net] cfg80211: Support key configuration for Beacon protection (BIGTK) (Jarod Wilson) [1860496]
- [net] cfg80211: More error messages for key addition failures (Jarod Wilson) [1860496]
- [net] cfg80211: fix indentation errors (Jarod Wilson) [1860496]
- [net] cfg80211: merge documentations of field "dev" (Jarod Wilson) [1860496]
- [net] cfg80211: merge documentations of field "debugfsdir" (Jarod Wilson) [1860496]
- [net] cfg80211: drop duplicated documentation of field "reg_notifier" (Jarod Wilson) [1860496]
- [net] cfg80211: drop duplicated documentation of field "perm_addr" (Jarod Wilson) [1860496]
- [net] cfg80211: drop duplicated documentation of field "_net" (Jarod Wilson) [1860496]
- [net] cfg80211: drop duplicated documentation of field "registered" (Jarod Wilson) [1860496]
- [net] cfg80211: drop duplicated documentation of field "privid" (Jarod Wilson) [1860496]
- [net] cfg80211: drop duplicated documentation of field "probe_resp_offload" (Jarod Wilson) [1860496]
- [net] Revert "nl80211: add src and dst addr attributes for control port tx/rx" (Jarod Wilson) [1860496]
- [net] Revert "mac80211: support NL80211_EXT_FEATURE_CONTROL_PORT_OVER_NL80211_MAC_ADDRS" (Jarod Wilson) [1860496]
- [net] cfg80211: remove support for adjacent channel compensation (Jarod Wilson) [1860496]
- [net] mac80211: check vif pointer before airtime calculation (Jarod Wilson) [1860496]
- [net] cfg80211: Pass lockdep expression to RCU lists (Jarod Wilson) [1860496]
- [wireless] mwifiex: change license text from MARVELL to NXP (Jarod Wilson) [1860496]
- [wireless] mt76: Introduce mt76_mcu data structure (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: remove rx_mask in mt7615_eeprom_parse_hw_cap (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: rename stat_wq in wq (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: extend RX scatter gather number (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rely on mt76_queues_read for mt7622 (Jarod Wilson) [1860496]
- [wireless] mt76: do not set HOST_BROADCAST_PS_BUFFERING for mt7615 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework rx phy index handling (Jarod Wilson) [1860496]
- [wireless] mt76: fix rounding issues on converting per-chain and combined txpower (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2: avoid starting the MAC too early (Jarod Wilson) [1860496]
- [wireless] mt76: avoid extra RCU synchronization on station removal (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix monitor mode on second PHY (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix adding active monitor interfaces (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: switch mt7615_mcu_set_rx_ba to v2 format (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: switch mt7615_mcu_set_tx_ba to v2 format (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: use new tag sta_rec_wtbl (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add starec operating flow for firmware v2 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add a helper to encapsulate sta_rec operation (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: simplify mcu_set_sta flow (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: simplify mcu_set_bmc flow (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for testing hardware reset (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: implement hardware reset support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: report firmware log event messages (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix and rework tx power handling (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add Kconfig entry for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: disable DBDC on MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: decrease rx ring size for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: implement DMA support for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: implement probing and firmware loading on MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: disable 5 GHz on MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add calibration free support for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add eeprom support for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add dma and tx queue initialization for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix MT_INT_TX_DONE_ALL definition for MT7622 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: store N9 firmware version instead of CR4 (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: split up firmware loading functions (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move mmio related code from pci.c to mmio.c (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add __aligned(4) to txp structs (Jarod Wilson) [1860496]
- [wireless] mt76: enable Airtime Queue Limit support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: increase dma mcu rx ring size (Jarod Wilson) [1860496]
- [wireless] mt76: dma: do not write cpu_idx on rx queue reset until after refill (Jarod Wilson) [1860496]
- [wireless] mt76: fix handling full tx queues in mt76_dma_tx_queue_skb_raw (Jarod Wilson) [1860496]
- [wireless] mt76: set dma-done flag for flushed descriptors (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: introduce MT_DRV_RX_DMA_HDR flag (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add endpoint to mt76u_bulk_msg signature (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: introduce mt76u_skb_dma_info routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: take into account different queue mapping for 7663 (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add {read/write}_extended utility routines (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: introduce mt76u_alloc_mcu_queue utility routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: resume all rx queue in mt76u_resume_rx (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add queue parameter to mt76u_rx_urb_alloc (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add mt76u_alloc_rx_queue utility routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: stop/free all possible rx queues (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: introduce mt76u_free_rx_queue utility routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: move mcu buffer allocation in mt76x02u drivers (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add queue id parameter to mt76u_submit_rx_buffers (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: use mt76_queue as mt76u_complete_rx context (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add mt76_queue to mt76u_refill_rx signature (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add mt76_queue to mt76u_get_next_rx_entry signature (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: add mt76u_process_rx_queue utility routine (Jarod Wilson) [1860496]
- [wireless] mt76: mt76u: check tx_status_data pointer in mt76u_tx_tasklet (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02u: avoid overwrite max_tx_fragments (Jarod Wilson) [1860496]
- [wireless] mt76: rely on mac80211 utility routines to compute airtime (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: remove leftover routine declaration (Jarod Wilson) [1860496]
- [wireless] mt76: move WIPHY_FLAG_HAS_CHANNEL_SWITCH in mt76_phy_init (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix endianness in mt7615_mcu_set_eeprom (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: initialize radar specs from host driver (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x2: get rid of leftover target (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add tracing support (Jarod Wilson) [1860496]
- [wireless] mt76: move mac_txdone tracepoint in mt76 module (Jarod Wilson) [1860496]
- [wireless] mt76: move dev_irq tracepoint in mt76 module (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add a get_stats() callback (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add per-phy mib statistics (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: report TSF information (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add set_antenna callback (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework set_channel function (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add missing settings for simultaneous dual-band support (Jarod Wilson) [1860496]
- [wireless] mt76: fix compilation warning in mt76_eeprom_override() (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: simplify led reg definitions (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: simplify led reg definitions (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: introduce LED support (Jarod Wilson) [1860496]
- [wireless] mt76: clear skb pointers from rx aggregation reorder buffer during cleanup (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: fix input validation issues for powersave-filtered frames (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: increase MCU command timeout (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: measure channel noise and report it via survey (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: fix MT7615_CFEND_RATE_DEFAULT value (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: minor mt76x02_mac_set_beacon optimization (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02u: do not set NULL beacons (Jarod Wilson) [1860496]
- [wireless] mt76: usb: use max packet length for m76u_copy (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: add channel switch support for usb interfaces (Jarod Wilson) [1860496]
- [wireless] mt76: speed up usb bulk copy (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: remove a copy call for usb speedup (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: add check for invalid vif idx (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: split beaconing (Jarod Wilson) [1860496]
- [wireless] mt76: mt76x02: omit beacon slot clearing (Jarod Wilson) [1860496]
- [wireless] mt76: use AC specific reorder timeout (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add set_coverage class support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: set 0 as min coverage_class value (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: report firmware version using ethtool (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: Fix build with older compilers (Jarod Wilson) [1860496]
- [wireless] mt76: eeprom: add support for big endian eeprom partition (Jarod Wilson) [1860496]
- [wireless] mt76: mt7603: reset STA_CCA counter setting the channel (Jarod Wilson) [1860496]
- [wireless] mt76: fix possible undetected invalid MAC address (Jarod Wilson) [1860496]
- [wireless] mt76: disable bh in mt76_dma_rx_poll (Jarod Wilson) [1860496]
- [wireless] mt76: fix rx dma ring descriptor state on reset (Jarod Wilson) [1860496]
- [wireless] mt7615: replace sta_state callback with sta_add/sta_remove (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: defer mcu initialization via workqueue (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: update beacon contents on BSS_CHANGED_BEACON (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add support for registering a second wiphy via debugfs (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: select the correct tx queue for frames sent to the second phy (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: move radio/mac initialization to .start/stop callbacks (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: initialize dbdc settings on interface add (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add multiple wiphy support to the rx path (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: rework chainmask handling (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add multiple wiphy support to the dfs support code (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: remove useless MT_HW_RDD0/1 enum (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add missing register init for dual-wiphy support (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add multiple wiphy support for smart carrier sense (Jarod Wilson) [1860496]
- [wireless] mt76: mt7615: add dual-phy support for mac80211 ops (Jarod Wilson) [1860496]
- [wireless] mt76: do not overwrite max_tx_fragments if it has been set (Jarod Wilson) [1860496]
- [wireless] mt76: move ampdu_ref from mt76_dev to driver struct (Jarod Wilson) [1860496]
- [wireless] mt76: add ext_phy field to struct mt76_wcid (Jarod Wilson) [1860496]
- [wireless] mt76: add function for allocating an extra wiphy (Jarod Wilson) [1860496]
- [wireless] mt76: add priv pointer to struct mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: add multiple wiphy support to mt76_get_min_avg_rssi (Jarod Wilson) [1860496]
- [wireless] mt76: move txpower and antenna mask to struct mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: move txpower_conf back to driver specific structs (Jarod Wilson) [1860496]
- [wireless] mt76: move chainmask back to driver specific structs (Jarod Wilson) [1860496]
- [wireless] mt76: move state from struct mt76_dev to mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: keep a set of software tx queues per phy (Jarod Wilson) [1860496]
- [wireless] mt76: move channel state to struct mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: add support for an extra wiphy in mt76_sta_state() (Jarod Wilson) [1860496]
- [wireless] mt76: add support for an extra wiphy in the tx status path (Jarod Wilson) [1860496]
- [net] mac80211: allow setting queue_len for drivers not using wake_tx_queue (Jarod Wilson) [1860496]
- [include] ieee80211: add WPA3 OWE AKM suite selector (Jarod Wilson) [1860496]
- [wireless] mac80211: Fix setting txpower to zero (Jarod Wilson) [1860496]
- [wireless] mt76: add support for an extra wiphy in the main tx path (Jarod Wilson) [1860496]
- [wireless] mt76: add support for an extra wiphy in the rx path (Jarod Wilson) [1860496]
- [wireless] mt76: introduce struct mt76_phy (Jarod Wilson) [1860496]
- [wireless] mt76: move initialization of some struct members to mt76_alloc_device (Jarod Wilson) [1860496]
- [wireless] rtw88: Fix incorrect beamformee role setting (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822: Make tables const, reduce data object size (Jarod Wilson) [1860496]
- [wireless] rtw88: disable TX-AMSDU on 2.4G band (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: modify rf protection setting (Jarod Wilson) [1860496]
- [wireless] rtw88: Use secondary channel offset enumeration (Jarod Wilson) [1860496]
- [wireless] rtw88: 8822c: update power sequence to v16 (Jarod Wilson) [1860496]
- [wireless] rtw88: add ciphers to suppress error message (Jarod Wilson) [1860496]
- [wireless] rtw88: avoid holding mutex for cancel_delayed_work_sync() (Jarod Wilson) [1860496]
- [wireless] rtw88: move rtw_enter_ips() to the last when config (Jarod Wilson) [1860496]
- [wireless] rtw88: pci: 8822c should set clock delay to zero (Jarod Wilson) [1860496]
- [wireless] rtw88: add rtw_read8_mask and rtw_read16_mask (Jarod Wilson) [1860496]
- [wireless] rtw88: remove unused parameter vif in rtw_lps_pg_info_get() (Jarod Wilson) [1860496]
- [wireless] brcmfmac: add the BRCM 4364 found in MacBook Pro 15, 2 (Jarod Wilson) [1860496]
- [wireless] ath11k: fix incorrect peer stats counters update (Jarod Wilson) [1860496]
- [wireless] ath11k: Fixing dangling pointer issue upon peer delete failure (Jarod Wilson) [1860496]
- [wireless] ath11k: fix parsing PPDU_CTRL type in pktlog (Jarod Wilson) [1860496]
- [wireless] ath11k: fix warn-on in disassociation (Jarod Wilson) [1860496]
- [wireless] ath11k: fix rcu lock protect in peer assoc confirmation (Jarod Wilson) [1860496]
- [wireless] ath11k: add HE rate accounting to driver (Jarod Wilson) [1860496]
- [wireless] ath11k: drop tx_info from ath11k_sta (Jarod Wilson) [1860496]
- [wireless] ath10k: Add support to read btcoex related data from DT (Jarod Wilson) [1860496]
- [wireless] ath10k: fix few checkpatch warnings (Jarod Wilson) [1860496]
- [net] mac80211: support NL80211_EXT_FEATURE_CONTROL_PORT_OVER_NL80211_MAC_ADDRS (Jarod Wilson) [1860496]
- [net] nl80211: add src and dst addr attributes for control port tx/rx (Jarod Wilson) [1860496]
- [net] mac80211: parse also the RSNXE IE (Jarod Wilson) [1860496]
- [net] cfg80211/mac80211: Allow user space to register for station Rx authentication (Jarod Wilson) [1860496]
- [include] ieee80211: fix 'the' doubling in comments (Jarod Wilson) [1860496]
- [net] mac80211: Remove support for changing AP SMPS mode (Jarod Wilson) [1860496]
- [net] mac80211: Handle SMPS mode changes only in AP mode (Jarod Wilson) [1860496]
- [net] mac80211: Accept broadcast probe responses on 6GHz band (Jarod Wilson) [1860496]
- [net] mac80211: HE: set RX NSS (Jarod Wilson) [1860496]
- [net] mac80211: set station bandwidth from HE capability (Jarod Wilson) [1860496]
- [net] mac80211: remove supported channels element in 6 GHz if ECSA support (Jarod Wilson) [1860496]
- [net] mac80211: update condition for HE disablement (Jarod Wilson) [1860496]
- [net] mac80211: make ieee80211_wep_init() return void (Jarod Wilson) [1860496]
- [net] mac80211: allow changing TX-related netdev features (Jarod Wilson) [1860496]
- [net] mac80211: check whether HE connection is allowed by the reg domain (Jarod Wilson) [1860496]
- [net] mac80211: refactor extended element parsing (Jarod Wilson) [1860496]
- [net] mac80211: simplify and improve HT/VHT/HE disable code (Jarod Wilson) [1860496]
- [net] cfg80211: Enhance the AKM advertizement to support per interface (Jarod Wilson) [1860496]
- [net] cfg80211: add no HE indication to the channel flag (Jarod Wilson) [1860496]
- [net] mac80211: fix 11w when using encapsulation offloading (Jarod Wilson) [1860496]
- [net] mac80211: fix tx status for no ack cases (Jarod Wilson) [1860496]
- [net] mac80211: add handling for BSS color (Jarod Wilson) [1860496]
- [net] nl80211: add handling for BSS color (Jarod Wilson) [1860496]
- [net] mac80211: debugfs: improve airtime_flags handler readability (Jarod Wilson) [1860496]
- [net] mac80211: Remove redundant assertion (Jarod Wilson) [1860496]
- [net] mac80211: add 802.11 encapsulation offloading support (Jarod Wilson) [1860496]
- [net] mac80211: Always show airtime debugfs file when TXQs are enabled (Jarod Wilson) [1860496]
- [include] trivial: mac80211: fix indentation (Jarod Wilson) [1860496]

* Thu Dec 31 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-269.el8]
- [fs] xfs: force writes to delalloc regions to unwritten (Carlos Maiolino) [1696580]
- [fs] xfs: refactor xfs_iomap_prealloc_size (Carlos Maiolino) [1696580]
- [fs] xfs: measure all contiguous previous extents for prealloc size (Carlos Maiolino) [1696580]
- [fs] xfs: don't fail unwritten extent conversion on writeback due to edquot (Carlos Maiolino) [1696580]
- [trace] SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow() (Dave Wysochanski) [1906309]
- [trace] Revert "SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow()" (Dave Wysochanski) [1906309]
- [uapi] uapi: fix statx attribute value overlap for DAX & MOUNT_ROOT (Eric Sandeen) [1905205]
- [trace] SUNRPC: Fix oops in the rpc_xdr_buf event class (Scott Mayhew) [1900157]
- [fs] NFS: Fix listxattr receive buffer size (Scott Mayhew) [1900157]
- [trace] SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow() (Scott Mayhew) [1900157]
- [net] SUNRPC: fix copying of multiple pages in gss_read_proxy_verf() (Scott Mayhew) [1900157]
- [net] svcrdma: fix bounce buffers for unaligned offsets and multiple pages (Scott Mayhew) [1900157]
- [pci] hv: Document missing hv_pci_protocol_negotiation() parameter (Mohammed Gamal) [1886102]
- [pci] hv: Make some functions static (Mohammed Gamal) [1886102]
- [pci] hv: Use struct_size() helper (Mohammed Gamal) [1886102]
- [pci] hv: Prepare hv_compose_msi_msg() for the VMBus-channel-interrupt-to-vCPU reassignment functionality (Mohammed Gamal) [1886102]
- [fs] xfs: allow individual quota grace period extension (Bill O'Donnell) [1827913]
- [fs] xfs: per-type quota timers and warn limits (Bill O'Donnell) [1827913]
- [fs] xfs: switch xfs_get_defquota to take explicit type (Bill O'Donnell) [1827913]
- [fs] xfs: pass xfs_dquot to xfs_qm_adjust_dqtimers (Bill O'Donnell) [1827913]
- [fs] xfs: fix up some whitespace in quota code (Bill O'Donnell) [1827913]
- [fs] xfs: preserve default grace interval during quotacheck (Bill O'Donnell) [1827913]
- [fs] quota: honor quota type in Q_XGETQSTATcalls (Bill O'Donnell) [1827913]

* Mon Dec 28 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-268.el8]
- [fs] NFS: Do uncached readdir when we're seeking a cookie in an empty page cache (Dave Wysochanski) [1893882]
- [fs] NFS: Reduce number of RPC calls when doing uncached readdir (Dave Wysochanski) [1893882]
- [fs] NFS: Optimisations for monotonically increasing readdir cookies (Dave Wysochanski) [1893882]
- [fs] NFS: Improve handling of directory verifiers (Dave Wysochanski) [1893882]
- [fs] NFS: Handle NFS4ERR_NOT_SAME and NFSERR_BADCOOKIE from readdir calls (Dave Wysochanski) [1893882]
- [fs] NFS: Allow the NFS generic code to pass in a verifier to readdir (Dave Wysochanski) [1893882]
- [fs] NFS: Cleanup to remove nfs_readdir_descriptor_t typedef (Dave Wysochanski) [1893882]
- [fs] NFS: Reduce readdir stack usage (Dave Wysochanski) [1893882]
- [fs] NFS: nfs_do_filldir() does not return a value (Dave Wysochanski) [1893882]
- [fs] NFS: More readdir cleanups (Dave Wysochanski) [1893882]
- [fs] NFS: Support larger readdir buffers (Dave Wysochanski) [1893882]
- [fs] NFS: Simplify struct nfs_cache_array_entry (Dave Wysochanski) [1893882]
- [fs] NFS: Replace kmap() with kmap_atomic() in nfs_readdir_search_array() (Dave Wysochanski) [1893882]
- [fs] NFS: Remove unnecessary kmap in nfs_readdir_xdr_to_array() (Dave Wysochanski) [1893882]
- [fs] NFS: Don't discard readdir results (Dave Wysochanski) [1893882]
- [fs] NFS: Clean up directory array handling (Dave Wysochanski) [1893882]
- [fs] NFS: Clean up nfs_readdir_page_filler() (Dave Wysochanski) [1893882]
- [fs] NFS: Clean up readdir struct nfs_cache_array (Dave Wysochanski) [1893882]
- [fs] NFS: Ensure contents of struct nfs_open_dir_context are consistent (Dave Wysochanski) [1893882]
- [fs] NFSv4.2: condition READDIR's mask for security label based on LSM state (Dave Wysochanski) [1893882]
- [fs] NFS: Remove unnecessary inode lock in nfs_fsync_dir() (Dave Wysochanski) [1893882]
- [fs] NFS: Remove unnecessary inode locking in nfs_llseek_dir() (Dave Wysochanski) [1893882]
- [netdrv] net: intel: Remove in_interrupt() warnings (Ken Cox) [1838732]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Ken Cox) [1838732]
- [netdrv] ixgbevf: use generic power management (Ken Cox) [1838732]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Ken Cox) [1838732]
- [netdrv] net/intel: remove driver versions from Intel drivers (Ken Cox) [1838732]
- [iommu] vt-d: Don't dereference iommu_device if IOMMU_API is not built (Vitaly Kuznetsov) [1887216]
- [iommu] vt-d: Gracefully handle DMAR units with no supported address widths (Vitaly Kuznetsov) [1887216]
- [iommu] vt-d: Skip TE disabling on quirky gfx dedicated iommu (Vitaly Kuznetsov) [1887216]
- [netdrv] Revert "mark the intel igc driver as tech preview" (Corinna Vinschen) [1838742]
- [netdrv] net: intel: Remove in_interrupt() warnings (Corinna Vinschen) [1838742]
- [netdrv] igc: Clean up nvm_info structure (Corinna Vinschen) [1838742]
- [netdrv] igc: Reject schedules with a base_time in the future (Corinna Vinschen) [1838742]
- [netdrv] igc: Export a way to read the PTP timer (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove reset disable flag (Corinna Vinschen) [1838742]
- [netdrv] igc: Save PTP time before a reset (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove references to SYSTIMR register (Corinna Vinschen) [1838742]
- [netdrv] igc: Expose LPI counters (Corinna Vinschen) [1838742]
- [netdrv] igc: Clean RX descriptor error flags (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove timeout check from ptp_tx work (Corinna Vinschen) [1838742]
- [netdrv] igc: Don't reschedule ptp_tx work (Corinna Vinschen) [1838742]
- [netdrv] igc: Rename IGC_TSYNCTXCTL_VALID macro (Corinna Vinschen) [1838742]
- [netdrv] igc: Add new device ID's (Corinna Vinschen) [1838742]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix not considering the TX delay for timestamps (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix wrong timestamp latency numbers (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix PTP initialization (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix static checker warning (Corinna Vinschen) [1838742]
- [netdrv] igc: Clean up the hw_stats structure (Corinna Vinschen) [1838742]
- [netdrv] igc: Clean up the mac_info structure (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove ledctl_ fields from the mac_info structure (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix registers definition (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unneeded ICTXQMTC register (Corinna Vinschen) [1838742]
- [netdrv] igc: Add Receive Descriptor Minimum Threshold Count to clear HW counters (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unneeded variable (Corinna Vinschen) [1838742]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove checking media type during MAC initialization (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unneeded check for copper media type (Corinna Vinschen) [1838742]
- [netdrv] igc: Refactor the igc_power_down_link() (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove TCP segmentation TX fail counter (Corinna Vinschen) [1838742]
- [netdrv] igc: Add LPI counters (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix Rx timestamp disabling (Corinna Vinschen) [1838742]
- [netdrv] igc: Refactor igc_ptp_set_timestamp_mode() (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove UDP filter setup in PTP code (Corinna Vinschen) [1838742]
- [netdrv] igc: Check __IGC_PTP_TX_IN_PROGRESS instead of ptp_tx_skb (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove duplicate code in Tx timestamp handling (Corinna Vinschen) [1838742]
- [netdrv] igc: Clean up Rx timestamping logic (Corinna Vinschen) [1838742]
- [netdrv] igc: Add initial LTR support (Corinna Vinschen) [1838742]
- [netdrv] igc: Add initial EEE support (Corinna Vinschen) [1838742]
- [netdrv] net/intel: remove driver versions from Intel drivers (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix wrong register name (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove Sequence Error Counter (Corinna Vinschen) [1838742]
- [netdrv] igc: Add Receive Error Counter (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove symbol error counter (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix IGC_MAX_RXNFC_RULES (Corinna Vinschen) [1838742]
- [netdrv] igc: Reject NFC rules with multiple matches (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unused flags (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unused descriptor's flags (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove igc_nfc_rule_exit() (Corinna Vinschen) [1838742]
- [netdrv] igc: Change adapter->nfc_rule_lock to mutex (Corinna Vinschen) [1838742]
- [netdrv] igc: Change return type from igc_disable_nfc_rule() (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix NFC rule validation (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix NFC rules leak when driver is unloaded (Corinna Vinschen) [1838742]
- [netdrv] igc: Refactor igc_ethtool_update_nfc_rule() (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix NFC rules restoration (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix NFC rules with multicast addresses (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix NFC rule overwrite cases (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix locking issue when retrieving NFC rules (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix 'sw_idx' type in struct igc_nfc_rule (Corinna Vinschen) [1838742]
- [netdrv] igc: Refactor igc_ethtool_add_nfc_rule() (Corinna Vinschen) [1838742]
- [netdrv] igc: Change byte order in struct igc_nfc_filter (Corinna Vinschen) [1838742]
- [netdrv] igc: Align terms used in NFC support code (Corinna Vinschen) [1838742]
- [netdrv] igc: Add 'igc_ethtool_' prefix to functions in igc_ethtool.c (Corinna Vinschen) [1838742]
- [netdrv] igc: Early return in igc_get_ethtool_nfc_entry() (Corinna Vinschen) [1838742]
- [netdrv] igc: Cleanup _get|set_rxnfc ethtool ops (Corinna Vinschen) [1838742]
- [netdrv] igc: Get rid of igc_max_channels() (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unused field from igc_nfc_filter (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove per queue good transmited counter register (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove header redirection register (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove obsolete circuit breaker registers (Corinna Vinschen) [1838742]
- [netdrv] igc: Enable NFC rules based source MAC address (Corinna Vinschen) [1838742]
- [netdrv] igc: Add support for source address filters in core (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove mac_table from igc_adapter (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove IGC_MAC_STATE_SRC_ADDR flag (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unused registers (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unused IGC_ICS_DRSTA define (Corinna Vinschen) [1838742]
- [netdrv] igc: Dump ETQF registers (Corinna Vinschen) [1838742]
- [netdrv] igc: Refactor ethertype filtering code (Corinna Vinschen) [1838742]
- [netdrv] igc: Fix MAX_ETYPE_FILTER value (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove ethertype filter in PTP code (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove duplicated IGC_RXPBS macro (Corinna Vinschen) [1838742]
- [netdrv] igc: Refactor VLAN priority filtering code (Corinna Vinschen) [1838742]
- [netdrv] igc: Return -EOPNOTSUPP when VLAN mask doesn't match (Corinna Vinschen) [1838742]
- [netdrv] igc: Dump VLANPQF register (Corinna Vinschen) [1838742]
- [netdrv] igc: Rename IGC_VLAPQF macro (Corinna Vinschen) [1838742]
- [netdrv] igc: Clean up obsolete NVM defines (Corinna Vinschen) [1838742]
- [netdrv] igc: remove IGC_REMOVED function (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove PCIe Control register (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unneeded register (Corinna Vinschen) [1838742]
- [netdrv] igc: Remove unneeded definition (Corinna Vinschen) [1838742]
- [netdrv] igc: Use netdev log helpers in igc_base.c (Corinna Vinschen) [1838742]
- [netdrv] igc: Use netdev log helpers in igc_dump.c (Corinna Vinschen) [1838742]
- [netdrv] igc: Use netdev log helpers in igc_ptp.c (Corinna Vinschen) [1838742]
- [netdrv] igc: Use netdev log helpers in igc_ethtool.c (Corinna Vinschen) [1838742]
- [netdrv] igc: add support to eeprom, registers and link self-tests (Corinna Vinschen) [1838742]
- [netdrv] igc: Use netdev log helpers in igc_main.c (Corinna Vinschen) [1838742]
- [netdrv] igc: Add ECN support for TSO (Corinna Vinschen) [1838742]
- [netdrv] ionic: fix mem leak in rx_empty (Jonathan Toppins) [1892492 1887516]
- [netdrv] ionic: no rx flush in deinit (Jonathan Toppins) [1892492 1887516]
- [netdrv] ionic: clean up sparse complaints (Jonathan Toppins) [1892492 1887516]
- [netdrv] ionic: add new bad firmware error code (Jonathan Toppins) [1887516]
- [netdrv] ionic: use lif ident for filter count (Jonathan Toppins) [1887516]
- [netdrv] ionic: refill lif identity after fw_up (Jonathan Toppins) [1887516]
- [netdrv] ionic: disable all queue napi contexts on timeout (Jonathan Toppins) [1887516]
- [netdrv] ionic: check qcq ptr in ionic_qcq_disable (Jonathan Toppins) [1887516]
- [netdrv] ionic: clear linkcheck bit on alloc fail (Jonathan Toppins) [1887516]
- [netdrv] ionic: drain the work queue (Jonathan Toppins) [1887516]
- [netdrv] ionic: contiguous memory for notifyq (Jonathan Toppins) [1887516]
- [netdrv] ionic: prevent early watchdog check (Jonathan Toppins) [1887516]
- [netdrv] ionic: stop watchdog timer earlier on remove (Jonathan Toppins) [1887516 1887263]
- [netdrv] net: ionic: Remove WARN_ON(in_interrupt()) (Jonathan Toppins) [1887516]
- [netdrv] net: ionic: Replace in_interrupt() usage (Jonathan Toppins) [1887516]
- [netdrv] ionic: add DIMLIB to Kconfig (Jonathan Toppins) [1861520]
- [netdrv] ionic: add devlink firmware update (Jonathan Toppins) [1861520]
- [netdrv] ionic: update the fw update api (Jonathan Toppins) [1861520]
- [netdrv] ionic: dynamic interrupt moderation (Jonathan Toppins) [1861520]
- [netdrv] ionic: fix up debugfs after queue swap (Jonathan Toppins) [1861520]
- [netdrv] ionic: clarify boolean precedence (Jonathan Toppins) [1861520]
- [netdrv] ionic: remove unused variable (Jonathan Toppins) [1861520]
- [netdrv] ionic: clean adminq service routine (Jonathan Toppins) [1861520]
- [netdrv] ionic: clean up desc_info and cq_info structs (Jonathan Toppins) [1861520]
- [netdrv] ionic: struct reorder for faster access (Jonathan Toppins) [1861520]
- [netdrv] ionic: clean up page handling code (Jonathan Toppins) [1861520]
- [netdrv] ionic: fix txrx work accounting (Jonathan Toppins) [1861520]
- [netdrv] ionic: pull reset_queues into tx_timeout handler (Jonathan Toppins) [1861520]
- [netdrv] ionic: change queue count with no reset (Jonathan Toppins) [1861520]
- [netdrv] ionic: change the descriptor ring length without full reset (Jonathan Toppins) [1861520]
- [netdrv] ionic: change mtu without full queue rebuild (Jonathan Toppins) [1861520]
- [netdrv] ionic: use index not pointer for queue tracking (Jonathan Toppins) [1861520]
- [netdrv] ionic: reduce contiguous memory allocation requirement (Jonathan Toppins) [1861520]
- [netdrv] ionic: clean up unnecessary non-static functions (Jonathan Toppins) [1861520]
- [netdrv] ionic: rework and simplify handling of the queue stats block (Jonathan Toppins) [1861520]
- [netdrv] ionic: remove lif list concept (Jonathan Toppins) [1861520]
- [netdrv] ionic: use kcalloc for new arrays (Jonathan Toppins) [1861520]
- [netdrv] ionic: fix up a couple of debug strings (Jonathan Toppins) [1861520]
- [netdrv] ionic: set MTU floor at ETH_MIN_MTU (Jonathan Toppins) [1861520]
- [netdrv] ionic_lif: Use devm_kcalloc() in ionic_qcq_alloc() (Jonathan Toppins) [1861520]
- [netdrv] ionic: separate interrupt for Tx and Rx (Jonathan Toppins) [1861520]
- [netdrv] ionic: tx separate servicing (Jonathan Toppins) [1861520]
- [netdrv] ionic: use fewer firmware doorbells on rx fill (Jonathan Toppins) [1861520]
- [netdrv] ionic: fix memory leak of object 'lid' (Jonathan Toppins) [1861520]
- [netdrv] ionic: interface file updates (Jonathan Toppins) [1861520]
- [netdrv] ionic: rearrange reset and bus-master control (Jonathan Toppins) [1861520]
- [netdrv] ionic: update eid test for overflow (Jonathan Toppins) [1861520]
- [netdrv] ionic: remove unused ionic_coal_hw_to_usec (Jonathan Toppins) [1861520]
- [netdrv] ionic: set netdev default name (Jonathan Toppins) [1861520]
- [netdrv] ionic: get MTU from lif identity (Jonathan Toppins) [1861520]
- [netdrv] ionic: keep rss hash after fw update (Jonathan Toppins) [1861520]
- [netdrv] ionic: update filter id after replay (Jonathan Toppins) [1861520]
- [netdrv] ionic: fix up filter locks and debug msgs (Jonathan Toppins) [1861520]
- [netdrv] ionic: use offset for ethtool regs data (Jonathan Toppins) [1861520]
- [md] md/raid5: Allow degraded raid6 to do rmw (Nigel Croxon) [1856838]
- [md] md/raid5: Fix Force reconstruct-write io stuck in degraded raid5 (Nigel Croxon) [1856838]
- [md] raid5: don't duplicate code for different paths in handle_stripe (Nigel Croxon) [1856838]
- [md] raid5-cache: hold spinlock instead of mutex in r5c_journal_mode_show (Nigel Croxon) [1856838]
- [md] md: print errno in super_written (Nigel Croxon) [1856838]
- [md] md/raid5: remove the redundant setting of STRIPE_HANDLE (Nigel Croxon) [1856838]
- [md] md: register new md sysfs file 'uuid' read-only (Nigel Croxon) [1856838]
- [md] md: fix max sectors calculation for super 1.0 (Nigel Croxon) [1856838]
- [md] md/raid5: use do_div() for 64 bit divisions in raid5_sync_request (Nigel Croxon) [1856838]
- [md] md/raid10: avoid deadlock on recovery (Nigel Croxon) [1856838]
- [md] md-cluster: fix rmmod issue when md_cluster convert bitmap to none (Nigel Croxon) [1856838]
- [md] md-cluster: fix safemode_delay value when converting to clustered bitmap (Nigel Croxon) [1856838]
- [md] md/raid5: support config stripe_size by sysfs entry (Nigel Croxon) [1856838]
- [md] md/raid5: set default stripe_size as 4096 (Nigel Croxon) [1856838]
- [md] md/raid456: convert macro STRIPE_* to RAID5_STRIPE_* (Nigel Croxon) [1856838]
- [md] raid5: remove the meaningless check in raid5_make_request (Nigel Croxon) [1856838]
- [md] raid5: put the comment of clear_batch_ready to the right place (Nigel Croxon) [1856838]
- [md] raid5: call clear_batch_ready before set STRIPE_ACTIVE (Nigel Croxon) [1856838]
- [md] md: raid10: Fix compilation warning (Nigel Croxon) [1856838]
- [md] md: raid5: Fix compilation warning (Nigel Croxon) [1856838]
- [md] md: raid5-cache: Remove set but unused variable (Nigel Croxon) [1856838]
- [md] md: Fix compilation warning (Nigel Croxon) [1856838]
- [md] md-cluster: fix wild pointer of unlock_all_bitmaps() (Nigel Croxon) [1856838]
- [md] md/raid5-cache: clear MD_SB_CHANGE_PENDING before flushing stripes (Nigel Croxon) [1856838]
- [md] md: fix deadlock causing by sysfs_notify (Nigel Croxon) [1856838]
- [md] md: raid0/linear: fix dereference before null check on pointer mddev (Nigel Croxon) [1856838]
- [md] md/raid1: Replace zero-length array with flexible-array (Nigel Croxon) [1856838]
- [md] md: add a newline when printing parameter 'start_ro' by sysfs (Nigel Croxon) [1856838]
- [md] md: stop using ->queuedata (Nigel Croxon) [1856838]
- [md] md/raid1: release pending accounting for an I/O only after write-behind is also finished (Nigel Croxon) [1856838]
- [md] md: remove redundant memalloc scope API usage (Nigel Croxon) [1856838]
- [md] raid5: update code comment of scribble_alloc() (Nigel Croxon) [1856838]
- [md] raid5: remove gfp flags from scribble_alloc() (Nigel Croxon) [1856838]
- [md] md: use memalloc scope APIs in mddev_suspend()/mddev_resume() (Nigel Croxon) [1856838]
- [md] md: remove the extra line for ->hot_add_disk (Nigel Croxon) [1856838]
- [md] md: flush md_rdev_misc_wq for HOT_ADD_DISK case (Nigel Croxon) [1856838]
- [md] md: don't flush workqueue unconditionally in md_open (Nigel Croxon) [1856838]
- [md] md: add new workqueue for delete rdev (Nigel Croxon) [1856838]
- [md] md: add checkings before flush md_misc_wq (Nigel Croxon) [1856838]
- [md] md: check arrays is suspended in mddev_detach before call quiesce operations (Nigel Croxon) [1856838]

* Wed Dec 23 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-267.el8]
- [scsi] storvsc: Fix error return in storvsc_probe() (Cathy Avery) [1895026]
- [scsi] storvsc: Support PAGE_SIZE larger than 4K (Cathy Avery) [1895026]
- [kernel] hv: hyperv.h: Introduce some hvpfn helper functions (Cathy Avery) [1895026]
- [scsi] storvsc: Add validation for untrusted Hyper-V values (Cathy Avery) [1895026]
- [scsi] storvsc: Fix spelling mistake (Cathy Avery) [1895026]
- [scsi] storvsc: Remove memset before memory freeing in storvsc_suspend() (Cathy Avery) [1895026]
- [net] tipc: fix incorrect setting window for bcast link (Xin Long) [1893085]
- [net] tipc: re-configure queue limit for broadcast link (Xin Long) [1893085]
- [net] tipc: fix NULL pointer dereference in tipc_named_rcv (Xin Long) [1893085]
- [net] tipc: Supply missing udp_media.h include file (Xin Long) [1893085]
- [net] tipc: add automatic rekeying for encryption key (Xin Long) [1893085]
- [net] tipc: add automatic session key exchange (Xin Long) [1893085]
- [net] tipc: introduce encryption master key (Xin Long) [1893085]
- [net] tipc: optimize key switching time and logic (Xin Long) [1893085]
- [net] tipc: Fix memory leak in tipc_group_create_member() (Xin Long) [1893085]
- [net] tipc: fix shutdown() of connection oriented socket (Xin Long) [1893085]
- [net] tipc: fix a deadlock when flushing scheduled work (Xin Long) [1893085]
- [net] tipc: fix shutdown() of connectionless socket (Xin Long) [1893085]
- [net] tipc: fix using smp_processor_id() in preemptible (Xin Long) [1893085]
- [net] tipc: fix use-after-free in tipc_bcast_get_mode (Xin Long) [1893085]
- [net] tipc: call rcu_read_lock() in tipc_aead_encrypt_done() (Xin Long) [1893085]
- [net] tipc: fix uninit skb->data in tipc_nl_compat_dumpit() (Xin Long) [1893085]
- [net] tipc: update a binding service via broadcast (Xin Long) [1893085]
- [hv] hv_balloon: do adjust_managed_page_count() when ballooning/un-ballooning (Vitaly Kuznetsov) [1894717]
- [hv] hv_balloon: simplify math in alloc_balloon_pages() (Vitaly Kuznetsov) [1894717]
- [md] dm integrity: don't use drivers that have CRYPTO_ALG_ALLOCATES_MEMORY (Vladis Dronov) [1903849]
- [md] dm crypt: don't use drivers that have CRYPTO_ALG_ALLOCATES_MEMORY (Vladis Dronov) [1903849]
- [crypto] crypto: drivers - set the flag CRYPTO_ALG_ALLOCATES_MEMORY (Vladis Dronov) [1903849]
- [include] crypto: algapi - introduce the flag CRYPTO_ALG_ALLOCATES_MEMORY (Vladis Dronov) [1903849]
- [fs] iomap: Set all uptodate bits for an Uptodate page (Brian Foster) [1654127]
- [scsi] scsi: ibmvfc: Avoid link down on FS9100 canister reboot (Desnes Augusto Nunes do Rosario) [1882613]
- [scsi] scsi: ibmvfc: Use compiler attribute defines instead of __attribute__() (Desnes Augusto Nunes do Rosario) [1882613]
- [arm64] arm64: Enable PCI write-combine resources under sysfs (Petr Oros) [1872943]
- [scsi] scsi: mpt3sas: Bump driver version to 35.101.00.00 (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Add module parameter multipath_on_hba (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Handle vSES vphy object during HBA reset (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Add bypass_dirty_port_flag parameter (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Handling HBA vSES device (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Set valid PhysicalPort in SMPPassThrough (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Update hba_port objects after host reset (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Get sas_device objects using device's rphy (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Rename transport_del_phy_from_an_existing_port() (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Get device objects using sas_address & portID (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Update hba_port's sas_address & phy_mask (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Rearrange _scsih_mark_responding_sas_device() (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Allocate memory for hba_port objects (Tomas Henzl) [1888543]
- [scsi] scsi: mpt3sas: Define hba_port structure (Tomas Henzl) [1888543]

* Tue Dec 22 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-266.el8]
- [netdrv] net: phy: realtek: Modify 2.5G PHY name to RTL8226 (Josef Oskera) [1889854]
- [netdrv] net: phy: realtek: enable ALDPS to save power for RTL8211F (Josef Oskera) [1889854]
- [netdrv] net: phy: realtek: fix rtl8211e rx/tx delay config (Josef Oskera) [1889854]
- [netdrv] net: phy: realtek: add support for RTL8125B-internal PHY (Josef Oskera) [1889854]
- [netdrv] net: phy: realtek: add delay to resume path of certain internal PHY's (Josef Oskera) [1889854]
- [netdrv] net: phy: realtek: read actual speed to detect downshift (Josef Oskera) [1889854]
- [netdrv] r8169: fix issue with forced threading in combination with shared interrupts (Josef Oskera) [1889854]
- [netdrv] r8169: fix operation under forced interrupt threading (Josef Oskera) [1889854]
- [netdrv] r8169: factor out handling rtl8169_stats (Josef Oskera) [1889854]
- [netdrv] r8169: consider that PHY reset may still be in progress after applying firmware (Josef Oskera) [1889854]
- [netdrv] r8169: fix data corruption issue on RTL8402 (Josef Oskera) [1889854]
- [netdrv] r8169: fix handling ether_clk (Josef Oskera) [1889854]
- [netdrv] r8169: fix RTL8168f/RTL8411 EPHY config (Josef Oskera) [1889854]
- [netdrv] r8169: remove member irq_enabled from struct rtl8169_private (Josef Oskera) [1889854]
- [netdrv] r8169: use napi_complete_done return value (Josef Oskera) [1889854]
- [netdrv] r8169: allow to enable ASPM on RTL8125A (Josef Oskera) [1889854]
- [netdrv] r8169: add support for RTL8125B (Josef Oskera) [1889854]
- [netdrv] r8169: sync support for RTL8401 with vendor driver (Josef Oskera) [1889854]
- [netdrv] r8169: merge handling of RTL8101e and RTL8100e (Josef Oskera) [1889854]
- [netdrv] r8169: rename RTL8125 to RTL8125A (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl8169_runtime_resume (Josef Oskera) [1889854]
- [netdrv] r8169: remove driver-specific mutex (Josef Oskera) [1889854]
- [netdrv] r8169: use RTNL to protect critical sections (Josef Oskera) [1889854]
- [netdrv] r8169: add rtl8169_up (Josef Oskera) [1889854]
- [netdrv] r8169: remove no longer needed checks for device being runtime-active (Josef Oskera) [1889854]
- [netdrv] r8169: mark device as not present when in PCI D3 (Josef Oskera) [1889854]
- [netdrv] r8169: allow setting irq coalescing if link is down (Josef Oskera) [1889854]
- [netdrv] r8169: move switching optional clock on/off to pll power functions (Josef Oskera) [1889854]
- [netdrv] r8169: move updating counters to rtl8169_down (Josef Oskera) [1889854]
- [netdrv] r8169: move napi_disable call and rename rtl8169_hw_reset (Josef Oskera) [1889854]
- [netdrv] r8169: replace synchronize_rcu with synchronize_net (Josef Oskera) [1889854]
- [netdrv] r8169: improve setting WoL on runtime-resume (Josef Oskera) [1889854]
- [netdrv] r8169: remove unused constant RsvdMask (Josef Oskera) [1889854]
- [netdrv] r8169: add info for DASH being enabled (Josef Oskera) [1889854]
- [netdrv] r8169: fix failing WoL (Josef Oskera) [1889854]
- [netdrv] r8169: improve handling power management ops (Josef Oskera) [1889854]
- [netdrv] r8169: make rtl8169_down central chip quiesce function (Josef Oskera) [1889854]
- [netdrv] r8169: move some calls to rtl8169_hw_reset (Josef Oskera) [1889854]
- [netdrv] r8169: don't reset tx ring indexes in rtl8169_tx_clear (Josef Oskera) [1889854]
- [netdrv] r8169: enable WAKE_PHY as only WoL source when runtime-suspending (Josef Oskera) [1889854]
- [netdrv] r8169: change driver data type (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl_remove_one (Josef Oskera) [1889854]
- [netdrv] r8169: sync RTL8168f/RTL8411 hw config with vendor driver (Josef Oskera) [1889854]
- [netdrv] r8169: sync RTL8168evl hw config with vendor driver (Josef Oskera) [1889854]
- [netdrv] r8169: sync RTL8168h hw config with vendor driver (Josef Oskera) [1889854]
- [netdrv] r8169: sync RTL8168g hw config with vendor driver (Josef Oskera) [1889854]
- [netdrv] r8169: remove mask argument from r8168ep_ocp_read (Josef Oskera) [1889854]
- [netdrv] r8169: remove mask argument from r8168dp_ocp_read (Josef Oskera) [1889854]
- [netdrv] r8169: remove mask argument from rtl_w0w1_eri (Josef Oskera) [1889854]
- [netdrv] r8169: work around an irq coalescing related tx timeout (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl8169_mark_to_asic (Josef Oskera) [1889854]
- [netdrv] r8169: make rtl_rx better readable (Josef Oskera) [1889854]
- [netdrv] r8169: remove remaining call to mdiobus_unregister (Josef Oskera) [1889854]
- [netdrv] r8169: don't include linux/moduleparam.h (Josef Oskera) [1889854]
- [netdrv] r8169: remove not needed checks in rtl8169_set_eee (Josef Oskera) [1889854]
- [netdrv] r8169: improve reset handling for chips from RTL8168g (Josef Oskera) [1889854]
- [netdrv] r8169: add helper rtl_wait_txrx_fifo_empty (Josef Oskera) [1889854]
- [netdrv] r8169: add helper rtl_enable_rxdvgate (Josef Oskera) [1889854]
- [netdrv] r8169: add helper r8168g_wait_ll_share_fifo_ready (Josef Oskera) [1889854]
- [netdrv] r8169: use fsleep in polling functions (Josef Oskera) [1889854]
- [netdrv] r8169: use new helper eth_hw_addr_crc (Josef Oskera) [1889854]
- [netdrv] r8169: switch from netif_xxx message functions to netdev_xxx (Josef Oskera) [1889854]
- [netdrv] r8169: remove "out of memory" error message from rtl_request_firmware (Josef Oskera) [1889854]
- [netdrv] r8169: simplify counter handling (Josef Oskera) [1889854]
- [netdrv] r8169: remove redundant driver message when entering promiscuous mode (Josef Oskera) [1889854]
- [netdrv] r8169: remove not needed parameter in rtl8169_set_magic_reg (Josef Oskera) [1889854]
- [netdrv] r8169: configure PME_SIGNAL for RTL8125 too (Josef Oskera) [1889854]
- [netdrv] r8169: improve max jumbo packet size definition (Josef Oskera) [1889854]
- [netdrv] r8169: add check for invalid parameter combination in rtl_set_coalesce (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl_set_coalesce (Josef Oskera) [1889854]
- [netdrv] r8169: improve interrupt coalescing parameter handling (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl_coalesce_choose_scale (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl_get_coalesce (Josef Oskera) [1889854]
- [netdrv] r8169: merge scale for tx and rx irq coalescing (Josef Oskera) [1889854]
- [netdrv] r8169: don't pass net_device to irq coalescing sub-functions (Josef Oskera) [1889854]
- [netdrv] r8169: improve error message if no dedicated PHY driver is found (Josef Oskera) [1889854]
- [netdrv] r8169: improve configuring RxConfig register (Josef Oskera) [1889854]
- [netdrv] r8169: improve handling CPCMD_MASK (Josef Oskera) [1889854]
- [netdrv] r8169: use devm_mdiobus_register (Josef Oskera) [1889854]
- [netdrv] r8169: change wmb to smb_wmb in rtl8169_start_xmit (Josef Oskera) [1889854]
- [netdrv] r8169: inline rtl8169_make_unusable_by_asic (Josef Oskera) [1889854]
- [netdrv] r8169: inline rtl8169_mark_as_last_descriptor (Josef Oskera) [1889854]
- [netdrv] r8169: remove PHY resume delay that is handled in the PHY driver now (Josef Oskera) [1889854]
- [netdrv] r8169: add workaround for RTL8168evl TSO hw issues (Josef Oskera) [1889854]
- [netdrv] r8169: improve rtl8169_tso_csum_v2 (Josef Oskera) [1889854]
- [netdrv] r8169: use rtl8169_set_features in rtl8169_init_one (Josef Oskera) [1889854]
- [netdrv] r8169: preserve VLAN setting on RTL8125 in rtl_init_rxcfg (Josef Oskera) [1889854]
- [netdrv] r8169: remove NETIF_F_HIGHDMA from vlan_features (Josef Oskera) [1889854]
- [netdrv] r8169: move setting OCP base to generic init code (Josef Oskera) [1889854]
- [s390] sclp: provide extended sccb support (Thomas Huth) [1798484]
- [s390] sclp: avoid copy of sclp_info_sccb (Thomas Huth) [1798484]
- [s390] sclp: use memblock for early read cpu info (Thomas Huth) [1798484]
- [include] ptp: add stub function for ptp_get_msgtype() (Ivan Vecera) [1899217]
- [include] ptp: Add generic ptp message type function (Ivan Vecera) [1899217]
- [net] ptp: Add generic ptp v2 header parsing function (Ivan Vecera) [1899217]
- [video] hyperv_fb: Fix the cache type when mapping the VRAM (Mohammed Gamal) [1886106]
- [video] hyperv_fb: include vmalloc.h (Mohammed Gamal) [1886106]
- [video] hyperv: hyperv_fb: Use physical memory for fb on HyperV Gen 1 VMs (Mohammed Gamal) [1886106]
- [video] hyperv_fb: Fix hibernation for the deferred IO feature (Mohammed Gamal) [1886106]
- [video] hyperv: hyperv_fb: Support deferred IO for Hyper-V frame buffer driver (Mohammed Gamal) [1886106]
- [uio] uio_hv_generic: add missed sysfs_remove_bin_file (Mohammed Gamal) [1886106]
- [input] hyperv-keyboard: Use VMBUS_RING_SIZE() for ringbuffer sizes (Mohammed Gamal) [1886106]
- [hid] hyperv: Use VMBUS_RING_SIZE() for ringbuffer sizes (Mohammed Gamal) [1886106]
- [netdrv] hv_netvsc: Add validation for untrusted Hyper-V values (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: Fix the queue_mapping in netvsc_vf_xmit() (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: Remove "unlikely" from netvsc_select_queue (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: do not use VF device if link is down (Mohammed Gamal) [1886097]
- [netdrv] hyperv: dump TX indirection table to ethtool regs (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: add support for vlans in AF_PACKET mode (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: Fix netvsc_start_xmit's return type (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: Remove unnecessary round_up for recv_completion_cnt (Mohammed Gamal) [1886097]
- [netdrv] hv_netvsc: use new helper tcp_v6_gso_csum_prep (Mohammed Gamal) [1886097]
- [tools] kvm_stat: add sample systemd unit file (Thomas Huth) [1851123]
- [tools] kvm_stat: Add command line switch '-L' to log to file (Thomas Huth) [1851123]
- [tools] kvm_stat: add command line switch '-z' to skip zero records (Thomas Huth) [1851123]
- [mm] mm/gup: Mark lock taken only after a successful retake (Chris von Recklinghausen) [1885412]
- [mm] mm/filemap.c: fix a data race in filemap_fault() (Chris von Recklinghausen) [1885412]
- [mm] mm: fix kthread_use_mm() vs TLB invalidate (Chris von Recklinghausen) [1885412]
- [fs] kernel: set USER_DS in kthread_use_mm (Chris von Recklinghausen) [1885412]
- [drm] kernel: better document the use_mm/unuse_mm API contract (Chris von Recklinghausen) [1885412]
- [kernel] kernel: move use_mm/unuse_mm to kthread.c (Chris von Recklinghausen) [1885412]
- [drm] drm/i915: convert get_user_pages() --> pin_user_pages() (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: introduce pin_user_pages_fast_only() (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: refactor and de-duplicate gup_fast() code (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: move __get_user_pages_fast() down a few lines in gup.c (Chris von Recklinghausen) [1885412]
- [mm] gup: document and work around "COW can break either way" issue (Chris von Recklinghausen) [1885412]
- [vfio] vfio: checking of validity of user vaddr in vfio_dma_rw (Chris von Recklinghausen) [1885412]
- [fs] mm/userfaultfd: honor FAULT_FLAG_KILLABLE in fault path (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: allow to react to fatal signals (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: allow VM_FAULT_RETRY for multiple times (Chris von Recklinghausen) [1885412]
- [mm] mm: allow VM_FAULT_RETRY for multiple times (Chris von Recklinghausen) [1885412]
- [fs] mm: introduce FAULT_FLAG_INTERRUPTIBLE (Chris von Recklinghausen) [1885412]
- [mm] mm: introduce FAULT_FLAG_DEFAULT (Chris von Recklinghausen) [1885412]
- [fs] userfaultfd: don't retake mmap_sem to emulate NOPAGE (Chris von Recklinghausen) [1885412]
- [include] mm: return faster for non-fatal signals in user mode faults (Chris von Recklinghausen) [1885412]
- [mm] powerpc/mm: use helper fault_signal_pending() (Chris von Recklinghausen) [1885412]
- [mm] arm64/mm: use helper fault_signal_pending() (Chris von Recklinghausen) [1885412]
- [mm] x86/mm: use helper fault_signal_pending() (Chris von Recklinghausen) [1885412]
- [mm] mm: introduce fault_signal_pending() (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: fix __get_user_pages() on fault retry of hugetlb (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: rename "nonblocking" to "locked" where proper (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: rename nr as nr_pinned in get_user_pages_fast() (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: require FOLL_GET for get_user_pages_fast() (Chris von Recklinghausen) [1885412]
- [mm] mm/filemap.c: don't bother dropping mmap_sem for zero size readahead (Chris von Recklinghausen) [1885412]
- [mm] mm/slb: export __kmalloc_track(_node)_caller (Chris von Recklinghausen) [1885412]
- [mm] mm: Add vmf_insert_pfn_xxx_prot() for huge page-table entries (Chris von Recklinghausen) [1885412]
- [vfio] vfio: introduce vfio_dma_rw to read/write a range of IOVAs (Chris von Recklinghausen) [1885412]
- [infiniband] mm, tree-wide: rename put_user_page*() to unpin_user_page*() (Chris von Recklinghausen) [1885412]
- [mm] mm/gup_benchmark: use proper FOLL_WRITE flags instead of hard-coding "1" (Chris von Recklinghausen) [1885412]
- [mm] powerpc: book3s64: convert to pin_user_pages() and put_user_page() (Chris von Recklinghausen) [1885412]
- [vfio] vfio, mm: pin_user_pages (FOLL_PIN) and put_user_page() conversion (Chris von Recklinghausen) [1885412]
- [media] media/v4l2-core: pin_user_pages (FOLL_PIN) and put_user_page() conversion (Chris von Recklinghausen) [1885412]
- [net] net/xdp: set FOLL_PIN via pin_user_pages() (Chris von Recklinghausen) [1885412]
- [drm] drm/via: set FOLL_PIN via pin_user_pages_fast() (Chris von Recklinghausen) [1885412]
- [mm] mm/process_vm_access: set FOLL_PIN via pin_user_pages_remote() (Chris von Recklinghausen) [1885412]
- [infiniband] IB/{core, hw, umem}: set FOLL_PIN via pin_user_pages*(), fix up ODP (Chris von Recklinghausen) [1885412]
- [documentation] mm/gup: introduce pin_user_pages*() and FOLL_PIN (Chris von Recklinghausen) [1885412]
- [media] media/v4l2-core: set pages dirty upon releasing DMA buffers (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: allow FOLL_FORCE for get_user_pages_fast() (Chris von Recklinghausen) [1885412]
- [vfio] vfio: fix FOLL_LONGTERM use, simplify get_user_pages_remote() call (Chris von Recklinghausen) [1885412]
- [mm] mm: fix get_user_pages_remote()'s handling of FOLL_LONGTERM (Chris von Recklinghausen) [1885412]
- [mm] mm/gup: factor out duplicate code from four routines (Chris von Recklinghausen) [1885412]
- [mm] mm: drop mmap_sem before calling balance_dirty_pages() in write fault (Chris von Recklinghausen) [1885412]
- [vfio] vfio/type1: untag user pointers in vaddr_get_pfn (Chris von Recklinghausen) [1885412]
- [mm] mm: untag user pointers in mm/gup.c (Chris von Recklinghausen) [1885412]
- [drm] drivers/gpu/drm/via: convert put_page() to put_user_page*() (Chris von Recklinghausen) [1885412]
- [fs] fs/io_uring.c: convert put_page() to put_user_page*() (Chris von Recklinghausen) [1885412]
- [mm] mm: mark the page referenced in gup_hugepte (Chris von Recklinghausen) [1885412]
- [mm] mm: switch gup_hugepte to use try_get_compound_head (Chris von Recklinghausen) [1885412]
- [mm] mm: move the powerpc hugepd code to mm/gup.c (Chris von Recklinghausen) [1885412]
- [mm] mm: validate get_user_pages_fast flags (Chris von Recklinghausen) [1885412]
- [mm] mm: consolidate the get_user_pages* implementations (Chris von Recklinghausen) [1885412]
- [mm] mm: reorder code blocks in gup.c (Chris von Recklinghausen) [1885412]
- [mm] mm: rename CONFIG_HAVE_GENERIC_GUP to CONFIG_HAVE_FAST_GUP (Chris von Recklinghausen) [1885412]
- [x86] mm: lift the x86_32 PAE version of gup_get_pte to common code (Chris von Recklinghausen) [1885412]
- [s390] mm: simplify gup_fast_permitted (Chris von Recklinghausen) [1885412]
- [mm] mm: use untagged_addr() for get_user_pages_fast addresses (Chris von Recklinghausen) [1885412]
- [mm] powerpc/mm: make gup_hugepte() static (Chris von Recklinghausen) [1885412]
- [mm] filemap: drop the mmap_sem for all blocking operations (Chris von Recklinghausen) [1885412]
- [mm] filemap: kill page_cache_read usage in filemap_fault (Chris von Recklinghausen) [1885412]
- [mm] filemap: pass vm_fault to the mmap ra helpers (Chris von Recklinghausen) [1885412]
- [mm] docs/core-api/mm: fix return value descriptions in mm/ (Chris von Recklinghausen) [1885412]
- [mm] docs/mm: vmalloc: re-indent kernel-doc comemnts (Chris von Recklinghausen) [1885412]
- [drm] drm/via: mark expected switch fall-throughs (Chris von Recklinghausen) [1885412]
- [mm] x86/mm: Break out kernel address space handling (Chris von Recklinghausen) [1885412]
- [kernel] locking/rwsem: Remove reader optimistic spinning (Waiman Long) [1895046]
- [kernel] locking/rwsem: Enable reader optimistic lock stealing (Waiman Long) [1895046]
- [kernel] locking/rwsem: Prevent potential lock starvation (Waiman Long) [1895046]
- [kernel] locking/rwsem: Pass the current atomic count to rwsem_down_read_slowpath() (Waiman Long) [1895046]
- [kernel] locking/rwsem: Fold __down_{read,write}*() (Waiman Long) [1895046]
- [kernel] locking/rwsem: Introduce rwsem_write_trylock() (Waiman Long) [1895046]
- [kernel] locking/rwsem: Better collate rwsem_read_trylock() (Waiman Long) [1895046]
- [kernel] rwsem: Implement down_read_interruptible (Waiman Long) [1895046]
- [kernel] rwsem: Implement down_read_killable_nested (Waiman Long) [1895046]
- [powerpc] powerpc/perf: Fix crash with is_sier_available when pmu is not set (Steve Best) [1904225]
- [powerpc] kvm: ppc: book3s hv: xive: Fix vCPU id sanity check (Greg Kurz) [1902709]
- [net] ip6_gre: set dev->hard_header_len when using header_ops (Antoine Tenart) [1895789]
- [fs] xfs: flush new eof page on truncate to avoid post-eof corruption (Brian Foster) [1878495]
- [netdrv] bonding: set dev->needed_headroom in bond_setup_by_slave() (Antoine Tenart) [1903073]
- [net] netfilter: bridge: reset skb->pkt_type after NF_INET_POST_ROUTING traversal (Antoine Tenart) [1901026]
- [infiniband] RDMA/umem: Prevent small pages from being returned by ib_umem_find_best_pgsz() (Kamal Heib) [1857605]
- [infiniband] IB/hfi1: Fix error return code in hfi1_init_dd() (Kamal Heib) [1857605]
- [infiniband] RDMA/pvrdma: Fix missing kfree() in pvrdma_register_device() (Kamal Heib) [1857605]
- [infiniband] RDMA/cm: Make the local_id_table xarray non-irq (Kamal Heib) [1857605]
- [infiniband] IB/srpt: Fix memory leak in srpt_add_one (Kamal Heib) [1857605]
- [infiniband] RDMA/bnxt_re: Set queue pair state when being queried (Kamal Heib) [1894681 1857605]
- [infiniband] RDMA/rxe: Handle skb_clone() failure in rxe_recv.c (Kamal Heib) [1857605]
- [infiniband] RDMA/rxe: Fix bug rejecting all multicast packets (Kamal Heib) [1857605]
- [infiniband] RDMA/rxe: Fix skb lifetime in rxe_rcv_mcast_pkt() (Kamal Heib) [1857605]
- [infiniband] IB/rdmavt: Fix sizeof mismatch (Kamal Heib) [1857605]
- [infiniband] RDMA/ipoib: Set rtnl_link_ops for ipoib interfaces (Kamal Heib) [1883480 1883478 1857605]
- [infiniband] RDMA/addr: Fix race with netevent_callback()/rdma_addr_cancel() (Kamal Heib) [1857605]
- [rdma] RDMA/umem: Fix signature of stub ib_umem_find_best_pgsz() (Kamal Heib) [1857605]
- [x86] kretprobe: Prevent triggering kretprobe from within kprobe_flush_task (Jerome Marchand) [1821265]
- [netdrv] net: intel: Remove in_interrupt() warnings (Jonathan Toppins) [1891101]
- [netdrv] ice: fix adding IP4 IP6 Flow Director rules (Jonathan Toppins) [1891101]
- [netdrv] ice: Fix pointer cast warnings (Jonathan Toppins) [1891101]
- [netdrv] ice: refactor devlink_port to be per-VSI (Jonathan Toppins) [1891101]
- [netdrv] ice: add the DDP Track ID to devlink info (Jonathan Toppins) [1891101]
- [netdrv] ice: Change ice_info_get_dsn to be void (Jonathan Toppins) [1891101]
- [netdrv] ice: remove repeated words (Jonathan Toppins) [1891101]
- [netdrv] ice: devlink: use *phD to print small buffer (Jonathan Toppins) [1891101]
- [netdrv] ice: preserve NVM capabilities in safe mode (Jonathan Toppins) [1891101]
- [netdrv] ice: increase maximum wait time for flash write commands (Jonathan Toppins) [1891101]
- [netdrv] ice: remove unused args from ice_get_open_tunnel_port() (Jonathan Toppins) [1891101]
- [netdrv] ice: fix memory leak in ice_vsi_setup (Jonathan Toppins) [1891101]
- [netdrv] ice: fix memory leak if register_netdev_fails (Jonathan Toppins) [1891101]
- [netdrv] ice: Fix call trace on suspend (Jonathan Toppins) [1891101]
- [netdrv] ice: simplify the return expression of ice_finalize_update() (Jonathan Toppins) [1891101]
- [netdrv] ice: Misc minor fixes (Jonathan Toppins) [1838737]
- [netdrv] ice: adjust profile ID map locks (Jonathan Toppins) [1838737]
- [netdrv] ice: update PTYPE lookup table (Jonathan Toppins) [1838737]
- [netdrv] ice: Graceful error handling in HW table calloc failure (Jonathan Toppins) [1838737]
- [netdrv] ice: port fix for chk_linearlize (Jonathan Toppins) [1838737]
- [netdrv] ice: Allow 2 queue pairs per VF on SR-IOV initialization (Jonathan Toppins) [1838737]
- [netdrv] ice: Clear and free XLT entries on reset (Jonathan Toppins) [1838737]
- [netdrv] ice: add useful statistics (Jonathan Toppins) [1838737]
- [netdrv] ice: remove page_reuse statistic (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix RSS profile locks (Jonathan Toppins) [1838737]
- [netdrv] ice: fix the vsi_id mask to be 10 bit for set_rss_lut (Jonathan Toppins) [1838737]
- [netdrv] ice: rename misleading grst_delay variable (Jonathan Toppins) [1838737]
- [netdrv] ice: mark PM functions as __maybe_unused (Jonathan Toppins) [1838737]
- [netdrv] ice: fix unused parameter warning (Jonathan Toppins) [1838737]
- [netdrv] ice: disable no longer needed workaround for FW logging (Jonathan Toppins) [1838737]
- [netdrv] ice: reduce scope of variable (Jonathan Toppins) [1838737]
- [netdrv] ice: cleanup VSI on probe fail (Jonathan Toppins) [1838737]
- [netdrv] ice: Allow all VLANs in safe mode (Jonathan Toppins) [1838737]
- [netdrv] ice: need_wakeup flag might not be set for Tx (Jonathan Toppins) [1838737]
- [netdrv] ice: distribute Tx queues evenly (Jonathan Toppins) [1838737]
- [netdrv] ice: Adjust scheduler default BW weight (Jonathan Toppins) [1838737]
- [netdrv] ice: Add RL profile bit mask check (Jonathan Toppins) [1838737]
- [netdrv] ice: fix overwriting TX/RX descriptor values when rebuilding VSI (Jonathan Toppins) [1838737]
- [netdrv] ice: return correct error code from ice_aq_sw_rules (Jonathan Toppins) [1838737]
- [netdrv] ice: restore VF MSI-X state during PCI reset (Jonathan Toppins) [1838737]
- [netdrv] ice: fix link event handling timing (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix link broken after GLOBR reset (Jonathan Toppins) [1838737]
- [netdrv] ice: Implement LFC workaround (Jonathan Toppins) [1838737]
- [netdrv] ice: implement device flash update via devlink (Jonathan Toppins) [1838737]
- [netdrv] ice: add flags indicating pending update of firmware module (Jonathan Toppins) [1838737]
- [netdrv] ice: Add AdminQ commands for FW update (Jonathan Toppins) [1838737]
- [netdrv] ice: Add support for unified NVM update flow capability (Jonathan Toppins) [1838737]
- [netdrv] ice: add 1G SGMII PHY type (Jonathan Toppins) [1838737]
- [netdrv] ice: Report AOC PHY Types as Fiber (Jonathan Toppins) [1838737]
- [netdrv] ice: add AQC get link topology handle support (Jonathan Toppins) [1838737]
- [netdrv] ice: Rename low_power_ctrl (Jonathan Toppins) [1838737]
- [netdrv] ice: update reporting of autoneg capabilities (Jonathan Toppins) [1838737]
- [netdrv] ice: add ice_aq_get_phy_caps() debug logs (Jonathan Toppins) [1838737]
- [netdrv] ice: support Total Port Shutdown on devices that support it (Jonathan Toppins) [1838737]
- [netdrv] ice: add link lenient and default override support (Jonathan Toppins) [1838737]
- [netdrv] ice: restore PHY settings on media insertion (Jonathan Toppins) [1838737]
- [netdrv] ice: move auto FEC checks into ice_cfg_phy_fec() (Jonathan Toppins) [1838737]
- [netdrv] ice: refactor FC functions (Jonathan Toppins) [1838737]
- [netdrv] ice: Add advanced power mgmt for WoL (Jonathan Toppins) [1838737]
- [netdrv] ice: split ice_discover_caps into two functions (Jonathan Toppins) [1838737]
- [netdrv] ice: split ice_parse_caps into separate functions (Jonathan Toppins) [1838737]
- [netdrv] ice: refactor ice_discover_caps to avoid need to retry (Jonathan Toppins) [1838737]
- [netdrv] ice: replace single-element array used for C struct hack (Jonathan Toppins) [1838737]
- [netdrv] ice: avoid unnecessary single-member variable-length structs (Jonathan Toppins) [1838737]
- [netdrv] ice: implement snapshot for device capabilities (Jonathan Toppins) [1838737]
- [netdrv] net/intel: remove driver versions from Intel drivers (Jonathan Toppins) [1838737]
- [netdrv] ice: protect ring accesses with WRITE_ONCE (Jonathan Toppins) [1838737]
- [netdrv] ice: Ignore EMODE when setting PHY config (Jonathan Toppins) [1838737]
- [netdrv] ice: fix aRFS after flow director delete (Jonathan Toppins) [1838737]
- [netdrv] ice: Use coalesce values from q_vector 0 when increasing q_vectors (Jonathan Toppins) [1838737]
- [netdrv] ice: fix PCI device serial number to be lowercase values (Jonathan Toppins) [1838737]
- [netdrv] ice: fix function signature style format (Jonathan Toppins) [1838737]
- [netdrv] ice: Allow VF to request reset as soon as it's initialized (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix inability to set channels when down (Jonathan Toppins) [1838737]
- [netdrv] ice: Always clear QRXFLXP_CNTXT before writing new value (Jonathan Toppins) [1838737]
- [netdrv] ice: Reset VF for all port VLAN changes from host (Jonathan Toppins) [1838737]
- [netdrv] ice: Update ICE_PHY_TYPE_HIGH_MAX_INDEX value (Jonathan Toppins) [1838737]
- [netdrv] ice: Increase timeout after PFR (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix transmit for all software offloaded VLANs (Jonathan Toppins) [1838737]
- [netdrv] ice: support adding 16 unicast/multicast filter on untrusted VF (Jonathan Toppins) [1838737]
- [netdrv] ice: allow host to clear administratively set VF MAC (Jonathan Toppins) [1838737]
- [netdrv] ice: Refactor VF VSI release and setup functions (Jonathan Toppins) [1838737]
- [netdrv] ice: Refactor VF reset (Jonathan Toppins) [1838737]
- [netdrv] ice: remove VM/VF disable command on CORER/GLOBR reset (Jonathan Toppins) [1838737]
- [netdrv] ice: Add functions to rebuild host VLAN/MAC config for a VF (Jonathan Toppins) [1838737]
- [netdrv] ice: Add function to set trust mode bit on reset (Jonathan Toppins) [1838737]
- [netdrv] ice: Renaming and simplification in VF init path (Jonathan Toppins) [1838737]
- [netdrv] ice: Separate VF VSI initialization/creation from reset flow (Jonathan Toppins) [1838737]
- [netdrv] ice: Add helper function for clearing VPGEN_VFRTRIG (Jonathan Toppins) [1838737]
- [netdrv] ice: Simplify ice_sriov_configure (Jonathan Toppins) [1838737]
- [netdrv] ice: Refactor ice_ena_vf_mappings to split MSIX and queue mappings (Jonathan Toppins) [1838737]
- [netdrv] ice: Declare functions static (Jonathan Toppins) [1838737]
- [netdrv] ice: fix kernel BUG if register_netdev fails (Jonathan Toppins) [1838737]
- [netdrv] ice: fix potential double free in probe unrolling (Jonathan Toppins) [1838737]
- [netdrv] ice: cleanup VSI context initialization (Jonathan Toppins) [1838737]
- [netdrv] ice: Poll for reset completion when DDP load fails (Jonathan Toppins) [1838737]
- [netdrv] ice: Check UMEM FQ size when allocating bufs (Jonathan Toppins) [1838737]
- [netdrv] ice: Refactor Rx checksum checks (Jonathan Toppins) [1838737]
- [netdrv] ice: avoid undefined behavior (Jonathan Toppins) [1838737]
- [netdrv] ice: Change number of XDP Tx queues to match number of Rx queues (Jonathan Toppins) [1838737]
- [netdrv] ice: Add XDP Tx to VSI ring stats (Jonathan Toppins) [1838737]
- [netdrv] ice: Change number of XDP TxQ to 0 when destroying rings (Jonathan Toppins) [1838737]
- [netdrv] ice: Handle critical FW error during admin queue initialization (Jonathan Toppins) [1838737]
- [netdrv] ice: Don't allow VLAN stripping change when pvid set (Jonathan Toppins) [1838737]
- [netdrv] ice: Add more Rx errors to netdev's rx_error counter (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix for memory leaks and modify ICE_FREE_CQ_BUFS (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix memory leak (Jonathan Toppins) [1838737]
- [netdrv] ice: fix MAC write command (Jonathan Toppins) [1838737]
- [netdrv] ice: set VF default LAN address (Jonathan Toppins) [1838737]
- [netdrv] ice: remove unused macro (Jonathan Toppins) [1838737]
- [netdrv] ice: fix signed vs unsigned comparisons (Jonathan Toppins) [1838737]
- [netdrv] ice: Fix error return code in ice_add_prof() (Jonathan Toppins) [1838737]
- [netdrv] ice: replace "fallthrough" comments with fallthrough reserved word (Jonathan Toppins) [1838737]

* Fri Dec 18 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-265.el8]
- [kernel] kernel/crash: reserve more memory for fadump (Pingfan Liu) [1891043]
- [powerpc] pseries: Pass MSI affinity to irq_create_mapping() (Laurent Vivier) [1702939]
- [kernel] genirq/irqdomain: Add an irq_create_mapping_affinity() function (Laurent Vivier) [1702939]
- [powerpc] powerpc/perf: Use regs->nip when SIAR is zero (Steve Best) [1903731]
- [powerpc] powerpc/perf: Use the address from SIAR register to set cpumode flags (Steve Best) [1903731]
- [powerpc] powerpc/perf: Drop the check for SIAR_VALID (Steve Best) [1903731]
- [powerpc] powerpc/perf: Add new power PMU flag "PPMU_P10_DD1" for power10 DD1 (Steve Best) [1903731]
- [netdrv] net/mlx5e: fix bpf_prog reference count leaks in mlx5e_alloc_rq (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Initialize QP mutex for the debug kernels (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Allow providing extra scatter CQE QP flag (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Query PPS pin operational status before registering it (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Fix slab-out-of-bounds in mlx5e_rep_is_lag_netdev (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Verify Hardware supports requested ptp function on a given pin (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Fix a bug of using ptp channel index as pin index (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Fix missing cleanup of ethtool steering during rep rx cleanup (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Fix error path of device attach (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Fix forward to next namespace (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-switch, Destroy TSAR after reload interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-switch, Destroy TSAR when fail to enable the mode (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Fix prefetch memory leak if get_prefetchable_mr fails (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Prevent prefetch from racing with implicit destruction (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Use xa_lock_irq when access to SRQ table (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Fix usage of rcu-protected pointer (Alaa Hleihel) [1858560]
- [netdrv] net/mxl5e: Verify that rpriv is not NULL (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-Switch, Fix vlan or qos setting in legacy mode (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Set PD pointers for the error flow unwind (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Fix legacy IPoIB QP initialization (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Protect from kernel crash if XRC_TGT doesn't have udata (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Fix integrity enabled QP creation (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove ECE limitation from the RAW_PACKET QPs (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Fix remote gid value in query QP (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Don't access ib_qp fields in internal destroy QP path (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Add missed RST2INIT and INIT2INIT steps during ECE handshake (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Fix -Wformat warning in check_ucmd_data() (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove duplicated assignment to resp.response_length (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-Switch, Fix some error pointer dereferences (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Return ECE DC support (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Don't rely on FW to set zeros in ECE response (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Return an error if copy_to_user fails (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Make mlx5e_dcbnl_ops static (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: reduce stack usage in qp_read_field (Alaa Hleihel) [1858560]
- [netdrv] mlx5: fix xdp data_meta setup in mlx5e_fill_xdp_buff (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Support TX port affinity for VF drivers in LAG mode (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Optimize performance for IPv4/IPv6 ethertype (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Helper function to set ethertype (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Use change upper event to setup representors' bond_metadata (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Slave representors sharing unique metadata for match (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-Switch, Alloc and free unique metadata for match (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Add bond_metadata and its slave entries (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Offload flow rules to active lower representor (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Support tc block sharing for representors (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Use netdev events to set/del egress acl forward-to-vport rule (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-Switch, Introduce APIs to enable egress acl forward-to-vport rule (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-Switch, Refactor eswitch ingress acl codes (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: E-Switch, Refactor eswitch egress acl codes (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Return ECE data after modify QP (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Set ECE options during modify QP (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Convert modify QP to use MLX5_SET macros (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove manually crafted QP context the query call (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Use direct modify QP implementation (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Set ECE options during QP create (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Get ECE options from FW during create QP (Alaa Hleihel) [1858560]
- [include] net/mlx5: Add ability to read and write ECE options (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Use IS_ERR() to check and simplify code (Alaa Hleihel) [1858560]
- [infiniband] net/mlx5: Add support for RDMA TX FT headers modifying (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Move iseg access helper routines close to mlx5_core driver (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Cleanup mlx5_ifc_fte_match_set_misc2_bits (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Update mlx5_ib driver name (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Calculate SQ stop room in a robust way (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Move internal timer read function to clock library (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Fix a bug of releasing wrong chunks on > 4K page size systems (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Dedicate fw page to the requesting function (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Fix query_srq_cmd() function (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Add support for drop action in DV steering (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Add support in steering default miss (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Refactor DV create flow (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Add support in forward to namespace (Alaa Hleihel) [1858560]
- [infiniband] {IB/net}/mlx5: Simplify don't trap code (Alaa Hleihel) [1858560]
- [include] net/mlx5: Replace zero-length array with flexible-array (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Enhance ICOSQ WQE info fields (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Accel, Remove unnecessary header include (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Use struct assignment for WQE info updates (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Take TX WQE info structures out of general EN header (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: kTLS, Do not fill edge for the DUMP WQEs in TX flow (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: kTLS, Fill work queue edge separately in TX flow (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Split TX acceleration offloads into two phases (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Update UDP fields of the SKB for GSO first (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Make TLS offload independent of wqe and pi (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Pass only eseg to IPSEC offload (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Return void from mlx5e_sq_xmit and mlx5i_sq_xmit (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Unify checks of TLS offloads (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Return bool from TLS and IPSEC offloads (Alaa Hleihel) [1858560]
- [netdrv] net: remove newlines in NL_SET_ERR_MSG_MOD (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove duplicated assignment to variable rcqe_sz (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Allow only raw Ethernet QPs when RoCE isn't enabled (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Assign profile before calling stages (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Move all WR logic from qp.c to separate file (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Refactor mlx5_post_send() to improve readability (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Update mlx5_ib to use new cmd interface (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Set UDP source port based on the grh.flow_label (Alaa Hleihel) [1858560 1851704]
- [infiniband] RDMA/mlx5: Define RoCEv2 udp source port when set path (Alaa Hleihel) [1858560 1851704]
- [infiniband] RDMA/mlx5: Set lag tx affinity according to slave (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Refactor affinity related code (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Add support to get lag physical port (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Change lag mutex lock to spin lock (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Consolidate into special function all create QP calls (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove redundant destroy QP call (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Copy response to the user in one place (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Handle udate outlen checks in one place (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Promote RSS RAW QP flags check to higher level (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Group all create QP parameters to simplify in-kernel interfaces (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Reduce amount of duplication in QP destroy (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Separate to user/kernel create QP flows (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Separate XRC_TGT QP creation from common flow (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Globally parse DEVX UID (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Delete impossible inlen check (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Rely on existence of udata to separate kernel/user flows (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove second user copy in create_user_qp (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Combine copy of create QP command in RSS RAW QP (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Promote RSS RAW QP attribute check in higher level (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Store QP type in the vendor QP structure (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Delete unsupported QP types (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Unify reserving space for WQEs (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Rename ICOSQ WQE info struct and field (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Fetch WQE: reuse code and enforce typing (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: XDP, Print the offending TX descriptor on error completion (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: TX, Generalise code and usage of error CQE dump (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Use proper name field for the UMR key (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Add support for release all pages event (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Rate limit page not found error messages (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Add helper function to release fw page (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Remove unused field in EQ (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Remove unneeded semicolon (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: IPsec, Fix coverity issue (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Process all vendor flags in one place (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Return all configured create flags through query QP (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Change scatter CQE flag to be set like other vendor flags (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Use flags_en mechanism to mark QP created with WQE signature (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Process create QP flags in one place (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Delete create QP flags obfuscation (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Initial separation of RAW_PACKET QP from common flow (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Remove second copy from user for non RSS RAW QPs (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Move DRIVER QP flags check into separate function (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Update all DRIVER QP places to use QP subtype (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Split scatter CQE configuration for DCT QP (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Separate create QP flows to be based on type (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Set QP subtype immediately when it is known (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Avoid setting redundant NULL for XRC QPs (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Prepare QP allocation for future removal (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Perform check if QP creation flow is valid (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Delete impossible GSI port check (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Organize QP types checks in one place (Alaa Hleihel) [1858560]
- [include] net/mlx5: TX WQE Add trailer insertion field (Alaa Hleihel) [1858560]
- [include] net/mlx5: Add release all pages capability bit (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Introduce TLS RX offload hardware bits (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Add structure and defines for pci sync for fw update event (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Add structure layout and defines for MFRL register (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Use aligned variable while allocating ICM memory (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Introduce IPsec Connect-X offload hardware bits and structures (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update transobj.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update SW steering new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update port.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update rl.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update uar.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update pd.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update pagealloc.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update mr.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update mcg.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update main.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update vxlan.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update mpfs.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update gid.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update lag.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update fw.c new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update fs_core new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update FPGA to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update eswitch to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] ethernet: remove redundant memset (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update statistics to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update eq.c to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update ecpf.c to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update debugfs.c to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Update cq.c to new cmd interface (Alaa Hleihel) [1858560]
- [infiniband] net/mlx5: Update vport.c to new cmd interface (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: improve some comments (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Read embedded cpu bit only once (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: Handle errors from netif_set_real_num_{tx, rx}_queues (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: IPsec, Refactor SA handle creation and destruction (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5e: IPSec, Expose IPsec HW stat only for supporting HW (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Refactor mlx5_accel_esp_create_hw_context parameter list (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Use the correct IPsec capability function for FPGA ops (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Enable SW-defined RoCEv2 UDP source port (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Refactor HCA capability set flow (Alaa Hleihel) [1858560]
- [infiniband] net/mlx5: Move QP logic to mlx5_ib (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Alphabetically sort build artifacts (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Delete not-used cmd header (Alaa Hleihel) [1858560]
- [infiniband] RDMA/mlx5: Delete Q counter allocations command (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Remove Q counter low level helper APIs (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Replace hand written QP context struct with automatic getters (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Remove extra indirection while storing QPN (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Open-code modify QP in the IPoIB module (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Open-code modify QP in the FPGA module (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Open-code modify QP in steering module (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Remove empty QP and CQ events handlers (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Open-code create and destroy QP calls (Alaa Hleihel) [1858560]
- [netdrv] net/mlx5: Provide simplified command interfaces (Alaa Hleihel) [1858560]
- [x86] kvm: x86/mmu: Fix get_mmio_spte() on CPUs supporting 5-level PT (Vitaly Kuznetsov) [1902184]
- [net] netdevsim: devlink flash timeout message (Petr Oros) [1882019]
- [net] devlink: collect flash notify params into a struct (Petr Oros) [1882019]
- [net] devlink: add timeout information to status_notify (Petr Oros) [1882019]
- [firmware] efi/esrt: Only call efi_mem_reserve() for boot services memory (Kairui Song) [1878024]
- [firmware] efi: Drop type and attribute checks in efi_mem_desc_lookup() (Kairui Song) [1878024]
- [fs] iomap: Fix direct I/O write consistency check (Andreas Grunbacher) [1875556]
- [fs] gfs2: fix O_SYNC write handling (Andreas Grunbacher) [1871923]
- [fs] gfs2: move setting current->backing_dev_info (Andreas Grunbacher) [1871923]
- [fs] gfs2: Don't return NULL from gfs2_inode_lookup (Andreas Grunbacher) [1872061]
- [fs] gfs2: If go_sync returns error, withdraw but skip invalidate (Robert S Peterson) [1875035]
- [fs] gfs2: Close timing window with GLF_INVALIDATE_IN_PROGRESS (Robert S Peterson) [1875035]
- [fs] gfs2: Fix refcount leak in gfs2_glock_poke (Robert S Peterson) [1875035]
- [fs] gfs2: Add missing truncate_inode_pages_final for sd_aspace (Robert S Peterson) [1875035]
- [fs] gfs2: call truncate_inode_pages_final for address space glocks (Robert S Peterson) [1875035]
- [fs] gfs2: simplify the logic in gfs2_evict_inode (Robert S Peterson) [1875035]
- [fs] gfs2: factor evict_linked_inode out of gfs2_evict_inode (Robert S Peterson) [1875035]
- [fs] gfs2: further simplify gfs2_evict_inode with new func evict_should_delete (Robert S Peterson) [1875035]
- [fs] gfs2: factor evict_unlinked_inode out of gfs2_evict_inode (Robert S Peterson) [1875035]
- [fs] gfs2: rename variable error to ret in gfs2_evict_inode (Robert S Peterson) [1875035]
- [net] ethtool: Add link extended state (Ivan Vecera) [1894545]
- [documentation] networking: ethtool-netlink: Add link extended state (Ivan Vecera) [1894545]
- [net] ethtool: fix error handling in linkstate_prepare_data() (Ivan Vecera) [1894545]
- [net] ethtool: provide UAPI for PHY Signal Quality Index (SQI) (Ivan Vecera) [1894545]

* Thu Dec 17 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-264.el8]
- [mm] mm/hugetlb: fix a race between hugetlb sysctl handlers (Julia Denham) [1886241] {CVE-2020-25285}
- [kernel] audit: do not set FS_EVENT_ON_CHILD in audit marks mask (Richard Guy Briggs) [1896480]
- [net] missing barriers in some of unix_sock ->addr and ->path accesses (Richard Guy Briggs) [1896480]
- [kernel] audit: fix macros warnings (Richard Guy Briggs) [1896480]
- [kernel] audit: trigger accompanying records when no rules present (Richard Guy Briggs) [1896480]
- [kernel] audit: fix a kernel-doc markup (Richard Guy Briggs) [1896480]
- [kernel] audit: Remove redundant null check (Richard Guy Briggs) [1896480]
- [kernel] audit: uninitialize variable audit_sig_sid (Richard Guy Briggs) [1896480]
- [kernel] audit: change unnecessary globals into statics (Richard Guy Briggs) [1896480]
- [kernel] audit: report audit wait metric in audit status reply (Richard Guy Briggs) [1896480]
- [security] audit: purge audit_log_string from the intra-kernel audit API (Richard Guy Briggs) [1896480]
- [security] apparmor: Check buffer bounds when mapping permissions mask (Richard Guy Briggs) [1896480]
- [kernel] audit: issue CWD record to accompany LSM_AUDIT_DATA_* records (Richard Guy Briggs) [1896480]
- [net] audit: use the proper gfp flags in the audit_log_nfcfg() calls (Richard Guy Briggs) [1896480]
- [include] audit: remove unused !CONFIG_AUDITSYSCALL __audit_inode* stubs (Richard Guy Briggs) [1896480]
- [net] audit: add gfp parameter to audit_log_nfcfg (Richard Guy Briggs) [1896480]
- [kernel] audit: log nftables configuration change events (Richard Guy Briggs) [1896480]
- [kernel] audit: Use struct_size() helper in alloc_chunk (Richard Guy Briggs) [1896480]
- [kernel] revert: 1320a4052ea1 ("audit: trigger accompanying records when no rules present") (Richard Guy Briggs) [1896480]
- [include] audit: Replace zero-length array with flexible-array (Richard Guy Briggs) [1896480]
- [netdrv] net: usb: lan78xx: Disable interrupts before calling generic_handle_irq() (Waiman Long) [1904213]
- [mm] x86/mm/cpa: Prevent large page split when ftrace flips RW on kernel text (Waiman Long) [1904213]
- [mm] x86/mm/cpa: Fix cpa_flush_array() TLB invalidation (Waiman Long) [1904213]
- [net] netlabel: fix an uninitialized warning in netlbl_unlabel_staticlist() (Ondrej Mosnacek) [1901171]
- [net] netlabel: fix our progress tracking in netlbl_unlabel_staticlist() (Ondrej Mosnacek) [1901171]
- [netdrv] net: ena: fix packet's addresses for rx_offset feature (Petr Oros) [1861967]
- [netdrv] net: ena: handle bad request id in ena_netdev (Petr Oros) [1861967]
- [netdrv] net: ena: Change WARN_ON expression in ena_del_napi_in_range() (Petr Oros) [1861967]
- [netdrv] net: ena: support new LLQ acceleration mode (Petr Oros) [1861967]
- [netdrv] net: ena: move llq configuration from ena_probe to ena_device_init() (Petr Oros) [1861967]
- [netdrv] net: ena: enable support of rss hash key and function changes (Petr Oros) [1861967]
- [netdrv] net: ena: add support for traffic mirroring (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: change ena_com_stats_admin stats to u64 (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: satisfy gcc warning (Petr Oros) [1861967]
- [netdrv] net: ena: add reserved PCI device ID (Petr Oros) [1861967]
- [netdrv] net: ena: avoid unnecessary rearming of interrupt vector when busy-polling (Petr Oros) [1861967]
- [netdrv] net: ena: Fix using plain integer as NULL pointer in ena_init_napi_in_range (Petr Oros) [1861967]
- [netdrv] ena_netdev: use generic power management (Petr Oros) [1861967]
- [netdrv] net: ena: xdp: update napi budget for DROP and ABORTED (Petr Oros) [1861967]
- [netdrv] net: ena: xdp: XDP_TX: fix memory leak (Petr Oros) [1861967]
- [netdrv] xdp: Rename convert_to_xdp_frame in xdp_convert_buff_to_frame (Petr Oros) [1861967]
- [netdrv] net: ena: reduce driver load time (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: minor code changes (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: fix spacing issues (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: code reorderings (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: remove unnecessary code (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: fix line break issues (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: fix spelling and grammar mistakes in comments (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: set queue sizes to u32 for consistency (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: rename ena_update_tx/rx_rings_intr_moderation() (Petr Oros) [1861967]
- [netdrv] net: ena: simplify ena_com_update_intr_delay_resolution() (Petr Oros) [1861967]
- [netdrv] net: ena: fix ena_com_comp_status_to_errno() return value (Petr Oros) [1861967]
- [netdrv] net: ena: use explicit variable size for clarity (Petr Oros) [1861967]
- [netdrv] net: ena: rename ena_com_free_desc to make API more uniform (Petr Oros) [1861967]
- [netdrv] net: ena: add support for the rx offset feature (Petr Oros) [1861967]
- [netdrv] ena: Add XDP frame size to amazon NIC driver (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: extract code to ena_indirection_table_set() (Petr Oros) [1861967]
- [netdrv] net: ena: cosmetic: remove unnecessary spaces and tabs in ena_com.h macros (Petr Oros) [1861967]
- [netdrv] net: ena: use SHUTDOWN as reset reason when closing interface (Petr Oros) [1861967]
- [netdrv] net: ena: drop superfluous prototype (Petr Oros) [1861967]
- [netdrv] net: ena: add support for reporting of packet drops (Petr Oros) [1861967]
- [netdrv] net: ena: add unmask interrupts statistics to ethtool (Petr Oros) [1861967]
- [netdrv] net: ena: remove code that does nothing (Petr Oros) [1861967]
- [netdrv] net: ena: changes to RSS hash key allocation (Petr Oros) [1861967]
- [netdrv] net: ena: change default RSS hash function to Toeplitz (Petr Oros) [1861967]
- [netdrv] net: ena: allow setting the hash function without changing the key (Petr Oros) [1861967]
- [netdrv] net: ena: fix error returning in ena_com_get_hash_function() (Petr Oros) [1861967]
- [netdrv] net: ena: avoid unnecessary admin command when RSS function set fails (Petr Oros) [1861967]
- [netdrv] net/ena: Fix build warning in ena_xdp_set() (Petr Oros) [1861967]
- [netdrv] net: ena: Make some functions static (Petr Oros) [1861967]
- [netdrv] net: ena: fix continuous keep-alive resets (Petr Oros) [1861967]
- [netdrv] net: ena: avoid memory access violation by validating req_id properly (Petr Oros) [1861967]
- [netdrv] net: ena: fix request of incorrect number of IRQ vectors (Petr Oros) [1861967]
- [netdrv] net: ena: fix incorrect setting of the number of msix vectors (Petr Oros) [1861967]
- [netdrv] net: ena: ethtool: clean up minor indentation issue (Petr Oros) [1861967]
- [netdrv] net: ena: reject unsupported coalescing params (Petr Oros) [1861967]
- [netdrv] net: ena: fix broken interface between ENA driver and FW (Petr Oros) [1861967]
- [netdrv] net/amazon: Ensure that driver version is aligned to the linux kernel (Petr Oros) [1861967]
- [netdrv] net: ena: ethtool: remove redundant non-zero check on rc (Petr Oros) [1861967]
- [netdrv] net: ena: remove set but not used variable 'hash_key' (Petr Oros) [1861967]
- [netdrv] net: ena: ena-com.c: prevent NULL pointer dereference (Petr Oros) [1861967]
- [netdrv] net: ena: ethtool: use correct value for crc32 hash (Petr Oros) [1861967]
- [netdrv] net: ena: make ena rxfh support ETH_RSS_HASH_NO_CHANGE (Petr Oros) [1861967]
- [netdrv] net: ena: fix corruption of dev_idx_to_host_tbl (Petr Oros) [1861967]
- [netdrv] net: ena: fix incorrectly saving queue numbers when setting RSS indirection table (Petr Oros) [1861967]
- [netdrv] net: ena: rss: store hash function as values and not bits (Petr Oros) [1861967]
- [netdrv] net: ena: rss: fix failure to get indirection table (Petr Oros) [1861967]
- [netdrv] net: ena: rss: do not allocate key when not supported (Petr Oros) [1861967]
- [netdrv] net: ena: fix incorrect default RSS key (Petr Oros) [1861967]
- [netdrv] net: ena: add missing ethtool TX timestamping indication (Petr Oros) [1861967]
- [netdrv] net: ena: fix uses of round_jiffies() (Petr Oros) [1861967]
- [netdrv] net: ena: fix potential crash when rxfh key is NULL (Petr Oros) [1861967]
- [netdrv] net: ena: remove set but not used variable 'rx_ring' (Petr Oros) [1861967]
- [netdrv] net: ena: fix issues in setting interrupt moderation params in ethtool (Petr Oros) [1861967]
- [netdrv] net: ena: fix default tx interrupt moderation interval (Petr Oros) [1861967]
- [netdrv] net: ena: Add first_interrupt field to napi struct (Petr Oros) [1861967]
- [netdrv] net: ena: Implement XDP_TX action (Petr Oros) [1861967]
- [netdrv] net: ena: implement XDP drop support (Petr Oros) [1861967]
- [netdrv] net: ena: fix napi handler misbehavior when the napi budget is zero (Petr Oros) [1861967]
- [netdrv] net: ena: ethtool: support set_channels callback (Petr Oros) [1861967]
- [netdrv] net: ena: remove redundant print of number of queues (Petr Oros) [1861967]
- [netdrv] net: ena: make ethtool -l show correct max number of queues (Petr Oros) [1861967]
- [netdrv] net: ena: ethtool: get_channels: use combined only (Petr Oros) [1861967]
- [netdrv] net: ena: multiple queue creation related cleanups (Petr Oros) [1861967]
- [netdrv] net: ena: change num_queues to num_io_queues for clarity and consistency (Petr Oros) [1861967]
- [kernel] rcu/tree: docs: document bkvcache new members at struct kfree_rcu_cpu (Nico Pache) [1894223]
- [mm] kasan: don't assume percpu shadow allocations will succeed (Nico Pache) [1894223]
- [lib] kasan: update required compiler versions in documentation (Nico Pache) [1894223]
- [lib] kasan: improve and simplify Kconfig.kasan (Nico Pache) [1894223]
- [lib] kasan: Fix required compiler version (Nico Pache) [1894223]
- [lib] kasan: Bump required compiler version (Nico Pache) [1894223]
- [documentation] kasan: update documentation for generic kasan (Nico Pache) [1894223]
- [mm] kasan: record and print the free track (Nico Pache) [1894223]
- [mm] rcu: kasan: record and print call_rcu() call stack (Nico Pache) [1894223]
- [kernel] rcu: Support reclaim for head-less object (Nico Pache) [1894223]
- [kernel] rcu: Introduce 2 arg kvfree_rcu() interface (Nico Pache) [1894223]
- [mm] mm/list_lru.c: Rename kvfree_rcu() to local variant (Nico Pache) [1894223]
- [kernel] rcu: Rename *_kfree_callback/*_kfree_rcu_offset/kfree_call_* (Nico Pache) [1894223]
- [kernel] rcu/tiny: support vmalloc in tiny-RCU (Nico Pache) [1894223]
- [kernel] rcu/tree: Maintain separate array for vmalloc ptrs (Nico Pache) [1894223]
- [kernel] rcu/tree: cache specified number of objects (Nico Pache) [1894223]
- [kernel] rcu/tree: Use static initializer for krc.lock (Nico Pache) [1894223]
- [kernel] rcu/tree: Move kfree_rcu_cpu locking/unlocking to separate functions (Nico Pache) [1894223]
- [kernel] rcu/tree: Simplify KFREE_BULK_MAX_ENTR macro (Nico Pache) [1894223]
- [kernel] rcu/tree: Make debug_objects logic independent of rcu_head (Nico Pache) [1894223]
- [kernel] rcu/tree: Repeat the monitor if any free channel is busy (Nico Pache) [1894223]
- [kernel] rcu/tree: Skip entry into the page allocator for PREEMPT_RT (Nico Pache) [1894223]
- [kernel] rcu/tree: Keep kfree_rcu() awake during lock contention (Nico Pache) [1894223]
- [kernel] rcu: Fix a kernel-doc warnings for "count" (Nico Pache) [1894223]
- [kernel] rcu/tree: Count number of batched kfree_rcu() locklessly (Nico Pache) [1894223]
- [kernel] rcu/tree: Add a shrinker to prevent OOM due to kfree_rcu() batching (Nico Pache) [1894223]
- [kernel] rcuperf: Measure memory footprint during kfree_rcu() test (Nico Pache) [1894223]
- [kernel] rcu: Add a trace event for kfree_rcu() use of kfree_bulk() (Nico Pache) [1894223]
- [kernel] rcu: Support kfree_bulk() interface in kfree_rcu() (Nico Pache) [1894223]
- [mm] kasan: fix clang compilation warning due to stack protector (Nico Pache) [1894223]
- [mm] kasan: disable branch tracing for core runtime (Nico Pache) [1894223]
- [mm] kasan: add missing functions declarations to kasan.h (Nico Pache) [1894223]
- [mm] kasan: consistently disable debugging features (Nico Pache) [1894223]
- [mm] kasan: unset panic_on_warn before calling panic() (Nico Pache) [1894223]
- [mm] kasan: detect negative size in memory operation function (Nico Pache) [1894223]
- [mm] kasan: No KASAN's memmove check if archs don't have it (Nico Pache) [1894223]
- [mm] kasan: use apply_to_existing_page_range() for releasing vmalloc shadow (Nico Pache) [1894223]
- [mm] kasan: fix crashes on access to memory mapped by vm_map_ram() (Nico Pache) [1894223]
- [mm] mm/kasan/common.c: fix compile error (Nico Pache) [1894223]
- [mm] kasan: support backing vmalloc space with real shadow memory (Nico Pache) [1894223]
- [mm] mm/vmalloc: rework vmap_area_lock (Nico Pache) [1894223]
- [mm] mm/vmalloc: remove preempt_disable/enable when doing preloading (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: switch to WARN_ON() and move it under unlink_va() (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: get rid of one single unlink_va() when merge (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: preload a CPU with one object for split purpose (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: remove "node" argument (Nico Pache) [1894223]
- [mm] mm/vmalloc: modify struct vmap_area to reduce its size (Nico Pache) [1894223]
- [mm] mm/vmalloc: do not keep unpurged areas in the busy tree (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: fix percpu free VM area search criteria (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: avoid bogus -Wmaybe-uninitialized warning (Nico Pache) [1894223]
- [mm] mm/vmap: add DEBUG_AUGMENT_LOWEST_MATCH_CHECK macro (Nico Pache) [1894223]
- [mm] mm/vmap: add DEBUG_AUGMENT_PROPAGATE_CHECK macro (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: keep track of free blocks for vmap allocation (Nico Pache) [1894223]
- [mm] mm/vmalloc.c: convert vmap_lazy_nr to atomic_long_t (Nico Pache) [1894223]
- [mm] mm/kasan: change kasan_check_{read, write} to return boolean (Nico Pache) [1894223]
- [mm] mm/kasan: introduce __kasan_check_{read, write} (Nico Pache) [1894223]
- [mm] kasan: fix coccinelle warnings in kasan_p*_table (Nico Pache) [1894223]
- [mm] kasan: fix kasan_check_read/write definitions (Nico Pache) [1894223]
- [lib] kasan: remove use after scope bugs detection (Nico Pache) [1894223]
- [lib] kasan: remove clang version check for KASAN_STACK (Nico Pache) [1894223]
- [lib] kasan: turn off asan-stack for clang-8 and earlier (Nico Pache) [1894223]
- [block] nbd: fix a block_device refcount leak in nbd_release (Ming Lei) [1901400]
- [tools] selftests: Set default protocol for raw sockets in nettest (Hangbin Liu) [1898813]
- [tools] selftests/net: improve descriptions for XFAIL cases in psock_snd.sh (Hangbin Liu) [1898813]
- [tools] selftests: rtnetlink: make kci_test_encap() return sub-test result (Hangbin Liu) [1898813]
- [tools] selftests: net: ip_defrag: modprobe missing nf_defrag_ipv6 support (Hangbin Liu) [1898813]
- [tools] selftests: use LDLIBS for libraries instead of LDFLAGS (Hangbin Liu) [1898813]
- [tools] selftests: tls: run all tests for TLS 1.2 and TLS 1.3 (Hangbin Liu) [1898813]
- [tools] selftests/net: add definition for SOL_DCCP to fix compilation errors for old libc (Hangbin Liu) [1898813]
- [tools] selftests: net: reuseport_addr_any: silence clang warning (Hangbin Liu) [1898813]
- [tools] selftests: net: refactor reuseport_addr_any test (Hangbin Liu) [1898813]
- [tools] selftests: net: reuseport_addr_any: add DCCP (Hangbin Liu) [1898813]
- [tools] selftests: net: test that listening sockets match on address properly (Hangbin Liu) [1898813]
- [tools] selftests/net: make udpgso_bench skip unsupported testcases (Hangbin Liu) [1898813]
- [tools] net/udpgso_bench.sh test fails on error (Hangbin Liu) [1898813]
- [tools] net/udpgso_bench.sh add UDP GSO audit tests (Hangbin Liu) [1898813]
- [tools] selftests: extend zerocopy tests to udp (Hangbin Liu) [1898813]
- [tools] net/udpgso_bench_tx: options to exercise TX CMSG (Hangbin Liu) [1898813]
- [tools] selftests: fixes for UDP GRO (Hangbin Liu) [1898813]
- [tools] selftests/net: replace obsolete NFT_CHAIN configuration (Hangbin Liu) [1898813]
- [tools] selftests: explicitly require kernel features needed by udpgro tests (Hangbin Liu) [1898813]
- [tools] selftests: add explicit test for multiple concurrent GRO sockets (Hangbin Liu) [1898813]
- [tools] selftests: add functionals test for UDP GRO (Hangbin Liu) [1898813]
- [tools] selftests: add some benchmark for UDP GRO (Hangbin Liu) [1898813]
- [tools] selftests: add GRO support to udp bench rx program (Hangbin Liu) [1898813]
- [net] sctp: change to hold/put transport for proto_unreach_timer (Xin Long) [1897084]
- [scsi] scsi: qedi: Add schedule_hw_err_handler callback for fan failure (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Add support for handling PCIe errors (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Add firmware error recovery invocation support (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Mark all connections for recovery on link down event (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Use snprintf instead of sprintf (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Protect active command list to avoid list corruption (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Fix list_del corruption while removing active I/O (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Skip firmware connection termination for PCI shutdown handler (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Use qed count from set_fp_int in msix allocation (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Remove redundant NULL check (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Staticify non-external function 'qedi_get_iscsi_error' (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Demote seemingly unintentional kerneldoc header (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Remove set but unused variable 'tmp' (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Remove 2 set but unused variables (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Remove unused variable udev & uctrl (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Remove comparison of 0/1 to bool variable (Nilesh Javali) [1854121]
- [scsi] scsi: qedi: Check for buffer overflow in qedi_set_path() (Nilesh Javali) [1854121]
- [scsi] scsi: qedf: Remove redundant assignment to variable 'rc' (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Retry qed->probe during recovery (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Add schedule_hw_err_handler callback for fan failure (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Return SUCCESS if stale rport is encountered (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: FDMI attributes correction (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Use pci_get_dsn() (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Fix for the session's E_D_TOV value (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Correct the comment in qedf_initiate_els (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Change the debug parameter permission to read & write (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Fix null ptr reference in qedf_stag_change_work (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Fix race between ELS completion and flushing ELS request (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Don't process ELS completion if event is flushed or cleaned up (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Initiate cleanup for ELS commands as well (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Send cleanup even for RRQ on timeout (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Do not kill timeout work for original I/O on RRQ completion (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Check the validity of rjt frame before processing (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Check for port type and role before processing an event (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Demote obvious misuse of kerneldoc to standard comment blocks (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Remove a whole host of unused variables (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Remove set but not checked variable 'tmp' (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Demote obvious misuse of kerneldoc to standard comment blocks (Nilesh Javali) [1854122]
- [scsi] scsi: qedf: Remove redundant initialization of variable rc (Nilesh Javali) [1854122]
- [infiniband] RDMA/qedr: Fix memory leak in iWARP CM (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix function prototype parameters alignment (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix inline size returned for iWARP (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix iWARP active mtu display (Manish Chopra) [1857857]
- [netdrv] qede: Notify qedr when mtu has changed (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix return code if accept is called on a destroyed qp (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix use of uninitialized field (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix doorbell setting (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix qp structure memory leak (Manish Chopra) [1857857]
- [netdrv] net: qed: RDMA personality shouldn't fail VF load (Manish Chopra) [1857857]
- [netdrv] net: qede: Disable aRFS for NPAR and 100G (Manish Chopra) [1857857]
- [netdrv] net: qed: Disable aRFS for NPAR and 100G (Manish Chopra) [1857857]
- [netdrv] net: qed: use eth_zero_addr() to clear mac address (Manish Chopra) [1857857]
- [netdrv] net: qede: use eth_zero_addr() to clear mac address (Manish Chopra) [1857857]
- [netdrv] qede: Use pM format specifier for MAC addresses (Manish Chopra) [1857857]
- [netdrv] qed: Use pM format specifier for MAC addresses (Manish Chopra) [1857857]
- [infiniband] qed: fix assignment of n_rq_elems to incorrect params field (Manish Chopra) [1857857]
- [netdrv] qed: fix the allocation of the chains with an external PBL (Manish Chopra) [1857857]
- [netdrv] qede: add .ndo_xdp_xmit() and XDP_REDIRECT support (Manish Chopra) [1857857]
- [netdrv] qede: refactor XDP Tx processing (Manish Chopra) [1857857]
- [netdrv] qede: reformat net_device_ops declarations (Manish Chopra) [1857857]
- [netdrv] qede: reformat several structures in "qede.h" (Manish Chopra) [1857857]
- [include] qed: introduce qed_chain_get_elem_used{, u32}() (Manish Chopra) [1857857]
- [include] qed: optimize common chain accessors (Manish Chopra) [1857857]
- [infiniband] qed: add support for different page sizes for chains (Manish Chopra) [1857857]
- [netdrv] qed: simplify chain allocation with init params struct (Manish Chopra) [1857857]
- [netdrv] qed: simplify initialization of the chains with an external PBL (Manish Chopra) [1857857]
- [netdrv] qed: move chain initialization inlines next to allocation functions (Manish Chopra) [1857857]
- [netdrv] qed: sanitize PBL chains allocation (Manish Chopra) [1857857]
- [netdrv] qed: prevent possible double-frees of the chains (Manish Chopra) [1857857]
- [netdrv] qed: move chain methods to a separate file (Manish Chopra) [1857857]
- [netdrv] qed: reformat Makefile (Manish Chopra) [1857857]
- [include] qed: reformat "qed_chain.h" a bit (Manish Chopra) [1857857]
- [netdrv] net: qed_hsi.h: Avoid the use of one-element array (Manish Chopra) [1857857]
- [netdrv] net: qed: Remove unneeded cast from memory allocation (Manish Chopra) [1857857]
- [netdrv] qed: suppress false-positives interrupt error messages on HW init (Manish Chopra) [1857857]
- [netdrv] qed: suppress "don't support RoCE & iWARP" flooding on HW init (Manish Chopra) [1857857]
- [netdrv] qed: Fix ILT and XRCD bitmap memory leaks (Manish Chopra) [1857857]
- [netdrv] qed: add support for the extended speed and FEC modes (Manish Chopra) [1857857]
- [netdrv] qed: populate supported link modes maps on module init (Manish Chopra) [1857857]
- [netdrv] qed: add missing loopback modes (Manish Chopra) [1857857]
- [netdrv] qed: add support for new port modes (Manish Chopra) [1857857]
- [netdrv] qed: remove unused qed_hw_info::port_mode and QED_PORT_MODE (Manish Chopra) [1857857]
- [netdrv] qed: reformat several structures a bit (Manish Chopra) [1857857]
- [netdrv] qede: introduce support for FEC control (Manish Chopra) [1857857]
- [netdrv] qede: format qede{,_vf}_ethtool_ops (Manish Chopra) [1857857]
- [netdrv] qed: add support for Forward Error Correction (Manish Chopra) [1857857]
- [netdrv] qed: reformat several structures a bit (Manish Chopra) [1857857]
- [netdrv] qed: use transceiver data to fill link partner's advertising speeds (Manish Chopra) [1857857]
- [netdrv] qed: add support for multi-rate transceivers (Manish Chopra) [1857857]
- [netdrv] qed: reformat public_port::transceiver_data a bit (Manish Chopra) [1857857]
- [netdrv] qede: populate supported link modes maps on module init (Manish Chopra) [1857857]
- [netdrv] qed, qede, qedf: convert link mode from u32 to ETHTOOL_LINK_MODE (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Add EDPM max size to alloc ucontext response (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Add EDPM mode type for user-fw compatibility (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: SRQ's bug fixes (Manish Chopra) [1857857]
- [include] net: qed: drop duplicate words in comments (Manish Chopra) [1857857]
- [netdrv] qede: convert to new udp_tunnel_nic infra (Manish Chopra) [1857857]
- [netdrv] qed: Disable "MFW indication via attention" SPAM every 5 minutes (Manish Chopra) [1857857]
- [netdrv] qed: Populate nvm-file attributes while reading nvm config partition (Manish Chopra) [1857857]
- [netdrv] net: qede: fix BE vs CPU comparison (Manish Chopra) [1857857]
- [netdrv] net: qede: fix kernel-doc for qede_ptp_adjfreq() (Manish Chopra) [1857857]
- [netdrv] net: qed: sanitize BE/LE data processing (Manish Chopra) [1857857]
- [netdrv] net: qed: use ptr shortcuts to dedup field accessing in some parts (Manish Chopra) [1857857]
- [netdrv] net: qed: improve indentation of some parts of code (Manish Chopra) [1857857]
- [netdrv] net: qed: address kernel-doc warnings (Manish Chopra) [1857857]
- [netdrv] net: qed: correct qed_hw_err_notify() prototype (Manish Chopra) [1857857]
- [netdrv] net: qed: cleanup global structs declarations (Manish Chopra) [1857857]
- [netdrv] net: qed: move static iro_arrout of header file (Manish Chopra) [1857857]
- [netdrv] qed: Make symbol 'qed_hw_err_type_descr' static (Manish Chopra) [1857857]
- [netdrv] net: qede: update copyright years (Manish Chopra) [1857857]
- [netdrv] net: qede: convert to SPDX License Identifiers (Manish Chopra) [1857857]
- [netdrv] net: qede: correct existing SPDX tags (Manish Chopra) [1857857]
- [netdrv] net: qed: update copyright years (Manish Chopra) [1857857]
- [netdrv] net: qed: convert to SPDX License Identifiers (Manish Chopra) [1857857]
- [netdrv] net: qed: correct existing SPDX tags (Manish Chopra) [1857857]
- [netdrv] qed: add missing error test for DBG_STATUS_NO_MATCHING_FRAMING_MODE (Manish Chopra) [1857857]
- [netdrv] net: qed: fix "maybe uninitialized" warning (Manish Chopra) [1857857]
- [netdrv] net: qed: reset ILT block sizes before recomputing to fix crashes (Manish Chopra) [1857857]
- [netdrv] net: qede: fix use-after-free on recovery and AER handling (Manish Chopra) [1857857]
- [netdrv] net: qede: fix PTP initialization on recovery (Manish Chopra) [1857857]
- [netdrv] net: qed: fix excessive QM ILT lines consumption (Manish Chopra) [1857857]
- [netdrv] net: qed: fix NVMe login fails over VFs (Manish Chopra) [1857857]
- [netdrv] net: qede: stop adding events on an already destroyed workqueue (Manish Chopra) [1857857]
- [netdrv] net: qed: fix async event callbacks unregistering (Manish Chopra) [1857857]
- [include] net: qed: fix left elements count calculation (Manish Chopra) [1857857]
- [infiniband] RDMA/qedr: Fix KASAN: use-after-free in ucma_event_handler+0x532 (Manish Chopra) [1857857]
- [netdrv] qed: Add EDPM mode type for user-fw compatibility (Manish Chopra) [1857857]
- [netdrv] qed: Add XRC to RoCE (Manish Chopra) [1857857]
- [netdrv] qed: changes to ILT to support XRC (Manish Chopra) [1857857]
- [include] net: qed: fix bad formatting (Manish Chopra) [1857857]
- [netdrv] net: qed: introduce critical hardware error handler (Manish Chopra) [1857857]
- [netdrv] net: qed: introduce critical fan failure handler (Manish Chopra) [1857857]
- [netdrv] net: qede: Implement ndo_tx_timeout (Manish Chopra) [1857857]
- [netdrv] net: qede: optional hw recovery procedure (Manish Chopra) [1857857]
- [netdrv] net: qed: attention clearing properties (Manish Chopra) [1857857]
- [netdrv] net: qed: cleanup debug related declarations (Manish Chopra) [1857857]
- [netdrv] net: qed: critical err reporting to management firmware (Manish Chopra) [1857857]
- [netdrv] net: qed: invoke err notify on critical areas (Manish Chopra) [1857857]
- [netdrv] net: qede: add hw err scheduled handler (Manish Chopra) [1857857]
- [netdrv] net: qed: adding hw_err states and handling (Manish Chopra) [1857857]
- [netdrv] net: qede: Use true for bool variable in qede_init_fp() (Manish Chopra) [1857857]
- [netdrv] qed: Make ll2_cbs static (Manish Chopra) [1857857]
- [netdrv] qede: Add support for handling the pcie errors (Manish Chopra) [1857857]
- [netdrv] qed: Enable device error reporting capability (Manish Chopra) [1857857]
- [netdrv] qed: use true,false for bool variables (Manish Chopra) [1857857]
- [netdrv] net: qed: Remove unneeded cast from memory allocation (Manish Chopra) [1857857]
- [netdrv] net: qede: reject unsupported coalescing params (Manish Chopra) [1857857]
- [scsi] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 440 (Manish Chopra) [1857857]
- [scsi] treewide: Add SPDX license identifier - Makefile/Kconfig (Manish Chopra) [1857857]
- [netdrv] sfc: don't double-down() filters in ef100_reset() (Jarod Wilson) [1856681]
- [netdrv] sfc: Fix error code in probe (Jarod Wilson) [1856681]
- [netdrv] sfc: fix boolreturn.cocci warning and rename function (Jarod Wilson) [1856681]
- [netdrv] sfc: Use 'pci_channel_state_t' instead of 'enum pci_channel_state' (Jarod Wilson) [1856681]
- [netdrv] sfc: Use fallthrough pseudo-keyword (Jarod Wilson) [1856681]
- [netdrv] sfc: fix build warnings on 32-bit (Jarod Wilson) [1856681]
- [netdrv] sfc: don't free_irq()s if they were never requested (Jarod Wilson) [1856681]
- [netdrv] sfc: null out channel->rps_flow_id after freeing it (Jarod Wilson) [1856681]
- [netdrv] sfc: take correct lock in ef100_reset() (Jarod Wilson) [1856681]
- [netdrv] sfc: really check hash is valid before using it (Jarod Wilson) [1856681]
- [netdrv] sfc: check hash is valid before using it (Jarod Wilson) [1856681]
- [netdrv] sfc: fix ef100 design-param checking (Jarod Wilson) [1856681]
- [netdrv] sfc: Fix build with CONFIG_RFS_ACCEL disabled (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: add nic-type for VFs, and bind to them (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: read pf_index at probe time (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: functions for selftests (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: statistics gathering (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: plumb in fini_dmaq (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: RX path for EF100 (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: RX filter table management and related gubbins (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: TX path for EF100 NICs (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: read Design Parameters at probe time (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: fail the probe if NIC uses unsol_ev credits (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: check firmware version at start-of-day (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: remove duplicated include from ef100_netdev.c (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: implement ndo_get_phys_port_{id, name} (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: read device MAC address at probe time (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: probe the PHY and configure the MAC (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: actually perform resets (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: extend ef100_check_caps to cover datapath_caps3 (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: read datapath caps, implement check_caps (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: process events for MCDI completions (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: implement ndo_open/close and EVQ probing (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: implement MCDI transport (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: don't call efx_reset_down()/up() on EF100 (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: PHY probe stub (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: reset-handling stub (Jarod Wilson) [1856681]
- [netdrv] sfc: skeleton EF100 PF driver (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: register accesses on EF100 (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: add EF100 register definitions (Jarod Wilson) [1856681]
- [netdrv] sfc: remove efx_ethtool_nway_reset() (Jarod Wilson) [1856681]
- [netdrv] sfc: drop unnecessary list_empty (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: helper function to set default RSS table of given size (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: NVRAM selftest support code (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: populate BUFFER_SIZE_BYTES in INIT_RXQ (Jarod Wilson) [1856681]
- [netdrv] sfc_ef100: add EF100 to NIC-revision enumeration (Jarod Wilson) [1856681]
- [netdrv] sfc: get drvinfo driver name from outside the common code (Jarod Wilson) [1856681]
- [netdrv] sfc: initialise RSS context ID to 'no RSS context' in efx_init_struct() (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise efx_fini_dmaq (Jarod Wilson) [1856681]
- [netdrv] sfc: factor out efx_mcdi_filter_table_down() from _remove() (Jarod Wilson) [1856681]
- [netdrv] sfc: don't call tx_limit_len if NIC type doesn't have one (Jarod Wilson) [1856681]
- [netdrv] sfc: assign TXQs without gaps (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise netif_set_real_numx_queues calls (Jarod Wilson) [1856681]
- [netdrv] sfc: make tx_queues_per_channel variable at runtime (Jarod Wilson) [1856681]
- [netdrv] sfc: move modparam 'rss_cpus' out of common channel code (Jarod Wilson) [1856681]
- [netdrv] sfc: move modparam 'interrupt_mode' out of common channel code (Jarod Wilson) [1856681]
- [netdrv] sfc: remove max_interrupt_mode (Jarod Wilson) [1856681]
- [netdrv] sfc: support setting MTU even if not privileged to configure MAC fully (Jarod Wilson) [1856681]
- [netdrv] sfc: don't call tx_remove if there isn't one (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise initialisation of efx->vport_id (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise efx->xq_entries initialisation (Jarod Wilson) [1856681]
- [netdrv] sfc: initialise max_channels in efx_init_channels() (Jarod Wilson) [1856681]
- [netdrv] sfc: move definition of EFX_MC_STATS_GENERATION_INVALID (Jarod Wilson) [1856681]
- [netdrv] sfc: factor out efx_tx_tso_header_length() and understand encapsulation (Jarod Wilson) [1856681]
- [netdrv] sfc: remove duplicate declaration of efx_enqueue_skb_tso() (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise TSO fallback code (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise efx_sync_rx_buffer() (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise some MAC configuration code (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise miscellaneous efx functions (Jarod Wilson) [1856681]
- [netdrv] sfc: add missing licence info to mcdi_filters.c (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise MCDI MAC stats handling (Jarod Wilson) [1856681]
- [netdrv] sfc: move NIC-specific mcdi_port declarations out of common header (Jarod Wilson) [1856681]
- [netdrv] sfc: extend common GRO interface to support CHECKSUM_COMPLETE (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise ARFS handling (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise drain event handling (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise PCI error handlers (Jarod Wilson) [1856681]
- [netdrv] sfc: track which BAR is mapped (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise FC advertising (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise other ethtool bits (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise ethtool NFC and RXFH/RSS functions (Jarod Wilson) [1856681]
- [netdrv] sfc: commonise ethtool link handling functions (Jarod Wilson) [1856681]
- [netdrv] sfc: split up nic.h (Jarod Wilson) [1856681]
- [netdrv] sfc: refactor EF10 stats handling (Jarod Wilson) [1856681]
- [netdrv] sfc: don't try to create more channels than we can have VIs (Jarod Wilson) [1856681]
- [netdrv] sfc: extend bitfield macros up to POPULATE_DWORD_13 (Jarod Wilson) [1856681]
- [netdrv] sfc: determine flag word automatically in efx_has_cap() (Jarod Wilson) [1856681]
- [netdrv] sfc: update MCDI protocol headers (Jarod Wilson) [1856681]
- [netdrv] sfc: replace '---help---' in Kconfig files with 'help' (Jarod Wilson) [1856681]
- [netdrv] sfc: add missing annotation for efx_ef10_try_update_nic_stats_vf() (Jarod Wilson) [1856681]
- [netdrv] sfc: avoid an unused-variable warning (Jarod Wilson) [1856681]
- [netdrv] sfc: fix dereference of table before it is null checked (Jarod Wilson) [1856681]
- [netdrv] sfc: siena_check_caps() can be static (Jarod Wilson) [1856681]
- [netdrv] sfc: actually wire up siena_check_caps() (Jarod Wilson) [1856681]
- [netdrv] sfc: make firmware-variant printing a nic_type function (Jarod Wilson) [1856681]
- [netdrv] sfc: make filter table probe caller responsible for adding VLANs (Jarod Wilson) [1856681]
- [netdrv] sfc: move rx_rss_context_exclusive into struct efx_mcdi_filter_table (Jarod Wilson) [1856681]
- [netdrv] sfc: rework handling of (firmware) multicast chaining state (Jarod Wilson) [1856681]
- [netdrv] sfc: move 'must restore' flags out of ef10-specific nic_data (Jarod Wilson) [1856681]
- [netdrv] sfc: use efx_has_cap for capability checks outside of NIC-specific code (Jarod Wilson) [1856681]
- [netdrv] sfc: make capability checking a nic_type function (Jarod Wilson) [1856681]
- [netdrv] sfc: move vport_id to struct efx_nic (Jarod Wilson) [1856681]
- [ntb] NTB: Revert "Add Hygon Device ID" (Myron Stowe) [1880468]
- [tools] NTB: ntb_test: Fix bug when counting remote files (Myron Stowe) [1908031]
- [ntb] NTB: perf: Fix race condition when run with ntb_test (Myron Stowe) [1908031]
- [ntb] NTB: perf: Fix support for hardware that doesn't have port numbers (Myron Stowe) [1908031]
- [ntb] NTB: perf: Don't require one more memory window than number of peers (Myron Stowe) [1908031]
- [ntb] NTB: ntb_pingpong: Choose doorbells based on port number (Myron Stowe) [1908031]
- [ntb] NTB: Fix the default port and peer numbers for legacy drivers (Myron Stowe) [1908031]
- [ntb] NTB: Revert the change to use the NTB device dev for DMA allocations (Myron Stowe) [1908031]
- [ntb] NTB: ntb_tool: reading the link file should not end in a NULL byte (Myron Stowe) [1908031]
- [ntb] ntb_perf: avoid false dma unmap of destination address (Myron Stowe) [1908031]
- [ntb] ntb_perf: increase sleep time from one milli sec to one sec (Myron Stowe) [1908031]
- [ntb] ntb_tool: pass correct struct device to dma_alloc_coherent (Myron Stowe) [1908031]
- [ntb] ntb_perf: pass correct struct device to dma_alloc_coherent (Myron Stowe) [1908031]
- [include] NTB: correct ntb_peer_spad_addr and ntb_peer_spad_read comment typos (Myron Stowe) [1908031]
- [ntb] ntb: intel: fix static declaration (Myron Stowe) [1908031]
- [ntb] ntb: intel: add hw workaround for NTB BAR alignment (Myron Stowe) [1908031]
- [ntb] ntb: intel: Add Icelake (gen4) support for Intel NTB (Myron Stowe) [1908031]
- [ntb] NTB: Fix static check warning in perf_clear_test (Myron Stowe) [1908031]
- [include] include/ntb: Fix typo in ntb_unregister_device description (Myron Stowe) [1908031]
- [ntb] NTB: add pci shutdown handler for AMD NTB (Myron Stowe) [1908031]
- [ntb] NTB: send DB event when driver is loaded or un-loaded (Myron Stowe) [1908031]
- [ntb] NTB: remove redundant setting of DB valid mask (Myron Stowe) [1908031]
- [ntb] NTB: return link up status correctly for PRI and SEC (Myron Stowe) [1908031]
- [ntb] NTB: add helper functions to set and clear sideinfo (Myron Stowe) [1908031]
- [ntb] NTB: move ntb_ctrl handling to init and deinit (Myron Stowe) [1908031]
- [ntb] NTB: handle link up, D0 and D3 events correctly (Myron Stowe) [1908031]
- [ntb] NTB: handle link down event correctly (Myron Stowe) [1908031]
- [ntb] NTB: remove handling of peer_sta from amd_link_is_up (Myron Stowe) [1908031]
- [ntb] NTB: set peer_sta within event handler itself (Myron Stowe) [1908031]
- [ntb] NTB: return the side info status from amd_poll_link (Myron Stowe) [1908031]
- [ntb] NTB: define a new function to get link status (Myron Stowe) [1908031]
- [ntb] NTB: Enable link up and down event notification (Myron Stowe) [1908031]
- [ntb] NTB: clear interrupt status register (Myron Stowe) [1908031]
- [ntb] NTB: Fix access to link status and control register (Myron Stowe) [1908031]
- [ntb] NTB: ntb_transport: Use scnprintf() for avoiding potential buffer overflow (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: Fix ntb_mw_clear_trans error if size == 0 (Myron Stowe) [1908031]
- [ntb] ntb_tool: Fix printk format (Myron Stowe) [1908031]
- [ntb] NTB: ntb_perf: Fix address err in perf_copy_chunk (Myron Stowe) [1908031]
- [ntb] NTB: Fix an error in get link status (Myron Stowe) [1908031]
- [ntb] NTB: Add Hygon Device ID (Myron Stowe) [1908031]
- [ntb] NTB: fix IDT Kconfig typos/spellos (Myron Stowe) [1908031]
- [ntb] ntb_hw_amd: Add memory window support for new AMD hardware (Myron Stowe) [1908031]
- [ntb] ntb_hw_amd: Add a new NTB PCI device ID (Myron Stowe) [1908031]
- [ntb] NTB: ntb_transport: remove redundant assignment to rc (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: make ntb_mw_set_trans() work when addr == 0 (Myron Stowe) [1908031]
- [ntb] ntb: point to right memory window index (Myron Stowe) [1908031]
- [ntb] NTB/msi: remove incorrect MODULE defines (Myron Stowe) [1908031]
- [documentation] NTB: Describe the ntb_msi_test client in the documentation (Myron Stowe) [1908031]
- [ntb] NTB: Add MSI interrupt support to ntb_transport (Myron Stowe) [1908031]
- [tools] NTB: Add ntb_msi_test support to ntb_test (Myron Stowe) [1908031]
- [ntb] NTB: Introduce NTB MSI Test Client (Myron Stowe) [1908031]
- [ntb] NTB: Introduce MSI library (Myron Stowe) [1908031]
- [ntb] NTB: Rename ntb.c to support multiple source files in the module (Myron Stowe) [1908031]
- [include] NTB: Introduce functions to calculate multi-port resource index (Myron Stowe) [1908031]
- [include] NTB: Introduce helper functions to calculate logical port number (Myron Stowe) [1908031]
- [pci] PCI/switchtec: Add module parameter to request more interrupts (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: Fix setup MW with failure bug (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: Skip unnecessary re-setup of shared memory window for crosslink case (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: Remove redundant steps of switchtec_ntb_reinit_peer() function (Myron Stowe) [1908031]
- [include] NTB: correct ntb_dev_ops and ntb_dev comment typos (Myron Stowe) [1908031]
- [ntb] NTB: amd: Silence shift wrapping warning in amd_ntb_db_vector_mask() (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: potential shift wrapping bug in switchtec_ntb_init_sndev() (Myron Stowe) [1908031]
- [ntb] NTB: ntb_transport: Ensure qp->tx_mw_dma_addr is initaliazed (Myron Stowe) [1908031]
- [ntb] NTB: ntb_hw_amd: set peer limit register (Myron Stowe) [1908031]
- [ntb] NTB: ntb_perf: Clear stale values in doorbell and command SPAD register (Myron Stowe) [1908031]
- [ntb] NTB: ntb_perf: Disable NTB link after clearing peer XLAT registers (Myron Stowe) [1908031]
- [ntb] NTB: ntb_perf: Increased the number of message retries to 1000 (Myron Stowe) [1908031]
- [ntb] ntb: intel: Make intel_ntb3_peer_db_addr static (Myron Stowe) [1908031]
- [ntb] NTB: add new parameter to peer_db_addr() db_bit and db_data (Myron Stowe) [1908031]
- [ntb] NTB: ntb_transport: Ensure the destination buffer is mapped for TX DMA (Myron Stowe) [1908031]
- [ntb] NTB: ntb_transport: Free MWs in ntb_transport_link_cleanup() (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: Added support of >=4G memory windows (Myron Stowe) [1908031]
- [include] ntb_hw_switchtec: NT req id mapping table register entry number should be 512 (Myron Stowe) [1908031]
- [ntb] ntb_hw_switchtec: debug print 64bit aligned crosslink BAR Numbers (Myron Stowe) [1908031]
- [ntb] ntb: idt: Alter the driver info comments (Myron Stowe) [1908031]
- [ntb] ntb: idt: Discard temperature sensor IRQ handler (Myron Stowe) [1908031]
- [ntb] ntb: idt: Add basic hwmon sysfs interface (Myron Stowe) [1908031]
- [ntb] ntb: idt: Alter temperature read method (Myron Stowe) [1908031]
- [netdrv] ntb_netdev: Simplify remove with client device drvdata (Myron Stowe) [1908031]
- [ntb] NTB: transport: Try harder to alloc an aligned MW buffer (Myron Stowe) [1908031]
- [ntb] ntb: ntb_transport: Mark expected switch fall-throughs (Myron Stowe) [1908031]
- [ntb] ntb: idt: Set PCIe bus address to BARLIMITx (Myron Stowe) [1908031]
- [ntb] NTB: ntb_hw_idt: replace IS_ERR_OR_NULL with regular NULL checks (Myron Stowe) [1908031]
- [ntb] ntb: intel: fix return value for ndev_vec_mask() (Myron Stowe) [1908031]
- [netdrv] ntb_netdev: fix sleep time mismatch (Myron Stowe) [1908031]

* Wed Dec 16 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-263.el8]
- [block] block: fix incorrect branching in blk_max_size_offset() (Mike Snitzer) [1903722]
- [md] dm: fix IO splitting (Mike Snitzer) [1903722]
- [block] block: fix get_max_io_size() (Mike Snitzer) [1903722]
- [block] block: Improve physical block alignment of split bios (Mike Snitzer) [1903722]
- [block] block: use gcd() to fix chunk_sectors limit stacking (Mike Snitzer) [1903722]
- [kernel] sched/deadline: Fix priority inheritance with multiple scheduling classes (Phil Auld) [1780490]
- [fs] Convert trailing spaces and periods in path components (Leif Sahlberg) [1882457]
- [block] loop: Fix occasional uevent drop (Ming Lei) [1897401]
- [block] block: add a return value to set_capacity_revalidate_and_notify (Ming Lei) [1897401]
- [fs] fat: truncate inode timestamp updates in setattr (Pavel Reichl) [1533270]
- [fs] fat: change timestamp updates to use fat_truncate_time (Pavel Reichl) [1533270]
- [fs] fat: add functions to update and truncate timestamps appropriately (Pavel Reichl) [1533270]
- [fs] fat: create a function to calculate the timezone offest (Pavel Reichl) [1533270]
- [net] icmp: randomize the global rate limiter (Guillaume Nault) [1899137]
- [net] ipv4: Restore flowi4_oif update before call to xfrm_lookup_route (Guillaume Nault) [1899137]
- [net] ipv4: Update exception handling for multipath routes via same device (Guillaume Nault) [1899137]
- [net] ip: fix tos reflection in ack and reset packets (Guillaume Nault) [1899137]
- [net] initialize fastreuse on inet_inherit_port (Guillaume Nault) [1899137]
- [net] refactor bind_bucket fastreuse into helper (Guillaume Nault) [1899137]
- [infiniband] RDMA/bnxt_re: Remove set but not used variable 'qplib_ctx' (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Remove the qp from list only if the qp destroy succeeds (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Fix driver crash on unaligned PSN entry address (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Restrict the max_gids to 256 (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Static NQ depth allocation (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Fix the qp table indexing (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Do not report transparent vlan from QP1 (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Change wr posting logic to accommodate variable wqes (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Add helper data structures (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Pull psn buffer dynamically based on prod (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: introduce a function to allocate swq (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: introduce wqe mode to select execution path (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt: Delete 'nq_ptr' variable which is not used (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Remove dead code from rcfw (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Simplify obtaining queue entry from hw ring (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Update missing hsi data structures (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Reduce device page size detection code (Selvin Xavier) [1861886]
- [infiniband] RDMA/bnxt_re: Remove unsupported modify_device callback (Selvin Xavier) [1861886]
- [include] net: Add netif_is_bareudp() API to identify bareudp devices (Guillaume Nault) [1839788]
- [net] Removed the device type check to add mpls support for devices (Guillaume Nault) [1839788]
- [tools] selftests: set conf.all.rp_filter=0 in bareudp.sh (Guillaume Nault) [1839788]
- [tools] selftests: disable rp_filter when testing bareudp (Guillaume Nault) [1839788]
- [tools] selftests: add test script for bareudp tunnels (Guillaume Nault) [1839788]
- [documentation] bareudp: Corrected description of bareudp module. (Guillaume Nault) [1839788]
- [netdrv] bareudp: forbid mixing IP and MPLS in multiproto mode (Guillaume Nault) [1839788]
- [netdrv] bareudp: Reverted support to enable & disable rx metadata collection (Guillaume Nault) [1839788]
- [documentation] bareudp: update iproute2 sample commands (Guillaume Nault) [1839788]
- [netdrv] bareudp: Added attribute to enable & disable rx metadata collection (Guillaume Nault) [1839788]
- [netdrv] bareudp: Fixed multiproto mode configuration (Guillaume Nault) [1839788]
- [netdrv] bareudp: Fixed configuration to avoid having garbage values (Guillaume Nault) [1839788]
- [netdrv] net: bareudp: avoid uninitialized variable warning (Guillaume Nault) [1839788]
- [netdrv] bareudp: Fixed bareudp receive handling (Guillaume Nault) [1839788]
- [netdrv] bareudp: remove unnecessary udp_encap_enable() in bareudp_socket_create() (Guillaume Nault) [1839788]
- [netdrv] bareudp: print error message when command fails (Guillaume Nault) [1839788]
- [netdrv] bareudp: add module alias (Guillaume Nault) [1839788]
- [netdrv] bareudp: Fix uninitialized variable warnings. (Guillaume Nault) [1839788]
- [netdrv] Special handling for IP & MPLS. (Guillaume Nault) [1839788]
- [net] UDP tunnel encapsulation module for tunnelling different protocols like MPLS, IP, NSH etc. (Guillaume Nault) [1839788]
- [arm64] arm64: remove arm64ksyms.c (Mark Salter) [1883365]
- [arm64] arm64: frace: use asm EXPORT_SYMBOL() (Mark Salter) [1883365]
- [arm64] arm64: string: use asm EXPORT_SYMBOL() (Mark Salter) [1883365]
- [arm64] arm64: uaccess: use asm EXPORT_SYMBOL() (Mark Salter) [1883365]
- [arm64] arm64: page: use asm EXPORT_SYMBOL() (Mark Salter) [1883365]
- [arm64] arm64: smccc: use asm EXPORT_SYMBOL() (Mark Salter) [1883365]
- [arm64] arm64: tishift: use asm EXPORT_SYMBOL() (Mark Salter) [1883365]
- [arm64] arm64: add EXPORT_SYMBOL_NOKASAN() (Mark Salter) [1883365]
- [mm] arm64: move memstart_addr export inline (Mark Salter) [1883365]
- [arm64] arm64: remove bitop exports (Mark Salter) [1883365]
- [arm64] arm64: lib: use C string functions with KASAN enabled (Mark Salter) [1883365]
- [arm64] arm64: add <asm/asm-prototypes.h> (Mark Salter) [1883365]
- [arm64] locking/atomics/arm64, arm64/bitops: Include <asm-generic/bitops/ext2-atomic-setbit.h> (Mark Salter) [1883365]
- [arm64] locking/atomics/arm64: Replace our atomic/lock bitop implementations with asm-generic (Mark Salter) [1883365]
- [include] locking/atomics, asm-generic/bitops/lock.h: Rewrite using atomic_fetch_*() (Mark Salter) [1883365]
- [include] locking/atomics, asm-generic/bitops/atomic.h: Rewrite using atomic_*() APIs (Mark Salter) [1883365]
- [thermal] thermal: rcar_thermal: Add missing braces to conditional statement (Ivan Vecera) [1894564]
- [thermal] thermal: Rename set_mode() to change_mode() (Ivan Vecera) [1894564]
- [thermal] thermal: Simplify or eliminate unnecessary set_mode() methods (Ivan Vecera) [1894564]
- [thermal] thermal: core: Stop polling DISABLED thermal devices (Ivan Vecera) [1894564]
- [thermal] thermal: Explicitly enable non-changing thermal zone devices (Ivan Vecera) [1894564]
- [thermal] thermal: Use mode helpers in drivers (Ivan Vecera) [1894564]
- [thermal] thermal: Add mode helpers (Ivan Vecera) [1894564]
- [thermal] thermal: remove get_mode() operation of drivers (Ivan Vecera) [1894564]
- [thermal] thermal: Store device mode in struct thermal_zone_device (Ivan Vecera) [1894564]
- [include] thermal: Add current mode to thermal zone device (Ivan Vecera) [1894564]
- [acpi] thermal: Store thermal mode in a dedicated enum (Ivan Vecera) [1894564]
- [acpi] acpi: thermal: Fix error handling in the register function (Ivan Vecera) [1894564]
- [thermal] thermal: core: skip update disabled thermal zones after suspend (Ivan Vecera) [1894564]
- [thermal] Thermal: do not clear passive state during system sleep (Ivan Vecera) [1894564]
- [thermal] thermal: of-thermal: disable passive polling when thermal zone is disabled (Ivan Vecera) [1894564]
- [crypto] crypto: qat - drop input parameter from adf_enable_aer() (Vladis Dronov) [1855190]
- [crypto] crypto: qat - fix function parameters descriptions (Vladis Dronov) [1855190]
- [crypto] crypto: qat - remove unnecessary mutex_init() (Vladis Dronov) [1855190]
- [crypto] crypto: qat - use PCI_VDEVICE (Vladis Dronov) [1855190]
- [crypto] crypto: qat - replace device ids defines (Vladis Dronov) [1855190]
- [crypto] crypto: qat - include domain in top level debugfs path (Vladis Dronov) [1855190]
- [crypto] crypto: qat - check cipher length for aead AES-CBC-HMAC-SHA (Vladis Dronov) [1855190]
- [crypto] crypto: qat - Use fallthrough pseudo-keyword (Vladis Dronov) [1855190]
- [crypto] crypto: qat - add delay before polling mailbox (Vladis Dronov) [1855190]
- [include] PCI: Add Intel QuickAssist device IDs (Vladis Dronov) [1855190]
- [crypto] crypto: qat - fix double free in qat_uclo_create_batch_init_list (Vladis Dronov) [1855190]
- [crypto] crypto: qat - fallback for xts with 192 bit keys (Vladis Dronov) [1855190]
- [crypto] crypto: qat - remove unused field in skcipher ctx (Vladis Dronov) [1855190]
- [crypto] crypto: qat - validate xts key (Vladis Dronov) [1855190]
- [crypto] crypto: qat - allow xts requests not multiple of block (Vladis Dronov) [1855190]
- [crypto] crypto: qat - update timeout logic in put admin msg (Vladis Dronov) [1855190]
- [crypto] crypto: qat - send admin messages to set of AEs (Vladis Dronov) [1855190]
- [crypto] crypto: qat - update fw init admin msg (Vladis Dronov) [1855190]
- [crypto] crypto: qat - remove packed attribute in etr structs (Vladis Dronov) [1855190]
- [crypto] crypto: qat - replace user types with kernel ABI __u types (Vladis Dronov) [1855190]
- [crypto] crypto: qat - replace user types with kernel u types (Vladis Dronov) [1855190]
- [crypto] crypto: qat - convert to SPDX License Identifiers (Vladis Dronov) [1855190]
- [crypto] crypto: qat - simplify the qat_crypto function (Vladis Dronov) [1855190]
- [crypto] crypto: qat - spelling s/Decrytp/Decrypt/ (Vladis Dronov) [1855190]
- [crypto] crypto: qat/adf_aer - Replace GFP_ATOMIC with GFP_KERNEL in adf_dev_aer_schedule_reset() (Vladis Dronov) [1855190]
- [thermal] thermal: int340x: processor_thermal: fix: update Jasper Lake PCI id (David Arcari) [1889331]
- [thermal] thermal: int3403_thermal: Downgrade error message (David Arcari) [1889331]
- [thermal] thermal/int340x_thermal: Prevent page fault on .set_mode() op (David Arcari) [1889331]
- [thermal] thermal/int340x_thermal: Don't require IDSP to exist (David Arcari) [1889331]
- [thermal] thermal/int340x_thermal: Export OEM vendor variables (David Arcari) [1889331]
- [thermal] thermal/int340x_thermal: Export GDDV (David Arcari) [1889331]
- [thermal] thermal: int3400_thermal: Statically initialize .get_mode()/.set_mode() ops (David Arcari) [1889331]
- [thermal] thermal: int340x_thermal: fix: Update Tiger Lake ACPI device IDs (David Arcari) [1889331]
- [thermal] thermal: int340x_thermal: Use scnprintf() for avoiding potential buffer overflow (David Arcari) [1889331]
- [thermal] thermal: int340x: processor_thermal: Add Tiger Lake support (David Arcari) [1889331]
- [platform] acpi: Remove header dependency (David Arcari) [1889331]
- [thermal] thermal: int340x: switch to use <linux/units.h> helpers (David Arcari) [1889331]
- [thermal] thermal: int340x: processor_thermal: Add Jasper Lake support (David Arcari) [1889331]
- [thermal] thermal: int340x_thermal: Add Tiger Lake ACPI device IDs (David Arcari) [1889331]
- [thermal] thermal: intel: int3403: replace printk(KERN_WARN...) with pr_warn(...) (David Arcari) [1889331]
- [thermal] thermal: intel: int340x_thermal: Remove unnecessary acpi_has_method() uses (David Arcari) [1889331]
- [thermal] thermal: int340x: processor_thermal: Add Ice Lake support (David Arcari) [1889331]
- [thermal] drivers: thermal: processor_thermal_device: Export sysfs interface for TCC offset (David Arcari) [1889331]
- [netdrv] net/mlx5e: Fix arch depending casting issue in FEC (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Kconfig: convert imply usage to weak dependency (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Fix condition for termination table cleanup (Alaa Hleihel) [1858559 1851700]
- [netdrv] net/mlx5: Use a separate work queue for fib event handling (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Add support for RDMA TX flow table (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Add support for RDMA TX steering (Alaa Hleihel) [1858559]
- [infiniband] IB/mlx5: Move to fully dynamic UAR mode once user space supports it (Alaa Hleihel) [1858559]
- [infiniband] IB/mlx5: Limit the scope of struct mlx5_bfreg_info to mlx5_ib (Alaa Hleihel) [1858559]
- [infiniband] IB/mlx5: Extend QP creation to get uar page index from user space (Alaa Hleihel) [1858559]
- [infiniband] IB/mlx5: Extend CQ creation to get uar page index from user space (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Avoid group version scan when not necessary (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Avoid incrementing FTE version (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Simplify matching group searches (Alaa Hleihel) [1858559]
- [infiniband] IB/mlx5: Generally use the WC auto detection test result (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Avoid forwarding to other eswitch uplink (Alaa Hleihel) [1858559 1851700]
- [netdrv] net/mlx5: Eswitch, enable forwarding back to uplink port (Alaa Hleihel) [1858559 1851700]
- [netdrv] net/mlx5e: Add support for offloading traffic from uplink to uplink (Alaa Hleihel) [1858559 1851700]
- [netdrv] net/mlx5: Don't use termination tables in slow path (Alaa Hleihel) [1858559 1851700]
- [netdrv] net/mlx5: Avoid configuring eswitch QoS if not supported (Alaa Hleihel) [1858559 1851700]
- [netdrv] net/mlx5: DR, Add support for flow table id destination action (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-Switch, Refactor unload all reps per rep type (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-Switch, Update VF vports config when num of VFs changed (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-Switch, Introduce per vport configuration for eswitch modes (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-switch, Make vport setup/cleanup sequence symmetric (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-Switch, Prepare for vport enable/disable refactor (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-Switch, Remove redundant warning when QoS enable failed (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-Switch, Remove redundant check of eswitch manager cap (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Allow MRs to be created in the cache synchronously (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Revise how the hysteresis scheme works for cache filling (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Fix locking in MR cache work queue (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Lock access to ent->available_mrs/limit when doing queue_work (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Fix MR cache size and limit debugfs (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Always remove MRs from the cache before destroying them (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Simplify how the MR cache bucket is located (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Rename the tracking variables for the MR cache (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Replace spinlock protected write with atomic var (Alaa Hleihel) [1858559]
- [infiniband] {IB, net}/mlx5: Move asynchronous mkey creation to mlx5_ib (Alaa Hleihel) [1858559]
- [infiniband] {IB, net}/mlx5: Assign mkey variant in mlx5_ib only (Alaa Hleihel) [1858559]
- [infiniband] {IB, net}/mlx5: Setup mkey variant before mr create command invocation (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Use offsetofend() instead of duplicated variant (Alaa Hleihel) [1858559]
- [infiniband] RDMA/mlx5: Remove duplicate definitions of SW_ICM macros (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: E-switch, make query inline mode a static function (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Allocate smaller size tables for ft offload (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Introduce TLS and IPSec objects enums (Alaa Hleihel) [1858559]
- [include] net/mlx5: Introduce egress acl forward-to-vport capability (Alaa Hleihel) [1858559]
- [infiniband] IB/mlx5: Add np_min_time_between_cnps and rp_max_rate debug params (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Fix header guard in rsc_dump.h (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Replace zero-length array with flexible-array member (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Remove a useless 'drain_workqueue()' call in 'mlx5e_ipsec_cleanup()' (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Add support for FEC modes based on 50G per lane links (Alaa Hleihel) [1858559]
- [netdrv] net/mlxe5: Separate between FEC and current speed (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Advertise globaly supported FEC modes (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Enforce setting of a single FEC mode (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Set FEC to auto when configured mode is not supported (Alaa Hleihel) [1858559]
- [netdrv] mlx5: Use proper logging and tracing line terminations (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Support dump callback in RX reporter (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Support dump callback in TX reporter (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5e: Gather reporters APIs together (Alaa Hleihel) [1858559]
- [netdrv] net/mlx5: Add support for resource dump (Alaa Hleihel) [1858559]
- [netdrv] bnxt_en: Fix wrong flag value passed to HWRM_PORT_QSTATS_EXT fw call (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix HWRM_FUNC_QSTATS_EXT firmware call (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Return -EOPNOTSUPP for ETHTOOL_GREGS on VFs (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Protect bnxt_set_eee() and bnxt_set_pauseparam() with mutex (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: return proper error codes in bnxt_show_temp (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Use memcpy to copy VPD field info (Jonathan Toppins) [1861885]
- [netdrv] net: ethernet: broadcom: have drivers select DIMLIB as needed (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix NULL ptr dereference crash in bnxt_fw_reset_task() (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Avoid sending firmware messages when AER error is detected (Jonathan Toppins) [1861885]
- [netdrv] bnxt: don't enable NAPI until rings are ready (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Setup default RSS map in all scenarios (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: init RSS table for Minimal-Static VF reservation (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: fix HWRM error when querying VF temperature (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix possible crash in bnxt_fw_reset_task() (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix PCI AER error recovery flow (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix ethtool -S statitics with XDP or TCs enabled (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Check for zero dir entries in NVRAM (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Don't query FW when netif_running() is false (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Remove superfluous memset() (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Add support for 'ethtool -d' (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Switch over to use the 64-bit software accumulated counters (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Accumulate all counters (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Retrieve hardware masks for port counters (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Retrieve hardware counter masks from firmware if available (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Allocate additional memory for all statistics blocks (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Refactor statistics code and structures (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Use macros to define port statistics size and offset (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Update firmware interface to 1.10.1.54 (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Remove PCIe non-counters from ethtool statistics (Jonathan Toppins) [1861885]
- [netdrv] net: bnxt: don't complain if TC flower can't be supported (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix completion ring sizing with TPA enabled (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Init ethtool link settings after reading updated PHY configuration (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix race when modifying pause settings (Jonathan Toppins) [1861885]
- [netdrv] bnxt: convert to new udp_tunnel_nic infra (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: allow firmware to disable VLAN offloads (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: clean up VLAN feature bit handling (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Implement ethtool -X to set indirection table (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Return correct RSS indirection table entries to ethtool -x (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fill HW RSS table from the RSS logical indirection table (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Add helper function to return the number of RSS contexts (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Add logical RSS indirection table structure (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix up bnxt_get_rxfh_indir_size() (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Set up the chip specific RSS table size (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Read VPD info only for PFs (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix statistics counters issue during ifdown with older firmware (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Do not enable legacy TX push on older firmware (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Store the running firmware version code (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Add board.serial_number field to info_get cb (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Return from timer if interface is not in open state (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix AER reset logic on 57500 chips (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Re-enable SRIOV during resume (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Simplify bnxt_resume() (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: fix firmware message length endianness (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix return code to "flash_device" (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Fix accumulation of bp->net_stats_prev (Jonathan Toppins) [1861885]
- [netdrv] net: bnxt: Remove Comparison to bool in bnxt_ethtool.c (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: show only relevant ethtool stats for a TX or RX ring (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Split HW ring statistics strings into RX and TX parts (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Refactor the software ring counters (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Add doorbell information to bnxt_en_dev struct (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Add support for L2 doorbell size (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Set the db_offset on 57500 chips for the RDMA MSIX entries (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Define the doorbell offsets on 57500 chips (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Improve kernel log messages related to ethtool reset (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: fix ethtool_reset_flags ABI violations (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: refactor ethtool firmware reset types (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: prepare to refactor ethtool reset types (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Do not include ETH_FCS_LEN in the max packet length sent to fw (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Improve TQM ring context memory sizing formulas (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Allocate TQM ring context memory according to fw specification (Jonathan Toppins) [1861885]
- [netdrv] bnxt_en: Update firmware spec. to 1.10.1.33 (Jonathan Toppins) [1861885]
- [fs] fs/namespace.c: fix mountpoint reference counter race (Pavel Reichl) [1852651] {CVE-2020-12114}

* Sun Dec 13 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-262.el8]
- [powerpc] powerpc/64: Fix kernel stack 16-byte alignment (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/aout: Fix struct user definition to use user_pt_regs (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/uapi: Fix sigcontext definition to use user_pt_regs (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] bpf: powerpc: fix broken uapi for BPF_PROG_TYPE_PERF_EVENT (Desnes Augusto Nunes do Rosario) [1854528]
- [tools] selftests/powerpc: Tests for kernel accessing user memory (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint/ptrace: Introduce PPC_DEBUG_FEATURE_DATA_BP_ARCH_31 (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix exception handling for CONFIG_HAVE_HW_BREAKPOINT=N (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix length calculation for unaligned target (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Move DAWR detection logic outside of hw_breakpoint.c (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint/ptrace: Fix SETHWDEBUG when CONFIG_HAVE_HW_BREAKPOINT=N (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix handling of vector instructions (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix quadword instruction handling on p10 predecessors (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/hw_breakpoint.h: delete duplicated word (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Remove 512 byte boundary (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Return available watchpoints dynamically (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Guest support for 2nd DAWR hcall (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Set CPU_FTR_DAWR1 based on pa-features bit (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/dt_cpu_ftrs: Add feature for 2nd DAWR (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Enable watchpoint functionality on power10 guest (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix DAWR exception for CACHEOP (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix DAWR exception constraint (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Fix 512 byte boundary limit (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] hw-breakpoints: Fix build warnings with clang (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint/xmon: Support 2nd DAWR (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint/xmon: Don't allow breakpoint overwriting (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Don't allow concurrent perf and ptrace events (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Prepare handler to handle more than one watchpoint (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Use builtin ALIGN*() macros (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Introduce is_ptrace_bp() function (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Use loop for thread_struct->ptrace_bps (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Convert thread_struct->hw_brk to an array (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Disable all available watchpoints when !dawr_force_enable (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Get watchpoint count dynamically while disabling them (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Provide DAWR number to __set_breakpoint (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Provide DAWR number to set_dawr (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint/ptrace: Return actual num of available watchpoints (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Introduce function to get nr watchpoints dynamically (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Add SPRN macros for second DAWR (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: move ptrace_triggered() into hw_breakpoint.c (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: create ppc_gethwdinfo() (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: create ptrace_get_debugreg() (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: split out ADV_DEBUG_REGS related functions (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: move register viewing functions out of ptrace.c (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: split out TRANSACTIONAL_MEM related functions (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: split out SPE related functions (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: split out ALTIVEC related functions (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: split out VSX related functions (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: drop PARAMETER_SAVE_AREA_OFFSET (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: drop unnecessary #ifdefs CONFIG_PPC64 (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: remove unused header includes (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc: Move ptrace into a subdirectory (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/watchpoint: Don't call dar_within_range() for Book3S (Desnes Augusto Nunes do Rosario) [1854528]
- [tools] selftests/powerpc: Enable range tests on 8xx in ptrace-hwbreak.c selftest (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/hw_breakpoints: Rewrite 8xx breakpoints to allow any address range size (Desnes Augusto Nunes do Rosario) [1854528]
- [tools] powerpc/watchpoint: Support for 8xx in ptrace-hwbreak.c selftest (Desnes Augusto Nunes do Rosario) [1854528]
- [tools] powerpc/watchpoint: Add DAR outside test in perf-hwbreak.c selftest (Desnes Augusto Nunes do Rosario) [1854528]
- [tools] selftests/powerpc: Rewrite ptrace-hwbreak.c selftest (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc: permanently include 8xx registers in reg.h (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: Simplify vr_get/set() to avoid GCC warning (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/64: Interrupts save PPR on stack rather than thread_struct (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc: Use SWITCH_FRAME_SIZE for prom and rtas entry (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc/ptrace: Don't use sizeof(struct pt_regs) in ptrace code (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc: Split user/kernel definitions of struct pt_regs (Desnes Augusto Nunes do Rosario) [1854528]
- [powerpc] powerpc: declare set_breakpoint() static (Desnes Augusto Nunes do Rosario) [1854528]
- [tools] perf vendor events power9: Added nest imc metric events (Michael Petlan) [1780258]
- [powerpc] powerpc/perf: Fix crashes with generic_compat_pmu & BHRB (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Exclude pmc5/6 from the irrelevant PMU group constraints (Michael Petlan) [1854525]
- [powerpc] powerpc/powernv/idle: add a basic stop 0-3 driver for POWER10 (Michael Petlan) [1854525]
- [powerpc] powerpc/kernel: Cleanup machine check function declarations (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Fix soft lockups due to missed interrupt accounting (Michael Petlan) [1854525]
- [powerpc] powerpc: Add POWER10 raw mode cputable entry (Michael Petlan) [1854525]
- [powerpc] powerpc/powernv: Machine check handler for POWER10 (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Add extended regs support for power10 platform (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Add support for outputting extended regs in perf intr_regs (Michael Petlan) [1854525]
- [tools] perf tools powerpc: Add support for extended regs in power10 (Michael Petlan) [1854525]
- [tools] perf tools powerpc: Add support for extended register capability (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Fix MMCRA_BHRB_DISABLE define for binutils < 2.28 (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Initialize power10 PMU registers in cpu setup routine (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: BHRB control to disable BHRB logic when not used (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Add Power10 BHRB filter support for PERF_SAMPLE_BRANCH_IND_CALL/COND (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Ignore the BHRB kernel address filtering for P10 (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: power10 Performance Monitoring support (Michael Petlan) [1854525]
- [powerpc] powerpc/perf: Add Power10 PMU feature to DT CPU features (Michael Petlan) [1854525]
- [powerpc] powerpc/xmon: Add PowerISA v3.1 PMU SPRs (Michael Petlan) [1854525]
- [powerpc] powerpc64: Break asm/percpu.h vs spinlock_types.h dependency (Greg Kurz) [1882796]
- [powerpc] watchpoint: Rename current DAWR macros (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Make struct kernel_param_ops definition const (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: simplify kvm_cma_reserve() (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s: Fix symbol undeclared warnings (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s: Remove redundant initialization of variable ret (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: xive: Convert to DEFINE_SHOW_ATTRIBUTE (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Set LPCR[HDICE] before writing HDEC (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Do not allocate HPT for a nested guest (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: Don't return -ENOTSUPP to userspace in ioctls (Greg Kurz) [1882796]
- [powerpc] 64s: handle ISA v3.1 local copy-paste context switches (Greg Kurz) [1882796]
- [powerpc] 64s: Move HMI IRQ stat from percpu variable to paca (Greg Kurz) [1882796]
- [powerpc] kvm/cma: Improve kernel log during boot (Greg Kurz) [1882796]
- [powerpc] kvm: Use correct CONFIG symbol in comment (Greg Kurz) [1882796]
- [powerpc] watchpoint: Rename current H_SET_MODE DAWR macro (Greg Kurz) [1882796]
- [tools] kvm: ppc: Fix typo on H_DISABLE_AND_GET hcall (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: Clean up redundant kvm_run parameters in assembly (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Save/restore new PMU registers (Greg Kurz) [1882796]
- [powerpc] perf: Add support for ISA3.1 PMU SPRs (Greg Kurz) [1882796]
- [powerpc] perf: Update Power PMU cache_events to u64 type (Greg Kurz) [1882796]
- [powerpc] perf: Update cpu_hw_event to use `struct` for storing MMCR registers (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Cleanup updates for kvm vcpu MMCR (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: Protect kvm_vcpu_read_guest with srcu locks (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Increase KVMPPC_NR_LPIDS on POWER8 and POWER9 (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3shv: Enable support for ISA v3.1 guests (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s pr: Remove uninitialized_var() usage (Greg Kurz) [1882796]
- [powerpc] kvm/book3s64: Fix kernel crash with nested kvm & DEBUG_VIRTUAL (Greg Kurz) [1882796]
- [powerpc] book3s64/kvm: Fix secondary page table walk warning during migration (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s: Fix some RCU-list locks (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Ignore kmemleak false positives (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: Clean up redundant 'kvm_run' parameters (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: Remove redundant kvm_run from vcpu_arch (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Remove redundant NULL check (Greg Kurz) [1882796]
- [powerpc] Fix compile issue with force DAWR (Greg Kurz) [1882796]
- [powerpc] silence a -Wcast-function-type warning in dawr_write_file_bool (Greg Kurz) [1882796]
- [powerpc] kvm: ppc: book3s hv: Fix r3 corruption in h_set_dabr() (Greg Kurz) [1882796]
- [powerpc] Add force enable of DAWR on P9 option (Greg Kurz) [1882796]
- [documentation] powerpc: Document issues with the DAWR on POWER9 (Greg Kurz) [1882796]
- [powerpc] Replace _ALIGN_UP() by ALIGN() (Greg Kurz) [1882796]
- [powerpc] Replace _ALIGN_DOWN() by ALIGN_DOWN() (Greg Kurz) [1882796]
- [netdrv] tg3: Fix soft lockup when tg3_reset_task() fails (Jonathan Toppins) [1899595]
- [tools] tools/power turbostat: update version number (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: harden against cpu hotplug (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: adjust for temperature offset (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Build with _FILE_OFFSET_BITS=64 (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Support AMD Family 19h (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Remove empty columns for Jacobsville (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Add a new GFXAMHz column that exposes gt_act_freq_mhz (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Skip pc8, pc9, pc10 columns, if they are disabled (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Fix output formatting for ACPI CST enumeration (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Replace HTTP links with HTTPS ones: TURBOSTAT UTILITY (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Enable accumulate RAPL display (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Introduce functions to accumulate RAPL consumption (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Make the energy variable to be 64 bit (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Always print idle in the system configuration header (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Print /dev/cpu_dma_latency (Prarit Bhargava) [1857136]
- [tools] turbostat/.gitignore: add SPDX License Identifier (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: update version (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Print cpuidle information (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Fix 32-bit capabilities warning (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Fix missing SYS_LPI counter on some Chromebooks (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Fix gcc build warnings (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Support Elkhart Lake (Prarit Bhargava) [1857136]
- [tools] tools/power turbostat: Support Jasper Lake (Prarit Bhargava) [1857136]
- [scsi] scsi: core: Return BLK_STS_AGAIN for ALUA transitioning (Ewan Milne) [1867264]
- [scsi] scsi: scsi_dh_alua: Set 'transitioning' state on Unit Attention (Ewan Milne) [1867264]
- [scsi] scsi: scsi_dh_alua: Return BLK_STS_AGAIN for ALUA transitioning state (Ewan Milne) [1867264]
- [block] scsi: block: Return status code in blk_mq_end_request() (Ewan Milne) [1867264]
- [scsi] scsi: scsi_dh_alua: Avoid crash during alua_bus_detach() (Ewan Milne) [1877156]
- [fs] gfs2: check for live vs. read-only file system in gfs2_fitrim (Abhijith Das) [1335139]
- [fs] gfs2: don't initialize statfs_change inodes in spectator mode (Abhijith Das) [1335139]
- [fs] gfs2: init_journal's undo directive should also undo the statfs inodes (Abhijith Das) [1335139]
- [fs] gfs2: Recover statfs info in journal head (Abhijith Das) [1335139]
- [fs] gfs2: lookup local statfs inodes prior to journal recovery (Abhijith Das) [1335139]
- [fs] gfs2: Add fields for statfs info in struct gfs2_log_header_host (Abhijith Das) [1335139]
- [block] nbd: don't update block size after device is started (Ming Lei) [1891363]
- [platform] platform/x86: thinkpad_acpi: lap or desk mode interface (David Arcari) [1889642]
- [infiniband] IB/mlx4: Convert rej_tmout radix-tree to XArray (Alaa Hleihel) [1858564]
- [infiniband] IB/mlx4: Adjust delayed work when a dup is observed (Alaa Hleihel) [1858564]
- [infiniband] IB/mlx4: Add support for REJ due to timeout (Alaa Hleihel) [1858564]
- [infiniband] IB/mlx4: Fix starvation in paravirt mux/demux (Alaa Hleihel) [1858564]
- [infiniband] IB/mlx4: Separate tunnel and wire bufs parameters (Alaa Hleihel) [1858564]
- [infiniband] IB/mlx4: Add support for MRA (Alaa Hleihel) [1858564]
- [infiniband] IB/mlx4: Add and improve logging (Alaa Hleihel) [1858564]
- [netdrv] net: ethernet: mlx4: Avoid assigning a value to ring_cons but not used it anymore in mlx4_en_xmit() (Alaa Hleihel) [1858564]
- [netdrv] net: ethernet: mlx4: Fix memory allocation in mlx4_buddy_init() (Alaa Hleihel) [1858564]
- [infiniband] treewide: Use fallthrough pseudo-keyword (Alaa Hleihel) [1858564]
- [netdrv] net/mlx4: Use fallthrough pseudo-keyword (Alaa Hleihel) [1858564]
- [netdrv] mlx4: convert to new udp_tunnel_nic infra (Alaa Hleihel) [1858564]
- [netdrv] mlx4: Mark PM functions as __maybe_unused (Alaa Hleihel) [1858564]
- [netdrv] mlx4: use generic power management (Alaa Hleihel) [1858564]
- [netdrv] mlx4: disable device on shutdown (Alaa Hleihel) [1858564 1858563]
- [include] IB/mlx4: Replace zero-length array with flexible-array (Alaa Hleihel) [1858564 1858563]
- [netdrv] net: mlx4: remove unneeded variable "err" in mlx4_en_ethtool_add_mac_rule() (Alaa Hleihel) [1858564 1858563]
- [netdrv] net: mlx4: remove unneeded variable "err" in mlx4_en_get_rxfh() (Alaa Hleihel) [1858564 1858563]
- [netdrv] net/mlx4_en: use napi_complete_done() in TX completion (Alaa Hleihel) [1858564 1858563]
- [netdrv] net/mlx4_en: avoid indirect call in TX completion (Alaa Hleihel) [1858564 1858562]
- [infiniband] RDMA/mlx4: Delete duplicated offsetofend implementation (Alaa Hleihel) [1858564 1858562]
- [netdrv] net: mlx4: reject unsupported coalescing params (Alaa Hleihel) [1858564 1858562]
- [hwmon] hwmon: (amd_energy) match for supported models (David Arcari) [1860387]
- [hwmon] hwmon: (amd_energy) Missing platform_driver_unregister() on error in amd_energy_init() (David Arcari) [1860387]
- [hwmon] hwmon: Add amd_energy driver to report energy counters (David Arcari) [1860387]
- [include] include/asm-generic/topology.h: guard cpumask_of_node() macro argument (David Arcari) [1860387]

* Fri Dec 11 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-261.el8]
- [x86] x86/dumpstack: Fix misleading instruction pointer error message (Kenneth Yin) [1903506]
- [powerpc] powerpc/powernv/opal-dump : Use IRQ_HANDLED instead of numbers in interrupt handler (Diego Domingos) [1891822]
- [powerpc] powerpc/powernv/dump: Handle multiple writes to ack attribute (Diego Domingos) [1891822]
- [powerpc] powerpc/powernv/dump: Fix race while processing OPAL dump (Diego Domingos) [1891822]
- [powerpc] powerpc/opal_elog: Handle multiple writes to ack attribute (Diego Domingos) [1891822]
- [powerpc] powerpc/powernv/elog: Fix race while processing OPAL error log event (Diego Domingos) [1891822]
- [hid] HID: logitech-dj: Fix an error in mse_bluetooth_descriptor (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-dj: Fix Dinovo Mini when paired with a MX5x00 receiver (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-dj: Handle quad/bluetooth keyboards with a builtin trackpad (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: Add PID for MX Anywhere 2 (Benjamin Tissoires) [1885560]
- [hid] HID: wacom: Avoid entering wacom_wac_pen_report for pad / battery (Benjamin Tissoires) [1885560]
- [hid] HID: ite: Add USB id match for Acer One S1003 keyboard dock (Benjamin Tissoires) [1885560]
- [hid] HID: multitouch: Lenovo X1 Tablet Gen3 trackpoint and buttons (Benjamin Tissoires) [1885560]
- [hid] HID: hid-input: fix stylus battery reporting (Benjamin Tissoires) [1885560]
- [hid] HID: roccat: add bounds checking in kone_sysfs_write_settings() (Benjamin Tissoires) [1885560]
- [hid] HID: core: Sanitize event code and type when mapping input (Benjamin Tissoires) [1885560]
- [hid] HID: core: Correctly handle ReportSize being zero (Benjamin Tissoires) [1885560]
- [hid] HID: elan: Fix memleak in elan_input_configured (Benjamin Tissoires) [1885560]
- [hid] HID: microsoft: Add rumble support for the 8bitdo SN30 Pro+ controller (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for all Saitek X52 devices (Benjamin Tissoires) [1885560]
- [hid] Revert "HID: usbhid: do not sleep when opening device" (Benjamin Tissoires) [1885560]
- [hid] HID: hiddev: Fix slab-out-of-bounds write in hiddev_ioctl_usage() (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Always poll three more Lenovo PixArt mice (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: Always sleep 60ms after I2C_HID_PWR_ON commands (Benjamin Tissoires) [1885560]
- [hid] HID: macally: Constify macally_id_table (Benjamin Tissoires) [1885560]
- [hid] HID: cougar: Constify cougar_id_table (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: add NOGET quirk for Logitech GROUP (Benjamin Tissoires) [1885560]
- [hid] HID: Replace HTTP links with HTTPS ones (Benjamin Tissoires) [1885560]
- [hid] HID: udraw-ps3: Replace HTTP links with HTTPS ones (Benjamin Tissoires) [1885560]
- [hid] HID: input: Fix devices that return multiple bytes in battery report (Benjamin Tissoires) [1885560]
- [hid] HID: lenovo: Fix spurious F23 key press report during resume from suspend (Benjamin Tissoires) [1885560]
- [hid] HID: lenovo: Add ThinkPad 10 Ultrabook Keyboard fn_lock support (Benjamin Tissoires) [1885560]
- [hid] HID: lenovo: Add ThinkPad 10 Ultrabook Keyboard support (Benjamin Tissoires) [1885560]
- [hid] HID: lenovo: Rename fn_lock sysfs attr handlers to make them generic (Benjamin Tissoires) [1885560]
- [hid] HID: lenovo: Factor out generic parts of the LED code (Benjamin Tissoires) [1885560]
- [hid] HID: lenovo: Merge tpkbd and cptkbd data structures (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: avoid repeated "multiplier = " log messages (Benjamin Tissoires) [1885560]
- [hid] HID: logitech: Use HIDPP_RECEIVER_INDEX instead of 0xff (Benjamin Tissoires) [1885560]
- [hid] HID: intel-ish-hid: Replace PCI_DEV_FLAGS_NO_D3 with pci_save_state (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Ignore Simply Automated UPB PIM (Benjamin Tissoires) [1885560]
- [hid] HID: apple: Disable Fn-key key-re-mapping on clone keyboards (Benjamin Tissoires) [1885560]
- [hid] HID: Wiimote: Treat the d-pad as an analogue stick (Benjamin Tissoires) [1885560]
- [hid] HID: steam: fixes race in handling device list (Benjamin Tissoires) [1885560]
- [hid] HID: magicmouse: do not set up autorepeat (Benjamin Tissoires) [1885560]
- [hid] HID: alps: support devices with report id 2 (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Always poll Obins Anne Pro 2 keyboard (Benjamin Tissoires) [1885560]
- [hid] HID: input: do not run GET_REPORT unless there's a Resolution Multiplier (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: add Mediacom FlexBook edge13 to descriptor override (Benjamin Tissoires) [1885560]
- [hid] HID: usbhid: remove redundant assignment to variable retval (Benjamin Tissoires) [1885560]
- [hid] HID: usbhid: do not sleep when opening device (Benjamin Tissoires) [1885560]
- [hid] HID: multitouch: Remove MT_CLS_WIN_8_DUAL (Benjamin Tissoires) [1885560]
- [hid] HID: sony: Fix for broken buttons on DS3 USB dongles (Benjamin Tissoires) [1885560]
- [hid] HID: Add quirks for Trust Panora Graphic Tablet (Benjamin Tissoires) [1885560]
- [hid] HID: apple: Swap the Fn and Left Control keys on Apple keyboards (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: add Schneider SCL142ALM to descriptor override (Benjamin Tissoires) [1885560]
- [hid] HID: intel-ish-hid: avoid bogus uninitialized-variable warning (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Add HID_QUIRK_NO_INIT_REPORTS quirk for Dell K12A keyboard-dock (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: reset Synaptics SYNA2393 on resume (Benjamin Tissoires) [1885560]
- [hid] HID: usbhid: Fix race between usbhid_close() and usbhid_stop() (Benjamin Tissoires) [1885560]
- [hid] HID: alps: ALPS_1657 is too specific; use U1_UNICORN_LEGACY instead (Benjamin Tissoires) [1885560]
- [hid] HID: alps: Add AUI1657 device ID (Benjamin Tissoires) [1885560]
- [hid] HID: fix typo in Kconfig (Benjamin Tissoires) [1885560]
- [hid] HID: logitech: Add support for Logitech G11 extra keys (Benjamin Tissoires) [1885560]
- [hid] HID: multitouch: add eGalaxTouch P80H84 support (Benjamin Tissoires) [1885560]
- [hid] HID: logitech: drop outdated references to unifying receivers (Benjamin Tissoires) [1885560]
- [hid] HID: rmi: Simplify an error handling path in 'rmi_hid_read_block()' (Benjamin Tissoires) [1885560]
- [hid] HID: intel-ish-hid: hbm.h: Replace zero-length array with flexible-array member (Benjamin Tissoires) [1885560]
- [hid] HID: intel-ish-hid: ishtp-dev.h: Replace zero-length array with flexible-array member (Benjamin Tissoires) [1885560]
- [hid] HID: Add driver fixing Glorious PC Gaming Race mouse report descriptor (Benjamin Tissoires) [1885560]
- [hid] HID: lg-g15: Do not fail the probe when we fail to disable F# emulation (Benjamin Tissoires) [1885560]
- [hid] HID: fix Kconfig word ordering (Benjamin Tissoires) [1885560]
- [hid] HID: add ALWAYS_POLL quirk to lenovo pixart mouse (Benjamin Tissoires) [1885560]
- [hid] HID: google: add moonball USB id (Benjamin Tissoires) [1885560]
- [hid] HID: appleir: Use devm_kzalloc() instead of kzalloc() (Benjamin Tissoires) [1885560]
- [hid] HID: appleir: Remove unnecessary goto label (Benjamin Tissoires) [1885560]
- [hid] HID: hid-sensor-custom: Use scnprintf() for avoiding potential buffer overflow (Benjamin Tissoires) [1885560]
- [hid] HID: hid-picolcd_fb: Use scnprintf() for avoiding potential buffer overflow (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-dj: add support for the static device in the Powerplay mat/receiver (Benjamin Tissoires) [1885560]
- [hid] HID: hid-bigbenff: fix race condition for scheduled work during removal (Benjamin Tissoires) [1885560]
- [hid] HID: hid-bigbenff: call hid_hw_stop() in case of error (Benjamin Tissoires) [1885560]
- [hid] HID: hid-bigbenff: fix general protection fault caused by double kfree (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: add Trekstor Surfbook E11B to descriptor override (Benjamin Tissoires) [1885560]
- [hid] HID: alps: Fix an error handling path in 'alps_input_configured()' (Benjamin Tissoires) [1885560]
- [hid] HID: hiddev: Fix race in in hiddev_disconnect() (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-dj: add debug msg when exporting a HID++ report descriptors (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Remove ITE 8595 entry from hid_have_special_driver (Benjamin Tissoires) [1885560]
- [include] HID: core: increase HID report buffer size to 8KiB (Benjamin Tissoires) [1885560]
- [hid] HID: core: fix off-by-one memset in hid_report_raw_event() (Benjamin Tissoires) [1885560]
- [hid] HID: apple: Add support for recent firmware on Magic Keyboards (Benjamin Tissoires) [1885560]
- [hid] HID: ite: Only bind to keyboard USB interface on Acer SW5-012 keyboard dock (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: BatteryVoltage: only read chargeStatus if extPower is active (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: avoid duplicate error handling code in 'hidpp_probe()' (Benjamin Tissoires) [1885560]
- [hid] HID: hidraw, uhid: Always report EPOLLOUT (Benjamin Tissoires) [1885560]
- [hid] HID: steam: Fix input device disappearing (Benjamin Tissoires) [1885560]
- [hid] hid-logitech-hidpp: read battery voltage from newer devices (Benjamin Tissoires) [1885560]
- [hid] HID: logitech: Add MX Master 3 Mouse (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: Support WirelessDeviceStatus connect events (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: Support translations from short to long reports (Benjamin Tissoires) [1885560]
- [hid] HID: hiddev: fix mess in hiddev_open() (Benjamin Tissoires) [1885560]
- [hid] HID: hid-input: clear unmapped usages (Benjamin Tissoires) [1885560]
- [hid] HID: Add quirk for incorrect input length on Lenovo Y720 (Benjamin Tissoires) [1885560]
- [hid] HID: ite: Add USB id match for Acer SW5-012 keyboard dock (Benjamin Tissoires) [1885560]
- [hid] HID: Add quirk for Xin-Mo Dual Controller (Benjamin Tissoires) [1885560]
- [hid] HID: hidraw: add support uniq ioctl (Benjamin Tissoires) [1885560]
- [hid] HID: Fix slab-out-of-bounds read in hid_field_extract (Benjamin Tissoires) [1885560]
- [hid] HID: picoLCD: constify fb ops (Benjamin Tissoires) [1885560]
- [hid] HID: uhid: Fix returning EPOLLOUT from uhid_char_poll (Benjamin Tissoires) [1885560]
- [hid] HID: hidraw: Fix returning EPOLLOUT from hidraw_poll (Benjamin Tissoires) [1885560]
- [hid] HID: rmi: Check that the RMI_STARTED bit is set before unregistering the RMI transport device (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: remove hid-led devices from hid_have_special_driver (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: Reset ALPS touchpads on resume (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: fix no irq after reset on raydium 3118 (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-hidpp: Silence intermittent get_battery_capacity errors (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: remove orphaned member sleep_delay (Benjamin Tissoires) [1885560]
- [hid] HID: quirks: Add quirk for HP MSU1465 PIXART OEM mouse (Benjamin Tissoires) [1885560]
- [hid] HID: core: check whether Usage Page item is after Usage ID items (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: Send power-on command after reset (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: Remove runtime power management (Benjamin Tissoires) [1885560]
- [hid] HID: google: Detect base folded usage instead of hard-coding whiskers (Benjamin Tissoires) [1885560]
- [hid] HID: google: add magnemite/masterball USB ids (Benjamin Tissoires) [1885560]
- [hid] HID: logitech: Add depends on LEDS_CLASS to Logitech Kconfig entry (Benjamin Tissoires) [1885560]
- [hid] HID: lg-g15: Add support for the G510's M1-M3 and MR LEDs (Benjamin Tissoires) [1885560]
- [hid] HID: lg-g15: Add support for controlling the G510's RGB backlight (Benjamin Tissoires) [1885560]
- [hid] HID: lg-g15: Add support for the G510 keyboards' gaming keys (Benjamin Tissoires) [1885560]
- [hid] HID: lg-g15: Add support for the M1-M3 and MR LEDs (Benjamin Tissoires) [1885560]
- [hid] HID: lg-g15: Add keyboard and LCD backlight control (Benjamin Tissoires) [1885560]
- [hid] HID: Add driver for Logitech gaming keyboards (G15, G15 v2) (Benjamin Tissoires) [1885560]
- [hid] HID: hidraw: replace printk() with corresponding pr_xx() variant (Benjamin Tissoires) [1885560]
- [hid] HID: prodikeys: make array keys static const, makes object smaller (Benjamin Tissoires) [1885560]
- [hid] HID: google: whiskers: signal tablet mode on connect (Benjamin Tissoires) [1885560]
- [hid] HID: google: whiskers: signal tablet mode switch on disconnect (Benjamin Tissoires) [1885560]
- [hid] HID: google: whiskers: more robust tablet mode detection (Benjamin Tissoires) [1885560]
- [hid] HID: core: fix dmesg flooding if report field larger than 32bit (Benjamin Tissoires) [1885560]
- [include] HID: core: Add printk_once variants to hid_warn() etc (Benjamin Tissoires) [1885560]
- [include] HID: core: reformat and reduce hid_printk macros (Benjamin Tissoires) [1885560]
- [hid] HID: i2c-hid: modify quirks for weida's devices (Benjamin Tissoires) [1885560]
- [hid] hid-logitech-dj: add the new Lightspeed receiver (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-dj: add support of the G700(s) receiver (Benjamin Tissoires) [1885560]
- [hid] HID: do not call hid_set_drvdata(hdev, NULL) in drivers (Benjamin Tissoires) [1885560]
- [hid] HID: logitech-dj: extend consumer usages range (Benjamin Tissoires) [1885560]
- [hid] hiddev: Return EPOLLOUT from hiddev_poll (Benjamin Tissoires) [1885560]
- [hid] hidraw: Return EPOLLOUT from hidraw_poll (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - add nopnp quirk for Acer Aspire 5 A515 (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - add Entroware Proteus EL07R4 to nomux and reset lists (Benjamin Tissoires) [1885560]
- [input] input: i8042 - Remove special Cayman handling (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - only increment wakeup count on touch (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - add ic type 0x15 (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - add support for high resolution reports (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - do not constantly re-query pattern ID (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - add firmware update info for ICs 0x11, 0x13, 0x14 (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - handle firmware updated on newer ICs (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - add support for different firmware page sizes (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - fix detecting IAP version on older controllers (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - handle devices with patterns above 1 (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - make fetching IC type of older controllers more robust (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - handle firmware not implementing "get pattern" command (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - add Lenovo XiaoXin Air 12 to i8042 nomux list (Benjamin Tissoires) [1885560]
- [input] Input: elantech - remove redundant assignments to variable error (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - enable InterTouch for ThinkPad X1E 1st gen (Benjamin Tissoires) [1885560]
- [uapi] Input: add `SW_MACHINE_COVER` (Benjamin Tissoires) [1885560]
- [input] input: i8042 - Remove special PowerPC handling (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - add a second working PNP_ID for Lenovo T470s (Benjamin Tissoires) [1885560]
- [input] Input: introduce input_mt_report_slot_inactive() (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - add ThinkPad S230u to i8042 reset list (Benjamin Tissoires) [1885560]
- [input] Revert "Input: i8042 - add ThinkPad S230u to i8042 nomux list" (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - attach fwnode to serio i8042 kbd device (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - add ThinkPad S230u to i8042 nomux list (Benjamin Tissoires) [1885560]
- [uapi] Input: update SPDX tag for input-event-codes.h (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - add Acer Aspire 5738z to nomux list (Benjamin Tissoires) [1885560]
- [uapi] Input: move the new KEY_SELECTIVE_SCREENSHOT keycode (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - enable RMI on HP Envy 13-ad105ng (Benjamin Tissoires) [1885560]
- [uapi] Input: allocate keycode for "Selective Screenshot" key (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - remove the LEN0049 dmi id from topbuttonpad list (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - enable SMBus on ThinkPad L470 (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - switch T470s to RMI4 by default (Benjamin Tissoires) [1885560]
- [input] Input: input_event - fix struct padding on sparc64 (Benjamin Tissoires) [1885560]
- [uapi] Input: add privacy screen toggle keycode (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - switch another X1 Carbon 6 to RMI/SMbus (Benjamin Tissoires) [1885560]
- [uapi] Input: Add event-codes for macro keys found on various keyboards (Benjamin Tissoires) [1885560]
- [input] Input: i8042 - enable wakeup on a stable struct device (Benjamin Tissoires) [1885560]
- [input] Input: psmouse - drop all unneeded functions from mouse headers (Benjamin Tissoires) [1885560]
- [input] Input: remove dev_err() usage after platform_get_irq() (Benjamin Tissoires) [1885560]
- [input] Input: synaptics - fix a typo (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - switch to using devm_add_action_or_reset() (Benjamin Tissoires) [1885560]
- [input] Input: elan_i2c - switch to using devm_device_add_groups() (Benjamin Tissoires) [1885560]
- [power] power: supply: core: Add Standard, Adaptive, and Custom charge types (Benjamin Tissoires) [1885560]
- [scsi] scsi: mpt3sas: Fix timeouts observed while reenabling IRQ (Tomas Henzl) [1880114]
- [fs] ext4: handle option set by mount flags correctly (Pavel Reichl) [1848084]
- [fs] xfs: preserve inode versioning across remounts (Pavel Reichl) [1848084]
- [kernel] kheaders: explain why include/config/autoconf.h is excluded from md5sum (Jiri Olsa) [1899585]
- [kernel] kheaders: remove the last bashism to allow sh to run it (Jiri Olsa) [1899585]
- [kernel] kheaders: optimize header copy for in-tree builds (Jiri Olsa) [1899585]
- [kernel] kheaders: optimize md5sum calculation for in-tree builds (Jiri Olsa) [1899585]
- [kernel] kheaders: remove unneeded 'cat' command piped to 'head' / 'tail' (Jiri Olsa) [1899585]
- [kernel] kheaders: substituting --sort in archive creation (Jiri Olsa) [1899585]
- [kernel] kheaders: make headers archive reproducible (Jiri Olsa) [1899585]
- [kernel] kheaders: include only headers into kheaders_data.tar.xz (Jiri Olsa) [1899585]
- [kernel] kheaders: remove meaningless -R option of 'ls' (Jiri Olsa) [1899585]
- [kernel] kheaders: Do not regenerate archive if config is not changed (Jiri Olsa) [1899585]
- [kernel] kheaders: Move from proc to sysfs (Jiri Olsa) [1899585]
- [kernel] kernel/Makefile: don't assume that kernel/gen_ikh_data.sh is executable (Jiri Olsa) [1899585]
- [init] init/config: Do not select BUILD_BIN2C for IKCONFIG (Jiri Olsa) [1899585]
- [kernel] Provide in-kernel headers to make extending kernel easier (Jiri Olsa) [1899585]
- [tty] pty: do tty_flip_buffer_push without port->lock in pty_write (Artem Savkov) [1787975]
- [virtio] virtio_balloon: fix sparse warning (Nico Pache) [1839055]
- [virtio] virtio_balloon: fix up endian-ness for free cmd id (Nico Pache) [1839055]
- [virtio] virtio-balloon: Document byte ordering of poison_val (Nico Pache) [1839055]
- [virtio] virtio-mmio: Reject invalid IRQ 0 command line argument (Nico Pache) [1839055]
- [virtio] virtio-balloon: Disable free page reporting if page poison reporting is not enabled (Nico Pache) [1839055]
- [virtio] virtio-mmio: Delete an error message in vm_find_vqs() (Nico Pache) [1839055]
- [virtio] virtio: add VIRTIO_RING_NO_LEGACY (Nico Pache) [1839055]
- [virtio] virtio-balloon: Avoid using the word 'report' when referring to free page hinting (Nico Pache) [1839055]
- [virtio] virtio-balloon: make virtballoon_free_page_report() static (Nico Pache) [1839055]
- [virtio] virtio-balloon: switch back to OOM handler for VIRTIO_BALLOON_F_DEFLATE_ON_OOM (Nico Pache) [1839055]
- [documentation] mm/page_reporting: add free page reporting documentation (Nico Pache) [1839055]
- [mm] mm/page_reporting: add budget limit on how many pages can be reported per pass (Nico Pache) [1839055]
- [mm] mm/page_reporting: rotate reported pages to the tail of the list (Nico Pache) [1839055]
- [virtio] virtio-balloon: add support for providing free page reports to host (Nico Pache) [1839055]
- [virtio] virtio-balloon: pull page poisoning config out of free page hinting (Nico Pache) [1839055]
- [mm] mm: introduce Reported pages (Nico Pache) [1839055]
- [mm] mm: add function __putback_isolated_page (Nico Pache) [1839055]
- [mm] mm: use zone and order instead of free area in free_list manipulators (Nico Pache) [1839055]
- [mm] mm: adjust shuffle code to allow for future coalescing (Nico Pache) [1839055]
- [virtio] virtio_balloon: Adjust label in virtballoon_probe (Nico Pache) [1839055]
- [virtio] virtio_ring: Fix mem leak with vring_new_virtqueue() (Nico Pache) [1839055]
- [virtio] virtio_balloon: Fix memory leaks on errors in virtballoon_probe() (Nico Pache) [1839055]
- [virtio] virtio-balloon: Fix memory leak when unloading while hinting is in progress (Nico Pache) [1839055]
- [virtio] virtio_balloon: prevent pfn array overflow (Nico Pache) [1839055]
- [virtio] virtio-pci: check name when counting MSI-X vectors (Nico Pache) [1839055]
- [virtio] virtio-balloon: initialize all vq callbacks (Nico Pache) [1839055]
- [virtio] virtio-mmio: convert to devm_platform_ioremap_resource (Nico Pache) [1839055]
- [virtio] virtio_balloon: divide/multiply instead of shifts (Nico Pache) [1839055]
- [virtio] virtio_balloon: name cleanups (Nico Pache) [1839055]
- [virtio] virtio_balloon: fix shrinker count (Nico Pache) [1839055]
- [virtio] virtio_balloon: fix shrinker scan number of pages (Nico Pache) [1839055]
- [virtio] virtio-mmio: add error check for platform_get_irq (Nico Pache) [1839055]
- [virtio] virtio: Fix indentation of VIRTIO_MMIO (Nico Pache) [1839055]
- [virtio] virtio/virtio_ring: do some comment fixes (Nico Pache) [1839055]
- [virtio] virtio_pci: fix a NULL pointer reference in vp_del_vqs (Nico Pache) [1839055]
- [virtio] virtio: hint if callbacks surprisingly might sleep (Nico Pache) [1839055]
- [virtio] virtio_balloon: remove the unnecessary 0-initialization (Nico Pache) [1839055]
- [virtio] virtio-balloon: improve update_balloon_size_func (Nico Pache) [1839055]
- [virtio] virtio-balloon: tweak config_changed implementation (Nico Pache) [1839055]
- [misc] virtio: don't allocate vqs when names= NULL (Nico Pache) [1839055]
- [virtio] virtio_pci: use queue idx instead of array idx to set up the vq (Nico Pache) [1839055]
- [virtio] virtio: remove deprecated VIRTIO_PCI_CONFIG() (Nico Pache) [1839055]
- [mm] mm/page_poison: expose page_poisoning_enabled to kernel modules (Nico Pache) [1839055]
- [virtio] virtio-balloon: VIRTIO_BALLOON_F_PAGE_POISON (Nico Pache) [1839055]
- [virtio] virtio-balloon: VIRTIO_BALLOON_F_FREE_PAGE_HINT (Nico Pache) [1839055]
- [virtio] virtio: pci-legacy: Validate queue pfn (Nico Pache) [1839055]
- [virtio] virtio: mmio-v1: Validate queue PFN (Nico Pache) [1839055]
- [virtio] virtio_balloon: replace oom notifier with shrinker (Nico Pache) [1839055]
- [virtio] virtio-balloon: kzalloc the vb struct (Nico Pache) [1839055]
- [virtio] virtio-balloon: remove BUG() in init_vqs (Nico Pache) [1839055]
- [mm] mm, debug_pagealloc: use a page type instead of page_ext flag (Nico Pache) [1839055]
- [mm] mm, page_alloc: more extensive free page checking with debug_pagealloc (Nico Pache) [1839055]
- [mm] mm, debug_pagelloc: use static keys to enable debugging (Nico Pache) [1839055]
- [include] include/linux/page_ext.h: drop definition of unused PAGE_EXT_DEBUG_POISON (Nico Pache) [1839055]
- [tty] vt: vt_ioctl: fix use-after-free in vt_in_use() (Vladis Dronov) [1875585]
- [tty] vt: vt_ioctl: fix VT_DISALLOCATE freeing in-use virtual console (Vladis Dronov) [1875585]
- [tty] vt: ioctl, switch VT_IS_IN_USE and VT_BUSY to inlines (Vladis Dronov) [1875585]
- [tty] vt: selection, introduce vc_is_sel (Vladis Dronov) [1875585]
- [fs] gfs2: Don't sleep during glock hash walk (Andreas Grunbacher) [1871173]

* Wed Dec 09 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-260.el8]
- [powerpc] powerpc/64s/hash: Fix hash_preload running with interrupts enabled (Diego Domingos) [1884152]
- [powerpc] powerpc/pseries: Avoid using addr_to_pfn in real mode (Diego Domingos) [1822675]
- [powerpc] powerpc/pseries: Handle UE event for memcpy_mcsafe (Diego Domingos) [1822675]
- [powerpc] powerpc/pseries: Fix MCE handling on pseries (Diego Domingos) [1822675]
- [powerpc] powerpc/64s/pseries: machine check convert to use common event code (Diego Domingos) [1822675]
- [powerpc] powerpc/powernv/mce: Print additional information about MCE error (Diego Domingos) [1822675]
- [powerpc] powerpc/powernv/mce: Print correct severity for MCE error (Diego Domingos) [1822675]
- [powerpc] powerpc/64s: Report SLB multi-hit rather than parity error (Diego Domingos) [1822675]
- [powerpc] powerpc/powernv/mce: Reduce MCE console logs to lesser lines (Diego Domingos) [1822675]
- [powerpc] powerpc/pseries/mce: Improve array initialization (Diego Domingos) [1822675]
- [powerpc] powerpc/pseries/mce: Fix misleading print for TLB mutlihit (Diego Domingos) [1822675]
- [netdrv] i40e: fix crash when Rx descriptor count is changed (Jiri Benc) [1882708]
- [netdrv] virtio_net: Fix out of bounds access of sq (Jiri Benc) [1882708]
- [tools] tools/bpftool: Fix attaching flow dissector (Jiri Benc) [1882708]
- [docs] bpf: Use valid and new links in index.rst (Jiri Benc) [1882708]
- [netdrv] netdevsim: fix unbalaced locking in nsim_create() (Jiri Benc) [1882708]
- [net] bpfilter: Allow to build bpfilter_umh as a module without static library (Jiri Benc) [1882708]
- [net] bpf, netns: Fix use-after-free in pernet pre_exit callback (Jiri Benc) [1882708]
- [net] xsk: Use dma_need_sync instead of reimplenting it (Jiri Benc) [1882708]
- [net] xsk: Remove a double pool->dev assignment in xp_dma_map (Jiri Benc) [1882708]
- [net] xsk: Replace the cheap_dma flag with a dma_need_sync flag (Jiri Benc) [1882708]
- [net] dma-mapping: Add a new dma_need_sync API (Jiri Benc) [1882708]
- [tools] selftests: bpf: Pass program to bpf_prog_detach in flow_dissector (Jiri Benc) [1882708]
- [tools] selftests: bpf: Pass program and target_fd in flow_dissector_reattach (Jiri Benc) [1882708]
- [net] bpf: flow_dissector: Check value of unused flags to BPF_PROG_DETACH (Jiri Benc) [1882708]
- [net] bpf: flow_dissector: Check value of unused flags to BPF_PROG_ATTACH (Jiri Benc) [1882708]
- [tools] libbpf: Adjust SEC short cut for expected attach type BPF_XDP_DEVMAP (Jiri Benc) [1882708]
- [tools] selftests/bpf: Test updating flow_dissector link with same program (Jiri Benc) [1882708]
- [net] bpf, netns: Keep a list of attached bpf_link's (Jiri Benc) [1882708]
- [net] bpf, netns: Keep attached programs in bpf_prog_array (Jiri Benc) [1882708]
- [net] flow_dissector: Pull BPF program assignment up to bpf-netns (Jiri Benc) [1882708]
- [tools] libbpf: Fix CO-RE relocs against .text section (Jiri Benc) [1882708]
- [tools] selftests/bpf: Move newer bpf_iter_* type redefining to a new header file (Jiri Benc) [1882708]
- [net] xdp: Handle frame_sz in xdp_convert_zc_to_xdp_frame() (Jiri Benc) [1882708]
- [net] xdp: Fix xsk_generic_xmit errno (Jiri Benc) [1882708]
- [tools] bpf: Selftests and tools use struct bpf_devmap_val from uapi (Jiri Benc) [1882708]
- [net] xdp: use shift instead of 64 bit division (Jiri Benc) [1882708]
- [net] bpf: Fix unused-var without NETDEVICES (Jiri Benc) [1882708]
- [net] seg6: fix seg6_validate_srh() to avoid slab-out-of-bounds (Jiri Benc) [1882708]
- [net] seg6: fix SRH processing to comply with RFC8754 (Jiri Benc) [1882708]
- [tools] selftests/bpf: Extend test_flow_dissector to cover link creation (Jiri Benc) [1882708]
- [tools] selftests/bpf: Convert test_flow_dissector to use BPF skeleton (Jiri Benc) [1882708]
- [tools] selftests/bpf, flow_dissector: Close TAP device FD after the test (Jiri Benc) [1882708]
- [tools] selftests/bpf: Add tests for attaching bpf_link to netns (Jiri Benc) [1882708]
- [tools] bpftool: Support link show for netns-attached links (Jiri Benc) [1882708]
- [tools] bpftool: Extract helpers for showing link attach type (Jiri Benc) [1882708]
- [tools] libbpf: Add support for bpf_link-based netns attachment (Jiri Benc) [1882708]
- [net] bpf: Add link-based BPF program attachment to network namespace (Jiri Benc) [1882708]
- [net] flow_dissector: Move out netns_bpf prog callbacks (Jiri Benc) [1882708]
- [net] Introduce netns_bpf for BPF programs attached to netns (Jiri Benc) [1882708]
- [net] flow_dissector: Pull locking up from prog attach callback (Jiri Benc) [1882708]
- [net] bpf: Allow SO_BINDTODEVICE opt in bpf_setsockopt (Jiri Benc) [1882708]
- [net] Make locking in sock_bindtoindex optional (Jiri Benc) [1882708]
- [net] add sock_bindtoindex (Jiri Benc) [1882708]
- [tools] selftest: Add tests for XDP programs in devmap entries (Jiri Benc) [1882708]
- [net] xdp: Add xdp_txq_info to xdp_buff (Jiri Benc) [1882708]
- [net] xdp: Introduce xdp_convert_frame_to_buff utility routine (Jiri Benc) [1882708]
- [net] maintainers: Adjust entry in XDP SOCKETS to actual file name (Jiri Benc) [1882708]
- [net] maintainers, xsk: Update AF_XDP section after moves/adds (Jiri Benc) [1882708]
- [net] xsk: Explicitly inline functions and move definitions (Jiri Benc) [1882708]
- [net] xdp: Simplify xdp_return_{frame, frame_rx_napi, buff} (Jiri Benc) [1882708]
- [net] xsk: Remove MEM_TYPE_ZERO_COPY and corresponding code (Jiri Benc) [1882708]
- [netdrv] mlx5, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL (Jiri Benc) [1882708]
- [netdrv] ixgbe, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL (Jiri Benc) [1882708]
- [netdrv] ice, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL (Jiri Benc) [1882708]
- [netdrv] i40e, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL (Jiri Benc) [1882708]
- [netdrv] i40e: Separate kernel allocated rx_bi rings from AF_XDP rings (Jiri Benc) [1882708]
- [netdrv] i40e: Refactor rx_bi accesses (Jiri Benc) [1882708]
- [net] xsk: Introduce AF_XDP buffer allocation API (Jiri Benc) [1867206 1882708]
- [net] xsk: Move defines only used by AF_XDP internals to xsk.h (Jiri Benc) [1882708]
- [net] xsk: Move driver interface to xdp_sock_drv.h (Jiri Benc) [1882708]
- [net] xsk: Move xskmap.c to net/xdp/ (Jiri Benc) [1882708]
- [net] xsk: Fix xsk_umem_xdp_frame_sz() (Jiri Benc) [1882708]
- [tools] selftests/bpf: Convert bpf_iter_test_kern{3, 4}.c to define own bpf_iter_meta (Jiri Benc) [1882708]
- [tools] selftest/bpf: Make bpf_iter selftest compilable against old vmlinux.h (Jiri Benc) [1882708]
- [net] bpf: Fix too large copy from user in bpf_test_init (Jiri Benc) [1882708]
- [tools] selftests/bpf: Xdp_adjust_tail add grow tail tests (Jiri Benc) [1882708]
- [tools] selftests/bpf: Adjust BPF selftest for xdp_adjust_tail (Jiri Benc) [1882708]
- [net] bpf: Add xdp.frame_sz in bpf_prog_test_run_xdp(). (Jiri Benc) [1882708]
- [net] xdp: Clear grow memory in bpf_xdp_adjust_tail() (Jiri Benc) [1882708]
- [net] xdp: Allow bpf_xdp_adjust_tail() to grow packet size (Jiri Benc) [1882708]
- [netdrv] mlx5: Rx queue setup time determine frame_sz for XDP (Jiri Benc) [1882708]
- [netdrv] xdp: For Intel AF_XDP drivers add XDP frame_sz (Jiri Benc) [1882708]
- [netdrv] ice: Add XDP frame size to driver (Jiri Benc) [1882708]
- [netdrv] i40e: Add XDP frame size to driver (Jiri Benc) [1882708]
- [netdrv] ixgbevf: Add XDP frame size to VF driver (Jiri Benc) [1882708]
- [netdrv] ixgbe: Add XDP frame size to driver (Jiri Benc) [1882708]
- [netdrv] ixgbe: Fix XDP redirect on archs with PAGE_SIZE above 4K (Jiri Benc) [1882708]
- [netdrv] virtio_net: Add XDP frame size in two code paths (Jiri Benc) [1882708]
- [netdrv] vhost_net: Also populate XDP frame size (Jiri Benc) [1882708]
- [netdrv] tun: Add XDP frame size (Jiri Benc) [1882708]
- [netdrv] nfp: Add XDP frame size to netronome driver (Jiri Benc) [1882708]
- [netdrv] net: thunderx: Add XDP frame size (Jiri Benc) [1882708]
- [netdrv] mlx4: Add XDP frame size and adjust max XDP MTU (Jiri Benc) [1882708]
- [netdrv] qlogic/qede: Add XDP frame size to driver (Jiri Benc) [1882708]
- [netdrv] hv_netvsc: Add XDP frame size to driver (Jiri Benc) [1882708]
- [netdrv] veth: Xdp using frame_sz in veth driver (Jiri Benc) [1882708]
- [netdrv] veth: Adjust hard_start offset on redirect XDP frames (Jiri Benc) [1882708]
- [net] xdp: Cpumap redirect use frame_sz and increase skb_tailroom (Jiri Benc) [1882708]
- [net] xdp: Xdp_frame add member frame_sz and handle in convert_to_xdp_frame (Jiri Benc) [1882708]
- [net] XDP-generic determining XDP frame size (Jiri Benc) [1882708]
- [netdrv] sfc: Add XDP frame size (Jiri Benc) [1882708]
- [netdrv] bnxt: Add XDP frame size to driver (Jiri Benc) [1882708]
- [net] xdp: Add frame size to xdp_buff (Jiri Benc) [1867209 1882708]
- [net] bpfilter: switch to kernel_write (Jiri Benc) [1882708]
- [tools] bpf: selftests: Add bpf_iter selftests (Jiri Benc) [1882708]
- [tools] bpf: selftests: Add iterator programs for ipv6_route and netlink (Jiri Benc) [1882708]
- [net] bpf: Enable bpf_iter targets registering ctx argument types (Jiri Benc) [1882708]
- [net] bpf: Change func bpf_iter_unreg_target() signature (Jiri Benc) [1882708]
- [net] bpf: Refactor bpf_iter target registration (Jiri Benc) [1882708]
- [net] bpf: Add netlink and ipv6_route bpf_iter targets (Jiri Benc) [1882708]
- [net] bpfilter: check if $(CC) can link static libc in Kconfig (Jiri Benc) [1882708]
- [net] bpfilter: document build requirements for bpfilter_umh (Jiri Benc) [1882708]
- [net] xsk: Remove unnecessary member in xdp_umem (Jiri Benc) [1882708]
- [net] xsk: Change two variable names for increased clarity (Jiri Benc) [1882708]
- [net] bpfilter: match bit size of bpfilter_umh to that of the kernel (Jiri Benc) [1882708]
- [docs] networking: convert filter.txt to ReST (Jiri Benc) [1882708]
- [net] xsk: Fix typo in xsk_umem_consume_tx and xsk_generic_xmit comments (Jiri Benc) [1882708]
- [net] introduce SO_BINDTOIFINDEX sockopt (Jiri Benc) [1882708]
- [net] netlink: Use sizeof_field() macro (Jiri Benc) [1882708]
- [net] xdp: Add SPDX license identifier - Makefile/Kconfig (Jiri Benc) [1882708]
- [net] bpfilter: prefix header search paths with $(srctree)/ (Jiri Benc) [1882708]
- [netdrv] virtio_net: Add XDP meta data support (Jiri Benc) [1882708]
- [netdrv] virtio_net: Keep vnet header zeroed if XDP is loaded for small buffer (Jiri Benc) [1882708]
- [netdrv] virtio-net: keep vnet header zeroed after processing XDP (Jiri Benc) [1882708]
- [netdrv] virtio-net: get rid of unnecessary container of rq stats (Jiri Benc) [1882708]
- [netdrv] virtio-net: correctly update XDP_TX counters (Jiri Benc) [1882708]
- [netdrv] virtio_net: Add kick stats (Jiri Benc) [1882708]
- [netdrv] virtio_net: Add XDP related stats (Jiri Benc) [1882708]
- [netdrv] virtio_net: Factor out the logic to determine xdp sq (Jiri Benc) [1882708]
- [netdrv] virtio_net: Make drop counter per-queue (Jiri Benc) [1882708]
- [netdrv] virtio_net: Use temporary storage for accounting rx stats (Jiri Benc) [1882708]
- [netdrv] bnx2: mark driver deprecated (Jonathan Toppins) [1878183]
- [net] openvswitch: silence suspicious RCU usage warning (Eelco Chaudron) [1895862]
- [net] openswitch: reuse the helper variable to improve the code readablity (Eelco Chaudron) [1895862]
- [net] openvswitch: remove unused keep_flows (Eelco Chaudron) [1895862]
- [net] openvswitch: refactor flow free function (Eelco Chaudron) [1895862]
- [net] openvswitch: improve the coding style (Eelco Chaudron) [1895862]
- [net] openvswitch: use skb_list_walk_safe helper for gso segments (Eelco Chaudron) [1895862]
- [net] openvswitch: do not update max_headroom if new headroom is equal to old headroom (Eelco Chaudron) [1895862]
- [net] openvswitch: drop unneeded likely() call around IS_ERR() (Eelco Chaudron) [1895862]
- [net] openvswitch: convert to kvmalloc (Eelco Chaudron) [1895862]
- [infiniband] RDMA/rxe: Mark Soft-RoCE driver as unsupported (Kamal Heib) [1878207]
- [net] netfilter: nf_log: missing vlan offload tag and proto (Florian Westphal) [1889990]
- [net] ipvs: clear skb->tstamp in forwarding path (Florian Westphal) [1889990]
- [net] netfilter: nft_meta: use socket user_ns to retrieve skuid and skgid (Florian Westphal) [1889990]
- [net] netfilter: ctnetlink: add a range check for l3/l4 protonum (Florian Westphal) [1889990] {CVE-2020-25211}
- [net] netfilter: nfnetlink: nfnetlink_unicast() reports EAGAIN instead of ENOBUFS (Florian Westphal) [1889990]
- [net] netfilter: nf_tables: fix destination register zeroing (Florian Westphal) [1889990]
- [net] netfilter: nf_tables: add NFTA_SET_USERDATA if not null (Florian Westphal) [1889990]
- [net] netfilter: flowtable: Set offload timeout when adding flow (Florian Westphal) [1889990]
- [net] netfilter: conntrack: Move nf_ct_offload_timeout to header file (Florian Westphal) [1889990]
- [net] netfilter: nft_set_rbtree: Handle outcomes of tree rotations in overlap detection (Florian Westphal) [1889990]
- [net] netfilter: nf_tables: nft_exthdr: the presence return value should be little-endian (Florian Westphal) [1889990]
- [net] netfilter: nft_set_pipapo: Drop useless assignment of scratch map index on insert (Florian Westphal) [1889990]
- [net] netfilter: arp_tables: init netns pointer in xt_tgdtor_param struct (Florian Westphal) [1889990]
- [net] netfilter: arp_tables: init netns pointer in xt_tgchk_param struct (Florian Westphal) [1889990]
- [net] ipvs: do not schedule icmp errors from tunnels (Florian Westphal) [1889990]
- [powercap] powercap: intel_rapl: add support for Sapphire Rapids (Steve Best) [1837373]
- [powercap] powercap/intel_rapl: add support for RocketLake (Steve Best) [1782715]
- [char] ipmi: Use fallthrough pseudo-keyword (Tony Camuso) [1877848]
- [char] ipmi/watchdog: add missing newlines when printing parameters by sysfs (Tony Camuso) [1877848]
- [char] ipmi: remve duplicate code in __ipmi_bmc_register() (Tony Camuso) [1877848]
- [documentation] docs: ipmi: Replace HTTP links with HTTPS ones (Tony Camuso) [1877848]
- [char] ipmi: ssif: Remove finished TODO comment about SMBus alert (Tony Camuso) [1877848]
- [documentation] Doc: driver-api: ipmi: Add description of alerts_broken module param (Tony Camuso) [1877848]
- [char] ipmi:ssif: Remove dynamic platform device handing (Tony Camuso) [1877848]
- [char] Try to load acpi_ipmi when an SSIF ACPI IPMI interface is added (Tony Camuso) [1877848]
- [char] ipmi_si: Load acpi_ipmi when ACPI IPMI interface added (Tony Camuso) [1877848]
- [char] ipmi:bt-bmc: Fix error handling and status check (Tony Camuso) [1877848]
- [char] ipmi: Replace guid_copy() with import_guid() where it makes sense (Tony Camuso) [1877848]
- [char] ipmi: use vzalloc instead of kmalloc for user creation (Tony Camuso) [1877848]
- [char] ipmi:bt-bmc: Fix some format issue of the code (Tony Camuso) [1877848]
- [char] ipmi:bt-bmc: Avoid unnecessary check (Tony Camuso) [1877848]
- [char] docs: fix references for ipmi.rst file (Tony Camuso) [1877848]
- [documentation] docs: move IPMI.txt to the driver API book (Tony Camuso) [1877848]

* Sat Dec 05 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-259.el8]
- [powerpc] pseries: Fix 64 bit logical memory block panic (Steve Best) [1894922]
- [mm] powerpc/book3s64/radix: Make radix_mem_block_size 64bit (Steve Best) [1894922]
- [powerpc] powerpc/64s/radix: Fix build failure with RADIX_MMU=n (Steve Best) [1894922]
- [x86] kvm: mmu: fix is_tdp_mmu_check when the TDP MMU is not in use (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: svm: Update cr3_lm_rsvd_bits for AMD SEV guests (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: Introduce cr3_lm_rsvd_bits in kvm_vcpu_arch (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: clflushopt should be treated as a no-op by emulation (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: handle MSR_IA32_DEBUGCTLMSR with report_ignored_msrs (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: request masterclock update any time guest uses different msr (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: ensure pv_cpuid.features is initialized when enabling cap (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: reads of restricted pv msrs should also result in #GP (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: use positive error values for msr emulation that causes #GP (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86/mmu: fix counting of rmap entries in pte_list_add (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: x86: bump KVM_MAX_CPUID_ENTRIES (Vitaly Kuznetsov) [1898914 1878097]
- [x86] vmxfeatures: rename features for consistency with KVM and manual (Vitaly Kuznetsov) [1898914 1878097]
- [x86] kvm: vmx: Add VMX_FEATURE_USR_WAIT_PAUSE (Vitaly Kuznetsov) [1878097 1898914]
- [x86] Expose SERIALIZE for supported cpuid (Vitaly Kuznetsov) [1878097 1898914]
- [x86] kvm: x86: Expose fast short REP MOV for supported cpuid (Vitaly Kuznetsov) [1878097 1898914]
- [x86] kvm: x86: Expose AVX512 VP2INTERSECT in cpuid for TGL (Vitaly Kuznetsov) [1878097 1898914]
- [x86] kvm: Convert to new CPU match macros (Vitaly Kuznetsov) [1878097 1898914]
- [documentation] docs: kvm: fix referenced ioctl symbol (Vitaly Kuznetsov) [1878097 1898914]
- [documentation] docs: kvm: api.rst: add missing spaces (Vitaly Kuznetsov) [1878097 1898914]
- [virt] kvm: use struct_size() and flex_array_size() helpers in kvm_io_bus_unregister_dev() (Vitaly Kuznetsov) [1878097 1898914]
- [documentation] documentation: kvm: fix a typo (Vitaly Kuznetsov) [1878097 1898914]
- [documentation] documentation: kvm: fix some typos in cpuid.rst (Vitaly Kuznetsov) [1878097 1898914]
- [documentation] documentation: kvm: fix a typo (Vitaly Kuznetsov) [1878097 1898914]
- [x86] x86/cpu: Fix typos and improve the comments in sync_core() (David Arcari) [1837457]
- [x86] x86/cpu: Use SERIALIZE in sync_core() when available (David Arcari) [1837457]
- [tools] tools arch x86: Sync asm/cpufeatures.h with the kernel sources (David Arcari) [1837457]
- [x86] x86/cpufeatures: Add enumeration for SERIALIZE instruction (David Arcari) [1837457]
- [x86] x86/cpu: Refactor sync_core() for readability (David Arcari) [1837457]
- [x86] x86/cpu: Relocate sync_core() to sync_core.h (David Arcari) [1837457]
- [arm64] kvm: arm64: Set HCR_EL2.PTW to prevent AT taking synchronous exception (Auger Eric) [1882794]
- [arm64] kvm: arm64: Survive synchronous exceptions caused by AT instructions (Auger Eric) [1882794]
- [arm64] kvm: arm64: Add kvm_extable for vaxorcism code (Auger Eric) [1882794]
- [arm64] kvm: arm64: Print warning when cpu erratum can cause guests to deadlock (Auger Eric) [1882794]
- [arm64] kvm: arm64: clean up redundant 'kvm_run' parameters (Auger Eric) [1882794]
- [arm64] kvm: arm64: Use common KVM implementation of MMU memory caches (Auger Eric) [1882794]
- [arm64] kvm: arm64: Use common code's approach for __GFP_ZERO with memory caches (Auger Eric) [1882794]
- [arm64] kvm: arm64: Drop @max param from mmu_topup_memory_cache() (Auger Eric) [1882794]
- [arm64] s/AMEVTYPE/AMEVTYPER (Auger Eric) [1882794]
- [arm64] kvm: arm64: bti: Reset BTYPE when skipping emulated instructions (Auger Eric) [1882794]
- [arm64] kvm: arm64: Remove S1PTW check from kvm_vcpu_dabt_iswrite() (Auger Eric) [1882794]
- [arm64] kvm: arm64: Assume write fault on S1PTW permission fault on instruction fetch (Auger Eric) [1882794]
- [arm64] kvm: arm64: Update page shift if stage 2 block mapping not supported (Auger Eric) [1882794]
- [arm64] kvm: arm64: Fix address truncation in traces (Auger Eric) [1882794]
- [arm64] kvm: arm64: Do not try to map PUDs when they are folded into PMD (Auger Eric) [1882794]
- [documentation] arm64/x86: kvm: Introduce steal-time cap (Auger Eric) [1882794]
- [arm64] kvm: arm64: pvtime: Fix stolen time accounting across migration (Auger Eric) [1882794]
- [kernel] kvm: arm64: Drop type input from kvm_put_guest (Auger Eric) [1882794]
- [arm64] kvm: arm64: pvtime: Fix potential loss of stolen time (Auger Eric) [1882794]
- [arm64] kvm: arm64: pvtime: steal-time is only supported when configured (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move S1PTW S2 fault logic out of io_mem_abort() (Auger Eric) [1882794]
- [arm64] kvm: arm64: Don't skip cache maintenance for read-only memslots (Auger Eric) [1882794]
- [arm64] kvm: arm64: Handle data and instruction external aborts the same way (Auger Eric) [1882794]
- [arm64] kvm: arm64: Rename kvm_vcpu_dabt_isextabt() (Auger Eric) [1882794]
- [trace] kvm: arm: Add trace name for ARM_NISV (Auger Eric) [1882794]
- [arm64] kvm: arm64: Ensure that all nVHE hyp code is in .hyp.text (Auger Eric) [1882794]
- [arm64] kvm: arm64: Don't use has_vhe() for CHOOSE_HYP_SYM() (Auger Eric) [1882794]
- [arm64] kvm: arm64: timers: Move timer registers to the sys_regs file (Auger Eric) [1882794]
- [arm64] kvm: arm64: timers: Rename kvm_timer_sync_hwstate to kvm_timer_sync_user (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move SPSR_EL1 to the system register array (Auger Eric) [1882794]
- [arm64] kvm: arm64: Disintegrate SPSR array (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move SP_EL1 to the system register array (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move ELR_EL1 to the system register array (Auger Eric) [1882794]
- [arm64] kvm: arm64: Make struct kvm_regs userspace-only (Auger Eric) [1882794]
- [arm64] kvm: arm64: debug: Drop useless vpcu parameter (Auger Eric) [1882794]
- [arm64] kvm: arm64: pauth: Use ctxt_sys_reg() instead of raw sys_regs access (Auger Eric) [1882794]
- [arm64] kvm: arm64: sve: Use __vcpu_sys_reg() instead of raw sys_regs access (Auger Eric) [1882794]
- [arm64] kvm: arm64: hyp: Use ctxt_sys_reg/__vcpu_sys_reg instead of raw sys_regs access (Auger Eric) [1882794]
- [arm64] kvm: arm64: Introduce accessor for ctxt->sys_reg (Auger Eric) [1882794]
- [arm64] kvm: arm64: Rename HSR to ESR (Auger Eric) [1882794]
- [arm64] kvm: arm64: Drop long gone function parameter documentation (Auger Eric) [1882794]
- [arm64] kvm: arm64: vgic-its: Change default outer cacheability for {PEND, PROP}BASER (Auger Eric) [1882794]
- [arm64] kvm: arm64: Lift instrumentation restrictions on VHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Remove __hyp_text macro, use build rules instead (Auger Eric) [1882794]
- [arm64] kvm: arm64: Compile remaining hyp/ files for both VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Duplicate hyp/timer-sr.c for VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Split hyp/sysreg-sr.c to VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Split hyp/debug-sr.c to VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Split hyp/switch.c to VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Duplicate hyp/tlb.c for VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move hyp-init.S to nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Build hyp-entry.S separately for VHE/nVHE (Auger Eric) [1882794]
- [arm64] kvm: arm64: Handle calls to prefixed hyp functions (Auger Eric) [1882794]
- [arm64] kvm: arm64: Use build-time defines in has_vhe() (Auger Eric) [1882794]
- [arm64] kvm: arm64: Add build rules for separate VHE/nVHE object files (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move __smccc_workaround_1_smc to .rodata (Auger Eric) [1882794]
- [arm64] kvm: arm64: Fix symbol dependency in __hyp_call_panic_nvhe (Auger Eric) [1882794]
- [arm64] kvm: arm64: Remove the target table (Auger Eric) [1882794]
- [arm64] kvm: arm64: Remove target_table from exit handlers (Auger Eric) [1882794]
- [arm64] kvm: arm64: Move ACTLR_EL1 emulation to the sys_reg_descs array (Auger Eric) [1882794]
- [arm64] kvm: arm64: Tolerate an empty target_table list (Auger Eric) [1882794]
- [arm64] kvm: arm64: Drop the target_table[] indirection (Auger Eric) [1882794]
- [arm64] kvm: Remove kern_hyp_va from get_vcpu_ptr (Auger Eric) [1882794]
- [arm64] kvm: arm64: Allow in-atomic injection of SPIs (Auger Eric) [1882794]
- [arm64] kvm: arm64: Add emulation for 32bit guests accessing ACTLR2 (Auger Eric) [1882794]
- [arm64] kvm: arm64: Use cpus_have_final_cap for has_vhe() (Auger Eric) [1882794]
- [arm64] efi: Move variable assignments after SECTIONS (Auger Eric) [1882794]
- [arm64] efi: Mark __efistub_stext_offset as an absolute symbol explicitly (Auger Eric) [1882794]
- [arm64] drop linker script hack to hide __efistub_ symbols (Auger Eric) [1882794]
- [arm64] kvm: arm64: Synchronize sysreg state on injecting an AArch32 exception (Auger Eric) [1882794]
- [arm64] kvm: arm64: Make vcpu_cp1x() work on Big Endian hosts (Auger Eric) [1882794]
- [arm64] kvm: arm64: Stop sparse from moaning at __hyp_this_cpu_ptr (Auger Eric) [1882794]
- [arm64] kvm: arm64: Check advertised Stage-2 page size capability (Auger Eric) [1882794]
- [arm64] cpufeature: Don't treat granule sizes as strict (Auger Eric) [1882794]
- [arm64] cpufeature: Validate hypervisor capabilities during CPU hotplug (Auger Eric) [1882794]
- [arm64] kvm: hyp: use cpus_have_final_cap() (Auger Eric) [1882794]
- [arm64] cpufeature: add cpus_have_final_cap() (Auger Eric) [1882794]
- [arm64] mark (__)cpus_have_const_cap as __always_inline (Auger Eric) [1882794]
- [arm64] Mark call_smc_arch_workaround_1 as __maybe_unused (Auger Eric) [1882794]
- [arm64] Make use of ARCH_WORKAROUND_1 even when KVM is not enabled (Auger Eric) [1882794]
- [arm64] kvm: arm64: Delete duplicated label in invalid_vector (Auger Eric) [1882794]
- [arm64] use mov_q instead of literal ldr (Auger Eric) [1882794]
- [arm64] kvm: Modernize __smccc_workaround_1_smc_start annotations (Auger Eric) [1882794]
- [arm64] kvm: Modernize annotation for __bp_harden_hyp_vecs (Auger Eric) [1882794]
- [arm64] kvm: Annotate assembly using modern annoations (Auger Eric) [1882794]
- [arm64] kvm: arm64: Prevent vcpu_has_ptrauth from generating OOL functions (Auger Eric) [1882794]
- [arm64] kvm: disable access to AMU registers from kvm guests (Auger Eric) [1882794]
- [arm64] kvm: arm64: pvtime: Ensure task delay accounting is enabled (Auger Eric) [1882794]
- [arm64] kvm: arm64: Stop writing aarch32's CSSELR into ACTLR (Auger Eric) [1882794]
- [arm64] kvm: Annotate guest entry/exit as a single function (Auger Eric) [1882794]
- [kernel] linkage: Introduce new macros for assembler symbols (Auger Eric) [1882794]
- [s390] kvm: s390: remove diag318 reset code (Thomas Huth) [1899497]
- [powerpc] powerpc/hv-gpci: Add sysfs files inside hv-gpci device to show cpumask (Michael Petlan) [1844416]
- [powerpc] powerpc/perf/hv-gpci: Add cpu hotplug support (Michael Petlan) [1844416]
- [documentation] Documentation/ABI: Add ABI documentation for hv-gpci format (Michael Petlan) [1844416]
- [documentation] Documentation/ABI: Add ABI documentation for hv-24x7 format (Michael Petlan) [1844416]
- [powerpc] powerpc/perf/hv-gpci: Fix starting index value (Michael Petlan) [1844416]
- [powerpc] powerpc/perf/hv-24x7: Move cpumask file to top folder of hv-24x7 driver (Michael Petlan) [1844416]
- [powerpc] powerpc/hv-24x7: Add sysfs files inside hv-24x7 device to show cpumask (Michael Petlan) [1844416]
- [powerpc] powerpc/perf/hv-24x7: Add cpu hotplug support (Michael Petlan) [1844416]
- [powerpc] powerpc/perf: Fix reading of MSRbits in trace-imc (Michael Petlan) [1854536]
- [powerpc] powerpc/perf: Add kernel support for new MSRbits in trace-imc (Michael Petlan) [1854536]
- [documentation] kdump: update kdump documentation due to change of crash URL (Lianbo Jiang) [1896236]
- [pinctrl] pinctrl: intel: Add Intel Emmitsburg pin controller support (David Arcari) [1837409]
- [x86] x86/platform/uv: Fix copied UV5 output archtype (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Drop last traces of uv_flush_tlb_others (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Recognize UV5 hubless system identifier (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove spaces from OEM IDs (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Fix missing OEM_TABLE_ID (Frank Ramsay) [1861439]
- [misc] x86/platform/uv: Update Copyrights to conform to HPE standards (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Update for UV5 NMI MMR changes (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Update UV5 TSC checking (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Update node present counting (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Update UV5 MMR references in UV GRU (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Adjust GAM MMR references affected by UV5 updates (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Update MMIOH references based on new UV5 MMRs (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Add and decode Arch Type in UVsystab (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Add UV5 direct references (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Update UV MMRs for UV5 (Frank Ramsay) [1861439]
- [misc] drivers/misc/sgi-xp: Adjust references in UV kernel modules (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove SCIR MMR references for UV systems (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove UV BAU TLB Shootdown Handler (Frank Ramsay) [1861439]
- [x86] x86/kernel: Fix more -Wmissing-prototypes warnings (Frank Ramsay) [1861439]
- [x86] x86/apic/uv: Avoid unused variable warning (Frank Ramsay) [1861439]
- [misc] misc: sgi-xp: xp_main: Staticify local functions xp_init() and xp_exit() (Frank Ramsay) [1861439]
- [misc] misc/sgi-xp: remove SGI SN2 support (Frank Ramsay) [1861439]
- [x86] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Frank Ramsay) [1861439]
- [x86] efi/x86: Remove unreachable code in kexec_enter_virtual_mode() (Frank Ramsay) [1861439]
- [x86] x86/efi: Remove unused EFI_UV1_MEMMAP code (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove uv bios and efi code related to EFI_UV1_MEMMAP (Frank Ramsay) [1861439]
- [x86] x86/efi: Remove references to no-longer-used efi_have_uv1_memmap() (Frank Ramsay) [1861439]
- [x86] x86/efi: Delete SGI UV1 detection (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove efi=old_map command line option (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove vestigial mention of UV1 platform from bios header (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for UV1 platform from uv (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for uv1 platform from uv_hub (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for UV1 platform from uv_bau (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for UV1 platform from uv_mmrs (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for UV1 platform from x2apic_uv_x (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for UV1 platform from uv_tlb (Frank Ramsay) [1861439]
- [x86] x86/platform/uv: Remove support for UV1 platform from uv_time (Frank Ramsay) [1861439]
- [x86] x86/apic/uv: Make x2apic_extra_bits static (Frank Ramsay) [1861439]
- [s390] uv: add destroy page call (Thomas Huth) [1882800]
- [s390] gmap: improve THP splitting (Thomas Huth) [1882800]
- [s390] kvm: s390: clean up redundant 'kvm_run' parameters (Thomas Huth) [1882800]
- [documentation] documentation: virt: kvm/s390-pv: drop doubled words (Thomas Huth) [1882800]
- [s390] kvm: s390: reduce number of IO pins to 1 (Thomas Huth) [1882800]
- [s390] protvirt: use scnprintf() instead of snprintf() (Thomas Huth) [1882800]
- [s390] kvm: s390: remove unneeded semicolon in gisa_vcpu_kicker() (Thomas Huth) [1882800]
- [s390] kvm: s390: vsie: gmap_table_walk() simplifications (Thomas Huth) [1882800]
- [s390] kvm: s390: vsie: Move conditional reschedule (Thomas Huth) [1882800]
- [s390] kvm: s390: vsie: Fix possible race when shadowing region 3 tables (Thomas Huth) [1882800]
- [s390] kvm: s390: vsie: Fix region 1 ASCE sanity shadow address checks (Thomas Huth) [1882800]
- [s390] kvm: s390: Use fallthrough; (Thomas Huth) [1882800]
- [s390] mm: use refcount_t for refcount (Thomas Huth) [1882800]
- [s390] mm: make gmap_test_and_clear_dirty_pmd static (Thomas Huth) [1882800]
- [s390] mm: optimize locking without huge pages in gmap_pmd_op_walk() (Thomas Huth) [1882800]
- [net] openvswitch: introduce common code for flushing flows (Eelco Chaudron) [1888576]
- [net] openvswitch: silence suspicious RCU usage warning (Eelco Chaudron) [1888576]
- [net] openvswitch: make masks cache size configurable (Eelco Chaudron) [1888576]
- [net] openvswitch: add masks cache hit counter (Eelco Chaudron) [1888576]
- [net] openvswitch: Prevent kernel-infoleak in ovs_ct_put_key() (Eelco Chaudron) [1888576]
- [net] openvswitch: kerneldoc fixes (Eelco Chaudron) [1888576]
- [net] openvswitch: use div_u64() for 64-by-32 divisions (Eelco Chaudron) [1888576]
- [net] openvswitch: suitable access to the dp_meters (Eelco Chaudron) [1888576]
- [net] openvswitch: use u64 for meter bucket (Eelco Chaudron) [1888576]
- [net] openvswitch: make EINVAL return value more obvious (Eelco Chaudron) [1888576]
- [net] openvswitch: remove the unnecessary check (Eelco Chaudron) [1888576]
- [net] openvswitch: set max limitation to meters (Eelco Chaudron) [1888576]
- [net] openvswitch: expand the meters supported number (Eelco Chaudron) [1888576]
- [net] openvswitch: use hlist_for_each_entry_rcu instead of hlist_for_each_entry (Eelco Chaudron) [1888576]
- [net] ovs: datapath: hide clang frame-overflow warnings (Eelco Chaudron) [1888576]
- [net] openvswitch: use netif_ovs_is_port() instead of opencode (Eelco Chaudron) [1888576]
- [platform] platform/x86: intel_pmc_core: avoid unused-function warnings (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: fix bound check in pmc_core_mphy_pg_show() (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: update TGL's LPM0 reg bit map name (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Make pmc_core_substate_res_show() generic (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Make pmc_core_lpm_display() generic for platforms that support sub-states (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Add slp_s0_offset attribute back to tgl_reg_map (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Remove duplicate 'if' to create debugfs entry (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Relocate pmc_core_*_display() to outside of CONFIG_DEBUG_FS (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Add debugfs support to access live status registers (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Dump low power status registers on an S0ix.y failure (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Add an additional parameter to pmc_core_lpm_display() (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Remove slp_s0 attributes from tgl_reg_map (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Refactor the driver by removing redundant code (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Add debugfs entry for low power mode status registers (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Add debugfs entry to access sub-state residencies (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Fix spelling of MHz unit (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Fix indentation in function definitions (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Put more stuff under #ifdef DEBUG_FS (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Respect error code of kstrtou32_from_user() (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Make debugfs entry for pch_ip_power_gating_status conditional (David Arcari) [1783140]
- [platform] platform/x86: intel_pmc_core: Remove unnecessary assignments (David Arcari) [1783140]

* Wed Dec 02 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-258.el8]
- [net] mptcp: provide rmem[0] limit (Davide Caratti) [1874368]
- [net] mptcp: add missing memory scheduling in the rx path (Davide Caratti) [1874368]
- [net] mptcp: depends on IPV6 but not as a module (Davide Caratti) [1874368]
- [tools] selftests: mptcp: depends on built-in IPv6 (Davide Caratti) [1874368]
- [net] mptcp: MPTCP_IPV6 should depend on IPV6 instead of selecting it (Davide Caratti) [1874368]
- [net] mptcp: subflows garbage collection (Davide Caratti) [1874368]
- [net] mptcp: fix fallback for MP_JOIN subflows (Davide Caratti) [1874368]
- [net] mptcp: make DACK4/DACK8 usage consistent among all subflows (Davide Caratti) [1874368]
- [net] mptcp: fix infinite loop on recvmsg()/worker() race. (Davide Caratti) [1874368]
- [net] mptcp: don't skip needed ack (Davide Caratti) [1874368]
- [net] mptcp: more DATA FIN fixes (Davide Caratti) [1874368]
- [net] mptcp: Constify mptcp_pm_ops (Davide Caratti) [1874368]
- [net] mptcp: ADD_ADDRs with echo bit are smaller (Davide Caratti) [1874368]
- [net] mptcp: Handle incoming 32-bit DATA_FIN values (Davide Caratti) [1874368]
- [net] mptcp: Consistently use READ_ONCE/WRITE_ONCE with msk->ack_seq (Davide Caratti) [1874368]
- [net] tcp: drop unused function argument from mptcp_incoming_options (Davide Caratti) [1874368]
- [net] mptcp: retransmit ADD_ADDR when timeout (Davide Caratti) [1874368]
- [net] mptcp: add sk_stop_timer_sync helper (Davide Caratti) [1874368]
- [net] mptcp: add struct mptcp_pm_add_entry (Davide Caratti) [1874368]
- [tools] selftests: mptcp: add remove addr and subflow test cases (Davide Caratti) [1874368]
- [tools] selftests: mptcp: add remove cfg in mptcp_connect (Davide Caratti) [1874368]
- [net] mptcp: add mptcp_destroy_common helper (Davide Caratti) [1874368]
- [net] mptcp: add RM_ADDR related mibs (Davide Caratti) [1874368]
- [net] mptcp: implement mptcp_pm_remove_subflow (Davide Caratti) [1874368]
- [net] mptcp: remove addr and subflow in PM netlink (Davide Caratti) [1874368]
- [net] mptcp: add accept_subflow re-check (Davide Caratti) [1874368]
- [tools] selftests: mptcp: add ADD_ADDR mibs check function (Davide Caratti) [1874368]
- [net] tcp: change pingpong threshold to 3 (Davide Caratti) [1874368]
- [net] tcp: Refactor pingpong code (Davide Caratti) [1874368]
- [net] mptcp: add ADD_ADDR related mibs (Davide Caratti) [1874368]
- [net] mptcp: send out ADD_ADDR with echo flag (Davide Caratti) [1874368]
- [net] mptcp: add the incoming RM_ADDR support (Davide Caratti) [1874368]
- [net] mptcp: add the outgoing RM_ADDR support (Davide Caratti) [1874368]
- [net] mptcp: rename addr_signal and the related functions (Davide Caratti) [1874368]
- [net] mptcp: Wake up MPTCP worker when DATA_FIN found on a TCP FIN packet (Davide Caratti) [1874368]
- [net] mptcp: fix integer overflow in mptcp_subflow_discard_data() (Davide Caratti) [1874368]
- [net] mptcp: Fix unsigned 'max_seq' compared with zero in mptcp_data_queue_ofo (Davide Caratti) [1874368]
- [tools] selftests: mptcp: interpret \n as a new line (Davide Caratti) [1874368]
- [tools] selftests: mptcp: interpret \n as a new line (Davide Caratti) [1874368]
- [tools] mptcp: simult flow self-tests (Davide Caratti) [1874368]
- [net] mptcp: call tcp_cleanup_rbuf on subflows (Davide Caratti) [1874368]
- [net] mptcp: allow picking different xmit subflows (Davide Caratti) [1874368]
- [net] mptcp: allow creating non-backup subflows (Davide Caratti) [1874368]
- [net] mptcp: move address attribute into mptcp_addr_info (Davide Caratti) [1874368]
- [net] mptcp: add OoO related mibs (Davide Caratti) [1874368]
- [net] mptcp: cleanup mptcp_subflow_discard_data() (Davide Caratti) [1874368]
- [net] mptcp: move ooo skbs into msk out of order queue. (Davide Caratti) [1874368]
- [net] mptcp: introduce and use mptcp_try_coalesce() (Davide Caratti) [1874368]
- [net] mptcp: basic sndbuf autotuning (Davide Caratti) [1874368]
- [net] mptcp: trigger msk processing even for OoO data (Davide Caratti) [1874368]
- [net] mptcp: set data_ready status bit in subflow_check_data_avail() (Davide Caratti) [1874368]
- [net] mptcp: rethink 'is writable' conditional (Davide Caratti) [1874368]
- [net] tcp: reduce POLLOUT events caused by TCP_NOTSENT_LOWAT (Davide Caratti) [1874368]
- [net] mptcp: fix kmalloc flag in mptcp_pm_nl_get_local_id (Davide Caratti) [1874368]
- [net] mptcp: fix subflow's remote_id issues (Davide Caratti) [1874368]
- [net] mptcp: fix subflow's local_id issues (Davide Caratti) [1874368]
- [net] mptcp: Remove unused macro MPTCP_SAME_STATE (Davide Caratti) [1874368]
- [net] treewide: Use fallthrough pseudo-keyword (Davide Caratti) [1874368]
- [net] netlink: consistently use NLA_POLICY_EXACT_LEN() (Davide Caratti) [1874368]
- [net] mptcp: free acked data before waiting for more memory (Davide Caratti) [1874368]
- [net] mptcp: sendmsg: reset iter on error redux (Davide Caratti) [1874368]
- [net] mptcp: sendmsg: reset iter on error (Davide Caratti) [1874368]
- [net] mptcp: fix warn at shutdown time for unaccepted msk sockets (Davide Caratti) [1874368]
- [net] mptcp: use mptcp_for_each_subflow in mptcp_stream_accept (Davide Caratti) [1874368]
- [net] mptcp: fix syncookie build error on UP (Davide Caratti) [1874368]
- [net] tcp: fix syn cookied MPTCP request socket leak (Davide Caratti) [1874368]
- [net] tcp: fix build fong CONFIG_MPTCP=n (Davide Caratti) [1874368]
- [tools] selftests: mptcp: add test cases for mptcp join tests with syn cookies (Davide Caratti) [1874368]
- [tools] selftests: mptcp: make 2nd net namespace use tcp syn cookies unconditionally (Davide Caratti) [1874368]
- [net] mptcp: enable JOIN requests even if cookies are in use (Davide Caratti) [1874368]
- [net] tcp: free request sock directly upon TFO or syncookies error (Davide Caratti) [1874368]
- [include] net: keep refcount warning in reqsk_free() (Davide Caratti) [1874368]
- [net] tcp: syncookies: create mptcp request socket for ACK cookies with MPTCP option (Davide Caratti) [1874368]
- [net] mptcp: subflow: add mptcp_subflow_init_cookie_req helper (Davide Caratti) [1874368]
- [net] mptcp: rename and export mptcp_subflow_request_sock_ops (Davide Caratti) [1874368]
- [net] mptcp: subflow: split subflow_init_req (Davide Caratti) [1874368]
- [net] mptcp: token: move retry to caller (Davide Caratti) [1874368]
- [net] tcp: rename request_sock cookie_ts bit to syncookie (Davide Caratti) [1874368]
- [net] mptcp: Safely store sequence number when sending data (Davide Caratti) [1874368]
- [net] mptcp: Safely read sequence number when lock isn't held (Davide Caratti) [1874368]
- [net] mptcp: Skip unnecessary skb extension allocation for bare acks (Davide Caratti) [1874368]
- [net] mptcp: Only use subflow EOF signaling on fallback connections (Davide Caratti) [1874368]
- [net] mptcp: Use full MPTCP-level disconnect state machine (Davide Caratti) [1874368]
- [net] mptcp: Add helper to process acks of DATA_FIN (Davide Caratti) [1874368]
- [net] mptcp: Add mptcp_close_state() helper (Davide Caratti) [1874368]
- [net] mptcp: Track received DATA_FIN sequence number and add related helpers (Davide Caratti) [1874368]
- [net] mptcp: Use MPTCP-level flag for sending DATA_FIN (Davide Caratti) [1874368]
- [net] mptcp: Remove outdated and incorrect comment (Davide Caratti) [1874368]
- [net] mptcp: Return EPIPE if sending is shut down during a sendmsg (Davide Caratti) [1874368]
- [net] mptcp: Allow DATA_FIN in headers without TCP FIN (Davide Caratti) [1874368]
- [net] subflow: introduce and use mptcp_can_accept_new_subflow() (Davide Caratti) [1874368]
- [net] subflow: use rsk_ops->send_reset() (Davide Caratti) [1874368]
- [net] mptcp: cleanup subflow_finish_connect() (Davide Caratti) [1874368]
- [net] mptcp: explicitly track the fully established status (Davide Caratti) [1874368]
- [net] mptcp: mark as fallback even early ones (Davide Caratti) [1874368]
- [net] mptcp: avoid data corruption on reinsert (Davide Caratti) [1874368]
- [net] subflow: always init 'rel_write_seq' (Davide Caratti) [1874368]
- [net] mptcp: zero token hash at creation time. (Davide Caratti) [1874368]
- [net] mptcp: move helper to where its used (Davide Caratti) [1874368]
- [tools] selftests/mptcp: Better delay & reordering configuration (Davide Caratti) [1874368]
- [tools] selftests: mptcp: fix typo in mptcp_connect usage (Davide Caratti) [1874368]
- [tools] mptcp: more stable diag self-tests (Davide Caratti) [1874368]
- [tools] selftests: mptcp: fix dependecies (Davide Caratti) [1874368]
- [net] inet_diag: validate INET_DIAG_REQ_PROTOCOL attribute (Davide Caratti) [1874368]
- [tools] selftests/mptcp: add diag interface tests (Davide Caratti) [1874368]
- [net] mptcp: add MPTCP socket diag interface (Davide Caratti) [1874368]
- [net] mptcp: add msk interations helper (Davide Caratti) [1874368]
- [net] inet_diag: support for wider protocol numbers (Davide Caratti) [1874368]
- [net] mptcp: use mptcp worker for path management (Davide Caratti) [1874368]
- [include] mptcp: Remove unused inline function mptcp_rcv_synsent() (Davide Caratti) [1874368]
- [net] mptcp: support IPV6_V6ONLY setsockopt (Davide Caratti) [1874368]
- [net] mptcp: add REUSEADDR/REUSEPORT support (Davide Caratti) [1874368]
- [net] use mptcp setsockopt function for SOL_SOCKET on mptcp sockets (Davide Caratti) [1874368]
- [net] mptcp: do nonce initialization at subflow creation time (Davide Caratti) [1874368]
- [net] mptcp: close poll() races (Davide Caratti) [1874368]
- [net] mptcp: __mptcp_tcp_fallback() returns a struct sock (Davide Caratti) [1874368]
- [net] mptcp: create first subflow at msk creation time (Davide Caratti) [1874368]
- [net] mptcp: check for plain TCP sock at accept time (Davide Caratti) [1874368]
- [net] mptcp: move mptcp_options_received's port initialization (Davide Caratti) [1874368]
- [net] mptcp: initialize mptcp_options_received's ahmac (Davide Caratti) [1874368]
- [net] mptcp: MPTCP_KUNIT_TESTS should depend on MPTCP instead of selecting it (Davide Caratti) [1874368]
- [net] mptcp: introduce token KUNIT self-tests (Davide Caratti) [1874368]
- [net] mptcp: move crypto test to KUNIT (Davide Caratti) [1874368]
- [net] mptcp: refactor token container (Davide Caratti) [1874368]
- [net] mptcp: add __init annotation on setup functions (Davide Caratti) [1874368]
- [net] tcp: move ipv4_specific to tcp include file (Davide Caratti) [1874368]
- [net] tcp: move ipv6_specific declaration to remove a warning (Davide Caratti) [1874368]
- [net] mptcp: use list_first_entry_or_null (Davide Caratti) [1874368]
- [net] mptcp: attempt coalescing when moving skbs to mptcp rx queue (Davide Caratti) [1874368]
- [net] allow __skb_ext_alloc to sleep (Davide Caratti) [1874368]
- [net] mptcp: remove inner wait loop from mptcp_sendmsg_frag (Davide Caratti) [1874368]
- [net] mptcp: fill skb page frag cache outside of mptcp_sendmsg_frag (Davide Caratti) [1874368]
- [net] mptcp: fill skb extension cache outside of mptcp_sendmsg_frag (Davide Caratti) [1874368]
- [net] mptcp: move common nospace-pattern to a helper (Davide Caratti) [1874368]
- [net] mptcp: Use 32-bit DATA_ACK when possible (Davide Caratti) [1874368]
- [s390] s390/qeth: implement ndo_bridge_setlink for learning_sync (Philipp Rudo) [1651745]
- [s390] s390/qeth: implement ndo_bridge_getlink for learning_sync (Philipp Rudo) [1651745]
- [s390] s390/qeth: Reset address notification in case of buffer overflow (Philipp Rudo) [1651745]
- [net] bridge: Add SWITCHDEV_FDB_FLUSH_TO_BRIDGE notifier (Philipp Rudo) [1651745]
- [s390] s390/qeth: Translate address events into switchdev notifiers (Philipp Rudo) [1651745]
- [s390] s390/qeth: Detect PNSO OC3 capability (Philipp Rudo) [1651745]
- [s390] s390/cio: Helper functions to read CSSID, IID, and CHID (Philipp Rudo) [1651745]
- [s390] s390/cio: Add new Operation Code OC3 to PNSO (Philipp Rudo) [1651745]
- [cpuidle] cpuidle: Drop misleading comments about RCU usage (David Arcari) [1888014]
- [cpuidle] cpuidle: Allow cpuidle drivers to take over RCU-idle (David Arcari) [1888014]
- [include] cpuidle: Make CPUIDLE_FLAG_TLB_FLUSHED generic (David Arcari) [1888014]
- [cpuidle] sched, idle, rcu: Push rcu_idle deeper into the idle path (David Arcari) [1888014]
- [cpuidle] cpuidle: Fixup IRQ state (David Arcari) [1888014]
- [kernel] cpuidle: Add RH_KABI warnings (David Arcari) [1878232]
- [acpi] cpuidle: ACPI: fix 'return' with no value build warning (David Arcari) [1878232]
- [acpi] cpuidle: change enter_s2idle() prototype (David Arcari) [1878232]
- [cpuidle] cpuidle/pseries: Make symbol 'pseries_idle_driver' static (David Arcari) [1878232]
- [cpuidle] cpuidle/powernv : Remove dead code block (David Arcari) [1878232]
- [cpuidle] cpuidle: Rearrange s2idle-specific idle state entry code (David Arcari) [1878232]
- [cpuidle] PM: s2idle: Clear _TIF_POLLING_NRFLAG before suspend to idle (David Arcari) [1878232]
- [cpuidle] cpuidle: Fix three reference count leaks (David Arcari) [1878232]
- [cpuidle] cpuidle: sysfs: Remove sysfs_switch and switch attributes (David Arcari) [1878232]
- [cpuidle] cpuidle: Make cpuidle governor switchable to be the default behaviour (David Arcari) [1878232]
- [cpuidle] cpuidle: sysfs: Accept governor name with 15 characters (David Arcari) [1878232]
- [cpuidle] cpuidle: sysfs: Fix the overlap for showing available governors (David Arcari) [1878232]
- [cpuidle] cpuidle: sysfs: Minor coding style corrections (David Arcari) [1878232]
- [cpuidle] cpuidle: sysfs: Remove the unused define_one_r(o/w) macros (David Arcari) [1878232]
- [cpuidle] cpuidle-haltpoll: Fix small typo (David Arcari) [1878232]
- [idle] intel_idle: Customize IceLake server support (David Arcari) [1881620 1857129]
- [idle] intel_idle: Eliminate redundant static variable (David Arcari) [1857129]
- [idle] intel_idle: Update copyright notice, known limitations and version (David Arcari) [1857129]
- [idle] intel_idle: Define CPUIDLE_FLAG_TLB_FLUSHED as BIT(16) (David Arcari) [1857129]
- [idle] intel_idle: Clean up kerneldoc comments for multiple functions (David Arcari) [1857129]
- [idle] intel_idle: Reorder declarations of static variables (David Arcari) [1857129]
- [idle] intel_idle: Annotate init time data structures (David Arcari) [1857129]
- [idle] intel_idle: Add __initdata annotations to init time variables (David Arcari) [1857129]
- [idle] intel_idle: Relocate definitions of cpuidle callbacks (David Arcari) [1857129]
- [idle] intel_idle: Clean up definitions of cpuidle callbacks (David Arcari) [1857129]
- [idle] intel_idle: Simplify LAPIC timer reliability checks (David Arcari) [1857129]
- [idle] intel_idle: Introduce 'states_off' module parameter (David Arcari) [1857129]
- [idle] intel_idle: Clean up irtl_2_usec() (David Arcari) [1857129]
- [idle] intel_idle: Move 3 functions closer to their callers (David Arcari) [1857129]
- [idle] intel_idle: Annotate initialization code and data structures (David Arcari) [1857129]
- [idle] intel_idle: Move and clean up intel_idle_cpuidle_devices_uninit() (David Arcari) [1857129]
- [idle] intel_idle: Rearrange intel_idle_cpuidle_driver_init() (David Arcari) [1857129]
- [idle] intel_idle: Clean up NULL pointer check in intel_idle_init() (David Arcari) [1857129]
- [idle] intel_idle: Fold intel_idle_probe() into intel_idle_init() (David Arcari) [1857129]
- [idle] intel_idle: Eliminate __setup_broadcast_timer() (David Arcari) [1857129]
- [idle] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 335 (David Arcari) [1857129]

* Wed Dec 02 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-257.el8]
- [hv] hv: vmbus: Allow cleanup of VMBUS_CONNECT_CPU if disconnected (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Add parsing of VMbus interrupt in ACPI DSDT (Mohammed Gamal) [1886096]
- [hv] driver: hv: util: Use VMBUS_RING_SIZE() for ringbuffer sizes (Mohammed Gamal) [1886096]
- [kernel] hv: vmbus: Move virt_to_hvpfn() to hyperv header (Mohammed Gamal) [1886096]
- [hv] hv: Use HV_HYP_PAGE in hv_synic_enable_regs() (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Introduce types of GPADL (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Move __vmbus_open() (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Always use HV_HYP_PAGE_SIZE for gpadl (Mohammed Gamal) [1886096]
- [hv] hv: remove cast from hyperv_die_event (Mohammed Gamal) [1886096]
- [hv] hv: Change flag to write log level in panic msg to false (Mohammed Gamal) [1886096]
- [kernel] hv: vmbus: Remove the lock field from the vmbus_channel struct (Mohammed Gamal) [1886096]
- [scsi] storvsc: Introduce the per-storvsc_device spinlock (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Remove unnecessary channel->lock critical sections (sc_list updaters) (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Use channel_mutex in channel_vp_mapping_show() (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Remove unnecessary channel->lock critical sections (sc_list readers) (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Replace cpumask_test_cpu(, cpu_online_mask) with cpu_online() (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Remove the numa_node field from the vmbus_channel struct (Mohammed Gamal) [1886096]
- [kernel] hv: vmbus: Remove the target_vp field from the vmbus_channel struct (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Resolve more races involving init_vp_index() (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Resolve race between init_vp_index() and CPU hotplug (Mohammed Gamal) [1886096]
- [hv] driver: hv: vmbus: drop a no long applicable comment (Mohammed Gamal) [1886096]
- [hv] hyper-v: Replace open-coded variant of *phN specifier (Mohammed Gamal) [1886096]
- [hv] hyper-v: Supply GUID pointer to printf() like functions (Mohammed Gamal) [1886096]
- [hv] hyper-v: Use UUID API for exporting the GUID (part 2) (Mohammed Gamal) [1886096]
- [hv] hv: remove redundant assignment to pointer primary_channel (Mohammed Gamal) [1886096]
- [scsi] storvsc: Re-init stor_chns when a channel interrupt is re-assigned (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Introduce the CHANNELMSG_MODIFYCHANNEL message type (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Synchronize init_vp_index() vs. CPU hotplug (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Remove the unused HV_LOCALIZED channel affinity logic (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Use a spin lock for synchronizing channel scheduling vs. channel removal (Mohammed Gamal) [1886096]
- [hv] hv_utils: Always execute the fcopy and vss callbacks in a tasklet (Mohammed Gamal) [1886096]
- [netdrv] hv_netvsc: Disable NAPI before closing the VMBus channel (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Replace the per-CPU channel lists with a global array of channels (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Don't bind the offer&rescind works to a specific CPU (Mohammed Gamal) [1886096]
- [hv] hv: vmbus: Always handle the VMBus messages on CPU0 (Mohammed Gamal) [1886096]
- [hv] hv: check VMBus messages lengths (Mohammed Gamal) [1886096]
- [hv] hv: make sure that 'struct vmbus_channel_message_header' compiles correctly (Mohammed Gamal) [1886096]
- [hv] hv: avoid passing opaque pointer to vmbus_onmessage() (Mohammed Gamal) [1886096]
- [hv] hv: allocate the exact needed memory for messages (Mohammed Gamal) [1886096]
- [hv] hv: copy from message page only what's needed (Mohammed Gamal) [1886096]
- [x86] hyperv: Clarify comment on x2apic mode (Mohammed Gamal) [1886099]
- [x86] hyperv: report value of misc_features (Mohammed Gamal) [1886099]
- [x86] hyperv: Make hv_setup_sched_clock inline (Mohammed Gamal) [1886099]
- [net] ipv6: reply ICMP error if the first fragment don't include all headers (Hangbin Liu) [1874734]
- [net] icmpv6: Add ICMPv6 Parameter Problem, code 3 definition (Hangbin Liu) [1874734]
- [powerpc] powerpc/process: Add missing include of stacktrace.h (Desnes Augusto Nunes do Rosario) [1883975]
- [powerpc] powerpc/test_emulate_sstep: Fix build error (Desnes Augusto Nunes do Rosario) [1883975]
- [nvdimm] powerpc/pmem: Initialize pmem device on newer hardware (Desnes Augusto Nunes do Rosario) [1878632]
- [powerpc] powerpc/pmem: Avoid the barrier in flush routines (Desnes Augusto Nunes do Rosario) [1878632]
- [powerpc] powerpc/pmem: Update ppc64 to use the new barrier instruction (Desnes Augusto Nunes do Rosario) [1878632]
- [md] libnvdimm/nvdimm/flush: Allow architecture to override the flush barrier (Desnes Augusto Nunes do Rosario) [1878632]
- [powerpc] powerpc/pmem: Add flush routines using new pmem store and sync instruction (Desnes Augusto Nunes do Rosario) [1878632]
- [powerpc] powerpc/pmem: Add new instructions for persistent storage and sync (Desnes Augusto Nunes do Rosario) [1878632]
- [powerpc] powerpc/pmem: Restrict papr_scm to P8 and above (Desnes Augusto Nunes do Rosario) [1878632]
- [i2c] i2c: ismt: Add support for Intel Emmitsburg PCH (David Arcari) [1886162]
- [include] timer: add fsleep for flexible sleeping (Josef Oskera) [1892674]
- [scsi] qla2xxx: Update driver version to 10.02.00.103-k (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Return EBUSY on fcport deletion (Nilesh Javali) [1887427]
- [trace] scsi: qla2xxx: Suppress two recently introduced compiler warnings (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix return of uninitialized value in rval (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Convert to DEFINE_SHOW_ATTRIBUTE (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Initialize variable in qla8044_poll_reg() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Do not consume srb greedily (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use constant when it is known (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix inconsistent format argument type in qla_dbg.c (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix inconsistent format argument type in qla_os.c (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix inconsistent format argument type in tcm_qla2xxx.c (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix point-to-point (N2N) device discovery issue (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix crash on session cleanup with unload (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix reset of MPI firmware (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix MPI reset needed message (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix buffer-buffer credit extraction error (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Correct the check for sscanf() return value (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add SLER and PI control support (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add IOCB resource tracking (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add rport fields in debugfs (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make tgt_port_database available in initiator mode (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix I/O errors during LIP reset tests (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Performance tweak (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix memory size truncation (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Reduce duplicate code in reporting speed (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Honor status qualifier in FCP_RSP per spec (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Allow dev_loss_tmo setting for FC-NVMe devices (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Setup debugfs entries for remote ports (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix I/O failures during remote port toggle testing (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove unneeded variable 'rval' (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Handle incorrect entry_type entries (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Log calling function name in qla2x00_get_sp_from_handle() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Simplify return value logic in qla2x00_get_sp_from_handle() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Warn if done() or free() are called on an already freed srb (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix the return value (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix wrong return value in qla_nvme_register_hba() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix wrong return value in qlt_chk_unresolv_exchg() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove redundant variable initialization (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix the size used in a 'dma_free_coherent()' call (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove pci-dma-compat wrapper API (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove superfluous memset() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix regression on sparc64 (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use MBX_TOV_SECONDS for mailbox command timeout values (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Address a set of sparse warnings (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: SAN congestion management implementation (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Change in PUREX to handle FPIN ELS requests (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Introduce a function for computing the debug message prefix (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make qla2x00_restart_isp() easier to read (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix a Coverity complaint in qla2100_fw_dump() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make __qla2x00_alloc_iocbs() initialize 32 bits of request_t.handle (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove a superfluous cast (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Initialize 'n' before using it (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make qla82xx_flash_wait_write_finish() easier to read (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove the __packed annotation from struct fcp_hdr and fcp_hdr_le (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Check the size of struct fcp_hdr at compile time (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix a condition in qla2x00_find_all_fabric_devs() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Set NVMe status code for failed NVMe FCP request (Nilesh Javali) [1887427]
- [scsi] scsi: Fix trivial spelling (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove return value from qla_nvme_ls() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove an unused function (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix endianness annotations in source files (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix endianness annotations in header files (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use make_handle() instead of open-coding it (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Cast explicitly to uint16_t / uint32_t (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Change {RD, WRT}_REG_*() function names from upper case into lower case (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix the code that reads from mailbox registers (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use register names instead of register offsets (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Change two hardcoded constants into offsetof() / sizeof() expressions (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Increase the size of struct qla_fcp_prio_cfg to FCP_PRIO_CFG_SIZE (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make a gap in struct qla2xxx_offld_chain explicit (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add more BUILD_BUG_ON() statements (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Sort BUILD_BUG_ON() statements alphabetically (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Simplify the functions for dumping firmware (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix spelling of a variable name (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Do not log message when reading port speed via sysfs (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make qlafx00_process_aen() return void (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use true, false for ha->fw_dumped (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use true, false for need_mpi_reset (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Make qla_set_ini_mode() return void (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix issue with adapter's stopping state (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix failure message in qlt_disable_vha() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix warning after FC target reset (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: check UNLOADING before posting async work (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: set UNLOADING before waiting for session deletion (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use ARRAY_SIZE() instead of open-coding it (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Split qla2x00_configure_local_loop() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix regression warnings (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Remove non functional code (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: add ring buffer for tracing debug logs (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix RDP respond data format (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: fix FW resource count values (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Improved secure flash support messages (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Use FC generic update firmware options routine for ISP27xx (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Avoid setting firmware options twice in 24xx_update_fw_options (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Convert MAKE_HANDLE() from a define into an inline function (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix sparse warnings triggered by the PCI state checking code (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Suppress endianness complaints in qla2x00_configure_local_loop() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Simplify the code for aborting SCSI commands (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix sparse warning reported by kbuild bot (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Print portname for logging in qla24xx_logio_entry() (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix qla2x00_echo_test() based on ISP type (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Correction to selection of loopback/echo test (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix RDP response size (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Handle cases for limiting RDP response payload length (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add deferred queue for processing ABTS and RDP (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Cleanup ELS/PUREX iocb fields (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Show correct port speed capabilities for RDP command (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Display message for FCE enabled (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add vendor extended FDMI commands (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add ql2xrdpenable module parameter for RDP (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add vendor extended RDP additions and amendments (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Add changes in preparation for vendor extended FDMI/RDP (Nilesh Javali) [1887427]
- [scsi] scsi: qla2xxx: Fix gnl.l memory leak on adapter init failure (Nilesh Javali) [1887427]

* Mon Nov 30 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-256.el8]
- [kernel] PM: hibernate: Batch hibernate and resume IO requests (Lenny Szubowicz) [1868096]
- [net] tunnels: Fix off-by-one in lower MTU bounds for ICMP/ICMPv6 replies (Antoine Tenart) [1895765]
- [block] block: mark flush request as IDLE when it is really finished (Ming Lei) [1895913]
- [net] vsock: forward all packets to the host when no H2G is registered (Vitaly Kuznetsov) [1893826]
- [maintainers] maintainers: Add entry for the Nitro Enclaves driver (Vitaly Kuznetsov) [1893826]
- [documentation] nitro_enclaves: Add overview documentation (Vitaly Kuznetsov) [1893826]
- [samples] nitro_enclaves: Add sample for ioctl interface usage (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add Makefile for the Nitro Enclaves driver (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add Kconfig for the Nitro Enclaves driver (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add logic for terminating an enclave (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add logic for starting an enclave (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add logic for setting an enclave memory region (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add logic for getting the enclave image load info (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add logic for setting an enclave vCPU (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Add logic for creating an enclave VM (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Init misc device providing the ioctl interface (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Handle out-of-band PCI device events (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Handle PCI device command requests (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Init PCI device driver (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Define enclave info for internal bookkeeping (Vitaly Kuznetsov) [1893826]
- [virt] nitro_enclaves: Define the PCI device interface (Vitaly Kuznetsov) [1893826]
- [uapi] nitro_enclaves: Add ioctl interface definition (Vitaly Kuznetsov) [1893826]
- [kernel] cpu/hotplug: Add new {add, remove}_cpu() functions (Vitaly Kuznetsov) [1893826]
- [x86] x86/delay: Introduce TPAUSE delay (Prarit Bhargava) [1838636]
- [x86] x86/delay: Refactor delay_mwaitx() for TPAUSE support (Prarit Bhargava) [1838636]
- [x86] x86/delay: Preparatory code cleanup (Prarit Bhargava) [1838636]
- [net] netfilter: ipset: Update byte and packet counters regardless of whether they match (Phil Sutter) [1806882]
- [net] ethtool: add and use message type for tunnel info reply (Ivan Vecera) [1867211]
- [infiniband] RDMA/hns: Mark hns_roce driver as unsupported (Kamal Heib) [1878211]
- [net] tipc: fix memory leak caused by tipc_buf_append() (Xin Long) [1865774]
- [net] tipc: fix the skb_unshare() in tipc_buf_append() (Xin Long) [1865774]
- [net] tipc: use skb_unshare() instead in tipc_buf_append() (Xin Long) [1865774]
- [netdrv] net: team: fix memory leak in __team_options_register (Hangbin Liu) [1892142]
- [netdrv] team: set dev->needed_headroom in team_setup_by_port() (Hangbin Liu) [1892142]
- [netdrv] team: use netif_is_team_port() (Hangbin Liu) [1892142]
- [char] random: decouple random and urandom extrng fops (Vladis Dronov) [1890711]
- [platform] platform/x86: intel_pmc_core: Add Intel RocketLake (RKL) support (Steve Best) [1782713]
- [netdrv] fm10k: convert to new udp_tunnel_nic infra (Vladis Dronov) [1884254]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Vladis Dronov) [1884254]
- [netdrv] docs: networking: reorganize driver documentation again (Vladis Dronov) [1884254]
- [netdrv] net/intel: remove driver versions from Intel drivers (Vladis Dronov) [1884254]
- [infiniband] RDMA/core: Fix ordering of CQ pool destruction (Kamal Heib) [1878969 1857603]
- [infiniband] IB/isert: Fix unaligned immediate-data handling (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Fix reported speed and width (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Fix unsafe linked list traversal after failing to allocate CQ (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Fix panic when calling kmem_cache_create() (Kamal Heib) [1867296 1857603]
- [infiniband] RDMA/rxe: Fix memleak in rxe_mem_init_user (Kamal Heib) [1857603]
- [net] xprtrdma: Release in-flight MRs on disconnect (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Fix the parent sysfs read when the interface has 15 chars (Kamal Heib) [1870430 1857603]
- [infiniband] RDMA/hfi1: Correct an interlock issue for TID RDMA WRITE request (Kamal Heib) [1870281 1857603]
- [infiniband] RDMA/core: Fix spelling mistake "Could't" -> "Couldn't" (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Remove pkey table (Kamal Heib) [1857603]
- [infiniband] RDMA/umem: Add a schedule point in ib_umem_get() (Kamal Heib) [1857603]
- [infiniband] RDMA/netlink: Remove CAP_NET_RAW check when dump a raw QP (Kamal Heib) [1857603]
- [rdma] RDMA/include: Replace license text with SPDX tags (Kamal Heib) [1857603]
- [infiniband] RDMA/cma: Execute rdma_cm destruction from a handler properly (Kamal Heib) [1857603]
- [infiniband] RDMA/cma: Remove unneeded locking for req paths (Kamal Heib) [1857603]
- [infiniband] RDMA/cma: Using the standard locking pattern when delivering the removal event (Kamal Heib) [1857603]
- [infiniband] RDMA/cma: Simplify DEVICE_REMOVAL for internal_id (Kamal Heib) [1857603]
- [infiniband] RDMA/efa: Add EFA 0xefa1 PCI ID (Kamal Heib) [1857603]
- [infiniband] RDMA/efa: User/kernel compatibility handshake mechanism (Kamal Heib) [1857603]
- [infiniband] RDMA/efa: Expose minimum SQ size (Kamal Heib) [1857603]
- [infiniband] RDMA/efa: Expose maximum TX doorbell batch (Kamal Heib) [1857603]
- [infiniband] IB/srpt: use new shared CQ mechanism (Kamal Heib) [1857603]
- [infiniband] IB/isert: use new shared CQ mechanism (Kamal Heib) [1857603]
- [infiniband] IB/iser: use new shared CQ mechanism (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Fix return error value in _ib_modify_qp() to negative (Kamal Heib) [1857603]
- [infiniband] RDMA/uverbs: Silence shiftTooManyBitsSigned warning (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Update write interface to use automatic object lifetime (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Align abort/commit object scheme for write() and ioctl() paths (Kamal Heib) [1857603]
- [uapi] RDMA: rdma_user_ioctl.h: fix a duplicated word + clarify (Kamal Heib) [1857603]
- [infiniband] RDMA/qedr: Remove the query_pkey callback (Kamal Heib) [1857603]
- [infiniband] RDMA/i40iw: Remove the query_pkey callback (Kamal Heib) [1857603]
- [infiniband] RDMA/cxgb4: Remove the query_pkey callback (Kamal Heib) [1857603]
- [infiniband] RDMA/siw: Remove the query_pkey callback (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Remove query_pkey from the mandatory ops (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Allocate the pkey cache only if the pkey_tbl_len is set (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Expose pkeys sysfs files only if pkey_tbl_len is set (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Prevent access to wr->next ptr afrer wr is posted to send queue (Kamal Heib) [1857603]
- [infiniband] IB/hfi1: Remove unnecessary fall-through markings (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Remove rxe_link_layer() (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Return void from rxe_mem_init_dma() (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Return void from rxe_init_port_param() (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Drop pointless checks in rxe_init_ports (Kamal Heib) [1857603]
- [infiniband] RDMA/counter: Allow manually bind QPs with different pids to same counter (Kamal Heib) [1857603]
- [infiniband] RDMA/counter: Only bind user QPs in auto mode (Kamal Heib) [1857603]
- [infiniband] RDMA/counter: Add PID category support in auto mode (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Skip dgid check in loopback mode (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Create and destroy counters in the ib_core (Kamal Heib) [1857603]
- [infiniband] IB/uverbs: Expose UAPI to query MR (Kamal Heib) [1857603]
- [infiniband] IB/uverbs: Expose UAPI to query ucontext (Kamal Heib) [1857603]
- [infiniband] IB/uverbs: Set IOVA on IB MR in uverbs layer (Kamal Heib) [1857603]
- [infiniband] IB/uverbs: Enable CQ ioctl commands by default (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Clean ib_alloc_xrcd() and reuse it to allocate XRC domain (Kamal Heib) [1857603]
- [infiniband] RDMA: Remove the udata parameter from alloc_mr callback (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Remove ib_alloc_mr_user function (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Check for error instead of success in alloc MR function (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Clean up tracepoint headers (Kamal Heib) [1857603]
- [infiniband] RDMA/ipoib: Handle user-supplied address when creating child (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Fix bogus WARN_ON during ib_unregister_device_queued() (Kamal Heib) [1857603]
- [infiniband] IB/hfi1: Convert PCIBIOS_* errors to generic -E* errors (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Delete not-used create RWQ table function (Kamal Heib) [1857603]
- [infiniband] IB/mad: Delete RMPP_STATE_CANCELING state (Kamal Heib) [1857603]
- [infiniband] IB/mad: Change atomics to refcount API (Kamal Heib) [1857603]
- [infiniband] IB/mad: Issue complete whenever decrements agent refcount (Kamal Heib) [1857603]
- [infiniband] RDMA: Add support to dump resource tracker in RAW format (Kamal Heib) [1857603]
- [infiniband] RDMA: Add dedicated CM_ID resource tracker function (Kamal Heib) [1857603]
- [infiniband] RDMA: Add dedicated QP resource tracker function (Kamal Heib) [1857603]
- [infiniband] RDMA: Add a dedicated CQ resource tracker function (Kamal Heib) [1857603]
- [infiniband] RDMA: Add dedicated MR resource tracker function (Kamal Heib) [1857603]
- [infiniband] RDMA/core: Don't call fill_res_entry for PD (Kamal Heib) [1857603]
- [infiniband] RDMA/rxe: Remove unused rxe_mem_map_pages (Kamal Heib) [1857603]
- [infiniband] RDMA/hfi1: Remove hfi1_create_qp declaration (Kamal Heib) [1857603]
- [infiniband] RDMA/ipoib: Return void from ipoib_mcast_stop_thread() (Kamal Heib) [1857603]
- [infiniband] RDMA: Correct trivial kernel-doc inconsistencies (Kamal Heib) [1857603]
- [infiniband] IB/srpt: Remove WARN_ON from srpt_cm_req_recv (Kamal Heib) [1857603]
- [tools] tools/power turbostat: Support additional CPU model numbers (Steve Best) [1782718]
- [net] udp_tunnel: add the ability to hard-code IANA VXLAN (Ivan Vecera) [1879204]
- [tools] selftests: net: add a test for UDP tunnel info infra (Ivan Vecera) [1867211]
- [netdrv] netdevsim: add UDP tunnel port offload support (Ivan Vecera) [1867211]
- [net] ethtool: add tunnel info interface (Ivan Vecera) [1867211]
- [net] ethtool: Make helpers public (Ivan Vecera) [1867211]
- [net] udp_tunnel: add central NIC RX port offload infrastructure (Ivan Vecera) [1867211]
- [net] udp_tunnel: re-number the offload tunnel types (Ivan Vecera) [1867211]
- [fs] debugfs: make sure we can remove u32_array files cleanly (Ivan Vecera) [1867211]
- [fs] debugfs: make debugfs_create_u32_array() return void (Ivan Vecera) [1867211]
- [fs] debugfs: update documented return values of debugfs helpers (Ivan Vecera) [1867211]

* Fri Nov 27 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-255.el8]
- [net] openvswitch: fix to make sure flow_lookup() is not preempted (Eelco Chaudron) [1888237]
- [netdrv] powerpc/vnic: Extend "failover pending" window (Steve Best) [1897280]
- [net] ipv6: Set SIT tunnel hard_header_len to zero (Davide Caratti) [1897244]
- [net] ip_tunnel: fix over-mtu packet send fail without TUNNEL_DONT_FRAGMENT flags (Davide Caratti) [1897244]
- [net] gre6: Fix reception with IP6_TNL_F_RCV_DSCP_COPY (Davide Caratti) [1897244]
- [netdrv] vxlan: fix memleak of fdb (Davide Caratti) [1897244]
- [net] vxlan: Ensure FDB dump is performed under RCU (Davide Caratti) [1897244]
- [net] gre: refetch erspan header from skb->data after pskb_may_pull() (Davide Caratti) [1897244]
- [net] erspan: fix the tun_info options_len check for erspan (Davide Caratti) [1897244]
- [net] ip_gre: fix possible use-after-free in erspan_rcv (Davide Caratti) [1897244]
- [net] erspan: fix error handling for erspan tunnel (Davide Caratti) [1897244]
- [net] erspan: return PACKET_REJECT when the appropriate tunnel is not found (Davide Caratti) [1897244]
- [netdrv] net: atlantic: fix build when object tree is separate (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: Use readx_poll_timeout() for large timeout (Igor Russkikh) [1857861]
- [netdrv] net: ethernet: aquantia: Fix wrong return value (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix PTP on AQC10X (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add hwmon getter for MAC temperature (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A0 ntuple filters (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: use intermediate variable to improve readability a bit (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: use U32_MAX in aq_hw_utils.c (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add support for 64-bit reads/writes (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: enable ipv6 support for TCP LSO and UDP GSO (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: PTP statistics (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: additional per-queue stats (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: use u64_stats_update_* to protect access to 64-bit stats (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: split rx and tx per-queue stats (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: make _get_sw_stats return count as return value (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: use simple assignment in _get_stats and _get_sw_stats (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: move FRAC_PER_NS to aq_hw.h (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add support for FW 4.x (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: align return value of ver_match function with function name (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: disable PTP on AQC111, AQC112 (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix ip dst and ipv6 address filters (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix aq_ndev_start_xmit()'s return type (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: put ptp code under IS_REACHABLE check (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add alignment checks in hw_atl2_utils_fw.c (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: missing space in a comment in aq_nic.h (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix typo in aq_ring_tx_clean (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: make aq_pci_func_init static (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: Replace ENOTSUPP usage to EOPNOTSUPP (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix variable type in aq_ethtool_get_pauseparam (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2: phy loopback support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2: report link partner capabilities (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2: flow control support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2: EEE support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: remove baseX usage (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2: half duplex support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: proper rss_ctrl1 (54c0) initialization (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: QoS implementation: min_rate (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: change the order of arguments for TC weight/credit setters (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: always use random TC-queue mapping for TX on A2 (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: automatically downgrade the number of queues if necessary (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: QoS implementation: max_rate (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: make TCVEC2RING accept nic_cfg (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: per-TC queue statistics (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: QoS implementation: multi-TC support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: changes for multi-TC support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: move PTP TC initialization to a separate function (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: changes for multi-TC support (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: unify MAC generation (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: remove check for boot code survivability before reset request (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: remove hw_atl_b0_hw_rss_set call from A2 code (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: remove TPO2 check from A0 code (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: rename AQ_NIC_RATE_2GS to AQ_NIC_RATE_2G5 (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: use __packed instead of the full expansion (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2 ingress / egress hw configuration (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: basic A2 init/deinit hw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: common functions needed for basic A2 init/deinit hw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: HW bindings for basic A2 init/deinit hw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add A2 RPF hw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: HW bindings for A2 RFP (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2 hw_ops skeleton (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: minimal A2 fw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: minimal A2 HW bindings required for fw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: A2 driver-firmware interface (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: move IS_CHIP_FEATURE to aq_hw.h (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: make hw_get_regs optional (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: simplify hw_get_fw_version() usage (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add hw_soft_reset, hw_prepare to hw_ops (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add defines for 10M and EEE 100M link mode (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add A2 device IDs (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: update company name in the driver description (Igor Russkikh) [1857861]
- [netdrv] aquantia: Fix the media type of AQC100 ethernet controller in the driver (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: MACSec offload statistics implementation (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: reject all unsupported coalescing params (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: Replace zero-length array with flexible-array member (Igor Russkikh) [1857861]
- [netdrv] net/aquantia: Delete module version (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix out of range usage of active_vlans array (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: possible fault in transition to hibernation (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix potential error handling (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: fix use after free kasan warn (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: better loopback mode handling (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: ptp gpio adjustments (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: check rpc result and wait for rpc address (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: checksum compat issue (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: remove duplicate entries (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: loopback configuration in improper place (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: broken link status on old fw (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: Signedness bug in aq_vec_isr_legacy() (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: make function 'aq_ethtool_get_priv_flags', 'aq_ethtool_set_priv_flags' static (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: make symbol 'aq_pm_ops' static (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: change email domains to Marvell (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: implement UDP GSO offload (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: update flow control logic (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: stylistic renames (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: code style cleanup (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: loopback tests via private flags (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add fw configuration memory area (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: adding ethtool physical identification (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: add msglevel configuration (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: refactoring pm logic (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: implement wake_phy feature (Igor Russkikh) [1857861]
- [netdrv] net: atlantic: update firmware interface (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix return value check in aq_ptp_init() (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix error handling in aq_ptp_poll (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: remove unused including <linux/version.h> (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: make two symbols be static (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix unintention integer overflow on left shift (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix spelling mistake: tx_queus -> tx_queues (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: disable ptp object build if no config (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix warnings on endianness (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix var initialization warning (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: add support for PIN funcs (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: add support for Phy access (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: implement get_ts_info ethtool (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: add support for ptp ioctls (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: rx filters for ptp (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: implement data PTP datapath (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: styling fixes on ptp related functions (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: add PTP rings infrastructure (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: add basic ptp_clock callbacks (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: unify styling of bit enums (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: PTP skeleton declarations and callbacks (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: add an error handling in aq_nic_set_multicast_list (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: correctly handle macvlan and multicast coexistence (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: do not pass lro session with invalid tcp checksum (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: when cleaning hw cache it should be toggled (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: temperature retrieval fix (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: Fix aq_vec_isr_legacy() return value (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix out of memory condition on rx side (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: linkstate irq should be oneshot (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix limit of vlan filters (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: fix removal of vlan 0 (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: implement vlan offload configuration (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: vlan offloads logic in datapath (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: adding fields and device features for vlan offload (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: added vlan offload related macros and functions (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: make all files GPL-2.0-only (Igor Russkikh) [1857861]
- [netdrv] net: aquantia: replace internal driver version code with uts (Igor Russkikh) [1857861]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 422 (Igor Russkikh) [1857861]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 308 (Igor Russkikh) [1857861]
- [include] net: phy: introduce phy_read_mmd_poll_timeout macro (Josef Oskera) [1892739]
- [include] net: phy: introduce phy_read_poll_timeout macro (Josef Oskera) [1892739]
- [netdrv] phy: add device-managed devm_mdiobus_register (Josef Oskera) [1892740]
- [include] net: add helper eth_hw_addr_crc (Josef Oskera) [1892738]
- [netdrv] LiquidIO: mark liquidio and liquidio_vf as deprecated in RHEL8 (Stefan Assmann) [1878178]
- [net] tcp: remove SOCK_QUEUE_SHRUNK (Paolo Abeni) [1890058]
- [net] tcp: fix receive window update in tcp_add_backlog() (Paolo Abeni) [1890058]
- [net] tcp: md5: allow changing MD5 keys in all socket states (Paolo Abeni) [1890058]
- [net] tcp: fix SO_RCVLOWAT possible hangs under high mem pressure (Paolo Abeni) [1890058]
- [net] tcp: md5: do not send silly options in SYNCOOKIES (Paolo Abeni) [1890058]
- [net] tcp: grow window for OOO packets only for SACK flows (Paolo Abeni) [1890058]
- [net] tcp: fix error recovery in tcp_zerocopy_receive() (Paolo Abeni) [1890058]
- [net] tcp: fix SO_RCVLOWAT hangs with fat skbs (Paolo Abeni) [1890058]
- [net] tcp: fix rx timestamp behavior for tcp_recvmsg (Paolo Abeni) [1890058]
- [fs] smb3: smbdirect support can be configured by default (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Do not schedule work to send immediate packet on every receive (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Properly process errors on ib_post_send (Leif Sahlberg) [1887940]
- [fs] cifs: Allocate crypto structures on the fly for calculating signatures of incoming packets (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Update receive credits before sending and deal with credits roll back on failure before sending (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Check send queue size before posting a send (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Merge code to track pending packets (Leif Sahlberg) [1887940]
- [fs] cifs: Allocate encryption header through kmalloc (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Check and extend sender credits in interrupt context (Leif Sahlberg) [1887940]
- [fs] cifs: smbd: Calculate the correct maximum packet size for segmented SMBDirect send/receive (Leif Sahlberg) [1887940]
- [net] core: device_rename: Use rwsem instead of a seqcount (Patrick Talbert) [1883310]

* Thu Nov 26 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-254.el8]
- [tools] perf tools: Add bpf image check to __map__is_kmodule (Michael Petlan) [1873270]
- [tools] perf tools: Add support for PERF_RECORD_KSYMBOL_TYPE_OOL (Michael Petlan) [1873270]
- [tools] perf record: Don't clear event's period if set by a term (Michael Petlan) [1873270]
- [tools] perf bench: The do_run_multi_threaded() function must use IS_ERR(perf_session__new()) (Michael Petlan) [1873270]
- [tools] perf top: Skip side-band event setup if HAVE_LIBBPF_SUPPORT is not set (Michael Petlan) [1873270]
- [tools] perf record: Skip side-band event setup if HAVE_LIBBPF_SUPPORT is not set (Michael Petlan) [1873270]
- [tools] perf evsel: Don't set sample_regs_intr/sample_regs_user for dummy event (Michael Petlan) [1873270]
- [tools] perf stat: Turn off summary for interval mode by default (Michael Petlan) [1873270]
- [tools] perf trace: Fix off by ones in memset() after realloc() in arches using libaudit (Michael Petlan) [1873270]
- [tools] perf top/report: Fix infinite loop in the TUI for grouped events (Michael Petlan) [1873270]
- [tools] redhat: use local hashmap library in perf (Michael Petlan) [1873270]
- [tools] libtraceevent: Fix build with binutils 2.35 (Michael Petlan) [1873270]
- [tools] perf tools: Fix record failure when mixed with ARM SPE event (Michael Petlan) [1873270]
- [tools] perf tests: Fix test 68 zstd compression for s390 (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Fix memory leak in process_dynamic_array_len (Michael Petlan) [1873270]
- [tools] perf tools: Sync hashmap.h with libbpf's (Michael Petlan) [1873270]
- [tools] libsubcmd: Fix OPT_CALLBACK_SET() (Michael Petlan) [1873270]
- [tools] perf report TUI: Remove needless 'dummy' event from menu (Michael Petlan) [1873270]
- [tools] perf intel-pt: Fix PEBS sample for XMM registers (Michael Petlan) [1873270]
- [tools] perf intel-pt: Fix displaying PEBS-via-PT with registers (Michael Petlan) [1873270]
- [tools] perf intel-pt: Fix recording PEBS-via-PT with registers (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Add proper KBUFFER_TYPE_TIME_STAMP handling (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Add API to read time information from kbuffer (Michael Petlan) [1873270]
- [tools] perf scripts python: exported-sql-viewer.py: Fix time chart call tree (Michael Petlan) [1873270]
- [tools] perf scripts python: exported-sql-viewer.py: Fix zero id in call tree 'Find' result (Michael Petlan) [1873270]
- [tools] perf scripts python: exported-sql-viewer.py: Fix zero id in call graph 'Find' result (Michael Petlan) [1873270]
- [tools] perf scripts python: exported-sql-viewer.py: Fix unexpanded 'Find' result (Michael Petlan) [1873270]
- [tools] perf record: Fix duplicated sideband events with Intel PT system wide tracing (Michael Petlan) [1873270]
- [tools] perf scripts python: export-to-postgresql.py: Fix struct.pack() int argument (Michael Petlan) [1873270]
- [tools] perf build: Fix error message when asking for -fsanitize=address without required libraries (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Add handler for __builtin_expect() (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Handle __attribute__((user)) in field names (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Add append() function helper for appending strings (Michael Petlan) [1873270]
- [tools] perf script: Initialize zstd_data (Michael Petlan) [1873270]
- [tools] perf pmu: Remove unused declaration (Michael Petlan) [1873270]
- [tools] perf parse-events: Fix an old style declaration (Michael Petlan) [1873270]
- [tools] perf parse-events: Fix an incompatible pointer (Michael Petlan) [1873270]
- [tools] perf bpf: Fix bpf prologue generation (Michael Petlan) [1873270]
- [tools] perf probe: Fix user attribute access in kprobes (Michael Petlan) [1873270]
- [tools] perf stat: Fix NULL pointer dereference (Michael Petlan) [1873270]
- [tools] perf report: Fix NULL pointer dereference in hists__fprintf_nr_sample_events() (Michael Petlan) [1873270]
- [tools] perf tools: Remove some duplicated includes (Michael Petlan) [1873270]
- [tools] perf symbols: Fix kernel maps for kcore and eBPF (Michael Petlan) [1873270]
- [tools] perf stat: Ensure group is defined on top of the same cpu mask (Michael Petlan) [1873270]
- [tools] perf libdw: Fix off-by 1 relative directory includes (Michael Petlan) [1873270]
- [tools] perf arm-spe: Support synthetic events (Michael Petlan) [1873270]
- [tools] perf auxtrace: Add four itrace options (Michael Petlan) [1873270]
- [tools] perf tools: Move arm-spe-pkt-decoder.h/c to the new dir (Michael Petlan) [1873270]
- [tools] perf test: Initialize memory in dwarf-unwind (Michael Petlan) [1873270]
- [tools] perf tests: Don't tail call optimize in unwind test (Michael Petlan) [1873270]
- [tools] tools compiler.h: Add attribute to disable tail calls (Michael Petlan) [1873270]
- [tools] perf build: Add a LIBPFM4=1 build test entry (Michael Petlan) [1873270]
- [tools] perf tools: Add optional support for libpfm4 (Michael Petlan) [1873270]
- [tools] perf tools: Correct license on jsmn JSON parser (Michael Petlan) [1873270]
- [tools] perf jit: Fix inaccurate DWARF line table (Michael Petlan) [1873270]
- [tools] perf jvmti: Remove redundant jitdump line table entries (Michael Petlan) [1873270]
- [tools] perf build: Add NO_SDT=1 to the default set of build tests (Michael Petlan) [1873270]
- [tools] perf build: Add NO_LIBCRYPTO=1 to the default set of build tests (Michael Petlan) [1873270]
- [tools] perf build: Add NO_SYSCALL_TABLE=1 to the build tests (Michael Petlan) [1873270]
- [tools] perf build: Remove libaudit from the default feature checks (Michael Petlan) [1873270]
- [tools] perf trace: Grow the syscall table as needed when using libaudit (Michael Petlan) [1873270]
- [tools] perf trace: Use zalloc() to make sure all fields are zeroed in the syscalltbl constructor (Michael Petlan) [1873270]
- [tools] perf trace: Remove union from syscalltbl, all the fields are needed (Michael Petlan) [1873270]
- [tools] perf build: Allow explicitely disabling the NO_SYSCALL_TABLE variable (Michael Petlan) [1873270]
- [tools] perf build: Group the NO_SYSCALL_TABLE logic (Michael Petlan) [1873270]
- [tools] perf intel-pt: Refine kernel decoding only warning message (Michael Petlan) [1873270]
- [tools] perf record: Respect --no-switch-events (Michael Petlan) [1873270]
- [tools] perf script: Fix --call-trace for Intel PT (Michael Petlan) [1873270]
- [tools] perf evlist: Disable 'immediate' events last (Michael Petlan) [1873270]
- [tools] perf kcore_copy: Fix module map when there are no modules loaded (Michael Petlan) [1873270]
- [tools] perf jvmti: Fix demangling Java symbols (Michael Petlan) [1873270]
- [tools] perf tests: Add test for the java demangler (Michael Petlan) [1873270]
- [tools] perf jvmti: Do not report error when missing debug information (Michael Petlan) [1873270]
- [tools] perf jvmti: Fix jitdump for methods without debug info (Michael Petlan) [1873270]
- [tools] perf symbols: Fix debuginfo search for Ubuntu (Michael Petlan) [1873270]
- [tools] perf parse: Add 'struct parse_events_state' pointer to scanner (Michael Petlan) [1873270]
- [tools] perf stat: Do not pass avg to generic_metric (Michael Petlan) [1873270]
- [tools] perf tests: Consider subtests when searching for user specified tests (Michael Petlan) [1873270]
- [tools] perf list: Add metrics to command line usage (Michael Petlan) [1873270]
- [tools] perf script: Don't force less for non tty output with --xed (Michael Petlan) [1873270]
- [tools] perf metricgroup: Remove unnecessary ', ' from events (Michael Petlan) [1873270]
- [tools] perf metricgroup: Add options to not group or merge (Michael Petlan) [1873270]
- [tools] perf metricgroup: Remove duped metric group events (Michael Petlan) [1873270]
- [tools] perf metricgroup: Order event groups by size (Michael Petlan) [1873270]
- [tools] perf metricgroup: Delay events string creation (Michael Petlan) [1873270]
- [tools] perf metricgroup: Use early return in add_metric (Michael Petlan) [1873270]
- [tools] perf metricgroup: Always place duration_time last (Michael Petlan) [1873270]
- [tools] perf metricgroup: Free metric_events on error (Michael Petlan) [1873270]
- [tools] perf util: Fix potential SEGFAULT in put_tracepoints_path error path (Michael Petlan) [1873270]
- [tools] perf util: Fix memory leak of prefix_if_not_in (Michael Petlan) [1873270]
- [tools] perf ftrace: Detect workload failure (Michael Petlan) [1873270]
- [tools] perf ftrace: Trace system wide if no target is given (Michael Petlan) [1873270]
- [tools] perf branch: Replace zero-length array with flexible-array (Michael Petlan) [1873270]
- [tools] perf config: Add stat.big-num support (Michael Petlan) [1873270]
- [tools] perf bpf-loader: Add missing '*' for key_scan_pos (Michael Petlan) [1873270]
- [tools] perf stat: Report summary for interval mode (Michael Petlan) [1873270]
- [tools] perf stat: Save aggr value to first member of prev_raw_counts (Michael Petlan) [1873270]
- [tools] perf stat: Copy counts from prev_raw_counts to evsel->counts (Michael Petlan) [1873270]
- [tools] perf counts: Reset prev_raw_counts counts (Michael Petlan) [1873270]
- [tools] perf stat: Fix wrong per-thread runtime stat for interval mode (Michael Petlan) [1873270]
- [tools] perf expr: Allow numbers to be followed by a dot (Michael Petlan) [1873270]
- [tools] perf metricgroup: Make 'evlist_used' variable a bitmap instead of array of bools (Michael Petlan) [1873270]
- [tools] perf stat: Fail on extra comma while parsing events (Michael Petlan) [1873270]
- [tools] perf script: Better align register values in dump (Michael Petlan) [1873270]
- [tools] perf stat: POWER9 metrics: expand "ICT" acronym (Michael Petlan) [1873270]
- [tools] perf tools: Replace zero-length array with flexible-array (Michael Petlan) [1873270]
- [tools] perf intel-pt: Use allocated branch stack for PEBS sample (Michael Petlan) [1873270]
- [tools] perf docs: Introduce security.txt file to document related issues (Michael Petlan) [1873270]
- [tools] perf tool: Make perf tool aware of SELinux access control (Michael Petlan) [1873270]
- [tools] perf docs: Extend CAP_SYS_ADMIN with CAP_PERFMON where needed (Michael Petlan) [1873270]
- [tools] perf expr: Migrate expr ids table to a hashmap (Michael Petlan) [1873270]
- [tools] perf tools: Grab a copy of libbpf's hashmap (Michael Petlan) [1873270]
- [tools] perf stat: Fix duration_time value for higher intervals (Michael Petlan) [1873270]
- [tools] perf trace: Fix compilation error for make NO_LIBBPF=1 DEBUG=1 (Michael Petlan) [1873270]
- [tools] perf beauty: Allow the CC used in the arch errno names script to acccept CFLAGS (Michael Petlan) [1873270]
- [tools] perf trace: Fix the selection for architectures to generate the errno name tables (Michael Petlan) [1873270]
- [tools] perf test: Improve pmu event metric testing (Michael Petlan) [1873270]
- [tools] perf test: Provide a subtest callback to ask for the reason for skipping a subtest (Michael Petlan) [1873270]
- [tools] perf parse-events: Make add PMU verbose output clearer (Michael Petlan) [1873270]
- [tools] perf expr: Fix memory leaks in metric bison (Michael Petlan) [1873270]
- [tools] perf expr: Test parsing of floating point numbers (Michael Petlan) [1873270]
- [tools] perf record: Use an eventfd to wakeup when done (Michael Petlan) [1873270]
- [tools] tools feature: Rename HAVE_EVENTFD to HAVE_EVENTFD_SUPPORT (Michael Petlan) [1873270]
- [tools] perf evsel: Initialize evsel->per_pkg_mask to NULL in evsel__init() (Michael Petlan) [1873270]
- [tools] perf evsel: Fix 2 memory leaks (Michael Petlan) [1873270]
- [tools] perf parse-events: Fix incorrect conversion of 'if () free()' to 'zfree()' (Michael Petlan) [1873270]
- [tools] perf tools: Fix is_bpf_image function logic (Michael Petlan) [1873270]
- [tools] perf c2c: Fix 'perf c2c record -e list' to show the default events used (Michael Petlan) [1873270]
- [tools] perf record: Add dummy event during system wide synthesis (Michael Petlan) [1873270]
- [tools] perf evsel: Dummy events never triggers, no need to ask for PERF_SAMPLE_BRANCH_STACK (Michael Petlan) [1873270]
- [tools] perf parse-events: Use strcmp() to compare the PMU name (Michael Petlan) [1873270]
- [tools] perf expr: Print a debug message for division by zero (Michael Petlan) [1873270]
- [tools] perf expr: Debug lex if debugging yacc (Michael Petlan) [1873270]
- [tools] perf expr: Parse numbers as doubles (Michael Petlan) [1873270]
- [tools] perf expr: Increase max other (Michael Petlan) [1873270]
- [tools] perf expr: Allow ',' to be an other token (Michael Petlan) [1873270]
- [tools] perf metrics: Fix parse errors in skylake metrics (Michael Petlan) [1873270]
- [tools] perf metrics: Fix parse errors in cascade lake metrics (Michael Petlan) [1873270]
- [tools] perf expr: Allow for unlimited escaped characters in a symbol (Michael Petlan) [1873270]
- [tools] perf script: Enable IP fields for callchains (Michael Petlan) [1873270]
- [tools] perf callchain: Setup callchain properly in pipe mode (Michael Petlan) [1873270]
- [tools] perf session: Try to read pipe data from file (Michael Petlan) [1873270]
- [tools] perf tools: Do not seek in pipe fd during tracing data processing (Michael Petlan) [1873270]
- [tools] perf tools: Do not display extra info when there is nothing to build (Michael Petlan) [1873270]
- [tools] perf probe: Do not show the skipped events (Michael Petlan) [1873270]
- [tools] perf probe: Check address correctness by map instead of _etext (Michael Petlan) [1873270]
- [tools] perf probe: Fix to check blacklist address correctly (Michael Petlan) [1873270]
- [tools] perf probe: Accept the instance number of kretprobe event (Michael Petlan) [1873270]
- [tools] perf counts: Rename perf_evsel__*counts() to evsel__*counts() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__w_cache* to evsel__w_cache* (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__new*() to evsel__new*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename *perf_evsel__get_config_term() & friends to evsel__env() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__fprintf() to evsel__fprintf() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__resort*() to evsel__resort*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__object_config() to evsel__object_config() (Michael Petlan) [1873270]
- [tools] perf cs-etm: Move definition of 'traceid_list' global variable from header file (Michael Petlan) [1873270]
- [tools] libsymbols kallsyms: Move hex2u64 out of header (Michael Petlan) [1873270]
- [tools] libsymbols kallsyms: Parse using io api (Michael Petlan) [1873270]
- [tools] perf bench: Add kallsyms parsing (Michael Petlan) [1873270]
- [tools] perf: cs-etm: Update to build with latest opencsd version (Michael Petlan) [1873270]
- [tools] perf symbol: Fix kernel symbol address display (Michael Petlan) [1873270]
- [tools] perf inject: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf annotate: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf trace: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf script: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf sched: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf lock: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf kmem: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf stat: Rename perf_evsel__*() operating on 'struct evsel *' to evsel__*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__store_ids() to evsel__store_id() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__env() to evsel__env() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__group_idx() to evsel__group_idx() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__fallback() to evsel__fallback() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__has*() to evsel__has*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__{prev, next}() to evsel__{prev, next}() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__parse_sample*() to evsel__parse_sample*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename *perf_evsel__read*() to *evsel__read() (Michael Petlan) [1873270]
- [tools] perf evsel: Ditch perf_evsel__cmp(), not used for quite a while (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__is_*() to evsel__is*() (Michael Petlan) [1873270]
- [tools] perf pmu: Add perf_pmu__find_by_type helper (Michael Petlan) [1873270]
- [tools] tools feature: Add support for detecting libpfm4 (Michael Petlan) [1873270]
- [tools] perf doc: Pass ASCIIDOC_EXTRA as an argument (Michael Petlan) [1873270]
- [tools] perf mem2node: Avoid double free related to realloc (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__{str, int}val() and other tracepoint field metehods to to evsel__*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__open_per_*() to evsel__open_per_*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__*filter*() to evsel__*filter*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename *perf_evsel__*set_sample_*() to *evsel__*set_sample_*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__group_desc() to evsel__group_desc() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename *perf_evsel__*name() to *evsel__*name() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename __perf_evsel__sample_size() to __evsel__sample_size() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__calc_id_pos() to evsel__calc_id_pos() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__config*() to evsel__config*() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__exit() to evsel__exit() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__is_aux_event() to evsel__is_aux_event() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__find_pmu() to evsel__find_pmu() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__compute_deltas() to evsel__compute_deltas() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename perf_evsel__nr_cpus() to evsel__nr_cpus() (Michael Petlan) [1873270]
- [tools] perf evsel: Rename 'struct perf_evsel__sb_cb_t' to 'struct evsel__sb_cb_t' (Michael Petlan) [1873270]
- [tools] perf intel-pt: Update documentation about using /proc/kcore (Michael Petlan) [1873270]
- [tools] perf intel-pt: Update documentation about itrace G and L options (Michael Petlan) [1873270]
- [tools] perf intel-pt: Add support for synthesizing branch stacks for regular events (Michael Petlan) [1873270]
- [tools] perf thread-stack: Add thread_stack__br_sample_late() (Michael Petlan) [1873270]
- [tools] perf evsel: Add support for synthesized branch stack sample type (Michael Petlan) [1873270]
- [tools] perf auxtrace: Add option to synthesize branch stack for regular events (Michael Petlan) [1873270]
- [tools] perf intel-pt: Change branch stack support to use thread-stacks (Michael Petlan) [1873270]
- [tools] perf intel-pt: Consolidate thread-stack use condition (Michael Petlan) [1873270]
- [tools] perf thread-stack: Add branch stack support (Michael Petlan) [1873270]
- [tools] perf tools: Simplify checking if SMT is active (Michael Petlan) [1873270]
- [tools] perf tools: Fix reading new topology attribute "core_cpus" (Michael Petlan) [1873270]
- [tools] libperf evlist: Fix a refcount leak (Michael Petlan) [1873270]
- [tools] perf parse-events: Fix another memory leaks found on parse_events() (Michael Petlan) [1873270]
- [tools] perf parse-events: Fix memory leaks found on parse_events (Michael Petlan) [1873270]
- [tools] perf parse-events: Fix memory leaks found on parse_events (Michael Petlan) [1873270]
- [tools] libperf: Add NULL pointer check for cpu_map iteration and NULL assignment for all_cpus (Michael Petlan) [1873270]
- [tools] perf record: Move side band evlist setup to separate routine (Michael Petlan) [1873270]
- [tools] perf record: Introduce --switch-output-event (Michael Petlan) [1873270]
- [tools] libsubcmd: Introduce OPT_CALLBACK_SET() (Michael Petlan) [1873270]
- [tools] perf evlist: Allow reusing the side band thread for more purposes (Michael Petlan) [1873270]
- [tools] perf evlist: Move the sideband thread routines to separate object (Michael Petlan) [1873270]
- [tools] perf parse-events: Add parse_events_option() variant that creates evlist (Michael Petlan) [1873270]
- [tools] perf bpf: Decouple creating the evlist from adding the SB event (Michael Petlan) [1873270]
- [tools] perf top: Move sb_evlist to 'struct perf_top' (Michael Petlan) [1873270]
- [tools] perf record: Move sb_evlist to 'struct record' (Michael Petlan) [1873270]
- [tools] perf tools: Move routines that probe for perf API features to separate file (Michael Petlan) [1873270]
- [tools] perf vendor events power9: Add hv_24x7 socket/chip level metric events (Michael Petlan) [1873270]
- [tools] perf tools: Enable Hz/hz prinitg for --metric-only option (Michael Petlan) [1873270]
- [tools] perf tests expr: Added test for runtime param in metric expression (Michael Petlan) [1873270]
- [tools] perf metricgroups: Enhance JSON/metric infrastructure to handle "?" (Michael Petlan) [1873270]
- [tools] perf pmu: Fix function name in comment, its get_cpuid_str(), not get_cpustr() (Michael Petlan) [1873270]
- [tools] perf report: Fix warning assignment of 0/1 to bool variable (Michael Petlan) [1873270]
- [tools] perf tools: Remove unneeded semicolons (Michael Petlan) [1873270]
- [tools] perf c2c: Remove unneeded semicolon (Michael Petlan) [1873270]
- [tools] libtraceevent: Remove unneeded semicolon (Michael Petlan) [1873270]
- [tools] perf script: Remove extraneous newline in perf_sample__fprintf_regs() (Michael Petlan) [1873270]
- [tools] perf synthetic events: Remove use of sscanf from /proc reading (Michael Petlan) [1873270]
- [tools] tools api: Add a lightweight buffered reading api (Michael Petlan) [1873270]
- [tools] perf bench: Add a multi-threaded synthesize benchmark (Michael Petlan) [1873270]
- [tools] perf record: Add num-synthesize-threads option (Michael Petlan) [1873270]
- [tools] perf test session topology: Fix data path (Michael Petlan) [1873270]
- [tools] perf stat: Improve runtime stat for interval mode (Michael Petlan) [1873270]
- [tools] perf stat: Zero all the 'ena' and 'run' array slot stats for interval mode (Michael Petlan) [1873270]
- [tools] perf evlist: Remove duplicate headers (Michael Petlan) [1873270]
- [tools] perf bench: Fix div-by-zero if runtime is zero (Michael Petlan) [1873270]
- [tools] perf cgroup: Avoid needless closing of unopened fd (Michael Petlan) [1873270]
- [tools] perf hist: Add fast path for duplicate entries check (Michael Petlan) [1873270]
- [tools] perf c2c: Add option to enable the LBR stitching approach (Michael Petlan) [1873270]
- [tools] perf top: Add option to enable the LBR stitching approach (Michael Petlan) [1873270]
- [tools] perf script: Add option to enable the LBR stitching approach (Michael Petlan) [1873270]
- [tools] perf report: Add option to enable the LBR stitching approach (Michael Petlan) [1873270]
- [tools] perf callchain: Stitch LBR call stack (Michael Petlan) [1873270]
- [tools] perf callchain: Save previous cursor nodes for LBR stitching approach (Michael Petlan) [1873270]
- [tools] perf thread: Save previous sample for LBR stitching approach (Michael Petlan) [1873270]
- [tools] perf thread: Add a knob for LBR stitch approach (Michael Petlan) [1873270]
- [tools] perf machine: Factor out lbr_callchain_add_lbr_ip() (Michael Petlan) [1873270]
- [tools] perf machine: Factor out lbr_callchain_add_kernel_ip() (Michael Petlan) [1873270]
- [tools] perf machine: Refine the function for LBR call stack reconstruction (Michael Petlan) [1873270]
- [tools] perf machine: Remove the indent in resolve_lbr_callchain_sample (Michael Petlan) [1873270]
- [tools] perf header: Support CPU PMU capabilities (Michael Petlan) [1873270]
- [tools] perf parser: Add support to specify rXXX event with pmu (Michael Petlan) [1873270]
- [tools] perf doc: allow ASCIIDOC_EXTRA to be an argument (Michael Petlan) [1873270]
- [tools] perf pmu: Add support for PMU capabilities (Michael Petlan) [1873270]
- [tools] tools lib traceevent: Take care of return value of asprintf (Michael Petlan) [1873270]
- [tools] perf stat: Force error in fallback on :k events (Michael Petlan) [1873270]
- [tools] perf tools: Add support for leader-sampling with AUX area events (Michael Petlan) [1873270]
- [tools] perf evlist: Allow multiple read formats (Michael Petlan) [1873270]
- [tools] perf evsel: Rearrange perf_evsel__config_leader_sampling() (Michael Petlan) [1873270]
- [tools] perf evlist: Move leader-sampling configuration (Michael Petlan) [1873270]
- [tools] perf evsel: Move and globalize perf_evsel__find_pmu() and perf_evsel__is_aux_event() (Michael Petlan) [1873270]
- [tools] perf intel-pt: Add support for synthesizing callchains for regular events (Michael Petlan) [1873270]
- [tools] perf evsel: Add support for synthesized sample type (Michael Petlan) [1873270]
- [tools] perf evsel: Be consistent when looking which evsel PERF_SAMPLE_ bits are set (Michael Petlan) [1873270]
- [tools] perf thread-stack: Add thread_stack__sample_late() (Michael Petlan) [1873270]
- [tools] perf auxtrace: Add an option to synthesize callchains for regular events (Michael Petlan) [1873270]
- [tools] perf auxtrace: For reporting purposes, un-group AUX area event (Michael Petlan) [1873270]
- [tools] perf s390-cpumsf: Implement ->evsel_is_auxtrace() callback (Michael Petlan) [1873270]
- [tools] perf cs-etm: Implement ->evsel_is_auxtrace() callback (Michael Petlan) [1873270]
- [tools] perf arm-spe: Implement ->evsel_is_auxtrace() callback (Michael Petlan) [1873270]
- [tools] perf intel-bts: Implement ->evsel_is_auxtrace() callback (Michael Petlan) [1873270]
- [tools] perf intel-pt: Implement ->evsel_is_auxtrace() callback (Michael Petlan) [1873270]
- [tools] perf auxtrace: Add ->evsel_is_auxtrace() callback (Michael Petlan) [1873270]
- [tools] perf metrictroup: Split the metricgroup__add_metric function (Michael Petlan) [1873270]
- [tools] perf expr: Add expr_scanner_ctx object (Michael Petlan) [1873270]
- [tools] perf expr: Add expr_ prefix for parse_ctx and parse_id (Michael Petlan) [1873270]
- [tools] perf synthetic-events: save 4kb from 2 stack frames (Michael Petlan) [1873270]
- [tools] tools api fs: Make xxx__mountpoint() more scalable (Michael Petlan) [1873270]
- [tools] perf bench: Add event synthesis benchmark (Michael Petlan) [1873270]
- [tools] perf script: Simplify auxiliary event printing functions (Michael Petlan) [1873270]
- [tools] perf tools: Support CAP_PERFMON capability (Michael Petlan) [1873270]
- [tools] perf annotate: Add basic support for bpf_image (Michael Petlan) [1873270]
- [tools] perf machine: Set ksymbol dso as loaded on arrival (Michael Petlan) [1873270]
- [tools] perf tools: Synthesize bpf_trampoline/dispatcher ksymbol event (Michael Petlan) [1873270]
- [tools] perf stat: Honour --timeout for forked workloads (Michael Petlan) [1873270]
- [powerpc] powerpc/watchpoint: Add hw_len wherever missing (Michael Petlan) [1873270]
- [kernel] perf: Fix task_function_call() error handling (Michael Petlan) [1873270]
- [x86] perf/x86/rapl: Fix RAPL config variable bug (Michael Petlan) [1873270]
- [x86] perf/x86/rapl: Add AMD Fam17h RAPL support (Michael Petlan) [1873270]
- [x86] perf/x86/rapl: Make perf_probe_msr() more robust and flexible (Michael Petlan) [1873270]
- [x86] perf/x86/rapl: Flip logic on default events visibility (Michael Petlan) [1873270]
- [x86] perf/x86/rapl: Refactor to share the RAPL code between Intel and AMD CPUs (Michael Petlan) [1873270]
- [x86] perf/x86/rapl: Move RAPL support to common x86 code (Michael Petlan) [1873270]
- [kernel] perf/core: Replace zero-length array with flexible-array (Michael Petlan) [1873270]
- [x86] perf/x86: Replace zero-length array with flexible-array (Michael Petlan) [1873270]
- [x86] perf/x86/intel: Add more available bits for OFFCORE_RESPONSE of Intel Tremont (Michael Petlan) [1873270]
- [x86] perf/x86/intel/pt: Drop pointless NULL assignment (Michael Petlan) [1873270]
- [kernel] perf: Add cond_resched() to task_function_call() (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: open access for CAP_PERFMON privileged process (Michael Petlan) [1873270]
- [kernel] perf/core: open access to probes for CAP_PERFMON privileged process (Michael Petlan) [1873270]
- [kernel] perf/core: Open access to the core for CAP_PERFMON privileged process (Michael Petlan) [1873270]
- [include] perf/core: Fix !CONFIG_PERF_EVENTS build warnings and failures (Michael Petlan) [1873270]
- [security] perf_event: Add support for LSM and SELinux checks (Michael Petlan) [1873270]
- [powerpc] powerpc/perf/hv-24x7: Fix inconsistent output values incase multiple hv-24x7 events run (Michael Petlan) [1873270]
- [powerpc] powerpc/hv-24x7: Add rtas call in hv-24x7 driver to get processor details (Michael Petlan) [1873270]
- [powerpc] powerpc/hv-24x7: Add sysfs files inside hv-24x7 device to show processor details (Michael Petlan) [1873270]
- [documentation] Documentation/ABI: Add ABI documentation for chips and sockets (Michael Petlan) [1873270]
- [powerpc] powerpc/pseries: Update hv-24x7 information after migration (Michael Petlan) [1873270]
- [powerpc] powerpc/watchpoint: Fix ptrace code that muck around with address/len (Michael Petlan) [1873270]
- [powerpc] powerpc/watchpoint: Fix length calculation for unaligned target (Michael Petlan) [1873270]
- [powerpc] powerpc/watchpoint: Introduce macros for watchpoint length (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: fix imc allocation failure handling (Michael Petlan) [1873270]
- [powerpc] powerpc/perf/24x7: use rb_entry (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: Fix MMCRA corruption by bhrb_filter (Michael Petlan) [1873270]
- [powerpc] perf/core, arch/powerpc: use PERF_PMU_CAP_NO_EXCLUDE for exclusion incapable PMUs (Michael Petlan) [1873270]
- [powerpc] Powerpc/perf: Wire up PMI throttling (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: Remove l2 bus events from HW cache event array (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: Add constraints for power9 l2/l3 bus events (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: Fix unit_sel/cache_sel checks (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: Cleanup cache_sel bits comment (Michael Petlan) [1873270]
- [powerpc] powerpc/perf: Fix thresholding counter data for unknown type (Michael Petlan) [1873270]
- [fs] writeback: Drop I_DIRTY_TIME_EXPIRE (Waiman Long) [1860031]
- [fs] writeback: Fix sync livelock due to b_dirty_time processing (Waiman Long) [1860031]
- [fs] writeback: Avoid skipping inode writeback (Waiman Long) [1860031]
- [fs] writeback: Protect inode->i_io_list with inode->i_lock (Waiman Long) [1860031]
- [fs] dcache: sort the freeing-without-RCU-delay mess for good (Waiman Long) [1860031]
- [net] udp: Improve load balancing for SO_REUSEPORT. (Davide Caratti) [1894075]
- [net] udp: Fix wrong clean up for IS_UDPLITE macro (Davide Caratti) [1894075]
- [fs] ext4: disallow modifying DAX inode flag if inline_data has been set (Eric Sandeen) [1838344]
- [include] dax: Fix compilation for CONFIG_DAX && !CONFIG_FS_DAX (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: Fix stack overflow when mounting fsdax pmem device (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dm: Call proper helper to determine dax support (Eric Sandeen) [1838876 1854346 1838344]
- [md] dm/dax: Fix table reference counts (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: fix detection of dax support for non-persistent memory block devices (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: do not print error message for non-persistent memory block device (Eric Sandeen) [1838876 1854346 1838344]
- [fs] dax: Fix incorrect argument passed to xas_set_err() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Support that ioctl(SETXFLAGS/GETXFLAGS) can set/get inode DAX on XFS (Eric Sandeen) [1838876 1854346 1838344]
- [dax] drivers/dax: Expand lock scope to cover the use of addresses (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/dax: Remove unused size parameter (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: print error message by pr_info() in __generic_fsdax_supported() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] ext4: avoid race conditions when remounting with options that change dax (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Update xfs_ioctl_setattr_dax_invalidate() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Combine xfs_diflags_to_linux() and xfs_diflags_to_iflags() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Create function xfs_inode_should_enable_dax() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Make DAX mount option a tri-state (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Change XFS_MOUNT_DAX to XFS_MOUNT_DAX_ALWAYS (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/xfs: Remove unnecessary initialization of i_rwsem (Eric Sandeen) [1838876 1854346 1838344]
- [documentation] Documentation/dax: Update DAX enablement for ext4 (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Introduce DAX inode flag (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Remove jflag variable (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Make DAX mount option a tri-state (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Only change S_DAX on inode load (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Update ext4_should_use_dax() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Change EXT4_MOUNT_DAX to EXT4_MOUNT_DAX_ALWAYS (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/ext4: Narrow scope of DAX check in setflags (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs: Introduce DCACHE_DONTCACHE (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs: Lift XFS_IDONTCACHE to the VFS layer (Eric Sandeen) [1838876 1854346 1838344]
- [documentation] Documentation/dax: Update Usage section (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs/stat: Define DAX statx attribute (Eric Sandeen) [1838876 1854346 1838344]
- [block] fs: Remove unneeded IS_DAX() check in io_is_direct() (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: Move mandatory ->zero_page_range() check in alloc_dax() (Eric Sandeen) [1838876 1854346 1838344]
- [fs] dax, iomap: Add helper dax_iomap_zero() to zero a range (Eric Sandeen) [1838876 1854346 1838344]
- [fs] dax: Use new dax zero page method for zeroing a page (Eric Sandeen) [1838876 1854346 1838344]
- [md] dm,dax: Add dax zero_page_range operation (Eric Sandeen) [1838876 1854346 1838344]
- [s390] s390, dcssblk, dax: Add dax zero_page_range operation to dcssblk driver (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax, pmem: Add a dax operation zero_page_range (Eric Sandeen) [1838876 1854346 1838344]
- [nvdimm] pmem: Add functions for reading/writing page to/from pmem (Eric Sandeen) [1838876 1854346 1838344]
- [fs] fs: Constify vma argument to vma_is_dax (Eric Sandeen) [1838876 1854346 1838344]
- [fs] dax: pass NOWAIT flag to iomap_apply (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: Get rid of fs_dax_get_by_host() helper (Eric Sandeen) [1838876 1854346 1838344]
- [fs] dax: Pass dax_dev instead of bdev to dax_writeback_mapping_range() (Eric Sandeen) [1838876 1854346 1838344]
- [dax] dax: Fix alloc_dax_region() compile warning (Eric Sandeen) [1838876 1854346 1838344]
- [fs] xfs: disable map_sync for async flush (Eric Sandeen) [1838876 1854346 1838344]
- [fs] ext4: disable map_sync for async flush (Eric Sandeen) [1838876 1854346 1838344]
- [include] dax: check synchronous mapping is supported (Eric Sandeen) [1838876 1854346 1838344]
- [dax] libnvdimm: add dax_dev sync flag (Eric Sandeen) [1838876 1854346 1838344]
- [nvdimm] libnvdimm: nd_region flush callback support (Eric Sandeen) [1838876 1854346 1838344]
- [fs] vfs: only allow FSSETXATTR to set DAX flag on files and dirs (Eric Sandeen) [1838876 1854346 1838344]
- [fs] vfs: teach vfs_ioc_fssetxattr_check to check extent size hints (Eric Sandeen) [1838876 1854346 1838344]
- [fs] vfs: teach vfs_ioc_fssetxattr_check to check project id info (Eric Sandeen) [1838876 1854346 1838344]
- [fs] vfs: create a generic checking function for FS_IOC_FSSETXATTR (Eric Sandeen) [1838876 1854346 1838344]
- [fs] vfs: create a generic checking and prep function for FS_IOC_SETFLAGS (Eric Sandeen) [1838876 1854346 1838344]
- [dax] drivers/dax: Allow to include DEV_DAX_PMEM as builtin (Eric Sandeen) [1838876 1854346 1838344]
- [netdrv] net: intel: Remove in_interrupt() warnings (Corinna Vinschen) [1838746]
- [netdrv] igb: read PBA number from flash (Corinna Vinschen) [1838746]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Corinna Vinschen) [1838746]
- [netdrv] treewide: Use fallthrough pseudo-keyword (Corinna Vinschen) [1838746]
- [netdrv] igb: use eth_zero_addr() to clear mac address (Corinna Vinschen) [1838746]
- [netdrv] igb: Remove unnecessary usages of memset (Corinna Vinschen) [1838746]
- [netdrv] igb: reinit_locked() should be called with rtnl_lock (Corinna Vinschen) [1838746]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Corinna Vinschen) [1838746]
- [netdrv] net/intel: remove driver versions from Intel drivers (Corinna Vinschen) [1838746]
- [netdrv] igb: make igb_set_fc_watermarks() return void (Corinna Vinschen) [1838746]
- [netdrv] igb: Report speed and duplex as unknown when device is runtime suspended (Corinna Vinschen) [1838746]
- [netdrv] igb: convert to use i2c_new_client_device() (Corinna Vinschen) [1838746]
- [net] Bluetooth: Allow suspend even when preparation has failed (Gopal Tiwari) [1881485]
- [net] Bluetooth: Check scan state before disabling during suspend (Gopal Tiwari) [1881485]
- [fs] fuse: fix the ->direct_IO() treatment of iov_iter (Miklos Szeredi) [1875608]
- [net] openvswitch: handle DNAT tuple collision (Dumitru Ceara) [1877128]
- [net] xdp: Rename convert_to_xdp_frame in xdp_convert_buff_to_frame (Petr Oros) [1867194]

* Wed Nov 25 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-253.el8]
- [fs] NFSv4.2: fix failure to unregister shrinker (Scott Mayhew) [1897988]
- [tools] cpupower: Provide online and offline CPU information (Diego Domingos) [1893779]
- [net] net/smc: improve return codes for SMC-Dv2 (Claudio Imbrenda) [1731027]
- [s390] s390/ism: fix incorrect system EID (Claudio Imbrenda) [1731027]
- [net] net/smc: fix suppressed return code (Claudio Imbrenda) [1731027]
- [net] net/smc: fix null pointer dereference in smc_listen_decline() (Claudio Imbrenda) [1731027]
- [net] net/smc: fix invalid return code in smcd_new_buf_create() (Claudio Imbrenda) [1731027]
- [net] net/smc: fix valid DMBE buffer sizes (Claudio Imbrenda) [1731027]
- [net] net/smc: fix use-after-free of delayed events (Claudio Imbrenda) [1731027]
- [net] net/smc: restore smcd_version when all ISM V2 devices failed to init (Claudio Imbrenda) [1731027]
- [net] net/smc: cleanup buffer usage in smc_listen_work() (Claudio Imbrenda) [1731027]
- [net] net/smc: consolidate unlocking in same function (Claudio Imbrenda) [1731027]
- [net] net/smc: use an array to check fields in system EID (Claudio Imbrenda) [1731027]
- [net] net/smc: send ISM devices with unique chid in CLC proposal (Claudio Imbrenda) [1731027]
- [net] net/smc: CLC decline - V2 enhancements (Claudio Imbrenda) [1731027]
- [net] net/smc: introduce CLC first contact extension (Claudio Imbrenda) [1731027]
- [net] net/smc: CLC accept / confirm V2 (Claudio Imbrenda) [1731027]
- [net] net/smc: determine accepted ISM devices (Claudio Imbrenda) [1731027]
- [net] net/smc: build and send V2 CLC proposal (Claudio Imbrenda) [1731027]
- [net] net/smc: determine proposed ISM devices (Claudio Imbrenda) [1731027]
- [net] net/smc: introduce list of pnetids for Ethernet devices (Claudio Imbrenda) [1731027]
- [net] net/smc: introduce CHID callback for ISM devices (Claudio Imbrenda) [1731027]
- [net] net/smc: introduce System Enterprise ID (SEID) (Claudio Imbrenda) [1731027]
- [net] net/smc: prepare for more proposed ISM devices (Claudio Imbrenda) [1731027]
- [net] net/smc: split CLC confirm/accept data to be sent (Claudio Imbrenda) [1731027]
- [net] net/smc: separate find device functions (Claudio Imbrenda) [1731027]
- [net] net/smc: CLC header fields renaming (Claudio Imbrenda) [1731027]
- [net] net/smc: remove constant and introduce helper to check for a pnet id (Claudio Imbrenda) [1731027]
- [netdrv] vmxnet3: fix cksum offload issues for non-udp tunnels (Cathy Avery) [1868451]
- [netdrv] vmxnet3: use correct tcp hdr length when packet is encapsulated (Cathy Avery) [1868451]
- [scsi] scsi: vmw_pvscsi: Use true, false for adapter->use_msg (Cathy Avery) [1895014]
- [scsi] scsi: vmw_pvscsi: Silence dma mapping errors (Cathy Avery) [1895014]
- [scsi] scsi: vmw_pvscsi: Fix swiotlb operation (Cathy Avery) [1895014]
- [scsi] scsi: vmw_pscsi: use sg helper to iterate over scatterlist (Cathy Avery) [1895014]
- [scsi] Revert "vmw_pvscsi: Fixed to work with SG_CHAIN" (Cathy Avery) [1895014]
- [scsi] scsi: vmw_pscsi: switch to generic DMA API (Cathy Avery) [1895014]
- [netdrv] mdiobus: Disable preemption upon u64_stats update (Petr Oros) [1889849]
- [net] u64_stats: Document writer non-preemptibility requirement (Petr Oros) [1889849]
- [netdrv] phy: fixed_phy: Remove unused seqcount (Petr Oros) [1889849]
- [net] net/smc: fix double kfree in smc_listen_work() (Claudio Imbrenda) [1847444]
- [net] net/smc: check variable before dereferencing in smc_close.c (Claudio Imbrenda) [1847444]
- [net] net/smc: use separate work queues for different worker types (Claudio Imbrenda) [1847444]
- [net] net/smc: use the retry mechanism for netlink messages (Claudio Imbrenda) [1847444]
- [net] net/smc: immediate freeing in smc_lgr_cleanup_early() (Claudio Imbrenda) [1847444]
- [net] net/smc: reduce smc_listen_decline() calls (Claudio Imbrenda) [1847444]
- [net] net/smc: improve server ISM device determination (Claudio Imbrenda) [1847444]
- [net] net/smc: common routine for CLC accept and confirm (Claudio Imbrenda) [1847444]
- [net] net/smc: dynamic allocation of CLC proposal buffer (Claudio Imbrenda) [1847444]
- [net] net/smc: introduce better field names (Claudio Imbrenda) [1847444]
- [net] net/smc: reduce active tcp_listen workers (Claudio Imbrenda) [1847444]
- [net] net/smc: fix sock refcounting in case of termination (Claudio Imbrenda) [1847444]
- [net] net/smc: reset sndbuf_desc if freed (Claudio Imbrenda) [1847444]
- [net] net/smc: fix toleration of fake add_link messages (Claudio Imbrenda) [1847444]
- [net] net/smc: Prevent kernel-infoleak in __smc_diag_dump() (Claudio Imbrenda) [1847444]
- [s390] s390/ism: fix error return code in ism_probe() (Claudio Imbrenda) [1847444]
- [s390] s390/zcrypt: Introduce Failure Injection feature (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: move ap_msg param one level up the call chain (Philipp Rudo) [1851124]
- [s390] s390/ap/zcrypt: revisit ap and zcrypt error handling (Philipp Rudo) [1851124]
- [s390] s390/ap: Support AP card SCLP config and deconfig operations (Philipp Rudo) [1851124]
- [s390] s390/sclp: Add support for SCLP AP adapter config/deconfig (Philipp Rudo) [1851124]
- [s390] s390/ap: add card/queue deconfig state (Philipp Rudo) [1851124]
- [s390] s390/ap: add error response code field for ap queue devices (Philipp Rudo) [1851124]
- [s390] s390/ap: split ap queue state machine state from device state (Philipp Rudo) [1851124]
- [crypto] s390/zcrypt: New config switch CONFIG_ZCRYPT_DEBUG (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: introduce msg tracking in zcrypt functions (Philipp Rudo) [1851124]
- [s390] s390/ap: rework crypto config info and default domain code (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: provide cex4 cca sysfs attributes for cex3 (Philipp Rudo) [1851124]
- [s390] s390/ap: rename and clarify ap state machine related stuff (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: split ioctl function into smaller code units (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: code beautification and struct field renames (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: fix smatch warnings (Philipp Rudo) [1851124]
- [s390] s390/ap: introduce new ap function ap_get_qdev() (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: replace snprintf/sprintf with scnprintf (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: Use scnprintf() for avoiding potential buffer overflow (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: Support for CCA protected key block version 2 (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: fix card and queue total counter wrap (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: move ap device reset from bus to driver code (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: Fix CCA cipher key gen with clear key value function (Philipp Rudo) [1851124]
- [s390] s390/zcrypt: handle new reply code FILTERED_BY_HYPERVISOR (Philipp Rudo) [1851124]
- [fs] NFSv4: Wait for stateid updates after CLOSE/OPEN_DOWNGRADE (Benjamin Coddington) [1888612]
- [fs] NFSv4.x recover from pre-mature loss of openstateid (Benjamin Coddington) [1888612]
- [fs] NFSv4: Handle NFS4ERR_OLD_STATEID in CLOSE/OPEN_DOWNGRADE (Benjamin Coddington) [1888612]
- [hv] hv: vmbus: Add timeout to vmbus_wait_for_unload (Mohammed Gamal) [1888980]
- [net] sched: act_gate: Unlock ->tcfa_lock in tc_setup_flow_action() (Ivan Vecera) [1874071]
- [net] sched: act_ct: Fix adding udp port mangle operation (Ivan Vecera) [1874071]
- [net] sched: Fix suspicious RCU usage while accessing tcf_tunnel_info (Ivan Vecera) [1874071]
- [net] sched: get rid of qdisc->padded (Ivan Vecera) [1874071]
- [net] sched: check error pointer in tcf_dump_walker() (Ivan Vecera) [1874071]
- [net] sched: remove a redundant goto chain check (Ivan Vecera) [1874071]
- [net] sched: cls_u32: Replace one-element array with flexible-array member (Ivan Vecera) [1874071]
- [net] sched: commit action insertions together (Ivan Vecera) [1874071]
- [net] sched: defer tcf_idr_insert() in tcf_action_init_1() (Ivan Vecera) [1874071]
- [net] sched: Remove unused function qdisc_queue_drop_head() (Ivan Vecera) [1874071]
- [net] sched: taprio: Fix allowing too small intervals (Ivan Vecera) [1874071]
- [net] sched: sch_generic: aviod concurrent reset and enqueue op for lockless qdisc (Ivan Vecera) [1874071]
- [net] sched: skip an unnecessay check (Ivan Vecera) [1874071]
- [net] sched: act_ife: load meta modules before tcf_idr_check_alloc() (Ivan Vecera) [1874071]
- [net] sched: fix error path in red_init() (Ivan Vecera) [1874071]
- [net] sched: taprio: Fix using wrong queues in gate mask (Ivan Vecera) [1874071]
- [net] sched: Use fallthrough pseudo-keyword (Ivan Vecera) [1874071]
- [net] netlink: consistently use NLA_POLICY_EXACT_LEN() (Ivan Vecera) [1874071]
- [net] sched: act_ct: fix miss set mru for ovs after defrag in act_ct (Ivan Vecera) [1874071]
- [net] sched: cls_u32: Use struct_size() helper (Ivan Vecera) [1874071]
- [net] sched: act_pedit: Use flex_array_size() helper in memcpy() (Ivan Vecera) [1874071]
- [net] sched: initialize timer earlier in red_init() (Ivan Vecera) [1874071]
- [net] sched: cls_flower: Add hash info to flow classification (Ivan Vecera) [1874071]
- [net] flow_dissector: add packet hash dissection (Ivan Vecera) [1874071]
- [net] sched: sch_api: add missing rcu read lock to silence the warning (Ivan Vecera) [1874071]
- [tools] tc-testing: Add tdc to kselftests (Ivan Vecera) [1874071]
- [net] sched: Do not drop root lock in tcf_qevent_handle() (Ivan Vecera) [1874071]
- [net] sched: kerneldoc fixes (Ivan Vecera) [1874071]
- [net] sched: Pass qdisc reference in struct flow_block_offload (Ivan Vecera) [1874071]
- [net] sched: Use fallthrough pseudo-keyword (Ivan Vecera) [1874071]
- [net] sched: Allow changing default qdisc to FQ-PIE (Ivan Vecera) [1874071]
- [net] qos: police action offloading parameter 'burst' change to the original value (Ivan Vecera) [1874071]
- [tools] selftests: forwarding: Add a RED test for SW datapath (Ivan Vecera) [1874071]
- [net] sched: sch_red: Add qevents "early_drop" and "mark" (Ivan Vecera) [1874071]
- [net] sched: sch_red: Split init and change callbacks (Ivan Vecera) [1874071]
- [net] sched: Introduce helpers for qevent blocks (Ivan Vecera) [1874071]
- [net] sched: sch_cake: add RFC 8622 LE PHB support to CAKE diffserv handling (Ivan Vecera) [1874071]
- [net] qos: police action add index for tc flower offloading (Ivan Vecera) [1874071]
- [net] qos: add tc police offloading action with max frame size limit (Ivan Vecera) [1874071]
- [net] sched: tcindex_change: Remove redundant null check (Ivan Vecera) [1874071]
- [net] sched: Remove redundant skb null check (Ivan Vecera) [1874071]
- [net] sched: Remove redundant condition in qdisc_graft (Ivan Vecera) [1874071]
- [net] sched: cls_u32: Use struct_size() in kzalloc() (Ivan Vecera) [1874071]
- [net] sched: taprio: Use struct_size() in kzalloc() (Ivan Vecera) [1874071]
- [net] vlan: consolidate VLAN parsing code and limit max parsing depth (Ivan Vecera) [1874071]
- [net] flow_offload: Move rhashtable inclusion to the source file (Ivan Vecera) [1874071]
- [net] sched: act_ct: fix restore the qdisc_skb_cb after defrag (Ivan Vecera) [1874071]
- [net] sched: fix a memory leak in atm_tc_init() (Ivan Vecera) [1874071]
- [net] sched: act_ct: add miss tcf_lastuse_update. (Ivan Vecera) [1874071]
- [net] sched: consistently handle layer3 header accesses in the presence of VLANs (Ivan Vecera) [1874071]
- [net] tunnel: Propagate ECT(1) when decapsulating as recommended by RFC6040 (Ivan Vecera) [1874071]
- [net] sched: sch_cake: fix a few style nits (Ivan Vecera) [1874071]
- [net] sched: sch_cake: don't call diffserv parsing code when it is not needed (Ivan Vecera) [1874071]
- [net] sched: sch_cake: don't try to reallocate or unshare skb unconditionally (Ivan Vecera) [1874071]
- [tools] tc-testing: avoid action cookies with odd length. (Ivan Vecera) [1874071]
- [net] sched: Add MODULE_DESCRIPTION entries to network modules (Ivan Vecera) [1874071]
- [tools] tc-testing: update geneve options match in tunnel_key unit tests (Ivan Vecera) [1874071]
- [net] flow_offload: fix flow_indr_dev_unregister path (Ivan Vecera) [1874071]
- [net] flow_offload: use flow_indr_block_cb_alloc/remove function (Ivan Vecera) [1874071]
- [net] flow_offload: add flow_indr_block_cb_alloc/remove function (Ivan Vecera) [1874071]
- [net] sched: act_gate: fix configuration of the periodic timer (Ivan Vecera) [1874071]
- [net] sched: act_gate: fix NULL dereference in tcf_gate_init() (Ivan Vecera) [1874071]
- [net] flow_offload: remove indirect flow_block declarations leftover (Ivan Vecera) [1874071]
- [net] sched: export __netdev_watchdog_up() (Ivan Vecera) [1874071]
- [net] sched: act_ct: add nat mangle action only for NAT-conntrack (Ivan Vecera) [1874071]
- [net] sched: sch_cake: Take advantage of skb->hash where appropriate (Ivan Vecera) [1874071]
- [net] sched: fix a couple of splats in the error path of tfc_gate_init() (Ivan Vecera) [1874071]
- [net] sched: get rid of unnecessary dev_qdisc_reset() (Ivan Vecera) [1874071]
- [net] sched: avoid resetting active qdisc for multiple times (Ivan Vecera) [1874071]
- [net] sched: add a tracepoint for qdisc creation (Ivan Vecera) [1874071]
- [net] sched: add tracepoints for qdisc_reset() and qdisc_destroy() (Ivan Vecera) [1874071]
- [net] sched: use qdisc_reset() in qdisc_destroy() (Ivan Vecera) [1874071]
- [net] sched: fix infinite loop in sch_fq_pie (Ivan Vecera) [1874071]
- [net] sched: fix reporting the first-time use timestamp (Ivan Vecera) [1874071]
- [net] tracing: Fix header include guards in trace event headers (Ivan Vecera) [1874071]
- [netdrv] ipvlan: fix device features (Davide Caratti) [1892621]
- [netdrv] ipvlan: consolidate TSO flags using NETIF_F_ALL_TSO (Davide Caratti) [1892621]
- [netdrv] ipvlan: set hw_enc_features like macvlan (Davide Caratti) [1892621]
- [tools] ACPI: Use valid link to the ACPI specification (David Arcari) [1857138]
- [tools] cpupower: Replace HTTP links with HTTPS ones (David Arcari) [1857138]
- [tools] cpupower: Fix NULL but dereferenced coccicheck errors (David Arcari) [1857138]
- [tools] cpupower: Fix comparing pointer to 0 coccicheck warns (David Arcari) [1857138]
- [tools] cpupower: Remove unneeded semicolon (David Arcari) [1857138]
- [tools] cpupower: .gitignore: add SPDX License Identifier (David Arcari) [1857138]
- [tools] cpupower: avoid multiple definition with gcc -fno-common (David Arcari) [1857138]
- [tools] cpupower: Revert library ABI changes from commit ae2917093fb60bdc1ed3e (David Arcari) [1857138]
- [tools] cpupower: ToDo: Update ToDo with ideas for per_cpu_schedule handling (David Arcari) [1857138]
- [tools] tools/power/cpupower: Fix initializer override in hsw_ext_cstates (David Arcari) [1857138]
- [tools] cpupower: update German translation (David Arcari) [1857138]
- [tools] tools/power/cpupower: fix 64bit detection when cross-compiling (David Arcari) [1857138]
- [tools] cpupower: Add missing newline at end of file (David Arcari) [1857138]
- [tools] cpupower: Replace GPLv2 boilerplate/reference with SPDX - rule 285 (David Arcari) [1857138]
- [tools] cpupower: correct spelling of interval (David Arcari) [1857138]
- [tools] cpupower: Replace GPLv2 boilerplate/reference with SPDX - rule 167 (David Arcari) [1857138]
- [tools] cpupower: Replace GPLv2 boilerplate/reference with SPDX - rule 166 (David Arcari) [1857138]
- [tools] cpupower: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (David Arcari) [1857138]
- [tools] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 155 (David Arcari) [1857138]
- [tools] cpupower: Add SPDX license identifier for more missed files (David Arcari) [1857138]
- [tools] tools/power/cpupower: Display boost frequency separately (David Arcari) [1857138]
- [tools] cpupower : Auto-completion for cpupower tool (David Arcari) [1857138]
- [tools] tools/power/cpupower: fix compilation with STATIC=true (David Arcari) [1857138]
- [tools] cpupower: remove stringop-truncation waring (David Arcari) [1857138]
- [tools] cpupower: convert ISO_8859-1 text comments to utf-8 (David Arcari) [1857138]
- [x86] x86/resctrl: Support wider MBM counters (Puneet Sethi) [1834658]
- [x86] x86/resctrl: Support CPUID enumeration of MBM counter width (Puneet Sethi) [1834658]
- [x86] x86/resctrl: Maintain MBM counter width per resource (Puneet Sethi) [1834658]
- [x86] x86/resctrl: Query LLC monitoring properties once during boot (Puneet Sethi) [1834658]
- [x86] x86/resctrl: Remove unnecessary RMID checks (Puneet Sethi) [1834658]
- [x86] x86/cpu: Move resctrl CPUID code to resctrl/ (Puneet Sethi) [1834658]
- [x86] x86/resctrl: Rename asm/resctrl_sched.h to asm/resctrl.h (Puneet Sethi) [1834658]
- [x86] x86/resctrl: Preserve CDP enable over CPU hotplug (Puneet Sethi) [1834658]
- [net] af_packet: TPACKET_V3: fix fill status rwlock imbalance (Ivan Vecera) [1889829]
- [net] packet: tpacket_rcv: do not increment ring index on drop (Ivan Vecera) [1889829]
- [net] af_packet: TPACKET_V3: replace busy-wait loop (Ivan Vecera) [1889829]
- [net] SUNRPC: Fix svc_flush_dcache() (Scott Mayhew) [1888214]
- [fs] pNFS/flexfiles: Be consistent about mirror index types (Scott Mayhew) [1888214]
- [fs] pNFS/flexfiles: Ensure we initialise the mirror bsizes correctly on read (Scott Mayhew) [1888214]
- [fs] NFSv4.2: fix client's attribute cache management for copy_file_range (Scott Mayhew) [1888214]
- [fs] nfs: Fix security label length not being reset (Scott Mayhew) [1888214]
- [net] SUNRPC: stop printk reading past end of string (Scott Mayhew) [1888214]
- [fs] NFS: Zero-stateid SETATTR should first return delegation (Scott Mayhew) [1888214]
- [fs] NFSv4.1 handle ERR_DELAY error reclaiming locking state on delegation recall (Scott Mayhew) [1888214]
- [net] SUNRPC: remove duplicate include (Scott Mayhew) [1888214]
- [fs] nfsd: fix oops on mixed NFSv4/NFSv3 client access (Scott Mayhew) [1888214]
- [fs] NFS: Fix flexfiles read failover (Scott Mayhew) [1888214]
- [fs] fs: nfs: delete repeated words in comments (Scott Mayhew) [1888214]
- [fs] rpc_pipefs: convert comma to semicolon (Scott Mayhew) [1888214]
- [fs] NFS: Don't return layout segments that are in use (Scott Mayhew) [1888214]
- [fs] NFS: Don't move layouts to plh_return_segs list while in use (Scott Mayhew) [1888214]
- [fs] NFS: Add layout segment info to pnfs read/write/commit tracepoints (Scott Mayhew) [1888214]
- [fs] NFS: Add tracepoints for layouterror and layoutstats (Scott Mayhew) [1888214]
- [fs] NFS: Report the stateid + status in trace_nfs4_layoutreturn_on_close() (Scott Mayhew) [1888214]
- [fs] NFSv4.2: xattr cache: get rid of cache discard work queue (Scott Mayhew) [1888214]
- [fs] NFS: remove redundant initialization of variable result (Scott Mayhew) [1888214]
- [net] svcrdma: CM event handler clean up (Scott Mayhew) [1888214]
- [net] svcrdma: Remove transport reference counting (Scott Mayhew) [1888214]
- [net] svcrdma: Fix another Receive buffer leak (Scott Mayhew) [1888214]
- [trace] SUNRPC: Refresh the show_rqstp_flags() macro (Scott Mayhew) [1888214]
- [fs] nfsd: netns.h: delete a duplicated word (Scott Mayhew) [1888214]
- [net] sunrpc: destroy rpc_inode_cachep after unregister_filesystem (Scott Mayhew) [1888214]
- [fs] freezer: Add unsafe version of freezable_schedule_timeout_interruptible() for NFS (Scott Mayhew) [1888214]
- [fs] NFSv4.2: add client side xattr caching (Scott Mayhew) [1888214]
- [fs] NFSv4.2: hook in the user extended attribute handlers (Scott Mayhew) [1888214]
- [fs] NFSv4.2: add the extended attribute proc functions (Scott Mayhew) [1888214]
- [fs] nfs: make the buf_to_pages_noslab function available to the nfs code (Scott Mayhew) [1888214]
- [fs] nfs: define and use the NFS_INO_INVALID_XATTR flag (Scott Mayhew) [1888214]
- [fs] NFS: Update symbolic flags displayed by trace events (Scott Mayhew) [1888214]
- [fs] nfs: modify update_changeattr to deal with regular files (Scott Mayhew) [1888214]
- [fs] NFSv4.2: query the extended attribute access bits (Scott Mayhew) [1888214]
- [fs] nfs: define nfs_access_get_cached function (Scott Mayhew) [1888214]
- [fs] NFSv4.2: add client side XDR handling for extended attributes (Scott Mayhew) [1888214]
- [fs] NFSv4.2: query the server for extended attribute support (Scott Mayhew) [1888214]
- [fs] NFSv4.2: define limits and sizes for user xattr handling (Scott Mayhew) [1888214]
- [include] nfs: add client side only definitions for user xattrs (Scott Mayhew) [1888214]
- [fs] nfsd: Use seq_putc() in two functions (Scott Mayhew) [1888214]
- [net] svcrdma: Display chunk completion ID when posting a rw_ctxt (Scott Mayhew) [1888214]
- [net] svcrdma: Record send_ctxt completion ID in trace_svcrdma_post_send() (Scott Mayhew) [1888214]
- [net] svcrdma: Introduce Send completion IDs (Scott Mayhew) [1888214]
- [net] svcrdma: Record Receive completion ID in svc_rdma_decode_rqst (Scott Mayhew) [1888214]
- [net] svcrdma: Introduce Receive completion IDs (Scott Mayhew) [1888214]
- [trace] svcrdma: Introduce infrastructure to support completion IDs (Scott Mayhew) [1888214]
- [net] svcrdma: Add common XDR encoders for RDMA and Read segments (Scott Mayhew) [1888214]
- [net] svcrdma: Add common XDR decoders for RDMA and Read segments (Scott Mayhew) [1888214]
- [net] SUNRPC: Add helpers for decoding list discriminators symbolically (Scott Mayhew) [1888214]
- [include] svcrdma: Remove declarations for functions long removed (Scott Mayhew) [1888214]
- [net] svcrdma: Clean up trace_svcrdma_send_failed() tracepoint (Scott Mayhew) [1888214]
- [net] svcrdma: Consolidate send_error helper functions (Scott Mayhew) [1888214]
- [net] svcrdma: Make svc_rdma_send_error_msg() a global function (Scott Mayhew) [1888214]
- [net] svcrdma: Eliminate return value for svc_rdma_send_error_msg() (Scott Mayhew) [1888214]
- [net] svcrdma: Add a @status parameter to svc_rdma_send_error_msg() (Scott Mayhew) [1888214]
- [net] svcrdma: Add @rctxt parameter to svc_rdma_send_error() functions (Scott Mayhew) [1888214]
- [net] svcrdma: Remove save_io_pages() call from send_error_msg() (Scott Mayhew) [1888214]
- [net] svcrdma: Fix page leak in svc_rdma_recv_read_chunk() (Scott Mayhew) [1888214]
- [net] SUNRPC: Augment server-side rpcgss tracepoints (Scott Mayhew) [1888214]
- [fs] nfsd: add fattr support for user extended attributes (Scott Mayhew) [1888214]
- [fs] nfsd: implement the xattr functions and en/decode logic (Scott Mayhew) [1888214]
- [fs] nfsd: add structure definitions for xattr requests / responses (Scott Mayhew) [1888214]
- [fs] nfsd: take xattr bits into account for permission checks (Scott Mayhew) [1888214]
- [fs] nfsd: define xattr functions to call into their vfs counterparts (Scott Mayhew) [1888214]
- [fs] nfsd: add defines for NFSv4.2 extended attribute support (Scott Mayhew) [1888214]
- [fs] nfsd: split off the write decode code into a separate function (Scott Mayhew) [1888214]
- [fs] xattr: add a function to check if a namespace is supported (Scott Mayhew) [1888214]
- [fs] xattr: break delegations in {set, remove}xattr (Scott Mayhew) [1888214]
- [uapi] nfs, nfsd: NFSv4.2 extended attribute protocol definitions (Scott Mayhew) [1888214]
- [fs] pNFS/flexfiles: The mirror count could depend on the layout segment range (Scott Mayhew) [1888214]
- [fs] pNFS/flexfiles: Clean up redundant calls to pnfs_put_lseg() (Scott Mayhew) [1888214]
- [fs] NFS: Allow applications to speed up readdir+statx() using AT_STATX_DONT_SYNC (Scott Mayhew) [1888214]
- [include] NFS: Replace zero-length array with flexible-array (Scott Mayhew) [1888214]
- [include] nfs4: Remove unneeded semicolon (Scott Mayhew) [1888214]
- [tools] selftests/livepatch: adopt to newer sysctl error format (Yannick Cote) [1869880]
- [tools] selftests/livepatch: Use "comm" instead of "diff" for dmesg (Yannick Cote) [1869880]
- [tools] selftests/livepatch: add test delimiter to dmesg (Yannick Cote) [1869880]
- [tools] selftests/livepatch: refine dmesg 'taints' in dmesg comparison (Yannick Cote) [1869880]
- [tools] selftests/livepatch: Don't clear dmesg when running tests (Yannick Cote) [1869880]
- [lib] selftests/livepatch: fix mem leaks in test-klp-shadow-vars (Yannick Cote) [1869880]
- [lib] selftests/livepatch: more verification in test-klp-shadow-vars (Yannick Cote) [1869880]
- [lib] selftests/livepatch: rework test-klp-shadow-vars (Yannick Cote) [1869880]
- [lib] selftests/livepatch: simplify test-klp-callbacks busy target tests (Yannick Cote) [1869880]
- [tools] selftests: Install settings files to fix TIMEOUT failures (Yannick Cote) [1869880]
- [cpufreq] cpufreq: intel_pstate: Fix intel_pstate_get_hwp_max() for turbo disabled (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Free memory only when turning off (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Add ->offline and ->online callbacks (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Tweak the EPP sysfs interface (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Update cached EPP in the active mode (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Refuse to turn off with HWP enabled (Puneet Sethi) [1881199]
- [documentation] Documentation: fix pm/intel_pstate build warning and wording (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Implement passive mode with HWP enabled (Puneet Sethi) [1881199]
- [tools] tools arch x86: Sync the msr-index.h copy with the kernel sources (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Fix cpuinfo_max_freq when MSR_TURBO_RATIO_LIMIT is 0 (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Fix EPP setting via sysfs in active mode (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Rearrange the storing of new EPP values (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Avoid enabling HWP if EPP is not supported (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Clean up aperf_mperf_shift description (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Supply struct attribute description for get_aperf_mperf_shift() (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Fix static checker warning for epp variable (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Allow raw energy performance preference value (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Allow enable/disable energy efficiency (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Add one more OOB control bit (Puneet Sethi) [1881199]
- [cpufreq] cpufreq: intel_pstate: Only mention the BIOS disabling turbo mode once (Puneet Sethi) [1881199]
- [documentation] Documentation: intel_pstate: update links for references (Puneet Sethi) [1881199]
- [documentation] Documentation: PM: Unify copyright notices (Puneet Sethi) [1881199]
- [documentation] Documentation: PM: Add SPDX license tags to multiple files (Puneet Sethi) [1881199]
- [documentation] cpufreq: intel_pstate: Documentation: Add references sections (Puneet Sethi) [1881199]
- [documentation] Documentation: intel_pstate: Clarify coordination of P-State limits (Puneet Sethi) [1881199]
- [documentation] Documentation: intel_pstate: Add base_frequency information (Puneet Sethi) [1881199]
- [i2c] i2c: ismt: Remove call to memset after dmam_alloc_coherent (Tony Camuso) [1875395]
- [i2c] i2c: ismt: Add support for Intel Cedar Fork (Tony Camuso) [1875395]
- [documentation] docs: net: fm10k: add documentation for fm10k driver (Vladis Dronov) [1838728]
- [netdrv] net: fm10k: reject unsupported coalescing params (Vladis Dronov) [1838728]
- [netdrv] intel: Replace zero-length array with flexible-array member (Vladis Dronov) [1838728]
- [netdrv] net: Use skb accessors in network drivers (Vladis Dronov) [1838728]
- [netdrv] hdlc_ppp: add range checks in ppp_cp_parse_cr() (Guillaume Nault) [1882082] {CVE-2020-25643}

* Sat Nov 21 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-252.el8]
- [pinctrl] pinctrl: sunrisepoint: Modify COMMUNITY macros to be consistent (David Arcari) [1783488]
- [pinctrl] pinctrl: cannonlake: Modify COMMUNITY macros to be consistent (David Arcari) [1783488]
- [pinctrl] pinctrl: tigerlake: Fix register offsets for TGL-H variant (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Update header block to reflect direct dependencies (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Switch to use intel_pinctrl_get_soc_data() (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Extract intel_pinctrl_get_soc_data() helper for wider use (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Use fallthrough pseudo-keyword (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Fix pin being driven low for a while on gpiod_get(..., GPIOD_OUT_HIGH) (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Drop no-op ACPI_PTR() call (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Make use of for_each_requested_gpio_in_range() (David Arcari) [1783488]
- [include] gpiolib: Introduce for_each_requested_gpio_in_range() macro (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Protect IO in few call backs by lock (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Split intel_config_get() to three functions (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Drop the only label in the code for consistency (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Get rid of redundant 'else' in intel_config_set_debounce() (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Make use of IRQ_RETVAL() (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Reduce scope of the lock (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Disable input and output buffer when switching to GPIO (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Allow drivers to define ACPI address space ID (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Allow drivers to define total amount of IRQs per community (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Move npins closer to pin_base in struct intel_community (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Update description in struct intel_community (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Use platform_get_irq_optional() explicitly (David Arcari) [1783488]
- [pinctrl] pinctrl: intel: Introduce new flag to force GPIO base to be 0 (David Arcari) [1783488]
- [pinctrl] pinctrl: tigerlake: Use generic flag for special GPIO base treatment (David Arcari) [1783488]
- [pinctrl] pinctrl: icelake: Use generic flag for special GPIO base treatment (David Arcari) [1783488]
- [pinctrl] pinctrl: cannonlake: Use generic flag for special GPIO base treatment (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Enable pin configuration setting for GPIO chip (David Arcari) [1783488]
- [pinctrl] pinctrl: sunrisepoint: Fix PAD lock register offset for SPT-H (David Arcari) [1783488]
- [pinctrl] pinctrl: baytrail: Mark expected switch fall-throughs (David Arcari) [1783488]
- [kernel] mm: disable proactive compaction by default (Rafael Aquini) [1848427]
- [mm] mm: use unsigned types for fragmentation score (Rafael Aquini) [1848427]
- [mm] mm: fix compile error due to COMPACTION_HPAGE_ORDER (Rafael Aquini) [1848427]
- [mm] mm: proactive compaction (Rafael Aquini) [1848427]
- [i2c] i2c: mlxbf: I2C_MLXBF should depend on MELLANOX_PLATFORM (Alaa Hleihel) [1655741 1655709]
- [i2c] i2c: mlxbf: Update author and maintainer email info (Alaa Hleihel) [1655741 1655709]
- [i2c] i2c: mlxbf: Update reference clock frequency (Alaa Hleihel) [1655741 1655709]
- [i2c] i2c: mlxbf: Remove unecessary wrapper functions (Alaa Hleihel) [1655741 1655709]
- [i2c] i2c: mlxbf: Fix resrticted cast warning of sparse (Alaa Hleihel) [1655741 1655709]
- [i2c] i2c: mlxbf: Add CONFIG_ACPI to guard ACPI function call (Alaa Hleihel) [1655741 1655709]
- [documentation] dt-bindings: i2c: I2C binding for Mellanox BlueField SoC (Alaa Hleihel) [1655741 1655709]
- [i2c] i2c: mlxbf: I2C SMBus driver for Mellanox BlueField SoC (Alaa Hleihel) [1655741 1655709]
- [misc] misc: eeprom: ee1004: convert to i2c_new_dummy_device (Alaa Hleihel) [1655741]
- [misc] eeprom: ee1004: Deal with nack on page selection (Alaa Hleihel) [1655741]
- [misc] eeprom: ee1004: Move selected page detection to a separate function (Alaa Hleihel) [1655741]
- [misc] eeprom: New ee1004 driver for DDR4 memory (Alaa Hleihel) [1655741]
- [net] xfrm: Use correct address family in xfrm_state_find (Xin Long) [1892641]
- [net] xfrm: clone whole liftime_cur structure in xfrm_do_migrate (Xin Long) [1892641]
- [net] xfrm: clone XFRMA_SEC_CTX in xfrm_do_migrate (Xin Long) [1892641]
- [net] xfrm: clone XFRMA_REPLAY_ESN_VAL in xfrm_do_migrate (Xin Long) [1892641]
- [net] xfrm: clone XFRMA_SET_MARK in xfrm_do_migrate (Xin Long) [1892641]
- [net] ip_vti: Fix unused variable warning (Xin Long) [1892641]
- [net] xfrm: Make the policy hold queue work with VTI. (Xin Long) [1892641]
- [s390] s390/qeth: delay draining the TX buffers (Philipp Rudo) [1847443]
- [s390] s390/qeth: strictly order bridge address events (Philipp Rudo) [1847443]
- [s390] s390/qeth: unify structs for bridge port state (Philipp Rudo) [1847443]
- [s390] s390/qeth: copy less data from bridge state events (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't let HW override the configured port role (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't disable address events during initialization (Philipp Rudo) [1847443]
- [s390] s390/qeth: make queue lock a proper spinlock (Philipp Rudo) [1847443]
- [s390] s390/qeth: use to_delayed_work() (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up qeth_l3_send_setdelmc()'s declaration (Philipp Rudo) [1847443]
- [s390] s390/qeth: use all configured RX buffers (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't process empty bridge port events (Philipp Rudo) [1847443]
- [s390] s390/qeth: integrate RX refill worker with NAPI (Philipp Rudo) [1847443]
- [s390] s390/qeth: tolerate pre-filled RX buffer (Philipp Rudo) [1847443]
- [s390] s390/qdio: remove internal polling in non-thinint path (Philipp Rudo) [1847443]
- [s390] s390/qdio: allow to scan all 128 Input SBALs (Philipp Rudo) [1847443]
- [s390] s390/qdio: fix statistics for 128 SBALs (Philipp Rudo) [1847443]
- [s390] s390/qeth: constify the MPC initialization data (Philipp Rudo) [1847443]
- [s390] s390/qeth: unify RX-mode hashtables (Philipp Rudo) [1847443]
- [s390] s390/qeth: cleanup OAT code (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up a magic number in the OAT callback (Philipp Rudo) [1847443]
- [s390] s390/qeth: use u64_to_user_ptr() in the OAT code (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up error handling for isolation mode cmds (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't clear the configured isolation mode (Philipp Rudo) [1847443]
- [s390] s390/qeth: only init the isolation mode when necessary (Philipp Rudo) [1847443]
- [s390] s390/qeth: fine-tune errno when cmds are cancelled (Philipp Rudo) [1847443]
- [s390] s390/qeth: reject unsupported link type earlier (Philipp Rudo) [1847443]
- [s390] s390/qeth: let isolation mode override HW offload restrictions (Philipp Rudo) [1847443]
- [s390] s390/qeth: fix error handling for isolation mode cmds (Philipp Rudo) [1847443]
- [s390] s390/qdio: warn about unexpected SLSB states (Philipp Rudo) [1847443]
- [s390] s390/qdio: clean up usage of qdio_data (Philipp Rudo) [1847443]
- [s390] s390/qdio: reduce SLSB writes during Input Queue processing (Philipp Rudo) [1847443]
- [s390] s390/qdio: fine-tune SLSB update (Philipp Rudo) [1847443]
- [s390] s390/cio, s390/qeth: cleanup PNSO CHSC (Philipp Rudo) [1847443]
- [s390] s390/qdio: remove q->first_to_kick (Philipp Rudo) [1847443]
- [s390] s390/qdio: fix up qdio_start_irq() kerneldoc (Philipp Rudo) [1847443]
- [s390] s390/qdio: add IRQ reduction for error SBALs (Philipp Rudo) [1847443]
- [s390] s390/qdio: refactor ACK processing for primed SBALs (Philipp Rudo) [1847443]
- [s390] s390/qdio: simplify overlap calculation on Input refill (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up Kconfig help text (Philipp Rudo) [1847443]
- [s390] s390/qeth: return error when starting a reset fails (Philipp Rudo) [1847443]
- [s390] s390/qeth: set TX IRQ marker on last buffer in a group (Philipp Rudo) [1847443]
- [s390] s390/qeth: indicate contiguous TX buffer elements (Philipp Rudo) [1847443]
- [s390] s390/qeth: merge TX skb mapping code (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't use restricted offloads for local traffic (Philipp Rudo) [1847443]
- [s390] s390/qeth: extract helpers for next-hop lookup (Philipp Rudo) [1847443]
- [s390] s390/qeth: add debugfs file for local IP addresses (Philipp Rudo) [1847443]
- [s390] s390/qeth: process local address events (Philipp Rudo) [1847443]
- [s390] s390/qeth: keep track of LP2LP capability for csum offload (Philipp Rudo) [1847443]
- [s390] s390/qeth: fix cancelling of TX timer on dev_close() (Philipp Rudo) [1847443]
- [s390] s390/qdio: remove always-true condition (Philipp Rudo) [1847443]
- [s390] s390/qdio: de-duplicate tiqdio_inbound_processing() (Philipp Rudo) [1847443]
- [s390] s390/qdio: keep track of allocated queue count (Philipp Rudo) [1847443]
- [s390] s390/qdio: roll-back after queue allocation error (Philipp Rudo) [1847443]
- [s390] s390/qdio: do more fine-grained allocation roll-back (Philipp Rudo) [1847443]
- [s390] s390/qdio: consolidate thinint init/exit (Philipp Rudo) [1847443]
- [s390] s390/qdio: put thinint indicator after early error (Philipp Rudo) [1847443]
- [s390] s390/qdio: tear down thinint indicator after early error (Philipp Rudo) [1847443]
- [s390] s390/qdio: consistently restore the IRQ handler (Philipp Rudo) [1847443]
- [s390] s390/qdio: clear DSCI early for polling drivers (Philipp Rudo) [1847443]
- [s390] s390/qdio: inline shared_ind() (Philipp Rudo) [1847443]
- [s390] s390/qdio: remove cdev from init_data (Philipp Rudo) [1847443]
- [s390] s390/qdio: allow for non-contiguous SBAL array in init_data (Philipp Rudo) [1847443]
- [s390] zfcp: inline zfcp_qdio_setup_init_data() (Philipp Rudo) [1847443]
- [s390] s390/qdio: cleanly split alloc and establish (Philipp Rudo) [1847443]
- [s390] s390/qeth: phase out OSN support (Philipp Rudo) [1847443]
- [s390] s390/qeth: make OSN / OSX support configurable (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove fake_broadcast attribute (Philipp Rudo) [1847443]
- [s390] s390/qdio: set qdio_irq->cdev at allocation time (Philipp Rudo) [1847443]
- [s390] s390/qdio: remove unused function declarations (Philipp Rudo) [1847443]
- [s390] s390/qeth: modernize two list helpers (Philipp Rudo) [1847443]
- [s390] s390/qeth: keep track of fixed prio-queue configuration (Philipp Rudo) [1847443]
- [s390] s390/qeth: fine-tune MAC Address-related errnos (Philipp Rudo) [1847443]
- [s390] s390/qeth: add TX IRQ coalescing support for IQD devices (Philipp Rudo) [1847443]
- [s390] s390/qeth: collect more TX statistics (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up the mac_bits (Philipp Rudo) [1847443]
- [s390] s390/qeth: simplify L3 dev_id logic (Philipp Rudo) [1847443]
- [s390] s390/qdio: extend polling support to multiple queues (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove redundant if-clause in RX poll code (Philipp Rudo) [1847443]
- [s390] s390/qeth: split out RX poll code (Philipp Rudo) [1847443]
- [s390] s390/qeth: simplify RX buffer tracking (Philipp Rudo) [1847443]
- [s390] s390/qdio: pass ISC as parameter to chsc_sadc() (Philipp Rudo) [1847443]
- [s390] s390/qeth: use dev->reg_state (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove gratuitous NULL checks (Philipp Rudo) [1847443]
- [s390] s390/qeth: add phys_to_virt() translation for AOB (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't report hard-coded driver version (Philipp Rudo) [1847443]
- [s390] s390/qeth: add SW timestamping support for IQD devices (Philipp Rudo) [1847443]
- [s390] s390/qeth: balance the TX queue selection for IQD devices (Philipp Rudo) [1847443]
- [s390] s390/qeth: allow configuration of TX queues for IQD devices (Philipp Rudo) [1847443]
- [s390] s390/qeth: allow configuration of TX queues for z/VM NICs (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove prio-queueing support for z/VM NICs (Philipp Rudo) [1847443]
- [s390] s390/qeth: use memory reserves in TX slow path (Philipp Rudo) [1847443]
- [s390] s390/qeth: use memory reserves to back RX buffers (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove VNICC callback parameter struct (Philipp Rudo) [1847443]
- [s390] s390/qdio: add tighter controls for IRQ polling (Philipp Rudo) [1847443]
- [s390] s390/qdio: export SSQD via debugfs (Philipp Rudo) [1847443]
- [s390] s390/qeth: support configurable RX copybreak (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't check for IFF_UP when scheduling napi (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't re-start read cmd when IDX has terminated (Philipp Rudo) [1847443]
- [s390] s390/qeth: reset seqnos on connection startup (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove unused cmd definitions (Philipp Rudo) [1847443]
- [s390] s390/qeth: validate device-provided MAC address (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up CREATE_ADDR cmd code (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove dead code in qeth_l3_iqd_read_initial_mac() (Philipp Rudo) [1847443]
- [s390] s390/qdio: simplify debugfs code (Philipp Rudo) [1847443]
- [s390] s390/qdio: use QDIO_IRQ_STATE_INACTIVE instead of 0 (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't warn for napi with 0 budget (Philipp Rudo) [1847443]
- [s390] s390/qdio: reduce access to cdev->private->qdio_data (Philipp Rudo) [1847443]
- [s390] s390/qdio: clean up cdev access in qdio_setup_irq() (Philipp Rudo) [1847443]
- [s390] s390/qdio: fill SL with absolute addresses (Philipp Rudo) [1847443]
- [s390] s390/qdio: don't allocate *aob array with GFP_ATOMIC (Philipp Rudo) [1847443]
- [s390] s390/qdio: simplify ACK tracking (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove HARDSETUP state (Philipp Rudo) [1847443]
- [s390] s390/qeth: make cmd/reply matching more flexible (Philipp Rudo) [1847443]
- [s390] s390/qeth: consolidate online/offline code (Philipp Rudo) [1847443]
- [s390] s390/qeth: shift some bridgeport code around (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove QETH_RX_PULL_LEN (Philipp Rudo) [1847443]
- [s390] s390/qeth: use napi_gro_frags() for SG skbs (Philipp Rudo) [1847443]
- [s390] s390/qeth: consolidate RX code (Philipp Rudo) [1847443]
- [s390] s390/qeth: make use of napi_schedule_irqoff() (Philipp Rudo) [1847443]
- [s390] s390/qeth: consolidate helpers for capability checking (Philipp Rudo) [1847443]
- [s390] s390/qeth: stop yielding the ip_lock during IPv4 registration (Philipp Rudo) [1847443]
- [s390] s390/qeth: don't raise NETDEV_REBOOT event from L3 offline path (Philipp Rudo) [1847443]
- [s390] s390/qeth: remove open-coded inet_make_mask() (Philipp Rudo) [1847443]
- [s390] s390/qeth: clean up L3 sysfs code (Philipp Rudo) [1847443]
- [s390] s390/qeth: overhaul L3 IP address dump code (Philipp Rudo) [1847443]
- [s390] s390/qeth: wake up all waiters from qeth_irq() (Philipp Rudo) [1847443]
- [s390] s390/qeth: only handle IRQs while device is online (Philipp Rudo) [1847443]
- [s390] s390: clean up qdio.h (Philipp Rudo) [1847443]
- [s390] s390/cio: fix kdoc for tiqdio_thinint_handler (Philipp Rudo) [1847443]
- [s390] s390/drivers: fix proc/debugfs file permissions (Philipp Rudo) [1847443]
- [s390] s390: convert to DEFINE_SHOW_ATTRIBUTE (Philipp Rudo) [1847443]
- [s390] scsi: zfcp: Avoid benign overflow of the Request Queue's free-level (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: Replace open-coded list move (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: Clean up zfcp_erp_action_ready() (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: Fix an outdated comment for zfcp_qdio_send() (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: Use prandom_u32_max() for backoff (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: fix wrong data and display format of SFP+ temperature (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: trace channel log even for FCP command responses (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: proper indentation to reduce confusion in zfcp_erp_required_act (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: move maximum age of diagnostic buffers into a per-adapter variable (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: implicitly refresh config-data diagnostics when reading sysfs (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: introduce sysfs interface to read the local B2B-Credit (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: implicitly refresh port-data diagnostics when reading sysfs (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: introduce sysfs interface for diagnostics of local SFP transceiver (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: support retrieval of SFP Data via Exchange Port Data (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: fix GCC compiler warning emitted with -Wmaybe-uninitialized (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: fix request object use-after-free in send path causing seqno errors (Philipp Rudo) [1874100]
- [s390] scsi: s390: zfcp_fc: use sg helper to iterate over scatterlist (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: reduce flood of fcrscn1 trace records on multi-element RSCN (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: improve kdoc for return of zfcp_status_read_refill() (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: drop old default switch case which might paper over missing case (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: drop default switch case which might paper over missing case (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: silence -Wimplicit-fallthrough in zfcp_erp_lun_strategy() (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: silence remaining kdoc warnings in header files (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: silence all W=1 build warnings for existing kdoc (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: properly format LUN (and WWPN) for LUN sharing violation kmsg (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: use enum zfcp_erp_act_result for argument/return of affected functions (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: use enum zfcp_erp_steps for struct zfcp_erp_action.step (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: the action field of zfcp_erp_action is actually the type (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: clarify function argument name for trace tag string (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: ERP thread setup kdoc update (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: update kernel message for invalid FCP_CMND length, it's not the CDB (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: drop duplicate seq_no from zfcp_fsf_req which is also in QTCB header (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: drop duplicate fsf_command from zfcp_fsf_req which is also in QTCB header (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: drop unnecessary forward prototype for struct zfcp_fsf_req (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: group sort internal structure definitions for proximity (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: namespace prefix for internal latency data structures (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: update width in comment for ZFCP_COMMON_FLAGS mask (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: move scsi_eh & non-ERP timeout defines owned by and local to zfcp_fsf.c (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: drop unnecessary forward prototype for struct zfcp_reqlist (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: move SG table helper from aux to fc and make them static (Philipp Rudo) [1874100]
- [s390] scsi: zfcp: remove unnecessary null pointer check before mempool_destroy (Philipp Rudo) [1874100]
- [s390] s390/dasd, zfcp: fix gcc 8 stringop-truncation warnings (Philipp Rudo) [1874100]
- [s390] s390/stp: unify stp_work_mutex and clock_sync_mutex (Philipp Rudo) [1856342]
- [s390] s390/stp: add sysfs file to show scheduled leap seconds (Philipp Rudo) [1856342]
- [s390] s390/stp: add support for leap seconds (Philipp Rudo) [1856342]
- [s390] s390/stp: use u32 instead of unsigned int (Philipp Rudo) [1856342]
- [s390] s390/stp: use __packed (Philipp Rudo) [1856342]
- [s390] s390/stp: add locking to sysfs functions (Philipp Rudo) [1856342]
- [s390] s390/stp: allow group and users to read stp sysfs files (Philipp Rudo) [1856342]
- [s390] s390/ipl: add support to control memory clearing for nvme re-IPL (Philipp Rudo) [1851122]
- [kernel] tick: broadcast-hrtimer: Fix a race in bc_set_next (Vladis Dronov) [1876567]
- [fs] gfs2: Make sure we don't miss any delayed withdraws (Robert S Peterson) [1873565]
- [fs] gfs2: add some much needed cleanup for log flushes that fail (Robert S Peterson) [1873565]
- [fs] gfs2: fix trans slab error when withdraw occurs inside log_flush (Robert S Peterson) [1873565]
- [block] blk-mq: mark flush request as IDLE in flush_end_io() (Gopal Tiwari) [1894347]
- [nvme] nvme-tcp: avoid repeated request completion (Gopal Tiwari) [1894347]
- [nvme] nvme-rdma: avoid repeated request completion (Gopal Tiwari) [1894347]
- [nvme] nvme-tcp: avoid race between time out and tear down (Gopal Tiwari) [1894347]
- [nvme] nvme-rdma: avoid race between time out and tear down (Gopal Tiwari) [1894347]
- [nvme] nvme: introduce nvme_sync_io_queues (Gopal Tiwari) [1894347]
- [documentation] kvm: x86: hyper-v: Mention SynDBG CPUID leaves in api.rst (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: remove unused variable (Vitaly Kuznetsov) [1882793]
- [tools] kvm: selftests: Don't require THP to run tests (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: evmcs: make evmcs_sanitize_exec_ctrls() work again (Vitaly Kuznetsov) [1882793]
- [tools] kvm: selftests: test behavior of unmapped L2 APIC-access address (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Fix NULL dereference at kvm_msr_ignored_check() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: replace static const variables with macros (Vitaly Kuznetsov) [1882793]
- [x86] kvm: ioapic: break infinite recursion on lazy EOI (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: rename pi_init to avoid conflict with paride (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Avoid modulo operator on 64-bit value to fix i386 build (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: NX largepage recovery for TDP MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Don't clear write flooding count for direct roots (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support MMIO in the TDP MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support write protection for nesting in tdp MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support disabling dirty logging for the tdp MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support dirty logging for the TDP MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support changed pte notifier in tdp MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Add access tracking for tdp_mmu (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support invalidate range MMU notifier for TDP MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Allocate struct kvm_mmu_pages for all pages in TDP MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Add TDP MMU PF handler (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Remove disallowed_hugepage_adjust shadow_walk_iterator arg (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Support zapping SPTEs in the TDP MMU (Vitaly Kuznetsov) [1882793]
- [virt] kvm: Cache as_id in kvm_memory_slot (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Add functions to handle changed TDP SPTEs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Allocate and free TDP MMU roots (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Init / Uninit the TDP MMU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Introduce tdp_iter (Vitaly Kuznetsov) [1882793]
- [x86] kvm: mmu: extract spte.h and spte.c (Vitaly Kuznetsov) [1882793]
- [x86] kvm: mmu: Separate updating a PTE from kvm_set_pte_rmapp (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Separate making SPTEs from set_spte (Vitaly Kuznetsov) [1882793]
- [x86] kvm: mmu: Separate making non-leaf sptes from link_shadow_page (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Let the guest own CR4.FSGSBASE (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Intercept guest reserved CR4 bits to inject #GP fault (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move call to update_exception_bitmap() into VMX code (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Invoke vendor's vcpu_after_set_cpuid() after all common updates (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Intercept LA57 to inject #GP fault when it's reserved (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Initialize prev_ga_tag before use (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: implement on demand allocation of the nested state (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: allow kvm_x86_ops.set_efer to return an error value (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: report negative values from wrmsr emulation to userspace (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: xen_hvm_config: cleanup return values (Vitaly Kuznetsov) [1882793]
- [x86] kvm x86/mmu: Make struct kernel_param_ops definitions const (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: allocate vcpu->arch.cpuid_entries dynamically (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: disconnect kvm_check_cpuid() from vcpu->arch.cpuid_entries (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: only provide PV features if enabled in guest's CPUID (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: set wall_clock in kvm_write_wall_clock() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: encapsulate wrmsr(MSR_KVM_SYSTEM_TIME) emulation in helper fn (Vitaly Kuznetsov) [1882793]
- [x86] kvm: hide KVM options from menuconfig when KVM is not compiled (Vitaly Kuznetsov) [1882793]
- [documentation] kvm: vmx: Forbid userspace MSR filters for x2APIC (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Ignore userspace MSR filters for x2APIC (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Fix x2APIC MSR intercept handling on !APICV platforms (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: vmx_uret_msrs_list[] can be static (Vitaly Kuznetsov) [1882793]
- [tools] kvm: x86: do not attempt TSC synchronization on guest writes (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: delay MSR permission processing to first nested VM run (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: rename KVM_REQ_GET_VMCS12_PAGES (Vitaly Kuznetsov) [1882793]
- [tools] kvm: selftests: Add test for user space MSR handling (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Introduce MSR filtering (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: vmx: Prevent MSR passthrough when MSR access is denied (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: svm: Prevent MSR passthrough when MSR access is denied (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Prepare MSR bitmaps for userspace tracked MSRs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add infrastructure for MSR filtering (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Allow deflecting unknown MSR accesses to user space (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Return -ENOENT on unimplemented MSRs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename vmx_uret_msr's "index" to "slot" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename "vmx_msr_index" to "vmx_uret_msrs_list" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename "vmx_set_guest_msr" to "vmx_set_guest_uret_msr" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename "find_msr_entry" to "vmx_find_uret_msr" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Add vmx_setup_uret_msr() to handle lookup and swap (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Move uret MSR lookup into update_transition_efer() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Check guest support for RDTSCP before processing MSR_TSC_AUX (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename "__find_msr_index" to "__vmx_find_uret_msr" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename vcpu_vmx's "guest_msrs_ready" to "guest_uret_msrs_loaded" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename vcpu_vmx's "save_nmsrs" to "nr_active_uret_msrs" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename vcpu_vmx's "nmsrs" to "nr_uret_msrs" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename the "shared_msr_entry" struct to "vmx_uret_msr" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename "vmx_find_msr_index" to "vmx_find_loadstore_msr_slot" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Prepend "MAX_" to MSR array size defines (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Rename "shared_msrs" to "user_return_msrs" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Move individual kvm_mmu initialization into common helper (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Read EXIT_QUAL and INTR_INFO only when needed for nested exit (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Use common definition for kvm_nested_vmexit tracepoint (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add macro wrapper for defining kvm_exit tracepoint (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add intr/vectoring info and error code to kvm_exit tracepoint (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Add a helper to test for a valid error code given an intr info (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Read guest RIP from within the kvm_nested_vmexit tracepoint (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add RIP to the kvm_entry, i.e. VM-Enter, tracepoint (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: WARN on attempt to switch the currently loaded VMCS (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Drop redundant VMCS switch and free_nested() call (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Ensure vmcs01 is the loaded VMCS when freeing nested state (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Move free_nested() below vmx_switch_vmcs() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Explicitly check for valid guest state for !unrestricted guest (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Reload vmcs01 if getting vmcs12's pages fails (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Reset the segment cache when stuffing guest segs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Track write/user faults using bools (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Hoist ITLB multi-hit workaround check up a level (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Rename 'hlevel' to 'level' in FNAME(fetch) (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Account NX huge page disallowed iff huge page was requested (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Capture requested page level before NX huge page workaround (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Move "huge page disallowed" calculation into mapping helpers (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Refactor the zap loop for recovering NX lpages (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Commit zap of remaining invalid pages when recovering lpages (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename ops.h to vmx_ops.h (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Extract posted interrupt support to separate files (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Bail early from final #PF handling on spurious faults (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Return unique RET_PF_* values if the fault was fixed (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Invert RET_PF_* check when falling through to emulation (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Return -EIO if page fault returns RET_PF_INVALID (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Recursively zap nested TDP SPs when zapping last/only parent (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Move flush logic from mmu_page_zap_pte() to FNAME(invlpg) (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: hyper-v: disallow configuring SynIC timers with no SynIC (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Stash 'kvm' in a local variable in kvm_mmu_free_roots() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Add a helper and macros to reduce boilerplate for sec exec ctls (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename RDTSCP secondary exec control name to insert "ENABLE" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Use VMX_FEATURE_* flags to define VMCS control bits (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Unconditionally clear CPUID.INVPCID if !CPUID.PCID (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Rename vmx_*_supported() helpers to cpu_has_vmx_*() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Use "illegal GPA" helper for PT/RTIT output base check (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move illegal GPA helper out of the MMU code (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Replace MSR_IA32_RTIT_OUTPUT_BASE_MASK with helper function (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Unexport cpuid_query_maxphyaddr() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Use precomputed MAXPHYADDR for RTIT base MSR check (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Do not perform emulation for INVD intercept (Vitaly Kuznetsov) [1882793]
- [x86] kvm: sev: shorten comments around sev_clflush_pages (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Mark SEV launch secret pages as dirty (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Add VM-Enter failed tracepoints for super early checks (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: CR3 MBZ bits are only 63:52 (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: emulating RDPID failure shall return #UD rather than #GP (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Morph notification vector IRQ on nested VM-Enter to pending PI (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Add tracepoint for cr_interception (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Analyze is_guest_mode() in svm_vcpu_run() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Invoke NMI handler via indirect call instead of INTn (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Move IRQ invocation to assembly subroutine (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add kvm_x86_ops hook to short circuit emulation (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: use __GFP_ZERO instead of clear_page() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: KVM needs to unset "unrestricted guest" VM-execution control in vmcs02 if vmcs12 doesn't set it (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Enable INVPCID feature on AMD (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move handling of INVPCID types to x86 (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Rename and move the function vmx_handle_memory_failure to x86.c (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Remove set_cr_intercept, clr_cr_intercept and is_cr_intercept (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Add new intercept word in vmcb_control_area (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Modify 64 bit intercept field to two 32 bit vectors (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Modify intercept_exceptions to generic intercepts (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Change intercept_dr to generic intercepts (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Change intercept_cr to generic intercepts (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Introduce vmcb_(set_intercept/clr_intercept/_is_intercept) (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: Remove unused field (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: refactor exit labels in svm_create_vcpu (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: use __GFP_ZERO instead of clear_page (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: refactor msr permission bitmap allocation (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: rename nested vmcb to vmcb12 (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: rename a variable in the svm_create_vcpu (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Reduce world switch latency caused by timer_advance_ns (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Narrow down the kick target vCPU (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Guarantee the timer is in tsc-deadline mode when setting (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Return 0 when getting the tscdeadline timer if the lapic is hw disabled (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Fix updating DFR missing apic map recalculation (Vitaly Kuznetsov) [1882793]
- [virt] kvm/eventfd: move wildcard calculation outside loop (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Simplify the initialization of nested_vmx_msrs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Fix VMX controls MSRs setup when nested VMX enabled (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: Avoid freeing uninitialized pointers in svm_set_nested_state() (Vitaly Kuznetsov) [1882793]
- [x86] hyperv: Remove aliases with X64 in their name (Vitaly Kuznetsov) [1882793]
- [x86] hyperv: Split hyperv-tlfs.h into arch dependent and independent files (Vitaly Kuznetsov) [1882793]
- [x86] hyperv: Remove HV_PROCESSOR_POWER_STATE #defines (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Add GHCB definitions (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: nested: Don't allocate VMCB structures on stack (Vitaly Kuznetsov) [1882793]
- [x86] kvm: mmu: page_track: Fix RCU list API usage (Vitaly Kuznetsov) [1882793]
- [kernel] rculist: Introduce list/hlist_for_each_entry_srcu() macros (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: update PFEC_MASK/PFEC_MATCH together with PF intercept (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Add a dedicated INVD intercept routine (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Reset MMU context if guest toggles CR4.SMAP or CR4.PKE (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: fix MSR_IA32_TSC read for nested migration (Vitaly Kuznetsov) [1882793]
- [tools] selftests: kvm: Fix assert failure in single-step test (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: vmx: Make smaller physical guest address space support user-configurable (Vitaly Kuznetsov) [1882793]
- [x86] revert "kvm: Check the allocation of pv cpu mask" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: emulator: more strict rsm checks (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: more strict SMM checks when returning to nested guest (Vitaly Kuznetsov) [1882793]
- [x86] svm: nsvm: setup nested msr permission bitmap on nested state load (Vitaly Kuznetsov) [1882793]
- [x86] svm: nsvm: correctly restore GIF on vmexit from nesting after migration (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Don't freeze guest when event delivery causes an APIC-access exit (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: avoid emulation with stale next_rip (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: always allow writing '0' to MSR_KVM_ASYNC_PF_EN (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Periodically schedule when unregistering regions on destroy (Vitaly Kuznetsov) [1882793]
- [x86] kvm x86/mmu: use KVM_REQ_MMU_SYNC to sync when needed (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Fix the update value of nested load IA32_PERF_GLOBAL_CTRL control (Vitaly Kuznetsov) [1882793]
- [virt] kvm: fix memory leak in kvm_io_bus_unregister_dev() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Check the allocation of pv cpu mask (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Update VMCS02 when L2 PAE PDPTE updates detected (Vitaly Kuznetsov) [1882793]
- [documentation] kvm: documentation: Minor fixups (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Toggling CR4.PKE does not load PDPTEs in PAE mode (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Toggling CR4.SMAP does not load PDPTEs in PAE mode (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: fix access code passed to gva_to_gpa (Vitaly Kuznetsov) [1882793]
- [tools] selftests: kvm: Use a shorter encoding to clear RAX (Vitaly Kuznetsov) [1882793]
- [x86] kvm/hyper-v: Synic default SCONTROL MSR needs to be enabled (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Don't attempt to load PDPTRs when 64-bit mode is enabled (Vitaly Kuznetsov) [1882793]
- [x86] kvm: detect assigned device via irqbypass manager (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Fix sev_pin_memory() error handling (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Set the TDCR settable bits (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Fix disable pause loop exit/pause filtering capability on SVM (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Prevent setting the tscdeadline timer if the lapic is hw disabled (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Specify max TDP level via kvm_configure_mmu() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Rename max_page_level to max_huge_page_level (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Dynamically calculate TDP level from max level and MAXPHYADDR (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vxm: Remove temporary WARN on expected vs. actual EPTP level mismatch (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Pull the PGD's level from the MMU instead of recalculating it (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Make vmx_load_mmu_pgd() static (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Add separate helper for shadow NPT root page role calc (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Drop a duplicate declaration of construct_eptp() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Using macros instead of magic values (Vitaly Kuznetsov) [1882793]
- [tools] kvm: nvmx: check for invalid hdr.vmx.flags (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: check for required but missing VMCS12 in KVM_SET_NESTED_STATE (Vitaly Kuznetsov) [1882793]
- [tools] selftests: kvm: do not set guest mode flag (Vitaly Kuznetsov) [1882793]
- [documentation] documentation: virt/kvm/api: eliminate duplicated word (Vitaly Kuznetsov) [1882793]
- [documentation] docs: kvm: Replace HTTP links with HTTPS ones (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: remove nonsensical EXITINFO1 adjustment on nested NPF (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add a capability for GUEST_MAXPHYADDR < HOST_MAXPHYADDR support (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: optimize #PF injection when MAXPHYADDR does not match (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Add guest physical address check in EPT violation and misconfig (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: introduce vmx_need_pf_intercept (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: update exception bitmap on CPUID changes (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: rename update_bp_intercept to update_exception_bitmap (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: mmu: Add guest physical address check in translate_gpa() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: mmu: Move translate_gpa() to mmu.c (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add helper functions for illegal GPA checking and page fault injection (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: move MSR_IA32_PERF_CAPABILITIES emulation to common x86 code (Vitaly Kuznetsov) [1882793]
- [virt] kvm: Move x86's MMU memory cache helpers to common KVM code (Vitaly Kuznetsov) [1882793]
- [kernel] kvm: Move x86's version of struct kvm_mmu_memory_cache to common code (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Prepend "kvm_" to memory cache helpers that will be global (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Skip filling the gfn cache for guaranteed direct MMU topups (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Zero allocate shadow pages (outside of mmu_lock) (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Make __GFP_ZERO a property of the memory cache (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Separate the memory caches for shadow pages and gfn arrays (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Clean up the gorilla math in mmu_topup_memory_caches() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Topup memory caches after walking GVA->GPA (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Move fast_page_fault() call above mmu_topup_memory_caches() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Try to avoid crashing KVM if a MMU memory cache is empty (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Remove superfluous gotos from mmu_topup_memory_caches() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Use consistent "mc" name for kvm_mmu_memory_cache locals (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Consolidate "page" variant of memory cache helpers (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Track the associated kmem_cache in the MMU caches (Vitaly Kuznetsov) [1882793]
- [x86] kvm/x86: pmu: Fix #GP condition check for RDPMC emulation (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move kvm_x86_ops.vcpu_after_set_cpuid() into kvm_vcpu_after_set_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Rename cpuid_update() callback to vcpu_after_set_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Rename kvm_update_cpuid() to kvm_vcpu_after_set_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Extract kvm_update_cpuid_runtime() from kvm_update_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Introduce kvm_check_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move kvm_apic_set_version() to kvm_update_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: lapic: Use guest_cpuid_has() in kvm_apic_set_version() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Go on updating other CPUID leaves when leaf 1 is absent (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Reset vcpu->arch.cpuid_nent to 0 if SET_CPUID* fails (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: limit the maximum number of vPMU fixed counters to 3 (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: Check that MBZ bits in CR3 and CR4 are not set on vmrun of nested guests (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Make CR4.VMXE reserved for the guest (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Create mask for guest CR4 reserved bits in kvm_update_cpuid() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Read PDPTEs on CR0.CD and CR0.NW changes (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Add "nopvspin" parameter to disable PV spinlocks (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Change print code to use pr_*() format (Vitaly Kuznetsov) [1882793]
- [x86] revert "kvm: x86: Fix setup the virt_spin_lock_key before static key get initialized" (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Rename page_header() to to_shadow_page() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Add sptep_to_sp() helper to wrap shadow page lookup (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Make kvm_mmu_page definition and accessor internal-only (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Add MMU-internal header (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Move kvm_mmu_available_pages() into mmu.c (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Move mmu_audit.c and mmutrace.h into the mmu/ sub-directory (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Exit to userspace on make_mmu_pages_available() error (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Batch zap MMU pages when shrinking the slab (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Batch zap MMU pages when recycling oldest pages (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Don't put invalid SPs back on the list of active pages (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Optimize MMU page cache lookup for fully direct MMUs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Avoid multiple hash lookups in kvm_get_mmu_page() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Use VMCALL and VMMCALL mnemonics in kvm_para.h (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Rename svm_nested_virtualize_tpr() to nested_svm_virtualize_tpr() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Add svm_ prefix to set/clr/is_intercept() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Add vmcb_ prefix to mark_*() functions (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Rename struct nested_state to svm_nested_state (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Wrap VM-Fail valid path in generic VM-Fail helper (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Set last_vmentry_cpu in vcpu_enter_guest (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move last_cpu into kvm_vcpu_arch as last_vmentry_cpu (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Add "last CPU" to some KVM_EXIT information (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Add last_cpu to struct vcpu_vmx (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Always set svm->last_cpu on VMRUN (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: Prefer vcpu->cpu to raw_smp_processor_id() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: report sev_pin_memory errors with PTR_ERR (Vitaly Kuznetsov) [1882793]
- [x86] kvm: svm: fix svn_pin_memory()'s use of get_user_pages_fast() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nsvm: Check that DR6[63:32] and DR7[64:32] are not set on vmrun of nested guests (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move the check for upper 32 reserved bits of DR6 to separate function (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Do the same ignore_msrs check for feature msrs (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Move ignore_msrs handling upper the stack (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Make .write_log_dirty a nested operation (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: WARN if PML emulation helper is invoked outside of nested guest (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Drop kvm_arch_write_log_dirty() wrapper (Vitaly Kuznetsov) [1882793]
- [s390] kvm: async_pf: change kvm_setup_async_pf()/kvm_arch_setup_async_pf() return type to bool (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: drop KVM_PV_REASON_PAGE_READY case from kvm_handle_page_fault() (Vitaly Kuznetsov) [1882793]
- [documentation] documentation: virt: kvm/api: drop doubled words (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Use KVM_POSSIBLE_CR*_GUEST_BITS to initialize guest/host masks (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Mark CR4.TSD as being possibly owned by the guest (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Inject #GP if guest attempts to toggle CR4.LA57 in 64-bit mode (Vitaly Kuznetsov) [1882793]
- [virt] kvm: use more precise cast and do not drop __user (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: bit 8 of non-leaf PDPEs is not reserved (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Fix async pf caused null-ptr-deref (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Remove vcpu_vmx's defunct copy of host_pkru (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: allow TSC to differ by NTP correction bounds without TSC scaling (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Fix MSR range of APIC registers in X2APIC mode (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Stop context switching MSR_IA32_UMWAIT_CONTROL (Vitaly Kuznetsov) [1882793]
- [x86] cpu: Move prototype for get_umwait_control_msr() to a global location (Vitaly Kuznetsov) [1882793]
- [x86] kvm: nvmx: Plumb L2 GPA through to PML emulation (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/mmu: Avoid mixing gpa_t with gfn_t in walk_addr_generic() (Vitaly Kuznetsov) [1882793]
- [x86] process/64: Make save_fsgs_for_kvm() ready for FSGSBASE (Vitaly Kuznetsov) [1882793]
- [kernel] kvm: Replace zero-length array with flexible-array (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Add helpers to identify interrupt type from intr_info (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Switch KVM guest to using interrupts for page ready APF delivery (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Remove defunct KVM_DEBUG_FS Kconfig (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Always treat MSR_IA32_PERF_CAPABILITIES as a valid PMU MSR (Vitaly Kuznetsov) [1882793]
- [x86] kvm_hv_set_msr(): use __put_user() instead of 32bit __clear_user() (Vitaly Kuznetsov) [1882793]
- [tools] kvm: selftests: update hyperv_cpuid with SynDBG tests (Vitaly Kuznetsov) [1882793]
- [x86] kvm/hyper-v: Add support for synthetic debugger via hypercalls (Vitaly Kuznetsov) [1882793]
- [x86] kvm/hyper-v: enable hypercalls regardless of hypercall page (Vitaly Kuznetsov) [1882793]
- [x86] kvm/hyper-v: Add support for synthetic debugger interface (Vitaly Kuznetsov) [1882793]
- [x86] hyper-v: Add synthetic debugger definitions (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86/pmu: Support full width counting (Vitaly Kuznetsov) [1882793]
- [documentation] kvm: x86: announce KVM_FEATURE_ASYNC_PF_INT (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: acknowledgment mechanism for async pf page ready notifications (Vitaly Kuznetsov) [1882793]
- [documentation] kvm: x86: interrupt based APF 'page ready' event delivery (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: extend struct kvm_vcpu_pv_apf_data with token info (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: hyperv: Remove duplicate definitions of Reference TSC Page (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Restrict ASYNC_PF to user space (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Sanitize kvm_async_pf_task_wait() (Vitaly Kuznetsov) [1882793]
- [x86] kvm: Handle async page faults directly through do_page_fault() (Vitaly Kuznetsov) [1882793]
- [virt] kvm: add halt-polling cpu usage stats (Vitaly Kuznetsov) [1882793]
- [powerpc] kvm: Replace vcpu->swait with rcuwait (Vitaly Kuznetsov) [1882793]
- [kernel] rcuwait: Introduce rcuwait_active() (Vitaly Kuznetsov) [1882793]
- [kernel] rcuwait: Introduce prepare_to and finish_rcuwait (Vitaly Kuznetsov) [1882793]
- [kernel] rcuwait: Add @state argument to rcuwait_wait_event() (Vitaly Kuznetsov) [1882793]
- [kernel] rcuwait: Let rcuwait_wake_up() return whether or not a task was awoken (Vitaly Kuznetsov) [1882793]
- [kernel] rcuwait: Fix stale wake call name in comment (Vitaly Kuznetsov) [1882793]
- [s390] kvm: s390: Use kvm_vcpu_wake_up in kvm_s390_vcpu_wakeup (Vitaly Kuznetsov) [1882793]
- [documentation] docs/virt/kvm: Document configuring and running nested guests (Vitaly Kuznetsov) [1882793]
- [tools] docs: fix broken references for ReST files that moved around (Vitaly Kuznetsov) [1882793]
- [x86] kvm: vmx: Extend VMXs #AC interceptor to handle split lock #AC in guest (Vitaly Kuznetsov) [1882793]
- [x86] kvm: x86: Emulate split-lock access as a write in emulator (Vitaly Kuznetsov) [1882793]
- [net] core: check length before updating Ethertype in skb_mpls_{push,pop} (Guillaume Nault) [1893886]
- [net] pktgen: fix error message with wrong function name (Guillaume Nault) [1893886]
- [net] handle the return value of pskb_carve_frag_list() correctly (Guillaume Nault) [1893886]
- [net] Fix potential wrong skb->protocol in skb_vlan_untag() (Guillaume Nault) [1893886]
- [net] make symbol 'flush_works' static (Guillaume Nault) [1893886]
- [net] compat: Add missing sock updates for SCM_RIGHTS (Guillaume Nault) [1893886]
- [net] mpls: drop skb's dst in mpls_forward() (Guillaume Nault) [1893886]
- [include] net: Added pointer check for dst->ops->neigh_lookup in dst_neigh_lookup_skb (Guillaume Nault) [1893886]
- [net] fix skb_panic to output real address (Guillaume Nault) [1893886]
- [net] fix a potential recursive NETDEV_FEAT_CHANGE (Guillaume Nault) [1893886]
- [net] neigh: send protocol value in neighbor create notification (Guillaume Nault) [1893886]
- [net] revert default NAPI poll timeout to 2 jiffies (Guillaume Nault) [1893886]
- [net] compat_ioctl: handle SIOCOUTQNSD (Guillaume Nault) [1893886]
- [net] neigh: use long type to store jiffies delta (Guillaume Nault) [1893886]
- [documentation] dev-tools: kselftest.rst: Update examples and paths (Hangbin Liu) [1876011]
- [tools] selftests/run_kselftest.sh: Make each test individually selectable (Hangbin Liu) [1876011]
- [tools] selftests: Extract run_kselftest.sh and generate stand-alone test list (Hangbin Liu) [1876011]
- [tools] selftests/harness: Flush stdout before forking (Hangbin Liu) [1876011]
- [tools] selftests: forwarding: Add missing 'rp_filter' configuration (Hangbin Liu) [1892298]
- [tools] selftests/net: relax cpu affinity requirement in msg_zerocopy test (Hangbin Liu) [1892298]
- [tools] selftests: ethtool: Fix test when only two speeds are supported (Hangbin Liu) [1892298]
- [tools] selftests/net: tcp_mmap: fix clang warning for target arch PowerPC (Hangbin Liu) [1892298]
- [tools] selftests/net: psock_fanout: fix clang issues for target arch PowerPC (Hangbin Liu) [1892298]
- [netdrv] netxen: mark netxen_nic as deprecated in RHEL8 (Ivan Vecera) [1878188]
- [net] linkmode: introduce linkmode_intersects() (Ivan Vecera) [1893193]
- [net] ipv6: avoid lockdep issue in fib6_del() (Hangbin Liu) [1892196]
- [net] ipv6: fix memory leaks on IPV6_ADDRFORM path (Hangbin Liu) [1892196]
- [net] ila: remove unused inline function ila_addr_is_ila (Hangbin Liu) [1892196]
- [net] ila: Fix uninitialised return value in ila_xlat_nl_cmd_flush (Hangbin Liu) [1892196]
- [netdrv] i40e: always propagate error value in i40e_set_vsi_promisc() (Stefan Assmann) [1835705]
- [netdrv] i40e: fix return of uninitialized aq_ret in i40e_set_vsi_promisc (Stefan Assmann) [1835705]
- [netdrv] i40e: Remove scheduling while atomic possibility (Stefan Assmann) [1835705]
- [pci] hv: Fix hibernation in case interrupts are not re-created (Mohammed Gamal) [1846838]
- [powerpc] kvm: ppc: book3s hv: xics: Replace the 'destroy' method by a 'release' method (Greg Kurz) [1857527]
- [security] selinux: complete the inlining of hashtab functions (Ondrej Mosnacek) [1878149]
- [security] selinux: prepare for inlining of hashtab functions (Ondrej Mosnacek) [1878149]
- [security] selinux: specialize symtab insert and search functions (Ondrej Mosnacek) [1878149]
- [security] selinux: fixed a checkpatch warning with the sizeof macro (Ondrej Mosnacek) [1878149]
- [security] selinux: log error messages on required process class / permissions (Ondrej Mosnacek) [1878149]
- [security] selinux: fix undefined return of cond_evaluate_expr (Ondrej Mosnacek) [1878149]
- [security] selinux: fix a double free in cond_read_node()/cond_read_list() (Ondrej Mosnacek) [1878149]
- [security] selinux: fix double free (Ondrej Mosnacek) [1878149]
- [security] selinux: netlabel: Remove unused inline function (Ondrej Mosnacek) [1878149]
- [security] selinux: do not allocate hashtabs dynamically (Ondrej Mosnacek) [1878149]
- [security] selinux: fix return value on error in policydb_read() (Ondrej Mosnacek) [1878149]
- [security] selinux: simplify range_write() (Ondrej Mosnacek) [1878149]
- [security] selinux: fix error return code in policydb_read() (Ondrej Mosnacek) [1878149]
- [security] selinux: don't produce incorrect filename_trans_count (Ondrej Mosnacek) [1878149]
- [security] selinux: implement new format of filename transitions (Ondrej Mosnacek) [1878149]
- [security] selinux: move context hashing under sidtab (Ondrej Mosnacek) [1878149]
- [security] selinux: hash context structure directly (Ondrej Mosnacek) [1878149]
- [security] selinux: store role transitions in a hash table (Ondrej Mosnacek) [1878149]
- [security] selinux: drop unnecessary smp_load_acquire() call (Ondrej Mosnacek) [1878149]
- [security] selinux: fix warning Comparison to bool (Ondrej Mosnacek) [1878149]
- [security] selinux: fix error return code in cond_read_list() (Ondrej Mosnacek) [1878149]
- [security] selinux: free str on error in str_read() (Ondrej Mosnacek) [1878149]
- [security] selinux: clean up indentation issue with assignment statement (Ondrej Mosnacek) [1878149]
- [security] selinux: avtab_init() and cond_policydb_init() return void (Ondrej Mosnacek) [1878149]
- [security] selinux: clean up error path in policydb_init() (Ondrej Mosnacek) [1878149]
- [security] selinux: remove unused initial SIDs and improve handling (Ondrej Mosnacek) [1878149]
- [security] selinux: reduce the use of hard-coded hash sizes (Ondrej Mosnacek) [1878149]
- [security] selinux: Add xfs quota command types (Ondrej Mosnacek) [1878149]
- [security] selinux: optimize storage of filename transitions (Ondrej Mosnacek) [1878149]
- [security] selinux: factor out loop body from filename_trans_read() (Ondrej Mosnacek) [1878149]
- [security] selinux: generalize evaluate_cond_node() (Ondrej Mosnacek) [1878149]
- [security] selinux: convert cond_expr to array (Ondrej Mosnacek) [1878149]
- [security] selinux: convert cond_av_list to array (Ondrej Mosnacek) [1878149]
- [security] selinux: convert cond_list to array (Ondrej Mosnacek) [1878149]
- [security] selinux: sel_avc_get_stat_idx should increase position index (Ondrej Mosnacek) [1878149]
- [security] selinux: simplify evaluate_cond_node() (Ondrej Mosnacek) [1878149]
- [security] selinux: move status variables out of selinux_ss (Ondrej Mosnacek) [1878149]
- [scripts] selinux: use kernel linux/socket.h for genheaders and mdp (Ondrej Mosnacek) [1878149]
- [scripts] genheaders: -<width>s had been there since v6; -*s - since v7 (Ondrej Mosnacek) [1878149]
- [scsi] scsi: megaraid_sas: Added support for shared host tagset for cpuhotplug (Ming Lei) [1876863]
- [scsi] scsi: scsi_debug: Support host tagset (Ming Lei) [1876863]
- [scsi] scsi: core: Show nr_hw_queues in sysfs (Ming Lei) [1876863]
- [scsi] scsi: Add host and host template flag 'host_tagset' (Ming Lei) [1876863]
- [block] null_blk: Support shared tag bitmap (Ming Lei) [1876863]
- [block] blk-mq, elevator: Count requests per hctx to improve performance (Ming Lei) [1876863]
- [block] blk-mq: Record active_queues_shared_sbitmap per tag_set for when using shared sbitmap (Ming Lei) [1876863]
- [block] blk-mq: Record nr_active_requests per queue for when using shared sbitmap (Ming Lei) [1876863]
- [block] blk-mq: Relocate hctx_may_queue() (Ming Lei) [1876863]
- [block] blk-mq: Facilitate a shared sbitmap per tagset (Ming Lei) [1876863]
- [block] blk-mq: Use pointers for blk_mq_tags bitmap tags (Ming Lei) [1876863]
- [block] blk-mq: Pass flags for tag init/free (Ming Lei) [1876863]
- [block] blk-mq: Free tags in blk_mq_init_tags() upon error (Ming Lei) [1876863]
- [block] blk-mq: Rename blk_mq_update_tag_set_depth() (Ming Lei) [1876863]
- [block] blk-mq: Rename BLK_MQ_F_TAG_SHARED as BLK_MQ_F_TAG_QUEUE_SHARED (Ming Lei) [1876863]
- [block] block: fix double account of flush request's driver tag (Ming Lei) [1876863]
- [block] blk-mq: centralise related handling into blk_mq_get_driver_tag (Ming Lei) [1876863]
- [block] blk-mq: streamline handling of q->mq_ops->queue_rq result (Ming Lei) [1876863]
- [block] blk-mq: remove pointless call of list_entry_rq() in hctx_show_busy_rq() (Ming Lei) [1876863]
- [block] blk-mq: move blk_mq_get_driver_tag into blk-mq.c (Ming Lei) [1876863]
- [block] blk-mq: support batching dispatch in case of io (Ming Lei) [1876863]
- [block] blk-mq: pass obtained budget count to blk_mq_dispatch_rq_list (Ming Lei) [1876863]
- [block] blk-mq: remove dead check from blk_mq_dispatch_rq_list (Ming Lei) [1876863]
- [block] blk-mq: move getting driver tag and budget into one helper (Ming Lei) [1876863]
- [block] blk-mq: pass hctx to blk_mq_dispatch_rq_list (Ming Lei) [1876863]
- [block] blk-mq: remove the BLK_MQ_REQ_INTERNAL flag (Ming Lei) [1876863]
- [net] netns: Constify exported functions (Guillaume Nault) [1806134]
- [net] netns: protect netns ID lookups with RCU (Guillaume Nault) [1806134]
- [net] netns: Remove __peernet2id_alloc() (Guillaume Nault) [1806134]
- [net] netns: read NETNSA_NSID as s32 attribute in rtnl_net_getid() (Guillaume Nault) [1806134]
- [tools] selftests: txtimestamp: add flag for timestamp validation tolerance. (Hangbin Liu) [1861175]
- [tools] selftests/net: so_txtime: fix clang issues for target arch PowerPC (Hangbin Liu) [1861175]
- [tools] selftests/net: rxtimestamp: fix clang issues for target arch PowerPC (Hangbin Liu) [1861175]
- [tools] selftest: txtimestamp: fix net ns entry logic (Hangbin Liu) [1861175]
- [tools] selftests/net: update initializer syntax to use c99 designators (Hangbin Liu) [1861175]
- [tools] selftests/net: add ipv6 test coverage in rxtimestamp test (Hangbin Liu) [1861175]
- [tools] selftests/net: plug rxtimestamp test into kselftest framework (Hangbin Liu) [1861175]
- [tools] selftests/net: in rxtimestamp getopt_long needs terminating null entry (Hangbin Liu) [1861175]
- [tools] selftests/net: in timestamping, strncpy needs to preserve null byte (Hangbin Liu) [1861175]
- [tools] selftests: move timestamping selftests to net folder (Hangbin Liu) [1861175]
- [tools] selftests: txtimestamp: print statistics for timestamp events. (Hangbin Liu) [1861175]
- [tools] selftests: txtimestamp: add support for epoll(). (Hangbin Liu) [1861175]
- [tools] selftests: txtimestamp: add new command-line flags. (Hangbin Liu) [1861175]
- [tools] selftests: txtimestamp: allow printing latencies in nsec. (Hangbin Liu) [1861175]
- [tools] selftests: txtimestamp: allow individual txtimestamp tests. (Hangbin Liu) [1861175]
- [tools] selftests: timestamping: Fix SIOCGSTAMP undeclared build failure (Hangbin Liu) [1861175]
- [tools] selftests: fix timestamping Makefile (Hangbin Liu) [1861175]
- [tools] selftests: add missing include unistd (Hangbin Liu) [1861175]
- [tools] selftests/txtimestamp: Fix an equals vs assign bug (Hangbin Liu) [1861175]
- [tools] selftests: add txtimestamp kselftest (Hangbin Liu) [1861175]
- [tools] selftests: expand txtimestamp with ipv6 dgram + raw and pf_packet (Hangbin Liu) [1861175]
- [tools] selftests: expand txtimestamp with cmsg support (Hangbin Liu) [1861175]
- [hwmon] hwmon: (k10temp) Add support for Zen3 CPUs (Wei Huang) [1846851]
- [powerpc] vfs: add faccessat2 syscall (Miklos Szeredi) [1333764]
- [fs] vfs: split out access_override_creds() (Miklos Szeredi) [1333764]
- [md] Revert "dm writecache: set "Tech Preview" taint using mark_tech_preview()" (Mike Snitzer) [1859413]
- [s390] mm: fix huge pte soft dirty copying (Cornelia Huck) [1700709]
- [fs] proc/mounts: add cursor (Miklos Szeredi) [1759472]

* Wed Nov 18 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-251.el8]
- [char] random: Add a poll handler to extrng_fops (Vladis Dronov) [1884857]
- [platform] platform/mellanox: mlxbf-pmc: Add Mellanox BlueField PMC driver (Alaa Hleihel) [1655729]
- [mm] mm/page_idle.c: skip offline pages (Chris von Recklinghausen) [1867490]
- [powerpc] powerpc/pseries: Detect secure and trusted boot state of the system (Diego Domingos) [1853411]
- [net] bpf: Check correct cred for CAP_SYSLOG in bpf_dump_raw_ok() (Yauheni Kaliuta) [1874003]
- [kernel] kallsyms: Refactor kallsyms_show_value() to take cred (Yauheni Kaliuta) [1874003]
- [kernel] kprobes: Show blacklist addresses as same as kallsyms does (Yauheni Kaliuta) [1874003]
- [arm64] arm64: insn: Report PAC and BTI instructions as skippable (Yauheni Kaliuta) [1874003]
- [arm64] arm64: insn: Don't assume unrecognized HINTs are skippable (Yauheni Kaliuta) [1874003]
- [lib] usercopy: Avoid soft lockups in test_check_nonzero_user() (Yauheni Kaliuta) [1874003]
- [security] selinux: map CAP_PERFMON and CAP_BPF to CAP_SYS_ADMIN (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: fix netdevsim trap_flow_action_cookie read (Yauheni Kaliuta) [1874003]
- [net] net/bpfilter: Initialize pos in __bpfilter_process_sockopt (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Extend map-in-map selftest to detect memory leaks (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix map leak in HASH_OF_MAPS map (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix NULL pointer dereference in __btf_resolve_helper_id() (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix cgroup sockopt verifier test (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Fix libbpf hashmap on (I)LP32 architectures (Yauheni Kaliuta) [1874003]
- [tools] selftests: bpf: Fix detach from sockmap tests (Yauheni Kaliuta) [1874003]
- [net] bpf: net: Avoid incorrect bpf_sk_reuseport_detach call (Yauheni Kaliuta) [1874003]
- [net] bpf: net: Avoid copying sk_user_data of reuseport_array during sk_clone (Yauheni Kaliuta) [1874003]
- [tools] bpf: Add tests for PTR_TO_BTF_ID vs. null comparison (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix an incorrect branch elimination by verifier (Yauheni Kaliuta) [1874003]
- [include] bpf: sockmap: Require attach_bpf_fd when detaching a program (Yauheni Kaliuta) [1874003]
- [net] bpf: sockmap: Check value of unused args to BPF_PROG_ATTACH (Yauheni Kaliuta) [1874003]
- [net] bpf: Enforce BPF ringbuf size to be the power of 2 (Yauheni Kaliuta) [1874003]
- [tools] bpf, sockmap: Add ingres skb tests that utilize merge skbs (Yauheni Kaliuta) [1874003]
- [net] bpf, sockmap: RCU dereferenced psock may be used outside RCU block (Yauheni Kaliuta) [1874003]
- [net] bpf, sockmap: RCU splat with redirect and strparser error or TLS (Yauheni Kaliuta) [1874003]
- [tools] bpf: tcp: bpf_cubic: fix spurious HYSTART_DELAY exit upon drop in min RTT (Yauheni Kaliuta) [1874003]
- [net] bpf: Do not allow btf_ctx_access with __int128 types (Yauheni Kaliuta) [1874003]
- [tools] bpf: Fix formatting in documentation for BPF helpers (Yauheni Kaliuta) [1874003]
- [net] bpf: Restore behaviour of CAP_SYS_ADMIN allowing the loading of networking bpf programs (Yauheni Kaliuta) [1874003]
- [net] bpf: Set the number of exception entries properly for subprograms (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Fix CO-RE relocs against .text section (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Forward-declare bpf_stats_type for systems with outdated UAPI headers (Yauheni Kaliuta) [1874003]
- [documentation] bpf: Document optval > PAGE_SIZE behavior for sockopt hooks (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Make sure optvals > PAGE_SIZE are bypassed (Yauheni Kaliuta) [1874003]
- [net] bpf: Don't return EINVAL from {get, set}sockopt when optlen > PAGE_SIZE (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Add ringbuf map type to map command docs (Yauheni Kaliuta) [1874003]
- [samples] bpf, xdp, samples: Fix null pointer dereference in *_user code (Yauheni Kaliuta) [1874003]
- [tools] tools/bpftool: Add ringbuf map to a list of known map types (Yauheni Kaliuta) [1874003]
- [tools] bpf: Fix definition of bpf_ringbuf_output() helper in UAPI comments (Yauheni Kaliuta) [1874003]
- [net] bpf: Undo internal BPF_PROBE_MEM in BPF insns dump (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Support pre-initializing .bss global variables (Yauheni Kaliuta) [1874003]
- [tools] tools/bpftool: Fix skeleton codegen (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix memlock accounting for sock_hash (Yauheni Kaliuta) [1874003]
- [net] bpf: tcp: Recv() should return 0 when the peer socket is closed (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Exit on error in function codegen (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Fix memory leak in codegen error cases (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add cgroup_skb/egress test for load_bytes_relative (Yauheni Kaliuta) [1874003]
- [net] net/filter: Permit reading NET in load_bytes_relative when MAC not set (Yauheni Kaliuta) [1874003]
- [tools] tools, bpf: Do not force gcc as CC (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Define __WORDSIZE if not available (Yauheni Kaliuta) [1874003]
- [net] bpf: Devmap adjust uapi for attach bpf program (Yauheni Kaliuta) [1874003]
- [net] bpf: Reset data_meta before running programs attached to devmap entry (Yauheni Kaliuta) [1874003]
- [scripts] scripts: Require pahole v1.16 when generating BTF (Yauheni Kaliuta) [1874003]
- [net] bpf, sockhash: Synchronize delete from bucket list on map free (Yauheni Kaliuta) [1874003]
- [net] bpf, sockhash: Fix memory leak when unlinking sockets in sock_hash_free (Yauheni Kaliuta) [1874003]
- [net] bpf/sockmap: Fix kernel panic at __tcp_bpf_recvmsg (Yauheni Kaliuta) [1874003]
- [kernel] bpf: rework the compat kernel probe handling (Yauheni Kaliuta) [1874003]
- [kernel] bpf: handle the compat string in bpf_trace_copy_string better (Yauheni Kaliuta) [1874003]
- [kernel] bpf: factor out a bpf_trace_copy_string helper (Yauheni Kaliuta) [1874003]
- [net] mmap locking API: add mmap_read_trylock_non_owner() (Yauheni Kaliuta) [1874003]
- [net] bpf: sockmap: use mmap locking API (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix ringbuf selftest sample counting undeterminism (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix an error code in check_btf_func() (Yauheni Kaliuta) [1874003]
- [net] bpf: make bpf_check_uarg_tail_zero() use check_zeroed_user() (Yauheni Kaliuta) [1874003]
- [lib] lib: introduce copy_struct_from_user() helper (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add a default $(CXX) value (Yauheni Kaliuta) [1874003]
- [tools] tools/bpf: Don't use $(COMPILE.c) (Yauheni Kaliuta) [1874003]
- [s390] s390/bpf: Use bcr 0, 0 as tail call nop filler (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix verifier test (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix sample_cnt shared between two threads (Yauheni Kaliuta) [1874003]
- [tools] bpf, selftests: Adapt cls_redirect to call csum_level helper (Yauheni Kaliuta) [1874003]
- [net] bpf: Add csum_level helper for fixing up csum levels (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix up bpf_skb_adjust_room helper's skb csum setting (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add _GNU_SOURCE for reallocarray to ringbuf.c (Yauheni Kaliuta) [1874003]
- [net] bpf: Use tracing helpers for lsm programs (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add test for SO_BINDTODEVICE opt of bpf_setsockopt (Yauheni Kaliuta) [1874003]
- [tools] tools/bpf: sync bpf.h (Yauheni Kaliuta) [1874003]
- [tools] bpf, selftests: Add test for ktls with skb bpf ingress policy (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix running sk_skb program types with ktls (Yauheni Kaliuta) [1874003]
- [net] bpf: Refactor sockmap redirect code so its easy to reuse (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add SEC name for xdp programs attached to device map (Yauheni Kaliuta) [1874003]
- [net] bpf: Add support to attach bpf program to a devmap entry (Yauheni Kaliuta) [1874003]
- [kernel] bpf: Use strncpy_from_unsafe_strict() in bpf_seq_printf() helper (Yauheni Kaliuta) [1874003]
- [net] devmap: Formalize map value as a named struct (Yauheni Kaliuta) [1874003]
- [net] bpf: Add rx_queue_mapping to bpf_sock (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add tests for write-only stacks/queues (Yauheni Kaliuta) [1874003]
- [documentation] docs/bpf: Add BPF ring buffer design notes (Yauheni Kaliuta) [1874003]
- [tools] bpf: Add BPF ringbuf and perf buffer benchmarks (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add BPF ringbuf selftests (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add BPF ring buffer support (Yauheni Kaliuta) [1874003]
- [tools] bpf: Implement BPF ring buffer and verifier support for it (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix map permissions check (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Cleanup comments in test_maps (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Cleanup some file descriptors in test_maps (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix a typo in test_maps (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Fix perf_buffer__free() API for sparse allocs (Yauheni Kaliuta) [1874003]
- [tools] bpf, selftests: Test probe_* helpers from SCHED_CLS (Yauheni Kaliuta) [1874003]
- [tools] bpf, selftests: Add sk_msg helpers load and attach test (Yauheni Kaliuta) [1874003]
- [net] bpf, sk_msg: Add get socket storage helpers (Yauheni Kaliuta) [1874003]
- [net] bpf: Extend bpf_base_func_proto helpers with probe_* and *current_task* (Yauheni Kaliuta) [1874003]
- [net] bpf, sk_msg: Add some generic helpers that may be useful from sk_msg (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix spelling in comment explaining ARG1 in ___bpf_prog_run (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Install headers as part of make install (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add API to consume the perf ring buffer content (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Print correct error message when failing to load BTF (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Make capability check account for new BPF caps (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Clean subcommand help messages (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: CONFIG_LIRC required for test_lirc_mode2.sh (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: CONFIG_IPV6_SEG6_BPF required for test_seg6_loop.o (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add general instructions for test execution (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, add printk to test_sk_lookup_kern to encode null ptr check (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, verifier case for non null pointer map value branch (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, verifier case for non null pointer check branch taken (Yauheni Kaliuta) [1874003]
- [net] bpf: Verifier track null pointer branch_taken with JNE and JEQ (Yauheni Kaliuta) [1874003]
- [tools] tools/bpf: sync bpf.h (Yauheni Kaliuta) [1874003]
- [tools] bpf, testing: Add get{peer, sock}name selftests to test_progs (Yauheni Kaliuta) [1874003]
- [tools] bpf, bpftool: Enable get{peer, sock}name attach types (Yauheni Kaliuta) [1874003]
- [tools] bpf, libbpf: Enable get{peer, sock}name attach types (Yauheni Kaliuta) [1874003]
- [net] bpf: Add get{peer, sock}name attach types for sock_addr (Yauheni Kaliuta) [1874003]
- [samples] samples, bpf: Refactor kprobe, tail call kern progs map definition (Yauheni Kaliuta) [1874003]
- [samples] samples, bpf: Add tracex7 test file to .gitignore (Yauheni Kaliuta) [1874003]
- [samples] samples, bpf: Refactor tail call user progs with libbpf (Yauheni Kaliuta) [1874003]
- [samples] samples, bpf: Refactor kprobe tracing user progs with libbpf (Yauheni Kaliuta) [1874003]
- [samples] samples, bpf: Refactor pointer error check with libbpf (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, add ktls tests to test_sockmap (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, add blacklist to test_sockmap (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, add whitelist option to test_sockmap (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, provide verbose option for selftests execution (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, break down test_sockmap into subtests (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, improve test_sockmap total bytes counter (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, print error in test_sockmap error cases (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, sockmap test prog run without setting cgroup (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, remove prints from sockmap tests (Yauheni Kaliuta) [1874003]
- [tools] bpf: Selftests, move sockmap bpf prog header into progs (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Remove test_align leftovers (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Move test_align under test_progs (Yauheni Kaliuta) [1874003]
- [tools] libbpf, hashmap: Fix signedness warnings (Yauheni Kaliuta) [1874003]
- [tools] libbpf, hashmap: Remove unused #include (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix check_return_code to only allowin trace_iter progs (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Use CAP_BPF and CAP_PERFMON in tests (Yauheni Kaliuta) [1874003]
- [net] bpf: Implement CAP_BPF (Yauheni Kaliuta) [1874003]
- [security] bpf, capability: Introduce CAP_BPF (Yauheni Kaliuta) [1874003]
- [security] capabilities: Introduce CAP_PERFMON to kernel and user space (Yauheni Kaliuta) [1874003]
- [tools] bpf, bpftool: Allow probing for CONFIG_HZ from kernel config (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Test for sk helpers in cgroup skb (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add connect_fd_to_fd, connect_wait net helpers (Yauheni Kaliuta) [1874003]
- [net] bpf: Introduce bpf_sk_{, ancestor_}cgroup_id helpers (Yauheni Kaliuta) [1874003]
- [net] bpf: Allow skb_ancestor_cgroup_id helper in cgroup skb (Yauheni Kaliuta) [1874003]
- [net] bpf: Allow sk lookup helpers in cgroup skb (Yauheni Kaliuta) [1874003]
- [tools] selftest/bpf: Fix spelling mistake "SIGALARM" -> "SIGALRM" (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix bpf_iter's task iterator logic (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Test narrow loads for bpf_sock_addr.user_port (Yauheni Kaliuta) [1874003]
- [net] bpf: Support narrow loads from bpf_sock_addr.user_port (Yauheni Kaliuta) [1874003]
- [samples] samples/bpf: xdp_redirect_cpu: Set MAX_CPUS according to NR_CPUS (Yauheni Kaliuta) [1874003]
- [samples] samples/bpf: Remove compiler warnings (Yauheni Kaliuta) [1874003]
- [net] bpf: Enable bpf_iter targets registering ctx argument types (Yauheni Kaliuta) [1874003]
- [net] bpf: Change func bpf_iter_unreg_target() signature (Yauheni Kaliuta) [1874003]
- [net] bpf: net: Refactor bpf_iter target registration (Yauheni Kaliuta) [1874003]
- [net] bpf: Add comments to interpret bpf_prog return values (Yauheni Kaliuta) [1874003]
- [tools] bpf: Change btf_iter func proto prefix to "bpf_iter_" (Yauheni Kaliuta) [1874003]
- [tools] tools/bpf: selftests : Explain bpf_iter test failures with llvm 10.0.0 (Yauheni Kaliuta) [1874003]
- [tools] selftest/bpf: Add BPF triggering benchmark (Yauheni Kaliuta) [1874003]
- [tools] selftest/bpf: Fmod_ret prog and implement test_overhead as part of bench (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add benchmark runner infrastructure (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Extract parse_num_list into generic testing_helpers.c (Yauheni Kaliuta) [1874003]
- [tools] tools, bpf: Synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1874003]
- [scripts] bpf: Minor fixes to BPF helpers documentation (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Minor fixes for documentation (Yauheni Kaliuta) [1874003]
- [tools] tools, bpftool: Poison and replace kernel integer typedefs (Yauheni Kaliuta) [1874003]
- [tools] bpf, libbpf: Replace zero-length array with flexible-array (Yauheni Kaliuta) [1874003]
- [arm64] bpf, arm64: Optimize ADD, SUB, JMP BPF_K using arm64 add/sub immediates (Yauheni Kaliuta) [1874003]
- [arm64] bpf, arm64: Optimize AND, OR, XOR, JSET BPF_K using arm64 logical immediates (Yauheni Kaliuta) [1874003]
- [tools] bpf, runqslower: include proper uapi/bpf.h (Yauheni Kaliuta) [1874003]
- [tools] tools/bpf: selftests: Add iter progs for bpf_map/task/task_file (Yauheni Kaliuta) [1874003]
- [tools] tools/bpftool: Add bpf_iter support for bptool (Yauheni Kaliuta) [1874003]
- [tools] tools/libpf: Add offsetof/container_of macro in bpf_helpers.h (Yauheni Kaliuta) [1874003]
- [tools] tools/libbpf: Add bpf_iter support (Yauheni Kaliuta) [1874003]
- [net] bpf: Support variable length array in tracing programs (Yauheni Kaliuta) [1874003]
- [net] bpf: Handle spilled PTR_TO_BTF_ID properly when checking stack_boundary (Yauheni Kaliuta) [1874003]
- [kernel] bpf: Add bpf_seq_printf and bpf_seq_write helpers (Yauheni Kaliuta) [1874003]
- [net] bpf: Add PTR_TO_BTF_ID_OR_NULL support (Yauheni Kaliuta) [1874003]
- [net] bpf: Add task and task/file iterator targets (Yauheni Kaliuta) [1874003]
- [net] bpf: Add bpf_map iterator (Yauheni Kaliuta) [1874003]
- [net] bpf: Implement common macros/helpers for target iterators (Yauheni Kaliuta) [1874003]
- [net] bpf: Create file bpf iterator (Yauheni Kaliuta) [1874003]
- [net] bpf: Create anonymous bpf iterator (Yauheni Kaliuta) [1874003]
- [net] bpf: Implement bpf_seq_read() for bpf iterator (Yauheni Kaliuta) [1874003]
- [net] bpf: Support bpf tracing/iter programs for BPF_LINK_UPDATE (Yauheni Kaliuta) [1874003]
- [net] bpf: Support bpf tracing/iter programs for BPF_LINK_CREATE (Yauheni Kaliuta) [1874003]
- [net] bpf: Allow loading of a bpf_iter program (Yauheni Kaliuta) [1874003]
- [net] bpf: Implement an interface to register bpf_iter targets (Yauheni Kaliuta) [1874003]
- [tools] bpf: Allow any port in bpf_bind helper (Yauheni Kaliuta) [1874003]
- [net] net: Refactor arguments of inet{,6}_bind (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Move existing common networking parts into network_helpers (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Generalize helpers to control background listener (Yauheni Kaliuta) [1874003]
- [net] crypto: lib/sha1 - rename "sha" to "sha1" (Yauheni Kaliuta) [1874003]
- [arm64] arm64: bpf: Annotate JITed code for BTI (Yauheni Kaliuta) [1874003]
- [arm64] arm64: insn: Add constants for new HINT instruction decode (Yauheni Kaliuta) [1874003]
- [kernel] sysctl: Fix unused function warning (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Use reno instead of dctcp (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix use-after-free of bpf_link when priming half-fails (Yauheni Kaliuta) [1874003]
- [tools] bpf: Bpf_{g, s}etsockopt for struct bpf_sock_addr (Yauheni Kaliuta) [1874003]
- [tools] bpf: Add selftest for BPF_ENABLE_STATS (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add support for command BPF_ENABLE_STATS (Yauheni Kaliuta) [1874003]
- [net] bpf: Sharing bpf runtime stats with BPF_ENABLE_STATS (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Test allowed maps for bpf_sk_select_reuseport (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Fix false uninitialized variable warning (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix unused variable warning (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Use SOCKMAP for server sockets in bpf_sk_assign test (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Test that lookup on SOCKMAP/SOCKHASH is allowed (Yauheni Kaliuta) [1874003]
- [net] bpf: Allow bpf_map_lookup_elem for SOCKMAP and SOCKHASH (Yauheni Kaliuta) [1874003]
- [tools] tools: bpftool: Make libcap dependency optional (Yauheni Kaliuta) [1874003]
- [tools] tools: bpftool: Allow unprivileged users to probe features (Yauheni Kaliuta) [1874003]
- [tools] tools: bpftool: For "feature probe" define "full_mode" bool as global (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Disable ASAN instrumentation for mmap()'ed memory read (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix invalid memory reads in core_relo selftest (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Fix memory leak in extract_build_id() (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Fix memory leak and possible double-free in hashmap__clear (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Convert test_hashmap into test_progs test (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add SAN_CFLAGS param to selftests build to allow sanitizers (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Ensure test flavors use correct skeletons (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add BTF-defined map-in-map support (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Refactor map creation logic and fix cleanup leak (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Refactor BTF-defined map definition parsing logic (Yauheni Kaliuta) [1874003]
- [tools] bpftool: Add link bash completions (Yauheni Kaliuta) [1874003]
- [tools] bpftool: Add bpftool-link manpage (Yauheni Kaliuta) [1874003]
- [tools] bpftool: Add bpf_link show and pin support (Yauheni Kaliuta) [1874003]
- [tools] bpftool: Expose attach_type-to-string array to non-cgroup code (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Test bpf_link's get_next_id, get_fd_by_id, and get_obj_info (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Add low-level APIs for new bpf_link commands (Yauheni Kaliuta) [1874003]
- [net] bpf: Add support for BPF_OBJ_GET_INFO_BY_FD for bpf_link (Yauheni Kaliuta) [1874003]
- [net] bpf: Support GET_FD_BY_ID and GET_NEXT_ID for bpf_link (Yauheni Kaliuta) [1874003]
- [net] bpf: Allocate ID for bpf_link (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Remove unneeded semicolon in btf_dump_emit_type (Yauheni Kaliuta) [1874003]
- [net] bpf, cgroup: Remove unused exports (Yauheni Kaliuta) [1874003]
- [tools] libbpf: Return err if bpf_object__load failed (Yauheni Kaliuta) [1874003]
- [tools] selftests/bpf: Add cls_redirect classifier (Yauheni Kaliuta) [1874003]
- [net] bpf: Make verifier log more relevant by default (Yauheni Kaliuta) [1874003]
- [net] bpf: add bpf_ktime_get_boot_ns() (Yauheni Kaliuta) [1874003]
- [net] net: bpf: Make bpf_ktime_get_ns() available to non GPL programs (Yauheni Kaliuta) [1874003]
- [net] net: bpf: Allow TC programs to call BPF_FUNC_skb_change_head (Yauheni Kaliuta) [1874003]
- [net] bpf: Fix missing bpf_base_func_proto in cgroup_base_func_proto for CGROUP_NET=n (Yauheni Kaliuta) [1874003]
- [tools] bpf_helpers.h: Add note for building with vmlinux.h or linux/types.h (Yauheni Kaliuta) [1874003]
- [net] bpf: Enable more helpers for BPF_PROG_TYPE_CGROUP_{DEVICE, SYSCTL, SOCKOPT} (Yauheni Kaliuta) [1874003]
- [tools] tools/bpf/bpftool: Remove duplicate headers (Yauheni Kaliuta) [1874003]
- [net] bpf: Remove set but not used variable 'dst_known' (Yauheni Kaliuta) [1874003]
- [net] xdp: export the DEV_MAP_BULK_SIZE macro (Yauheni Kaliuta) [1874003]
- [kernel] trace/bpf_trace: Open access for CAP_PERFMON privileged process (Yauheni Kaliuta) [1874003]
- [scsi] scsi: lpfc: Fix initial FLOGI failure due to BBSCN not supported (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Update lpfc version to 12.8.0.5 (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Reject CT request for MIB commands (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add FDMI Vendor MIB support (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix duplicate wq_create_version check (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Removed unused macros in lpfc_attr.c (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Re-fix use after free in lpfc_rq_buf_free() (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix scheduling call while in softirq context in lpfc_unreg_rpi (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix invalid sleeping context in lpfc_sli4_nvmet_alloc() (Dick Kennedy) [1887549]
- [scsi] scsi: Remove unneeded break statements (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add dependency on CPU_FREQ (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Remove unneeded variable 'status' in lpfc_fcp_cpu_map_store() (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Drop nodelist reference on error in lpfc_gen_req() (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Remove set but not used 'qp' (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Update lpfc version to 12.8.0.4 (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Extend the RDF FPIN Registration descriptor for additional events (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix FLOGI/PLOGI receive race condition in pt2pt discovery (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix setting IRQ affinity with an empty CPU mask (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix spelling mistake "Cant" -> "Can't" (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Update lpfc version to 12.8.0.3 (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix validation of bsg reply lengths (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix retry of PRLI when status indicates its unsupported (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix oops when unloading driver while running mds diags (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix RSCN timeout due to incorrect gidft counter (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix no message shown for lpfc_hdw_queue out of range value (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix FCoE speed reporting (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add missing misc_deregister() for lpfc_init() (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: nvmet: Avoid hang / use-after-free again when destroying targetport (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix typo in comment for ULP (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add description for lpfc_release_rpi()'s 'ndlpl param (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix a bunch of kerneldoc misdemeanors (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add and rename a whole bunch of function parameter descriptions (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Use __printf() format notation (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix kerneldoc parameter formatting/misnaming/missing issues (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix some function parameter descriptions (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Ensure variable has the same stipulations as code using it (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix-up formatting/docrot where appropriate (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Provide description for lpfc_mem_alloc()'s 'align' param (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix-up around 120 documentation issues (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Remove unused variable 'pg_addr' (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Correct some pretty obvious misdocumentation (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix less-than-zero comparison of unsigned value (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix interrupt assignments when multiple vectors are supported on same CPU (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix inconsistent indenting (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Update lpfc version to 12.8.0.2 (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add an internal trace log buffer (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add blk_io_poll support for latency improvment (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Add support to display if adapter dumps are available (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Allow applications to issue Common Set Features mailbox command (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix language in 0373 message to reflect non-error message (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix shost refcount mismatch when deleting vport (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix stack trace seen while setting rrq active (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix oops due to overrun when reading SLI3 data (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix missing MDS functionality (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Fix unused assignment in lpfc_sli4_bsg_link_diag_test (Dick Kennedy) [1887549]
- [scsi] scsi: lpfc: Avoid another null dereference in lpfc_sli4_hba_unset() (Dick Kennedy) [1887549]
- [scsi] lpfc_debugfs: get rid of pointless access_ok() (Dick Kennedy) [1887549]
- [scsi] lpfc: add nvmet discovery_event op support (Dick Kennedy) [1887549]
- [scsi] scsi: core: Don't start concurrent async scan on same host (Ming Lei) [1874501]
- [crypto] crypto: bcm - Verify GCM/CCM key length in setkey (Vladis Dronov) [1887389]
- [x86] x86/cpufeatures: Add support for fast short REP; MOVSB (Steve Best) [1838265]
- [scsi] scsi: mpt3sas: A small correction in _base_process_reply_queue (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Fix sync irqs (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Detect tampered Aero and Sea adapters (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Don't call disable_irq from IRQ poll handler (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Remove pci-dma-compat wrapper API (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Remove superfluous memset() (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Update driver version to 35.100.00.00 (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Postprocessing of target and LUN reset (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Add functions to check if any cmd is outstanding on Target and LUN (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Rename and export interrupt mask/unmask functions (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Cancel the running work during host reset (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Dump system registers for debugging (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Memset config_cmds.reply buffer with zeros (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Fix kdoc comments format (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Fix set but unused variable (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Fix error returns in BRM_status_show (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Fix unlock imbalance (Tomas Henzl) [1851440]
- [scsi] scsi: mpt3sas: Fix spelling mistake (Tomas Henzl) [1851440]
- [s390] s390/zcrypt: Fix ZCRYPT_PERDEV_REQCNT ioctl (Claudio Imbrenda) [1885962]
- [scsi] scsi: megaraid: Make smp_affinity_enable static (Tomas Henzl) [1860910]
- [scsi] remove ioremap_nocache and devm_ioremap_nocache (Tomas Henzl) [1860910]
- [scsi] scsi: megaraid: Remove set but unused variable (Tomas Henzl) [1860910]
- [scsi] scsi: megaraid: Fix compilation warnings (Tomas Henzl) [1860910]
- [scsi] scsi: megaraid: Fix kdoc comments format (Tomas Henzl) [1860910]
- [scsi] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Tomas Henzl) [1860910]
- [net] ethtool: Add support for 100Gbps per lane link modes (Ivan Vecera) [1879202]

* Mon Nov 16 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-250.el8]
- [netdrv] ibmveth: Fix use of ibmveth in a bridge (Steve Best) [1893294]
- [x86] ima: add a new CONFIG for loading arch-specific policies (Bruno Meneguele) [1869758]
- [netdrv] e1000e: Add support for Meteor Lake (Ken Cox) [1838750]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Ken Cox) [1838750]
- [netdrv] treewide: Use fallthrough pseudo-keyword (Ken Cox) [1838750]
- [netdrv] e1000e: Remove unnecessary usages of memset (Ken Cox) [1838750]
- [netdrv] e1000e: continue to init PHY even when failed to disable ULP (Ken Cox) [1838750]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Ken Cox) [1838750]
- [netdrv] net/intel: remove driver versions from Intel drivers (Ken Cox) [1838750]
- [netdrv] e1000e: fix unused-function warning (Ken Cox) [1838750]
- [netdrv] e1000e: Do not wake up the system via WOL if device wakeup is disabled (Ken Cox) [1838750]
- [netdrv] e1000e: Relax condition to trigger reset for ME workaround (Ken Cox) [1838750]
- [netdrv] e1000e: disable s0ix entry and exit flows for ME systems (Ken Cox) [1838750]
- [netdrv] e1000e: Disable TSO for buffer overrun workaround (Ken Cox) [1838750]
- [netdrv] e1000e: Warn if disabling ULP failed (Ken Cox) [1838750]
- [scsi] scsi: fnic: Do not call 'scsi_done()' for unhandled commands (Govindarajulu Varadarajan) [1870397]
- [netdrv] intel-ethernet: clean up W=1 warnings in kdoc (Corinna Vinschen) [1838749]
- [netdrv] igbvf: use generic power management (Corinna Vinschen) [1838749]
- [netdrv] ethernet/intel: Convert fallthrough code comments (Corinna Vinschen) [1838749]
- [netdrv] net/intel: remove driver versions from Intel drivers (Corinna Vinschen) [1838749]
- [net] SUNRPC: Properly set the @subbuf parameter of xdr_buf_subsegment() (Steve Dickson) [1884361]
- [net] SUNRPC: Fix ("SUNRPC: Add "@len" parameter to gss_unwrap()") (Steve Dickson) [1884361]
- [net] netfilter: nf_queue: do not release refcouts until nf_reinject is done (Florian Westphal) [1886557]
- [net] netfilter: nf_queue: place bridge physports into queue_entry struct (Florian Westphal) [1886557]
- [net] netfilter: nf_queue: make nf_queue_entry_release_refs static (Florian Westphal) [1886557]
- [firewire] firewire: Deprecate Firewire support in RHEL8 (Prarit Bhargava) [1871863]
- [lib] Add pldmfw library for PLDM firmware update (Patrick Talbert) [1878278]
- [lib] bitops: introduce the for_each_set_clump8 macro (Patrick Talbert) [1878278]
- [mm] x86/ioremap: Map EFI runtime services data as encrypted for SEV (Lenny Szubowicz) [1883134]
- [powerpc] Revert "powerpc/powernv/idle: Replace CPU feature check with PVR check" (Steve Best) [1882365]
- [powerpc] powerpc/xive: Do not expose a debugfs file when XIVE is disabled (Steve Best) [1854526]
- [kvm] powerpc/xive: Enforce load-after-store ordering when StoreEOI is active (Steve Best) [1854526]
- [powerpc] powerpc/xive: Add a debugfs file to dump internal XIVE state (Steve Best) [1854526]
- [net] openvswitch: add TTL decrement action (Eelco Chaudron) [1762450]

* Thu Nov 12 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-249.el8]
- [kernel] futex: Adjust absolute futex timeouts with per time namespace offset (Waiman Long) [1548297]
- [kernel] futex: Remove unused or redundant includes (Waiman Long) [1548297]
- [include] vdso: Fix clocksource.h macro detection (Waiman Long) [1548297]
- [x86] um: Fix header inclusion (Waiman Long) [1548297]
- [arm64] arm64: vdso32: make vdso32 install conditional (Waiman Long) [1548297]
- [arm64] ARM64: vdso32: Install vdso32 from vdso_install (Waiman Long) [1548297]
- [arm64] vdso/treewide: Add vdso_data pointer argument to __arch_get_hw_counter() (Waiman Long) [1548297]
- [kernel] timekeeping/vsyscall: Provide vdso_update_begin/end() (Waiman Long) [1548297]
- [include] lib/vdso: Allow to add architecture-specific vdso data (Waiman Long) [1548297]
- [arm64] arm64: enable time namespace support (Waiman Long) [1548297]
- [arm64] arm64/vdso: Restrict splitting VVAR VMA (Waiman Long) [1548297]
- [arm64] arm64/vdso: Handle faults on timens page (Waiman Long) [1548297]
- [arm64] arm64/vdso: Add time namespace page (Waiman Long) [1548297]
- [arm64] arm64/vdso: Zap vvar pages when switching to a time namespace (Waiman Long) [1548297]
- [arm64] arm64/vdso: use the fault callback to map vvar pages (Waiman Long) [1548297]
- [arm64] arm64: compat: Allow 32-bit vdso and sigpage to co-exist (Waiman Long) [1548297]
- [x86] x86/vdso: Unbreak paravirt VDSO clocks (Waiman Long) [1548297]
- [lib] lib/vdso: Provide sanity check for cycles (again) (Waiman Long) [1548297]
- [kernel] clocksource: Remove obsolete ifdef (Waiman Long) [1548297]
- [tools] selftests/timens: handle a case when alarm clocks are not supported (Waiman Long) [1548297]
- [arm64] arm64: vdso: Add --eh-frame-hdr to ldflags (Waiman Long) [1548297]
- [arm64] arm64: vdso: Add -fasynchronous-unwind-tables to cflags (Waiman Long) [1548297]
- [arm64] arm64: vdso: use consistent 'map' nomenclature (Waiman Long) [1548297]
- [arm64] arm64: vdso: use consistent 'abi' nomenclature (Waiman Long) [1548297]
- [arm64] arm64: vdso: simplify arch_vdso_type ifdeffery (Waiman Long) [1548297]
- [arm64] arm64: vdso: remove aarch32_vdso_pages (Waiman Long) [1548297]
- [arm64] arm64: vdso: Add '-Bsymbolic' to ldflags (Waiman Long) [1548297]
- [x86] x86/vdso/vdso2c: Convert iterators to unsigned (Waiman Long) [1548297]
- [x86] x86/vdso/vdso2c: Correct error messages on file open (Waiman Long) [1548297]
- [include] vdso/datapage: Use correct clock mode name in comment (Waiman Long) [1548297]
- [arm64] arm64: vdso: don't free unallocated pages (Waiman Long) [1548297]
- [fs] proc, time/namespace: Show clock symbolic names in /proc/pid/timens_offsets (Waiman Long) [1548297]
- [kernel] time/namespace: Add max_time_namespaces ucount (Waiman Long) [1548297]
- [kernel] time/namespace: Fix time_for_children symlink (Waiman Long) [1548297]
- [arm64] arm64: compat: Fix syscall number of compat_clock_getres (Waiman Long) [1548297]
- [tools] selftests/timens: Remove duplicated include <time.h> (Waiman Long) [1548297]
- [kernel] sys/sysinfo: Respect boottime inside time namespace (Waiman Long) [1548297]
- [clocksource] clocksource/drivers/arm_arch_timer: Fix vDSO clockmode when vDSO disabled (Waiman Long) [1548297]
- [lib] lib/vdso: Enable common headers (Waiman Long) [1548297]
- [x86] x86/vdso: Enable x86 to use common headers (Waiman Long) [1548297]
- [arm64] arm64: vdso32: Include common headers in the vdso library (Waiman Long) [1548297]
- [arm64] arm64: vdso: Include common headers in the vdso library (Waiman Long) [1548297]
- [arm64] arm64: Introduce asm/vdso/processor.h (Waiman Long) [1548297]
- [arm64] arm64: vdso32: Code clean up (Waiman Long) [1548297]
- [include] linux/elfnote.h: Replace elf.h with UAPI equivalent (Waiman Long) [1548297]
- [include] common: Introduce processor.h (Waiman Long) [1548297]
- [include] linux/ktime.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/jiffies.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/time64.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/time32.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/time.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/math64.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/clocksource.h: Extract common header for vDSO (Waiman Long) [1548297]
- [arm64] arm64: Introduce asm/vdso/clocksource.h (Waiman Long) [1548297]
- [x86] x86: Introduce asm/vdso/clocksource.h (Waiman Long) [1548297]
- [include] linux/limits.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/bits.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/const.h: Extract common header for vDSO (Waiman Long) [1548297]
- [include] linux/bits.h: make BIT(), GENMASK(), and friends available in assembly (Waiman Long) [1548297]
- [lib] lib/vdso: Allow architectures to provide the vdso data pointer (Waiman Long) [1548297]
- [lib] lib/vdso: Allow architectures to override the ns shift operation (Waiman Long) [1548297]
- [lib] lib/vdso: Allow fixed clock mode (Waiman Long) [1548297]
- [include] lib/vdso: Move VCLOCK_TIMENS to vdso_clock_modes (Waiman Long) [1548297]
- [kernel] lib/vdso: Avoid highres update if clocksource is not VDSO capable (Waiman Long) [1548297]
- [lib] lib/vdso: Cleanup clock mode storage leftovers (Waiman Long) [1548297]
- [arm64] ARM/arm64: vdso: Use common vdso clock mode storage (Waiman Long) [1548297]
- [x86] x86/vdso: Use generic VDSO clock mode storage (Waiman Long) [1548297]
- [kernel] clocksource: Add common vdso clock mode storage (Waiman Long) [1548297]
- [x86] x86/vdso: Move VDSO clocksource state tracking to callback (Waiman Long) [1548297]
- [include] clocksource: Cleanup struct clocksource and documentation (Waiman Long) [1548297]
- [lib] lib/vdso: Allow the high resolution parts to be compiled out (Waiman Long) [1548297]
- [lib] lib/vdso: Only read hrtimer_res when needed in __cvdso_clock_getres() (Waiman Long) [1548297]
- [x86] x86/vdso: Mark the TSC clocksource path likely (Waiman Long) [1548297]
- [kernel] lib/vdso: Update coarse timekeeper unconditionally (Waiman Long) [1548297]
- [kernel] lib/vdso: Make __arch_update_vdso_data() logic understandable (Waiman Long) [1548297]
- [kernel] alarmtimer: Unregister wakeup source when module get fails (Waiman Long) [1548297]
- [tools] selftests/timens: Check for right timens offsets after fork and exec (Waiman Long) [1548297]
- [tools] selftests/timens: Add a simple perf test for clock_gettime() (Waiman Long) [1548297]
- [tools] selftests/timens: Add timer offsets test (Waiman Long) [1548297]
- [tools] selftests/timens: Add procfs selftest (Waiman Long) [1548297]
- [tools] selftests/timens: Add a test for clock_nanosleep() (Waiman Long) [1548297]
- [tools] selftests/timens: Add a test for timerfd (Waiman Long) [1548297]
- [tools] selftests/timens: Add Time Namespace test for supported clocks (Waiman Long) [1548297]
- [fs] fs/proc: Introduce /proc/pid/timens_offsets (Waiman Long) [1548297]
- [x86] x86/vdso: Zap vvar pages when switching to a time namespace (Waiman Long) [1548297]
- [x86] x86/vdso: On timens page fault prefault also VVAR page (Waiman Long) [1548297]
- [x86] x86/vdso: Handle faults on timens page (Waiman Long) [1548297]
- [kernel] time: Allocate per-timens vvar page (Waiman Long) [1548297]
- [x86] x86/vdso: Add time napespace page (Waiman Long) [1548297]
- [x86] x86/vdso: Provide vdso_data offset on vvar_page (Waiman Long) [1548297]
- [lib] lib/vdso: Prepare for time namespace support (Waiman Long) [1548297]
- [x86] x86/vdso: Restrict splitting VVAR VMA (Waiman Long) [1548297]
- [fs] fs/proc: Respect boottime inside time namespace for /proc/uptime (Waiman Long) [1548297]
- [kernel] posix-timers: Make clock_nanosleep() time namespace aware (Waiman Long) [1548297]
- [kernel] hrtimers: Prepare hrtimer_nanosleep() for time namespaces (Waiman Long) [1548297]
- [kernel] alarmtimer: Make nanosleep() time namespace aware (Waiman Long) [1548297]
- [kernel] posix-timers: Make timer_settime() time namespace aware (Waiman Long) [1548297]
- [fs] timerfd: Make timerfd_settime() time namespace aware (Waiman Long) [1548297]
- [kernel] time: Add do_timens_ktime_to_host() helper (Waiman Long) [1548297]
- [kernel] posix-clocks: Wire up clock_gettime() with timens offsets (Waiman Long) [1548297]
- [kernel] posix-timers: Use clock_get_ktime() in common_timer_get() (Waiman Long) [1548297]
- [kernel] posix-clocks: Introduce clock_get_ktime() callback (Waiman Long) [1548297]
- [kernel] alarmtimer: Provide get_timespec() callback (Waiman Long) [1548297]
- [kernel] alarmtimer: Rename gettime() callback to get_ktime() (Waiman Long) [1548297]
- [kernel] posix-clocks: Rename .clock_get_timespec() callbacks accordingly (Waiman Long) [1548297]
- [kernel] posix-clocks: Rename the clock_get() callback to clock_get_timespec() (Waiman Long) [1548297]
- [kernel] time: Add timens_offsets to be used for tasks in time namespace (Waiman Long) [1548297]
- [kernel] ns: Introduce Time Namespace (Waiman Long) [1548297]
- [lib] lib/vdso: Mark do_hres() and do_coarse() as __always_inline (Waiman Long) [1548297]
- [lib] lib/vdso: Avoid duplication in __cvdso_clock_getres() (Waiman Long) [1548297]
- [lib] lib/vdso: Let do_coarse() return 0 to simplify the callsite (Waiman Long) [1548297]
- [x86] x86/vdso: Remove unused VDSO_HAS_32BIT_FALLBACK (Waiman Long) [1548297]
- [arm64] arm64: compat: vdso: Remove unused VDSO_HAS_32BIT_FALLBACK (Waiman Long) [1548297]
- [lib] lib/vdso: Remove checks on return value for 32 bit vDSO (Waiman Long) [1548297]
- [lib] lib/vdso: Remove VDSO_HAS_32BIT_FALLBACK (Waiman Long) [1548297]
- [arm64] arm64: compat: vdso: Expose BUILD_VDSO32 (Waiman Long) [1548297]
- [include] lib/vdso: Add unlikely() hint into vdso_read_begin() (Waiman Long) [1548297]
- [x86] y2038: vdso: change time_t to __kernel_old_time_t (Waiman Long) [1548297]
- [uapi] y2038: add __kernel_old_timespec and __kernel_old_time_t (Waiman Long) [1548297]
- [arm64] timekeeping/vsyscall: Update VDSO data unconditionally (Waiman Long) [1548297]
- [x86] um: Fix VDSO compiler warning (Waiman Long) [1548297]
- [kernel] timekeeping/vsyscall: Prevent math overflow in BOOTTIME update (Waiman Long) [1548297]
- [arm64] arm64: compat: vdso: Use legacy syscalls as fallback (Waiman Long) [1548297]
- [x86] x86/vdso/32: Use 32bit syscall fallback (Waiman Long) [1548297]
- [arm64] arm64: vdso: Cleanup Makefiles (Waiman Long) [1548297]
- [arm64] arm64: vdso: fix flip/flop vdso build bug (Waiman Long) [1548297]
- [x86] x86/vdso: Fix flip/flop vdso build bug (Waiman Long) [1548297]
- [kernel] timekeeping/vsyscall: Use __iter_div_u64_rem() (Waiman Long) [1548297]
- [arm64] arm64: compat: Fix __arch_get_hw_counter() implementation (Waiman Long) [1548297]
- [arm64] arm64: Fix __arch_get_hw_counter() implementation (Waiman Long) [1548297]
- [arm64] arm64: compat: No need for pre-ARMv7 barriers on an ARMv8 system (Waiman Long) [1548297]
- [arm64] arm64: vdso: Remove unnecessary asm-offsets.c definitions (Waiman Long) [1548297]
- [include] vdso: Remove superfluous #ifdef __KERNEL__ in vdso/datapage.h (Waiman Long) [1548297]
- [arm64] arm64: vdso: Enable vDSO compat support (Waiman Long) [1548297]
- [arm64] arm64: compat: Get sigreturn trampolines from vDSO (Waiman Long) [1548297]
- [arm64] arm64: elf: VDSO code page discovery (Waiman Long) [1548297]
- [arm64] arm64: compat: VDSO setup for compat layer (Waiman Long) [1548297]
- [arm64] arm64: vdso: Refactor vDSO code (Waiman Long) [1548297]
- [arm64] arm64: compat: Add vDSO (Waiman Long) [1548297]
- [arm64] arm64: compat: Generate asm offsets for signals (Waiman Long) [1548297]
- [arm64] arm64: compat: Expose signal related structures (Waiman Long) [1548297]
- [arm64] arm64: compat: Add missing syscall numbers (Waiman Long) [1548297]
- [arm64] arm64: vdso: Build vDSO with -ffixed-x18 (Waiman Long) [1548297]
- [arm64] arm64: vdso: Substitute gettimeofday() with C implementation (Waiman Long) [1548297]
- [lib] lib/vdso: Build 32 bit specific functions in the right context (Waiman Long) [1548297]
- [lib] lib/vdso: Make __cvdso_clock_getres() static (Waiman Long) [1548297]
- [lib] lib/vdso: Make clock_getres() POSIX compliant again (Waiman Long) [1548297]
- [lib] lib/vdso/32: Provide legacy syscall fallbacks (Waiman Long) [1548297]
- [lib] lib/vdso: Move fallback invocation to the callers (Waiman Long) [1548297]
- [lib] lib/vdso/32: Remove inconsistent NULL pointer checks (Waiman Long) [1548297]
- [x86] lib/vdso: Make delta calculation work correctly (Waiman Long) [1548297]
- [x86] x86/vdso: Add clock_gettime64() entry point (Waiman Long) [1548297]
- [x86] x86/vdso: Add clock_getres() entry point (Waiman Long) [1548297]
- [x86] x86/vdso: Switch to generic vDSO implementation (Waiman Long) [1548297]
- [x86] x86/vdso: Prevent segfaults due to hoisted vclock reads (Waiman Long) [1548297]
- [kernel] timekeeping: Provide a generic update_vsyscall() implementation (Waiman Long) [1548297]
- [lib] lib/vdso: Add compat support (Waiman Long) [1548297]
- [lib] lib/vdso: Provide generic VDSO implementation (Waiman Long) [1548297]
- [include] hrtimer: Split out hrtimer defines into separate header (Waiman Long) [1548297]
- [include] vdso: Define standardized vdso_datapage (Waiman Long) [1548297]
- [arm64] arm64: arch_timer: mark functions as __always_inline (Waiman Long) [1548297]
- [x86] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 223 (Waiman Long) [1548297]
- [clocksource] clocksource/drivers/arm_arch_timer: Don't trace count reader functions (Waiman Long) [1548297]
- [arm64] arm64: vdso: Explicitly add build-id option (Waiman Long) [1548297]
- [x86] gcc-9: properly declare the {pv, hv}clock_page storage (Waiman Long) [1548297]
- [arm64] arm64: vdso: Fix clock_getres() for CLOCK_REALTIME (Waiman Long) [1548297]
- [arm64] arm64: compat: Refactor aarch32_alloc_vdso_pages() (Waiman Long) [1548297]
- [arm64] arm64: compat: Split kuser32 (Waiman Long) [1548297]
- [arm64] arm64: compat: Alloc separate pages for vectors and sigpage (Waiman Long) [1548297]
- [arm64] arm64: arch_timer: Ensure counter register reads occur with seqlock held (Waiman Long) [1548297]
- [clocksource] clocksource/arm_arch_timer: Use arch_timer_read_counter to access stable counters (Waiman Long) [1548297]
- [clocksource] clocksource/arm_arch_timer: Remove use of workaround static key (Waiman Long) [1548297]
- [arm64] clocksource/arm_arch_timer: Drop use of static key in arch_timer_reg_read_stable (Waiman Long) [1548297]
- [clocksource] clocksource/arm_arch_timer: Direcly assign set_next_event workaround (Waiman Long) [1548297]
- [arm64] arm64: Use arch_timer_read_counter instead of arch_counter_get_cntvct (Waiman Long) [1548297]
- [watchdog] watchdog/sbsa: Use arch_timer_read_counter instead of arch_counter_get_cntvct (Waiman Long) [1548297]
- [kernel] alarmtimer: Return correct remaining time (Waiman Long) [1548297]
- [arm64] arm64: vdso: use $(LD) instead of $(CC) to link VDSO (Waiman Long) [1548297]
- [arm64] arm64: vdso: fix and clean-up Makefile (Waiman Long) [1548297]
- [x86] x86/vdso: Remove hpet_page from vDSO (Waiman Long) [1548297]
- [scripts] checksyscalls: fix up mq_timedreceive and stat exceptions (Waiman Long) [1548297]
- [uapi] time: Add time_types.h (Waiman Long) [1548297]
- [uapi] socket: Add struct __kernel_sock_timeval (Waiman Long) [1548297]
- [arm64] arm64: asm-offsets: remove unused offsets (Waiman Long) [1548297]
- [arm64] y2038: add 64-bit time_t syscalls to all 32-bit architectures (Waiman Long) [1548297]
- [arm64] arm64: replace arm64-obj-* in Makefile with obj-* (Waiman Long) [1548297]
- [x86] x86/vdso: Remove obsolete "fake section table" reservation (Waiman Long) [1548297]
- [x86] x86/vdso: Rename variable to fix -Wshadow warning (Waiman Long) [1548297]
- [x86] x86/vdso: Rearrange do_hres() to improve code generation (Waiman Long) [1548297]
- [x86] x86/vdso: Document vgtod_ts better (Waiman Long) [1548297]
- [x86] x86/vdso: Remove "memory" clobbers in the vDSO syscall fallbacks (Waiman Long) [1548297]
- [x86] x86/vdso: Initialize the CPU/node NR segment descriptor earlier (Waiman Long) [1548297]
- [x86] x86/vdso: Introduce helper functions for CPU and node number (Waiman Long) [1548297]
- [x86] x86/segments/64: Rename the GDT PER_CPU entry to CPU_NUMBER (Waiman Long) [1548297]
- [x86] x66/vdso: Add CLOCK_TAI support (Waiman Long) [1548297]
- [x86] x86/vdso: Move cycle_last handling into the caller (Waiman Long) [1548297]
- [x86] x86/vdso: Simplify the invalid vclock case (Waiman Long) [1548297]
- [x86] x86/vdso: Replace the clockid switch case (Waiman Long) [1548297]
- [x86] x86/vdso: Collapse coarse functions (Waiman Long) [1548297]
- [x86] x86/vdso: Collapse high resolution functions (Waiman Long) [1548297]
- [x86] x86/vdso: Introduce and use vgtod_ts (Waiman Long) [1548297]
- [x86] x86/vdso: Use unsigned int consistently for vsyscall_gtod_data:: Seq (Waiman Long) [1548297]
- [x86] x86/vdso: Enforce 64bit clocksource (Waiman Long) [1548297]
- [x86] x86/time: Implement clocksource_arch_init() (Waiman Long) [1548297]
- [kernel] clocksource: Provide clocksource_arch_init() (Waiman Long) [1548297]
- [fs] fs/proc/uptime.c: use ktime_get_boottime_ts64 (Waiman Long) [1548297]
- [include] y2038: Provide aliases for compat helpers (Waiman Long) [1548297]
- [fs] kernel: add kcompat_sys_{f,}statfs64() (Waiman Long) [1548297]
- [kernel] sysinfo: Remove get_monotonic_boottime() (Waiman Long) [1548297]
- [kernel] posix-timers: Use new ktime_get_*_ts64() helpers (Waiman Long) [1548297]
- [kernel] time: Use ktime_get_real_seconds() in time syscall (Waiman Long) [1548297]
- [include] time: Introduce struct __kernel_itimerspec (Waiman Long) [1548297]
- [scripts] kconfig: improve the recursive dependency report (Bruno Meneguele) [1890578]
- [scripts] kconfig: report recursive dependency involving 'imply' (Bruno Meneguele) [1890578]
- [scripts] kconfig: error out when seeing recursive dependency (Bruno Meneguele) [1890578]
- [scsi] scsi: hpsa: Update copyright (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Remove pci-dma-compat wrapper API (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Use fallthrough pseudo-keyword (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Correct ctrl queue depth (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Bump version (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Increase controller error handling timeout (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Increase queue depth for external LUNs (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Correct rare oob condition (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: hpsa_ioctl(): Tidy up a bit (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Get rid of compat_alloc_user_space() (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Don't bother with vmalloc for BIG_IOCTL_Command_struct (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: Lift {BIG_, }IOCTL_Command_struct copy{in, out} into hpsa_ioctl() (Joseph Szczypek) [1861541]
- [scsi] scsi: hpsa: remove ioremap_nocache and devm_ioremap_nocache (Joseph Szczypek) [1861541]
- [tools] selftests/powerpc: Make alignment handler test P9N DD2.1 vector CI load workaround (Gustavo Duarte) [1887442]
- [powerpc] powerpc: Fix undetected data corruption with P9N DD2.1 VSX CI load emulation (Gustavo Duarte) [1887442]
- [scsi] scsi: smartpqi: Update copyright (Don Brace) [1861538]
- [scsi] scsi: smartpqi: Bump version to 1.2.16-010 (Don Brace) [1861538]
- [scsi] scsi: smartpqi: Add RAID bypass counter (Don Brace) [1861538]
- [scsi] scsi: smartpqi: Avoid crashing kernel for controller issues (Don Brace) [1861538]
- [scsi] scsi: smartpqi: Update logical volume size after expansion (Don Brace) [1861538]
- [scsi] scsi: smartpqi: Add id support for SmartRAID 3152-8i (Don Brace) [1861538]
- [scsi] scsi: smartpqi: Identify physical devices without issuing INQUIRY (Don Brace) [1861538]
- [mm] mm: simplify find_min_pfn_with_active_regions() (Baoquan He) [1844157]
- [mm] mm: clean up free_area_init_node() and its helpers (Baoquan He) [1844157]
- [mm] mm: rename free_area_init_node() to free_area_init_memoryless_node() (Baoquan He) [1844157]
- [mm] mm: free_area_init: allow defining max_zone_pfn in descending order (Baoquan He) [1844157]
- [powerpc] mm: remove early_pfn_in_nid() and CONFIG_NODES_SPAN_OTHER_NODES (Baoquan He) [1844157]
- [mm] mm: memmap_init: iterate over memblock regions rather that check each PFN (Baoquan He) [1844157]
- [mm] arm64: simplify detection of memory zone boundaries for UMA configs (Baoquan He) [1844157]
- [mm] mm: use free_area_init() instead of free_area_init_nodes() (Baoquan He) [1844157]
- [mm] mm: free_area_init: use maximal zone PFNs rather than zone sizes (Baoquan He) [1844157]
- [mm] mm: remove CONFIG_HAVE_MEMBLOCK_NODE_MAP option (Baoquan He) [1844157]
- [mm] numa: make "nr_node_ids" unsigned int (Baoquan He) [1844157]
- [mm] mm: make early_pfn_to_nid() and related defintions close to each other (Baoquan He) [1844157]
- [mm] mm: memblock: replace dereferences of memblock_region.nid with API calls (Baoquan He) [1844157]
- [mm] mm: factor out next_present_section_nr() (Baoquan He) [1844157]
- [mm] mm/page_alloc: fix and rework pfn handling in memmap_init_zone() (Baoquan He) [1844157]
- [mm] mm/page_alloc: skip non present sections on zone initialization (Baoquan He) [1844157]
- [mm] mm: move mirrored memory specific code outside of memmap_init_zone (Baoquan He) [1844157]
- [mm] mm: calculate deferred pages after skipping mirrored memory (Baoquan He) [1844157]
- [mm] mm/memblock.c: fix a typo in __next_mem_pfn_range() comments (Baoquan He) [1844157]
- [mm] memblock: remove memblock_{set, clear}_region_flags (Baoquan He) [1844157]
- [mm] mm: replace all open encodings for NUMA_NO_NODE (Baoquan He) [1844157]
- [powerpc] lockdep: Only trace IRQ edges (Waiman Long) [1885084]
- [arm64] arm64: Implement arch_irqs_disabled() (Waiman Long) [1885084]
- [include] locking/lockdep: Cleanup (Waiman Long) [1885084]
- [include] lockdep: Use raw_cpu_*() for per-cpu variables (Waiman Long) [1885084]
- [x86] locking/seqlock, headers: Untangle the spaghetti monster (Waiman Long) [1885084]
- [misc] vmw_balloon: Explicitly include linux/io.h for virt_to_phys() (Waiman Long) [1885084]
- [x86] x86: i8259: Add missing include file (Waiman Long) [1885084]
- [include] seqcount: More consistent seqprop names (Waiman Long) [1885084]
- [include] seqcount: Compress SEQCNT_LOCKNAME_ZERO() (Waiman Long) [1885084]
- [include] seqlock: Fold seqcount_LOCKNAME_init() definition (Waiman Long) [1885084]
- [include] seqlock: Fold seqcount_LOCKNAME_t definition (Waiman Long) [1885084]
- [include] seqlock: s/__SEQ_LOCKDEP/__SEQ_LOCK/g (Waiman Long) [1885084]
- [kernel] hrtimer: Use sequence counter with associated raw spinlock (Waiman Long) [1885084]
- [kernel] timekeeping: Use sequence counter with associated raw spinlock (Waiman Long) [1885084]
- [kernel] timekeeping: Use proper seqcount initializer (Waiman Long) [1885084]
- [init] sched: tasks: Use sequence counter with associated spinlock (Waiman Long) [1885084]
- [kernel] lockdep: Refactor IRQ trace events fields into struct (Waiman Long) [1885084]
- [drm] dma-buf: Use sequence counter with associated wound/wait mutex (Waiman Long) [1885084]
- [dma-buf] dma-buf: Remove custom seqcount lockdep class key (Waiman Long) [1885084]
- [include] seqlock: Align multi-line macros newline escapes at 72 columns (Waiman Long) [1885084]
- [documentation] seqlock: Extend seqcount API with associated locks (Waiman Long) [1885084]
- [include] seqlock: lockdep assert non-preemptibility on seqcount_t write (Waiman Long) [1885084]
- [lib] lockdep: Add preemption enabled/disabled assertion APIs (Waiman Long) [1885084]
- [include] seqlock: Implement raw_seqcount_begin() in terms of raw_read_seqcount() (Waiman Long) [1885084]
- [include] seqlock: Add kernel-doc for seqcount_t and seqlock_t APIs (Waiman Long) [1885084]
- [include] seqlock: Reorder seqcount_t and seqlock_t API definitions (Waiman Long) [1885084]
- [include] seqlock: seqcount_t latch: End read sections with read_seqcount_retry() (Waiman Long) [1885084]
- [include] seqlock: Properly format kernel-doc code samples (Waiman Long) [1885084]
- [documentation] Documentation: locking: Describe seqlock design and usage (Waiman Long) [1885084]
- [include] seqlock: Require WRITE_ONCE surrounding raw_seqcount_barrier (Waiman Long) [1885084]
- [include] seqlock, kcsan: Add annotations for KCSAN (Waiman Long) [1885084]
- [include] include/linux/compiler.h: Introduce data_race(expr) macro (Waiman Long) [1885084]
- [kernel] kcsan: Add Kernel Concurrency Sanitizer infrastructure (Waiman Long) [1885084]
- [include] locking/qspinlock: Do not include atomic.h from qspinlock_types.h (Waiman Long) [1885084]
- [include] locking/atomic: Move ATOMIC_INIT into linux/types.h (Waiman Long) [1885084]
- [connector] connector/cn_proc: Protect send_msg() with a local lock (Waiman Long) [1885084]
- [mm] mm/swap: Use local_lock for protection (Waiman Long) [1885084]
- [include] radix-tree: Use local_lock for protection (Waiman Long) [1885084]
- [include] locking: Introduce local_lock() (Waiman Long) [1885084]
- [documentation] Documentation/locking/locktypes: Minor copy editor fixes (Waiman Long) [1885084]
- [documentation] Documentation/locking/locktypes: Further clarifications and wordsmithing (Waiman Long) [1885084]
- [documentation] Documentation: Add lock ordering and nesting documentation (Waiman Long) [1885084]
- [mm] mm/swap.c: trivial mark_page_accessed() cleanup (Waiman Long) [1885084]
- [lib] radix tree: Remove radix_tree_maybe_preload_order (Waiman Long) [1885084]
- [kernel] locking/lockdep: Fix "USED" <- "IN-NMI" inversions (Waiman Long) [1885084]
- [kernel] lockdep: Remove lockdep_hardirq{s_enabled, _context}() argument (Waiman Long) [1885084]
- [kernel] lockdep: Change hardirq{s_enabled, _context} to per-cpu variables (Waiman Long) [1885084]
- [kernel] x86/entry: Rename trace_hardirqs_off_prepare() (Waiman Long) [1885084]
- [kernel] lockdep: Prepare for NMI IRQ state tracking (Waiman Long) [1885084]
- [include] lockdep: Move list.h inclusion into lockdep.h (Waiman Long) [1885084]
- [include] lockdep: Split header file into lockdep and lockdep_types (Waiman Long) [1885084]
- [kernel] lockdep: __always_inline more for noinstr (Waiman Long) [1885084]
- [kernel] lockdep: Prepare for noinstr sections (Waiman Long) [1885084]
- [kernel] tracing: Provide lockdep less trace_hardirqs_on/off() variants (Waiman Long) [1885084]
- [include] vmlinux.lds.h: Create section for protection against instrumentation (Waiman Long) [1885084]
- [kernel] locking/lockdep: Replace zero-length array with flexible-array (Waiman Long) [1885084]
- [kernel] hrtimer: Don't dereference the hrtimer pointer after the callback (Waiman Long) [1885084]
- [kernel] hrtimer: Add missing sparse annotation for __run_timer() (Waiman Long) [1885084]
- [kernel] lockdep: Always inline lockdep_{off,on}() (Waiman Long) [1885084]
- [kernel] locking/lockdep: Improve 'invalid wait context' splat (Waiman Long) [1885084]
- [kernel] lockdep: Rename trace_{hard, soft}{irq_context, irqs_enabled}() (Waiman Long) [1885084]
- [kernel] lockdep: Rename trace_softirqs_{on,off}() (Waiman Long) [1885084]
- [kernel] lockdep: Rename trace_hardirq_{enter, exit}() (Waiman Long) [1885084]
- [kernel] completion: Use lockdep_assert_RT_in_threaded_ctx() in complete_all() (Waiman Long) [1885084]
- [usb] completion: Use simple wait queues (Waiman Long) [1885084]
- [kernel] sched/swait: Prepare usage in completions (Waiman Long) [1885084]
- [kernel] lockdep: Add posixtimer context tracing bits (Waiman Long) [1885084]
- [kernel] lockdep: Annotate irq_work (Waiman Long) [1885084]
- [kernel] lockdep: Add hrtimer context tracing bits (Waiman Long) [1885084]
- [include] lockdep: Introduce wait-type checks (Waiman Long) [1885084]
- [kernel] lockdep: Teach lockdep about "USED" <- "IN-NMI" inversions (Waiman Long) [1885084]
- [kernel] locking/lockdep: Rework lockdep_lock (Waiman Long) [1885084]
- [kernel] locking/lockdep: Fix bad recursion pattern (Waiman Long) [1885084]
- [s390] s390/ftrace: fix endless recursion in function_graph tracer (Waiman Long) [1885084]
- [s390] s390/time: ensure get_clock_monotonic() returns monotonic values (Waiman Long) [1885084]
- [kernel] irq_work: Fix IRQ_WORK_BUSY bit clearing (Waiman Long) [1885084]
- [kernel] irq_work: Slightly simplify IRQ_WORK_PENDING clearing (Waiman Long) [1885084]
- [kernel] irq_work: Fix irq_work_claim() memory ordering (Waiman Long) [1885084]
- [kernel] irq_work: Convert flags to atomic_t (Waiman Long) [1885084]
- [kernel] kprobes: Prohibit probing on lockdep functions (Waiman Long) [1885084]
- [kernel] kprobes: Prohibit probing on hardirq tracers (Waiman Long) [1885084]
- [lib] locking/lockdep: Make global debug_locks* variables read-mostly (Waiman Long) [1885084]
- [kernel] locking/lockdep: Delete unnecessary #include (Waiman Long) [1885084]
- [kernel] tracing: More reverting of "tracing: Centralize preemptirq tracepoints and unify their usage" (Waiman Long) [1885084]
- [kernel] tracing/irqsoff: Handle preempt_count for different configs (Waiman Long) [1885084]
- [kernel] tracing: Partial revert of "tracing: Centralize preemptirq tracepoints and unify their usage" (Waiman Long) [1885084]
- [kernel] tracing: irqsoff: Account for additional preempt_disable (Waiman Long) [1885084]
- [kernel] tracing: Centralize preemptirq tracepoints and unify their usage (Waiman Long) [1885084]
- [kernel] tracing/irqsoff: Split reset into separate functions (Waiman Long) [1885084]
- [kernel] sched/fair: Use dst group while checking imbalance for NUMA balancer (Phil Auld) [1877360]
- [kernel] sched/fair: Reduce busy load balance interval (Phil Auld) [1877360]
- [kernel] sched/fair: Reduce minimal imbalance threshold (Phil Auld) [1877360]
- [kernel] sched/fair: Minimize concurrent LBs between domain level (Phil Auld) [1877360]
- [kernel] sched/fair: Fix wrong cpu selecting from isolated domain (Phil Auld) [1877360]
- [kernel] sched/fair: Relax constraint on task's load during load balance (Phil Auld) [1877360]
- [kernel] sched/numa: Use runnable_avg to classify node (Phil Auld) [1877360]
- [kernel] sched: Remove duplicated tick_nohz_full_enabled() check (Phil Auld) [1877360]
- [kernel] sched: Warn if garbage is passed to default_wake_function() (Phil Auld) [1877360]
- [kernel] sched: nohz: stop passing around unused "ticks" parameter (Phil Auld) [1877360]
- [kernel] sched/fair: update_pick_idlest() Select group with lowest group_util when idle_cpus are equal (Phil Auld) [1877360]
- [kernel] sched: Better document ttwu() (Phil Auld) [1877360]
- [kernel] sched/fair: handle case of task_h_load() returning 0 (Phil Auld) [1877360]
- [kernel] sched: Fix unreliable rseq cpu_id for new tasks (Phil Auld) [1877360]
- [kernel] sched/core: s/WF_ON_RQ/WQ_ON_CPU/ (Phil Auld) [1877360]
- [include] sched/core: Remove mmdrop() definition (Phil Auld) [1877360]
- [kernel] sched/fair: Optimize dequeue_task_fair() (Phil Auld) [1877360]
- [kernel] sched/pelt: Cleanup PELT divider (Phil Auld) [1877360]
- [kernel] sched/fair: Fix NOHZ next idle balance (Phil Auld) [1877360]
- [kernel] sched: correct SD_flags returned by tl->sd_flags() (Phil Auld) [1877360]
- [kernel] sched/fair: Remove unused 'sd' parameter from scale_rt_capacity() (Phil Auld) [1877360]
- [kernel] sched/idle, stop: Remove .get_rr_interval from sched_class (Phil Auld) [1877360]
- [kernel] sched/core: Remove redundant 'preempt' param from sched_class->yield_to_task() (Phil Auld) [1877360]
- [kernel] sched/pelt: Remove redundant cap_scale() definition (Phil Auld) [1877360]
- [kernel] sched/pelt: Sync util/runnable_sum with PELT window when propagating (Phil Auld) [1877360]
- [kernel] sched/cpuacct: Fix charge cpuacct.usage_sys (Phil Auld) [1877360]
- [kernel] sched/cpuacct: Use __this_cpu_add() instead of this_cpu_ptr() (Phil Auld) [1877360]
- [kernel] sched/fair: Fix unthrottle_cfs_rq() for leaf_cfs_rq list (Phil Auld) [1877360]
- [kernel] sched/core: Simplify sched_init() (Phil Auld) [1877360]
- [kernel] sched/fair: Mark sched_init_granularity __init (Phil Auld) [1877360]
- [kernel] sched/core: Fix illegal RCU from offline CPUs (Phil Auld) [1877360]
- [kernel] sched/fair: Use __this_cpu_read() in wake_wide() (Phil Auld) [1877360]
- [kernel] sched: Extract the task putting code from pick_next_task() (Phil Auld) [1877360]
- [kernel] sched: Make newidle_balance() static again (Phil Auld) [1877360]
- [kernel] sched/fair: Remove distribute_running from CFS bandwidth (Phil Auld) [1877360]
- [kernel] sched/fair: Simplify the code of should_we_balance() (Phil Auld) [1877360]
- [kernel] sched/debug: Fix trival print_task() format (Phil Auld) [1877360]
- [kernel] sched/debug: Factor out printing formats into common macros (Phil Auld) [1877360]
- [kernel] sched/debug: Remove redundant macro define (Phil Auld) [1877360]
- [kernel] sched/core: Remove unused rq::last_load_update_tick (Phil Auld) [1877360]
- [kernel] sched/fair: Align rq->avg_idle and rq->avg_scan_cost (Phil Auld) [1877360]
- [kernel] sched/fair: Improve spreading of utilization (Phil Auld) [1877360]
- [kernel] sched/fair: Fix condition of avg_load calculation (Phil Auld) [1877360]
- [kernel] kthread: Do not preempt current task if it is going to call schedule() (Phil Auld) [1877360]
- [kernel] sched/core: Distribute tasks within affinity masks (Phil Auld) [1877360]
- [kernel] time/sched_clock: Expire timer in hardirq context (Phil Auld) [1877360]
- [kernel] sched/deadline: Make two functions static (Phil Auld) [1877360]
- [mm] slab: store tagged freelist for off-slab slabmgmt (Waiman Long) [1887067]
- [mm] mm/kasan: fix false positive invalid-free reports with CONFIG_KASAN_SW_TAGS=y (Waiman Long) [1887067]
- [arm64] arm64: avoid clang warning about self-assignment (Waiman Long) [1887067]
- [mm] kasan: add memory corruption identification for software tag-based mode (Waiman Long) [1887067]
- [mm] mm/kasan: print frame description for stack bugs (Waiman Long) [1887067]
- [mm] kasan: initialize tag to 0xff in __kasan_kmalloc (Waiman Long) [1887067]
- [mm] kasan: Makefile: Replace -pg with CC_FLAGS_FTRACE (Waiman Long) [1887067]
- [mm] x86/uaccess, kasan: Fix KASAN vs SMAP (Waiman Long) [1887067]
- [mm] mm/kasan: Simplify stacktrace handling (Waiman Long) [1887067]
- [mm] kasan: fix variable 'tag' set but not used warning (Waiman Long) [1887067]
- [mm] slub: fix a crash with SLUB_DEBUG + KASAN_SW_TAGS (Waiman Long) [1887067]
- [mm] kasan, slab: remove redundant kasan_slab_alloc hooks (Waiman Long) [1887067]
- [mm] kasan, slab: make freelist stored without tags (Waiman Long) [1887067]
- [mm] kasan, slab: fix conflicts with CONFIG_HARDENED_USERCOPY (Waiman Long) [1887067]
- [mm] kasan: prevent tracing of tags.c (Waiman Long) [1887067]
- [mm] kasan: fix random seed generation for tag-based mode (Waiman Long) [1887067]
- [mm] slub: fix SLAB_CONSISTENCY_CHECKS + KASAN_SW_TAGS (Waiman Long) [1887067]
- [mm] kasan, slub: fix more conflicts with CONFIG_SLAB_FREELIST_HARDENED (Waiman Long) [1887067]
- [mm] kasan, slub: fix conflicts with CONFIG_SLAB_FREELIST_HARDENED (Waiman Long) [1887067]
- [mm] kasan, slub: move kasan_poison_slab hook before page_address (Waiman Long) [1887067]
- [mm] kmemleak: account for tagged pointers when calculating pointer range (Waiman Long) [1887067]
- [mm] kasan, kmemleak: pass tagged pointers to kmemleak (Waiman Long) [1887067]
- [mm] kasan: fix assigning tags twice (Waiman Long) [1887067]
- [mm] kasan: mark file common so ftrace doesn't trace it (Waiman Long) [1887067]
- [mm] kasan: fix krealloc handling for tag-based mode (Waiman Long) [1887067]
- [mm] kasan: make tag based mode work with CONFIG_HARDENED_USERCOPY (Waiman Long) [1887067]
- [arm64] kasan, arm64: use ARCH_SLAB_MINALIGN instead of manual aligning (Waiman Long) [1887067]
- [mm] kasan: add SPDX-License-Identifier mark to source files (Waiman Long) [1887067]
- [documentation] kasan: update documentation (Waiman Long) [1887067]
- [arm64] kasan, arm64: select HAVE_ARCH_KASAN_SW_TAGS (Waiman Long) [1887067]
- [mm] kasan: add __must_check annotations to kasan hooks (Waiman Long) [1887067]
- [mm] kasan, mm, arm64: tag non slab memory allocated via pagealloc (Waiman Long) [1887067]
- [arm64] kasan, arm64: add brk handler for inline instrumentation (Waiman Long) [1887067]
- [mm] kasan: add hooks implementation for tag-based mode (Waiman Long) [1887067]
- [mm] kasan: add bug reporting routines for tag-based mode (Waiman Long) [1887067]
- [mm] kasan: split out generic_report.c from report.c (Waiman Long) [1887067]
- [mm] kasan, mm: perform untagged pointers comparison in krealloc (Waiman Long) [1887067]
- [mm] kasan, arm64: enable top byte ignore for the kernel (Waiman Long) [1887067]
- [mm] kasan, arm64: fix up fault handling logic (Waiman Long) [1887067]
- [mm] kasan: preassign tags to objects with ctors or SLAB_TYPESAFE_BY_RCU (Waiman Long) [1887067]
- [arm64] kasan, arm64: untag address in _virt_addr_is_linear (Waiman Long) [1887067]
- [arm64] kasan: add tag related helper functions (Waiman Long) [1887067]
- [mm] kasan: initialize shadow to 0xff for tag-based mode (Waiman Long) [1887067]
- [mm] kasan: rename kasan_zero_page to kasan_early_shadow_page (Waiman Long) [1887067]
- [arm64] kasan, arm64: adjust shadow size for tag-based mode (Waiman Long) [1887067]
- [mm] kasan: add CONFIG_KASAN_GENERIC and CONFIG_KASAN_SW_TAGS (Waiman Long) [1887067]
- [mm] kasan: rename source files to reflect the new naming scheme (Waiman Long) [1887067]
- [mm] kasan: move common generic and tag-based code to common.c (Waiman Long) [1887067]
- [mm] kasan, slub: handle pointer tags in early_kmem_cache_node_alloc (Waiman Long) [1887067]
- [mm] kasan, mm: change hooks signatures (Waiman Long) [1887067]
- [arm64] arm64: kasan: Increase stack size for KASAN_EXTRA (Waiman Long) [1887067]
- [s390] s390/cio: add cond_resched() in the slow_eval_known_fn() loop (Claudio Imbrenda) [1885961]
- [s390] scsi: zfcp: fix missing erp_lock in port recovery trigger for point-to-point (Claudio Imbrenda) [1885876]
- [tools] selftests/vm/gup_benchmark.c: match gup struct to kernel (Rafael Aquini) [1873952]
- [uapi] redhat: Fix the number of KVM_CAP_S390_DIAG318 (Thomas Huth) [1659413]
- [s390] setup: diag 318: refactor struct (Thomas Huth) [1659413]
- [s390] kvm: diagnose 0x318 sync and reset (Thomas Huth) [1659413]
- [mm] swap: reduce lock contention on swap cache from swap slots allocation (Nico Pache) [1839049]
- [mm] mm/swapfile.c: use prandom_u32_max() (Nico Pache) [1839049]
- [mm] swap: try to scan more free slots even when fragmented (Nico Pache) [1839049]
- [mm] mm/swapfile.c: move inode_lock out of claim_swapfile (Nico Pache) [1839049]
- [mm] vfs: don't allow writes to swap files (Nico Pache) [1839049]
- [mm] mm: set S_SWAPFILE on blockdev swap devices (Nico Pache) [1839049]
- [edac] EDAC/ie31200: Add Intel Coffee Lake CPU support (Aristeu Rozanski) [1847567]

* Wed Nov 11 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-248.el8]
- [netdrv] macsec: avoid use-after-free in macsec_handle_frame() (Balazs Nemeth) [1890122]
- [include] netlink: check for null extack in cookie helpers (Ivan Vecera) [1878274]
- [net] ethtool: Don't omit the netlink reply if no features were changed (Ivan Vecera) [1878274]
- [net] ethtool: Account for hw_features in netlink interface (Ivan Vecera) [1878274]
- [net] ethtool: Fix preserving of wanted feature bits in netlink interface (Ivan Vecera) [1878274]
- [net] ethtool: ethnl_set_linkmodes: remove redundant null check (Ivan Vecera) [1878274]
- [net] ethtool: fix genlmsg_put() failure handling in ethnl_default_dumpit() (Ivan Vecera) [1878274]
- [net] ethtool: add missing string for NETIF_F_GSO_TUNNEL_REMCSUM (Ivan Vecera) [1878274]
- [net] ethtool: Fix check in ethtool_rx_flow_rule_create (Ivan Vecera) [1878274]
- [net] ethtool: linkinfo: remove an unnecessary NULL check (Ivan Vecera) [1878274]
- [net] ethtool: propagate get_coalesce return value (Ivan Vecera) [1878274]
- [net] ethtool: don't call set_channels in drivers if config didn't change (Ivan Vecera) [1878274]
- [net] ethtool: check if there is at least one channel for TX/RX in the core (Ivan Vecera) [1878274]
- [net] drivers: Remove inclusion of vermagic header (Ivan Vecera) [1878274]
- [net] ethtool: count header size in reply size estimate (Ivan Vecera) [1878274]
- [net] ethtool: provide timestamping information with TSINFO_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add timestamping related string sets (Ivan Vecera) [1878274]
- [net] ethtool: add EEE_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set EEE settings with EEE_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide EEE settings with EEE_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add PAUSE_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set pause parameters with PAUSE_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide pause parameters with PAUSE_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add COALESCE_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set coalescing parameters with COALESCE_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide coalescing parameters with COALESCE_GET request (Ivan Vecera) [1878274]
- [net] ethtool: fix reference leak in ethnl_set_privflags() (Ivan Vecera) [1878274]
- [net] ethtool: fix incorrect tx-checksumming settings reporting (Ivan Vecera) [1878274]
- [include] ethtool.h: Replace zero-length array with flexible-array member (Ivan Vecera) [1878274]
- [net] ethtool: fix reference leak in some *_SET handlers (Ivan Vecera) [1878274]
- [net] ethtool: reject unrecognized request flags (Ivan Vecera) [1878274]
- [include] netlink: add nl_set_extack_cookie_u32() (Ivan Vecera) [1878274]
- [net] netlink: allow extack cookie also for error messages (Ivan Vecera) [1878274]
- [net] ethtool: fix spelling mistake "exceeeds" -> "exceeds" (Ivan Vecera) [1878274]
- [net] ethtool: add CHANNELS_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set device channel counts with CHANNELS_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide channel counts with CHANNELS_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add RINGS_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set device ring sizes with RINGS_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide ring sizes with RINGS_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add PRIVFLAGS_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set device private flags with PRIVFLAGS_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide private flags with PRIVFLAGS_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add FEATURES_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set netdev features with FEATURES_SET request (Ivan Vecera) [1878274]
- [net] ethtool: add ethnl_parse_bitset() helper (Ivan Vecera) [1878274]
- [net] ethtool: provide netdev features with FEATURES_GET request (Ivan Vecera) [1878274]
- [net] ethtool: update mapping of features to legacy ioctl requests (Ivan Vecera) [1878274]
- [net] ethtool: rename ethnl_parse_header() to ethnl_parse_header_dev_get() (Ivan Vecera) [1878274]
- [include] hns: reject unsupported coalescing params (Ivan Vecera) [1878274]
- [include] net: liquidio: reject unsupported coalescing params (Ivan Vecera) [1878274]
- [net] ethtool: Factored out similar ethtool link settings for virtual devices to core (Ivan Vecera) [1878274]
- [net] ethtool: limit bitset size (Ivan Vecera) [1878274]
- [net] ethtool: fix application of verbose no_mask bitset (Ivan Vecera) [1878274]
- [net] ethtool: Add support for low latency RS FEC (Ivan Vecera) [1878274]
- [net] ethtool: add WOL_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set wake-on-lan settings with WOL_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide WoL settings with WOL_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add DEBUG_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set message mask with DEBUG_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide message mask with DEBUG_GET request (Ivan Vecera) [1878274]
- [net] ethtool: fix kernel-doc descriptions (Ivan Vecera) [1878274]
- [net] ethtool: potential NULL dereference in strset_prepare_data() (Ivan Vecera) [1878274]
- [net] ethtool: fix ->reply_size() error handling (Ivan Vecera) [1878274]
- [net] ethtool: fix a memory leak in ethnl_default_start() (Ivan Vecera) [1878274]
- [net] ethtool: remove set but not used variable 'lsettings' (Ivan Vecera) [1878274]
- [net] ethtool: provide link state with LINKSTATE_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add LINKMODES_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: set link modes related data with LINKMODES_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide link mode information with LINKMODES_GET request (Ivan Vecera) [1878274]
- [net] ethtool: add LINKINFO_NTF notification (Ivan Vecera) [1878274]
- [net] ethtool: add default notification handler (Ivan Vecera) [1878274]
- [net] ethtool: set link settings with LINKINFO_SET request (Ivan Vecera) [1878274]
- [net] ethtool: provide link settings with LINKINFO_GET request (Ivan Vecera) [1878274]
- [net] ethtool: provide string sets with STRSET_GET request (Ivan Vecera) [1878274]
- [net] ethtool: default handlers for GET requests (Ivan Vecera) [1878274]
- [net] ethtool: support for netlink notifications (Ivan Vecera) [1878274]
- [net] ethtool: netlink bitset handling (Ivan Vecera) [1878274]
- [net] ethtool: helper functions for netlink interface (Ivan Vecera) [1878274]
- [net] ethtool: introduce ethtool netlink interface (Ivan Vecera) [1878274]
- [net] ethtool: provide link mode names as a string set (Ivan Vecera) [1878274]
- [net] ethtool: move string arrays into common file (Ivan Vecera) [1878274]
- [net] ethtool: move RHEL specific stuff to separate header file (Ivan Vecera) [1878274]
- [net] ethtool: move to its own directory (Ivan Vecera) [1878274]
- [net] rtnetlink: provide permanent hardware address in RTM_NEWLINK (Ivan Vecera) [1878274]
- [net] Zeroing the structure ethtool_wolinfo in ethtool_get_wol() (Ivan Vecera) [1878274]
- [net] ethtool: Allow parsing ETHER_FLOW types when using flow_rule (Ivan Vecera) [1878274]
- [net] ethtool: Allow matching on vlan DEI bit (Ivan Vecera) [1878274]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Ivan Vecera) [1878274]
- [include] net: ethtool: Document get_rxfh_context and set_rxfh_context ethtool ops (Ivan Vecera) [1878274]
- [include] ethtool: avoid signed-unsigned comparison in ethtool_validate_speed() (Ivan Vecera) [1878274]
- [net] ethtool: not call vzalloc for zero sized memory request (Ivan Vecera) [1878274]
- [net] ethtool: reduce stack usage with clang (Ivan Vecera) [1878274]
- [net] ethtool: Use explicit designated initializers for .cmd (Ivan Vecera) [1878274]
- [net] ethtool: remove unnecessary check in ethtool_get_regs() (Ivan Vecera) [1878274]
- [include] uapi/ethtool: fix spelling errors (Ivan Vecera) [1878274]
- [net] ethtool: fix a missing-check bug (Ivan Vecera) [1878274]
- [include] ethtool: Remove trailing semicolon for static inline (Ivan Vecera) [1878274]
- [net] ipv6: some fixes for ipv6_dev_find() (Xin Long) [1862458]
- [net] tipc: not enable tipc when ipv6 works as a module (Xin Long) [1862458]
- [net] tipc: set ub->ifindex for local ipv6 address (Xin Long) [1862458]
- [net] ipv6: add ipv6_dev_find() (Xin Long) [1862458]
- [powerpc] powerpc/pseries: explicitly reschedule during drmem_lmb list traversal (Steve Best) [1892377]
- [scsi] scsi: ibmvscsi: Fix potential race after loss of transport (Steve Best) [1892316]
- [mm] mm: fix a race during THP splitting (Rafael Aquini) [1865813 1739593]
- [mm] mm, memcg: do not high throttle allocators based on wraparound (Waiman Long) [1873759]
- [mm] mm, memcg: throttle allocators based on ancestral memory.high (Waiman Long) [1873759]
- [mm] mm, memcg: fix corruption on 64-bit divisor in memory.high throttling (Waiman Long) [1873759]
- [mm] mm, memcg: throttle allocators when failing reclaim over memory.high (Waiman Long) [1873759]
- [mm] mm, oom: dump stack of victim when reaping failed (Waiman Long) [1873759]
- [mm] mm/oom: fix pgtables units mismatch in Killed process message (Waiman Long) [1873759]
- [mm] mm, oom: consider present pages for the node size (Waiman Long) [1873759]
- [mm] mm/oom_kill.c: fix oom_cpuset_eligible() comment (Waiman Long) [1873759]
- [mm] mm/oom: add oom_score_adj and pgtables to Killed process message (Waiman Long) [1873759]
- [mm] mm/oom_kill.c: remove redundant OOM score normalization in select_bad_process() (Waiman Long) [1873759]
- [fs] oom: decouple mems_allowed from oom_unkillable_task (Waiman Long) [1873759]
- [mm] mm, oom: remove redundant task_in_mem_cgroup() check (Waiman Long) [1873759]
- [mm] mm, oom: refactor dump_tasks for memcg OOMs (Waiman Long) [1873759]
- [mm] mm, oom: describe task memory unit, larger PID pad (Waiman Long) [1873759]
- [mm] mm, oom: remove oom_lock from oom_reaper (Waiman Long) [1873759]
- [mm] mm/vmscan: remove unused RECLAIM_OFF/RECLAIM_ZONE (Waiman Long) [1873759]
- [mm] mm/vmscan: remove prefetch_prev_lru_page (Waiman Long) [1873759]
- [mm] mm/vmscan.c: remove unused return value of shrink_node (Waiman Long) [1873759]
- [mm] mm/vmscan.c: clean code by removing unnecessary assignment (Waiman Long) [1873759]
- [mm] mm: vmscan: protect shrinker idr replace with CONFIG_MEMCG (Waiman Long) [1873759]
- [mm] mm/vmscan.c: fix typo in comment (Waiman Long) [1873759]
- [mm] mm: vmscan: enforce inactive:active ratio at the reclaim root (Waiman Long) [1873759]
- [mm] mm: vmscan: detect file thrashing at the reclaim root (Waiman Long) [1873759]
- [mm] mm: vmscan: move file exhaustion detection to the node level (Waiman Long) [1873759]
- [include] mm: vmscan: harmonize writeback congestion tracking for nodes & memcgs (Waiman Long) [1873759]
- [mm] mm: vmscan: split shrink_node() into node part and memcgs part (Waiman Long) [1873759]
- [mm] mm: vmscan: turn shrink_node_memcg() into shrink_lruvec() (Waiman Long) [1873759]
- [mm] mm: vmscan: replace shrink_node() loop with a retry jump (Waiman Long) [1873759]
- [mm] mm: vmscan: naming fixes: global_reclaim() and sane_reclaim() (Waiman Long) [1873759]
- [mm] mm: vmscan: move inactive_list_is_low() swap check to the caller (Waiman Long) [1873759]
- [mm] mm: vmscan: simplify lruvec_lru_size() (Waiman Long) [1873759]
- [mm] mm/vmscan.c: remove unused scan_control parameter from pageout() (Waiman Long) [1873759]
- [mm] mm/vmscan: remove unused lru_pages argument (Waiman Long) [1873759]
- [mm] mm: do not allow MADV_PAGEOUT for CoW pages (Waiman Long) [1873759]
- [mm] mm: fix trying to reclaim unevictable lru page when calling madvise_pageout (Waiman Long) [1873759]
- [mm] mm: factor out common parts between MADV_COLD and MADV_PAGEOUT (Waiman Long) [1873759]
- [mm] mm: introduce MADV_PAGEOUT (Waiman Long) [1873759]
- [mm] mm: change PAGEREF_RECLAIM_CLEAN with PAGE_REFRECLAIM (Waiman Long) [1873759]
- [mm] mm: introduce MADV_COLD (Waiman Long) [1873759]
- [mm] mm: thp: don't need care deferred split queue in memcg charge move path (Waiman Long) [1873759]
- [mm] mm: thp: make deferred split shrinker memcg aware (Waiman Long) [1873759]
- [mm] mm: shrinker: make shrinker not depend on memcg kmem (Waiman Long) [1873759]
- [mm] mm: move mem_cgroup_uncharge out of __page_cache_release() (Waiman Long) [1873759]
- [mm] mm: thp: extract split_queue_* into a struct (Waiman Long) [1873759]
- [mm] mm/page_alloc.c: move ifdefery out of free_area_init_core (Waiman Long) [1873759]
- [mm] mm, memcg: do not set reclaim_state on soft limit reclaim (Waiman Long) [1873759]
- [mm] mm, vmscan: do not special-case slab reclaim when watermarks are boosted (Waiman Long) [1873759]
- [mm] mm/vmscan.c: add checks for incorrect handling of current->reclaim_state (Waiman Long) [1873759]
- [mm] mm/vmscan.c: calculate reclaimed slab caches in all reclaim paths (Waiman Long) [1873759]
- [mm] mm/vmscan.c: add a new member reclaim_state in struct shrink_control (Waiman Long) [1873759]
- [mm] mm: vmscan: remove double slab pressure by inc'ing sc->nr_scanned (Waiman Long) [1873759]
- [mm] mm: limit boost_watermark on small zones (Waiman Long) [1873759]
- [mm] mm: do not boost watermarks to avoid fragmentation for the DISCONTIG memory model (Waiman Long) [1873759]
- [mm] mm, page_alloc: fix a division by zero error when boosting watermarks v2 (Waiman Long) [1873759]
- [mm] mm, page_alloc: do not wake kswapd with zone lock held (Waiman Long) [1873759]
- [mm] mm/page_alloc.c: drop uneeded __meminit and __meminitdata (Waiman Long) [1873759]
- [mm] mm/page_alloc.c: fix never set ALLOC_NOFRAGMENT flag (Waiman Long) [1873759]
- [mm] mm/page_alloc.c: avoid potential NULL pointer dereference (Waiman Long) [1873759]
- [mm] mm/vmscan.c: don't disable irq again when count pgrefill for memcg (Waiman Long) [1873759]
- [mm] mm/vmscan: drop may_writepage and classzone_idx from direct reclaim begin template (Waiman Long) [1873759]
- [mm] mm/vmscan: add tracepoints for node reclaim (Waiman Long) [1873759]
- [mm] mm: generalize putback scan functions (Waiman Long) [1873759]
- [mm] mm: remove pages_to_free argument of move_active_pages_to_lru() (Waiman Long) [1873759]
- [mm] mm/workingset: remove unused @mapping argument in workingset_eviction() (Waiman Long) [1873759]
- [mm] Revert "mm: slowly shrink slabs with a relatively small number of objects" (Waiman Long) [1873759]
- [mm] mm: reclaim small amounts of memory when an external fragmentation event occurs (Waiman Long) [1873759]
- [mm] mm: use alloc_flags to record if kswapd can wake (Waiman Long) [1873759]
- [mm] mm: move zone watermark accesses behind an accessor (Waiman Long) [1873759]
- [mm] mm, page_alloc: spread allocations across zones before introducing fragmentation (Waiman Long) [1873759]
- [mm] mm: Convert delete_from_swap_cache to XArray (Waiman Long) [1873759]
- [fs] mm: zero-seek shrinkers (Waiman Long) [1873759]
- [mm] mm/vmscan.c: fix int overflow in callers of do_shrink_slab() (Waiman Long) [1873759]
- [mm] mm: slowly shrink slabs with a relatively small number of objects (Waiman Long) [1873759]
- [mm] mm: fix page_freeze_refs and page_unfreeze_refs in comments (Waiman Long) [1873759]
- [mm] mm: check shrinker is memcg-aware in register_shrinker_prepared() (Waiman Long) [1873759]
- [mm] mm: use special value SHRINKER_REGISTERING instead of list_empty() check (Waiman Long) [1873759]
- [mm] mm/vmscan.c: move check for SHRINKER_NUMA_AWARE to do_shrink_slab() (Waiman Long) [1873759]
- [mm] mm/vmscan.c: condense scan_control (Waiman Long) [1873759]
- [arch] asm-generic/tlb: add missing CONFIG symbol (Waiman Long) [1873759]
- [include] asm-gemeric/tlb: remove stray function declarations (Waiman Long) [1873759]
- [x86] x86/ldt: Remove unused variable in map_ldt_struct() (Waiman Long) [1873759]
- [x86] x86/ldt: Unmap PTEs for the slot before freeing LDT pages (Waiman Long) [1873759]
- [x86] x86/mm/tlb: Add freed_tables argument to flush_tlb_mm_range (Waiman Long) [1873759]
- [mm] asm-generic/tlb: Remove tlb_table_flush() (Waiman Long) [1873759]
- [mm] asm-generic/tlb: Remove tlb_flush_mmu_free() (Waiman Long) [1873759]
- [mm] asm-generic/tlb: Remove CONFIG_HAVE_GENERIC_MMU_GATHER (Waiman Long) [1873759]
- [mm] asm-generic/tlb: Remove arch_tlb*_mmu() (Waiman Long) [1873759]
- [s390] s390/tlb: Convert to generic mmu_gather (Waiman Long) [1873759]
- [mm] asm-generic/tlb: Introduce CONFIG_HAVE_MMU_GATHER_NO_GATHER=y (Waiman Long) [1873759]
- [include] asm-generic/tlb, ia64: Conditionally provide tlb_migrate_finish() (Waiman Long) [1873759]
- [include] asm-generic/tlb: Provide generic tlb_flush() based on flush_tlb_mm() (Waiman Long) [1873759]
- [arm64] asm-generic/tlb, arch: Provide generic tlb_flush() based on flush_tlb_range() (Waiman Long) [1873759]
- [mm] asm-generic/tlb, arch: Provide CONFIG_HAVE_MMU_GATHER_PAGE_SIZE (Waiman Long) [1873759]
- [include] asm-generic/tlb: Provide a comment (Waiman Long) [1873759]
- [mm] mm/memory: Move mmu_gather and TLB invalidation code into its own file (Waiman Long) [1873759]
- [x86] x86/mm: Page size aware flush_tlb_mm_range() (Waiman Long) [1873759]
- [x86] x86/ldt: Split out sanity check in map_ldt_struct() (Waiman Long) [1873759]
- [mm] asm-generic/tlb: Track which levels of the page tables have been cleared (Waiman Long) [1873759]
- [include] asm-generic/tlb: Track freeing of page-table directories in struct mmu_gather (Waiman Long) [1873759]
- [mm] mm/cow: don't bother write protecting already write-protected pages (Waiman Long) [1873759]
- [powerpc] mm/mmu_gather: invalidate TLB correctly on batch allocation failure and flush (Diego Domingos) [1805031]
- [powerpc] powerpc/mmu_gather: enable RCU_TABLE_FREE even for !SMP case (Diego Domingos) [1805031]
- [fs] cifs: smb1: Try failing back to SetFileInfo if SetPathInfo fails (Leif Sahlberg) [1857038]

* Mon Nov 09 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-247.el8]
- [scsi] scsi: libfc: Fix passing zero to 'PTR_ERR' warning (Chris Leech) [1849542]
- [scsi] scsi: libfc: Fix for double free() (Chris Leech) [1849542]
- [scsi] scsi: libfc: Free skb in fc_disc_gpn_id_resp() for valid cases (Chris Leech) [1849542]
- [scsi] scsi: fcoe: Memory leak fix in fcoe_sysfs_fcf_del() (Chris Leech) [1849542]
- [scsi] scsi: fcoe: Use eth_zero_addr() to clear mac address (Chris Leech) [1849542]
- [scsi] scsi: libfc: Provide missing and repair existing function documentation (Chris Leech) [1849542]
- [scsi] scsi: libfc: Fix a couple of misdocumented function parameters (Chris Leech) [1849542]
- [scsi] scsi: libfc: Repair function parameter documentation (Chris Leech) [1849542]
- [scsi] scsi: fcoe: Correct some kernel-doc issues (Chris Leech) [1849542]
- [scsi] scsi: fcoe: Fix a myriad of documentation issues (Chris Leech) [1849542]
- [scsi] scsi: fcoe: Fix various kernel-doc infringements (Chris Leech) [1849542]
- [scsi] scsi: libfc: trivial: Fix spelling mistake of 'discovery' (Chris Leech) [1849542]
- [scsi] scsi: libfc: Supply some missing kerneldoc struct/function attributes/params (Chris Leech) [1849542]
- [scsi] scsi: libfc: fc_disc: Fix-up some incorrectly referenced function parameters (Chris Leech) [1849542]
- [scsi] scsi: libfc: Skip additional kref updating work event (Chris Leech) [1849542]
- [scsi] scsi: libfc: Handling of extra kref (Chris Leech) [1849542]
- [scsi] scsi: fcoe: remove unneeded semicolon in fcoe.c (Chris Leech) [1849542]
- [scsi] scsi: libfc: rport state move to PLOGI if all PRLI retry exhausted (Chris Leech) [1849542]
- [scsi] scsi: libfc: If PRLI rejected, move rport to PLOGI state (Chris Leech) [1849542]
- [scsi] scsi: libfc: free response frame from GPN_ID (Chris Leech) [1849542]
- [scsi] scsi: fcoe: fix null-ptr-deref Read in fc_release_transport (Chris Leech) [1849542]
- [scsi] scsi: fcoe: remove redundant call to skb_transport_header (Chris Leech) [1849542]
- [scsi] scsi: fcoe: pass in fcoe_rport structure instead of fc_rport_priv (Chris Leech) [1849542]
- [scsi] scsi: fcoe: Embed fc_rport_priv in fcoe_rport structure (Chris Leech) [1849542]
- [scsi] scsi: libfc: Whitespace cleanup in libfc.h (Chris Leech) [1849542]
- [scsi] scsi: fcoe: fix a typo (Chris Leech) [1849542]
- [scsi] scsi: libfc: fix null pointer dereference on a null lport (Chris Leech) [1849542]
- [scsi] scsi: libfcoe: switch to SPDX tags (Chris Leech) [1849542]
- [scsi] scsi: libfc: switch to SPDX tags (Chris Leech) [1849542]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Chris Leech) [1849542]
- [scsi] scsi: fcoe: remove unneeded fcoe_ctlr_destroy_store export (Chris Leech) [1849542]
- [scsi] scsi: fcoe: convert to use BUS_ATTR_WO (Chris Leech) [1849542]
- [scsi] scsi: libfc: free skb when receiving invalid flogi resp (Chris Leech) [1849542]
- [scsi] scsi: fcoe: remove set but not used variable 'port' (Chris Leech) [1849542]
- [scsi] scsi: libfc: fc_rport: Mark expected switch fall-through (Chris Leech) [1849542]
- [scsi] scsi: libfc: Remove set but not used variable 'disc' (Chris Leech) [1849542]
- [scsi] scsi: libfc: remove set but not used variable 'rpriv' (Chris Leech) [1849542]
- [scsi] scsi: libfc: remove unnecessary condition check (Chris Leech) [1849542]
- [scsi] scsi: fcoe: hold disc_mutex when traversing rport lists (Chris Leech) [1849542]
- [net] netfilter: nftables: allow re-computing sctp CRC-32C in 'payload' statements (Davide Caratti) [1741052]
- [fs] nfsd4: fix NULL dereference in nfsd/clients display code (Scott Mayhew) [1872311]
- [fs] nfsd: Fix old-style function definition (Scott Mayhew) [1872311]
- [fs] nfsd: clients don't need to break their own delegations (Scott Mayhew) [1872311]
- [kernel] kthread: save thread function (Scott Mayhew) [1872311]
- [fs] locks: Add trace_leases_conflict (Scott Mayhew) [1872311]
- [fs] SUNRPC reverting d03727b248d0 ("NFSv4 fix CLOSE not waiting for direct IO compeletion") (Scott Mayhew) [1872311]
- [fs] NFS: Fix interrupted slots by sending a solo SEQUENCE operation (Scott Mayhew) [1872311]
- [net] SUNRPC: Add missing definition of ARCH_IMPLEMENTS_FLUSH_DCACHE_PAGE (Scott Mayhew) [1872311]
- [fs] NFSv4 fix CLOSE not waiting for direct IO compeletion (Scott Mayhew) [1872311]
- [fs] nfs: Fix memory leak of export_path (Scott Mayhew) [1872311]
- [net] sunrpc: fixed rollback in rpc_gssd_dummy_populate() (Scott Mayhew) [1872311]
- [net] xprtrdma: Clean up disconnect (Scott Mayhew) [1872311]
- [fs] nfsd: apply umask on fs without ACL support (Scott Mayhew) [1872311]
- [fs] NFS: Fix direct WRITE throughput regression (Scott Mayhew) [1872311]
- [trace] SUNRPC: rpc_xprt lifetime events should record xprt->state (Scott Mayhew) [1872311]
- [fs] nfs: set invalid blocks after NFSv4 writes (Scott Mayhew) [1872311]
- [fs] NFS: remove redundant initialization of variable result (Scott Mayhew) [1872311]
- [fs] NFS: Add a tracepoint in nfs_set_pgio_error() (Scott Mayhew) [1872311]
- [fs] NFS: Trace short NFS READs (Scott Mayhew) [1872311]
- [fs] NFS: nfs_xdr_status should record the procedure name (Scott Mayhew) [1872311]
- [net] SUNRPC: Set SOFTCONN when destroying GSS contexts (Scott Mayhew) [1872311]
- [net] SUNRPC: rpc_call_null_helper() should set RPC_TASK_SOFT (Scott Mayhew) [1872311]
- [net] SUNRPC: rpc_call_null_helper() already sets RPC_TASK_NULLCREDS (Scott Mayhew) [1872311]
- [net] SUNRPC: trace RPC client lifetime events (Scott Mayhew) [1872311]
- [net] SUNRPC: Trace transport lifetime events (Scott Mayhew) [1872311]
- [net] SUNRPC: Split the xdr_buf event class (Scott Mayhew) [1872311]
- [net] SUNRPC: Add tracepoint to rpc_call_rpcerror() (Scott Mayhew) [1872311]
- [trace] SUNRPC: Update the RPC_SHOW_SOCKET() macro (Scott Mayhew) [1872311]
- [trace] SUNRPC: Update the rpc_show_task_flags() macro (Scott Mayhew) [1872311]
- [net] SUNRPC: Trace GSS context lifetimes (Scott Mayhew) [1872311]
- [net] SUNRPC: receive buffer size estimation values almost never change (Scott Mayhew) [1872311]
- [net] sunrpc: use kmemdup_nul() in gssp_stringify() (Scott Mayhew) [1872311]
- [fs] nfsd: safer handling of corrupted c_type (Scott Mayhew) [1872311]
- [fs] mm/writeback: discard NR_UNSTABLE_NFS, use NR_WRITEBACK instead (Scott Mayhew) [1872311]
- [mm] mm/writeback: replace PF_LESS_THROTTLE with PF_LOCAL_THROTTLE (Scott Mayhew) [1872311]
- [net] SUNRPC: Remove unreachable error condition in rpcb_getport_async() (Scott Mayhew) [1872311]
- [fs] nfsd: Fix svc_xprt refcnt leak when setup callback client failed (Scott Mayhew) [1872311]
- [net] sunrpc: check that domain table is empty at module unload (Scott Mayhew) [1872311]
- [fs] NFS: remove duplicate headers (Scott Mayhew) [1872311]
- [fs] NFSv4.1 fix rpc_call_done assignment for BIND_CONN_TO_SESSION (Scott Mayhew) [1872311]
- [fs] NFS: Use the correct style for SPDX License Identifier (Scott Mayhew) [1872311]
- [net] net: sunrpc: Fix off-by-one issues in 'rpc_ntop6' (Scott Mayhew) [1872311]
- [fs] NFS: move dprintk after nfs_alloc_fattr in nfs3_proc_lookup (Scott Mayhew) [1872311]
- [fs] NFSD: Fix improperly-formatted Doxygen comments (Scott Mayhew) [1872311]
- [fs] NFSD: Squash an annoying compiler warning (Scott Mayhew) [1872311]
- [net] SUNRPC: Clean up request deferral tracepoints (Scott Mayhew) [1872311]
- [fs] NFSD: Add tracepoints for monitoring NFSD callbacks (Scott Mayhew) [1872311]
- [fs] NFSD: Add tracepoints to the NFSD state management code (Scott Mayhew) [1872311]
- [fs] NFSD: Add tracepoints to NFSD's duplicate reply cache (Scott Mayhew) [1872311]
- [trace] SUNRPC: svc_show_status() macro should have enum definitions (Scott Mayhew) [1872311]
- [net] SUNRPC: Restructure svc_udp_recvfrom() (Scott Mayhew) [1872311]
- [net] SUNRPC: Refactor svc_recvfrom() (Scott Mayhew) [1872311]
- [net] SUNRPC: Clean up svc_release_skb() functions (Scott Mayhew) [1872311]
- [net] SUNRPC: Refactor recvfrom path dealing with incomplete TCP receives (Scott Mayhew) [1872311]
- [net] SUNRPC: Replace dprintk() call sites in TCP receive path (Scott Mayhew) [1872311]
- [net] SUNRPC: Restructure svc_tcp_recv_record() (Scott Mayhew) [1872311]
- [net] SUNRPC: Rename svc_sock::sk_reclen (Scott Mayhew) [1872311]
- [net] SUNRPC: Trace server-side rpcbind registration events (Scott Mayhew) [1872311]
- [net] SUNRPC: Replace dprintk call sites in TCP state change callouts (Scott Mayhew) [1872311]
- [net] SUNRPC: Add more svcsock tracepoints (Scott Mayhew) [1872311]
- [net] SUNRPC: Remove "#include <trace/events/skb.h>" (Scott Mayhew) [1872311]
- [net] SUNRPC: Trace a few more generic svc_xprt events (Scott Mayhew) [1872311]
- [net] SUNRPC: Tracepoint to record errors in svc_xpo_create() (Scott Mayhew) [1872311]
- [trace] SUNRPC: Remove kernel memory address from svc_xprt tracepoints (Scott Mayhew) [1872311]
- [net] svcrdma: Add tracepoints to report ->xpo_accept failures (Scott Mayhew) [1872311]
- [net] svcrdma: Displayed remote IP address should match stored address (Scott Mayhew) [1872311]
- [include] svcrdma: Remove the SVCRDMA_DEBUG macro (Scott Mayhew) [1872311]
- [net] svcrdma: Rename tracepoints that record header decoding errors (Scott Mayhew) [1872311]
- [net] svcrdma: Remove backchannel dprintk call sites (Scott Mayhew) [1872311]
- [net] SUNRPC: Move xpt_mutex into socket xpo_sendto methods (Scott Mayhew) [1872311]
- [net] sunrpc: add missing newline when printing parameter 'pool_mode' by sysfs (Scott Mayhew) [1872311]
- [net] sunrpc: Remove unused function ip_map_update (Scott Mayhew) [1872311]
- [fs] nfsd: handle repeated BIND_CONN_TO_SESSION (Scott Mayhew) [1872311]
- [net] ip_tunnel_core: Fix build for archs without _HAVE_ARCH_IPV6_CSUM (Aaron Conole) [1849736]
- [tools] selftests: pmtu.sh: Add tests for UDP tunnels handled by Open vSwitch (Aaron Conole) [1849736]
- [tools] selftests: pmtu.sh: Add tests for bridged UDP tunnels (Aaron Conole) [1849736]
- [net] geneve: Support for PMTU discovery on directly bridged links (Aaron Conole) [1849736]
- [net] vxlan: Support for PMTU discovery on directly bridged links (Aaron Conole) [1849736]
- [net] tunnels: PMTU discovery support for directly bridged IP packets (Aaron Conole) [1849736]
- [net] ipv4: route: Ignore output interface in FIB lookup for PMTU route (Aaron Conole) [1849736]
- [infiniband] RDMA/core: Free DIM memory in error unwind (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Stop DIM before destroying CQ (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Add min length checks to user structure copies (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Protect access to remote_sidr_table (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Fix race in rdma_alloc_commit_uobject() (Kamal Heib) [1857602]
- [net] xprtrdma: fix incorrect header size calculations (Kamal Heib) [1857602]
- [net] xprtrdma: Fix handling of connect errors (Kamal Heib) [1857602]
- [net] xprtrdma: Fix return code from rpcrdma_xprt_connect() (Kamal Heib) [1857602]
- [net] xprtrdma: Fix recursion into rpcrdma_xprt_disconnect() (Kamal Heib) [1857602]
- [net] xprtrdma: Fix double-free in rpcrdma_ep_create() (Kamal Heib) [1857602]
- [infiniband] RDMA/siw: Fix reporting vendor_part_id (Kamal Heib) [1857602]
- [infiniband] IB/sa: Resolv use-after-free in ib_nl_make_request() (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add explicit cast OPA_MTU_8192 to 'enum ib_mtu' (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add atomic triggered sleep/wakeup (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Correct -EBUSY handling in tx code (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Restore kfree in dummy_netdev cleanup (Kamal Heib) [1857602]
- [infiniband] IB/mad: Fix use after free when destroying MAD agent (Kamal Heib) [1857602]
- [infiniband] RDMA/counter: Query a counter before release (Kamal Heib) [1857602]
- [net] xprtrdma: Fix handling of RDMA_ERROR replies (Kamal Heib) [1857602]
- [net] xprtrdma: Clean up synopsis of rpcrdma_flush_disconnect() (Kamal Heib) [1857602]
- [net] xprtrdma: Use re_connect_status safely in rpcrdma_xprt_connect() (Kamal Heib) [1857602]
- [net] xprtrdma: Prevent dereferencing r_xprt->rx_ep after it is freed (Kamal Heib) [1857602]
- [infiniband] RDMA/mad: Fix possible memory leak in ib_mad_post_receive_mads() (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Check that type_attrs is not NULL prior access (Kamal Heib) [1857602]
- [infiniband] RDMA/cma: Protect bind_list and listen_list while finding matching cm id (Kamal Heib) [1857602]
- [infiniband] RDMA/efa: Set maximum pkeys device attribute (Kamal Heib) [1857602]
- [infiniband] RDMA/rvt: Fix potential memory leak caused by rvt_alloc_rq (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Annotate CMA unlock helper routine (Kamal Heib) [1857602]
- [infiniband] RDMA/siw: Fix pointer-to-int-cast warning in siw_rx_pbl() (Kamal Heib) [1857602]
- [infiniband] RDMA/hfi1: Fix trivial mis-spelling of 'descriptor' (Kamal Heib) [1857602]
- [net] xprtrdma: Make xprt_rdma_slot_table_entries static (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Spurious WARNING triggered in cm_destroy_id() (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Use free_netdev() in hfi1_netdev_free() (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Move and rename trace_cm_id_create() (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Fix hfi1_netdev_rx_init() error handling (Kamal Heib) [1857602]
- [infiniband] RDMA: Remove 'max_map_per_fmr' (Kamal Heib) [1857602]
- [infiniband] RDMA: Remove 'max_fmr' (Kamal Heib) [1857602]
- [net] RDMA/rds: Remove FMR support for memory registration (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Remove FMR device ops (Kamal Heib) [1857602]
- [infiniband] RDMA/rdmavt: Remove FMR memory registration (Kamal Heib) [1857602]
- [infiniband] RDMA/mthca: Remove FMR support for memory registration (Kamal Heib) [1857602]
- [infiniband] RDMA/mlx4: Remove FMR support for memory registration (Kamal Heib) [1857602]
- [infiniband] RDMA/i40iw: Remove FMR leftovers (Kamal Heib) [1857602]
- [infiniband] RDMA/bnxt_re: Remove FMR leftovers (Kamal Heib) [1857602]
- [infiniband] RDMA/mlx5: Remove FMR leftovers (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Remove FMR pool API (Kamal Heib) [1857602]
- [infiniband] RDMA/srp: Remove support for FMR memory registration (Kamal Heib) [1857602]
- [infiniband] RDMA/iser: Remove support for FMR memory registration (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Fix several reference count leaks (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Fix spelling mistake "enought" -> "enough" (Kamal Heib) [1857602]
- [rdma] RDMA/core: Use offsetofend() instead of open coding (Kamal Heib) [1857602]
- [infiniband] RDMA/srpt: Increase max_send_sge (Kamal Heib) [1857602]
- [infiniband] RDMA/srpt: Reduce max_recv_sge to 1 (Kamal Heib) [1857602]
- [infiniband] RDMA/srpt: Make debug output more detailed (Kamal Heib) [1857602]
- [infiniband] RDMA/srp: Make the channel count configurable per target (Kamal Heib) [1857602]
- [infiniband] hfi1: get rid of pointless access_ok() (Kamal Heib) [1857602]
- [infiniband] RDMA/cma: Provide ECE reject reason (Kamal Heib) [1857602]
- [infiniband] RDMA/cma: Connect ECE to rdma_accept (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Send and receive ECE parameter over the wire (Kamal Heib) [1857602]
- [infiniband] RDMA/ucma: Deliver ECE parameters through UCMA events (Kamal Heib) [1857602]
- [infiniband] RDMA/ucma: Extend ucma_connect to receive ECE parameters (Kamal Heib) [1857602]
- [rdma] RDMA/cm: Add Enhanced Connection Establishment (ECE) bits (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Use sizeof_field() helper (Kamal Heib) [1857602]
- [infiniband] RDMA/ipoib: Remove can_sleep parameter from iboib_mcast_alloc (Kamal Heib) [1857602]
- [infiniband] IB/cma: Fix ports memory leak in cma_configfs (Kamal Heib) [1857602]
- [infiniband] IB/uverbs: Introduce create/destroy QP commands over ioctl (Kamal Heib) [1857602]
- [infiniband] IB/uverbs: Introduce create/destroy WQ commands over ioctl (Kamal Heib) [1857602]
- [infiniband] IB/uverbs: Introduce create/destroy SRQ commands over ioctl (Kamal Heib) [1857602]
- [rdma] IB/uverbs: Move QP, SRQ, WQ type and flags to UAPI (Kamal Heib) [1857602]
- [infiniband] IB/uverbs: Extend CQ to get its own asynchronous event FD (Kamal Heib) [1857602]
- [infiniband] IB/uverbs: Refactor related objects to use their own asynchronous event FD (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Allow the ioctl layer to abort a fully created uobject (Kamal Heib) [1857602]
- [infiniband] IB/mlx5: Expose UAR object and its alloc/destroy commands (Kamal Heib) [1857602]
- [infiniband] IB/mlx5: Fix a NULL vs IS_ERR() check (Kamal Heib) [1857602]
- [infiniband] IB/mlx5: Introduce UAPIs to manage packet pacing (Kamal Heib) [1857602]
- [netdrv] net/mlx5: Expose raw packet pacing APIs (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Enable the transmit side of the datagram ipoib netdev (Kamal Heib) [1857602]
- [infiniband] IB/ipoib: Add capability to switch between datagram and connected mode (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add packet histogram trace event (Kamal Heib) [1857602]
- [infiniband] IB/{hfi1, ipoib, rdma}: Broadcast ping sent packets which exceeded mtu size (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Activate the dummy netdev (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add rx functions for dummy netdev (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add interrupt handler functions for accelerated ipoib (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add functions to receive accelerated ipoib packets (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Rename num_vnic_contexts as num_netdev_contexts (Kamal Heib) [1857602]
- [infiniband] IB/ipoib: Increase ipoib Datagram mode MTU's upper limit (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: RSM rules for AIP (Kamal Heib) [1857602]
- [infiniband] IB/{rdmavt, hfi1}: Implement creation of accelerated UD QPs (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Remove module parameter for KDETH qpns (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add the transmit side of a datagram ipoib RDMA netdev (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add functions to transmit datagram ipoib packets (Kamal Heib) [1857602]
- [infiniband] IB/hfi1: Add accelerated IP capability bit (Kamal Heib) [1857602]
- [infiniband] RDMA/efa: Report host information to the device (Kamal Heib) [1857602]
- [infiniband] RDMA/efa: Fix setting of wrong bit in get/set_feature commands (Kamal Heib) [1857602]
- [infiniband] RDMA/siw: Replace one-element array and use struct_size() helper (Kamal Heib) [1857602]
- [net] svcrdma: Fix backchannel return code (Kamal Heib) [1857602]
- [net] svcrdma: trace undersized Write chunks (Kamal Heib) [1857602]
- [net] svcrdma: Trace page overruns when constructing RDMA Reads (Kamal Heib) [1857602]
- [net] svcrdma: Clean up handling of get_rw_ctx errors (Kamal Heib) [1857602]
- [net] svcrdma: Clean up the tracing for rw_ctx_init errors (Kamal Heib) [1857602]
- [infiniband] RDMA/srpt: Add a newline when printing parameter 'srpt_service_guid' by sysfs (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Consolidate ib_create_srq flows (Kamal Heib) [1857602]
- [infiniband] RDMA/uverbs: Fix create WQ to use the given user handle (Kamal Heib) [1857602]
- [infiniband] RDMA/uverbs: Cleanup wq/srq context usage from uverbs layer (Kamal Heib) [1857602]
- [rdma] IB/rdmavt: Replace zero-length array with flexible-array (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Increment the refcount inside cm_find_listen() (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Remove needless cm_id variable (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Remove the cm_free_id() wrapper function (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Make find_remote_id() return a cm_id_private (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Add a note explaining how the timewait is eventually freed (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Pass the cm_id_private into cm_cleanup_timewait (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Pull duplicated code into cm_queue_work_unlock() (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Remove unused store to ret in cm_rej_handler (Kamal Heib) [1857602]
- [infiniband] RDMA/cm: Remove return code from add_cm_id_to_port_list (Kamal Heib) [1857602]
- [infiniband] RDMA/addr: Mark addr_resolve as might_sleep() (Kamal Heib) [1857602]
- [infiniband] RDMA/ucma: Return stable IB device index as identifier (Kamal Heib) [1857602]
- [infiniband] RDMA/cma: Initialize the flow label of CM's route path record (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Consider flow label when building skb (Kamal Heib) [1857602]
- [rdma] RDMA/core: Add hash functions to calculate RoCEv2 flowlabel and UDP source port (Kamal Heib) [1857602]
- [infiniband] RDMA: Allow ib_client's to fail when add() is called (Kamal Heib) [1857602]
- [infiniband] RDMA/mad: Remove snoop interface (Kamal Heib) [1857602]
- [infiniband] RDMA/efa: Count admin commands errors (Kamal Heib) [1857602]
- [infiniband] RDMA/efa: Count mmap failures (Kamal Heib) [1857602]
- [infiniband] RDMA/efa: Report create CQ error counter (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Get xmit slave for LAG (Kamal Heib) [1857602]
- [infiniband] RDMA/core: Add LAG functionality (Kamal Heib) [1857602]
- [infiniband] RDMA: Group create AH arguments in struct (Kamal Heib) [1857602]
- [infiniband] RDMA/rw: use DIV_ROUND_UP to calculate nr_ops (Kamal Heib) [1857602]
- [infiniband] RDMA/cma: Limit the scope of rdma_is_consumer_reject function (Kamal Heib) [1857602]
- [infiniband] IB: Fix some documentation warnings (Kamal Heib) [1857602]
- [infiniband] RDMA: Remove a few extra calls to ib_get_client_data() (Kamal Heib) [1857602]
- [infiniband] RDMA/uverbs: Make the event_queue fds return POLLERR when disassociated (Kamal Heib) [1857602]
- [infiniband] RDMA/rxe: Set default vendor ID (Kamal Heib) [1857602]
- [netdrv] bonding: Use fallthrough pseudo-keyword (Jarod Wilson) [1860495]
- [netdrv] bonding: fix active-backup failover for current ARP slave (Jarod Wilson) [1860495]
- [netdrv] bonding: fix a potential double-unregister (Jarod Wilson) [1860495]
- [netdrv] net: bonding: bond_alb: Describe alb_handle_addr_collision_on_attach()'s 'bond' and 'addr' params (Jarod Wilson) [1860495]
- [netdrv] net: bonding: bond_main: Document 'proto' and rename 'new_active' parameters (Jarod Wilson) [1860495]
- [netdrv] net: bonding: bond_3ad: Fix a bunch of kerneldoc parameter issues (Jarod Wilson) [1860495]
- [netdrv] bonding: show saner speed for broadcast mode (Jarod Wilson) [1868265 1860495]
- [netdrv] bonding: check return value of register_netdevice() in bond_newlink() (Jarod Wilson) [1860495]
- [netdrv] bonding: check error value of register_netdevice() immediately (Jarod Wilson) [1860495]
- [netdrv] bonding: don't need RTNL for ipsec helpers (Jarod Wilson) [1860495]
- [netdrv] bonding: deal with xfrm state in all modes and add more error-checking (Jarod Wilson) [1860495]
- [netdrv] bonding: allow xfrm offload setup post-module-load (Jarod Wilson) [1860495]
- [netdrv] bonding: Remove extraneous parentheses in bond_setup (Jarod Wilson) [1860495]
- [netdrv] bonding/xfrm: use real_dev instead of slave_dev (Jarod Wilson) [1860495]
- [netdrv] bonding: support hardware encryption offload to slaves (Jarod Wilson) [1860495]
- [netdrv] mlx5: become aware of when running as a bonding slave (Jarod Wilson) [1860495]
- [netdrv] ixgbe_ipsec: become aware of when running as a bonding slave (Jarod Wilson) [1860495]
- [net] xfrm: bail early on slave pass over skb (Jarod Wilson) [1860495]
- [netdrv] bonding: Fix reference count leak in bond_sysfs_slave_add (Jarod Wilson) [1860495]
- [netdrv] bonding: propagate transmit status (Jarod Wilson) [1860495]
- [netdrv] bonding: remove useless stats_lock_key (Jarod Wilson) [1860495]
- [netdrv] bonding: Implement ndo_get_xmit_slave (Jarod Wilson) [1860495]
- [netdrv] bonding: Add array of all slaves (Jarod Wilson) [1860495]
- [netdrv] bonding: Add function to get the xmit slave in active-backup mode (Jarod Wilson) [1860495]
- [netdrv] bonding: Add helper function to get the xmit slave in rr mode (Jarod Wilson) [1860495]
- [netdrv] bonding: Add helper function to get the xmit slave based on hash (Jarod Wilson) [1860495]
- [netdrv] bonding/alb: Add helper functions to get the xmit slave (Jarod Wilson) [1860495]
- [netdrv] bonding: Rename slave_arr to usable_slaves (Jarod Wilson) [1860495]
- [netdrv] bonding: Export skip slave logic to function (Jarod Wilson) [1860495]
- [netdrv] bonding: Remove inclusion of vermagic header (Jarod Wilson) [1860495]
- [netdrv] net/bond: Delete driver and module versions (Jarod Wilson) [1860495]

* Sun Nov 08 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-246.el8]
- [mm] powerpc/book3s64/radix: Fix boot failure with large amount of guest memory (Steve Best) [1854543]
- [powerpc] powerpc/book3s64/radix: Add kernel command line option to disable radix GTSE (Steve Best) [1854543]
- [powerpc] powerpc/prom: Enable Radix GTSE in cpu pa-features (Steve Best) [1854543]
- [powerpc] powerpc/mm/book3s64/radix: Off-load TLB invalidations to host when !GTSE (Steve Best) [1854543]
- [powerpc] powerpc/pseries: H_REGISTER_PROC_TBL should ask for GTSE only if enabled (Steve Best) [1854543]
- [powerpc] powerpc/mm: Enable radix GTSE only if supported (Steve Best) [1854543]
- [misc] powerpc/64s/radix: introduce options to disable use of the tlbie instruction (Steve Best) [1854543]
- [mm] powerpc/64s: remove unnecessary translation cache flushes at boot (Steve Best) [1854543]
- [mm] powerpc/64s/pseries: radix flush translations before MMU is enabled at boot (Steve Best) [1854543]
- [mm] powerpc/64s: make mmu_partition_table_set_entry TLB flush optional (Steve Best) [1854543]
- [mm] powerpc/64s/radix: tidy up TLB flushing code (Steve Best) [1854543]
- [mm] powerpc/64s: remove register_process_table callback (Steve Best) [1854543]
- [mm] powerpc/mm: Limit resize_hpt_for_hotplug() call to hash guests only (Steve Best) [1854543]
- [powerpc] powerpc/mm/radix: Create separate mappings for hot-plugged memory (Steve Best) [1854543]
- [mm] powerpc/mm/radix: Remove split_kernel_mapping() (Steve Best) [1854543]
- [mm] powerpc/mm/radix: Free PUD table when freeing pagetable (Steve Best) [1854543]
- [mm] powerpc/mm/radix: Fix PTE/PMD fragment count for early page table mappings (Steve Best) [1854543]
- [mm] powerpc/64s: Fix page table fragment refcount race vs speculative references (Steve Best) [1854543]
- [powerpc] powerpc/security: Fix link stack flush instruction (Gustavo Duarte) [1862103]
- [powerpc] powerpc/pseries: add new branch prediction security bits for link stack (Gustavo Duarte) [1862103]
- [powerpc] powerpc/security: Allow for processors that flush the link stack using the special bcctr (Gustavo Duarte) [1862103]
- [powerpc] powerpc/64s: Move branch cache flushing bcctr variant to ppc-ops.h (Gustavo Duarte) [1862103]
- [powerpc] powerpc/security: split branch cache flush toggle from code patching (Gustavo Duarte) [1862103]
- [powerpc] powerpc/security: make display of branch cache flush more consistent (Gustavo Duarte) [1862103]
- [powerpc] powerpc/security: change link stack flush state to the flush type enum (Gustavo Duarte) [1862103]
- [powerpc] powerpc/security: re-name count cache flush to branch cache flush (Gustavo Duarte) [1862103]
- [kernel] smp: Remove superfluous cond_func check in smp_call_function_many_cond() (Prarit Bhargava) [1882551]
- [kernel] smp: Remove allocation mask from on_each_cpu_cond.*() (Prarit Bhargava) [1882551]
- [kernel] smp: Add a smp_cond_func_t argument to smp_call_function_many() (Prarit Bhargava) [1882551]
- [kernel] smp: Use smp_cond_func_t as type for the conditional function (Prarit Bhargava) [1882551]
- [kernel] smp, cpumask: introduce on_each_cpu_cond_mask (Prarit Bhargava) [1882551]
- [kernel] smp: use __cpumask_set_cpu in on_each_cpu_cond (Prarit Bhargava) [1882551]
- [pci] PCI: Add support for root bus sizing (Myron Stowe) [1886036]
- [drm] PCI: Use ioremap(), not phys_to_virt() for platform ROM (Myron Stowe) [1886036]
- [pci] PCI: Avoid ASMedia XHCI USB PME# from D0 defect (Myron Stowe) [1886036]
- [pci] PCI/ACPI: Move pcie_to_hpx3_typefrom stack to static data (Myron Stowe) [1886036]
- [documentation] Documentation: PCI: Add background on Boot Interrupts (Myron Stowe) [1886036]
- [pci] PCI: Add boot interrupt quirk mechanism for Xeon chipsets (Myron Stowe) [1886036]
- [pci] PCI: Add PCIE_LNKCAP2_SLS2SPEED() macro (Myron Stowe) [1886036]
- [pci] PCI: Use pci_speed_string() for all PCI/PCI-X/PCIe strings (Myron Stowe) [1886036]
- [pci] PCI: Add pci_speed_string() (Myron Stowe) [1886036]
- [pci] PCI: Add 32 GT/s decoding in some macros (Myron Stowe) [1886036]
- [powerpc] powerpc/test_emulate_step: Move extern declaration to sstep.h (Desnes Augusto Nunes do Rosario) [1854542]
- [powerpc] powerpc/sstep: Introduce macros to retrieve Prefix instruction operands (Desnes Augusto Nunes do Rosario) [1854542]
- [powerpc] powerpc/test_emulate_step: Add negative tests for prefixed addi (Desnes Augusto Nunes do Rosario) [1854542]
- [powerpc] powerpc/test_emulate_step: Enhancement to test negative scenarios (Desnes Augusto Nunes do Rosario) [1854542]
- [netdrv] drivers/net/ibmvnic: Update VNIC protocol version reporting (Steve Best) [1882269]
- [s390] s390/zcrypt: fix kmalloc 256k failure (Claudio Imbrenda) [1885963]
- [x86] crypto: x86/aesni-gcm - fix crash on empty plaintext (Herbert Xu) [1882868]
- [x86] crypto: x86/aesni-gcm - make 'struct aesni_gcm_tfm_s' static const (Herbert Xu) [1882868]
- [x86] crypto: aesni - Add scatter/gather avx stubs, and use them in C (Herbert Xu) [1882868]
- [x86] crypto: aesni - Introduce partial block macro (Herbert Xu) [1882868]
- [x86] crypto: aesni - Introduce READ_PARTIAL_BLOCK macro (Herbert Xu) [1882868]
- [x86] crypto: aesni - Move ghash_mul to GCM_COMPLETE (Herbert Xu) [1882868]
- [x86] crypto: aesni - Fill in new context data structures (Herbert Xu) [1882868]
- [x86] crypto: aesni - Merge avx precompute functions (Herbert Xu) [1882868]
- [x86] crypto: aesni - Split AAD hash calculation to separate macro (Herbert Xu) [1882868]
- [x86] crypto: aesni - Add GCM_COMPLETE macro (Herbert Xu) [1882868]
- [x86] crypto: aesni - support 256 byte keys in avx asm (Herbert Xu) [1882868]
- [x86] crypto: aesni - Macro-ify func save/restore (Herbert Xu) [1882868]
- [x86] crypto: aesni - Introduce gcm_context_data (Herbert Xu) [1882868]
- [x86] crypto: aesni - Merge GCM_ENC_DEC (Herbert Xu) [1882868]
- [pci] PCI: Add DMA alias quirk for PLX PEX NTB (Myron Stowe) [1884657]
- [pci] PCI: Add nr_devfns parameter to pci_add_dma_alias() (Myron Stowe) [1884657]
- [pci] PCI: Fix pci_add_dma_alias() bitmask size (Myron Stowe) [1884657]
- [pci] PCI/IOV: Fix memory leak in pci_iov_add_virtfn() (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Add Gen4 device IDs (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Add Gen4 MRPC GAS access permission check (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Add Gen4 flash information interface support (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Add Gen4 system info register support (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Separate Gen3 register structures into unions (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Factor out Gen3 ioctl_flash_part_info() (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Add 'generation' variable (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Rename generation-specific constants (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Move check event ID from mask_event() to switchtec_event_isr() (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Remove redundant valid PFF number count (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Add support for Intercomm Notify and Upstream Error Containment (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Fix vep_vector_number ioread width (Myron Stowe) [1884657]
- [pci] PCI/switchtec: Use dma_set_mask_and_coherent() (Myron Stowe) [1884657]
- [pci] PCI: Allow adjust_bridge_window() to shrink resource if necessary (Myron Stowe) [1884657]
- [pci] PCI: Set resource size directly in adjust_bridge_window() (Myron Stowe) [1884657]
- [pci] PCI: Rename extend_bridge_window() to adjust_bridge_window() (Myron Stowe) [1884657]
- [pci] PCI: Rename extend_bridge_window() parameter (Myron Stowe) [1884657]
- [pci] PCI: Consider alignment of hot-added bridges when assigning resources (Myron Stowe) [1884657]
- [pci] PCI: Remove local variable usage in pci_bus_distribute_available_resources() (Myron Stowe) [1884657]
- [pci] PCI: Pass size + alignment to pci_bus_distribute_available_resources() (Myron Stowe) [1884657]
- [pci] PCI: Rename variables (Myron Stowe) [1884657]
- [pci] PCI: Remove unnecessary braces (Myron Stowe) [1884657]
- [pci] PCI: Don't disable bridge BARs when assigning bus resources (Myron Stowe) [1884657]
- [documentation] Documentation: PCI: Fix pci_alloc_irq_vectors() function name typo (Myron Stowe) [1884657]
- [pci] PCI: Increase D3 delay for AMD Ryzen5/7 XHCI controllers (Myron Stowe) [1884657]
- [pci] PCI: Add generic quirk for increasing D3hot delay (Myron Stowe) [1884657]
- [edac] x86/mce, EDAC/mce_amd: Print PPIN in machine check records (Prarit Bhargava) [1860381]

* Sat Nov 07 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-245.el8]
- [netdrv] geneve: add transport ports in route lookup for geneve (Mark Gray) [1884481] {CVE-2020-25645}
- [drm] PM: sleep: core: Rename DPM_FLAG_NEVER_SKIP (Ivan Vecera) [1867164]
- [base] PM: sleep: core: Drop racy and redundant checks from device_prepare() (Ivan Vecera) [1867164]
- [mm] mm/page_isolation: fix potential warning from user (Waiman Long) [1811009]
- [mm] mm/hotplug: silence a lockdep splat with printk() (Waiman Long) [1811009]
- [mm] mm/debug.c: always print flags in dump_page() (Waiman Long) [1811009]
- [mm] mm/debug.c: PageAnon() is true for PageKsm() pages (Waiman Long) [1811009]
- [mm] mm/debug.c: __dump_page() prints an extra line (Waiman Long) [1811009]
- [mm] mm: fix some typos in mm directory (Waiman Long) [1811009]
- [mm] mm, fault_around: do not take a reference to a locked page (Waiman Long) [1811009]
- [mm] mm: remove the exporting of totalram_pages (Waiman Long) [1880090]
- [mm] mm: remove managed_page_count_lock spinlock (Waiman Long) [1880090]
- [mm] mm: convert totalram_pages and totalhigh_pages variables to atomic (Waiman Long) [1880090]
- [mm] mm: convert zone->managed_pages to atomic variable (Waiman Long) [1880090]
- [net] mm: reference totalram_pages and managed_pages once per function (Waiman Long) [1880090]
- [mm] mm/page_alloc: Introduce free_area_init_core_hotplug (Waiman Long) [1880090]
- [mm] mm/page_alloc: inline function to handle CONFIG_DEFERRED_STRUCT_PAGE_INIT (Waiman Long) [1880090]
- [mm] mm: remove __paginginit (Waiman Long) [1880090]
- [mm] mm: access zone->node via zone_to_nid() and zone_set_nid() (Waiman Long) [1880090]
- [mm] mm, page_alloc: double zone's batchsize (Waiman Long) [1880090]
- [powerpc] powerpc/pseries/cmm: fix managed page counts when migrating pages between zones (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug: drain per-cpu pages again during memory offline (Chris von Recklinghausen) [1754739]
- [mm] mm: move nr_deactivate accounting to shrink_active_list() (Chris von Recklinghausen) [1754739]
- [mm] sh: fix build error in mm/init.c (Chris von Recklinghausen) [1754739]
- [mm] mm/memremap: set caching mode for PCI P2PDMA memory to WC (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug: add pgprot_t to mhp_params (Chris von Recklinghausen) [1754739]
- [mm] powerpc/mm: thread pgprot_t through create_section_mapping() (Chris von Recklinghausen) [1754739]
- [mm] x86/mm: thread pgprot_t through init_memory_mapping() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug: rename mhp_restrictions to mhp_params (Chris von Recklinghausen) [1754739]
- [include] mm/memory_hotplug: drop the flags field from struct mhp_restrictions (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: cleanup __add_pages() (Chris von Recklinghausen) [1754739]
- [mm] mm, hotplug: fix page online with DEBUG_PAGEALLOC compiled but not enabled (Chris von Recklinghausen) [1754739]
- [mm] arm64/mm: Enable memory hot remove (Chris von Recklinghausen) [1754739]
- [firmware] arm/efi: EFI soft reservation to memblock (Chris von Recklinghausen) [1754739]
- [mm] arm64: mm: convert mm/dump.c to use walk_page_range() (Chris von Recklinghausen) [1754739]
- [base] mm/memory_hotplug: drop valid_start/valid_end from test_pages_in_a_zone() (Chris von Recklinghausen) [1754739]
- [base] mm/memory_hotplug: pass in nid to online_pages() (Chris von Recklinghausen) [1754739]
- [mm] mm: remove "count" parameter from has_unmovable_pages() (Chris von Recklinghausen) [1754739]
- [base] mm: remove the memory isolate notifier (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Disable instrumentation in the EFI runtime handling code (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: avoid KASAN false positives when accessing the 1: 1 mapping (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Limit EFI old memory map to SGI UV machines (Chris von Recklinghausen) [1754739]
- [x86] efi/libstub/x86: Fix unused-variable warning (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Simplify mixed mode call wrapper (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Simplify 64-bit EFI firmware call wrapper (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Split SetVirtualAddresMap() wrappers into 32 and 64 bit versions (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Split off some old memmap handling into separate routines (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Re-disable RT services for 32-bit kernels running on 64-bit EFI (Chris von Recklinghausen) [1754739]
- [x86] efi/libstub: Distinguish between native/mixed not 32/64 bit (Chris von Recklinghausen) [1754739]
- [firmware] efi/libstub: Extend native protocol definitions with mixed_mode aliases (Chris von Recklinghausen) [1754739]
- [firmware] efi/libstub: Use a helper to iterate over a EFI handle array (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Rename efi_is_native() to efi_is_mixed() (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Unify 32/64-bit functions (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Convert GOP structures to typedef and clean up some types (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Remove unused typedef (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Remove bogus packed attribute from GOP structures (Chris von Recklinghausen) [1754739]
- [firmware] efi/libstub/random: Initialize pointer variables to zero for mixed mode (Chris von Recklinghausen) [1754739]
- [firmware] efi: Fix efi_loaded_image_t::unload type (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Fix memory leak in __gop_query32/64() (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Return EFI_SUCCESS if a usable GOP was found (Chris von Recklinghausen) [1754739]
- [firmware] efi/gop: Return EFI_NOT_FOUND if there are no usable GOPs (Chris von Recklinghausen) [1754739]
- [hv] mm/memory_hotplug.c: remove __online_page_set_limits() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: don't allow to online/offline memory blocks with holes (Chris von Recklinghausen) [1754739]
- [mm] mm/page_isolation.c: convert SKIP_HWPOISON to MEMORY_OFFLINE (Chris von Recklinghausen) [1754739]
- [mm] mm/page_alloc.c: don't set pages PageReserved() when offlining (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug: remove __online_page_free() and __online_page_increment_counters() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: add a bounds check to __add_pages() (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Fix NMI vs ESPFIX (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Unwind the ESPFIX stack earlier on exception entry (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Move FIXUP_FRAME after pushing fs in SAVE_ALL (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Simplify common_exception (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Use ss segment where required (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Fix IRET exception (Chris von Recklinghausen) [1754739]
- [x86] x86/xen/32: Make xen_iret_crit_fixup() independent of frame layout (Chris von Recklinghausen) [1754739]
- [x86] x86/stackframe/32: Repair 32-bit Xen PV (Chris von Recklinghausen) [1754739]
- [x86] x86/stackframe/32: Allow int3_emulate_push() (Chris von Recklinghausen) [1754739]
- [x86] x86: Hide the int3_emulate_call/jmp functions from UML (Chris von Recklinghausen) [1754739]
- [x86] ftrace/x86_64: Emulate call function while updating in breakpoint handler (Chris von Recklinghausen) [1754739]
- [x86] x86/stackframe/32: Provide consistent pt_regs (Chris von Recklinghausen) [1754739]
- [x86] kprobes, x86/ptrace.h: Make regs_get_kernel_stack_nth() not fault on bad stack (Chris von Recklinghausen) [1754739]
- [x86] x86/stackframe, x86/ftrace: Add pt_regs frame annotations (Chris von Recklinghausen) [1754739]
- [x86] x86/stackframe, x86/kprobes: Fix frame pointer annotations (Chris von Recklinghausen) [1754739]
- [x86] x86/stackframe: Move ENCODE_FRAME_POINTER to asm/frame.h (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Clean up return from interrupt preemption path (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Simulation mode (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Switch to balloon_page_alloc() (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Implement balloon compaction (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Convert loaned_pages to an atomic_long_t (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Rip out memory isolate notifier (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Use adjust_managed_page_count() insted of totalram_pages_* (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Drop page array (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Cleanup rc handling in cmm_init() (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Report errors when registering notifiers fails (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries/cmm: Implement release() function for sysfs device (Chris von Recklinghausen) [1754739]
- [x86] x86/efi: Push EFI_MEMMAP check into leaf routines (Chris von Recklinghausen) [1754739]
- [mm] powerpc: Don't flush caches when adding memory (Chris von Recklinghausen) [1754739]
- [firmware] efi/random: use arch-independent efi_call_proto() (Chris von Recklinghausen) [1754739]
- [x86] x86/dumpstack/64: Don't evaluate exception stacks before setup (Chris von Recklinghausen) [1754739]
- [xen] xen/balloon: Mark pages PG_offline in balloon_append() (Chris von Recklinghausen) [1754739]
- [xen] xen/balloon: Drop __balloon_append() (Chris von Recklinghausen) [1754739]
- [xen] xen/balloon: Set pages PageOffline() in balloon_add_region() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: prevent memory leak when reusing pgdat (Chris von Recklinghausen) [1754739]
- [base] drivers/base/memory.c: don't store end_section_nr in memory blocks (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug: remove move_pfn_range() (Chris von Recklinghausen) [1754739]
- [mm] mm: introduce compound_nr() (Chris von Recklinghausen) [1754739]
- [x86] x86/asm: Make some functions local labels (Chris von Recklinghausen) [1754739]
- [firmware] efi-stub: Fix get_efi_config_table on mixed-mode setups (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: move UV_SYSTAB handling into arch/x86 (Chris von Recklinghausen) [1754739]
- [x86] efi: x86: move efi_is_table_address() into arch/x86 (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: remove unneeded return for void function (Chris von Recklinghausen) [1754739]
- [x86] x86/uaccess: Remove redundant CLACs in getuser/putuser error paths (Chris von Recklinghausen) [1754739]
- [x86] x86/uaccess: Remove ELF function annotation from copy_user_handle_tail() (Chris von Recklinghausen) [1754739]
- [x86] x86/entry: Fix thunk function ELF sizes (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/64: Simplify idtentry a little (Chris von Recklinghausen) [1754739]
- [mm] mm: vmscan: correct some vmscan counters for THP swapout (Chris von Recklinghausen) [1754739]
- [mm] mm/gup: speed up check_and_migrate_cma_pages() on huge page (Chris von Recklinghausen) [1754739]
- [x86] x86/ldt: Initialize the context lock for init_mm (Chris von Recklinghausen) [1754739]
- [powerpc] powerpc/pseries: avoid blocking in irq when queuing hotplug events (Chris von Recklinghausen) [1754739]
- [arm64] arm64/mm: don't initialize pgd_cache twice (Chris von Recklinghausen) [1754739]
- [mm] mm/vmscan.c: fix recent_rotated history (Chris von Recklinghausen) [1754739]
- [x86] efi/x86/Add missing error handling to old_memmap 1:1 mapping code (Chris von Recklinghausen) [1754739]
- [mm] arm64/mm: Inhibit huge-vmap with ptdump (Chris von Recklinghausen) [1754739]
- [mm] mm/vmscan.c: simplify shrink_inactive_list() (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: cleanup memory offline path (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: fix the wrong usage of N_HIGH_MEMORY (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: drop redundant hugepage_migration_supported check (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: unlock 1GB-hugetlb on x86_64 (Chris von Recklinghausen) [1754739]
- [mm] mm: move recent_rotated pages calculation to shrink_inactive_list() (Chris von Recklinghausen) [1754739]
- [mm] x86/mm: Initialize PGD cache during mm initialization (Chris von Recklinghausen) [1754739]
- [x86] x86/alternatives: Initialize temporary mm for patching (Chris von Recklinghausen) [1754739]
- [mm] x86/mm: Fix a crash with kmemleak_scan() (Chris von Recklinghausen) [1754739]
- [x86] x86/irq: Fix outdated comments (Chris von Recklinghausen) [1754739]
- [mm] mm/hotplug: treat CMA pages as unmovable (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Remove stack overflow debug code (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Remap the IRQ stack with guard pages (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Split the IRQ stack into its own pages (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Init hardirq_stack_ptr during CPU hotplug (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/32: Handle irq stack allocation failure proper (Chris von Recklinghausen) [1754739]
- [xen] x86/irq/32: Invoke irq_ctx_init() from init_IRQ() (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Rename irq_stack_ptr to hardirq_stack_ptr (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/32: Rename hard/softirq_stack to hard/softirq_stack_ptr (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/32: Make irq stack a character array (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/32: Define IRQ_STACK_SIZE (Chris von Recklinghausen) [1754739]
- [x86] x86/dumpstack/64: Speedup in_exception_stack() (Chris von Recklinghausen) [1754739]
- [x86] x86/exceptions: Split debug IST stack (Chris von Recklinghausen) [1754739]
- [x86] x86/exceptions: Enable IST guard pages (Chris von Recklinghausen) [1754739]
- [x86] x86/exceptions: Disconnect IST index and stack order (Chris von Recklinghausen) [1754739]
- [x86] x86/cpu: Remove orig_ist array (Chris von Recklinghausen) [1754739]
- [x86] x86/cpu: Prepare TSS.IST setup for guard pages (Chris von Recklinghausen) [1754739]
- [x86] x86/dumpstack/64: Use cpu_entry_area instead of orig_ist (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Use cpu entry area instead of orig_ist (Chris von Recklinghausen) [1754739]
- [mm] x86/traps: Use cpu_entry_area instead of orig_ist (Chris von Recklinghausen) [1754739]
- [mm] x86/cpu_entry_area: Provide exception stack accessor (Chris von Recklinghausen) [1754739]
- [mm] x86/cpu_entry_area: Prepare for IST guard pages (Chris von Recklinghausen) [1754739]
- [x86] x86/exceptions: Add structs for exception stacks (Chris von Recklinghausen) [1754739]
- [mm] x86/cpu_entry_area: Cleanup setup functions (Chris von Recklinghausen) [1754739]
- [x86] x86/exceptions: Make IST index zero based (Chris von Recklinghausen) [1754739]
- [x86] x86/exceptions: Remove unused stack defines on 32bit (Chris von Recklinghausen) [1754739]
- [x86] x86/64: Remove stale CURRENT_MASK (Chris von Recklinghausen) [1754739]
- [x86] x86/idt: Remove unused macro SISTG (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Sanitize the top/bottom confusion (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Remove a hardcoded irq_stack_union access (Chris von Recklinghausen) [1754739]
- [x86] x86/dumpstack: Fix off-by-one errors in stack identification (Chris von Recklinghausen) [1754739]
- [x86] x86/irq/64: Limit IST stack overflow check to #DB stack (Chris von Recklinghausen) [1754739]
- [mm] arm64: mm: Consolidate early page table allocation (Chris von Recklinghausen) [1754739]
- [mm] arm64: mm: don't call page table ctors for init_mm (Chris von Recklinghausen) [1754739]
- [mm] arm64: mm: use appropriate ctors for page tables (Chris von Recklinghausen) [1754739]
- [x86] x86/uaccess: Move copy_user_handle_tail() into asm (Chris von Recklinghausen) [1754739]
- [mm] mm/page_isolation.c: fix a wrong flag in set_migratetype_isolate() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: fix notification in offline error path (Chris von Recklinghausen) [1754739]
- [mm] mm/hotplug: fix an imbalance with DEBUG_PAGEALLOC (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: explicitly pass the head to isolate_huge_page (Chris von Recklinghausen) [1754739]
- [mm] mm/vmscan.c: do not allocate duplicate stack variables in shrink_page_list() (Chris von Recklinghausen) [1754739]
- [mm] mm: refactor swap-in logic out of shmem_getpage_gfp (Chris von Recklinghausen) [1754739]
- [mm] mm/vmscan.c: remove 7th argument of isolate_lru_pages() (Chris von Recklinghausen) [1754739]
- [mm] mm: remove extra drain pages on pcp list (Chris von Recklinghausen) [1754739]
- [mm] mm/memory-hotplug: Allow memory resources to be children (Chris von Recklinghausen) [1754739]
- [kernel] mm/resource: Move HMM pr_debug() deeper into resource code (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: fix off-by-one in is_pageblock_removable (Chris von Recklinghausen) [1754739]
- [mm] x86/cpu_entry_area: Move percpu_setup_debug_store() to __init section (Chris von Recklinghausen) [1754739]
- [mm] arm64: ptdump: Don't iterate kernel page tables using PTRS_PER_PXX (Chris von Recklinghausen) [1754739]
- [firmware] efi: Use 32-bit alignment for efi_guid_t (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: __offline_pages fix wrong locking (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: test_pages_in_a_zone do not pass the end of zone (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: is_mem_section_removable do not pass the end of a zone (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: don't bail out in do_migrate_range() prematurely (Chris von Recklinghausen) [1754739]
- [mm] arm64: dump: no need to check return value of debugfs_create functions (Chris von Recklinghausen) [1754739]
- [x86] x86/asm/suspend: Drop ENTRY from local data (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: deobfuscate migration part of offlining (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: try to migrate full pfn range (Chris von Recklinghausen) [1754739]
- [mm] mm, hotplug: move init_currently_empty_zone() under zone_span_lock protection (Chris von Recklinghausen) [1754739]
- [mm] mm: only report isolation failures when offlining memory (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: be more verbose for memory offline failures (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: print reason for the offlining failure (Chris von Recklinghausen) [1754739]
- [mm] mm, memory_hotplug: drop pointless block alignment checks from __offline_pages (Chris von Recklinghausen) [1754739]
- [x86] x86/efi: Don't unmap EFI boot services code/data regions for EFI_OLD_MEMMAP and EFI_MIXED_MODE (Chris von Recklinghausen) [1754739]
- [x86] kprobes/x86: Blacklist non-attachable interrupt functions (Chris von Recklinghausen) [1754739]
- [include] linkage: add generic GLOBAL() macro (Chris von Recklinghausen) [1754739]
- [x86] x86/efi: Move efi_<reserve/free>_boot_services() to arch/x86 (Chris von Recklinghausen) [1754739]
- [x86] x86/efi: Unmap EFI boot services code/data regions from efi_pgd (Chris von Recklinghausen) [1754739]
- [mm] x86/mm/pageattr: Introduce helper function to unmap EFI boot services (Chris von Recklinghausen) [1754739]
- [x86] x86/fpu: Use the correct exception table macro in the XSTATE_OP wrapper (Chris von Recklinghausen) [1754739]
- [firmware] efi/arm/libstub: Pack FDT after populating it (Chris von Recklinghausen) [1754739]
- [x86] x86/traps: Complete prototype declarations (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: clean up node_states_check_changes_offline() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: simplify node_states_check_changes_online (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: tidy up node_states_clear_node() (Chris von Recklinghausen) [1754739]
- [mm] mm/memory_hotplug.c: spare unnecessary calls to node_set_state (Chris von Recklinghausen) [1754739]
- [include] include/linux/linkage.h: align weak symbols (Chris von Recklinghausen) [1754739]
- [mm] shmem: Convert shmem_add_to_page_cache to XArray (Chris von Recklinghausen) [1754739]
- [mm] shmem: Convert shmem_radix_tree_replace to XArray (Chris von Recklinghausen) [1754739]
- [mm] mm: Convert add_to_swap_cache to XArray (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Clear the CS high bits (Chris von Recklinghausen) [1754739]
- [x86] x86-32, hibernate: Set up temporary text mapping for 32bit system (Chris von Recklinghausen) [1754739]
- [x86] x86-32, hibernate: Switch to original page table after resumed (Chris von Recklinghausen) [1754739]
- [x86] x86-32, hibernate: Enable CONFIG_ARCH_HIBERNATION_HEADER on 32bit system (Chris von Recklinghausen) [1754739]
- [x86] x86, hibernate: Extract the common code of 64/32 bit system (Chris von Recklinghausen) [1754739]
- [x86] x86-32/asm/power: Create stack frames in hibernate_asm_32.S (Chris von Recklinghausen) [1754739]
- [x86] PM / hibernate: Check the success of generating md5 digest before hibernation (Chris von Recklinghausen) [1754739]
- [x86] x86/efi: Load fixmap GDT in efi_call_phys_epilog() before setting cr3 (Chris von Recklinghausen) [1754739]
- [x86] x86/xen: Move pv irq related functions under CONFIG_XEN_PV umbrella (Chris von Recklinghausen) [1754739]
- [x86] x86/extable: Introduce _ASM_EXTABLE_UA for uaccess fixups (Chris von Recklinghausen) [1754739]
- [x86] x86/efi: Load fixmap GDT in efi_call_phys_epilog() (Chris von Recklinghausen) [1754739]
- [tools] tools arch: Update arch/x86/lib/memcpy_64.S copy used in 'perf bench mem memcpy' (Chris von Recklinghausen) [1754739]
- [mm] x86/mm: Remove redundant check for kmem_cache_create() (Chris von Recklinghausen) [1754739]
- [x86] x86/power/hibernate_64: Remove VLA usage (Chris von Recklinghausen) [1754739]
- [firmware] efi: Deduplicate efi_open_volume() (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Merge 32-bit and 64-bit UGA draw protocol setup routines (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Align efi_uga_draw_protocol typedef names to convention (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Merge the setup_efi_pci32() and setup_efi_pci64() routines (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Prevent reentrant firmware calls in mixed mode (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Add debug code to check entry/exit CR3 (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Add PTI CR3 switches to NMI handler code (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Add PTI cr3 switch to non-NMI entry/exit points (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Handle Entry from Kernel-Mode on Entry-Stack (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Introduce SAVE_ALL_NMI and RESTORE_ALL_NMI (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Leave the kernel via trampoline stack (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Enter the kernel via trampoline stack (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Load task stack from x86_tss.sp1 in SYSENTER handler (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Split off return-to-kernel path (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Unshare NMI return path (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Put ESPFIX code into a macro (Chris von Recklinghausen) [1754739]
- [x86] x86/entry/32: Rename TSS_sysenter_sp0 to TSS_entry2task_stack (Chris von Recklinghausen) [1754739]
- [x86] efi/x86: Clean up the eboot code (Chris von Recklinghausen) [1754739]
- [x86] x86/asm/64: Use 32-bit XOR to zero registers (Chris von Recklinghausen) [1754739]
- [x86] Revert "x86/platform/uv: Mark uv_bios_call() and uv_bios_call_irqsave() static" (Frank Ramsay) [1833121]
- [x86] Revert "x86/platform/uv: Unexport sn_coherency_id" (Frank Ramsay) [1833121]
- [x86] Revert "x86/platform/uv: Unexport symbols only used by x2apic_uv_x.c" (Frank Ramsay) [1833121]
- [x86] x86/apic: Cleanup the include maze (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Fix missing checks of kcalloc() return values (Frank Ramsay) [1833121]
- [x86] x86/platform/UV: Replace kmalloc() and memset() with kalloc() calls (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Remove the unused _uv_cpu_blade_processor_id() macro (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Unexport uv_apicid_hibits (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Remove _uv_hub_info_check() (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Simplify uv_send_IPI_one() (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Mark uv_min_hub_revision_id static (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Mark is_uv_hubless() static (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Remove the UV*_HUB_IS_SUPPORTED macros (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Unexport symbols only used by x2apic_uv_x.c (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Unexport sn_coherency_id (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Remove the uv_partition_coherence_id() macro (Frank Ramsay) [1833121]
- [x86] x86/platform/uv: Mark uv_bios_call() and uv_bios_call_irqsave() static (Frank Ramsay) [1833121]
- [x86] x86/platform/UV: Mark memblock related init code and data correctly (Frank Ramsay) [1833121]
- [x86] x86/platform/UV: Remove unnecessary #ifdef CONFIG_EFI (Frank Ramsay) [1833121]
- [x86] x86/platform/UV: Remove uv_bios_call_reentrant() (Frank Ramsay) [1833121]
- [x86] x86/platform/UV: Use efi_enabled() instead of test_bit() (Frank Ramsay) [1833121]
- [x86] x86/apic/uv: Remove code for unused distributed GRU mode (Frank Ramsay) [1833121]

* Fri Nov 06 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-244.el8]
- [thermal] thermal/x86_pkg_temp: Make pkg_temp_lock a raw_spinlock_t (Prarit Bhargava) [1890657]
- [net] sched: act_tunnel_key: fix OOB write in case of IPv6 ERSPAN tunnels (Davide Caratti) [1889601]
- [netdrv] ibmveth: Identify ingress large send packets (Gustavo Duarte) [1887038]
- [netdrv] ibmveth: Switch order of ibmveth_helper calls (Gustavo Duarte) [1887038]
- [sound] ALSA: redhat: add drivers/soundwire tree and regmap-sdw to the redhat/filter-modules.sh (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC - enable AMD Renoir support for DMIC (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC - enable the Intel's SoundWire driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: fix incorrect locking in hdmi_pcm_close (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fix jack detection with Realtek codecs when in D3 (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireworks: use semicolons rather than commas to separate statements (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: use semicolons rather than commas to separate statements (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/i915 - fix list corruption with concurrent probes (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - The front Mic on a HP machine doesn't work (Jaroslav Kysela) [1869536]
- [sound] ALSA: hdspm: Fix typo arbitary (Jaroslav Kysela) [1869536]
- [sound] ALSA: bebob: potential info leak in hwdep_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS D700SA with ALC887 (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: endpoint.c: fix repeated word 'there' (Jaroslav Kysela) [1869536]
- [sound] ALSA: portman2x4: fix repeated word 'if' (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add mute Led support for HP Elitebook 845 G7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: loader: handle all SOF_IPC_EXT types (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: haswell: Mark FE DAIs as nonatomic (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: broadwell: Mark FE DAIs as nonatomic (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: Mark FE DAIs as nonatomic (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add version_id to avoid rt714/rt715 confusion (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt715-sdw: probe with RT714 Device ID (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt1316: add missing component string (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt1308: add extra check on init (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qdsp6: add ifdef CONFIG_OF around of_device_id (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-cpu: Enable MI2S BCLK and LRCLK together (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt700: add codec prefix (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Remove unused variables (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Remove ti, asi-format code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Set regcache when shutting down and waking device (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Add shutdown capability via a GPIO (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Remove duplicate code for I/V sense (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASOC: Intel: sof_sdw: restore playback functionality with max98373 amps (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: add support for new SoundWire hardware layout on TGL (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: remove hard-coded codec_conf table (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: remove ternary operator (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra_max98090: use devm_snd_soc_register_card() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: hda_dsp_common: use static function in conditional block (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: mx27vis-aic32x4: use devm_snd_soc_register_card() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: imx-mc13783: use devm_snd_soc_register_card() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm_adsp: Pass full name to snd_ctl_notify (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt715: Add power-up delay to fix dmic pop sound issue (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Enable the power of "MICBIAS" and "Vref2" for the DMIC clock (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hda: allow runtime pm at end of probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: add codec name prefix to ACPI machine description (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: sysfs: add slave status and device number before probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: add enumerated Slave device to device list (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: remove an unnecessary NULL check (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: cadence: add data port test fail interrupt (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: enable test modes (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: enable Data Port test modes (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - set mic to auto detect on a HP AIO machine (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - Don't register a cb func if it is registered already (Jaroslav Kysela) [1869536]
- [sound] ALSA: HDA: Early Forbid of runtime PM (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - remove kerneldoc for internal hdac_i915 function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ctl: Workaround for lockdep warning wrt card->ctl_files_rwlock (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Disable autosuspend for Lenovo ThinkStation P620 (Jaroslav Kysela) [1869536]
- [sound] ALSA: treewide: Remove uninitialized_var() usage (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: arm: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: add dpcm_create/remove_debugfs_state() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: move CONFIG_DEBUG_FS functions to top side (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: magician: convert to use i2c_new_client_device() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: Enable AC'97 bus support for PXA machines (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: Select regmap from AC'97 machines (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: support TDM out and 8ch I2S out (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: kirkwood: fix external clock probe defer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ppc: keywest: convert to use i2c_new_client_device() (Jaroslav Kysela) [1869536]
- [sound] ALSA: treewide: Use sizeof_field() macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: Set ops to NULL on remove (Jaroslav Kysela) [1869536]
- [sound] ALSA: ppc: More constifications (Jaroslav Kysela) [1869536]
- [sound] ALSA: i2c: Constify snd_kcontrol_new items (Jaroslav Kysela) [1869536]
- [sound] ALSA: ppc: Constify snd_kcontrol_new items (Jaroslav Kysela) [1869536]
- [sound] ALSA: vxpocket: Support PCM sync_stop (Jaroslav Kysela) [1869536]
- [sound] ALSA: mips: Constify snd_device_ops definitions (Jaroslav Kysela) [1869536]
- [sound] ALSA: i2c: Constify snd_device_ops definitions (Jaroslav Kysela) [1869536]
- [sound] ALSA: seq: oss: Fix running status after receiving sysex (Jaroslav Kysela) [1869536]
- [sound] ALSA: arm: More constification (Jaroslav Kysela) [1869536]
- [sound] ALSA: treewide: add "WITH Linux-syscall-note" to SPDX tag of uapi headers (Jaroslav Kysela) [1869536]
- [sound] ALSA: treewide: replace '---help---' in Kconfig files with 'help' (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: fix SPDX license for header file (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac: make SOF HDA codec driver probe deterministic (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Refactor sample rate function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Fix the spacing and new lines (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Convert bit mask to GENMASK in header (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Fix unbalanced calls to pm_runtime (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Add the TAS2110 class-D amplifier (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: control: add size checks for ext_bytes control .put() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: control: fix size checks for volatile ext_bytes control .get() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: control: fix size checks for ext_bytes control .get() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tlv320aic32x4: Enable fast charge (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tlv320aic32x4: Ensure a minimum delay before clock stabilization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt711: wait for the delayed work to finish when the system suspends (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Fix error handling with update_bits (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Fix required DT properties in the code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Add missing bias level power states (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Fix calling reset in probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt700: wait for the delayed work to finish when the system suspends (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Add the TAS2564 compatible (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: add missing MODULE_LICENSE() for imx-common (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: pm: Fix prepare callback behavior for OF usecase (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: cs42l51: add additional ADC volume controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: fix the process being scheduled on core0 always (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - fix CONTROLLER_IN_GPU macro name (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - handle multiple i915 device instances (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - controller is in GPU on the DG1 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - add Intel DG1 PCI and HDMI ids (Jaroslav Kysela) [1869536]
- [sound] ALSA: Revert "ALSA: hda - Fix silent audio output and corrupted input on MSI X570-A PRO" (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add delay quirk for H570e USB headsets (Jaroslav Kysela) [1869536]
- [sound] ALSA: compat_ioctl: avoid compat_alloc_user_space (Jaroslav Kysela) [1869536]
- [sound] ALSA: asihpi: fix spellint typo in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Enable front panel headset LED on Lenovo ThinkStation P520 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Couldn't detect Mic if booting with headset plugged (Jaroslav Kysela) [1869536]
- [sound] ALSA: asihpi: fix iounmap in error handler (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: use {u32|u16}p_replace_bits (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: cadence: use u32p_replace_bits (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: get max rows and cols info from compatible (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: add support to block packing mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: clear BIT FIELDs before value set (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: Add generic bandwidth allocation algorithm (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ak4458: Add DSD support for ak4458 and ak4497 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-sc7180: Add MODULE_DEVICE_TABLE (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Add support for tgl-h (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codec: tlv320aic32x4: do software reset before clock registration (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codec: tlv320aic32x4: fix missing aic32x4_disable_regulators() in error path (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Set MCLK input or output direction (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Add fsl_sai_check_version function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Add new added registers and new bit definition (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6afe-clocks: add q6afe clock controller (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: reduce verbosity of boot error logs (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: fix range checks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: remove several superfluous type-casts (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: (cosmetic) remove redundant "ret" variable uses (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: control: update test for pm_runtime_get_sync() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: debug: update test for pm_runtime_get_sync() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Add `src_hash` to `sof_ipc_fw_version` structure (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: Add debug support for imx platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: disable size checks for bytes_ext controls if needed (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_audmix: make clock and output src write only (Jaroslav Kysela) [1869536]
- [sound] ALSA: remove calls to usb_pipe_type_check for control endpoints (Jaroslav Kysela) [1869536]
- [sound] ALSA: hiface: move to use usb_control_msg_send() (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: move to use usb_control_msg_send() and usb_control_msg_recv() (Jaroslav Kysela) [1869536]
- [sound] ALSA: 6fire: move to use usb_control_msg_send() and usb_control_msg_recv() (Jaroslav Kysela) [1869536]
- [sound] ALSA: usx2y: move to use usb_control_msg_send() (Jaroslav Kysela) [1869536]
- [sound] ALSA: USB: add usb_control_msg_send() and usb_control_msg_recv() (Jaroslav Kysela) [1869536]
- [sound] ALSA: USB: move snd_usb_pipe_sanity_check into the USB core (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: Fix the failure to flush DAC data before playback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: Fix DC calibration on bypass boost mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: stm32: sai: add pm_runtime support (Jaroslav Kysela) [1869536]
- [sound] ALSA: rockchip_i2s: fix a possible divide-by-zero bug in rockchip_i2s_hw_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Use DMI oem string search for tgl_max98373_rt5682 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda-loader: s/master/primary (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: remove the HDA_DSP_CORE_MASK() macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: modify core_power_up/down op (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: rename cores_mask to host_managed_cores_mask (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: j721e-evm: Add support for j7200-cpb audio (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: support machine driver with rt1015p (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe-dai: add support to Codec DMA ports (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe: add codec lpass clocks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe: update q6afe_set_param to support global clocks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe: add lpass hw voting support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe: add global q6afe waitqueue (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe: prepare afe_apr_send_pkt to take response opcode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6routing: add support to Codec DMA ports (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6dsp: q6afe: add support to Codec DMA ports (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qdsp6: dt-bindings: Add q6afe display_port dt binding (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015p: add codec driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: cadence: add parity error injection through debugfs (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: export broadcast read/write capability for tests (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: realtek-soundwire: ignore initial PARITY errors (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: use quirk to filter out invalid parity errors (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: slave: add first_interrupt_done status (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: filter-out unwanted interrupt reports (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC/soundwire: bus: use property to set interrupt masks (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: Remove unused inline function snd_mask_sizeof (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/asihpi: Remove unused function hpi_stream_group_get_map() (Jaroslav Kysela) [1869536]
- [sound] ALSA: mixart: Correct comment wrt obsoleted tasklet usage (Jaroslav Kysela) [1869536]
- [sound] ALSA: aloop: Replace tasklet with work (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mchp-spdiftx: add driver for S/PDIF TX Controller (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: fix SLIBMUS/SLIMBUS typo (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: cadence: fix race condition between suspend and Slave device alerts (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: imx-es8328: add missing put_device() call in imx_es8328_probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: Parse auxiliary devices from device tree (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mt6359: fix failed to parse DT properties (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Implement snd_sof_bytes_ext_volatile_get kcontrol IO (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: Add support for WO and RO TLV byte kcontrols (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: Kconfig: Allow the j721e machine driver to be used on K3 platform (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: KeemBay: Fix warning potential ! vs ~ typo (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: add v1.5.1 compatible (Jaroslav Kysela) [1869536]
- [sound] ALSA: dt-bindings: soundwire: add bindings for Qcom controller (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: add support for mmio soundwire master devices (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: avoid dependency on CONFIG_SLIMBUS (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: fix abh/ahb typo (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: make process type optional (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_mux (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_process (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_tone (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_asrc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_src (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_host (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_volume (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_mixer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: append extended data to sof_ipc_comp_dai (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: add helper for setting up IPC component (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: use the sof_ipc_comp reserved bytes for extended data (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: parse comp_ext_tokens for all widgets (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: create component extended tokens (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: add comp_ext to struct snd_sof_widget (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: tokens: add token for component UUID (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Manage module clock via DAPM (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Attach the bus clock to the regmap (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Sort masks in a consistent order (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Fix field bit number indentation (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Fix ADC_DIG_CTRL field name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Fix AIF1_MXR_SRC field names (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Fix AIF1_ADCDAT_CTRL field names (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Fix AIF1 MODCLK widget name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Remove extraneous widgets (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add dailink .prepare and .hw_free callback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add dailink .trigger callback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: clarify return value for get_sdw_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: remove stream handling from .prepare and .hw_free (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: remove .trigger operation (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: fix NULL/ERR_PTR confusion (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: stream: fix NULL/IS_ERR confusion (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: remove SDW_REG_SHIFT() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel_init: use FIELD_{GET|PREP} (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: use FIELD_{GET|PREP} (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: cadence: use FIELD_{GET|PREP} (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom : use FIELD_{GET|PREP} (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: stream: use FIELD_{GET|PREP} (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: slave: use SDW_DISCO_LINK_ID() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: use FIELD_GET() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: define and use addr bit masks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: fix core enable sequence (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: support topology components on secondary cores (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: add a "core" parameter to widget loading functions (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Set SAI Channel Mode to Output Mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Support multiple data channel enable bits (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: don't manage link power individually (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: pass link_mask information to each master (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add error log for clock-stop invalid configs (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: stream: enable hw_sync as needed by hardware (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add multi-link hw_synchronization information (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: update multi-link definition with hw sync details (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add missing support for all clock stop modes (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add multi-link support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: ignore software command retries (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: disable shim wake on suspend (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: fix port_readydynamic allocation in mipi_disco (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: add definition for maximum number of ports (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: soundwire: remove port_readyusage from codecs (Jaroslav Kysela) [1869536]
- [sound] ALSA: vx: vx_pcm: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: vx: vx_pcm: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: vx: vx_core: clarify operator precedence (Jaroslav Kysela) [1869536]
- [sound] ALSA: rawmidi: (cosmetic) align function parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: atmel: ac97: clarify operator precedence (Jaroslav Kysela) [1869536]
- [sound] ALSA: ac97: (cosmetic) align argument names (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb: scarless_gen2: fix endianness issue (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: (cosmetic) align function parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: auto_parser: remove shadowed variable declaration (Jaroslav Kysela) [1869536]
- [sound] ALSA: aoa: i2sbus: use DECLARE_COMPLETION_ONSTACK() macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: init: use DECLARE_COMPLETION_ONSTACK() macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: compress_offload: remove redundant initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: compress_offload: dereference after checking for NULL pointer (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: timer: clarify operator precedence (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: timer: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: pcm_memory: dereference pointer after NULL checks (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: pcm: simplify locking for timers (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Prefer async probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: remove artificial component and DAI name constraint (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: shutdown codec when changing filter type (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: AMD: Clean kernel log from deferred probe error messages (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: Simplify error handling during FW boot (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: Add sof_tgl_ops for TGL platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: Define FW boot sequence with ICCMAX (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: define macro for code loader stream format (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: modify the signature of get_stream_with_tag() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: Add helper function to program ICCMAX stream (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: Remove unused parameters in cl_dsp_init() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fix VS_LTRC register name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: sof-of-dev: Add .arch_ops field (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: Replace sdev->private with sdev->pdata->hw_pdata (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: add extended rom status dump to error log (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: fix the ipc_size calculation for process component (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: intel: hda: support also devices with 1 and 3 dmics (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: fix a runtime pm issue in SOF when HDMI codec doesn't work (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: report error only for the last ROM init iteration (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: loader: Add debug box region (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: Parse debug ABI version (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: loader: fix memory leak in get_ext_windows (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: IPC: make sof_ipc_window monosized (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: fix intel_suspend/resume defined but not used warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add AE-7 exit commands (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add AE-7 custom controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add AE-7 microphone selection commands (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add output selection for SoundBlaster AE-7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add DSP setup functions for AE-7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add init data for SoundBlaster AE-7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add pre-init function for SoundBlaster AE-7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add ca0132_mmio_init data for SoundBlaster AE-7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Set AE-7 bools and select mixer (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add SoundBlaster AE-7 pincfg (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add new quirk ID for SoundBlaster AE-7 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Fix Recon3D Center/LFE output (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add quirk output selection structures (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_alt_out_select (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Remove surround output selection (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add bass redirection controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add full-range speaker selection controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add surround channel config control (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add speaker tuning initialization commands (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Cleanup ca0132_mmio_init function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hdmi: tidy up a memset() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: use consistent HDAudio spelling in comments/docs (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: add dev_dbg log when driver is not selected (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: acpi: add dev_dbg() log for probe completion (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: IPC: reduce verbosity of IPC pointer updates (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: reduce the log level for unhandled widgets (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: remove unnecessary memory alloc for sdev->private (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: (cosmetic) use the "bool" type where it makes sense (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: (cosmetic) remove redundant variable initialisations (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Add -EPROBE_DEFER check for regmap init (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ak5558: Add regulator support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: clean-up inclusion of header files (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: sof_sdw: add rt711 rt1316 rt714 SDCA codec support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Add topology filename override based on dmi data match (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_rt5682: override quirk data for tgl_max98373_rt5682 (Jaroslav Kysela) [1869536]
- [sound] ALSA: SoC: Intel: sof_sdw: Add support for product Ripto (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: rename id as part_id (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: check SoundWire version when matching codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max98373-sdw: add missing test on resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: soc-acpi: add support for SDCA boards (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: soc-acpi: mirror CML and TGL configurations (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof-soundwire: add support for rt5682 on link2 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: soc-acpi: cnl: add support for rt5682 on SoundWire link2 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: modify SoundWire version id in acpi match table (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Correct wrongly matching entries with audio class (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7219: Fix I/O voltage range configuration during probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: sof_sdw: add .exit callback function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: add support for TLV320AIC32x4 codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: add build support for SoundWire (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: add missing out of memory check on drvdata->clks allocation (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt6359: add codec driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Properly match with audio interface class (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Simplify quirk entries with a macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Move device rename and profile quirks to an internal table (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Hook up component probe function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: s3c2412-i2s: avoid hardcoded S3C2410_PA_IIS (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: rx1950: turn into platform driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: neo1973: turn into platform driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt*-sdw: use SDW_SLAVE_ENTRY_EXT (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm_adsp: Update naming in error handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Get "extal" clock rate by clk_get_rate (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: add a dedicated menuconfig (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8962: Export DAC/ADC monomix switches (Jaroslav Kysela) [1869536]
- [sound] ALSA: remove duplicate "the the" phrase in Kconfig text (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: delete repeated words in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm0010: use DECLARE_COMPLETION_ONSTACK() macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: simple-card: Use snd_soc_of_parse_aux_devs() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: Add common helper to parse aux devs from device tree (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ak4458: Add regulator support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hdmi: support 'ELD' mixer (Jaroslav Kysela) [1869536]
- [sound] ALSA: sound/soc/intel: Fix spelling mistake "cant" --> "can't" (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: delete repeated words in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: various vendors: delete repeated words in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: (cosmetic) align function parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: skl-topology: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: skl-topology: remove redundant assignments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: sst-utils: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: cldma: remove redundant initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: skl-nhlt: remove redundant initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: haswell-ipc: remove redundant assignments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: haswell: (cosmetic) align function parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: common: (cosmetic) align function parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Baytrail: (cosmetic) align function parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: (cosmetic) align parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: sst_pvt: simplify return handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: sst_loader: remove always-true condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: remove useless assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: platform-pcm: fix redundant return (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: sst_pvt: remove redundant initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: remove redundant initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: sst: remove useless NULL assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: platform-pcm: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: compress: remove redundant assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Atom: sst-atom-controls: remove redundant assignments (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: refine runtime pm for SDW_INTEL_CLK_STOP_BUS_RESET (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: support clock_stop mode without quirks (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel_init: handle power rail dependencies for clock stop mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add CLK_STOP_NOT_ALLOWED support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add CLK_STOP_BUS_RESET support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add CLK_STOP_TEARDOWN for pm_runtime suspend (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: pm_runtime idle scheduling (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: reinitialize IP+DSP in .prepare(), but only when resuming (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: call helper to reset Slave states on resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: fix race condition on system resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: reset pm_runtime status during system resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add pm_runtime support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7219: Fix clock handling around codec level probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7219: Move soft reset handling to codec level probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7219: Move required devm_* allocations to device level code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm-dai: add support to copy callback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm-dai: add gapless support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm-dai: prepare set params to accept profile change (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm-dai: add next track metadata support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: add support to gapless flag in q6asm open (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: add support to remove intial and trailing silence (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: add length to write command token (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: use flags directly from q6asm-dai (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: make commands specific to streams (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: rename misleading session id variable (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: KMB: Enable TDM audio capture (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codec: tlv3204: Moving GPIO reset and add ADC reset (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codec: tlv3204: Increased maximum supported channels (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codec: tlv3204: Enable 24 bit audio support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Enable DAPM for earpiece switch (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Enable DAPM for line out switch (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Make line out routes stereo (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Enable DAPM for headphone switch (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Make headphone routes stereo (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Group and sort mixer routes (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Gate the amplifier clock during suspend (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun50i-codec-analog: Fix duplicate use of ADC enable bits (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bytcht_cx2072x: simplify return handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: rename shadowed variable for all broadwell boards (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda-codec: move variable used conditionally (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASOC: SOF: Intel: hda-codec: move unused label to correct position (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Add a quirk for LRCK inversion (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Add missing mixer routes (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sun8i-codec: Fix DAPM to match the hardware topology (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Replace synchronous check with fsl_sai_dir_is_synced (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Drop TMR/RMR settings for synchronous mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Refine enable/disable TE/RE sequence in trigger() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-platform: Use platform_get_irq (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-cpu: Use platform_get_resource (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-sc7180: Add platform driver for lpass audio (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-cpu: fix concurrency issue (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass: Use regmap_field for i2sctl and dmactl registers (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-platform: fix memory leak (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-platform: Replace card->dev with component->dev (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-cpu: Move ahbix clk to platform specific function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: Add common array to initialize soc based core clocks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Use dev_dbg() in rt5682_clk_check() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: Add basic power management support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: master: enable pm runtime (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: add argument to function definition (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: add module_sdw_driver helper macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: sdw.h: fix indentation (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: sdw.h: fix PRBS/Static_1 swapped definitions (Jaroslav Kysela) [1869536]
- [sound] ALSA: seq: virmidi: Fix running status after receiving sysex (Jaroslav Kysela) [1869536]
- [sound] ALSA: bt87x: use pci_status_get_and_clear_errors (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - The Mic on a RedmiBook doesn't work (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: Do not cleanup uninitialized dais on soc_pcm_open failure (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fixup headset for ASUS GX502 laptop (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Improved routing for Thinkpad X1 7th/8th Gen (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: fix double free of dangling pointer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN Converter9 2-in-1 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: use consistent HDAudio spelling in comments/docs (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: add dev_dbg log when driver is not selected (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fix a runtime pm issue in SOF when integrated GPU is disabled (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: hdmi - add Rocketlake support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: haswell: Fix power transition refactor (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: oss: Remove superfluous WARN_ON() for mulaw sanity check (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8994: Ensure the device is resumed in wm89xx_mic_detect functions (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8994: Skip setting of the WM8994_MICBIAS register for WM1811 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - Fix silent audio output and corrupted input on MSI X570-A PRO (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: axg-toddr: fix channel order on g12 platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: add snd_soc_find_dai_with_mutex() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: always check pin power status in i915 pin fixup (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: Fix refcount imbalance on error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt700: Fix return check for devm_regmap_init_sdw() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt715: Fix return check for devm_regmap_init_sdw() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt711: Fix return check for devm_regmap_init_sdw() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1308-sdw: Fix return check for devm_regmap_init_sdw() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98373: Fix return check for devm_regmap_init_sdw() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion NT950XCJ-X716A (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add basic capture support for Pioneer DJ DJM-250MK2 (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add implicit feedback quirk for UR22C (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: fixup ams_delta_mute() function name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pcm3168a: ignore 0 Hz settings (Jaroslav Kysela) [1869536]
- [sound] ALSA: Revert "ALSA: hda: Add support for Loongson 7A1000 controller" (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/tegra: Program WAKEEN register for Tegra (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Fix 2 channel swapping for Tegra (Jaroslav Kysela) [1869536]
- [sound] ALSA: ca0106: fix error code handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: tgl_max98373: fix a runtime pm issue in multi-thread case (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-digi00x: exclude Avid Adrenaline from detection (Jaroslav Kysela) [1869536]
- [sound] ALSA: ALSA; firewire-tascam: exclude Tascam FE-8 from detection (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: Set card->owner to avoid warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: atom: Add period size constraint (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: avoid reset of sdo_limit (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic: Fix NULLptr dereference in autosuspend delay (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: fix typo in comment on INTSTAT registers (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: ignore broken processing/extension unit (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: Fix memleak in sst_media_open (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8994: Avoid attempts to read unreadable registers (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: msm8916-wcd-analog: fix register Interrupt offset (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8994: Prevent access to invalid VU register bits on WM1811 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add model alc298-samsung-headphone (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Update documentation comment for MS2109 quirk (Jaroslav Kysela) [1869536]
- [sound] ALSA: isa: fix spelling mistakes in the comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add capture support for Saffire 6 (USB 1.1) (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add quirk for Samsung Galaxy Flex Book (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: Fix potential Oops in snd_echo_resume() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: Use force connectivity quirk on another HP desktop (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Fix unused variable warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6routing: add dummy register read/write function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6afe-dai: mark all widgets registers as SND_SOC_NOPM (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Make soc_component_read() returning an error code again (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - reverse the setting value in the micmute_led_set (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaduio: Drop superfluous volatile modifier (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Replacing component->name with codec_dai->name (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: add quirk for Pioneer DDJ-RB (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: work around streaming quirk for MacroSilicon MS2109 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - fix the micmute led status for Lenovo ThinkCentre AIO (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: fix overeager device match for MacroSilicon MS2109 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Fix pin default on Intel NUC 8 Rugged (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Creative USB X-Fi Pro SB1095 volume knob support (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: fix spelling mistake "buss" -> "bus" (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci: delete repeated words in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: isa: delete repeated words in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/tegra: Add 100us dma stop delay (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Add dma stop delay variable (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hda/tegra: Set buffer alignment to 128 bytes (Jaroslav Kysela) [1869536]
- [sound] ALSA: seq: oss: Serialize ioctls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: Add quirk to force connectivity (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: add startech usb audio dock name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: Fix unused variable warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra210_i2s: Fix compile warning with CONFIG_PM=n (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra210_dmic: Fix compile warning with CONFIG_PM=n (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra210_ahub: Fix compile warning with CONFIG_PM=n (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra210_admaif: Fix compile warning with CONFIG_PM=n (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra186_dspk: Fix compile warning with CONFIG_PM=n (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add support for Lenovo ThinkStation P620 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: renoir: restore two more registers during resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8962: Do not remove ADDITIONAL_CONTROL_4 from readable register list (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Remove fsl_asoc_card_set_bias_level function (Jaroslav Kysela) [1869536]
- [sound] ALSA: Revert "ALSA: hda: call runtime_allow() for all hda controllers" (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Fix AE-5 microphone selection commands (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Add new quirk ID for Recon3D (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/ca0132 - Fix ZxR Headphone gain control get value (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add alc269/alc662 pin-tables for Loongson-3 laptops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: Two step component registration (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: Simplify snd_soc_component_initialize declaration (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: Relocate and expose snd_soc_component_initialize (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sh: Replace 'select' DMADEVICES 'with depends on' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Fix value of FSL_SAI_CR1_RFW_MASK (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: use less strict tests for dailink capabilities (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rk3399_gru_sound: Add DAPM pins, kcontrols for jack detection (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8962: Do not access WM8962_GPIO_BASE (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: use resource_size (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: drop unnecessary list_empty (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Added hw_params support for ALC1015 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Passing card structure based on codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Renaming snd-soc-card structure and fields (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: Add sound support for Midas boards (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: KMB: Rework disable channel function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: KMB: Add 8kHz audio support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: Fix regression causing sysfs entries to disappear (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: axg-tdm-formatters: fix sclk inversion (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: axg-tdmin: fix g12a skew (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: axg-tdm-interface: fix link fmt setup (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Fixed HP right speaker no sound (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fix NULL pointer dereference during suspend (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: bcm2835: Silence clk_get() error on -EPROBE_DEFER (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Update shutdown GPIO property (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: disable traces when switching to S0Ix D0I3 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: fix the suspend procedure to support s0ix entry (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: Fix keep_power assignment for non-component devices (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Workaround for spurious wakeups on some Intel platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: endpoint : remove needless check before usb_free_coherent() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: AMD: Restore PME_EN state at Power On (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel/boards: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Fix add a "ultra_low_power" function for intel reference board (alc256) (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dapm: don't call pm_runtime_* on card device (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: typo_fix: enable headset mic of ASUS ROG Zephyrus G14(GA401) series with ALC289 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus G15(GA502) series with ALC289 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: update dsm param bin max size (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Update dsm init sequence and condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: don't report of_xlate_dai_name failures (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: Avoid printing errors for -EPROBE_DEFER (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: Use qcom_snd_parse_of() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: Parse properties with "qcom, " prefix (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: Support parsing links without DPCM (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6afe: Remove unused q6afe_is_rx_port() function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: Use snd_soc_dai_link_set_capabilities() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: Use devm for resource management (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Fix dac event dapm mixer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Support configuring dai fmt from DT (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_esai: add IRQF_SHARED for devm_request_irq (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Fix build error due to 64-by-32 division (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: fix SND_SOC_J721E_EVM warnings & errors (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: omap: Replace HTTP links with HTTPS ones (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm_adsp: Support new metadata block ID's (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: Replace HTTP links with HTTPS ones (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: Replace HTTP links with HTTPS ones (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: uniphier: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mxs: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: xtensa: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: kirkwood: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sprd: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: generic: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: bcm: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: au1x: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dwc: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atmel: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rockchip: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: cirrus: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sh: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sof: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: stm: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sunxi: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ux500: use asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-xxx: add asoc_substream_to_rtd() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_rt5514_max98927: Fix kabylake_ssp_fixup function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hda: fix deadlock after PCM open error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hda: fix memleak on module unload (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hda: call patch_ops.free() on probe error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Replace HTTP links with HTTPS ones (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183: support machine driver with max98357b (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183: support left justified format for I2S (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel/skl/hda - fix probe regression on systems without i915 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: pcm: Update rate/channels for SAI/ESAI DAIs (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: Update SAI config bclk/fsync rate (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx8: Add SAI dai driver for i.MX/i.MX8X (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx8m: Fix SAI DAI driver for i.MX8M (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx8: Fix ESAI DAI driver name for i.MX8/iMX8X (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: Use ARRAY_SIZE instead of hardcoded value (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: define INFO_ flags in dsp_ops for imx8 (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add implicit feedback quirk for SSL2 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add Tegra210 based ADMAIF driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2770: Fix reset gpio property name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98357a: move control of SD_MODE back to DAI ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: Soundwire: intel_init: save Slave(s) _ADR info in sdw_intel_ctx (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add wake interrupt support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel/cadence: merge Soundwire interrupt handlers/threads (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel_init: add implementation of sdw_intel_enable_irq() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: introduce helper for link synchronization (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: introduce a helper to arm link synchronization (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: revisit SHIM programming sequences (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: report slave_ids for each link to SOF driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add clock stop quirks (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add mutex for shared SHIM register access (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add prototype for WAKEEN interrupt processing (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: add link_list to handle interrupts with a single thread (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: update headers for interrupts (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: reuse code for wait loops to set/clear bits (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: board: sof_rt5682: Update rt1015 pll input clk freq (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: avoid crash if invalid DSP topology loaded (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add support for systems without i915 audio (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt711: remove properties in card remove (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt711: remove hard-coded codec name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai.h: drop a duplicated word (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wcd9335.h: fix duplicated word (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra20_das.h: delete duplicated words (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: Avoid the use of one-element array (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add Tegra186 based DSPK driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add Tegra210 based AHUB driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add Tegra210 based I2S driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add Tegra210 based DMIC driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add support for CIF programming (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: common: change match table ehl-rt5660 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: remove .digital_mute (Jaroslav Kysela) [1869536]
- [sound] ALSA: Replace the word "slave" in vmaster API (Jaroslav Kysela) [1869536]
- [sound] ALSA: asihpi: delete duplicated word (Jaroslav Kysela) [1869536]
- [sound] ALSA: Replace HTTP links with HTTPS ones (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Fixed ALC298 sound bug by adding quirk for Samsung Notebook Pen S (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: optimize the power consumption (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai.h: don't use discriminatory terms for comment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: qdsp6: Use IS_ERR() instead of IS_ERR_OR_NULL() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: disable MICBIAS and Vref2 widget in default (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: qdsp6: Use the defined variable to clean code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: snd_soc_dai_digital_mute() for both CPU/Codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atmel: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: fixes the missed kfree() for axg_card_add_tdm_loopback (Jaroslav Kysela) [1869536]
- [sound] ALSA: info: Drop WARN_ON() from buffer NULL sanity check (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: Use kmemdup in podhd_set_monitor_level() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Add support for Loongson 7A1000 controller (Jaroslav Kysela) [1869536]
- [sound] ALSA: Revert "ALSA: pcm: Use SG-buffer only when direct DMA is available" (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: Add missed return for calling soc_component_ret (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl-asoc-card: Trivial: Fix misspelling of 'exists' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Support Headphone and Microphone Jack detection (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: simple-card-utils: Support configure pin_name for asoc_simple_init_jack (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: ak*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: cs*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: da*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: es*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: alc*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: pcm*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: ssm*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: tas*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: tlv*: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: spear: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdmi-codec: merge .digital_mute() into .mute_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: drm/mediatek: exit earlier if failed to register audio driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: drm/i2c/tda998x: Make tda998x_audio_digital_mute static (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai.c: add .no_capture_mute support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdmi-codec: return -ENOTSUPP for digital_mute (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fix snd_hda_codec_cleanup() documentation (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: export snd_hda_codec_cleanup_for_unbind() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Report the button event in the headset type only (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add missed put_device() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - fixup for yet another Intel reference board (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Enable Speaker for ASUS UX563 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Enable Speaker for ASUS UX533 and UX534 (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: fix the kernel-doc comment (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Replace blacklist word (Jaroslav Kysela) [1869536]
- [sound] ALSA: via82xx: Replace the words whitelist (Jaroslav Kysela) [1869536]
- [sound] ALSA: nm256: Replace the words blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: intel8x0: Replace the words white/blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Replace the words white/blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: es1968: Replace the words white/blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: ctxfi: Replace the word blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: bt87x: Replace the words white/blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: ac97: Replace the words white/blacklist (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: don't free dma_data in DAI shutdown (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: cadence: allocate/free dma_data in set_sdw_stream (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: remove stream allocation/free (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: stream: add helper to startup/shutdown streams (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: implement get_sdw_stream() operations (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/tegra: Disable sync-write operation (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ssi: don't use discriminatory terms for debug log (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: siu: don't use discriminatory terms for parameter (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsi: don't use discriminatory terms for comment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rsnd: don't use discriminatory terms for comment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rsnd: don't use discriminatory terms for function names (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Enable Vref2 under using PLL2 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rockchip: spdif: Handle clk by pm runtime (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: re-enable IRQs on failure path (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: add hw monitor volume control for POD HD500 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Enable headset mic of Acer TravelMate B311R-31 with ALC256 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus G14(G401) series with ALC289 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - change to suitable link model for ASUS platform (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix race against the error recovery URB submission (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: Improve dai-set-fmt comment in cht_codec_fixup() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: support HDMI jack reporting (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: use hdmi-codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183: use hdmi-codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_spdif: Add kctl for configuring TX validity bit (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_spdif: Clear the validity bit for TX (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: Sync the pending work cancel at disconnection (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: Perform sanity check for each URB creation (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: ak4458: Remove set but never checked variable 'ret' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: tlv320aic26: Demote seemingly unintentional kerneldoc header (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt5659: Remove many unused const variables (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt5631: fix spurious kernel-doc start and missing arguments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ux500: ux500_msp_i2s: Remove unused variables 'reg_val_DR' and 'reg_val_TSTDR' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: pxa-ssp: Demote seemingly unintentional kerneldoc header (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sunxi: sun4i-spdif: Fix misspelling of 'reg_dac_txdata' in kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sunxi: sun4i-i2s: add missing clock and format arguments in kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: qdsp6: q6asm: Provide documentation for 'codec_profile' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sti: uniperif: fix 'defined by not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atmel-pdmic: remove codec component (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atmel-classd: remove codec component (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt*: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max98390: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: es8316: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: omap-mcbsp-st: Remove set, but unused variable 'w' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: jz4770: Remove defined but never used variable 'mic_boost_tlv' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: da7219: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: da7210: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: uniphier: aio-core: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra20_das: remove always-true comparison (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: pcm: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: spdif: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atmel: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sdw_max98373: add card_late_probe support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof-sdw: add MAX98373 I2C dependencies (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max98373: add SoundWire support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max98373: split I2C and common parts (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: support machine driver with rt1015 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: extract codec and DAI names (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: remove forward declaration of headset_init (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: sort header inclusions in alphabetical (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt286: fix unexpected interrupt happens (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8974: remove unsupported clock mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8974: fix Boost Mixer Aux Switch (Jaroslav Kysela) [1869536]
- [sound] ALSA: xen: Remove superfluous fall through comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: atmel: Remove invalid "fall through" comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: Address bugs in the interrupt handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: Prevent some noise on unloading the module (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: Prevent races in calls to set_audio_format() (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: Race conditions around "opencount" (Jaroslav Kysela) [1869536]
- [sound] ALSA: echoaudio: Remove redundant check (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: fixed kernel warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183: support machine driver with rt1015 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183: sort header inclusions in alphabetical (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qdsp6: use dev_err instead of pr_err (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: add command opcode to timeout error report (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: core: fix null-ptr-deref bug during device removal (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoc: codecs: max98373: remove Idle_bias_on to let codec suspend (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max98373: Removed superfluous volume control from chip default (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: add more logs when topology load fails (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: factor kfree(se) in error handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: use break on errors, not continue (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: fix tlvs in error handling for widget_dmixer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: fix kernel oops on route addition error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: add min/max channels for SAI/ESAI on i.MX8/i.MX8M (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: fix non BE conversion (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: set dai_link dpcm_ flags with a helper (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb/line6: remove 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: mpc8610_hpcd: Add missing of_node_put() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7213: add default clock handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add ACPI dependency check (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: raven: acp3x-i2s: remove unused-but-set variable (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: raven: acp3x-pcm-dma: remove unused-but-set variable (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: raven: acp3x-i2s: fix 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: raven: acp3x-pcm-dma: fix 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: acp-rt5645: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: acp-da7219-max98357a: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: Fix build error on m68k and others (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: Remove only the registered component in devm functions (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: Add Intel silent stream support (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/au88x0: remove "defined but not used" warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: vx_core: remove warning for empty loop body (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcmcia/pdaudiocf: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/via82xx: remove 'set but not used' warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/fm801: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/es1938: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: xen: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/oxygen/xonar_wm87x6: remove always true condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/rme9652/hdspm: remove always true condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/korg1212: remove 'set but not used' warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/emu10k1: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pci/emu10k1: remove "set but not used' warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/ctxfi: fix kernel-doc warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/ctxfi/ctatc: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/aw2-saa7146: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/echoaudio: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/asihpi: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/asihpi: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: pci/asihpi: remove 'set but not used' warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: isa/gus: remove 'set but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: isa/gus: remove -Wmissing-prototypes warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: compress: fix partial_drain completion state (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add implicit feedback quirk for RTX6001 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: fix SND_HDA_GENERIC kconfig & build (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: add quirk for MacroSilicon MS2109 (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: pcm_iec958: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Enable headset mic of Acer Veriton N4660G with ALC269VC (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Enable headset mic of Acer C20-820 with ALC269VC (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Enable audio jacks of Acer vCopperbox with ALC269VC (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Fix Lenovo Thinkpad X1 Carbon 7th quirk subdevice id (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: improve debug traces for stream lookups (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/hdmi: fix failures at PCM open on Intel ICL and later (Jaroslav Kysela) [1869536]
- [sound] ALSA: opl3: fix infoleak in opl3 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm8400: remove unused variables (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-ac97: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add logic to check dmic hardware runtime (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: j721e-evm: Fix missing unlock on error in j721e_audio_hw_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl_esai: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl_asrc: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl_spdif: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl-asoc-card: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl_ssi: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: fsl_ssi_dbg: remove spurious kernel-doc comment start (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5670: Rename dev_gpio to gpio1_is_irq (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5670: Remove struct rt5670_platform_data (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bxt-da7219-max98357a: return -EINVAL on unrecognized speaker amplifier (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm8994: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm9713: remove spurious kernel-doc comment start (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm8960: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm8986: fix missing kernel-doc arguments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: cs42l42: remove always-true comparisons (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: cs4270: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: sof-acpi-dev: fix 'defined but unused' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: atom: fix 'defined but not used' warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: atom: fix kernel-doc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bxt-da7219-max98357a: support MAX98390 speaker amp (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: Add an option to select internal ratio mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Enable interrupt in dma_open (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: KeemBay: Fix header guard (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_sai: Refine regcache usage with pm runtime (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: Add custom machine driver for j721e EVM (CPB and IVI) (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Specify stream_name for playback/capture (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rockchip: add format and rate constraints on rk3399 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Rectifying Unbalanced pm_runtime_enable! issue (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: cancel jack_detect_work if hs_jack is set to null even soundwire mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix some typos (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Replace s/frame/packet/ where appropriate (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix packet size calculation (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: initialize bus clock base and scale registers (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: add definitions for 1.2 spec (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: remove multiple blank lines (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: extend SDW_SLAVE_ENTRY (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus_type: convert open-coded while() to for() loop (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5670: Fix dac- and adc- vol-tlv values being off by a factor of 10 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5670: Add new gpio1_is_ext_spk_en quirk and enable it on the Lenovo Miix 2 10 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5670: Correct RT5670_LDO_SEL_MASK (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: Change bus format to I2S 2 channel (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Add voltage sense slot configuration (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Add right and left channel slot programming (Jaroslav Kysela) [1869536]
- [sound] ALSA: asoc: Update supported rate and format for dummy dai (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: Drop HAS_DMA dependency to fix link failure (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: Add MAX98373 support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: Fix a typo in Kconfig (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: common: add match table for TGL MAX98373 + RT5682 SoundWire driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoc: Intel: cml_rt1011_rt5682: explicitly access first codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: snd/soc: correct trivial kernel-doc inconsistency (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Boards: tgl_max98373: Update TDM configuration in hw_params (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: cml_rt1011_rt5682: use for_each_card_prelinks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Boards: cml_rt1011_rt5682: use statically define codec config (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Boards: cml_rt1011_rt5682: reduce log level for printing quirk (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: sof_rt5682: Add support for jsl-max98360a-rt5682 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Boards: tgl_max98373: Fix the comment for max_98373_components (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Boards: tgl_max98373: add dai_trigger function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: boards: byt*.c: remove cast in dev_info quirk log (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add quirk override with kernel parameter (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bxt_rt298: add missing .owner field (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add missing .owner field (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: cml_rt1011_rt5682: add missing .owner field (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: nocodec: add missing .owner field (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: add missing header inclusion (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dapm: declare missing structure prototypes (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: move definition of enum snd_soc_bias_level (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Fix format issue for extra space before a comma (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2562: Update shutdown GPIO property (Jaroslav Kysela) [1869536]
- [sound] ALSA: AsoC: amd: add missing snd- module prefix to the acp3x-rn driver kernel module (Jaroslav Kysela) [1869536]
- [sound] ALSA: core: Warn on empty module (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda - let hs_mic be picked ahead of hp_mic (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Add WM8524 support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: fix the pop noise while OMTP type headset plugin (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix OOB access of mixer element list (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: add quirk for Samsung USBC Headset (AKG) (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1011: fix KASAN out-of-bounds bug in find_next_bit() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: set playback and capture constraints (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: Fix uninitialized scalar variable in fsl_easrc_set_ctx_format (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: cml_rt1011_rt5682: disable jack in dailink .exit() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: sof_rt5682: move disabling jack to dai link's exit() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: kbl-rt5660: use .exit() dailink callback to release gpiod (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: fix module load/unload issues (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: introduce exit() callback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_mqs: Fix unchecked return value for clk_prepare_enable (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_mqs: Don't check clock is NULL before calling clk API (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add registration quirk for Kingston HyperX Cloud Flight S (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm_adsp: Add controls for calibration and diagnostic FW (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: remove snd_soc_component_read32() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: ak*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: cs*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: da*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: alc*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: msm*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: tlv*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wcd*: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atmel: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: rename to snd_soc_component_read() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: use io_mutex correctly (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: merge snd_soc_component_read() and snd_soc_component_read32() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: Constify static structs (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: transition to 3 steps initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel_init: pass link information as platform data (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel_init: use devm_ allocation (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel_init: remove useless test (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: clarify drvdata and remove more indirections (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: cleanups for indirections/logs (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: fix memory leak with devm_kasprintf (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: clock_stop: don't deal with UNATTACHED Slave devices (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: Replace 'objs' by 'y' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_spdif: Add pm runtime function (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Enable sync-write operation as default for all controllers (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rockchip: Fix a reference count leak (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Removing unnecessary instance initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: closing specific instance (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Let LED cdev handling suspend/resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Unify LED helper code (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/sigmatel: Use the new vmaster mute LED helper (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/conexant: Use the new vmaster mute LED helper (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Use the new vmaster mute LED helper (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: generic: Add vmaster mute LED helper (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: generic: Drop the old mic-mute LED hook (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: generic: Drop unused snd_hda_gen_fixup_micmute_led() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/sigmatel: Convert to cdev-variant of mic-mute LED controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/conexant: Convert to cdev-variant of mic-mute LED controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Convert to cdev-variant of mic-mute LED controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: generic: Add a helper for mic-mute LED with LED classdev (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: generic: Always call led-trigger for mic mute LED (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Intel: add missing PCI IDs for ICL-H, TGL-H and EKL (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: broadwell: simplify card names for SOF uses (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: cht*: simplify card names for SOF uses (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: byt*: simplify card names for SOF uses (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hdac_hda: fix memleak with regmap not freed on remove (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: add PCI IDs for ICL-H and TGL-H (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: add PCI ID for CometLake-S (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: SOF: merge COMETLAKE_LP and COMETLAKE_H (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: imply acodec glue on axg sound card (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add mute LED and micmute LED support for HP systems (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_spdif: Add support for imx6sx platform (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Add MQS support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Fix reference count leaks (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix potential use-after-free of streams (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add quirk for MSI GE63 laptop (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: Flush DAC data before playback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_ssi: Fix bclk calculation for mono channel (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Replace zero-length array with flexible-array (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: AMD: Use mixer control to switch between DMICs (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Add Amp init common setting func (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: DAI wclk supports 44100 Hz output (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Let PLL2 support the freq conversion for 44100Hz sample rate (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rl6231: Add new supports on rl6231 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: img-parallel-out: Fix a reference count leak (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: img: Fix a reference count leak in img_i2s_in_set_fmt (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8960: Support headphone jack detection function (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: samsung: Add driver for Aries boards (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm0010: Use kmemdup rather than duplicating its implementation (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Add makefiles and kconfig changes for KeemBay (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Add KeemBay platform driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt6358: support DMIC one-wire mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: Fix "Function parameter not described" warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: Fix -Wunused-but-set-variable (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: Fix -Wmissing-prototypes warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: tidyup Copyright (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: merge soc_pcm_trigger_start/stop() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: merge soc-io.c into soc-component.c (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_init() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_trigger() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_hw_free() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_hw_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_prepare() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add soc_component_err() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_initialize() to soc-component.c (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_xxx_regmap() to soc-component (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add soc_component_pin() and share code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm/compress: reduce verbosity on mapping ok messages (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: improve error messages in soc_pcm_new() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: reduce verbosity of BE override message (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: Use SG-buffer only when direct DMA is available (Jaroslav Kysela) [1869536]
- [sound] ALSA: memalloc: Make SG-buffer helper usable for continuous buffer, too (Jaroslav Kysela) [1869536]
- [sound] ALSA: memalloc: Initialize all fields of snd_dma_buffer properly (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: Use dma_mmap_coherent() on x86, too (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98357a: add compatible string for MAX98360A (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: Clear RIRB status before reading WP (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: Update rt1015 default register value according to spec modification (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: common: set correct directions for dailinks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoc: q6afe: add support to get port direction (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: fix checks for multi-cpu FE dailinks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: Let dai clks be registered whether mclk exists or not (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: wait for notification when changing clock configuration for protocol v3 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-topology: use devm_snd_soc_register_dai() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-devres: add devm_snd_soc_register_dai() (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Set 48 kHz rate for Rodecaster (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: add quirk for Denon DCD-1500RE (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc_dma: Fix data copying speed issue with EDMA (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc_dma: Reuse the dma channel if available in Back-End (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dmaengine_pcm: export soc_component_to_pcm (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: export snd_soc_lookup_component_nolocked (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add implicit feedback quirk for SSL2+ (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Add NVIDIA codec IDs 9a & 9d through a0 to patch table (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: q6asm: handle EOS correctly (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Update regmap readable reg and volatile (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5645: Add platform-data for Asus T101HA (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT10-A tablet (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: nocodec: conditionally set dpcm_capture/dpcm_playback flags (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: boards: replace capture_only by dpcm_capture (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: core: only convert non DPCM link to DPCM link (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: dpcm: fix playback/capture checks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: dpcm: Only allow playback/capture if supported (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: add missing free_irq() in error path (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: disallow linking stream to itself (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Manage auto-pm of all bundled interfaces (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - add a pintbl quirk for several Lenovo machines (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: fix snd_pcm_link() lockdep splat (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Use the new macro for HP Dock rename quirks (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add vendor, product and profile name for HP Thunderbolt Dock (Jaroslav Kysela) [1869536]
- [sound] ALSA: emu10k1: delete an unnecessary condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix inconsistent card PM state after resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Fix potential crash during param fw loading (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Fix incorrect printf qualifier (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Defer probe when fail to find codec device (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rl6231: Modify the target DMIC clock rate (Jaroslav Kysela) [1869536]
- [sound] ALSA: es1688: Add the missed snd_card_free() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: add sienna_cichlid audio asic id for sienna_cichlid up (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add Pioneer DJ DJM-900NXS2 support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: q6asm-dai: kCFI fix (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_remove_dai_link() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_add_dai_link() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_set_bias_level_post() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_set_bias_level() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_remove() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_late_probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add probed bit field to snd_soc_card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_resume_post() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_resume_pre() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_suspend_post() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: add snd_soc_card_suspend_pre() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: move snd_soc_card_subclass to soc-card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: move snd_soc_card_get_codec_dai() to soc-card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: move snd_soc_card_set/get_drvdata() to soc-card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: move snd_soc_card_jack_new() to soc-card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-card: move snd_soc_card_get_kcontrol() to soc-card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: add soc-card.c (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc.h: convert bool to bit field for snd_soc_card (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sof_pcm512x: remove CONFIG_SND_HDA_CODEC_HDMI condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sof-sdw: remove CONFIG_SND_SOC_SOF_HDA_AUDIO_CODEC condition (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: add depends on SND_SOC_SOF_HDA_AUDIO_CODEC for common hdmi (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fixing usage of plain int instead of NULL (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix generic hda codec support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Baytrail: fix 'defined but not used' warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: Subject:ASoC: soc-pcm: fix BE dai not hw_free and shutdown during mixer update (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: reduce verbosity of error messages for sof-dai and sof-link (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc_dma: Fix dma_chan leak when config DMA channel failed (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: Enable class-D silence and clock detections (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: img-i2s-out: Fix runtime PM imbalance on error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: remove the redundant pass checks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: refine and log the header in the correct pass (Jaroslav Kysela) [1869536]
- [sound] ALSA: ac97: Remove sound driver for ancient platform (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: Removing unnecessary instance initialization (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sta32x: add missed function calls in error paths (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: split i2c driver into separate module (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: nau8810: add I2C device and compatible ID (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ingenic: Unconditionally depend on devicetree (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Clean up quirk entries with macros (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Fix return value check in asoc_mmp_sspa_probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8962: Fix runtime PM imbalance on error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: img-spdif-in: Fix runtime PM imbalance on error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: img-spdif-out: Fix runtime PM imbalance on error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: BYT: harden IPC initialization and handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: BYT: mask BUSY or DONE interrupts in handler (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: BYT: add .remove op (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ipc: ignore DSP replies received when they are not expected (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: byt/cht: add .pm_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640/51: remove .ignore_suspend (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: pm: handle resume on legacy Intel platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: byt: Add PM callbacks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dapm: Move dai_link widgets to runtime to fix use after free (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add new codec supported for ALC287 (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Quirks for Gigabyte TRX40 Aorus Master onboard audio (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tas2552: Fix runtime PM imbalance in tas2552_component_probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fix incomplete error-handling in img_i2s_in_probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: Fix runtime PM imbalance in omap2_mcbsp_set_clks_src (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fix semicolon.cocci warnings (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: mixer: volume quirk for ESS Technology Asus USB DAC (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add a model for Thinkpad T570 without DAC workaround (Jaroslav Kysela) [1869536]
- [sound] ALSA: hwdep: fix a left shifting 1 by 31 UB bug (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: Merge suspend/resume function to runtime_suspend/resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: imx-audmix: Fix unused assignment to variable 'ret' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: Fix -Wmissing-prototypes warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98390: Added Amplifier Driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse compiler version (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse windows (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse firmware version (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Introduce extended manifest (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: loader: Adjust validation condition for fw_offset (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: add snd_soc_link_compr_set_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: add snd_soc_link_compr_shutdown() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: add snd_soc_link_compr_startup() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: add snd_soc_link_be_hw_params_fixup() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: remove unneeded parameter from snd_soc_link_xxx() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-link: move soc_rtd_xxx() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: add soc-link.c (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: add support for MOTU UltraLite-mk3 (FireWire only model) (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: keep ADCs and DACs always on (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: add digital microphone controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: refactoring protocol v2 for fetching mode switch (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: refactoring protocol v3 for clock source getter (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: refactoring protocol v2 for clock source getter (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: remove obsoleted codes (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: use table-based calculation of packet formats for stream management (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: use table-based calculation of packet formats for proc (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: add alternative functions to detect packet format for protocol v3 (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: add alternative functions to detect packet format for protocol v2 (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: add model-specific table of chunk count (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: drop protocol structure (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: add wrapper functions for protocol-dependent operations (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: localize protocol data (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: move spec data to v3 protocol file (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: move spec data to v2 protocol file (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: remove Compulab pxa2xx boards (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: add mono playback switch (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: add filter controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: don't use regmap defaults (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Fix the error handling in probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: use a single module (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: fix ADC level control (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: fix spelling mistake (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: fix trailing line in sysfs_slave.c (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: add Slave sysfs support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: master: add sysfs support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: disco: s/ch/channels/ (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Add Device Tree support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: return error when acp de-init fails (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: refactoring dai_hw_params() callback (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: fix kernel warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_micfil: Do not pass irq numbers in comments (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_micfil: Remove unneeded ifdef's (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: Set ASR76K and ASR56K based on processing clock (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: enable build for RN machine driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: RN machine driver using dmic (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: create platform devices for Renoir (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: enable Renoir acp3x drivers build (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add ACP PDM DMA driver pm ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add Renoir ACP PCI driver PM ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add ACP PDM DMA driver dai ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add acp3x pdm driver dma ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: irq handler changes for ACP3x PDM dma driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add ACP3x PDM platform driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: create acp3x pdm platform device (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add acp init/de-init functions (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add Renoir ACP PCI driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: add Renoir ACP3x IP register header (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add more fixup entries for Clevo machines (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: master: add runtime pm support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus_type: add sdw_master_device support (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: add unique bus id (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus_type: introduce sdw_slave_type and sdw_master_type (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: rename sdw_bus_master_add/delete, add arguments (Jaroslav Kysela) [1869536]
- [sound] ALSA: iec1712: Initialize STDSP24 properly when using the model=staudio option (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT8-A tablet (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max9867: fix volume controls (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_micfil: Fix unused assignment in fsl_set_clock_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd: raven: Make the driver name consistent across files (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_micfil: Fix indentation to put on one line affected code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: cleanup dai / component active code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dwc: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: uniphier: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: pxa: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: meson: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: jz4740: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: cirrus: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: bcm: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: atomel: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: use snd_soc_xxx_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_stream_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_active() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dapm: use snd_soc_dai_activate()/deactivate() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_action() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-pcm: replace snd_soc_runtime_activate()/deactivate() to macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7213: move set_pll to codec level (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7213: move set_sysclk to codec level (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7213: Add regulator support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: da7213: Add da7212 DT compatible (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: remap BTN_0 as KEY_PLAYPAUSE (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt700: remap buttons (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt711: remap buttons (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: fix typo in components string (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: soc-acpi: change machine driver name for WM8804 platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: make imx8m_dsp_ops static (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: make dsp_ops static (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: define INFO_ flags in dsp_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: sdw: relax sdw machine select constraints (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: add support to smart amplifier (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: inform DSP that driver is going to be removed (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: add a power_down_notify method (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Do nothing when DSP PM callbacks are not set (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt1308-sdw: remove duplicate allocation (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt*-sdw: fix memory leak in set_sdw_stream() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt*-sdw: don't assign slave_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus Xtreme (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm: fix incorrect hw_base increase (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Unexport some local helper functions (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Drop unused snd_hda_queue_unsol_event() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Fix potential race in unsol event handler (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add duplex sound support for USB devices using implicit feedback (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: fixing upper volume limit for RME Babyface Pro routing crosspoints (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_esai: introduce SoC specific data (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Limit int mic boost for Thinkpad T530 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8962: Use force clear for WM8962_SYSCLK_ENA after reset (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Set appropriate bus format for given bit width (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Add support for the runtime power management (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Prepare/unprepare the clocks (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Remove the embedded struct ssp_device (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Add support for soc-generic-dmaengine-pcm (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Get rid of dma_params and phys_base (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: A trivial typo fix (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: omap-mcbsp: Fix an error handling path in 'asoc_mcbsp_probe()' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: Update description for HDaudio kconfig (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ux500: mop500: Fix some refcounted resources issues (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: Replace zero-length array with flexible-array (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Drop S20_3LE case (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mmp-sspa: Flip SNDRV_PCM_FMTBIT_S24_3LE on (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Use readq to read 64 bit registers (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: baytrail: Fix register access (Jaroslav Kysela) [1869536]
- [sound] ALSA: SoC: rsnd: add interrupt support for SSI BUSIF buffer (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add COEF workaround for ASUS ZenBook UX431DA (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Enable headset mic of ASUS UX581LV with ALC295 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Enable headset mic of ASUS UX550GE with ALC295 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Enable headset mic of ASUS GL503VM with ALC295 (Jaroslav Kysela) [1869536]
- [sound] ALSA: drivers/powerpc: Replace _ALIGN_UP() by ALIGN() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: core: fix error return code in sof_probe_continue() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: set headset button maps (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-motu: fulfill missing entries in Kconfig (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: (cosmetic) remove multiple superfluous "else" statements (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: (cosmetic) remove multiple superfluous "else" statements (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: Use IRQF_ONESHOT (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireface: add support for RME Fireface UFX (untested) (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireface: add support for RME FireFace 802 (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireface: code refactoring to decide name of sound card (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireface: code refactoring to add enumeration constants for model identification (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireface: start IR context immediately (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireface: fix configuration error for nominal sampling transfer frequency (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek: Add quirk for Samsung Notebook (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: Replace zero-length array with flexible-array (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Fix unused variable warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: use sequence of syt offset and data block on pool in AMDTP domain (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: pool ideal sequence of syt offset and data block (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: add cache for packet sequence to AMDTP domain structure (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: code refactoring for data block calculation (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: code refactoring for syt offset calculation (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: code refactoring for syt computation (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: code refactoring for parameters of packet queue and IRQ timing (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: add reference to domain structure from stream structure (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: use macro for maximum value of second in 1394 OHCI isoc descriptor (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: fix invalid assignment to union data for directional parameter (Jaroslav Kysela) [1869536]
- [sound] ALSA: fireworks: Replace zero-length array with flexible-array (Jaroslav Kysela) [1869536]
- [sound] ALSA: Replace zero-length array with flexible-array (Jaroslav Kysela) [1869536]
- [sound] ALSA: rawmidi: Fix racy buffer resize under concurrent accesses (Jaroslav Kysela) [1869536]
- [sound] ALSA: soc: fsl_asrc: Make some functions static (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1016: Add the rt1016 support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5677: Use devm_snd_soc_register_component() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: mt8183: fix error handling of platform_get_irq() (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Allow SST driver on SKL and KBL platforms with DMIC (Jaroslav Kysela) [1869536]
- [sound] ALSA: portman2x4: Use bitwise instead of arithmetic operator for flags (Jaroslav Kysela) [1869536]
- [sound] ALSA: sound/ppc: Use bitwise instead of arithmetic operator for flags (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mediatek: Fix error handling (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: amd :High hw_level while simultaneous capture (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Return true, false for return type bool (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: lpass-cpu: Make I2S SD lines configurable (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Use hdac_to_hda_codec macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Use dev_to_hdac_dev macro (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: bus: reduce verbosity on enumeration (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: debugfs: clarify SDPX license with GPL-2.0-only (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: slave: don't init debugfs on device registration error (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: qcom: fix error handling in probe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8524: Add support S32_LE (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: Use the defined variable to simplify code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt1015: Add condition to prevent SoC providing bclk in ratio of 50 times of sample rate (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rl6231: Add the K bypass for the PLL parameters (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: adau7118: Mark the ADAU7118 reset register as volatile (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: max9768: update contact email (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: max98373: reorder max98373_reset() in resume (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/tegra: workaround playback failure on Tegra194 (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: add member to store ratio for stripe control (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/tegra: correct number of SDO lines for Tegra194 (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: add mapping for ASRock TRX40 Creator (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Fix S3 pop noise on Dell Wyse (Jaroslav Kysela) [1869536]
- [sound] ALSA: Revert "ALSA: hda/realtek: Fix pop noise on ALC225" (Jaroslav Kysela) [1869536]
- [sound] ALSA: firewire-lib: fix 'function sizeof not defined' error of tracepoints format (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: Add poll callback for hwdep (Jaroslav Kysela) [1869536]
- [sound] ALSA: line6: hwdep: add support for O_NONBLOCK opening mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF/Intel: clarify SPDX license with GPL-2.0-only (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ipc: channel map structures (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: boards: sof-wm8804: support for Hifiberry Digiplus boards (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Update correct LED status at the first time usage of update_mute_led() (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Add control message quirk delay for Kingston HyperX headset (Jaroslav Kysela) [1869536]
- [sound] ALSA: isa/wavefront: prevent out of bounds write in ioctl (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Fix unused variable warning w/o CONFIG_LEDS_TRIGGER_AUDIO (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Add LED class support for micmute LED (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Enable micmute LED on and HP system (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda/realtek - Introduce polarity for micmute LED GPIO (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: sort out Kconfig, again (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: remove unwanted btn_type assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: remove duplicate rt5682_reset() calls (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: replace message printing from pr_() to dev_() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: remove empty default case (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: fix space issues (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: simplify assertions (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: change trigger sequence to fix pop noise when stopping playback on sdw platforms (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: replace sof_link_hda_process by sof_set_dai_config (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: set component dai_index to ipc dai config dai_index (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: send ipc for all found DAIs in sof_set_dai_config (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: broadwell: Fix oops during module removal (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: rt5682: fix I2C/Soundwire dependencies (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: mark PM functions __maybe_unused (Jaroslav Kysela) [1869536]
- [sound] ALSA: seq: oss: remove unused inline function snd_seq_oss_timer_is_realtime (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mxs-saif: Fix unused assignment (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoc: nau8810: add AUX related dapm widgets and routes (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: wm97xx: fix ac97 dependency (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: component: suppress uninitialized-variable warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_get_metadata() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_set_metadata() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_pointer() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_ack() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_get_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_set_params() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_trigger() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_shutdown() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compr_start() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_pcm_dai_remove() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_pcm_dai_probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_pcm_dai_bespoke_trigger() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_pcm_dai_trigger() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_pcm_dai_prepare() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_pcm_dai_new() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: don't overwide dai->driver->ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-dai: add soc_dai_err() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: Use devm_snd_soc_register_card() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: broadwell: add channel constraint (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: bdw-rt5650: add channel constraint (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: bdw-rt5677: add channel constraint (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: boards: add explicit dependency on GPIOLIB when DMIC is used (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: davinci-mcasp: Fix dma_chan refcnt leak when getting dma type (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: Automatic DMIC format configuration according to information from NHLT (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Multiple I/O PCM format support for pipe (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: Add alternative topology binary name (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hisilicon: Use the defined variable to clean code (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: Check for null pointer before dereferencing "ctx" in fsl_easrc_hw_free() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: ti: remove comparison to bool in omap_mcbsp_dai_set_dai_fmt() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: mxs-saif: Avoid unnecessary check (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw: add amp number in components string for ucm (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: hisilicon: Use IS_ERR() instead of IS_ERR_OR_NULL() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_esai: Disable exception interrupt before scheduling tasklet (Jaroslav Kysela) [1869536]
- [sound] ALSA: pcm_native: result of put_user() needs to be checked (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: snd-sof-intel-hda-common - add hda_model parameter and pass it to HDA codec driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-compress: avoid false-positive Wuninitialized warning (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8962: set CLOCKING2 as non-volatile register (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix racy list management in output queue (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Remove async workaround for Scarlett 2nd gen (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Improve frames size computation (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Refactor Intel NHLT init (Jaroslav Kysela) [1869536]
- [sound] ALSA: ACPICA: Add NHLT table signature (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Add missing dependency on IMX_SCU (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: fix spelling mistake "prefitler" -> "prefilter" (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: Skylake: Replace guid_copy() with import_guid() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: dmic: Allow GPIO operations to sleep (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: return true, false in snd_soc_volsw_is_stereo() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Fix build (Jaroslav Kysela) [1869536]
- [sound] ALSA: oxygen: use true, false for bool variables (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Fix a limit check in proc_dump_substream_formats() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel/skl/hda - fix oops on systems without i915 audio codec (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Add initial ZL38060 driver (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-compress: remove snd_compr_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sprd: use snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: sof: use snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: atom: use snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: qcom: q6sp6: use snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: uniphier: use snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codec: wm_adsp: use snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-compress: add snd_compress_ops (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: txx9: add back the hack for a too small resource_size_t (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_easrc: Add EASRC ASoC CPU DAI drivers (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: Move common definition to fsl_asrc_common (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: Support new property fsl, asrc-format (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl-asoc-card: Support new property fsl, asrc-format (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_asrc: rename asrc_priv to asrc (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Enable audio mclk during tegra_asoc_utils_init() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Add audio mclk parent configuration (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: Use device managed resource APIs to get the clock (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wcd934x: remove unneeded semicolon (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wcd9335: remove unneeded semicolon (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wcd934x: remove unnecessary comparisons to bool (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: boards: split woofer and tweeter support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Fix wrong dependency of da7210 and wm8983 (Jaroslav Kysela) [1869536]
- [sound] ALSA: soundwire: intel: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: Print more information in stream proc files (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: txx9: don't work around too small resource_size_t (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: haswell: Power transition refactor (Jaroslav Kysela) [1869536]
- [sound] ALSA: Fix misspellings of "Analog Devices" (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Fix misspellings of "Analog Devices" (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: handle multiple sets of tuple arrays (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: stop parsing when all tokens have been found (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: Get HDA rate and channels from topology (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: fix: parse hda_tokens to &config->hda (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: Get ALH rate amd channels from topology (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: align sof_ipc_dai_alh_params with FW (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Rename deprecated DMIC IPC struct field (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Change DMIC load IPC to fixed length (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: Fix typo in header file comment text (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Add XRUN flags field to struct sof_ipc_buffer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: make sof_ipc_cc_version to fixed length (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: change type char to uint8_t in topology.h (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: change type char to uint8_t in trace.h (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: change type char to uint8_t in info.h (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: add debug ABI version (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: add probe support extend data (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: Add support for DC Blocker (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse compiler version (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse windows (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: ext_manifest: parse firmware version (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Introduce extended manifest (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Introduce offset in firmware data (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Mark get_ext* function ext_hdr arguments as const (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: topology: fix: handle DAI widget connections properly with multiple CPU DAI's (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Add i.MX8MP device descriptor (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: Add i.MX8M HW support (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx: fix undefined reference issue (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: imx8: Fix randbuild error (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: topology: Remove unneeded semicolon (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: fsl_micfil: Omit superfluous error message in fsl_micfil_probe() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: skl_hda_generic: remove rtd->codec_dai (Jaroslav Kysela) [1869536]
- [sound] ALSA: usb-audio: RME Babyface Pro mixer patch (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8900: remove some defined but not used symbols (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8990: remove some defined but unused symbols (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8991: remove defined but not used 'wm8991_dapm_rxvoice_controls' (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: wm8994: remove wm1811_snd_controls and mixin_boost_tlv (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: Support nvidia, headset property (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt711: remove codec_dai use (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt700: remove codec_dai use (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt5682: remove codec_dai use (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_rt1308: remove codec dai use (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_hdmi: remove codec_dai use (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_sdw_hdmi: fix compilation issue in fallback mode (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof-da7219-max98373: add DMIC widget and route (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel: sof_sdw: init all aggregated codecs (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: boards: support Elkhart Lake with rt5660 (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: add PCI ID for ElkhartLake (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: Add ElkhartLake HDMI codec vid (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: intel/skl/hda - set autosuspend timeout for hda codecs (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: Intel: sof_da7219_max98373: Add BE dailink for dmic16k (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: remove cpu_dai/codec_dai/cpu_dais/codec_dais (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: tidyup soc_new_pcm_runtime() rtd setups (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: set rtd->num_cpu/codec at soc_new_pcm_runtime() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: soc-core: Add dynamic debug logs in soc_dai_link_sanity_check() (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: log number of microphones detected in NHLT tables (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: reduce verbosity on SoundWire detection (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: codecs: rt1308-sdw: reduce verbosity (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove unnecessary parentheses (Jaroslav Kysela) [1869536]
- [sound] ALSA: ASoC: SOF: remove unneeded variables (Jaroslav Kysela) [1869536]
- [sound] ALSA: hda: add autodetection for SoundWire (Jaroslav Kysela) [1869536]
- [s390] mm/gup: fix gup_fast with dynamic page table folding (Philipp Rudo) [1879401 1768713 1883266]

* Thu Nov 05 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-243.el8]
- [netdrv] Take common prefetch code structure into a function (Ivan Vecera) [1882011]
- [net] lwtunnel: only keep the available bits when setting vxlan md->gbp (Xin Long) [1879363]
- [net] sched: only keep the available bits when setting vxlan md->gbp (Xin Long) [1879363]
- [vhost] Don't call access_ok() when using IOTLB (Greg Kurz) [1883084]
- [clocksource] hv: clocksource: Add notrace attribute to read_hv_sched_clock_*() functions (Mohammed Gamal) [1880230]
- [net] core: Replace driver version to be kernel version (Petr Oros) [1867192]
- [net] use netif_is_bridge_port() to check for IFF_BRIDGE_PORT (Josef Oskera) [1867923]
- [net] sctp: fix sctp_auth_init_hmacs() error path (Xin Long) [1891413]
- [net] sctp: Fix IPv6 ancestor_size calc in sctp_copy_descendant (Xin Long) [1891413]
- [net] sctp: add SCTP_PEER_ADDR_THLDS_V2 sockopt (Xin Long) [1891413]
- [net] sctp: add support for Primary Path Switchover (Xin Long) [1891413]
- [net] sctp: add SCTP_EXPOSE_POTENTIALLY_FAILED_STATE sockopt (Xin Long) [1891413]
- [net] sctp: add SCTP_ADDR_POTENTIALLY_FAILED notification (Xin Long) [1891413]
- [net] sctp: add pf_expose per netns and sock and asoc (Xin Long) [1891413]
- [net] qos offload add flow status with dropped count (Ivan Vecera) [1890263]
- [i2c] i2c: i801: Add support for Intel Tiger Lake PCH-H (Steve Best) [1782725]
- [i2c] i2c: i801: Add support for Intel Emmitsburg PCH (David Arcari) [1837403]
- [mfd] mfd: intel-lpss: Add Intel Emmitsburg PCH PCI IDs (David Arcari) [1837403]
- [powerpc] powerpc/papr_scm: Fix warning triggered by perf_stats_show() (Diego Domingos) [1875364]
- [powerpc] powerpc/papr_scm: Limit the readability of 'perf_stats' sysfs attribute (Diego Domingos) [1875364]
- [powerpc] powerpc/papr_scm: Add support for fetching nvdimm 'fuel-gauge' metric (Diego Domingos) [1875364]
- [powerpc] powerpc/papr_scm: Fetch nvdimm performance stats from PHYP (Diego Domingos) [1875364]
- [include] driver-core: Introduce DEVICE_ATTR_ADMIN_{RO, RW} (Diego Domingos) [1875364]
- [net] netfilter: reject: skip csum verification for protocols that don't support it (Florian Westphal) [1740082]
- [net] netfilter: Fix remainder of pseudo-header protocol 0 (Florian Westphal) [1740082]
- [powerpc] powerpc/pseries: Add KVM guest doorbell restrictions (Diego Domingos) [1870221]
- [powerpc] powerpc: Inline doorbell sending functions (Diego Domingos) [1870221]
- [powerpc] powerpc/pseries: Use doorbells even if XIVE is available (Diego Domingos) [1870221]
- [powerpc] powerpc: Fix P10 PVR revision in /proc/cpuinfo for SMT4 cores (Steve Best) [1885927]
- [tools] selftests: implement flower classifier terse dump tests (Ivan Vecera) [1879189]
- [net] sched: cls_flower: implement terse dump support (Ivan Vecera) [1879189]
- [net] sched: implement terse dump support in act (Ivan Vecera) [1879189]
- [net] sched: introduce terse dump flag (Ivan Vecera) [1879189]
- [netdrv] net/mlx5e: Fix missing switch_id for representors (Petr Oros) [1874073]
- [tools] selftests: net: Add port split test (Petr Oros) [1874073]
- [net] devlink: Move input checks from driver to devlink (Petr Oros) [1874073]
- [net] devlink: Add a new devlink port split ability attribute and pass to netlink (Petr Oros) [1874073]
- [netdrv] mlxsw: Set port split ability attribute in driver (Petr Oros) [1874073]
- [net] devlink: Add a new devlink port lanes attribute and pass to netlink (Petr Oros) [1874073]
- [netdrv] mlxsw: Set number of port lanes attribute in driver (Petr Oros) [1874073]
- [net] devlink: Replace devlink_port_attrs_set parameters with a struct (Petr Oros) [1874073]
- [net] devlink: Move switch_port attribute of devlink_port_attrs to devlink_port (Petr Oros) [1874073]
- [net] devlink: Move set attribute of devlink_port_attrs to devlink_port (Petr Oros) [1874073]
- [netdrv] mlx5e: Use helper API to get devlink port index for all port flavours (Petr Oros) [1874073]
- [net] devlink: Add support for board.serial_number to info_get cb. (Petr Oros) [1879194]
- [net] devlink: Support setting hardware address of port function (Petr Oros) [1879195]
- [net] devlink: Support querying hardware address of port function (Petr Oros) [1879195]
- [net] devlink: Prepare devlink port functions to fill extack (Petr Oros) [1879195]
- [net] sctp: not disable bh in the whole sctp_get_port_local() (Xin Long) [1704525]
- [net] sctp: replace some sock_net(sk) with just 'net' (Xin Long) [1704525]
- [x86] x86/resctrl: Fix a NULL vs IS_ERR() static checker warning in rdt_cdp_peer_get() (Terry Bowman) [1873124]

* Wed Nov 04 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-242.el8]
- [net] sched: initialize with 0 before setting erspan md->u (Xin Long) [1879358]
- [net] ipv6: Discard next-hop MTU less than minimum link MTU (Balazs Nemeth) [1879893]
- [kvm] Revert "x86/kvm: Move context tracking where it belongs" (Nitesh Narayan Lal) [1890284]
- [video] hyperv_fb: Update screen_info after removing old framebuffer (Kairui Song) [1870081]
- [x86] x86/kexec: Use up-to-dated screen_info copy to fill boot params (Kairui Song) [1870081]
- [netdrv] netdevsim: Register control traps (Petr Oros) [1888724]
- [net] devlink: Add ACL control packet traps (Petr Oros) [1888724]
- [net] devlink: Add layer 3 control packet traps (Petr Oros) [1888724]
- [net] devlink: Add layer 2 control packet traps (Petr Oros) [1888724]
- [net] devlink: Add 'control' trap type (Petr Oros) [1888724]
- [net] devlink: Add 'mirror' trap action (Petr Oros) [1888724]
- [netdrv] netdevsim: Move layer 3 exceptions to exceptions trap group (Petr Oros) [1888724]
- [net] devlink: Create dedicated trap group for layer 3 exceptions (Petr Oros) [1888724]
- [net] xfrmi: drop ignore_df check before updating pmtu (Balazs Nemeth) [1857679]
- [kernel] sched/features: Fix !CONFIG_JUMP_LABEL case (Daniel Bristot de Oliveira) [1885850]
- [net] flow_offload: simplify hw stats check handling (Ivan Vecera) [1888317]
- [scsi] scsi: core: Only re-run queue in scsi_end_request() if device queue is busy (Ewan Milne) [1885733]
- [scsi] scsi: core: Clean up scsi_noretry_cmd() (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Make sdebug_build_parts() respect virtual_gb (Ewan Milne) [1885733]
- [scsi] scsi: fc: Add 256GBit speed setting to SCSI FC transport (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Implement lun_format (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Remove superfluous close zone in resp_open_zone() (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport_sas: Add spaces around binary operator "|" (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport_srp: Sanitize scsi_target_block/unblock sequences (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Implement tur_ms_to_ready parameter (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Fix request sense (Ewan Milne) [1885733]
- [scsi] scsi: core: Delete unnecessary buffer allocation for every loop iteration (Ewan Milne) [1885733]
- [scsi] scsi: core: Add missing scsi_device_put() in scsi_host_block() (Ewan Milne) [1885733]
- [scsi] scsi: core: Only return started requests from scsi_host_find_tag() (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport_iscsi: Drop a duplicated word (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport_sas: Add missing newline in sysfs 'enable' attribute (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport_fc: Match HBA Attribute Length with HBAAPI V2.0 definitions (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Update documentation url and bump version (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: every_nth triggered error injection (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Support hostwide tags (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add check for sdebug_max_queue during module init (Ewan Milne) [1885733]
- [scsi] scsi: sd_zbc: Fix kdoc comment format (Ewan Milne) [1885733]
- [scsi] scsi: sd: Fix kdoc comment format (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Fix in_use bitmap corruption (Ewan Milne) [1885733]
- [scsi] scsi: core: Register sysfs for SCSI workqueue (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport_spi: Fix function pointer check (Ewan Milne) [1885733]
- [scsi] scsi: core: Fix formatting errors in scsi_lib.c (Ewan Milne) [1885733]
- [scsi] scsi: core: Remove scsi_sdb_cache (Ewan Milne) [1885733]
- [scsi] scsi: sr: Fix sr_probe() missing deallocate of device minor (Ewan Milne) [1885733]
- [scsi] scsi: sr: Fix sr_probe() missing mutex_destroy (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Parser tables and code interaction (Ewan Milne) [1885733]
- [scsi] scsi: core: Refactor scsi_mq_setup_tags function (Ewan Milne) [1885733]
- [scsi] scsi: core: Fix incorrect usage of shost_for_each_device (Ewan Milne) [1885733]
- [scsi] scsi: sd: Add zoned capabilities device attribute (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Fix an error handling bug in sdeb_zbc_model_str() (Ewan Milne) [1885733]
- [scsi] scsi: pm: Balance pm_only counter of request queue during system resume (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Disallow zone sizes that are not powers of 2 (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Implement ZBC host-aware emulation (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add zone_size_mb module parameter (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add zone_nr_conv module parameter (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add zone_max_open module parameter (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add ZBC module parameter (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add ZBC zone commands (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add ZBC mode and VPD pages (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Bump to version 1.89 (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Re-arrange parameters alphabetically (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Implement PRE-FETCH commands (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Weaken rwlock around ramdisk access (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Implement VERIFY(10), add VERIFY(16) (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Add per_host_store option (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Use scsi_et_resid() where appropriate (Ewan Milne) [1885733]
- [scsi] scsi: scsi_debug: Randomize command completion time (Ewan Milne) [1885733]
- [scsi] scsi: core: doc: Change function comments to kernel-doc style (Ewan Milne) [1885733]
- [scsi] scsi: sr: Use {get, put}_unaligned_be*() instead of open-coding these functions (Ewan Milne) [1885733]
- [scsi] scsi_ioctl.c: switch SCSI_IOCTL_GET_IDLUN to copy_to_user() (Ewan Milne) [1885733]
- [scsi] scsi: core: Avoid calling synchronize_rcu() for each device in scsi_host_block() (Ewan Milne) [1885733]
- [scsi] scsi: st: remove unneeded variable 'result' in st_release() (Ewan Milne) [1885733]
- [scsi] scsi: sr: Fix sr_block_release() (Ewan Milne) [1885733]
- [scsi] scsi: scsi_trace: Use get_unaligned_be24() (Ewan Milne) [1885733]
- [scsi] scsi: st: Use get_unaligned_be24() and sign_extend32() (Ewan Milne) [1885733]
- [scsi] scsi: core: add scsi_host_busy_iter() (Ewan Milne) [1885733]
- [scsi] scsi: core: add scsi_host_(block, unblock) helper function (Ewan Milne) [1885733]
- [scsi] scsi: core: add scsi_host_complete_all_commands() helper (Ewan Milne) [1885733]
- [scsi] scsi: sr: get rid of sr global mutex (Ewan Milne) [1885733]
- [powerpc] scsi: sr: remove references to BLK_DEV_SR_VENDOR, leave it enabled (Ewan Milne) [1885733]
- [scsi] scsi: core: remove .for_blk_mq (Ewan Milne) [1885733]
- [scsi] scsi: sd_zbc: Rename sd_zbc_check_zones() (Ewan Milne) [1885733]
- [scsi] scsi: sd_zbc: Simplify sd_zbc_check_zones() (Ewan Milne) [1885733]
- [ata] scsi: core: Clean up SG_NONE (Ewan Milne) [1885733]
- [scsi] scsi: scsi_transport.h: switch to SPDX tags (Ewan Milne) [1885733]
- [scsi] scsi: libsas: Inject revalidate event for root port event (Ewan Milne) [1885733]
- [scsi] scsi: libsas: Stop hardcoding SAS address length (Ewan Milne) [1885733]
- [scsi] scsi: clean obsolete return values of eh_timed_out (Ewan Milne) [1885733]
- [scsi] scsi: libsas: Fix some indentation in libsas.h (Ewan Milne) [1885733]
- [scsi] scsi: st: mark expected switch fall-throughs (Ewan Milne) [1885733]
- [scsi] scsi: libsas: delete dead code in scsi_transport_sas.c (Ewan Milne) [1885733]
- [nvme] nvme-rdma: params to enable pi_capable devices (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Fix return value in __lpfc_nvme_ls_abort (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: fix axchg pointer reference after free and double frees (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Fix pointer checks and comments in (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] scsi: lpfc: Fix lpfc_nodelist leak when processing unsolicited event (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] scsi: lpfc: Remove redundant initialization to variable rc (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Refactor Send LS Response support (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Refactor Send LS Abort support (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: nvme: Add Receive LS Request and Send LS Response support to nvme (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Refactor Send LS Request support (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: nvmet: Add Send LS Request and Abort LS Request support (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: nvmet: Add support for NVME LS request hosthandle (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Refactor NVME LS receive handling (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Commonize lpfc_async_xchg_ctx state and flag definitions (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Refactor nvmet_rcv_ctx to create lpfc_async_xchg_ctx (Gopal Tiwari) [1857052 1857051 1853231]
- [scsi] lpfc: Refactor lpfc nvme headers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fabrics: allow to queue requests for live queues (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fc: cancel async events before freeing event struct (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: cancel async events before freeing event struct (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: cancel async events before freeing event struct (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Revert: Fix controller creation races with teardown flow (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: only use power of two io boundaries (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: fix reset hang if controller died in the middle of a reset (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Fix NULL dereference for pci nvme controllers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: cancel nvme device request before disabling (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: Fix a missed _irqsave version of spin_lock in 'nvmet_fc_fod_op_done()' (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: serialize controller teardown sequences (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: fix reset hang if controller died in the middle of a reset (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: fix timeout handler (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: fix controller instance leak (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: fix timeout handler (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fabrics: don't check state NVME_CTRL_NEW for request acceptance (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: serialize controller teardown sequences (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: Fix NULL dereference when a connect data comes in h2cdata pdu (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: have nvme_wait_freeze_timeout return if it timed out (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: Disable keep-alive timer when kato is cleared to 0h (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fc: Fix wrong return value in __nvme_fc_init_request() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Use spin_lock_irq() when taking the ctrl->lock (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: skip noiob for zoned devices (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: call blk_mq_free_request() directly (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: fix oops in pt cmd execution (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: Use u32 for nvme_dev.q_depth and nvme_queue.q_depth (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add ns tear down label for pt-cmd handling (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: fix a memory leak (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-passthru: Reject commands with non-sgl flags set (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-loop: remove extra variable in create ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-loop: set ctrl state connecting after init (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: introduce nvme_ctrl_get_by_path() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: introduce the passthru Kconfig option (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: introduce the passthru configfs interface (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: Add passthru enable/disable helpers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add passthru code to process commands (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: export nvme_find_get_ns() and nvme_put_ns() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: introduce nvme_execute_passthru_rq to call nvme_passthru_() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: remove redundant del_work_active flag (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: create helper function to obtain command effects (Gopal Tiwari) [1857052 1853231]
- [nvme] nvme-hwmon: log the controller device name (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: check successful reference in nvmet_fc_find_target_assoc (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: clear any SGL flags in passthru commands (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: fix deadlock in disconnect during scan_work and/or ana_work (Gopal Tiwari) [1857052 1857051 1853231]
- [acpi] nvme-pci: add support for ACPI StorageD3Enable property (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: use new shared CQ mechanism (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: use xarray for ctrl ns storing (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: document nvme controller states (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: use new shared CQ mechanism (Gopal Tiwari) [1857052 1857051 1853231]
- [infiniband] RDMA/core: Add protection for shared CQs used by ULPs (Gopal Tiwari) [1857052 1853231]
- [infiniband] RDMA/core: Introduce shared CQ pool API (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: remove an unnecessary condition (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: remove redundant validation in nvme_start_ctrl() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: prevent SK hynix PC400 from using Write Zeroes command (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: fix possible hang waiting for icresp response (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: explicitly update mpath disk capacity on revalidation (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: remove ns->disk checks (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: fix some comments issues (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: remove redundant segment validation (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: use the consistent return type of nvme_pci_iod_alloc_size() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: add a blank line after declarations (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: support for multiple Command Sets Supported and Effects log pages (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: document quirked Intel models (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: expose reconnect_delay and ctrl_loss_tmo via sysfs (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: use USEC_PER_SEC instead of magic numbers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: implement multiple I/O Command Set support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: simplify nvmet_process_resp_list (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: leverage request plugging (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: have queue prod/cons send list become a llist (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: optimize network stack with setting msg flags according to batch size (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fcloop: verify wwnn and wwpn format (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: use unsigned type for u64 (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: introduce flags member in nvmet_fabrics_ops (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: remove has_keyed_sgls initialization (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-loop: remove unused 'target_ctrl' in nvme_loop_ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: remove the empty line at the beginning of nvme_should_reset() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: code cleanup for nvme_alloc_host_mem() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: use unsigned for io queue depth (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-core: use u16 type for ctrl->sqsize (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-core: use u16 type for directives (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: fix a crash in nvme_mpath_add_disk (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: fix a missing completion with remove invalidation (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: factor out a nvme_rdma_end_request helper (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-multipath: fix deadlock due to head->lock (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: don't protect ns mutation with ns->head->lock (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-multipath: fix bogus request queue reference put (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-multipath: fix deadlock between ana_work and scan_work (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: fix possible deadlock when I/O is blocked (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: assign completion vector correctly (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: initialize tagset numa value to the value of the ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: override the value of the controller's numa node (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: initialize tagset numa value to the value of the ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: set initial value for controller's numa node (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-loop: initialize tagset numa value to the value of the ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: use simple suspend when a HMB is enabled (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: constify nvmet_tcp_ops (Gopal Tiwari) [1857052 1857051 1853231]
- [net] net: add sock_set_keepalive (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: constify nvme_tcp_mq_ops and nvme_tcp_admin_mq_ops (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: do not call del_gendisk() on a disk that was never added (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] ipv4: add ip_sock_set_tos (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] tcp: add tcp_sock_set_syncnt (Gopal Tiwari) [1857052 1857051 1853231]
- [net] tcp: add tcp_sock_set_nodelay (Gopal Tiwari) [1857052 1857051 1853231]
- [net] net: add sock_no_linger (Gopal Tiwari) [1857052 1857051 1853231]
- [target] net: add sock_set_reuseaddr (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] net: add sock_set_priority (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: avoid race between nvme_reap_pending_cqes() and nvme_poll() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add metadata/T10-PI support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: add metadata/T10-PI support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add metadata support for block devices (Gopal Tiwari) [1857052 1857051 1853231]
- [include] nvme: add Metadata Capabilities enumerations (Gopal Tiwari) [1857052 1853231]
- [nvme] nvme: set dma alignment to qword (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add metadata characteristics for a namespace (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: introduce NVME_INLINE_METADATA_SG_CNT (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: introduce max_integrity_segments ctrl attribute (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: add metadata/T10-PI support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: enforce extended LBA format for fabrics metadata (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: introduce nvme_rdma_sgl structure (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: rename nvmet_check_data_len to nvmet_check_transfer_len (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: rename nvmet_rw_len to nvmet_rw_data_len (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: generate AEN for ns revalidate size change (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: introduce NVME_NS_METADATA_SUPPORTED flag (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: introduce namespace features flag (Gopal Tiwari) [1857052 1857051 1853231]
- [lightnvm] lightnvm: disable interleaved metadata (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: make nvme_ns_has_pi accessible to transports (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add helper to revalidate bdev and file ns (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: revalidate-ns & generate AEN from configfs (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: set MSG_EOR if we send last payload in the batch (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: replace zero-length array with flexible-array (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: delete an unnecessary declaration (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: make sure write/poll_queues less or equal then cpu count (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: disable streams when get stream params failed (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: fix io_opt limit setting (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: set MSG_SENDPAGE_NOTLAST with MSG_MORE when we have more to send (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-tcp: move send/recv error handling in the send/recv methods instead of call-sites (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: mark nvmet_ana_state static (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: set MSG_SENDPAGE_NOTLAST with MSG_MORE when we have more to send (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: replace kstrndup() with kmemdup_nul() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: dma read memory barrier for completions (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: try to send request in queue_rq context (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: align addrfam list to spec (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: flush scan work on passthrough commands (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: define constants for identification values (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: use type-name map for address treq (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: use type-name map for ana states (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: use type-name map for address family (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-multipath: stop using ->queuedata (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: remove volatile cqes (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: avoid scheduling io_work if we are already polling (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: clean up error handling in nvme_init_ns_head (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: remove last_sq_tail (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add generic type-name mapping (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: centralize port enable access for configfs (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fc: avoid gcc-10 zero-length-bounds warning (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-tcp: use bh_lock in data_ready (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: add ns revalidation support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: slight cleanup for kbuild test warnings (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: unlink head after removing last namespace (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-multipath: set bdi capabilities once (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: revalidate after verifying identifiers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: use SRQ per completion vector (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: add an error flow for post_recv failures (Gopal Tiwari) [1857052 1853231]
- [nvme] nvme: remove the magic 1024 constant in nvme_scan_ns_list (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: release namespace head reference on error (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: avoid an Identify Controller command for each namespace scan (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: factor out a nvme_ns_remove_by_nsid helper (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: consolidate chunk_sectors settings (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: consolodate io settings (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: revalidate namespace stream parameters (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: clean up nvme_scan_work (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: refine the Qemu Identify CNS quirk (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: check namespace head shared property (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: always search for namespace head (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: remove unused parameter (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: add LS failure messages (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: provide num dword helper (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: Add Disconnect Association Xmt support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: track hostport handle for associations (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fcloop: add target to host LS request support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fcloop: refactor to enable target to host LS (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: rename ls_list to ls_rcv_list (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: perform small cleanups on unneeded checks (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fc: Update header and host for common definitions for LS handling (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: Update target for common definitions for LS handling (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: Better size LS buffers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fc nvmet-fc: refactor for common LS definitions (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fc: Add Disconnect Association Rcv support (Gopal Tiwari) [1857052 1857051 1853231]
- [include] nvme-fc: Sync header to FC-NVME-2 rev 1.08 (Gopal Tiwari) [1857052 1853231]
- [nvme] nvme-fc and nvmet-fc: revise LLDD api for LS reception and LS request (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: fix "slimmer CQ head update" (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: prevent double free in nvme_alloc_ns() error handling (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: fix double free of rdma queue (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: fix bonding failover possible NULL deref (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: fix NULL dereference when removing a referral (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: inherit stable pages constraint in the mpath stack device (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-fc: fix typo in comment (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: Replace comma with a semicolon (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fcloop: fix deallocation of working context (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: fix compat address handling in several ioctls (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Fix controller creation races with teardown flow (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-rdma: Add warning on state change failure at nvme_rdma_setup_ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: cleanup namespace identifier reporting in nvme_init_ns_head (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: rename __nvme_find_ns_head to nvme_find_ns_head (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: release ida resources (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: Implement get_mdts controller op (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Use nvme_state_terminal helper (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet-rdma: allocate RW ctxs according to mdts (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Add compat_ioctl handler for NVME_IOCTL_SUBMIT_IO (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-fabrics: Use scnprintf() for avoiding potential buffer overflow (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Remove unused return code from nvme_delete_ctrl_sync (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: Re-order nvme_pci_free_ctrl (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: properly print controller address (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: Add get_mdts op for controllers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: Simplify nvme_poll_irqdisable (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: slimmer CQ head update (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: Remove two-pass completions (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: Remove tag from process cq (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: check ncqr & nsqr for set-features cmd (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Check for readiness more quickly, to speed up boot time (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: code cleanup nvme_identify_ns_desc() (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Don't deter users from enabling hwmon support (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: expose hostid via sysfs for fabrics controllers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: expose hostnqn via sysfs for fabrics controllers (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] scsi: treewide: Consolidate {get, put}_unaligned_e24() definitions (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: check sscanf value for subsys serial attr (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: remove unused return code from nvme_alloc_ns (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: configfs code cleanup (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: make ctrl model configurable (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvmet: make ctrl-id configurable (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme: Fix uninitialized-variable warning (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme-pci: Use single IRQ vector for old Apple models (Gopal Tiwari) [1857052 1857051 1853231]
- [nvme] nvme/pci: Add sleep quirk for Samsung and Toshiba drives (Gopal Tiwari) [1857052 1857051 1853231]
- [md] dm: fix request-based DM to not bounce through indirect dm_make_request (Mike Snitzer) [1885650]
- [md] dm: add support for REQ_NOWAIT and enable it for linear target (Mike Snitzer) [1885650]
- [block] block: add QUEUE_FLAG_NOWAIT (Mike Snitzer) [1885650]
- [md] dm: export dm_copy_name_and_uuid (Mike Snitzer) [1885650]
- [md] dm snap persistent: simplify area_io() (Mike Snitzer) [1885650]
- [md] dm thin metadata: Remove unused local variable when create thin and snap (Mike Snitzer) [1885650]
- [md] dm raid: fix discard limits for raid0, raid1 and raid10 (Mike Snitzer) [1885650]
- [md] dm: use dm_table_get_device_name() where appropriate in targets (Mike Snitzer) [1885650]
- [md] dm table: make 'struct dm_table' definition accessible to all of DM core (Mike Snitzer) [1885650]
- [md] dm: eliminate need for start_io_acct() forward declaration (Mike Snitzer) [1885650]
- [md] dm: simplify __process_abnormal_io() (Mike Snitzer) [1885650]
- [md] dm: push use of on-stack flush_bio down to __send_empty_flush() (Mike Snitzer) [1885650]
- [md] dm thin metadata: Fix use-after-free in dm_bm_set_read_only (Mike Snitzer) [1885650]
- [md] dm thin metadata: Avoid returning cmd->bm wild pointer on error (Mike Snitzer) [1885650]
- [md] dm cache metadata: Avoid returning cmd->bm wild pointer on error (Mike Snitzer) [1885650]
- [md] dm integrity: fix error reporting in bitmap mode after creation (Mike Snitzer) [1885650]
- [md] dm crypt: Initialize crypto wait structures (Mike Snitzer) [1885650]
- [md] dm mpath: fix racey management of PG initialization (Mike Snitzer) [1885650]
- [md] dm writecache: handle DAX to partitions on persistent memory correctly (Mike Snitzer) [1885650]
- [md] dm ioctl: Fix compilation warning (Mike Snitzer) [1885650]
- [md] dm raid: Remove empty if statement (Mike Snitzer) [1885650]
- [md] dm verity: Fix compilation warning (Mike Snitzer) [1885650]
- [md] dm bufio: do buffer cleanup from a workqueue (Mike Snitzer) [1885650]
- [md] dm verity: add "panic_on_corruption" error handling mode (Mike Snitzer) [1885650]
- [md] dm: use noio when sending kobject event (Mike Snitzer) [1885650]
- [md] dm writecache: add cond_resched to loop in persistent_memory_claim() (Mike Snitzer) [1885650]
- [md] dm ioctl: use struct_size() helper in retrieve_deps() (Mike Snitzer) [1885650]
- [md] dm writecache: skip writecache_wait when using pmem mode (Mike Snitzer) [1885650]
- [md] dm writecache: correct uncommitted_block when discarding uncommitted entry (Mike Snitzer) [1885650]
- [md] dm crypt: avoid truncating the logical block size (Mike Snitzer) [1885650]
- [md] dm bufio: clean up rbtree block ordering (Mike Snitzer) [1885650]
- [documentation] dm integrity: add status line documentation (Mike Snitzer) [1885650]
- [md] dm: replace zero-length array with flexible-array (Mike Snitzer) [1885650]
- [md] dm mpath: add Historical Service Time Path Selector (Mike Snitzer) [1885650]
- [md] dm mpath: pass IO start time to path selector (Mike Snitzer) [1885650]
- [md] dm writecache: improve performance on DDR persistent memory (Optane) (Mike Snitzer) [1885650]
- [md] dm writecache: remove superfluous test in persistent_memory_claim (Mike Snitzer) [1885650]
- [md] dm persistent data: switch exit_ro_spine to return void (Mike Snitzer) [1885650]
- [md] dm integrity: remove set but not used variables (Mike Snitzer) [1885650]
- [documentation] dm crypt: document encrypted keyring key option (Mike Snitzer) [1885650]
- [md] dm crypt: support using encrypted keys (Mike Snitzer) [1885650]
- [md] dm verity fec: fix hash block number in verity_fec_decode (Mike Snitzer) [1885650]
- [documentation] dm integrity: document allow_discard option (Mike Snitzer) [1885650]
- [net] bridge: always clear mcast matching struct on reports and leaves (Ivan Vecera) [1859244]
- [net] bridge: increase multicast's default maximum number of entries (Ivan Vecera) [1859244]
- [net] bridge: mark hash_elasticity as obsolete (Ivan Vecera) [1859244]
- [net] bridge: multicast: use non-bh rcu flavor (Ivan Vecera) [1859244]
- [net] bridge: convert multicast to generic rhashtable (Ivan Vecera) [1859244]
- [net] revert "net/bridge: Replace call_rcu_bh() and rcu_barrier_bh()" (Ivan Vecera) [1859244]
- [net] ip6gre: avoid tx_error when sending MLD/DAD on external tunnels (Davide Caratti) [1847838]
- [nvme] nvme-rdma: fix controller reset hang during traffic (Ming Lei) [1881760]
- [nvme] nvme-tcp: fix controller reset hang during traffic (Ming Lei) [1881760]
- [scsi] scsi: sd: sd_zbc: Fix ZBC disk initialization (Ming Lei) [1881760]
- [md] dm: update original bio sector on Zone Append (Ming Lei) [1881760]
- [s390] s390/dasd: Fix zero write for FBA devices (Ming Lei) [1881760]
- [block] block: restore a specific error code in bdev_del_partition (Ming Lei) [1881760]
- [block] blk-stat: make q->stats->lock irqsafe (Ming Lei) [1881760]
- [block] blk-iocost: ioc_pd_free() shouldn't assume irq disabled (Ming Lei) [1881760]
- [block] block: fix locking in bdev_del_partition (Ming Lei) [1881760]
- [block] block: release disk reference in hd_struct_free_work (Ming Lei) [1881760]
- [block] loop: Set correct device size when using LOOP_CONFIGURE (Ming Lei) [1881760]
- [block] loop: unset GENHD_FL_NO_PART_SCAN on LOOP_CONFIGURE (Ming Lei) [1881760]
- [block] block: check queue's limits.discard_granularity in __blkdev_issue_discard() (Ming Lei) [1881760]
- [block] block: don't do revalidate zones on invalid devices (Ming Lei) [1881760]
- [s390] s390/dasd: fix inability to use DASD with DIAG driver (Ming Lei) [1881760]
- [tools] iocost_monitor: start from the oldest usage index (Ming Lei) [1881760]
- [block] iocost: Fix check condition of iocg abs_vdebt (Ming Lei) [1881760]
- [block] block: Use non _rcu version of list functions for tag_set_list (Ming Lei) [1881760]
- [block] blk-cgroup: show global disk stats in root cgroup io.stat (Ming Lei) [1881760]
- [block] blk-cgroup: make iostat functions visible to stat printing (Ming Lei) [1881760]
- [block] block: improve discard bio alignment in __blkdev_issue_discard() (Ming Lei) [1881760]
- [block] block: defer flush request no matter whether we have elevator (Ming Lei) [1881760]
- [block] block: make blk_timeout_init() static (Ming Lei) [1881760]
- [block] Revert "blk-rq-qos: remove redundant finish_wait to rq_qos_wait." (Ming Lei) [1881760]
- [block] block: relax jiffies rounding for timeouts (Ming Lei) [1881760]
- [lib] sbitmap: Consider cleared bits in sbitmap_bitmap_show() (Ming Lei) [1881760]
- [block] blk-cgroup: clean up indentation (Ming Lei) [1881760]
- [block] blk-cgroup: remove a dead check in blk_throtl_bio (Ming Lei) [1881760]
- [block] blk-cgroup: remove blkcg_bio_issue_check (Ming Lei) [1881760]
- [block] blk-cgroup: move rcu locking from blkcg_bio_issue_check to blk_throtl_bio (Ming Lei) [1881760]
- [kernel] cgroup: unexport cgroup_rstat_updated (Ming Lei) [1881760]
- [block] blk-cgroup: remove the !bio->bi_blkg check in blkcg_bio_issue_check (Ming Lei) [1881760]
- [block] block: move the initial blkg lookup into blkg_tryget_closest (Ming Lei) [1881760]
- [block] block: bypass blkg_tryget_closest for the root_blkg (Ming Lei) [1881760]
- [block] block: merge blkg_lookup_create and __blkg_lookup_create (Ming Lei) [1881760]
- [block] block: move the bio cgroup associatation helpers to blk-cgroup.c (Ming Lei) [1881760]
- [block] block: move bio_associate_blkg_from_page to mm/page_io.c (Ming Lei) [1881760]
- [block] block: merge __bio_associate_blkg into bio_associate_blkg_from_css (Ming Lei) [1881760]
- [block] block: really clone the block cgroup in bio_clone_blkg_association (Ming Lei) [1881760]
- [block] blkcg: clean up blkg_tryget_closest() (Ming Lei) [1881760]
- [block] block: remove bio_disassociate_blkg (Ming Lei) [1881760]
- [md] dm: use bio_uninit instead of bio_disassociate_blkg (Ming Lei) [1881760]
- [block] blk-rq-qos: remove redundant finish_wait to rq_qos_wait (Ming Lei) [1881760]
- [block] blktrace: Provide event for request merging (Ming Lei) [1881760]
- [fs] block: simplify sb_is_blkdev_sb (Ming Lei) [1881760]
- [fs] block: mark bd_finish_claiming static (Ming Lei) [1881760]
- [tty] tty/sysrq: emergency_thaw_all does not depend on CONFIG_BLOCK (Ming Lei) [1881760]
- [block] blk-iocost: Use struct_size() in kzalloc_node() (Ming Lei) [1881760]
- [block] block: bio: Use struct_size() in kmalloc() (Ming Lei) [1881760]
- [block] block: create the request_queue debugfs_dir on registration (Ming Lei) [1881760]
- [block] blk-mq: add a new blk_mq_complete_request_remote API (Ming Lei) [1881760]
- [block] blk-mq: factor out a blk_mq_complete_need_ipi helper (Ming Lei) [1881760]
- [block] blk-mq: remove the get_cpu/put_cpu pair in blk_mq_complete_request (Ming Lei) [1881760]
- [block] blk-mq: move failure injection out of blk_mq_complete_request (Ming Lei) [1881760]
- [block] blk-mq: merge the softirq vs non-softirq IPI logic (Ming Lei) [1881760]
- [block] blk-mq: short cut the IPI path in blk_mq_force_complete_rq for !SMP (Ming Lei) [1881760]
- [block] blk-mq: complete polled requests directly (Ming Lei) [1881760]
- [block] blk-mq: remove raise_blk_irq (Ming Lei) [1881760]
- [block] blk-mq: factor out a helper to reise the block softirq (Ming Lei) [1881760]
- [block] blk-mq: merge blk-softirq.c into blk-mq.c (Ming Lei) [1881760]
- [block] nbd: Fix memory leak in nbd_add_socket (Ming Lei) [1881760]
- [block] block: make function __bio_integrity_free() static (Ming Lei) [1881760]
- [block] virtio-blk: free vblk-vqs in error path of virtblk_probe() (Ming Lei) [1881760]
- [block] blk-mq-debugfs: update blk_queue_flag_nameaccordingly for new flags (Ming Lei) [1881760]
- [block] block: release bip in a right way in error path (Ming Lei) [1881760]
- [fs] block: make function 'kill_bdev' static (Ming Lei) [1881760]
- [block] loop: replace kill_bdev with invalidate_bdev (Ming Lei) [1881760]
- [block] partitions/ldm: Replace uuid_copy() with import_uuid() where it makes sense (Ming Lei) [1881760]
- [block] block: update hctx map when use multiple maps (Ming Lei) [1881760]
- [trace] trace/events/block.h: drop kernel-doc for dropped function parameter (Ming Lei) [1881760]
- [block] blk-mq: Remove redundant 'return' statement (Ming Lei) [1881760]
- [block] umem: remove redundant initialization of variable ret (Ming Lei) [1881760]
- [block] pktcdvd: remove redundant initialization of variable ret (Ming Lei) [1881760]
- [kernel] blktrace: fix endianness for blk_log_remap() (Ming Lei) [1881760]
- [kernel] blktrace: fix endianness in get_pdu_int() (Ming Lei) [1881760]
- [kernel] blktrace: use errno instead of bi_status (Ming Lei) [1881760]
- [block] block: nr_sects_write(): Disable preemption on seqcount write (Ming Lei) [1881760]
- [nvme] block: remove the error argument to the block_bio_complete tracepoint (Ming Lei) [1881760]
- [block] loop: Fix wrong masking of status flags (Ming Lei) [1881760]
- [block] block/bio-integrity: don't free 'buf' if bio_integrity_add_page() failed (Ming Lei) [1881760]
- [block] block: always define struct blk_integrity in genhd.h (Ming Lei) [1881760]
- [s390] dasd: refactor dasd_ioctl_information (Ming Lei) [1881760]
- [block] loop: Add LOOP_CONFIGURE ioctl (Ming Lei) [1881760]
- [block] loop: Clean up LOOP_SET_STATUS lo_flags handling (Ming Lei) [1881760]
- [block] loop: Rework lo_ioctl() __user argument casting (Ming Lei) [1881760]
- [block] loop: Move loop_set_status_from_info() and friends up (Ming Lei) [1881760]
- [block] loop: Factor out configuring loop from status (Ming Lei) [1881760]
- [block] loop: Remove figure_loop_size() (Ming Lei) [1881760]
- [block] loop: Refactor loop_set_status() size calculation (Ming Lei) [1881760]
- [block] loop: Switch to set_capacity_revalidate_and_notify() (Ming Lei) [1881760]
- [block] loop: Factor out setting loop device size (Ming Lei) [1881760]
- [block] loop: Remove sector_t truncation checks (Ming Lei) [1881760]
- [block] loop: Call loop_config_discard() only after new config is applied (Ming Lei) [1881760]
- [block] block/swim3: use set_current_state macro (Ming Lei) [1881760]
- [block] block: mark bio_wouldblock_error() bio with BIO_QUIET (Ming Lei) [1881760]
- [block] blk-wbt: rename __wbt_update_limits to wbt_update_limits (Ming Lei) [1881760]
- [block] blk-wbt: remove wbt_update_limits (Ming Lei) [1881760]
- [block] blk-throttle: remove tg_drain_bios (Ming Lei) [1881760]
- [block] blk-throttle: remove blk_throtl_drain (Ming Lei) [1881760]
- [block] null_blk: force complete for timeout request (Ming Lei) [1881760]
- [block] block: fix a warning when blkdev.h is included for !CONFIG_BLOCK builds (Ming Lei) [1881760]
- [block] block: reduce part_stat_lock() scope (Ming Lei) [1881760]
- [block] block: use __this_cpu_add() instead of access by smp_processor_id() (Ming Lei) [1881760]
- [block] block: remove rcu_read_lock() from part_stat_lock() (Ming Lei) [1881760]
- [block] block: add a blk_account_io_merge_bio helper (Ming Lei) [1881760]
- [block] block: account merge of two requests (Ming Lei) [1881760]
- [block] zram: nvdimm: use bio_{start, end}_io_acct and disk_{start, end}_io_acct (Ming Lei) [1881760]
- [nvdimm] nvdimm: use bio_{start,end}_io_acct (Ming Lei) [1881760]
- [md] dm: use bio_{start,end}_io_acct (Ming Lei) [1881760]
- [block] rsxx: use bio_{start,end}_io_acct (Ming Lei) [1881760]
- [block] drbd: use bio_{start,end}_io_acct (Ming Lei) [1881760]
- [block] block: add disk/bio-based accounting helpers (Ming Lei) [1881760]
- [block] block: remove the disk and queue NULL checks in blkdev_issue_flush (Ming Lei) [1881760]
- [fs] block: remove the error_sector argument to blkdev_issue_flush (Ming Lei) [1881760]
- [block] block: Remove unused flush_queue_delayed in struct blk_flush_queue (Ming Lei) [1881760]
- [block] null_blk: Zero-initialize read buffers in non-memory-backed mode (Ming Lei) [1881760]
- [include] block: Document the bio_vec properties (Ming Lei) [1881760]
- [block] bio.h: Declare the arguments of the bio iteration functions const (Ming Lei) [1881760]
- [block] block: Fix type of first compat_put_{, u}long() argument (Ming Lei) [1881760]
- [block] block: merge part_{inc, dev}_in_flight into their only callers (Ming Lei) [1881760]
- [block] block: don't call part_{inc, dec}_in_flight for blk-mq devices (Ming Lei) [1881760]
- [block] block: move the blk-mq calls out of part_in_flight{, _rw} (Ming Lei) [1881760]
- [block] block: mark blk_account_io_completion static (Ming Lei) [1881760]
- [block] blk-mq: allow blk_mq_make_request to consume the q_usage_counter reference (Ming Lei) [1881760]
- [kernel] blktrace: Report pid with note messages (Ming Lei) [1881760]
- [block] iocost: don't let vrate run wild while there's no saturation signal (Ming Lei) [1881760]
- [block] block: move blk_io_schedule() out of header file (Ming Lei) [1881760]
- [block] block: export bio_release_pages and bio_iov_iter_get_pages (Ming Lei) [1881760]
- [block] null_blk: Support REQ_OP_ZONE_APPEND (Ming Lei) [1881760]
- [scsi] scsi: sd_zbc: emulate ZONE_APPEND commands (Ming Lei) [1881760]
- [scsi] scsi: sd_zbc: factor out sanity checks for zoned commands (Ming Lei) [1881760]
- [block] block: Modify revalidate zones (Ming Lei) [1881760]
- [block] block: introduce blk_req_zone_write_trylock (Ming Lei) [1881760]
- [block] block: Introduce REQ_OP_ZONE_APPEND (Ming Lei) [1881760]
- [block] block: rename __bio_add_pc_page to bio_add_hw_page (Ming Lei) [1881760]
- [block] block: provide fallbacks for blk_queue_zone_is_seq and blk_queue_zone_no (Ming Lei) [1881760]
- [fs] block: add blk_io_schedule() for avoiding task hung in sync dio (Ming Lei) [1881760]
- [block] block: don't hold part0's refcount in IO path (Ming Lei) [1881760]
- [block] block: only define 'nr_sects_seq' in hd_part for 32bit SMP (Ming Lei) [1881760]
- [block] bdi: fix up for "remove the name field in struct backing_dev_info" (Ming Lei) [1881760]
- [fs] hfs: stop using ioctl_by_bdev (Ming Lei) [1881760]
- [fs] bdi: remove the name field in struct backing_dev_info (Ming Lei) [1881760]
- [mtd] bdi: simplify bdi_alloc (Ming Lei) [1881760]
- [block] bdi: remove bdi_register_owner (Ming Lei) [1881760]
- [mm] bdi: unexport bdi_register_va (Ming Lei) [1881760]
- [base] driver core: remove device_create_vargs (Ming Lei) [1881760]
- [block] block: rename blk_mq_alloc_rq_maps (Ming Lei) [1881760]
- [block] block: rename __blk_mq_alloc_rq_map (Ming Lei) [1881760]
- [fs] udf: stop using ioctl_by_bdev (Ming Lei) [1881760]
- [fs] isofs: stop using ioctl_by_bdev (Ming Lei) [1881760]
- [fs] hfsplus: stop using ioctl_by_bdev (Ming Lei) [1881760]
- [cdrom] cdrom: factor out a cdrom_multisession helper (Ming Lei) [1881760]
- [cdrom] cdrom: factor out a cdrom_read_tocentry helper (Ming Lei) [1881760]
- [ide] ide-cd: rename cdrom_read_tocentry (Ming Lei) [1881760]
- [cdrom] block: add a cdrom_device_info pointer to struct gendisk (Ming Lei) [1881760]
- [block] block: add a bio_queue_enter helper (Ming Lei) [1881760]
- [block] block: replace BIO_QUEUE_ENTERED with BIO_CGROUP_ACCT (Ming Lei) [1881760]
- [block] block: improve the submit_bio and generic_make_request documentation (Ming Lei) [1881760]
- [block] blk-mq: make function '__blk_mq_sched_dispatch_requests' static (Ming Lei) [1881760]
- [block] block: bypass ->make_request_fn for blk-mq drivers (Ming Lei) [1881760]
- [md] dm: remove the make_request_fn check in device_area_is_invalid (Ming Lei) [1881760]
- [block] block: remove create_io_context (Ming Lei) [1881760]
- [fs] block: unexport bdev_read_page and bdev_write_page (Ming Lei) [1881760]
- [scsi] scsi: merge scsi_init_sgtable into scsi_init_io (Ming Lei) [1881760]
- [block] block: provide a blk_rq_map_sg variant that returns the last element (Ming Lei) [1881760]
- [block] block: remove RQF_COPY_USER (Ming Lei) [1881760]
- [block] block: fold bdev_unhash_inode into invalidate_partition (Ming Lei) [1881760]
- [block] block: simplify block device syncing in bdev_del_partition (Ming Lei) [1881760]
- [block] block: don't call invalidate_partition from blk_drop_partitions (Ming Lei) [1881760]
- [s390] dasd: use blk_drop_partitions instead of badly reimplementing it (Ming Lei) [1881760]
- [block] block: remove the disk argument from blk_drop_partitions (Ming Lei) [1881760]
- [block] block: remove hd_struct_kill (Ming Lei) [1881760]
- [block] block: cleanup hd_struct freeing (Ming Lei) [1881760]
- [block] block: pass a hd_struct to delete_partition (Ming Lei) [1881760]
- [block] block: refactor blkpg_ioctl (Ming Lei) [1881760]
- [block] null_blk: don't allow discard for zoned mode (Ming Lei) [1881760]
- [block] null_blk: return error for invalid zone size (Ming Lei) [1881760]
- [block] iocost: protect iocg->abs_vdebt with iocg->waitq.lock (Ming Lei) [1881760]
- [block] block: remove the bd_openers checks in blk_drop_partitions (Ming Lei) [1881760]
- [block] null_blk: Cleanup zoned device initialization (Ming Lei) [1881760]
- [block] null_blk: Fix zoned command handling (Ming Lei) [1881760]
- [fs] block: remove unused header (Ming Lei) [1881760]
- [fs] bdev: Reduce time holding bd_mutex in sync in blkdev_close() (Ming Lei) [1881760]
- [trace] blk-wbt: Drop needless newlines from tracepoint format strings (Ming Lei) [1881760]
- [block] blk-wbt: Use tracepoint_string() for wbt_step tracepoint string literals (Ming Lei) [1881760]
- [s390] s390/dasd: remove IOSCHED_DEADLINE from DASD Kconfig (Ming Lei) [1881760]
- [block] block: fix busy device checking in blk_drop_partitions again (Ming Lei) [1881760]
- [block] block: fix busy device checking in blk_drop_partitions (Ming Lei) [1881760]
- [block] blkcg: don't offline parent blkcg first (Ming Lei) [1881760]
- [block] blkcg: rename blkcg->cgwb_refcnt to ->online_pin and always use it (Ming Lei) [1881760]
- [block] null_blk: add trace in null_blk_zoned.c (Ming Lei) [1881760]
- [block] null_blk: add tracepoint helpers for zoned mode (Ming Lei) [1881760]
- [block] block: add a zone condition debug helper (Ming Lei) [1881760]
- [block] rsxx: Replace zero-length array with flexible-array member (Ming Lei) [1881760]
- [block] null_blk: describe the usage of fault injection param (Ming Lei) [1881760]
- [block] null_blk: fix spurious IO errors after failed past-wp access (Ming Lei) [1881760]
- [block] nbd: requeue command if the soecket is changed (Ming Lei) [1881760]
- [block] nbd: enable replace socket if only one connection is configured (Ming Lei) [1881760]
- [block] block/drbd: delete invalid function drbd_md_mark_dirty_ (Ming Lei) [1881760]
- [block] loop: Only freeze block queue when needed (Ming Lei) [1881760]
- [block] loop: Only change blocksize when needed (Ming Lei) [1881760]
- [block] block: move bdevname() into block/generic-partition-rh.c (Ming Lei) [1881760]
- [block] block: return NULL in blk_alloc_queue() on error (Ming Lei) [1881760]
- [block] block: simplify queue allocation (Ming Lei) [1881760]
- [block] Revert "blkdev: check for valid request queue before issuing flush" (Ming Lei) [1881760]
- [block] null_blk: use blk_mq_init_queue_data (Ming Lei) [1881760]
- [block] block: add a blk_mq_init_queue_data helper (Ming Lei) [1881760]
- [block] block: move the ->devnode callback to struct block_device_operations (Ming Lei) [1881760]
- [block] block: move block layer internals out of include/linux/genhd.h (Ming Lei) [1881760]
- [fs] block: move guard_bio_eod to bio.c (Ming Lei) [1881760]
- [block] block: unexport disk_map_sector_rcu (Ming Lei) [1881760]
- [block] block: unexport disk_get_part (Ming Lei) [1881760]
- [block] block: mark part_in_flight and part_in_flight_rw static (Ming Lei) [1881760]
- [block] block: mark block_depr static (Ming Lei) [1881760]
- [block] block: factor out requeue handling from dispatch code (Ming Lei) [1881760]
- [block] block/diskstats: replace time_in_queue with sum of request times (Ming Lei) [1881760]
- [block] block/diskstats: accumulate all per-cpu counters in one pass (Ming Lei) [1881760]
- [block] block: merge partition-generic.c and check.c (Ming Lei) [1881760]
- [block] block: move the various x86 Unix label formats out of genhd.h (Ming Lei) [1881760]
- [block] partitions/msdos: remove LINUX_SWAP_PARTITION (Ming Lei) [1881760]
- [block] block: move the *_PARTITION enum out of genhd.h (Ming Lei) [1881760]
- [scsi] block: move struct partition out of genhd.h (Ming Lei) [1881760]
- [block] block: remove block/partitions/sun.h (Ming Lei) [1881760]
- [block] block: remove block/partitions/sgi.h (Ming Lei) [1881760]
- [block] block: remove block/partitions/osf.h (Ming Lei) [1881760]
- [block] block: remove block/partitions/karma.h (Ming Lei) [1881760]
- [block] block: declare all partition detection routines in check.h (Ming Lei) [1881760]
- [block] block: remove warn_no_part (Ming Lei) [1881760]
- [md] block: cleanup how md_autodetect_dev is called (Ming Lei) [1881760]
- [block] block: unexport read_dev_sector and put_dev_sector (Ming Lei) [1881760]
- [scsi] scsi: simplify scsi_partsize (Ming Lei) [1881760]
- [block] block: remove alloc_part_info and free_part_info (Ming Lei) [1881760]
- [block] block: move sysfs methods shared by disks and partitions to genhd.c (Ming Lei) [1881760]
- [block] block: move disk_name and related helpers out of partition-generic.c (Ming Lei) [1881760]
- [fs] block: remove __bdevname (Ming Lei) [1881760]
- [block] block: remove the blk_lookup_devt export (Ming Lei) [1881760]
- [block] block, bfq: invoke flush_idle_tree after reparent_active_queues in pd_offline (Ming Lei) [1881760]
- [block] block, bfq: make reparent_leaf_entity actually work only on leaf entities (Ming Lei) [1881760]
- [block] block, bfq: turn put_queue into release_process_ref in __bfq_bic_change_cgroup (Ming Lei) [1881760]
- [block] block, bfq: move forward the getting of an extra ref in bfq_bfqq_move (Ming Lei) [1881760]
- [scsi] scsi: Convert to use set_capacity_revalidate_and_notify (Ming Lei) [1881760]
- [nvme] nvme: Convert to use set_capacity_revalidate_and_notify (Ming Lei) [1881760]
- [block] virtio_blk.c: Convert to use set_capacity_revalidate_and_notify (Ming Lei) [1881760]
- [block] block/genhd: Notify udev about capacity change (Ming Lei) [1881760]
- [fs] block: fix a device invalidation regression (Ming Lei) [1881760]
- [block] blk-iocost: remove duplicated lines in comments (Ming Lei) [1881760]
- [block] block: sed-opal: Change the check condition for regular session validity (Ming Lei) [1881760]
- [block] block: Document genhd capability flags (Ming Lei) [1881760]
- [block] block: cleanup comment for blk_flush_complete_seq (Ming Lei) [1881760]
- [block] block: remove unneeded argument from blk_alloc_flush_queue (Ming Lei) [1881760]
- [block] block: cleanup for _blk/blk_rq_prep_clone (Ming Lei) [1881760]
- [block] block: remove redundant setting of QUEUE_FLAG_DYING (Ming Lei) [1881760]
- [block] block: use bio_{wouldblock, io}_error in direct_make_request (Ming Lei) [1881760]
- [block] block: fix comment for blk_cloned_rq_check_limits (Ming Lei) [1881760]
- [block] null_blk: Add support for init_hctx() fault injection (Ming Lei) [1881760]
- [block] null_blk: Handle null_add_dev() failures properly (Ming Lei) [1881760]
- [block] null_blk: Fix the null_add_dev() error path (Ming Lei) [1881760]
- [block] compat_ioctl: simplify up block/ioctl.c (Ming Lei) [1881760]
- [block] compat_ioctl: block: simplify compat_blkpg_ioctl() (Ming Lei) [1881760]
- [block] compat_ioctl: block: move blkdev_compat_ioctl() into ioctl.c (Ming Lei) [1881760]
- [block] blk-mq: insert flush request to the front of dispatch queue (Ming Lei) [1881760]
- [block] block: Remove used kblockd_schedule_work_on() (Ming Lei) [1881760]
- [block] null_blk: remove unused fields in 'nullb_cmd' (Ming Lei) [1881760]
- [block] drbd: fifo_alloc() should use struct_size (Ming Lei) [1881760]
- [block] partitions/ldm: fix spelling mistake "to" -> "too" (Ming Lei) [1881760]
- [block] block: mark zone-mgmt bios with REQ_SYNC (Ming Lei) [1881760]
- [block] blk-mq: Document functions for sending request (Ming Lei) [1881760]
- [block] block: Allow t10-pi to be modular (Ming Lei) [1881760]
- [block] blk-mq: optimise blk_mq_flush_plug_list() (Ming Lei) [1881760]
- [include] list: introduce list_for_each_continue() (Ming Lei) [1881760]
- [block] blk-mq: optimise rq sort function (Ming Lei) [1881760]
- [block] blk-cgroup: cgroup_rstat_updated() shouldn't be called on cgroup1 (Ming Lei) [1881760]
- [block] blk-cgroup: separate out blkg_rwstat under CONFIG_BLK_CGROUP_RWSTAT (Ming Lei) [1881760]
- [block] blk-cgroup: reimplement basic IO stats using cgroup rstat (Ming Lei) [1881760]
- [block] blk-cgroup: remove now unused blkg_print_stat_{bytes|ios}_recursive() (Ming Lei) [1881760]
- [block] blk-throtl: stop using blkg->stat_bytes and ->stat_ios (Ming Lei) [1881760]
- [block] bfq-iosched: Ensure bio->bi_blkg is valid before using it (Ming Lei) [1881760]
- [block] bfq-iosched: stop using blkg->stat_bytes and ->stat_ios (Ming Lei) [1881760]
- [block] bfq-iosched: relocate bfqg_*rwstat*() helpers (Ming Lei) [1881760]
- [md] dm: fix comment in __dm_suspend() (Mike Snitzer) [1881531]
- [md] dm: fold dm_process_bio() into dm_make_request() (Mike Snitzer) [1881531]
- [md] dm: fix missing imposition of queue_limits from dm_wq_work() thread (Mike Snitzer) [1881531]
- [md] dm: optimize max_io_len() by inlining max_io_len_target_boundary() (Mike Snitzer) [1881531]
- [md] dm: push md->immutable_target optimization down to __process_bio() (Mike Snitzer) [1881531]
- [md] dm: change max_io_len() to use blk_max_size_offset() (Mike Snitzer) [1881531]
- [md] dm table: stack 'chunk_sectors' limit to account for target-specific splitting (Mike Snitzer) [1881531]
- [block] block: allow 'chunk_sectors' to be non-power-of-2 (Mike Snitzer) [1881531]
- [block] block: use lcm_not_zero() when stacking chunk_sectors (Mike Snitzer) [1881531]
- [md] dm: fix bio splitting and its bio completion order for regular IO (Mike Snitzer) [1881531]
- [net] net-sysfs: add backlog len and CPU id to softnet data (Paolo Abeni) [1866909]
- [net] try to avoid unneeded backlog flush (Paolo Abeni) [1866909]
- [net] skbuff: fix a data race in skb_queue_len() (Paolo Abeni) [1866909]
- [cpuidle] cpuidle: pseries: Fix CEDE latency conversion from tb to us (Diego Domingos) [1608791]
- [cpuidle] cpuidle: pseries: Fixup exit latency for CEDE(0) (Diego Domingos) [1608791]
- [cpuidle] cpuidle: pseries: Add function to parse extended CEDE records (Diego Domingos) [1608791]
- [cpuidle] cpuidle: pseries: Set the latency-hint before entering CEDE (Diego Domingos) [1608791]
- [arm64] paravirt: Initialize steal time when cpu is online (Andrew Jones) [1879137]

* Mon Nov 02 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-241.el8]
- [infiniband] i40iw: Add support to make destroy QP synchronous (Stefan Assmann) [1757949]
- [fs] xfs: don't eat an EIO/ENOSPC writeback error when scrubbing data fork (Carlos Maiolino) [1859160]
- [fs] xfs: fix inode allocation block res calculation precedence (Carlos Maiolino) [1859160]
- [fs] xfs: fix reflink quota reservation accounting error (Carlos Maiolino) [1859160]
- [fs] xfs: preserve rmapbt swapext block reservation from freed blocks (Carlos Maiolino) [1859160]
- [fs] xfs: fix duplicate verification from xfs_qm_dqflush() (Carlos Maiolino) [1859160]
- [fs] xfs: fix unmount hang and memory leak on shutdown during quotaoff (Carlos Maiolino) [1859160]
- [fs] xfs: factor out quotaoff intent AIL removal and memory free (Carlos Maiolino) [1859160]
- [fs] xfs: fix incorrect test in xfs_alloc_ag_vextent_lastblock (Carlos Maiolino) [1859160]
- [fs] xfs: fix regression in "cleanup xfs_dir2_block_getdents" (Carlos Maiolino) [1859160]
- [fs] xfs: fix use-after-free when aborting corrupt attr inactivation (Carlos Maiolino) [1859160]
- [fs] xfs: fix iclog release error check race with shutdown (Carlos Maiolino) [1859160]
- [fs] xfs: Add the missed xfs_perag_put() for xfs_ifree_cluster() (Carlos Maiolino) [1859160]
- [fs] xfs: clean up the error handling in xfs_swap_extents (Carlos Maiolino) [1859160]
- [fs] xfs: acquire superblock freeze protection on eofblocks scans (Carlos Maiolino) [1859160]
- [fs] xfs: xfs_dabuf_map should return ENOMEM when map allocation fails (Carlos Maiolino) [1859160]
- [fs] xfs: fix xfs_buf_ioerror_alert location reporting (Carlos Maiolino) [1859160]
- [fs] xfs: remove unnecessary null pointer checks from _read_agf callers (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_*read_agf return EAGAIN to ALLOC_FLAG_TRYLOCK callers (Carlos Maiolino) [1859160]
- [fs] xfs: remove the xfs_btree_get_buffunctions (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_trans_get_buf return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_trans_get_buf_map return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_buf_read return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_buf_get_uncached return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_buf_get return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_buf_read_map return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_buf_get_map return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: make xfs_buf_alloc return an error code (Carlos Maiolino) [1859160]
- [fs] xfs: fix uninitialized variable in xfs_attr3_leaf_inactive (Carlos Maiolino) [1859160]
- [fs] xfs: change return value of xfs_inode_need_cow to int (Carlos Maiolino) [1859160]
- [fs] xfs: check log iovec size to make sure it's plausibly a buffer log format (Carlos Maiolino) [1859160]
- [fs] xfs: make struct xfs_buf_log_format have a consistent size (Carlos Maiolino) [1859160]
- [fs] xfs: complain if anyone tries to create a too-large buffer log item (Carlos Maiolino) [1859160]
- [fs] xfs: clean up xfs_buf_item_get_format return value (Carlos Maiolino) [1859160]
- [fs] xfs: streamline xfs_attr3_leaf_inactive (Carlos Maiolino) [1859160]
- [fs] xfs: fix memory corruption during remote attr value buffer invalidation (Carlos Maiolino) [1859160]
- [fs] xfs: refactor remote attr value buffer invalidation (Carlos Maiolino) [1859160]
- [fs] xfs: fix IOCB_NOWAIT handling in xfs_file_dio_aio_read (Carlos Maiolino) [1859160]
- [fs] xfs: Add __packed to xfs_dir2_sf_entry_t definition (Carlos Maiolino) [1859160]
- [fs] xfs: fix s_maxbytes computation on 32-bit kernels (Carlos Maiolino) [1859160]
- [fs] xfs: truncate should remove all blocks, not just to the end of the page cache (Carlos Maiolino) [1859160]
- [fs] xfs: introduce XFS_MAX_FILEOFF (Carlos Maiolino) [1859160]
- [fs] xfs: remove bogus assertion when online repair isn't enabled (Carlos Maiolino) [1859160]
- [fs] xfs: Remove all strlen in all xfs_attr_* functions for attr names (Carlos Maiolino) [1859160]
- [fs] xfs: fix misuse of the XFS_ATTR_INCOMPLETE flag (Carlos Maiolino) [1859160]
- [fs] xfs: also remove cached ACLs when removing the underlying attr (Carlos Maiolino) [1859160]
- [fs] xfs: reject invalid flags combinations in XFS_IOC_ATTRMULTI_BY_HANDLE (Carlos Maiolino) [1859160]
- [fs] xfs: remove shadow variable in xfs_btree_lshift (Carlos Maiolino) [1859160]
- [fs] xfs: quota: move to time64_t interfaces (Carlos Maiolino) [1859160]
- [fs] xfs: Make the symbol 'xfs_rtalloc_log_count' static (Carlos Maiolino) [1859160]
- [fs] libxfs: resync with the userspace libxfs (Carlos Maiolino) [1859160]
- [fs] xfs: fix log reservation overflows when allocating large rt extents (Carlos Maiolino) [1859160]
- [fs] xfs: fix mount failure crash on invalid iclog memory access (Carlos Maiolino) [1859160]
- [fs] xfs: don't check for AG deadlock for realtime files in bunmapi (Carlos Maiolino) [1859160]
- [fs] xfs: fix realtime file data space leak (Carlos Maiolino) [1859160]
- [fs] xfs: allow parent directory scans to be interrupted with fatal signals (Carlos Maiolino) [1859160]
- [fs] xfs: remove the mappedbno argument to xfs_da_get_buf (Carlos Maiolino) [1859160]
- [fs] xfs: remove the mappedbno argument to xfs_da_read_buf (Carlos Maiolino) [1859160]
- [fs] xfs: split xfs_da3_node_read (Carlos Maiolino) [1859160]
- [fs] xfs: remove the mappedbno argument to xfs_dir3_leafn_read (Carlos Maiolino) [1859160]
- [fs] xfs: remove the mappedbno argument to xfs_dir3_leaf_read (Carlos Maiolino) [1859160]
- [fs] xfs: remove the mappedbno argument to xfs_attr3_leaf_read (Carlos Maiolino) [1859160]
- [fs] xfs: remove the mappedbno argument to xfs_da_reada_buf (Carlos Maiolino) [1859160]
- [fs] xfs: improve the xfs_dabuf_map calling conventions (Carlos Maiolino) [1859160]
- [fs] xfs: refactor xfs_dabuf_map (Carlos Maiolino) [1859160]
- [fs] xfs: simplify mappedbno handling in xfs_da_{get, read}_buf (Carlos Maiolino) [1859160]
- [fs] xfs: report corruption only as a regular error (Carlos Maiolino) [1859160]
- [fs] xfs: Remove kmem_zone_free() wrapper (Carlos Maiolino) [1859160]
- [fs] xfs: Remove kmem_zone_destroy() wrapper (Carlos Maiolino) [1859160]
- [fs] xfs: Remove slab init wrappers (Carlos Maiolino) [1859160]
- [fs] xfs: fix another missing include (Carlos Maiolino) [1859160]
- [fs] xfs: remove XFS_IOC_FSSETDM and XFS_IOC_FSSETDM_BY_HANDLE (Carlos Maiolino) [1859160]
- [fs] xfs: remove duplicated include from xfs_dir2_data.c (Carlos Maiolino) [1859160]
- [fs] xfs: remove unused structure members & simple typedefs (Carlos Maiolino) [1859160]
- [fs] xfs: remove unused typedef definitions (Carlos Maiolino) [1859160]
- [fs] xfs: Replace function declaration by actual definition (Carlos Maiolino) [1859160]
- [fs] xfs: remove the xfs_qoff_logitem_t typedef (Carlos Maiolino) [1859160]
- [fs] xfs: remove the xfs_dq_logitem_t typedef (Carlos Maiolino) [1859160]
- [fs] xfs: remove the xfs_quotainfo_t typedef (Carlos Maiolino) [1859160]
- [fs] xfs: remove the xfs_disk_dquot_t and xfs_dquot_t (Carlos Maiolino) [1859160]
- [fs] xfs: avoid time_t in user api (Carlos Maiolino) [1859160]
- [fs] xfs: don't reset the "inode core" in xfs_iread (Carlos Maiolino) [1859160]
- [fs] xfs: merge the projid fields in struct xfs_icdinode (Carlos Maiolino) [1859160]
- [fs] xfs: use a struct timespec64 for the in-core crtime (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->m_dirnameops (Carlos Maiolino) [1859160]
- [fs] xfs: remove the unused m_chsize field (Carlos Maiolino) [1859160]
- [fs] xfs: convert open coded corruption check to use XFS_IS_CORRUPT (Carlos Maiolino) [1859160]
- [fs] xfs: kill the XFS_WANT_CORRUPT_* macros (Carlos Maiolino) [1859160]
- [fs] xfs: add a XFS_IS_CORRUPT macro (Carlos Maiolino) [1859160]
- [fs] xfs: attach dquots before performing xfs_swap_extents (Carlos Maiolino) [1859160]
- [fs] xfs: actually check xfs_btree_check_block return in xfs_btree_islastblock (Carlos Maiolino) [1859160]
- [fs] xfs: always pass a valid hdr to xfs_dir3_leaf_check_int (Carlos Maiolino) [1859160]
- [fs] xfs: merge xfs_dir2_data_freescan and xfs_dir2_data_freescan_int (Carlos Maiolino) [1859160]
- [fs] xfs: remove the now unused dir ops infrastructure (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->data_get_ftype and ->data_put_ftype (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->data_bestfree_p (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xfs_dir2_data_entsize (Carlos Maiolino) [1859160]
- [fs] xfs: move the dir2 data block fixed offsets to struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->data_entry_tag_p (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->data_entsize (Carlos Maiolino) [1859160]
- [fs] xfs: replace xfs_dir3_data_endp with xfs_dir3_data_end_offset (Carlos Maiolino) [1859160]
- [fs] xfs: remove the now unused ->data_entry_p method (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup __xfs_dir3_data_check (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xfs_dir2_data_freescan_int (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xfs_dir2_block_to_sf (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xchk_directory_data_bestfree (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xchk_dir_rec (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xfs_dir2_leaf_getdents (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xfs_dir2_block_getdents (Carlos Maiolino) [1859160]
- [fs] xfs: remove the ->data_unused_p method (Carlos Maiolino) [1859160]
- [fs] xfs: remove the ->data_dot_entry_p and ->data_dotdot_entry_p methods (Carlos Maiolino) [1859160]
- [fs] xfs: remove the data_dotdot_offset field in struct xfs_dir_ops (Carlos Maiolino) [1859160]
- [fs] xfs: remove the data_dot_offset field in struct xfs_dir_ops (Carlos Maiolino) [1859160]
- [fs] xfs: remove the unused ->data_first_entry_p method (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->sf_get_ftype and ->sf_put_ftype (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->sf_get_ino and ->sf_put_ino (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->sf_entsize and ->sf_nextentry (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->sf_get_parent_ino and ->sf_put_parent_ino (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->db_to_fdb and ->db_to_fdindex (Carlos Maiolino) [1859160]
- [fs] xfs: move the max dir2 free bests count to struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: move the dir2 free header size to struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: add a bests pointer to struct xfs_dir3_icfree_hdr (Carlos Maiolino) [1859160]
- [fs] xfs: make the xfs_dir3_icfree_hdr available to xfs_dir2_node_addname_int (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->free_hdr_to_disk (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->free_hdr_from_disk (Carlos Maiolino) [1859160]
- [fs] xfs: move the max dir2 leaf entries count to struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: move the dir2 leaf header size to struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: add an entries pointer to struct xfs_dir3_icleaf_hdr (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->leaf_hdr_to_disk (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->leaf_hdr_from_disk (Carlos Maiolino) [1859160]
- [fs] xfs: move the node header size to struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: add a btree entries pointer to struct xfs_da3_icnode_hdr (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->node_hdr_to_disk (Carlos Maiolino) [1859160]
- [fs] xfs: devirtualize ->node_hdr_from_disk (Carlos Maiolino) [1859160]
- [fs] xfs: refactor btree node scrubbing (Carlos Maiolino) [1859160]
- [fs] xfs: use unsigned int for all size values in struct xfs_da_geometry (Carlos Maiolino) [1859160]
- [fs] xfs: move incore structures out of xfs_da_format.h (Carlos Maiolino) [1859160]
- [fs] xfs: remove a stray tab in xfs_remount_rw() (Carlos Maiolino) [1859160]
- [fs] xfs: convert EIO to EFSCORRUPTED when log contents are invalid (Carlos Maiolino) [1859160]
- [fs] xfs: refactor "does this fork map blocks" predicate (Carlos Maiolino) [1859160]
- [fs] xfs: clean up weird while loop in xfs_alloc_ag_vextent_near (Carlos Maiolino) [1859160]
- [fs] xfs: annotate functions that trip static checker locking checks (Carlos Maiolino) [1859160]
- [fs] xfs: Correct comment tyops -> typos (Carlos Maiolino) [1859160]
- [fs] xfs: range check ri_cnt when recovering log items (Carlos Maiolino) [1859160]
- [fs] xfs: "optimize" buffer item log segment bitmap setting (Carlos Maiolino) [1859160]
- [fs] xfs: null out bma->prev if no previous extent (Carlos Maiolino) [1859160]
- [fs] xfs: fix missing header includes (Carlos Maiolino) [1859160]
- [fs] xfs: periodically yield scrub threads to the scheduler (Carlos Maiolino) [1859160]
- [fs] xfs: remove redundant assignment to variable error (Carlos Maiolino) [1859160]
- [fs] xfs: add missing early termination checks to record scrubbing functions (Carlos Maiolino) [1859160]
- [fs] xfs: make the assertion message functions take a mount parameter (Carlos Maiolino) [1859160]
- [fs] xfs: add missing assert in xfs_fsmap_owner_from_rmap (Carlos Maiolino) [1859160]
- [fs] xfs: decrease indenting problems in xfs_dabuf_map (Carlos Maiolino) [1859160]
- [fs] xfs: fold xfs_mount-alloc() into xfs_init_fs_context() (Carlos Maiolino) [1859160]
- [fs] xfs: move xfs_fc_parse_param() above xfs_fc_get_tree() (Carlos Maiolino) [1859160]
- [fs] xfs: move xfs_fc_get_tree() above xfs_fc_reconfigure() (Carlos Maiolino) [1859160]
- [fs] xfs: move xfs_fc_reconfigure() above xfs_fc_free() (Carlos Maiolino) [1859160]
- [fs] xfs: switch to use the new mount-api (Carlos Maiolino) [1859160]
- [fs] xfs: dont set sb in xfs_mount_alloc() (Carlos Maiolino) [1859160]
- [fs] xfs: move xfs_parseargs() validation to a helper (Carlos Maiolino) [1859160]
- [fs] xfs: refactor xfs_parseags() (Carlos Maiolino) [1859160]
- [fs] xfs: avoid redundant checks when options is empty (Carlos Maiolino) [1859160]
- [fs] xfs: refactor suffix_kstrtoint() (Carlos Maiolino) [1859160]
- [fs] xfs: add xfs_remount_ro() helper (Carlos Maiolino) [1859160]
- [fs] xfs: add xfs_remount_rw() helper (Carlos Maiolino) [1859160]
- [fs] xfs: merge freeing of mp names and mp (Carlos Maiolino) [1859160]
- [fs] xfs: use kmem functions for struct xfs_mount (Carlos Maiolino) [1859160]
- [fs] xfs: dont use XFS_IS_QUOTA_RUNNING() for option check (Carlos Maiolino) [1859160]
- [fs] xfs: use super s_id instead of struct xfs_mount m_fsname (Carlos Maiolino) [1859160]
- [fs] xfs: remove unused struct xfs_mount field m_fsname_len (Carlos Maiolino) [1859160]
- [fs] xfs: always log corruption errors (Carlos Maiolino) [1859160]
- [fs] xfs: constify the buffer pointer arguments to error functions (Carlos Maiolino) [1859160]
- [fs] xfs: relax shortform directory size checks (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup use of the XFS_ALLOC_ flags (Carlos Maiolino) [1859160]
- [fs] xfs: move extent zeroing to xfs_bmapi_allocate (Carlos Maiolino) [1859160]
- [fs] xfs: refactor xfs_bmapi_allocate (Carlos Maiolino) [1859160]
- [fs] xfs: simplify the xfs_iomap_write_direct calling (Carlos Maiolino) [1859160]
- [fs] xfs: don't log the inode in xfs_fs_map_blocks if it (Carlos Maiolino) [1859160]
- [fs] xfs: slightly tweak an assert in xfs_fs_map_blocks (Carlos Maiolino) [1859160]
- [fs] xfs: remove the extsize argument to xfs_eof_alignment (Carlos Maiolino) [1859160]
- [fs] xfs: mark xfs_eof_alignment static (Carlos Maiolino) [1859160]
- [fs] xfs: simplify xfs_iomap_eof_align_last_fsb (Carlos Maiolino) [1859160]
- [fs] xfs: merge xfs_showargs into xfs_fs_show_options (Carlos Maiolino) [1859160]
- [fs] xfs: clean up printing inode32/64 in xfs_showargs (Carlos Maiolino) [1859160]
- [fs] xfs: clean up printing the allocsize option in (Carlos Maiolino) [1859160]
- [fs] xfs: reverse the polarity of XFS_MOUNT_COMPAT_IOSIZE (Carlos Maiolino) [1859160]
- [fs] xfs: rename the XFS_MOUNT_DFLT_IOSIZE option to (Carlos Maiolino) [1859160]
- [fs] xfs: simplify parsing of allocsize mount option (Carlos Maiolino) [1859160]
- [fs] xfs: rename the m_writeio_* fields in struct xfs_mount (Carlos Maiolino) [1859160]
- [fs] xfs: remove the m_readio_* fields in struct xfs_mount (Carlos Maiolino) [1859160]
- [fs] xfs: don't use a different allocsice for -o wsync (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup calculating the stat optimal I/O size (Carlos Maiolino) [1859160]
- [fs] xfs: remove the dsunit and dswidth variables in (Carlos Maiolino) [1859160]
- [fs] xfs: simplify setting bio flags (Carlos Maiolino) [1859160]
- [fs] xfs: refactor xfs_iread_extents to use xfs_btree_visit_blocks (Carlos Maiolino) [1859160]
- [fs] xfs: refactor xfs_bmap_count_blocks using newer btree helpers (Carlos Maiolino) [1859160]
- [fs] xfs: replace -EIO with -EFSCORRUPTED for corrupt metadata (Carlos Maiolino) [1859160]
- [fs] xfs: namecheck directory entry names before listing them (Carlos Maiolino) [1859160]
- [fs] xfs: namecheck attribute names before listing them (Carlos Maiolino) [1859160]
- [fs] xfs: check attribute leaf block structure (Carlos Maiolino) [1859160]
- [fs] xfs: consolidate preallocation in xfs_file_fallocate (Carlos Maiolino) [1859160]
- [fs] xfs: disable xfs_ioc_space for always COW inodes (Carlos Maiolino) [1859160]
- [fs] fs: add generic UNRESVSP and ZERO_RANGE ioctl handlers (Carlos Maiolino) [1859160]
- [fs] xfs: don't implement XFS_IOC_RESVSP / XFS_IOC_RESVSP64 (Carlos Maiolino) [1859160]
- [fs] xfs: use xfs_inode_buftarg in xfs_file_ioctl (Carlos Maiolino) [1859160]
- [fs] xfs: use xfs_inode_buftarg in xfs_file_dio_aio_write (Carlos Maiolino) [1859160]
- [fs] xfs: add a xfs_inode_buftarg helper (Carlos Maiolino) [1859160]
- [fs] xfs: mark xfs_buf_free static (Carlos Maiolino) [1859160]
- [fs] xfs: add mising include of xfs_pnfs.h for missing declarations (Carlos Maiolino) [1859160]
- [fs] xfs: don't set bmapi total block req where minleft is (Carlos Maiolino) [1859160]
- [fs] xfs: cap longest free extent to maximum allocatable (Carlos Maiolino) [1859160]
- [fs] xfs: remove the duplicated inode log fieldmask set (Carlos Maiolino) [1859160]
- [fs] xfs: improve the IOMAP_NOWAIT check for COW inodes (Carlos Maiolino) [1859160]
- [fs] xfs: cleanup xfs_direct_write_iomap_begin (Carlos Maiolino) [1859160]
- [fs] xfs: rename the whichfork variable in xfs_buffered_write_iomap_begin (Carlos Maiolino) [1859160]
- [fs] xfs: split the iomap ops for buffered vs direct writes (Carlos Maiolino) [1859160]
- [fs] xfs: move xfs_file_iomap_begin_delay around (Carlos Maiolino) [1859160]
- [fs] xfs: split out a new set of read-only iomap ops (Carlos Maiolino) [1859160]
- [fs] xfs: factor out a helper to calculate the end_fsb (Carlos Maiolino) [1859160]
- [fs] xfs: fill out the srcmap in iomap_begin (Carlos Maiolino) [1859160]
- [fs] xfs: refactor xfs_file_iomap_begin_delay (Carlos Maiolino) [1859160]
- [fs] xfs: pass two imaps to xfs_reflink_allocate_cow (Carlos Maiolino) [1859160]
- [fs] xfs: remove xfs_reflink_dirty_extents (Carlos Maiolino) [1859160]
- [fs] xfs: also call xfs_file_iomap_end_delalloc for zeroing operations (Carlos Maiolino) [1859160]
- [fs] xfs: remove the XLOG_STATE_DO_CALLBACK state (Carlos Maiolino) [1859160]
- [fs] xfs: turn ic_state into an enum (Carlos Maiolino) [1859160]
- [fs] xfs: remove the unused XLOG_STATE_ALL and XLOG_STATE_UNUSED flags (Carlos Maiolino) [1859160]
- [fs] xfs: remove dead ifdef XFSERRORDEBUG code (Carlos Maiolino) [1859160]
- [fs] xfs: call xlog_state_release_iclog with l_icloglock held (Carlos Maiolino) [1859160]
- [fs] xfs: move the locking from xlog_state_finish_copy to the callers (Carlos Maiolino) [1859160]
- [fs] xfs: remove the unused ic_io_size field from xlog_in_core (Carlos Maiolino) [1859160]
- [fs] xfs: pass the correct flag to xlog_write_iclog (Carlos Maiolino) [1859160]
- [fs] xfs: optimize near mode bnobt scans with concurrent cntbt lookups (Carlos Maiolino) [1859160]
- [fs] xfs: factor out tree fixup logic into helper (Carlos Maiolino) [1859160]
- [fs] xfs: refactor near mode alloc bnobt scan into separate function (Carlos Maiolino) [1859160]
- [fs] xfs: refactor and reuse best extent scanning logic (Carlos Maiolino) [1859160]
- [fs] xfs: refactor allocation tree fixup code (Carlos Maiolino) [1859160]
- [fs] xfs: reuse best extent tracking logic for bnobt scan (Carlos Maiolino) [1859160]
- [fs] xfs: refactor cntbt lastblock scan best extent logic into helper (Carlos Maiolino) [1859160]
- [fs] xfs: track best extent from cntbt lastblock scan in alloc cursor (Carlos Maiolino) [1859160]
- [fs] xfs: track allocation busy state in allocation cursor (Carlos Maiolino) [1859160]
- [fs] xfs: introduce allocation cursor data structure (Carlos Maiolino) [1859160]
- [fs] xfs: track active state of allocation btree cursors (Carlos Maiolino) [1859160]
- [fs] xfs: ignore extent size hints for always COW inodes (Carlos Maiolino) [1859160]
- [fs] xfs: include QUOTA, FATAL ASSERT build options in XFS_BUILD_OPTIONS (Carlos Maiolino) [1859160]
- [pinctrl] pinctrl: tigerlake: Add support for Tiger Lake-H (Steve Best) [1782722]
- [pinctrl] pinctrl: intel: Introduce common flags for GPIO mapping scheme (Steve Best) [1782722]
- [mfd] mfd: intel-lpss: Add Intel Tiger Lake PCH-H PCI IDs (Steve Best) [1782724]

* Fri Oct 30 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.10.el8]
- [netdrv] iavf: Fix incorrect adapter get in iavf_resume (Stefan Assmann) [1842896]
- [netdrv] iavf: use generic power management (Stefan Assmann) [1842896]
- [net] openvswitch: fixes crash if nf_conncount_init() fails (Eelco Chaudron) [1876445]
- [fs] cifs`: handle ERRBaduid for SMB1 (Leif Sahlberg) [1875184]
- [net] SUNRPC: 'Directory with parent 'rpc_clnt' already present!' (Scott Mayhew) [1872310]
- [fs] NFS/pnfs: Don't use RPC_TASK_CRED_NOREF with pnfs (Scott Mayhew) [1872310]
- [fs] NFS: Don't use RPC_TASK_CRED_NOREF with delegreturn (Scott Mayhew) [1872310]
- [net] SUNRPC: Signalled ASYNC tasks need to exit (Scott Mayhew) [1872310]
- [net] SUNRPC: fix use-after-free in rpc_free_client_work() (Scott Mayhew) [1872310]
- [fs] NFS: Fix a race in __nfs_list_for_each_server() (Scott Mayhew) [1872310]
- [net] SUNRPC: defer slow parts of rpc_free_client() to a workqueue (Scott Mayhew) [1872310]
- [net] SUNRPC: Revert 241b1f419f0e ("SUNRPC: Remove xdr_buf_trim()") (Scott Mayhew) [1872310]
- [fs] NFSv4: Remove unreachable error condition due to rpc_run_task() (Scott Mayhew) [1872310]
- [net] SUNRPC: Remove unreachable error condition (Scott Mayhew) [1872310]
- [fs] nfs: Fix potential posix_acl refcnt leak in nfs3_set_acl (Scott Mayhew) [1872310]
- [fs] NFS/pnfs: Fix a credential use-after-free issue in pnfs_roc() (Scott Mayhew) [1872310]
- [fs] NFS/pnfs: Ensure that _pnfs_return_layout() waits for layoutreturn completion (Scott Mayhew) [1872310]
- [net] svcrdma: Fix leak of svc_rdma_recv_ctxt objects (Scott Mayhew) [1872310]
- [fs] NFS: Fix an ABBA spinlock issue in pnfs_update_layout() (Scott Mayhew) [1872310]
- [net] SUNRPC/cache: Fix unsafe traverse caused double-free in cache_purge (Scott Mayhew) [1872310]
- [fs] nfsd: memory corruption in nfsd4_lock() (Scott Mayhew) [1872310]
- [fs] pNFS: Fix RCU lock leakage (Scott Mayhew) [1872310]
- [fs] NFS: Clean up process of marking inode stale (Scott Mayhew) [1872310]
- [fs] NFS: Add softreval behaviour to nfs_lookup_revalidate() (Scott Mayhew) [1872310]
- [fs] NFS: Add mount option 'softreval' (Scott Mayhew) [1872310]
- [net] SUNRPC: Don't start a timer on an already queued rpc task (Scott Mayhew) [1872310]
- [fs] NFS/pnfs: Reference the layout cred in pnfs_prepare_layoutreturn() (Scott Mayhew) [1872310]
- [fs] NFS/pnfs: Fix dereference of layout cred in pnfs_layoutcommit_inode() (Scott Mayhew) [1872310]
- [fs] NFS: Beware when dereferencing the delegation cred (Scott Mayhew) [1872310]
- [fs] NFS: Add a module parameter to set nfs_mountpoint_expiry_timeout (Scott Mayhew) [1872310]
- [fs] NFS: Try to join page groups before an O_DIRECT retransmission (Scott Mayhew) [1872310]
- [fs] NFS: Refactor nfs_lock_and_join_requests() (Scott Mayhew) [1872310]
- [fs] NFS: Reverse the submission order of requests in __nfs_pageio_add_request() (Scott Mayhew) [1872310]
- [fs] NFS: Clean up nfs_lock_and_join_requests() (Scott Mayhew) [1872310]
- [fs] NFS: Remove the redundant function nfs_pgio_has_mirroring() (Scott Mayhew) [1872310]
- [fs] NFS: Fix memory leaks in nfs_pageio_stop_mirroring() (Scott Mayhew) [1872310]
- [fs] NFS: Fix a request reference leak in nfs_direct_write_clear_reqs() (Scott Mayhew) [1872310]
- [fs] NFS: Fix races nfs_page_group_destroy() vs nfs_destroy_unlinked_subrequests() (Scott Mayhew) [1872310]
- [fs] NFS: Remove unused FLUSH_SYNC support in nfs_initiate_pgio() (Scott Mayhew) [1872310]
- [fs] pNFS/flexfiles: Specify the layout segment range in LAYOUTGET (Scott Mayhew) [1872310]
- [fs] pNFS/flexfiles: remove requirement for whole file layouts (Scott Mayhew) [1872310]
- [fs] pNFS/flexfiles: Check the layout segment range before doing I/O (Scott Mayhew) [1872310]
- [fs] pNFS/flexfile: Don't merge layout segments if the mirrors don't match (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Fix pnfs_layout_mark_request_commit() invalid layout segment handling (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Simplify bucket layout segment reference counting (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Clean up pNFS commit operations (Scott Mayhew) [1872310]
- [fs] NFS: Remove bucket array from struct pnfs_ds_commit_info (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Add a helper pnfs_generic_search_commit_reqs() (Scott Mayhew) [1872310]
- [fs] pNFS: Enable per-layout segment commit structures (Scott Mayhew) [1872310]
- [fs] pNFS: Add infrastructure for cleaning up per-layout commit structures (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Support commit arrays in nfs_clear_pnfs_ds_commit_verifiers() (Scott Mayhew) [1872310]
- [fs] NFS: Fix O_DIRECT commit verifier handling (Scott Mayhew) [1872310]
- [fs] NFS: commit errors should be fatal (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Allow O_DIRECT to release the DS commitinfo (Scott Mayhew) [1872310]
- [fs] pNFS: Support per-layout segment commits in pnfs_generic_commit_pagelist() (Scott Mayhew) [1872310]
- [fs] pNFS: Support per-layout segment commits in pnfs_generic_recover_commit_reqs() (Scott Mayhew) [1872310]
- [fs] NFSv4/pNFS: Scan the full list of commit arrays when committing (Scott Mayhew) [1872310]
- [fs] NFSv4/pnfs: Support a list of commit arrays in struct pnfs_ds_commit_info (Scott Mayhew) [1872310]
- [net] SUNRPC: Fix a potential buffer overflow in 'svc_print_xprts()' (Scott Mayhew) [1872310]
- [include] SUNRPC/cache: don't allow invalid entries to be flushed (Scott Mayhew) [1872310]
- [fs] pNFS: Add a helper to allocate the array of buckets (Scott Mayhew) [1872310]
- [fs] NFS/pNFS: Refactor pnfs_generic_commit_pagelist() (Scott Mayhew) [1872310]
- [fs] pNFS/flexfiles: Simplify allocation of the mirror array (Scott Mayhew) [1872310]
- [fs] NFS: Don't specify NFS version in "UDP not supported" error (Scott Mayhew) [1872310]
- [fs] nfsroot: set tcp as the default transport protocol (Scott Mayhew) [1872310]
- [fs] NFS: direct.c: Fix memory leak of dreq when nfs_get_lock_context fails (Scott Mayhew) [1872310]
- [fs] nfs: Fix up documentation in nfs_follow_referral() and nfs_do_submount() (Scott Mayhew) [1872310]
- [net] sunrpc: Add tracing for cache events (Scott Mayhew) [1872310]
- [net] SUNRPC/cache: Allow garbage collection of invalid cache entries (Scott Mayhew) [1872310]
- [net] sunrpc: clean up cache entry add/remove from hashtable (Scott Mayhew) [1872310]
- [net] sunrpc: Fix potential leaks in sunrpc_cache_unhash() (Scott Mayhew) [1872310]
- [fs] nfsd: export upcalls must not return ESTALE when mountd is down (Scott Mayhew) [1872310]
- [fs] nfsd: Don't add locks to closed or closing open stateids (Scott Mayhew) [1872310]
- [net] SUNRPC: Teach server to use xprt_sock_sendmsg for socket sends (Scott Mayhew) [1872310]
- [net] SUNRPC: Refactor xs_sendpages() (Scott Mayhew) [1872310]
- [fs] NFSD: Clean up nfsd4_encode_readv (Scott Mayhew) [1872310]
- [fs] fs: nfsd: nfs4state.c: Use built-in RCU list checking (Scott Mayhew) [1872310]
- [net] sunrpc: Pass lockdep expression to RCU lists (Scott Mayhew) [1872310]
- [include] sunrpc: Replace zero-length array with flexible-array member (Scott Mayhew) [1872310]
- [net] SUNRPC: Trim stack utilization in the wrap and unwrap paths (Scott Mayhew) [1872310]
- [net] SUNRPC: Remove xdr_buf_read_mic() (Scott Mayhew) [1872310]
- [net] sunrpc: Fix gss_unwrap_resp_integ() again (Scott Mayhew) [1872310]
- [fs] nfs: Replace zero-length array with flexible-array member (Scott Mayhew) [1872310]
- [fs] NFSv4.2: error out when relink swapfile (Scott Mayhew) [1872310]
- [fs] NFS:remove redundant call to nfs_do_access (Scott Mayhew) [1872310]
- [net] SUNRPC: remove redundant assignments to variable status (Scott Mayhew) [1872310]
- [fs] NFSv4: Add support for CB_RECALL_ANY for flexfiles layouts (Scott Mayhew) [1872310]
- [fs] NFSv4: Clean up nfs_delegation_reap_expired() (Scott Mayhew) [1872310]
- [fs] NFSv4: Clean up nfs_delegation_reap_unclaimed() (Scott Mayhew) [1872310]
- [fs] NFSv4: Clean up nfs_client_return_marked_delegations() (Scott Mayhew) [1872310]
- [fs] NFS: Add a helper nfs_client_for_each_server() (Scott Mayhew) [1872310]
- [fs] NFSv4/pnfs: Clean up nfs_layout_find_inode() (Scott Mayhew) [1872310]
- [fs] NFSv4: Ensure layout headers are RCU safe (Scott Mayhew) [1872310]
- [fs] NFSv4/pnfs: Return valid stateids in nfs_layout_find_inode_by_stateid() (Scott Mayhew) [1872310]
- [fs] pNFS/flexfiles: Report DELAY and GRACE errors from the DS to the server (Scott Mayhew) [1872310]
- [fs] NFS: Limit the size of the access cache by default (Scott Mayhew) [1872310]
- [fs] NFS: Avoid referencing the cred twice in async rename/unlink (Scott Mayhew) [1872310]
- [fs] NFSv4: Avoid unnecessary credential references in layoutget (Scott Mayhew) [1872310]
- [fs] NFSv4: Avoid referencing the cred unnecessarily during NFSv4 I/O (Scott Mayhew) [1872310]
- [fs] NFS: Assume cred is pinned by open context in I/O requests (Scott Mayhew) [1872310]
- [net] SUNRPC: Don't take a reference to the cred on synchronous tasks (Scott Mayhew) [1872310]
- [net] SUNRPC: Add a flag to avoid reference counts on credentials (Scott Mayhew) [1872310]
- [fs] NFS: Ensure we time out if a delegreturn does not complete (Scott Mayhew) [1872310]
- [fs] NFSv4/pnfs: pnfs_set_layout_stateid() should update the layout cred (Scott Mayhew) [1872310]
- [fs] NFSv4: nfs_update_inplace_delegation() should update delegation cred (Scott Mayhew) [1872310]
- [fs] NFS: Use the 64-bit server readdir cookies when possible (Scott Mayhew) [1872310]
- [net] Documentation: nfsroot.rst: Fix references to nfsroot.rst (Scott Mayhew) [1872310]
- [fs] nfs: add missing "posix" local_lock constant table definition (Scott Mayhew) [1622041]
- [samples] samples/vfs: avoid warning in statx override (Scott Mayhew) [1622041]
- [fs] Fix use after free in get_tree_bdev() (Scott Mayhew) [1622041]
- [security] selinux: fix regression introduced by move_mount(2) syscall (Scott Mayhew) [1622041]
- [fs] mm/hugetlbfs: fix for_each_hstate() loop in init_hugetlbfs_fs() (Scott Mayhew) [1622041]
- [fs] mm/hugetlbfs: fix error handling when setting up mounts (Scott Mayhew) [1622041]
- [fs] cramfs: fix usage on non-MTD device (Scott Mayhew) [1622041]
- [fs] vfs: move_mount: reject moving kernel internal mounts (Scott Mayhew) [1622041]
- [fs] do_move_mount(): fix an unsafe use of is_anon_ns() (Scott Mayhew) [1622041]
- [fs] fs/namespace: fix unprivileged mount propagation (Scott Mayhew) [1622041]
- [fs] vfs: fsmount: add missing mntget() (Scott Mayhew) [1622041]
- [fs] get rid of checking for absent device name in vfs_get_tree() (Scott Mayhew) [1622041]
- [scripts] scripts/gdb: replace flags (MS_xyz -> SB_xyz) (Scott Mayhew) [1622041]
- [mm] tmpfs: switch to use of invalfc() (Scott Mayhew) [1622041]
- [kernel] cgroup1: switch to use of errorfc() et.al (Scott Mayhew) [1622041]
- [fs] procfs: switch to use of invalfc() (Scott Mayhew) [1622041]
- [fs] hugetlbfs: switch to use of invalfc() (Scott Mayhew) [1622041]
- [fs] cramfs: switch to use of errofc() et.al (Scott Mayhew) [1622041]
- [fs] gfs2: switch to use of errorfc() et.al (Scott Mayhew) [1622041]
- [include] prefix-handling analogues of errorf() and friends (Scott Mayhew) [1622041]
- [fs] turn fs_param_is_... into functions (Scott Mayhew) [1622041]
- [fs] fs_parse: handle optional arguments sanely (Scott Mayhew) [1622041]
- [fs] fs_parse: fold fs_parameter_desc/fs_parameter_spec (Scott Mayhew) [1622041]
- [x86] x86/resctrl: Fix typos in the mba_sc mount option (Scott Mayhew) [1622041]
- [fs] fs_parser: remove fs_parameter_description name field (Scott Mayhew) [1622041]
- [documentation] vfs: Update mount API docs (Scott Mayhew) [1622041]
- [fs] add prefix to fs_context->log (Scott Mayhew) [1622041]
- [include] new primitive: __fs_parse() (Scott Mayhew) [1622041]
- [include] struct p_log, variants of warnf() et.al. taking that one instead (Scott Mayhew) [1622041]
- [fs] teach logfc() to handle prefices, give it saner calling conventions (Scott Mayhew) [1622041]
- [kernel] get rid of cg_invalf() (Scott Mayhew) [1622041]
- [fs] get rid of fs_value_is_filename_empty (Scott Mayhew) [1622041]
- [fs] don't bother with explicit length argument for __lookup_constant() (Scott Mayhew) [1622041]
- [fs] fold struct fs_parameter_enum into struct constant_table (Scott Mayhew) [1622041]
- [fs] fs_parse: get rid of ->enums (Scott Mayhew) [1622041]
- [fs] fs: fs_parser: fix printk format warning (Scott Mayhew) [1622041]
- [fs] Pass consistent param->type to fs_parse() (Scott Mayhew) [1622041]
- [fs] vfs: add missing blkdev_put() in get_tree_bdev() (Scott Mayhew) [1622041]
- [mm] shmem: fix LSM options parsing (Scott Mayhew) [1622041]
- [fs] gfs2: make gfs2_fs_parameters static (Scott Mayhew) [1622041]
- [fs] gfs2: Fix initialisation of args for remount (Scott Mayhew) [1622041]
- [fs] gfs2: Fix memory leak when gfs2meta's fs_context is freed (Scott Mayhew) [1622041]
- [fs] gfs2: Convert gfs2 to fs_context (Scott Mayhew) [1622041]
- [fs] NFS: Fix fscache super_cookie allocation (Scott Mayhew) [1622041]
- [fs] NFS: Fix a few constant_table array definitions (Scott Mayhew) [1622041]
- [fs] NFS: Fix leak of ctx->nfs_server.hostname (Scott Mayhew) [1622041]
- [fs] NFS: Don't hard-code the fs_type when submounting (Scott Mayhew) [1622041]
- [fs] NFS: Ensure the fs_context has the correct fs_type before mounting (Scott Mayhew) [1622041]
- [fs] nfs: Return EINVAL rather than ERANGE for mount parse errors (Scott Mayhew) [1622041]
- [fs] NFS: Attach supplementary error information to fs_context (Scott Mayhew) [1622041]
- [fs] NFS: Additional refactoring for fs_context conversion (Scott Mayhew) [1622041]
- [fs] NFS: Add fs_context support (Scott Mayhew) [1622041]
- [fs] NFS: Convert mount option parsing to use functionality from fs_parser.h (Scott Mayhew) [1622041]
- [fs] NFS: rename nfs_fs_context pointer arg in a few functions (Scott Mayhew) [1622041]
- [fs] NFS: Do some tidying of the parsing code (Scott Mayhew) [1622041]
- [fs] NFS: Add a small buffer in nfs_fs_context to avoid string dup (Scott Mayhew) [1622041]
- [fs] NFS: Deindent nfs_fs_context_parse_option() (Scott Mayhew) [1622041]
- [fs] NFS: Split nfs_parse_mount_options() (Scott Mayhew) [1622041]
- [fs] NFS: Rename struct nfs_parsed_mount_data to struct nfs_fs_context (Scott Mayhew) [1622041]
- [fs] NFS: Constify mount argument match tables (Scott Mayhew) [1622041]
- [fs] NFS: Move mount parameterisation bits into their own file (Scott Mayhew) [1622041]
- [fs] nfs: get rid of ->set_security() (Scott Mayhew) [1622041]
- [fs] nfs_clone_sb_security(): simplify the check for server bogosity (Scott Mayhew) [1622041]
- [fs] nfs: get rid of mount_info ->fill_super() (Scott Mayhew) [1622041]
- [fs] nfs: don't pass nfs_subversion to ->create_server() (Scott Mayhew) [1622041]
- [fs] nfs: unexport nfs_fs_mount_common() (Scott Mayhew) [1622041]
- [fs] nfs: merge xdev and remote file_system_type (Scott Mayhew) [1622041]
- [fs] nfs: don't bother passing nfs_subversion to ->try_mount() and nfs_fs_mount_common() (Scott Mayhew) [1622041]
- [fs] nfs: stash nfs_subversion reference into nfs_mount_info (Scott Mayhew) [1622041]
- [fs] nfs: lift setting mount_info from nfs_xdev_mount() (Scott Mayhew) [1622041]
- [fs] nfs4: fold nfs_do_root_mount/nfs_follow_remote_path (Scott Mayhew) [1622041]
- [fs] nfs: don't bother setting/restoring export_path around do_nfs_root_mount() (Scott Mayhew) [1622041]
- [fs] nfs: fold nfs4_remote_fs_type and nfs4_remote_referral_fs_type (Scott Mayhew) [1622041]
- [fs] nfs: lift setting mount_info from nfs4_remote{, _referral}_mount (Scott Mayhew) [1622041]
- [fs] nfs: stash server into struct nfs_mount_info (Scott Mayhew) [1622041]
- [fs] saner calling conventions for nfs_fs_mount_common() (Scott Mayhew) [1622041]
- [fs] NFS: Make "port=" mount option optional for RDMA mounts (Scott Mayhew) [1622041]
- [fs] vfs: Make fs_parse() handle fs_param_is_fd-type params better (Scott Mayhew) [1622041]
- [include] vfs: Convert ramfs, shmem, tmpfs, devtmpfs, rootfs to use the new mount API (Scott Mayhew) [1622041]
- [mm] shmem_parse_one(): switch to use of fs_parse() (Scott Mayhew) [1622041]
- [mm] shmem_parse_options(): take handling a single option into a helper (Scott Mayhew) [1622041]
- [mm] shmem_parse_options(): don't bother with mpol in separate variable (Scott Mayhew) [1622041]
- [mm] shmem_parse_options(): use a separate structure to keep the results (Scott Mayhew) [1622041]
- [base] make shmem_fill_super() static (Scott Mayhew) [1622041]
- [fs] make ramfs_fill_super() static (Scott Mayhew) [1622041]
- [base] devtmpfs: don't mix {ramfs, shmem}_fill_super() with mount_single() (Scott Mayhew) [1622041]
- [fs] vfs: Convert squashfs to use the new mount API (Scott Mayhew) [1622041]
- [mtd] mtd: Kill mount_mtd() (Scott Mayhew) [1622041]
- [fs] vfs: Convert cramfs to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Add a single-or-reconfig keying to vfs_get_super() (Scott Mayhew) [1622041]
- [mtd] mtd: Provide fs_context-aware mount_mtd() replacement (Scott Mayhew) [1622041]
- [fs] vfs: Create fs_context-aware mount_bdev() replacement (Scott Mayhew) [1622041]
- [fs] new helper: get_tree_keyed() (Scott Mayhew) [1622041]
- [fs] vfs: set fs_context::user_ns for reconfigure (Scott Mayhew) [1622041]
- [init] mnt_init(): call shmem_init() unconditionally (Scott Mayhew) [1622041]
- [base] constify ksys_mount() string arguments (Scott Mayhew) [1622041]
- [fs] don't bother with registering rootfs (Scott Mayhew) [1622041]
- [fs] init_rootfs(): don't bother with init_ramfs_fs() (Scott Mayhew) [1622041]
- [security] vfs: Convert selinuxfs to use the new mount API (Scott Mayhew) [1622041]
- [security] vfs: Convert securityfs to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert openpromfs to use the new mount API (Scott Mayhew) [1622041]
- [xen] vfs: Convert xenfs to use the new mount API (Scott Mayhew) [1622041]
- [oprofile] vfs: Convert oprofilefs to use the new mount API (Scott Mayhew) [1622041]
- [misc] vfs: Convert ibmasmfs to use the new mount API (Scott Mayhew) [1622041]
- [infiniband] vfs: Convert qib_fs/ipathfs to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert efivarfs to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert configfs to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert binfmt_misc to use the new mount API (Scott Mayhew) [1622041]
- [fs] convenience helper: get_tree_single() (Scott Mayhew) [1622041]
- [fs] convenience helper get_tree_nodev() (Scott Mayhew) [1622041]
- [fs] vfs: Kill sget_userns() (Scott Mayhew) [1622041]
- [fs] vfs: Use sget_fc() for pseudo-filesystems (Scott Mayhew) [1622041]
- [dma-buf] fold mount_pseudo_xattr() into pseudo_fs_get_tree() (Scott Mayhew) [1622041]
- [virtio] vfs: Convert virtio_balloon to use the new mount API (Scott Mayhew) [1622041]
- [scsi] vfs: Convert ocxlflash to use the new mount API (Scott Mayhew) [1622041]
- [misc] vfs: Convert cxl to use the new mount API (Scott Mayhew) [1622041]
- [drm] vfs: Convert drm to use the new mount API (Scott Mayhew) [1622041]
- [dax] vfs: Convert dax to use the new mount API (Scott Mayhew) [1622041]
- [net] vfs: Convert sockfs to use the new mount API (Scott Mayhew) [1622041]
- [mm] vfs: Convert zsmalloc to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert pipe to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert nsfs to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert bdev to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert anon_inodes to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Convert aio to use the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Provide a mount_pseudo-replacement for the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Provide sb->s_iflags settings in fs_context struct (Scott Mayhew) [1622041]
- [fs] vfs: Fix refcounting of filenames in fs_parser (Scott Mayhew) [1622041]
- [fs] move mount_capable() further out (Scott Mayhew) [1622041]
- [fs] move mount_capable() calls to vfs_get_tree() (Scott Mayhew) [1622041]
- [kernel] cpuset: move mount -t cpuset logics into cgroup.c (Scott Mayhew) [1622041]
- [fs] procfs: set ->user_ns before calling ->get_tree() (Scott Mayhew) [1622041]
- [ipc] mqueue: set ->user_ns before ->get_tree() (Scott Mayhew) [1622041]
- [fs] switch mount_capable() to fs_context (Scott Mayhew) [1622041]
- [fs] legacy_get_tree(): pass fc->user_ns to mount_capable() (Scott Mayhew) [1622041]
- [fs] move the capability checks from sget_userns() to legacy_get_tree() (Scott Mayhew) [1622041]
- [fs] vfs: Kill mount_ns() (Scott Mayhew) [1622041]
- [fs] vfs: Convert nfsctl to use the new mount API (Scott Mayhew) [1622041]
- [net] vfs: Convert rpc_pipefs to use the new mount API (Scott Mayhew) [1622041]
- [fs] consolidate the capability checks in sget_{fc, userns}() (Scott Mayhew) [1622041]
- [fs] start massaging the checks in sget_...(): move to sget_userns() (Scott Mayhew) [1622041]
- [x86] no need to protect against put_user_ns(NULL) (Scott Mayhew) [1622041]
- [fs] mount_pseudo(): drop 'name' argument, switch to d_make_root() (Scott Mayhew) [1622041]
- [mm] zsmalloc: don't bother with dentry_operations (Scott Mayhew) [1622041]
- [virtio] balloon: don't bother with dentry_operations (Scott Mayhew) [1622041]
- [scsi] cxlflash: don't bother with dentry_operations (Scott Mayhew) [1622041]
- [misc] cxl: don't bother with dentry_operations (Scott Mayhew) [1622041]
- [fs] fs: VALIDATE_FS_PARSER should default to n (Scott Mayhew) [1622041]
- [security] selinux: fix a missing-check bug in selinux_sb_eat_lsm_opts() (Scott Mayhew) [1622041]
- [security] selinux: fix a missing-check bug in selinux_add_mnt_opt( ) (Scott Mayhew) [1622041]
- [powerpc] uapi: Wire up the mount API syscalls on non-x86 arches (Scott Mayhew) [1622041]
- [x86] uapi, x86: Fix the syscall numbering of the mount API syscalls (Scott Mayhew) [1622041]
- [fs] uapi, fsopen: use square brackets around "fscontext" (Scott Mayhew) [1622041]
- [samples] vfs: Add a sample program for the new mount API (Scott Mayhew) [1622041]
- [x86] vfs: syscall: Add fspick() to select a superblock for reconfiguration (Scott Mayhew) [1622041]
- [x86] vfs: syscall: Add fsmount() to create a mount for a superblock (Scott Mayhew) [1622041]
- [fs] vfs: syscall: Add fsconfig() for configuring and managing a context (Scott Mayhew) [1622041]
- [fs] vfs: Implement logging through fs_context (Scott Mayhew) [1622041]
- [fs] vfs: syscall: Add fsopen() to prepare for superblock creation (Scott Mayhew) [1622041]
- [fs] Make anon_inodes unconditional (Scott Mayhew) [1622041]
- [fs] teach move_mount(2) to work with OPEN_TREE_CLONE (Scott Mayhew) [1622041]
- [x86] vfs: syscall: Add move_mount(2) to move mounts around (Scott Mayhew) [1622041]
- [fs] vfs: syscall: Add open_tree(2) to reference or clone a mount (Scott Mayhew) [1622041]
- [fs] fix sysfs_init_fs_context() in !CONFIG_NET_NS case (Scott Mayhew) [1622041]
- [fs] vfs: Add some logging to the core users of the fs_context log (Scott Mayhew) [1622041]
- [fs] vfs: Implement logging through fs_context (Scott Mayhew) [1622041]
- [documentation] vfs: Provide documentation for new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Remove kern_mount_data() (Scott Mayhew) [1622041]
- [fs] hugetlbfs: Convert to fs_context (Scott Mayhew) [1622041]
- [kernel] cpuset: Use fs_context (Scott Mayhew) [1622041]
- [fs] kernfs, sysfs, cgroup, intel_rdt: Support fs_context (Scott Mayhew) [1622041]
- [kernel] cgroup: store a reference to cgroup_ns into cgroup_fs_context (Scott Mayhew) [1622041]
- [kernel] cgroup1_get_tree(): separate "get cgroup_root to use" into a separate helper (Scott Mayhew) [1622041]
- [kernel] cgroup_do_mount(): massage calling conventions (Scott Mayhew) [1622041]
- [kernel] cgroup: stash cgroup_root reference into cgroup_fs_context (Scott Mayhew) [1622041]
- [kernel] cgroup2: switch to option-by-option parsing (Scott Mayhew) [1622041]
- [kernel] cgroup1: switch to option-by-option parsing (Scott Mayhew) [1622041]
- [kernel] cgroup: take options parsing into ->parse_monolithic() (Scott Mayhew) [1622041]
- [kernel] cgroup: fold cgroup1_mount() into cgroup1_get_tree() (Scott Mayhew) [1622041]
- [kernel] cgroup: start switching to fs_context (Scott Mayhew) [1622041]
- [ipc] ipc: Convert mqueue fs to fs_context (Scott Mayhew) [1622041]
- [fs] proc: Add fs_context support to procfs (Scott Mayhew) [1622041]
- [fs] procfs: Move proc_fill_super() to fs/proc/root.c (Scott Mayhew) [1622041]
- [include] introduce cloning of fs_context (Scott Mayhew) [1622041]
- [fs] convenience helpers: vfs_get_super() and sget_fc() (Scott Mayhew) [1622041]
- [fs] vfs: Implement a filesystem superblock creation/configuration context (Scott Mayhew) [1622041]
- [include] vfs: Put security flags into the fs_context struct (Scott Mayhew) [1622041]
- [security] selinux: Implement the new mount API LSM hooks (Scott Mayhew) [1622041]
- [include] vfs: Add LSM hooks for the new mount API (Scott Mayhew) [1622041]
- [fs] vfs: Add configuration parser helpers (Scott Mayhew) [1622041]
- [include] vfs: Introduce logging functions (Scott Mayhew) [1622041]
- [fs] introduce fs_context methods (Scott Mayhew) [1622041]
- [fs] fs_context flavour for submounts (Scott Mayhew) [1622041]
- [fs] convert do_remount_sb() to fs_context (Scott Mayhew) [1622041]
- [fs] vfs_get_tree(): evict the call of security_sb_kern_mount() (Scott Mayhew) [1622041]
- [fs] new helper: do_new_mount_fc() (Scott Mayhew) [1622041]
- [fs] teach vfs_get_tree() to handle subtype, switch do_new_mount() to it (Scott Mayhew) [1622041]
- [fs] new helpers: vfs_create_mount(), fc_mount() (Scott Mayhew) [1622041]
- [fs] vfs: Introduce fs_context, switch vfs_kern_mount() to it (Scott Mayhew) [1622041]
- [fs] saner handling of temporary namespaces (Scott Mayhew) [1622041]
- [fs] separate copying and locking mount tree on cross-userns copies (Scott Mayhew) [1622041]
- [fs] kill kernfs_pin_sb() (Scott Mayhew) [1622041]
- [fs] mount_fs: suppress MAC on MS_SUBMOUNT as well as MS_KERNMOUNT (Scott Mayhew) [1622041]
- [security] LSM: new method: ->sb_add_mnt_opt() (Scott Mayhew) [1622041]
- [security] selinux: rewrite selinux_sb_eat_lsm_opts() (Scott Mayhew) [1622041]
- [security] selinux: regularize Opt_... names a bit (Scott Mayhew) [1622041]
- [security] selinux: switch away from match_token() (Scott Mayhew) [1622041]
- [security] selinux: new helper - selinux_add_opt() (Scott Mayhew) [1622041]
- [include] LSM: bury struct security_mnt_opts (Scott Mayhew) [1622041]
- [security] selinux: switch to private struct selinux_mnt_opts (Scott Mayhew) [1622041]
- [fs] LSM: hide struct security_mnt_opts from any generic code (Scott Mayhew) [1622041]
- [security] LSM: turn sb_eat_lsm_opts() into a method (Scott Mayhew) [1622041]
- [fs] nfs_remount(): don't leak, don't ignore LSM options quietly (Scott Mayhew) [1622041]
- [security] LSM: split ->sb_set_mnt_opts() out of ->sb_kern_mount() (Scott Mayhew) [1622041]
- [fs] new helper: security_sb_eat_lsm_opts() (Scott Mayhew) [1622041]
- [security] LSM: lift extracting and parsing LSM options into the caller of ->sb_remount() (Scott Mayhew) [1622041]
- [security] LSM: lift parsing LSM options into the caller of ->sb_kern_mount() (Scott Mayhew) [1622041]
- [fs] vfs: Separate changing mount flags full remount (Scott Mayhew) [1622041]
- [fs] vfs: Suppress MS_* flag defs within the kernel unless explicitly enabled (Scott Mayhew) [1622041]

* Tue Oct 27 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.9.el8]
- [hv] hv_utils: drain the timesync packets on onchannelcallback (Vitaly Kuznetsov) [1884733]
- [hv] hv_utils: return error if host timesysnc update is stale (Vitaly Kuznetsov) [1884733]
- [netdrv] hv_netvsc: Cache the current data path to avoid duplicate call and message (Mohammed Gamal) [1876527]
- [netdrv] hv_netvsc: Switch the data path at the right time during hibernation (Mohammed Gamal) [1876527]
- [netdrv] hv_netvsc: Fix hibernation for mlx5 VF driver (Mohammed Gamal) [1876527]
- [hv] hv: vmbus: hibernation: do not hang forever in vmbus_bus_resume() (Mohammed Gamal) [1876519]
- [target] scsi: target: Fix lun lookup for TARGET_SCF_LOOKUP_LUN_FROM_TAG case (Maurizio Lombardi) [1880395]
- [target] scsi: target: iscsi: Fix hang in iscsit_access_np() when getting tpg->np_login_sem (Maurizio Lombardi) [1880395]
- [target] scsi: target: iscsi: Fix data digest calculation (Maurizio Lombardi) [1880395]
- [target] scsi: target: Make iscsit_register_transport() return void (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Make TMR notification optional (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Implement tmr_notify callback (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Fix and simplify timeout handling (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Factor out new helper ring_insert_padding (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Do not queue aborted commands (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Use priv pointer in se_cmd (Maurizio Lombardi) [1880395]
- [target] scsi: target: Add tmr_notify backend function (Maurizio Lombardi) [1880395]
- [target] scsi: target: Modify core_tmr_abort_task() (Maurizio Lombardi) [1880395]
- [target] scsi: target: iscsi: Fix inconsistent debug message (Maurizio Lombardi) [1880395]
- [target] scsi: target: iscsi: Fix login error when receiving (Maurizio Lombardi) [1880395]
- [target] scsi: target: Remove unused variable 'tpg' (Maurizio Lombardi) [1880395]
- [target] scsi: target: cxgbit: Remove tx flow control code (Maurizio Lombardi) [1880395]
- [target] scsi: target: cxgbit: Check connection state before issuing hardware command (Maurizio Lombardi) [1880395]
- [target] scsi: target: Handle short iSIDs (Maurizio Lombardi) [1880395]
- [target] scsi: target: Fix iscsi transport id buf len calculation (Maurizio Lombardi) [1880395]
- [target] scsi: target: Fix iscsi transport id buffer setup (Maurizio Lombardi) [1880395]
- [target] scsi: target: Fix iscsi transport id parsing (Maurizio Lombardi) [1880395]
- [target] scsi: target: Fix crash during SPEC_I_PT handling (Maurizio Lombardi) [1880395]
- [target] scsi: target: Fix xcopy sess release leak (Maurizio Lombardi) [1880395]
- [target] scsi: target: Check enforce_pr_isids during registration (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Fix crash on ARM during cmd completion (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Fix crash in tcmu_flush_dcache_range on ARM (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Optimize use of flush_dcache_page (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Remove unnecessary bit TCMU_CMD_BIT_INFLIGHT (Maurizio Lombardi) [1880395]
- [target] scsi: target: Rename target_setup_cmd_from_cdb() to target_cmd_parse_cdb() (Maurizio Lombardi) [1880395]
- [target] scsi: target: Fix NULL pointer dereference (Maurizio Lombardi) [1880395]
- [target] scsi: target: Initialize LUN in transport_init_se_cmd() (Maurizio Lombardi) [1880395]
- [target] scsi: target: Factor out a new helper, target_cmd_init_cdb() (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Fix size in calls to tcmu_flush_dcache_range (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Fix a use after free in tcmu_check_expired_queue_cmd() (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Userspace must not complete queued commands (Maurizio Lombardi) [1880395]
- [target] scsi: target: core: Add initiatorname to NON_EXISTENT_LUN error (Maurizio Lombardi) [1880395]
- [target] scsi: target: loopback: Fix READ with data and sensebytes (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Make pgr_support and alua_support attributes writable (Maurizio Lombardi) [1880395]
- [target] scsi: target: Make transport_flags per device (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: Add attributes enforce_pr_isids and force_pr_aptpl (Maurizio Lombardi) [1880395]
- [target] scsi: target: Add missing emulate_pr attribute to passthrough backends (Maurizio Lombardi) [1880395]
- [target] scsi: target: iscsi: Remove the iscsi_data_count structure (Maurizio Lombardi) [1880395]
- [target] scsi: target: Put lun_ref at end of tmr processing (Maurizio Lombardi) [1880395]
- [target] scsi: target/iblock: fix WRITE SAME zeroing (Maurizio Lombardi) [1880395]
- [target] scsi: target: tcmu: reset_ring should reset TCMU_DEV_BIT_BROKEN (Maurizio Lombardi) [1880395]
- [target] scsi: target: fix PR IN / READ FULL STATUS for FC (Maurizio Lombardi) [1880395]
- [target] scsi: target: Write NULL to *port_nexus_ptr if no ISID (Maurizio Lombardi) [1880395]
- [target] scsi: target: use the stack for XCOPY passthrough cmds (Maurizio Lombardi) [1880395]
- [target] scsi: target: increase XCOPY I/O size (Maurizio Lombardi) [1880395]
- [target] scsi: target: avoid per-loop XCOPY buffer allocations (Maurizio Lombardi) [1880395]
- [target] scsi: target: drop xcopy DISK BLOCK LENGTH debug (Maurizio Lombardi) [1880395]
- [target] scsi: target: use #define for xcopy descriptor len (Maurizio Lombardi) [1880395]
- [crypto] crypto: testmgr - mark cts(cbc(aes)) as FIPS allowed (Vladis Dronov) [1855161]
- [kernel] sched/deadline: Unthrottle PI boosted threads while enqueuing (Daniel Bristot de Oliveira) [1869760]
- [kernel] sched/deadline: Fix stale throttling on de-/boosted tasks (Daniel Bristot de Oliveira) [1869760]
- [netdrv] treewide: Use fallthrough pseudo-keyword (Jonathan Toppins) [1871286]
- [netdrv] tg3: Avoid the use of one-element array (Jonathan Toppins) [1871286]
- [netdrv] net: tg3: tidy up loop, remove need to compute off with a multiply (Jonathan Toppins) [1871286]
- [netdrv] net: tg3: reject unsupported coalescing params (Jonathan Toppins) [1871286]
- [netdrv] net: tg3: use skb_list_walk_safe helper for gso segments (Jonathan Toppins) [1871286]
- [gpio] gpio: gpio-mlxbf2.c: Provide __releases() annotation to stop confusing Sparse (Alaa Hleihel) [1816931]
- [gpio] gpio: gpio-mlxbf2: Tell the compiler that ACPI functions may not be use (Alaa Hleihel) [1816931]
- [gpio] gpio: mlxbf2: Fix sleeping while holding spinlock (Alaa Hleihel) [1816931]
- [gpio] gpio: mlxbf2: fix return value check in mlxbf2_gpio_get_lock_res() (Alaa Hleihel) [1816931]
- [gpio] gpio: mlxbf2: remove unused including <linux/version.h> (Alaa Hleihel) [1816931]
- [gpio] gpio: add driver for Mellanox BlueField 2 GPIO controller (Alaa Hleihel) [1816931]
- [include] compiler_attributes.h: Add 'fallthrough' pseudo keyword for switch/case use (Ivan Vecera) [1867168]
- [net] net: sctp: Rename fallthrough label to unhandled (Ivan Vecera) [1867168]

* Mon Oct 26 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.8.el8]
- [pci] PCI: Mark AMD Navi10 GPU rev 0x00 ATS as broken (Myron Stowe) [1888310]
- [netdrv] nfp: flower: fix ABI mismatch between driver and firmware (Ivan Vecera) [1886717]
- [netdrv] netronome: fix ipv6 link error (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: fix incorrect flag assignment (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: fix used time of merge flow statistics (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: inform firmware of flower features (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: renaming of feature bits (Ivan Vecera) [1886717]
- [netdrv] nfp: don't check lack of RX/TX channels (Ivan Vecera) [1886717]
- [netdrv] nfp: abm: fix error return code in nfp_abm_vnic_alloc() (Ivan Vecera) [1886717]
- [netdrv] nfp: abm: fix a memory leak bug (Ivan Vecera) [1886717]
- [netdrv] net/nfp: Update driver to use global kernel version (Ivan Vecera) [1886717]
- [netdrv] nfp: allow explicitly selected delayed stats (Ivan Vecera) [1886717]
- [netdrv] net: nfp: Use scnprintf() for avoiding potential buffer overflow (Ivan Vecera) [1886717]
- [netdrv] nfp: let core reject the unsupported coalescing parameters (Ivan Vecera) [1886717]
- [netdrv] nfp: Use pci_get_dsn() (Ivan Vecera) [1886717]
- [netdrv] netronome: Replace zero-length array with flexible-array member (Ivan Vecera) [1886717]
- [netdrv] devlink: move devlink documentation to subfolder (Ivan Vecera) [1886717]
- [netdrv] remove ioremap_nocache and devm_ioremap_nocache (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: implement the stream sync RX resync (Ivan Vecera) [1886717]
- [netdrv] nfp: pass packet pointer to nfp_net_parse_meta() (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: update flow merge code to support IPv6 tunnels (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: support ipv6 tunnel keep-alive messages from fw (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: handle notifiers for ipv6 route changes (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: handle ipv6 tunnel no neigh request (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: modify pre-tunnel and set tunnel action for ipv6 (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: offload list of IPv6 tunnel endpoint addresses (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: compile match for IPv6 tunnels (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: move udp tunnel key match compilation to helper function (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: pass flow rule pointer directly to match functions (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: fix stats id allocation (Ivan Vecera) [1886717]
- [netdrv] netronome: use the new txqueue timeout argument (Ivan Vecera) [1886717]
- [netdrv] nfp: add support for TLV device stats (Ivan Vecera) [1886717]
- [netdrv] treewide: Use sizeof_field() macro (Ivan Vecera) [1886717]
- [netdrv] net: use rhashtable_lookup() instead of rhashtable_lookup_fast() (Ivan Vecera) [1886717]
- [netdrv] nfp: bpf: make array exp_mask static, makes object smaller (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: fix memory leak in nfp_flower_spawn_vnic_reprs (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: prevent memory leak in nfp_flower_spawn_phy_reprs (Ivan Vecera) [1886717]
- [netdrv] nfp: read chip model from the PluDevice register (Ivan Vecera) [1886717]
- [netdrv] nfp: devlink: set unknown fw_load_policy (Ivan Vecera) [1886717]
- [documentation] Documentation: nfp: add nfp driver specific notes (Ivan Vecera) [1886717]
- [netdrv] kdoc: fix nfp_fw_load documentation (Ivan Vecera) [1886717]
- [netdrv] nfp: devlink: add 'reset_dev_on_drv_probe' support (Ivan Vecera) [1886717]
- [netdrv] nfp: devlink: add 'fw_load_policy' support (Ivan Vecera) [1886717]
- [netdrv] nfp: add devlink param infrastructure (Ivan Vecera) [1886717]
- [netdrv] nfp: honor FW reset and loading policies (Ivan Vecera) [1886717]
- [netdrv] nfp: nsp: add support for hwinfo set operation (Ivan Vecera) [1886717]
- [netdrv] nfp: nsp: add support for optional hwinfo lookup (Ivan Vecera) [1886717]
- [netdrv] nfp: nsp: add support for fw_loaded command (Ivan Vecera) [1886717]
- [netdrv] nfp: bpf: add simple map op cache (Ivan Vecera) [1886717]
- [netdrv] nfp: bpf: rework MTU checking (Ivan Vecera) [1886717]
- [netdrv] net: Use skb accessors in network drivers (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: rename tls packet counters (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: undo TLS sequence tracking when dropping the frame (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: avoid one of the ifdefs for TLS (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: don't leave key material in freed FW cmsg skbs (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: count TSO segments separately for the TLS offload (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: use unique connection ids instead of 4-tuple for TX (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: move setting ipver_vlan to a helper (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: ignore queue limits for delete commands (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: fix error return code in nfp_net_tls_add() (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: enable TLS RX offload (Ivan Vecera) [1886717]
- [netdrv] net/tls: don't clear TX resync flag on error (Ivan Vecera) [1886717]
- [netdrv] net/tls: add tracing for device/offload events (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: make use of kernel-driven TX resync (Ivan Vecera) [1886717]
- [netdrv] net/tls: generalize the resync callback (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: implement RX TLS resync (Ivan Vecera) [1886717]
- [netdrv] nfp: add async version of mailbox communication (Ivan Vecera) [1886717]
- [netdrv] nfp: rename nfp_ccm_mbox_alloc() (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: set skb decrypted flag (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: add basic statistics (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: add/delete TLS TX connections (Ivan Vecera) [1886717]
- [netdrv] nfp: tls: add datapath support for TLS TX (Ivan Vecera) [1886717]
- [netdrv] nfp: flower: use struct_size() helper (Ivan Vecera) [1886717]
- [netdrv] nfp: add missing kdoc (Ivan Vecera) [1886717]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Ivan Vecera) [1886717]
- [iommu] iommu/amd: Fix the overwritten field in IVMD header (Baoquan He) [1869148]
- [powerpc] pseries/drmem: don't cache node id in drmem_lmb struct (Diego Domingos) [1816543]
- [include] cgroup: Fix sock_cgroup_data on big-endian (Vladis Dronov) [1868659] {CVE-2020-14356}
- [include] cgroup: fix cgroup_sk_alloc() for sk_clone_lock() (Vladis Dronov) [1868659] {CVE-2020-14356}
- [net] netprio_cgroup: Fix unlimited memory leak of v2 cgroups (Vladis Dronov) [1868659] {CVE-2020-14356}
- [netdrv] net/broadcom: Clean broadcom code from driver versions (Jonathan Toppins) [1872443]

* Wed Oct 21 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.7.el8]
- [net] Bluetooth: fix kernel oops in store_pending_adv_report (Gopal Tiwari) [1888455] {CVE-2020-24490}
- [net] Bluetooth: L2CAP: Fix calling sk_filter on non-socket based channel (Gopal Tiwari) [1888258] {CVE-2020-12351}
- [net] Bluetooth: A2MP: Fix not initializing all members (Gopal Tiwari) [1888807] {CVE-2020-12352}
- [mm] mm, compaction: make capture control handling safe wrt interrupts (Rafael Aquini) [1862175]
- [mm] mm/compaction: fix a typo in comment "pessemistic"->"pessimistic" (Rafael Aquini) [1862175]
- [mm] mm/compaction: add missing annotation for compact_lock_irqsave (Rafael Aquini) [1862175]
- [mm] mm/compaction.c: clean code by removing unnecessary assignment (Rafael Aquini) [1862175]
- [kernel] mm/compaction: Disable compact_unevictable_allowed on RT (Rafael Aquini) [1862175]
- [kernel] mm/compaction: really limit compact_unevictable_allowed to 0 and 1 (Rafael Aquini) [1862175]
- [mm] mm, compaction: fully assume capture is not NULL in compact_zone_order() (Rafael Aquini) [1862175]
- [mm] mm, compaction: fix wrong pfn handling in __reset_isolation_pfn() (Rafael Aquini) [1862175]
- [mm] mm/compaction.c: remove unnecessary zone parameter in isolate_migratepages() (Rafael Aquini) [1862175]
- [mm] mm: compaction: avoid 100 CPU usage during compaction when a task is killed (Rafael Aquini) [1862175]
- [mm] mm, compaction: make sure we isolate a valid PFN (Rafael Aquini) [1862175]
- [mm] mm/compaction.c: correct zone boundary handling when isolating pages from a pageblock (Rafael Aquini) [1862175]
- [trace] mm, compaction: some tracepoints should be defined only when CONFIG_COMPACTION is set (Rafael Aquini) [1862175]
- [trace] mm: compaction: show gfp flag names in try_to_compact_pages tracepoint (Rafael Aquini) [1862175]
- [mm] mm/compaction.c: fix an undefined behaviour (Rafael Aquini) [1862175]
- [mm] mm, page_alloc: always use a captured page regardless of compaction result (Rafael Aquini) [1862175]
- [mm] mm/compaction.c: abort search if isolation fails (Rafael Aquini) [1862175]
- [mm] mm/compaction.c: correct zone boundary handling when resetting pageblock skip hints (Rafael Aquini) [1862175]
- [include] include/linux/list.h: fix list_is_first() kernel-doc (Rafael Aquini) [1862175]
- [mm] mm/compaction: pass pgdat to too_many_isolated() instead of zone (Rafael Aquini) [1862175]
- [mm] mm: remove zone_lru_lock() function, access ->lru_lock directly (Rafael Aquini) [1862175]
- [mm] mm, compaction: capture a page under direct compaction (Rafael Aquini) [1862175]
- [mm] mm, compaction: be selective about what pageblocks to clear skip hints (Rafael Aquini) [1862175]
- [mm] mm, compaction: sample pageblocks for free pages (Rafael Aquini) [1862175]
- [mm] mm, compaction: round-robin the order while searching the free lists for a target (Rafael Aquini) [1862175]
- [mm] mm, compaction: reduce premature advancement of the migration target scanner (Rafael Aquini) [1862175]
- [mm] mm, compaction: do not consider a need to reschedule as contention (Rafael Aquini) [1862175]
- [mm] mm, compaction: rework compact_should_abort as compact_check_resched (Rafael Aquini) [1862175]
- [mm] mm, compaction: keep cached migration PFNs synced for unusable pageblocks (Rafael Aquini) [1862175]
- [mm] mm, compaction: check early for huge pages encountered by the migration scanner (Rafael Aquini) [1862175]
- [mm] mm, compaction: finish pageblock scanning on contention (Rafael Aquini) [1862175]
- [mm] mm, compaction: avoid rescanning the same pageblock multiple times (Rafael Aquini) [1862175]
- [mm] mm, compaction: use free lists to quickly locate a migration target (Rafael Aquini) [1862175]
- [mm] mm, compaction: keep migration source private to a single compaction instance (Rafael Aquini) [1862175]
- [mm] mm, compaction: use free lists to quickly locate a migration source (Rafael Aquini) [1862175]
- [mm] mm, compaction: always finish scanning of a full pageblock (Rafael Aquini) [1862175]
- [mm] mm, migrate: immediately fail migration of a page with no migration handler (Rafael Aquini) [1862175]
- [mm] mm, compaction: rename map_pages to split_map_pages (Rafael Aquini) [1862175]
- [mm] mm, compaction: remove unnecessary zone parameter in some instances (Rafael Aquini) [1862175]
- [mm] mm, compaction: remove last_migrated_pfn from compact_control (Rafael Aquini) [1862175]
- [mm] mm, compaction: rearrange compact_control (Rafael Aquini) [1862175]
- [mm] mm, compaction: shrink compact_control (Rafael Aquini) [1862175]
- [kernel] mm: remove sysctl_extfrag_handler() (Rafael Aquini) [1862175]
- [net] netlink: fix state reallocation in policy export (Petr Oros) [1874050]
- [net] netlink: add infrastructure to expose policies to userspace (Petr Oros) [1874050]
- [lib] netlink: factor out policy range helpers (Petr Oros) [1874050]
- [net] netlink: remove NLA_EXACT_LEN_WARN (Petr Oros) [1874050]
- [include] netlink: allow NLA_MSECS to have range validation (Petr Oros) [1874050]
- [net] netlink: extend policy range validation (Petr Oros) [1874050]
- [net] nl80211: link recursive netlink nested policy (Petr Oros) [1874050]
- [lib] netlink: limit recursion depth in policy validation (Petr Oros) [1874050]
- [net] netlink: remove type-unsafe validation_data pointer (Petr Oros) [1874050]
- [powerpc] powerpc/pseries: new lparcfg key/value pair: partition_affinity_score (Steve Best) [1879420]
- [powerpc] powerpc/perf: consolidate GPCI hcall structs into asm/hvcall.h (Steve Best) [1879420]
- [include] iopoll: Introduce read_poll_timeout_atomic macro (Patrick Talbert) [1879211]
- [include] iopoll: redefined readx_poll_timeout macro to simplify the code (Patrick Talbert) [1879211]
- [include] iopoll: introduce read_poll_timeout macro (Patrick Talbert) [1879211]
- [infiniband] IB/ipoib: Fix double free of skb in case of multicast traffic in CM mode (Kamal Heib) [1857600]
- [infiniband] RDMA/core: Fix double destruction of uobject (Kamal Heib) [1857600]
- [infiniband] RDMA/pvrdma: Fix missing pci disable in pvrdma_pci_probe() (Kamal Heib) [1857600]
- [net] xprtrdma: Fix use of xdr_stream_encode_item_{present, absent} (Kamal Heib) [1857600]
- [net] xprtrdma: Fix trace point use-after-free race (Kamal Heib) [1857600]
- [net] xprtrdma: Restore wake-up-all to rpcrdma_cm_event_handler() (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Fix missing RDMA_CM_EVENT_REJECTED event after receiving REJ message (Kamal Heib) [1857600]
- [net] xprtrdma: kmalloc rpcrdma_ep separate from rpcrdma_xprt (Kamal Heib) [1857600]
- [net] xprtrdma: Extract sockaddr from struct rdma_cm_id (Kamal Heib) [1857600]
- [net] xprtrdma: Merge struct rpcrdma_ia into struct rpcrdma_ep (Kamal Heib) [1857600]
- [net] xprtrdma: Disconnect on flushed completion (Kamal Heib) [1857600]
- [net] xprtrdma: Remove rpcrdma_ia::ri_flags (Kamal Heib) [1857600]
- [net] xprtrdma: Invoke rpcrdma_ia_open in the connect worker (Kamal Heib) [1857600]
- [net] xprtrdma: Allocate Protection Domain in rpcrdma_ep_create() (Kamal Heib) [1857600]
- [net] xprtrdma: Refactor rpcrdma_ep_connect() and rpcrdma_ep_disconnect() (Kamal Heib) [1857600]
- [net] xprtrdma: Clean up the post_send path (Kamal Heib) [1857600]
- [net] xprtrdma: Refactor frwr_init_mr() (Kamal Heib) [1857600]
- [net] xprtrdma: Invoke rpcrdma_ep_create() in the connect worker (Kamal Heib) [1857600]
- [net] xprtrdma: Enhance MR-related trace points (Kamal Heib) [1857600]
- [infiniband] IB/iser: Always check sig MR before putting it to the free pool (Kamal Heib) [1857600]
- [infiniband] RDMA/efa: Use in-kernel offsetofend() to check field availability (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Make sure the cm_id is in the IB_CM_IDLE state in destroy (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Allow ib_send_cm_sidr_rep() to be done under lock (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Allow ib_send_cm_rej() to be done under lock (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Allow ib_send_cm_drep() to be done under lock (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Allow ib_send_cm_dreq() to be done under lock (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Add some lockdep assertions for cm_id_priv->lock (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Make it clearer how concurrency works in cm_req_handler() (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Make it clear that there is no concurrency in cm_sidr_req_handler() (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Simplify establishing a listen cm_id (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Make the destroy_id flow more robust (Kamal Heib) [1857600]
- [net] svcrdma: Avoid DMA mapping small RPC Replies (Kamal Heib) [1857600]
- [net] svcrdma: Fix double sync of transport header buffer (Kamal Heib) [1857600]
- [net] svcrdma: Refactor chunk list encoders (Kamal Heib) [1857600]
- [net] SUNRPC: Add encoders for list item discriminators (Kamal Heib) [1857600]
- [net] svcrdma: Rename svcrdma_encode trace points in send routines (Kamal Heib) [1857600]
- [net] svcrdma: Update synopsis of svc_rdma_send_reply_msg() (Kamal Heib) [1857600]
- [net] svcrdma: Update synopsis of svc_rdma_map_reply_msg() (Kamal Heib) [1857600]
- [net] svcrdma: Update synopsis of svc_rdma_send_reply_chunk() (Kamal Heib) [1857600]
- [net] svcrdma: De-duplicate code that locates Write and Reply chunks (Kamal Heib) [1857600]
- [include] svcrdma: Use struct xdr_stream to decode ingress transport headers (Kamal Heib) [1857600]
- [net] svcrdma: Remove svcrdma_cm_event() trace point (Kamal Heib) [1857600]
- [net] SUNRPC: Add xdr_pad_size() helper (Kamal Heib) [1857600]
- [net] nfsd: Fix NFSv4 READ on RDMA when using readv (Kamal Heib) [1857600]
- [net] svcrdma: Replace zero-length array with flexible-array member (Kamal Heib) [1857600]
- [infiniband] RDMA/cm: Delete not implemented CM peer to peer communication (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Teach lockdep about the order of rtnl and lock (Kamal Heib) [1857600]
- [infiniband] RDMA/rw: map P2P memory correctly for signature operations (Kamal Heib) [1857600]
- [infiniband] RDMA/ipoib: reject unsupported coalescing params (Kamal Heib) [1857600]
- [infiniband] RDMA/providers: Fix return value when QP type isn't supported (Kamal Heib) [1857600]
- [infiniband] RDMA/hns: Use the new APIs for printing log (Kamal Heib) [1857600]
- [infiniband] RDMA/hns: Optimize hns_roce_modify_qp function (Kamal Heib) [1857600]
- [infiniband] RDMA/hns: RDMA/hns: Assign rq head pointer when enable rq record db (Kamal Heib) [1857600]
- [infiniband] RDMA/hns: Update the prompt message for creating and destroy qp (Kamal Heib) [1857600]
- [infiniband] RDMA/efa: Do not delay freeing of DMA pages (Kamal Heib) [1857600]
- [infiniband] RDMA/efa: Properly document the interrupt mask register (Kamal Heib) [1857600]
- [infiniband] RDMA/efa: Unified getters/setters for device structs bitmask access (Kamal Heib) [1857600]
- [infiniband] RDMA/ipoib: Don't set constant driver version (Kamal Heib) [1857600]
- [infiniband] RDMA: Replace zero-length array with flexible-array member (Kamal Heib) [1857600]
- [infiniband] RDMA/ucma: Use refcount_t for the ctx->ref (Kamal Heib) [1857600]
- [infiniband] RDMA/core: Get rid of ib_create_qp_user (Kamal Heib) [1857600]
- [infiniband] RDMA/core: Add weak ordering dma attr to dma mapping (Kamal Heib) [1857600]
- [infiniband] RDMA/ucma: Mask QPN to be 24 bits according to IBTA (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Use refcount API to reflect refcount (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Rename cma_device ref/deref helpers to to get/put (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Use refcount API to reflect refcount (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Rename cma_device ref/deref helpers to to get/put (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Use RDMA device port iterator (Kamal Heib) [1857600]
- [infiniband] RDMA/cma: Use a helper function to enqueue resolve work items (Kamal Heib) [1857600]
- [infiniband] RDMA/rw: Fix error flow during RDMA context initialization (Kamal Heib) [1857600]
- [infiniband] IB/core: Add interface to advise_mr for kernel users (Kamal Heib) [1857600]
- [infiniband] IB/core: Introduce ib_reg_user_mr (Kamal Heib) [1857600]
- [uapi] RDMA/core: Add the core support field to METHOD_GET_CONTEXT (Kamal Heib) [1857600]
- [infiniband] RDMA/uverbs: Add ioctl command to get a device context (Kamal Heib) [1857600]
- [fs] xfs: Fix false positive lockdep warning with sb_internal & fs_reclaim (Waiman Long) [1838643]
- [mm] mm/mmu_notifier: mm/rmap.c: Fix a mmu_notifier range bug in try_to_unmap_one (Waiman Long) [1871883]
- [mm] mm/memory.c: initialise mmu_notifier_range correctly (Waiman Long) [1871883]
- [mm] mm/mmu_notifier: use structure for invalidate_range_start/end calls v2 (Waiman Long) [1871883]
- [mm] hugetlb: take PMD sharing into account when flushing tlb/caches (Waiman Long) [1871883]
- [mm] mm, hugetlbfs: pass fault address to cow handler (Waiman Long) [1871883]
- [mm] mm, hugetlbfs: rename address to haddr in hugetlb_cow() (Waiman Long) [1871883]
- [mm] mm, huge page: copy target sub-page last when copy huge page (Waiman Long) [1871883]
- [mm] mm, clear_huge_page: move order algorithm into a separate function (Waiman Long) [1871883]
- [mm] Revert "mm: always flush VMA ranges affected by zap_page_range" (Waiman Long) [1871883]
- [kernel] psi: eliminate kthread_worker from psi trigger scheduling mechanism (Waiman Long) [1873040]
- [kernel] psi: get poll_work to run when calling poll syscall next time (Waiman Long) [1873040]
- [block] block: loop: set discard granularity and alignment for block device backed loop (Ming Lei) [1866712]
- [net] gre: recompute gre csum for sctp over gre tunnels (Lorenzo Bianconi) [1755200]
- [include] mm/hugetlb: enable arch specific huge page size support for migration (Donghai Qiao) [1869887]
- [mm] arm64/mm: enable HugeTLB migration for contiguous bit HugeTLB pages (Donghai Qiao) [1869887]
- [lib] idr: Fix idr_get_next_ul race with idr_remove (Felix Ansell) [1866062]
- [lib] genalloc: Fix a set of docs build warnings (Felix Ansell) [1866062]
- [lib] lib/Kconfig: fix OBJAGG in lib/ menu structure (Felix Ansell) [1866062]
- [lib] lib: Reduce user_access_begin() boundaries in strncpy_from_user() and strnlen_user() (Felix Ansell) [1866062]

* Fri Oct 16 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.6.el8]
- [char] random32: update the net random state on interrupt and activity (Donghai Qiao) [1867569] {CVE-2020-16166}
- [fs] nfs: Fix getxattr kernel panic and memory overflow (Benjamin Coddington) [1880894] {CVE-2020-25212}
- [tools] selftests: rtnetlink: Test bridge enslavement with different parent IDs (Jonathan Toppins) [1860479]
- [tools] selftests: rtnetlink: correct the final return value for the test (Jonathan Toppins) [1860479]
- [net] Fix bridge enslavement failure (Jonathan Toppins) [1860479]
- [net] Make mpls_entry_encode() available for generic users (Patrick Talbert) [1878818]
- [net] SUNRPC dont update timeout value on connection reset (Steve Dickson) [1861895]
- [kernel] overflow.h: Add flex_array_size() helper (Petr Oros) [1876924]
- [net] netpoll: accept NULL np argument in netpoll_send_skb() (Ivan Vecera) [1867968]
- [net] netpoll: netpoll_send_skb() returns transmit status (Ivan Vecera) [1867968]
- [net] netpoll: move netpoll_send_skb() out of line (Ivan Vecera) [1867968]
- [net] netpoll: remove dev argument from netpoll_send_skb_on_dev() (Ivan Vecera) [1867968]
- [net] netpoll: Fix use correct return type for ndo_start_xmit() (Ivan Vecera) [1867968]
- [net] core: Introduce netdev_get_xmit_slave (Ivan Vecera) [1867974]
- [net] get rid of lockdep_set_class_and_subclass() (Ivan Vecera) [1867961]
- [net] change addr_list_lock back to static key (Ivan Vecera) [1867961]
- [net] batman-adv: Revert "Drop lockdep.h include for soft-interface.c" (Ivan Vecera) [1867961]
- [net] partially revert dynamic lockdep key changes (Ivan Vecera) [1867961]
- [kernel] rcu: Maintain RHEL kABI (Waiman Long) [1862812]
- [kernel] rcu: Don't acquire lock in NMI handler in rcu_nmi_enter_common() (Waiman Long) [1862812]
- [kernel] rcu: Add *_ONCE() to rcu_data ->rcu_forced_tick (Waiman Long) [1862812]
- [kernel] rcu: Make rcu_barrier() account for offline no-CBs CPUs (Waiman Long) [1862812]
- [kernel] rcu: Clear ->core_needs_qs at GP end or self-reported QS (Waiman Long) [1862812]
- [kernel] rcu: Forgive slow expedited grace periods at boot time (Waiman Long) [1862812]
- [tools] torture: Hoist calls to lscpu to higher-level kvm.sh script (Waiman Long) [1862812]
- [tools] torture: Allow "CFLIST" to specify default list of scenarios (Waiman Long) [1862812]
- [kernel] rcutorture: Dynamically allocate rcu_fwds structure (Waiman Long) [1862812]
- [kernel] rcutorture: Complete threading rcu_fwd pointers through functions (Waiman Long) [1862812]
- [kernel] rcutorture: Move to dynamic initialization of rcu_fwds (Waiman Long) [1862812]
- [kernel] rcutorture: Thread rcu_fwd pointer through forward-progress functions (Waiman Long) [1862812]
- [kernel] rcutorture: Pull callback forward-progress data into rcu_fwd struct (Waiman Long) [1862812]
- [tools] rcutorture: Add worst-case call_rcu() forward-progress results (Waiman Long) [1862812]
- [tools] torture: Handle systems lacking the mpstat command (Waiman Long) [1862812]
- [tools] torture: Handle jitter for CPUs that cannot be offlined (Waiman Long) [1862812]
- [tools] rcutorture: Dispense with Dracut for initrd creation (Waiman Long) [1862812]
- [tools] torture: Use gawk instead of awk for systime() function (Waiman Long) [1862812]
- [kernel] rcu: Avoid tick_dep_set_cpu() misordering (Waiman Long) [1862812]
- [kernel] rcu: Provide wrappers for uses of ->rcu_read_lock_nesting (Waiman Long) [1862812]
- [kernel] rcu: Use READ_ONCE() for ->expmask in rcu_read_unlock_special() (Waiman Long) [1862812]
- [kernel] rcu: Clear ->rcu_read_unlock_special only once (Waiman Long) [1862812]
- [kernel] rcu: Clear .exp_hint only when deferred quiescent state has been reported (Waiman Long) [1862812]
- [kernel] rcu: Rename some instance of CONFIG_PREEMPTION to CONFIG_PREEMPT_RCU (Waiman Long) [1862812]
- [kernel] rcu: Use CONFIG_PREEMPTION where appropriate (Waiman Long) [1862812]
- [kernel] rcu: Make PREEMPT_RCU be a modifier to TREE_RCU (Waiman Long) [1862812]
- [kernel] rcu: Use lockdep rather than comment to enforce lock held (Waiman Long) [1862812]
- [kernel] rcu: Avoid data-race in rcu_gp_fqs_check_wake() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Fix dump_tree hierarchy print always active (Waiman Long) [1862812]
- [kernel] rculist.h: Add list_tail_rcu() (Waiman Long) [1862812]
- [kernel] rculist_nulls: Change docbook comment headers (Waiman Long) [1862812]
- [kernel] rculist_nulls: Add docbook comments (Waiman Long) [1862812]
- [include] rcu: Add a hlist_nulls_unhashed_lockless() function (Waiman Long) [1862812]
- [kernel] rcu: Use WRITE_ONCE() for assignments to ->pprev for hlist_nulls (Waiman Long) [1862812]
- [kernel] rcu: Remove kfree_call_rcu_nobatch() (Waiman Long) [1862812]
- [kernel] rcu: Remove kfree_rcu() special casing and lazy-callback handling (Waiman Long) [1862812]
- [kernel] rcu: Add support for debug_objects debugging for kfree_rcu() (Waiman Long) [1862812]
- [kernel] rcu: Add multiple in-flight batches of kfree_rcu() work (Waiman Long) [1862812]
- [kernel] rcu: Make kfree_rcu() use a non-atomic ->monitor_todo (Waiman Long) [1862812]
- [kernel] rcuperf: Add kfree_rcu() performance Tests (Waiman Long) [1862812]
- [kernel] rcu: Add basic support for kfree_rcu() batching (Waiman Long) [1862812]
- [kernel] rcu: Remove unused stop-machine #include (Waiman Long) [1862812]
- [kernel] srcu: Apply *_ONCE() to ->srcu_last_gp_end (Waiman Long) [1862812]
- [kernel] rcu: Switch force_qs_rnp() to for_each_leaf_node_cpu_mask() (Waiman Long) [1862812]
- [kernel] rcu: Move rcu_{expedited, normal} definitions into rcupdate.h (Waiman Long) [1862812]
- [kernel] rcu: Move gp_state_namesand gp_state_getname() to tree_stall.h (Waiman Long) [1862812]
- [kernel] rcu: Remove the declaration of call_rcu() in tree.h (Waiman Long) [1862812]
- [kernel] rcu: Fix tracepoint tracking RCU CPU kthread utilization (Waiman Long) [1862812]
- [kernel] rcu: Fix harmless omission of "CONFIG_" from #if condition (Waiman Long) [1862812]
- [kernel] rcu: Mark non-global functions and variables as static (Waiman Long) [1862812]
- [kernel] rcu: Enable tick for nohz_full CPUs slow to provide expedited QS (Waiman Long) [1862812]
- [kernel] rcu: Replace synchronize_sched_expedited_wait() "_sched" with "_rcu" (Waiman Long) [1862812]
- [kernel] rcu: Update tree_exp.h function-header comments (Waiman Long) [1862812]
- [kernel] rcu: Rename sync_rcu_preempt_exp_done() to sync_rcu_exp_done() (Waiman Long) [1862812]
- [kernel] rcu: Allow only one expedited GP to run concurrently with wakeups (Waiman Long) [1862812]
- [kernel] rcu: Fix missed wakeup of exp_wq waiters (Waiman Long) [1862812]
- [kernel] rcu: Substitute lookup for bit-twiddling in sync_rcu_exp_select_node_cpus() (Waiman Long) [1862812]
- [kernel] rcu: Fix data-race due to atomic_t copy-by-value (Waiman Long) [1862812]
- [kernel] rcu: Avoid modifying mask_ofl_ipi in sync_rcu_exp_select_node_cpus() (Waiman Long) [1862812]
- [kernel] rcu: Use *_ONCE() to protect lockless ->expmask accesses (Waiman Long) [1862812]
- [kernel] rcutorture: Make in-kernel-loop testing more brutal (Waiman Long) [1862812]
- [kernel] rcutorture: Separate warnings for each failure type (Waiman Long) [1862812]
- [kernel] rcu: Remove unused variable rcu_perf_writer_state (Waiman Long) [1862812]
- [tools] rcutorture: Remove CONFIG_HOTPLUG_CPU=n from scenarios (Waiman Long) [1862812]
- [kernel] rcu: Remove unused function rcutorture_record_progress() (Waiman Long) [1862812]
- [kernel] rcu: Make kernel-mode nohz_full CPUs invoke the RCU core processing (Waiman Long) [1862812]
- [kernel] rcu: Confine ->core_needs_qs accesses to the corresponding CPU (Waiman Long) [1862812]
- [kernel] rcu: Reset CPU hints when reporting a quiescent state (Waiman Long) [1862812]
- [kernel] rcu: Force nohz_full tick on upon irq enter instead of exit (Waiman Long) [1862812]
- [kernel] rcu: Force tick on for nohz_full CPUs not reaching quiescent states (Waiman Long) [1862812]
- [kernel] rcutorture: Emulate dyntick aspect of userspace nohz_full sojourn (Waiman Long) [1862812]
- [kernel] rcu: Make CPU-hotplug removal operations enable tick (Waiman Long) [1862812]
- [kernel] stop_machine: Provide RCU quiescent state in multi_cpu_stop() (Waiman Long) [1862812]
- [kernel] rcutorture: Force on tick for readers and callback flooders (Waiman Long) [1862812]
- [kernel] rcu: Force on tick when invoking lots of callbacks (Waiman Long) [1862812]
- [kernel] time: Export tick start/stop functions for rcutorture (Waiman Long) [1862812]
- [kernel] nohz: Add TICK_DEP_BIT_RCU (Waiman Long) [1862812]
- [kernel] rcu: Suppress levelspread uninitialized messages (Waiman Long) [1862812]
- [kernel] rcu: Fix uninitialized variable in nocb_gp_wait() (Waiman Long) [1862812]
- [trace] rcu: Update descriptions for rcu_future_grace_period tracepoint (Waiman Long) [1862812]
- [trace] rcu: Update descriptions for rcu_nocb_wake tracepoint (Waiman Long) [1862812]
- [trace] rcu: Remove obsolete descriptions for rcu_barrier tracepoint (Waiman Long) [1862812]
- [kernel] rcu: Ensure that ->rcu_urgent_qs is set before resched IPI (Waiman Long) [1862812]
- [kernel] rcu: Several rcu_segcblist functions can be static (Waiman Long) [1862812]
- [kernel] rcu: Remove unused function hlist_bl_del_init_rcu() (Waiman Long) [1862812]
- [kernel] rcu: Allow rcu_do_batch() to dynamically adjust batch sizes (Waiman Long) [1862812]
- [kernel] srcu: Avoid srcutorture security-based pointer obfuscation (Waiman Long) [1862812]
- [kernel] rcu/nocb: Don't wake no-CBs GP kthread if timer posted under overload (Waiman Long) [1862812]
- [kernel] rcu/nocb: Reduce __call_rcu_nocb_wake() leaf rcu_node ->lock contention (Waiman Long) [1862812]
- [kernel] rcu/nocb: Reduce nocb_cb_wait() leaf rcu_node ->lock contention (Waiman Long) [1862812]
- [kernel] rcu/nocb: Advance CBs after merge in rcutree_migrate_callbacks() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Avoid synchronous wakeup in __call_rcu_nocb_wake() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Print no-CBs diagnostics when rcutorture writer unduly delayed (Waiman Long) [1862812]
- [kernel] rcu/nocb: EXP Check use and usefulness of ->nocb_lock_contended (Waiman Long) [1862812]
- [kernel] rcu/nocb: Add bypass callback queueing (Waiman Long) [1862812]
- [kernel] rcu/nocb: Atomic ->len field in rcu_segcblist structure (Waiman Long) [1862812]
- [kernel] rcu/nocb: Unconditionally advance and wake for excessive CBs (Waiman Long) [1862812]
- [kernel] rcu/nocb: Reduce ->nocb_lock contention with separate ->nocb_gp_lock (Waiman Long) [1862812]
- [kernel] rcu/nocb: Reduce contention at no-CBs invocation-done time (Waiman Long) [1862812]
- [kernel] rcu/nocb: Reduce contention at no-CBs registry-time CB advancement (Waiman Long) [1862812]
- [kernel] rcu/nocb: Round down for number of no-CBs grace-period kthreads (Waiman Long) [1862812]
- [kernel] rcu/nocb: Avoid ->nocb_lock capture by corresponding CPU (Waiman Long) [1862812]
- [kernel] rcu/nocb: Avoid needless wakeups of no-CBs grace-period kthread (Waiman Long) [1862812]
- [kernel] rcu/nocb: Make __call_rcu_nocb_wake() safe for many callbacks (Waiman Long) [1862812]
- [kernel] rcu/nocb: Never downgrade ->nocb_defer_wakeup in wake_nocb_gp_defer() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Enable re-awakening under high callback load (Waiman Long) [1862812]
- [kernel] rcu/nohz: Turn off tick for offloaded CPUs (Waiman Long) [1862812]
- [kernel] rcu/nocb: Suppress uninitialized false-positive in nocb_gp_wait() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Use build-time no-CBs check in rcu_pending() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Use build-time no-CBs check in rcu_core() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Use build-time no-CBs check in rcu_do_batch() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Remove obsolete nocb_gp_head and nocb_gp_tail fields (Waiman Long) [1862812]
- [kernel] rcu/nocb: Remove obsolete nocb_cb_tail and nocb_cb_head fields (Waiman Long) [1862812]
- [kernel] rcu/nocb: Remove obsolete nocb_q_count and nocb_q_count_lazy fields (Waiman Long) [1862812]
- [kernel] rcu/nocb: Remove obsolete nocb_head and nocb_tail fields (Waiman Long) [1862812]
- [kernel] rcu/nocb: Use rcu_segcblist for no-CBs CPUs (Waiman Long) [1862812]
- [kernel] rcu/nocb: Leave ->cblist enabled for no-CBs CPUs (Waiman Long) [1862812]
- [kernel] rcu/nocb: Allow lockless use of rcu_segcblist_empty() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Allow lockless use of rcu_segcblist_restempty() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Remove deferred wakeup checks for extended quiescent states (Waiman Long) [1862812]
- [kernel] rcu/nocb: Check for deferred nocb wakeups before nohz_full early exit (Waiman Long) [1862812]
- [kernel] rcu/nocb: Make rcutree_migrate_callbacks() start at leaf rcu_node structure (Waiman Long) [1862812]
- [kernel] rcu/nocb: Add checks for offloaded callback processing (Waiman Long) [1862812]
- [kernel] rcu/nocb: Use separate flag to indicate offloaded ->cblist (Waiman Long) [1862812]
- [kernel] rcu/nocb: Use separate flag to indicate disabled ->cblist (Waiman Long) [1862812]
- [kernel] rcu/nocb: Print gp/cb kthread hierarchy if dump_tree (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename rcu_nocb_leader_stride kernel boot parameter (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename and document no-CB CB kthread sleep trace event (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename rcu_organize_nocb_kthreads() local variable (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename wake_nocb_leader_defer() to wake_nocb_gp_defer() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename __wake_nocb_leader() to __wake_nocb_gp() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename wake_nocb_leader() to wake_nocb_gp() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename nocb_follower_wait() to nocb_cb_wait() (Waiman Long) [1862812]
- [kernel] rcu/nocb: Provide separate no-CBs grace-period kthreads (Waiman Long) [1862812]
- [kernel] rcu/nocb: Update comments to prepare for forward-progress work (Waiman Long) [1862812]
- [kernel] rcu/nocb: Rename rcu_data fields to prepare for forward-progress work (Waiman Long) [1862812]
- [kernel] rcutorture: Aggressive forward-progress tests shouldn't block shutdown (Waiman Long) [1862812]
- [kernel] rcuperf: Make rcuperf kernel test more robust for !expedited mode (Waiman Long) [1862812]
- [kernel] rcutorture: Emulate userspace sojourn during call_rcu() floods (Waiman Long) [1862812]
- [tools] rcutorture: Test TREE03 with the threadirqs kernel boot parameter (Waiman Long) [1862812]
- [tools] torture: Expand last_ts variable in kvm-test-1-run.sh (Waiman Long) [1862812]
- [kernel] rcuperf: Fix perf_type module-parameter description (Waiman Long) [1862812]
- [documentation] doc: Add rcutree.kthread_prio pointer to stallwarn.txt (Waiman Long) [1862812]
- [kernel] rcu: Change return type of rcu_spawn_one_boost_kthread() (Waiman Long) [1862812]
- [kernel] rcu: Add destroy_work_on_stack() to match INIT_WORK_ONSTACK() (Waiman Long) [1862812]
- [kernel] rcu: Add kernel parameter to dump trace after RCU CPU stall warning (Waiman Long) [1862812]
- [kernel] rcu: Restore barrier() to rcu_read_lock() and rcu_read_unlock() (Waiman Long) [1862812]
- [kernel] rcu: Simplify rcu_note_context_switch exit from critical section (Waiman Long) [1862812]
- [kernel] rcu: Make rcu_read_unlock_special() checks match raise_softirq_irqoff() (Waiman Long) [1862812]
- [kernel] rcu: Simplify rcu_read_unlock_special() deferred wakeups (Waiman Long) [1862812]
- [tools] rcu: Don't return a value from rcu_assign_pointer() (Waiman Long) [1862812]
- [kernel] rcu: Force inlining of rcu_read_lock() (Waiman Long) [1862812]
- [kernel] rcu: Fix irritating whitespace error in rcu_assign_pointer() (Waiman Long) [1862812]
- [kernel] rcu: validate arguments for rcu tracepoints (Waiman Long) [1862812]
- [trace] tracing: introduce TRACE_EVENT_NOP() (Waiman Long) [1862812]
- [kernel] kprobes: Prohibit probing on RCU debug routine (Waiman Long) [1862812]
- [init] time: Make VIRT_CPU_ACCOUNTING_GEN depend on GENERIC_CLOCKEVENTS (Waiman Long) [1862812]
- [kernel] time: Move CONTEXT_TRACKING to kernel/time/Kconfig (Waiman Long) [1862812]

* Tue Oct 13 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.5.el8]
- [fs] xfs: don't commit sunit/swidth updates to disk if that would cause repair failures (Bill O'Donnell) [1849407]
- [fs] xfs: split the sunit parameter update into two parts (Bill O'Donnell) [1849407]
- [fs] xfs: refactor agfl length computation function (Bill O'Donnell) [1849407]
- [net] netfilter: conntrack: proc: rename stat column (Florian Westphal) [1875681]
- [net] netfilter: conntrack: add clash resolution stat counter (Florian Westphal) [1875681]
- [net] netfilter: conntrack: remove ignore stats (Florian Westphal) [1875681]
- [net] netfilter: conntrack: do not increment two error counters at same time (Florian Westphal) [1875681]
- [net] netfilter: conntrack: do not auto-delete clash entries on reply (Florian Westphal) [1875681]
- [powerpc] powerpc/pseries/iommu: Allow bigger 64bit window by removing default DMA window (Steve Best) [1725198]
- [powerpc] powerpc/pseries/iommu: Move window-removing part of remove_ddw into remove_dma_window (Steve Best) [1725198]
- [powerpc] powerpc/pseries/iommu: Update call to ibm, query-pe-dma-windows (Steve Best) [1725198]
- [powerpc] powerpc/pseries/iommu: Create defines for operations in ibm, ddw-applicable (Steve Best) [1725198]
- [x86] x86/cpu: Add Sapphire Rapids CPU model number (Puneet Sethi) [1872367]
- [x86] x86/cpu: Add Lakefield, Alder Lake and Rocket Lake models to the to Intel CPU family (Steve Best) [1838902]

* Thu Oct 08 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.4.el8]
- [powerpc] powerpc/xmon: Improve dumping prefixed instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add a ppc_inst_as_str() helper (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add ppc_inst_as_u64() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add ppc_inst_next() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/sstep: Add tests for Prefixed Add Immediate (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/sstep: Let compute tests specify a required cpu feature (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/sstep: Set NIP in instruction emulation tests (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/sstep: Add tests for prefixed floating-point load/stores (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/sstep: Add tests for prefixed integer load/stores (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add POWER10 architected mode (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/dt_cpu_ftrs: Add MMA feature (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/dt_cpu_ftrs: Enable Prefixed Instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/dt_cpu_ftrs: Advertise support for ISA v3.1 if selected (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add support for ISA v3.1 (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add new HWCAP bits (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc sstep: Add support for prefixed fixed-point arithmetic (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc sstep: Add support for prefixed load/stores (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Support prefixed instructions in alignment handler (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/kprobes: Don't allow breakpoints on suffixes (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Don't allow breakpoints on suffixes (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Test prefixed instructions in feature fixups (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Test prefixed code patching (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add prefixed instructions to instruction data type (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/optprobes: Add register argument to patch_imm64_load_insns() (Desnes Augusto Nunes do Rosario) [1854524]
- [kvm] powerpc: Define new SRR1 bits for a ISA v3.1 (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/83xx: handle machine check caused by watchdog timer (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Enable Prefixed Instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Make test_translate_branch() independent of instruction length (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Move insertion of breakpoint for xol'ing (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Use a function for reading instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Introduce a function for reporting instruction length (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Define and use get_user_instr() et. al (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/kprobes: Use patch_instruction() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add a probe_kernel_read_inst() function (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add a probe_user_read_inst() function (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Use a function for reading instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Use a datatype for instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/lib: Refactor __patch_instruction() to use __put_user_asm() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: use probe_user_read() and probe_user_write() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/process: Constify the number of insns printed by show instructions functions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/process: Fix interleaved output in show_user_instructions() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/process: Fix sparse address space warnings (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Don't print kernel instructions in show_user_instructions() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Add show_user_instructions() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/lib: fix book3s/32 boot failure due to code patching (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Introduce functions for instruction equality (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Use a function for byte swapping instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Use a function for getting the instruction op code (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Use an accessor for instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc sstep: Add support for extswsli instruction (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: sstep: Add support for maddhd, maddhdu, maddld instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Use a macro for creating instructions from u32s (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/fsl: Add infrastructure to fixup branch predictor flush (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/smp: Use code patching to restore reset vector (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: sstep: Add tests for addcinstruction (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: sstep: Add tests for addinstruction (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: sstep: Add tests for compute type instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/sstep: Fix DS operand in ld encoding to appropriate value (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/fsl: Add barrier_nospec implementation for NXP PowerPC Book3E (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/watchpoint: Don't ignore extraneous exceptions blindly (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/watchpoint: Disable watchpoint hit by larx/stcx instructions (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/kgdb: add kgdb_arch_set/remove_breakpoint() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/hw_breakpoint: move instruction stepping out of hw_breakpoint_handler() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: add modify_instruction() and modify_instruction_site() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: Change calling convention for create_branch() et. al (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc: simplify patch_instruction_site() and patch_branch_site() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/code-patching: Add a helper to get the address of a patch_site (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/ftrace: Handle large kernel configs (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/32: use patch_site_addr() in machine_init() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/lib: Use patch_site to patch copy_32 functions once cache is enabled (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Use bitwise calculations in_breakpoint_table() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Move breakpoints to text section (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Move breakpoint instructions to own array (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/xmon: Remove store_inst() for patch_instruction() (Desnes Augusto Nunes do Rosario) [1854524]
- [powerpc] powerpc/powernv/idle: Exclude mfspr on HID1, 4, 5 on P9 and above (Steve Best) [1854539]
- [powerpc] powerpc/powernv/idle: Rename pnv_first_spr_loss_level variable (Steve Best) [1854539]
- [powerpc] powerpc/powernv/idle: Replace CPU feature check with PVR check (Steve Best) [1854539]
- [powerpc] powerpc/64s: Don't set FSCR bits in INIT_THREAD (Steve Best) [1854523]
- [powerpc] powerpc/64s: Save FSCR to init_task.thread.fscr after feature init (Steve Best) [1854523]
- [powerpc] powerpc/64s: Don't let DT CPU features set FSCR_DSCR (Steve Best) [1854523]
- [powerpc] powerpc/64s: Don't init FSCR_DSCR in __init_FSCR() (Steve Best) [1854523]

* Wed Oct 07 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.3.el8]
- [kernel] sched/cfs: change initial value of runnable_avg (Phil Auld) [1875995]
- [kernel] sched/fair: Fix runnable_avg for throttled cfs (Phil Auld) [1875995]
- [kernel] sched/fair: Fix kernel build warning in test_idle_cores() for !SMT NUMA (Phil Auld) [1875995]
- [kernel] sched/numa: Acquire RCU lock for checking idle cores during NUMA balancing (Phil Auld) [1875995]
- [kernel] sched/numa: Stop an exhastive search if a reasonable swap candidate or idle CPU is found (Phil Auld) [1875995]
- [kernel] sched/numa: Bias swapping tasks based on their preferred node (Phil Auld) [1875995]
- [kernel] sched/numa: Find an alternative idle CPU if the CPU is part of an active NUMA balance (Phil Auld) [1875995]
- [kernel] sched/numa: Prefer using an idle CPU as a migration target instead of comparing tasks (Phil Auld) [1875995]
- [kernel] sched/fair: Take into account runnable_avg to classify group (Phil Auld) [1875995]
- [kernel] sched/pelt: Add a new runnable average signal (Phil Auld) [1875995]
- [kernel] sched/pelt: Remove unused runnable load average (Phil Auld) [1875995]
- [kernel] sched: Disable allowing small imbalance to preserve RHEL performance (Phil Auld) [1875995]
- [kernel] sched/numa: Use similar logic to the load balancer for moving between domains with spare capacity (Phil Auld) [1875995]
- [kernel] sched/numa: Replace runnable_load_avg by load_avg (Phil Auld) [1875995]
- [kernel] sched/numa: Distinguish between the different task_numa_migrate() failure cases (Phil Auld) [1875995]
- [kernel] sched/numa: Trace when no candidate CPU was found on the preferred node (Phil Auld) [1875995]
- [kernel] sched/fair: Allow a small load imbalance between low utilisation SD_NUMA domains (Phil Auld) [1875995]
- [mm] powerpc/smp: Implement cpu_to_coregroup_id (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Create coregroup domain (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Allocate cpumask only after searching thread group (Diego Domingos) [1854541]
- [powerpc] powerpc/numa: Detect support for coregroup (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Optimize start_secondary (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Dont assume l2-cache to be superset of sibling (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Move topology fixups into a new function (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Move powerpc_topology above (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Merge Power9 topology with Power topology (Diego Domingos) [1854541]
- [powerpc] powerpc/smp: Fix a warning under !NEED_MULTIPLE_NODES (Diego Domingos) [1854541]
- [mm] powerpc/numa: Restrict possible nodes based on platform (Diego Domingos) [1854541]
- [mm] powerpc/numa: Limit possible nodes to within num_possible_nodes (Diego Domingos) [1854541]
- [powerpc] powerpc: Fix misleading small cores print (Diego Domingos) [1854541]
- [netdrv] ibmvnic: add missing parenthesis in do_reset() (Steve Best) [1879547]
- [wireless] rtw88: don't hold all IRQs disabled for PS operations (Jarod Wilson) [1874730]
- [netdrv] ibmvnic fix NULL tx_pools and rx_tools issue at do_reset (Steve Best) [1872676]

* Fri Oct 02 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.2.el8]
- [kernel] sched: Fix use of count for nr_running tracepoint (Phil Auld) [1861444]
- [kernel] sched: Add a tracepoint to track rq->nr_running (Phil Auld) [1861444]
- [kernel] sched/debug: Add new tracepoints to track util_est (Phil Auld) [1861444]
- [kernel] sched/debug: Export the newly added tracepoints (Phil Auld) [1861444]
- [kernel] sched/debug: Add sched_overutilized tracepoint (Phil Auld) [1861444]
- [kernel] sched/debug: Add new tracepoint to track PELT at se level (Phil Auld) [1861444]
- [kernel] sched/debug: Add a new sched_trace_*() helper functions (Phil Auld) [1861444]
- [kernel] sched/autogroup: Make autogroup_path() always available (Phil Auld) [1861444]

* Tue Sep 29 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-240.1.el8]
- [mm] mm/kmemleak.c: fix check for softirq context (Waiman Long) [1878006]
- [include] mm/hotplug: invalid PFNs from pfn_to_online_page() (Waiman Long) [1878006]
- [mm] mm, kmemleak: little optimization while scanning (Waiman Long) [1878006]
- [mm] kmemleak: add module param to print warnings to dmesg (Waiman Long) [1878006]
- [mm] kmemleak: always register debugfs file (Waiman Long) [1878006]
- [scsi] scsi: megaraid_sas: Don't call disable_irq from process IRQ poll (Tomas Henzl) [1837200]
- [scsi] scsi: megaraid_sas: Remove undefined ENABLE_IRQ_POLL macro (Tomas Henzl) [1837200]
- [platform] platform/x86: dcdbas: Check SMBIOS for protected buffer address (David Arcari) [1858680]
- [platform] firmware: dcdbas: Move dcdbas to drivers/platform/x86 (David Arcari) [1858680]
- [fs] cifs: fix DFS mount with cifsacl/modefromsid (Leif Sahlberg) [1871246]
- [fs] ext4: fix potential negative array index in do_split() (Pavel Reichl) [1846165] {CVE-2020-14314}
- [include] block: allow for_each_bvec to support zero len bvec (Ming Lei) [1872032]
- [nvme] nvme-pci: disable the write zeros command for Intel 600P/P3100 (David Milburn) [1875391]

* Wed Sep 23 2020 Jan Stancek <jstancek@redhat.com> [4.18.0-239.1.el8]
- [netdrv] ice: Disable VLAN pruning in promiscuous mode (Jonathan Toppins) [1787477]
- [mm] mm: slub: introduce 'slub_merge' kernel parameter (Rafael Aquini) [1871214]
- [kernel] time/tick-broadcast: Fix tick_broadcast_offline() lockdep complaint (Alexey Klimov) [1877380]

* Sat Sep 19 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-239.el8]
- [init] init/Kconfig: disable io_uring (Jeff Moyer) [1879754]
- [block] blk-mq: always allow reserved allocation in hctx_may_queue (Ming Lei) [1740874]
- [nvme] nvme-rdma: Avoid double freeing of async event data (Gopal Tiwari) [1878140]
- [kernel] printk: queue wake_up_klogd irq_work only if per-CPU areas are ready (Igor Mammedov) [1867022]

* Thu Sep 17 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-238.el8]
- [firmware] efi: don't reserve MOK config table memory region (Kairui Song) [1878584]
- [fs] xfs: fix boundary test in xfs_attr_shortform_verify (Eric Sandeen) [1875316] {CVE-2020-14385}
- [powerpc] powerpc/pseries: Do not initiate shutdown when system is running on UPS (Diego Domingos) [1870477]

* Tue Sep 15 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-237.el8]
- [fs] nfsd: avoid a NULL dereference in __cld_pipe_upcall() (Scott Mayhew) [1847225]
- [net] packet: fix overflow in tpacket_rcv (Hangbin Liu) [1876224] {CVE-2020-14386}
- [net] packet: make tp_drops atomic (Hangbin Liu) [1876224] {CVE-2020-14386}
- [net] espintcp: restore IP CB before handing the packet to xfrm (Sabrina Dubroca) [1868201]
- [fs] Revert "NFSv4: Handle NFS4ERR_OLD_STATEID in CLOSE/OPEN_DOWNGRADE" (Benjamin Coddington) [1865978]
- [fs] Revert "NFSv4.x recover from pre-mature loss of openstateid" (Benjamin Coddington) [1865978]
- [infiniband] RDMA/mlx4: Read pkey table length instead of hardcoded value (Alaa Hleihel) [1853564]
- [net] net/smc: set rx_off for SMCR explicitly (Philipp Rudo) [1875833]
- [drm] drm/i915: Auto detect DPCD backlight support by default (Lyude Paul) [1872381]
- [drm] drm/i915: Fix DPCD register order in intel_dp_aux_enable_backlight() (Lyude Paul) [1872381]
- [drm] drm/i915: Assume 100 brightness when not in DPCD control mode (Lyude Paul) [1872381]
- [drm] drm/i915: Fix eDP DPCD aux max backlight calculations (Lyude Paul) [1872381]
- [kernel] tracing: Define MCOUNT_INSN_SIZE when not defined without direct calls (Jiri Olsa) [1857599]
- [kernel] ftrace: Fix function_graph tracer interaction with BPF trampoline (Jiri Olsa) [1857599]
- [x86] x86/function_graph: Simplify with function_graph_enter() (Jiri Olsa) [1857599]
- [kernel] function_graph: Create function_graph_enter() to consolidate architecture code (Jiri Olsa) [1857599]

* Wed Sep 09 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-236.el8]
- [crypto] pefile: Support multiple signatures in verify_pefile_signature (Lenny Szubowicz) [1862072]
- [security] integrity: Load certs from the EFI MOK config table (Lenny Szubowicz) [1868306]
- [security] integrity: Move import of MokListRT certs to a separate routine (Lenny Szubowicz) [1868306]
- [firmware] efi: Support for MOK variable config table (Lenny Szubowicz) [1868306]
- [kernel] Move to dual-signing to split signing keys up better (Frantisek Hrbata) [1837434] {CVE-2020-10713}
- [powerpc] pseries/hotplug-cpu: wait indefinitely for vCPU death (Michael Roth) [1856588]
- [powerpc] kvm: ppc: book3s hv: Rework secure mem slot dropping (Michael Roth) [1851259]
- [powerpc] kvm: ppc: book3s hv: Move kvmppc_svm_page_out up (Michael Roth) [1851259]
- [powerpc] kvm: ppc: book3s hv: Migrate hot plugged memory (Michael Roth) [1851259]
- [powerpc] kvm: ppc: book3s hv: In H_SVM_INIT_DONE, migrate remaining normal-GFNs to secure-GFNs (Michael Roth) [1851259]
- [powerpc] kvm: ppc: book3s hv: Track the state GFNs associated with secure VMs (Michael Roth) [1851259]
- [powerpc] kvm: ppc: book3s hv: Disable page merging in H_SVM_INIT_START (Michael Roth) [1851259]
- [powerpc] kvm: ppc: book3s hv: Fix function definition in book3s_hv_uvmem.c (Michael Roth) [1851259]
- [kernel] mmap locking api: initial implementation as rwsem wrappers (Michael Roth) [1851259]
- [mm] handle multiple owners of device private pages in migrate_vma (Michael Roth) [1851259]
- [mm] migrate.c: clean up useless code in migrate_vma_collect_pmd() (Michael Roth) [1851259]
- [mm] remove the unused MIGRATE_PFN_DEVICE flag (Michael Roth) [1851259]
- [powerpc] rhel: powerpc: kvm: Increase HDEC threshold to enter guest (David Gibson) [1733467]
- [netdrv] r8152: Add macpassthru support for ThinkPad Thunderbolt 3 Dock Gen 2 (Michal Schmidt) [1851966]
- [fs] ceph: fix inode number handling on arches with 32-bit ino_t (Jeff Layton) [1869679]
- [fs] ceph: don't allow setlease on cephfs (Jeff Layton) [1872382]
- [block] blk-mq: order adding requests to hctx->dispatch and checking SCHED_RESTART (Ming Lei) [1859628]

* Thu Sep 03 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-235.el8]
- [s390] scsi: zfcp: Move allocation of the shost object to after xconf- and xport-data (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Fence early sysfs interfaces for accesses of shost objects (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Fence adapter status propagation for common statuses (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Move p-t-p port allocation to after xport data (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Fence fc_host updates during link-down handling (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Move fc_host updates during xport data handling into fenced function (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Move shost updates during xconfig data handling into fenced function (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Move shost modification after QDIO (re-)open into fenced function (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: fix fc_host attributes that should be unknown on local link down (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: wire previously driver-specific sysfs attributes also to fc_host (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: expose fabric name as common fc_host sysfs attribute (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: add diagnostics buffer for exchange config data (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: diagnostics buffer caching and use for exchange port data (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: signal incomplete or error for sync exchange config/port data (Claudio Imbrenda) [1872799]
- [s390] scsi: zfcp: Fix use-after-free in request timeout handlers (Claudio Imbrenda) [1872796]
- [tools] selftests/powerpc: Update the stack expansion test (Gustavo Duarte) [1869755]
- [mm] powerpc: Allow 4224 bytes of stack expansion for the signal frame (Gustavo Duarte) [1869755]
- [tools] selftests/powerpc: Add test of stack expansion logic (Gustavo Duarte) [1869755]
- [mm] mm: check that mm is still valid in madvise() (Jeff Moyer) [1874560]
- [block] block: virtio_blk: fix handling single range discard request (Ming Lei) [1842035]
- [block] block: respect queue limit of max discard segment (Ming Lei) [1842035]
- [fs] io_uring: Fix NULL pointer dereference in loop_rw_iter() (Jeff Moyer) [1854649]
- [fs] io_uring: return locked and pinned page accounting (Jeff Moyer) [1854649]
- [fs] io_uring: always allow drain/link/hardlink/async sqe flags (Jeff Moyer) [1854649]
- [fs] io_uring: ensure double poll additions work with both request types (Jeff Moyer) [1854649]
- [fs] io_uring: fix recvmsg memory leak with buffer selection (Jeff Moyer) [1854649]
- [fs] io_uring: fix missing msg_name assignment (Jeff Moyer) [1854649]
- [fs] io_uring: fix memleak in io_sqe_files_register() (Jeff Moyer) [1854649]
- [fs] io_uring: account user memory freed when exit has been queued (Jeff Moyer) [1854649]
- [fs] io_uring: fix memleak in __io_sqe_files_update() (Jeff Moyer) [1854649]
- [fs] io_uring: fix regression with always ignoring signals in io_cqring_wait() (Jeff Moyer) [1854649]
- [fs] io_uring: use signal based task_work running (Jeff Moyer) [1854649]
- [kernel] task_work: teach task_work_add() to do signal_wake_up() (Jeff Moyer) [1854649]
- [fs] io_uring: fix missing ->mm on exit (Jeff Moyer) [1854649]
- [fs] io_uring: fix potential use after free on fallback request free (Jeff Moyer) [1854649]
- [fs] io_uring: fix req->work corruption (Jeff Moyer) [1854649]
- [fs] io_uring: fix NULL-mm for linked reqs (Jeff Moyer) [1854649]
- [fs] io_uring: fix current->mm NULL dereference on exit (Jeff Moyer) [1854649]
- [fs] io_uring: fix hanging iopoll in case of -EAGAIN (Jeff Moyer) [1854649]
- [fs] io_uring: fix io_sq_thread no schedule when busy (Jeff Moyer) [1854649]
- [fs] io_uring: fix possible race condition against REQ_F_NEED_CLEANUP (Jeff Moyer) [1854649]
- [fs] io_uring: reap poll completions while waiting for refs to drop on exit (Jeff Moyer) [1854649]
- [fs] io_uring: acquire 'mm' for task_work for SQPOLL (Jeff Moyer) [1854649]
- [fs] io_uring: add memory barrier to synchronize io_kiocb's result and iopoll_completed (Jeff Moyer) [1854649]
- [fs] io_uring: don't fail links for EAGAIN error in IOPOLL mode (Jeff Moyer) [1854649]
- [fs] io_uring: fix io_kiocb.flags modification race in IOPOLL mode (Jeff Moyer) [1854649]
- [fs] io_uring: allow O_NONBLOCK async retry (Jeff Moyer) [1854649]
- [fs] io_uring: use kvfree() in io_sqe_buffer_register() (Jeff Moyer) [1854649]
- [fs] io_uring: validate the full range of provided buffers for access (Jeff Moyer) [1854649]
- [fs] io_uring: re-set iov base/len for buffer select retry (Jeff Moyer) [1854649]
- [fs] io_uring: fix {SQ, IO}POLL with unsupported opcodes (Jeff Moyer) [1854649]
- [fs] io_uring: disallow close of ring itself (Jeff Moyer) [1854649]
- [fs] io_uring: fix overflowed reqs cancellation (Jeff Moyer) [1854649]
- [fs] io_uring: fix flush req->refs underflow (Jeff Moyer) [1854649]
- [fs] io_uring: async task poll trigger cleanup (Jeff Moyer) [1854649]
- [fs] io_uring: allow POLL_ADD with double poll_wait() users (Jeff Moyer) [1854649]
- [fs] io_uring: remove 'fd is io_uring' from close path (Jeff Moyer) [1854649]
- [nvme] nvme: allow retry for requests with REQ_FAILFAST_TRANSPORT set (Mike Snitzer) [1843515]
- [nvme] nvme: decouple basic ANA log page re-read support from native multipathing (Mike Snitzer) [1843515]
- [nvme] nvme: update failover handling to work with REQ_FAILFAST_TRANSPORT (Mike Snitzer) [1843515]
- [nvme] nvme: Return BLK_STS_TARGET if the DNR bit is set (Mike Snitzer) [1843515]
- [nvme] nvme: redirect commands on dying queue (Mike Snitzer) [1843515]
- [nvme] nvme: just check the status code type in nvme_is_path_error (Mike Snitzer) [1843515]
- [nvme] nvme: refactor command completion (Mike Snitzer) [1843515]
- [nvme] nvme-multipath: do not reset on unknown status (Mike Snitzer) [1843515]
- [nvme] Revert "nvme: allow ANA support to be independent of native multipathing" (Mike Snitzer) [1843515]
- [nvme] Revert "nvme-multipath: do not reset on unknown status" (Mike Snitzer) [1843515]
- [mm] mm, THP, swap: fix allocating cluster for swapfile by mistake (Gao Xiang) [1855474]
- [net] sched: act_ct: Fix skb double-free in tcf_ct_handle_fragments() error flow (Marcelo Leitner) [1866391]
- [net] netfilter: conntrack: allow sctp hearbeat after connection re-use (Florian Westphal) [1865798]
- [video] vgacon: Fix for missing check in scrollback handling (Lyude Paul) [1859472] {CVE-2020-14331}
- [scsi] Revert "scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe during probe" (Nilesh Javali) [1866744]
- [scsi] Revert "scsi: qla2xxx: Fix crash on qla2x00_mailbox_command" (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Fix null pointer access during disconnect from subsystem (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Check if FW supports MQ before enabling (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Fix WARN_ON in qla_nvme_register_hba (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Allow ql2xextended_error_logging special value 1 to be set anytime (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Reduce noisy debug message (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Fix login timeout (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Flush I/O on zone disable (Nilesh Javali) [1866744]
- [scsi] scsi: qla2xxx: Flush all sessions on zone disable (Nilesh Javali) [1866744]
- [tools] bpf: selftests: global_funcs: Check err_str before strstr (Yauheni Kaliuta) [1873163]
- [netdrv] net/mlx5e: E-Switch, Specify flow_source for rule with no in_port (Alaa Hleihel) [1869602]
- [netdrv] net/mlx5e: E-Switch, Add misc bit when misc fields changed for mirroring (Alaa Hleihel) [1869602]
- [tools] selftests/bpf: test for map update access from within EXT programs (=?UTF-8?q?Toke=20H=C3=B8iland-J=C3=B8rgensen?=) [1871071]
- [tools] selftests/bpf: test for checking return code for the extended prog (=?UTF-8?q?Toke=20H=C3=B8iland-J=C3=B8rgensen?=) [1871071]
- [tools] selftests/bpf: Add test for freplace program with write access (=?UTF-8?q?Toke=20H=C3=B8iland-J=C3=B8rgensen?=) [1871071]
- [net] bpf: verifier: use target program's type for access verifications (=?UTF-8?q?Toke=20H=C3=B8iland-J=C3=B8rgensen?=) [1871071]
- [scsi] scsi: lpfc: Fix NVMe rport deregister and registration during ADISC (Dick Kennedy) [1871223]
- [scsi] scsi: lpfc: Fix LUN loss after cable pull (Dick Kennedy) [1871223]
- [infiniband] RDMA/bnxt_re: Do not add user qps to flushlist (Selvin Xavier) [1858674]
- [fs] NFSv4.0 allow nconnect for v4.0 (Benjamin Coddington) [1842746]
- [mm] mm/vunmap: add cond_resched() in vunmap_pmd_range (Rafael Aquini) [1871710]
- [s390] s390/bpf: Maintain 8-byte stack alignment (Jiri Olsa) [1871040]

* Thu Aug 20 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-234.el8]
- [netdrv] vrf: Fix IPv6 with qdisc and xfrm (Sabrina Dubroca) [1868565]
- [netdrv] vrf: make sure skb->data contains ip header to make routing (Sabrina Dubroca) [1868565]
- [netdrv] vrf: Check skb for XFRM_TRANSFORMED flag (Sabrina Dubroca) [1868565]
- [net] Do not clear the sock TX queue in sk_set_socket() (Andrea Claudi) [1850421]
- [net] Use RCU_INIT_POINTER() to set sk_wq (Andrea Claudi) [1850421]
- [net] netfilter: ip6tables: Add a .pre_exit hook in all ip6table_foo.c. (Florian Westphal) [1862384]
- [net] netfilter: iptables: Add a .pre_exit hook in all iptable_foo.c. (Florian Westphal) [1862384]
- [net] netfilter: ipset: Fix an error code in ip_set_sockfn_get() (Florian Westphal) [1862384]
- [net] netfilter: nft_set_rbtree: Don't account for expired elements on insertion (Florian Westphal) [1862384]
- [net] netfilter: nft_set_rbtree: Drop spurious condition for overlap detection on insertion (Florian Westphal) [1862384]
- [net] netfilter: nft_set_rbtree: Detect partial overlaps on insertion (Florian Westphal) [1862384]
- [net] netfilter: nft_set_rbtree: Introduce and use nft_rbtree_interval_start() (Florian Westphal) [1862384]
- [net] netfilter: nf_tables: fix nat hook table deletion (Florian Westphal) [1862384]
- [net] netfilter: ipset: call ip_set_free() instead of kfree() (Florian Westphal) [1862384]
- [net] netfilter: ip6tables: Split ip6t_unregister_table() into pre_exit and exit helpers. (Florian Westphal) [1862384]
- [net] netfilter: iptables: Split ipt_unregister_table() into pre_exit and exit helpers. (Florian Westphal) [1862384]
- [net] netfilter: nft_set_pipapo: Disable preemption before getting per-CPU pointer (Florian Westphal) [1862384]
- [net] netfilter: nft_nat: return EOPNOTSUPP if type or flags are not supported (Florian Westphal) [1862384]
- [net] netfilter: conntrack: comparison of unsigned in cthelper confirmation (Florian Westphal) [1862384]
- [net] netfilter: conntrack: refetch conntrack after nf_conntrack_update() (Florian Westphal) [1862384]
- [net] netfilter: conntrack: Pass value of ctinfo to __nf_conntrack_update (Florian Westphal) [1862384]
- [net] netfilter: conntrack: make conntrack userspace helpers work again (Florian Westphal) [1862384]
- [net] netfilter: nfnetlink_cthelper: unbreak userspace helper support (Florian Westphal) [1862384]
- [net] netfilter: nf_conntrack_pptp: fix compilation warning with W=1 build (Florian Westphal) [1862384]
- [net] netfilter: nf_conntrack_pptp: prevent buffer overflows in debug code (Florian Westphal) [1862384]
- [net] netfilter: nft_set_bitmap: initialize set element extension in lookups (Florian Westphal) [1862384]
- [net] netfilter: nft_fwd_netdev: validate family and chain type (Florian Westphal) [1862384]
- [net] netfilter: nft_payload: add missing attribute validation for payload csum flags (Florian Westphal) [1862384]
- [net] netfilter: cthelper: add missing attribute validation for cthelper (Florian Westphal) [1862384]
- [net] netfilter: ipset: Fix forceadd evaluation path (Florian Westphal) [1862384]
- [net] netfilter: bridge: make sure to pull arp header in br_nf_forward_arp() (Florian Westphal) [1862384]
- [net] netfilter: nft_set_rbtree: bogus lookup/get on consecutive elements in named sets (Florian Westphal) [1862384]
- [net] netfilter: ctnetlink: netns exit must wait for callbacks (Florian Westphal) [1862384]
- [arm64] kvm: arm64: Don't inherit exec permission across page-table levels (Andrew Jones) [1869297]
- [arm64] kvm: arm64: Flush the instruction cache if not unmapping the VM on reboot (Andrew Jones) [1869297]
- [s390] s390, dcssblk: kaddr and pfn can be NULL to ->direct_access() (Claudio Imbrenda) [1868927]
- [fs] chardev: Avoid potential use-after-free in 'chrdev_open()' (Vladis Dronov) [1866324] {CVE-2020-0305}
- [net] net: accept an empty mask in /sys/class/net/*/queues/rx-*/rps_cpus (Nitesh Narayan Lal) [1868433]
- [x86] Revert "x86/intel: Disable HPET on Intel Ice Lake platforms" (David Arcari) [1868405]
- [kernel] sched: Fix race against ptrace_freeze_trace() (Oleg Nesterov) [1862560]
- [kernel] sched: Fix loadavg accounting race (Oleg Nesterov) [1862560]
- [kernel] kernel/sched/: remove caller signal_pending branch predictions (Oleg Nesterov) [1862560]
- [kernel] locking/spinlock, sched/core: Clarify requirements for smp_mb__after_spinlock() (Oleg Nesterov) [1862560]
- [nvme] nvme: multipath: round-robin: eliminate "fallback" variable (Gopal Tiwari) [1868443]
- [nvme] nvme: multipath: round-robin: fix single non-optimized path case (Gopal Tiwari) [1868443]
- [nvme] nvme-multipath: do not fall back to __nvme_find_path() for non-optimized paths (Gopal Tiwari) [1868443]
- [nvme] nvme-multipath: fix logic for non-optimized paths (Gopal Tiwari) [1868443]
- [tools] selftests/bpf: Fix segmentation fault in test_progs (Yauheni Kaliuta) [1868494]
- [pci] hv: Fix a timing issue which causes kdump to fail occasionally (Mohammed Gamal) [1861960]
- [hv] hv: vmbus: Only notify Hyper-V for die events that are oops (Vitaly Kuznetsov) [1868131]
- [x86] kvm: nsvm: Correctly set the shadow NPT root level in its MMU role (Vitaly Kuznetsov) [1845507]
- [x86] kvm: x86: drop superfluous mmu_check_root() from fast_pgd_switch() (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: use nested_svm_load_cr3() on guest->host switch (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: implement nested_svm_load_cr3() and use it for host->guest switch (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: move kvm_set_cr3() after nested_svm_uninit_mmu_context() (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: introduce nested_svm_load_cr3()/nested_npt_enabled() (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: prepare to handle errors from enter_svm_guest_mode() (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: reset nested_run_pending upon nested_svm_vmrun_msrpm() failure (Vitaly Kuznetsov) [1845507]
- [x86] kvm: mmu: stop dereferencing vcpu->arch.mmu to get the context for MMU init (Vitaly Kuznetsov) [1845507]
- [x86] kvm: nsvm: split kvm_init_shadow_npt_mmu() from kvm_init_shadow_mmu() (Vitaly Kuznetsov) [1845507]
- [security] selinux: compute genfs symlink context in case of CephFS (Ondrej Mosnacek) [1865800]
- [fs] ceph: set sec_context xattr on symlink creation (Ondrej Mosnacek) [1861509]
- [tools] selftests: bpf: define SO_RCVTIMEO and SO_SNDTIMEO properly for ppc64le (Jiri Benc) [1860386]
- [tools] bpf: Sync RHEL version of asm-generic/socket.h to tools/ (Jiri Benc) [1860386]
- [tools] selftests: bpf: skip tests not working on RHEL (Jiri Benc) [1866908]
- [tools] Revert "selftests: bpf: disable test_lwt_seg6local" (Jiri Benc) [1866908]
- [tools] Revert "bpf: selftests: remove test_bpftool_build.sh from TEST_PROGS" (Jiri Benc) [1866908]
- [tools] selftests: add option to skip specific tests in RHEL (Jiri Benc) [1866908]
- [tools] selftests: bpf: switch off timeout (Jiri Benc) [1866908]
- [tools] selftest/firmware: Add selftest timeout in settings (Jiri Benc) [1866908]
- [tools] selftests/harness: Limit step counter reporting (Jiri Benc) [1866908]
- [tools] selftests/harness: Clean up kern-doc for fixtures (Jiri Benc) [1866908]
- [tools] selftests: fix condition in run_tests (Jiri Benc) [1866908]
- [tools] selftests: do not use .ONESHELL (Jiri Benc) [1866908]
- [tools] selftests/harness: Report skip reason (Jiri Benc) [1866908]
- [tools] selftests/harness: Display signed values correctly (Jiri Benc) [1866908]
- [tools] selftests/harness: Refactor XFAIL into SKIP (Jiri Benc) [1866908]
- [tools] selftests/harness: Switch to TAP output (Jiri Benc) [1866908]
- [tools] selftests: Add header documentation and helpers (Jiri Benc) [1866908]
- [tools] kselftest: fix TAP output for skipped tests (Jiri Benc) [1866908]
- [tools] kselftest: ksft_test_num return type should be unsigned (Jiri Benc) [1866908]
- [tools] selftests: introduce gen_tar Makefile target (Jiri Benc) [1866908]
- [tools] kselftest: add fixture variants (Jiri Benc) [1866908]
- [tools] kselftest: run tests by fixture (Jiri Benc) [1866908]
- [tools] kselftest: create fixture objects (Jiri Benc) [1866908]
- [tools] kselftest: factor out list manipulation to a helper (Jiri Benc) [1866908]
- [tools] selftests: add build/cross-build dependency check script (Jiri Benc) [1866908]
- [tools] kselftest/runner: allow to properly deliver signals to tests (Jiri Benc) [1866908]
- [tools] selftests/harness: fix spelling mistake "SIGARLM" -> "SIGALRM" (Jiri Benc) [1866908]
- [tools] selftests: enforce local header dependency in lib.mk (Jiri Benc) [1866908]
- [tools] selftests/harness: Handle timeouts cleanly (Jiri Benc) [1866908]
- [tools] selftests/harness: Move test child waiting logic (Jiri Benc) [1866908]
- [tools] selftests: Fix kselftest O=objdir build from cluttering top level objdir (Jiri Benc) [1866908]
- [tools] selftests: allow detection of build failures (Jiri Benc) [1866908]
- [tools] selftests: fix build behaviour on targets' failures (Jiri Benc) [1866908]
- [tools] kselftest: Support old perl versions (Jiri Benc) [1866908]
- [tools] kselftest/runner: Print new line in print of timeout log (Jiri Benc) [1866908]
- [tools] selftests: Fix dangling documentation references to kselftest_module.sh (Jiri Benc) [1866908]
- [tools] kselftest: Fix NULL INSTALL_PATH for TARGETS runlist (Jiri Benc) [1866908]
- [tools] selftests: Move kselftest_module.sh into kselftest/ (Jiri Benc) [1866908]
- [tools] selftests: gen_kselftest_tar.sh: Do not clobber kselftest/ (Jiri Benc) [1866908]
- [tools] selftests/kselftest/runner.sh: Add 45 second timeout per test (Jiri Benc) [1866908]
- [tools] kselftest: exclude failed TARGETS from runlist (Jiri Benc) [1866908]
- [tools] kselftest: add capability to skip chosen TARGETS (Jiri Benc) [1866908]
- [tools] selftests: Add kselftest-all and kselftest-install targets (Jiri Benc) [1866908]
- [tools] selftests: use "$(MAKE)" instead of "make" (Jiri Benc) [1866908]
- [tools] kselftest: save-and-restore errno to allow for m formatting (Jiri Benc) [1866908]
- [tools] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 481 (Jiri Benc) [1866908]
- [tools] selftests/harness: Allow test to configure timeout (Jiri Benc) [1866908]
- [tools] selftests: avoid KBUILD_OUTPUT dir cluttering with selftest objects (Jiri Benc) [1866908]
- [tools] selftests: fix bpf build/test workflow regression when KBUILD_OUTPUT is set (Jiri Benc) [1866908]
- [tools] selftests: fix install target to use default install path (Jiri Benc) [1866908]
- [tools] selftests: build and run gpio when output directory is the src dir (Jiri Benc) [1866908]
- [documentation] doc: kselftest: Fix KBUILD_OUTPUT usage instructions (Jiri Benc) [1866908]
- [tools] selftests: fix headers_install circular dependency (Jiri Benc) [1866908]
- [tools] selftests/harness: Add 30 second timeout per test (Jiri Benc) [1866908]
- [tools] kselftest: Add test module framework header (Jiri Benc) [1866908]
- [tools] kselftest: Add test runner creation script (Jiri Benc) [1866908]
- [tools] selftests/harness: Update named initializer syntax (Jiri Benc) [1866908]
- [tools] selftest: include stdio.h in kselftest.h (Jiri Benc) [1866908]
- [tools] selftests: do not macro-expand failed assertion expressions (Jiri Benc) [1866908]
- [documentation] Documentation/dev-tools: clean up kselftest.rst (Jiri Benc) [1866908]
- [documentation] doc: dev-tools: kselftest.rst: update config file location (Jiri Benc) [1866908]
- [documentation] doc: dev-tools: kselftest.rst: update contributing new tests (Jiri Benc) [1866908]

* Tue Aug 18 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-233.el8]
- [fs] nfs: ensure correct writeback errors are returned on close() (Scott Mayhew) [1849424]
- [netdrv] net: thunderx: use spin_lock_bh in nicvf_set_rx_mode_task() (Dean Nelson) [1824858]
- [crypto] crypto: ecc - SP800-56A rev 3 local public key validation (Herbert Xu) [1855817]
- [crypto] crypto: dh - SP800-56A rev 3 local public key validation (Herbert Xu) [1855817]
- [crypto] crypto: dh - check validity of Z before export (Herbert Xu) [1855817]
- [lib] lib/mpi: Add mpi_sub_ui() (Herbert Xu) [1855817]
- [crypto] crypto: ecdh - check validity of Z before export (Herbert Xu) [1855817]
- [netdrv] net: thunderx: initialize VF's mailbox mutex before first usage (Dean Nelson) [1866827]
- [kernel] timers: Lower base clock forwarding threshold (Phil Auld) [1833096]
- [kernel] timers: Remove must_forward_clk (Phil Auld) [1833096]
- [kernel] timers: Spare timer softirq until next expiry (Phil Auld) [1833096]
- [kernel] timers: Expand clk forward logic beyond nohz (Phil Auld) [1833096]
- [kernel] timers: Reuse next expiry cache after nohz exit (Phil Auld) [1833096]
- [kernel] timers: Always keep track of next expiry (Phil Auld) [1833096]
- [kernel] timers: Optimize _next_timer_interrupt() level iteration (Phil Auld) [1833096]
- [kernel] timers: Add comments about calc_index() ceiling work (Phil Auld) [1833096]
- [kernel] timers: Move trigger_dyntick_cpu() to enqueue_timer() (Phil Auld) [1833096]
- [kernel] timers: Use only bucket expiry for base->next_expiry value (Phil Auld) [1833096]
- [kernel] timers: Preserve higher bits of expiration on index calculation (Phil Auld) [1833096]
- [kernel] timer: Fix wheel index calculation on last level (Phil Auld) [1833096]
- [kernel] timer: Prevent base->clk from moving backward (Phil Auld) [1833096]
- [kernel] timer: Read jiffies once when forwarding base clk (Phil Auld) [1833096]
- [powerpc] powerpc/64: Update Speculation_Store_Bypass in /proc/<pid>/status (Gustavo Duarte) [1773868]
- [scsi] scsi: virtio-scsi: Correctly handle the case where all LUNs are unplugged (Maxim Levitsky) [1756093]
- [kvm] kvm: x86: replace kvm_spec_ctrl_test_value with runtime test on the host (Maxim Levitsky) [1853447]
- [kvm] x86/kvm: Move context tracking where it belongs (Nitesh Narayan Lal) [1854011]
- [scsi] scsi: megaraid_sas: Clear affinity hint (Tomas Henzl) [1828351]
- [netdrv] revert "vxlan: fix tos value before xmit" (Andrea Claudi) [1862166]
- [net] udp: Copy has_conns in reuseport_grow(). (Marcelo Leitner) [1867160]
- [net] dev: Defer free of skbs in flush_backlog (Marcelo Leitner) [1867160]
- [include] net: core: reduce recursion limit value (Marcelo Leitner) [1867160]
- [netdrv] pppoe: only process PADT targeted at local interfaces (Andrea Claudi) [1866850]
- [net] espintcp: count packets dropped in espintcp_rcv (Sabrina Dubroca) [1866393]
- [net] espintcp: handle short messages instead of breaking the encap socket (Sabrina Dubroca) [1866393]
- [net] espintcp: recv() should return 0 when the peer socket is closed (Sabrina Dubroca) [1866393]
- [net] espintcp: support non-blocking sends (Sabrina Dubroca) [1866393]
- [net] mptcp: be careful on subflow creation (Davide Caratti) [1862200]
- [net] mptcp: fix bogus sendmsg() return code under pressure (Davide Caratti) [1862200]
- [net] mptcp: fix joined subflows with unblocking sk (Davide Caratti) [1862200]
- [net] subflow: explicitly check for plain tcp rsk (Davide Caratti) [1862200]
- [net] mptcp: silence warning in subflow_data_ready() (Davide Caratti) [1862200]
- [net] mptcp: fix race in subflow_data_ready() (Davide Caratti) [1862200]
- [net] mptcp: fix memory leak in mptcp_subflow_create_socket() (Davide Caratti) [1862200]
- [net] mptcp: don't leak msk in token container (Davide Caratti) [1862200]
- [net] ipv4: Silence suspicious RCU usage warning (Guillaume Nault) [1866430]
- [net] devinet: fix memleak in inetdev_init() (Guillaume Nault) [1866430]
- [net] ipip: fix wrong address family in init error path (Guillaume Nault) [1866430]
- [net] inet_csk: Fix so_reuseport bind-address cache in tb->fast* (Guillaume Nault) [1866430]
- [net] ipmr: Add lockdep expression to ipmr_for_each_table macro (Guillaume Nault) [1866430]
- [net] ipmr: Fix RCU list debugging warning (Guillaume Nault) [1866430]
- [net] tcp: make sure listeners don't initialize congestion-control state (Paolo Abeni) [1865904]
- [net] sched: The error lable position is corrected in ct_init_module (Davide Caratti) [1865890]
- [net] sched: cls_api: fix nooffloaddevcnt warning dmesg log (Davide Caratti) [1865890]
- [net] tls: fix race condition causing kernel panic (Sabrina Dubroca) [1861756]
- [net] tls: free record only on encryption error (Sabrina Dubroca) [1861756]
- [net] tls: fix encryption error checking (Sabrina Dubroca) [1861756]
- [net] l2tp: add sk_family checks to l2tp_validate_socket (Guillaume Nault) [1861453]
- [net] l2tp: do not use inet_hash()/inet_unhash() (Guillaume Nault) [1861453]
- [net] tipc: allow to build NACK message in link timeout function (Xin Long) [1860877]
- [net] tipc: fix retransmission on unicast links (Xin Long) [1860877]
- [net] tipc: fix NULL pointer dereference in tipc_disc_rcv() (Xin Long) [1860877]
- [net] tipc: remove set but not used variable 'prev' (Xin Long) [1860877]
- [net] tipc: call tsk_set_importance from tipc_topsrv_create_listener (Xin Long) [1860877]
- [net] tipc: add support for broadcast rcv stats dumping (Xin Long) [1860877]
- [net] tipc: enable broadcast retrans via unicast (Xin Long) [1860877]
- [net] tipc: add back link trace events (Xin Long) [1860877]
- [net] tipc: introduce Gap ACK blocks for broadcast link (Xin Long) [1860877]
- [net] tipc: block BH before using dst_cache (Xin Long) [1860877]
- [net] tipc: fix partial topology connection closure (Xin Long) [1860877]
- [net] xfrm: policy: match with both mark and mask on user interfaces (Xin Long) [1854116]
- [scsi] scsi: dh: Add Fujitsu device to devinfo and dh lists (Ewan Milne) [1861418]
- [x86] kvm: Set KVM_SOFT_MAX_VCPUS to 1024 (Eduardo Habkost) [1856996]
- [md] dm integrity: fix integrity recalculation that is improperly skipped (Mike Snitzer) [1860160]
- [netdrv] ibmvnic: Fix IRQ mapping disposal in error path (Steve Best) [1867498]
- [infiniband] IB/hfi1: Do not destroy link_wq when the device is shut down (Kamal Heib) [1858392]
- [infiniband] IB/hfi1: Do not destroy hfi1_wq when the device is shut down (Kamal Heib) [1858392]
- [netdrv] Revert "net/broadcom: Clean broadcom code from driver versions" (Jonathan Toppins) [1867146]
- [net] devmap: Use bpf_map_area_alloc() for allocating hash buckets (Jiri Benc) [1842380]
- [kernel] kexec_file: Correctly output debugging information for the PT_LOAD ELF header (Lianbo Jiang) [1861186]
- [kernel] kexec: Improve & fix crash_exclude_mem_range() to handle overlapping ranges (Lianbo Jiang) [1861186]
- [x86] x86/crash: Correct the address boundary of function parameters (Lianbo Jiang) [1861186]
- [fs] ceph: handle zero-length feature mask in session messages (Jeff Layton) [1866018]
- [s390] s390/bpf: Tolerate not converging code shrinking (Yauheni Kaliuta) [1857120]
- [s390] s390/bpf: Use brcl for jumping to exit_ip if necessary (Yauheni Kaliuta) [1857120]
- [s390] s390/bpf: Fix sign extension in branch_ku (Yauheni Kaliuta) [1857120]
- [tools] selftests: bpf: test_kmod.sh: Fix running out of srctree (Yauheni Kaliuta) [1857120]
- [lib] bpf: revert "test_bpf: Flag tests that cannot be jited on s390" (Yauheni Kaliuta) [1857120]
- [kernel] uprobes: ensure that uprobe->offset and ->ref_ctr_offset are properly aligned (Oleg Nesterov) [1848596]

* Mon Aug 10 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-232.el8]
- [fs] nfs: nfs_file_write() should check for writeback errors (Scott Mayhew) [1852788]
- [s390] s390/cpum_cf, perf: change DFLT_CCERROR counter name (Philipp Rudo) [1865794]
- [net] net/smc: unique reason code for exceeded max dmb count (Philipp Rudo) [1865792]
- [s390] s390/ism: indicate correct error reason in ism_alloc_dmb() (Philipp Rudo) [1865792]
- [net] net/smc: fix dmb buffer shortage (Philipp Rudo) [1865792]
- [net] net/smc: put slot when connection is killed (Philipp Rudo) [1865792]
- [net] net/smc: fix restoring of fallback changes (Philipp Rudo) [1865792]
- [net] net/smc: remove freed buffer from list (Philipp Rudo) [1865792]
- [net] net/smc: do not call dma sync for unmapped memory (Philipp Rudo) [1865792]
- [net] net/smc: fix handling of delete link requests (Philipp Rudo) [1865792]
- [net] net/smc: move add link processing for new device into llc layer (Philipp Rudo) [1865792]
- [net] net/smc: drop out-of-flow llc response messages (Philipp Rudo) [1865792]
- [net] net/smc: protect smc ib device initialization (Philipp Rudo) [1865792]
- [net] net/smc: fix link lookup for new rdma connections (Philipp Rudo) [1865792]
- [net] net/smc: clear link during SMC client link down processing (Philipp Rudo) [1865792]
- [net] net/smc: handle unexpected response types for confirm link (Philipp Rudo) [1865792]
- [net] net/smc: switch smcd_dev_list spinlock to mutex (Philipp Rudo) [1865792]
- [net] net/smc: fix sleep bug in smc_pnet_find_roce_resource() (Philipp Rudo) [1865792]
- [net] net/smc: fix work request handling (Philipp Rudo) [1865792]
- [net] net/smc: separate LLC wait queues for flow and messages (Philipp Rudo) [1865792]
- [net] net/smc: pre-fetch send buffer outside of send_lock (Philipp Rudo) [1865792]
- [nvme] nvme-fc: set max_segments to lldd max value (Ewan Milne) [1853181]
- [powerpc] ppc64/kexec_file: enable early kernel's OPAL calls (Diego Domingos) [1829715]
- [powerpc] ppc64/kexec_file: fix kexec load failure with lack of memory hole (Diego Domingos) [1829715]
- [powerpc] ppc64/kexec_file: add appropriate regions for memory reserve map (Diego Domingos) [1829715]
- [powerpc] ppc64/kexec_file: prepare elfcore header for crashing kernel (Diego Domingos) [1829715]
- [powerpc] ppc64/kexec_file: setup backup region for kdump kernel (Diego Domingos) [1829715]
- [powerpc] ppc64/kexec_file: restrict memory usage of kdump kernel (Diego Domingos) [1829715]
- [mm] powerpc/drmem: make lmb walk a bit more flexible (Diego Domingos) [1829715]
- [powerpc] ppc64/kexec_file: avoid stomping memory used by special regions (Diego Domingos) [1829715]
- [powerpc] powerpc/kexec_file: add helper functions for getting memory ranges (Diego Domingos) [1829715]
- [powerpc] powerpc/kexec_file: mark PPC64 specific code (Diego Domingos) [1829715]
- [kernel] kexec_file: allow archs to handle special regions while locating memory hole (Diego Domingos) [1829715]
- [netdrv] net/mlx5e: CT: Support restore ipv6 tunnel (Alaa Hleihel) [1862975]
- [netdrv] ionic: unlock queue mutex in error path (Jonathan Toppins) [1854270]
- [netdrv] ionic: use mutex to protect queue operations (Jonathan Toppins) [1854270]
- [net] xfrm: esp6: fix the location of the transport header with encapsulation (Sabrina Dubroca) [1857653]
- [net] ipv4: fill fl4_icmp_{type, code} in ping_v4_sendmsg (Sabrina Dubroca) [1861324]
- [netdrv] geneve: fix an uninitialized value in geneve_changelink() (Sabrina Dubroca) [1860945]
- [net] ip_tunnel: fix use-after-free in ip_tunnel_lookup() (Sabrina Dubroca) [1860945]
- [netdrv] vxlan: Avoid infinite loop when suppressing NS messages with invalid options (Sabrina Dubroca) [1860945]
- [tools] selftests: mptcp: capture pcap on both sides (Hangbin Liu) [1859880]
- [tools] selftests/net: report etf errors correctly (Hangbin Liu) [1859880]
- [tools] selftests: net: ip_defrag: ignore EPERM (Hangbin Liu) [1859880]
- [tools] selftests: forwarding: pedit_dsfield: Check counter value (Hangbin Liu) [1859880]
- [tools] selftests: net: tcp_mmap: fix SO_RCVLOWAT setting (Hangbin Liu) [1859880]
- [tools] selftests: net: tcp_mmap: clear whole tcp_zerocopy_receive struct (Hangbin Liu) [1859880]
- [tools] selftests: A few improvements to fib_nexthops.sh (Hangbin Liu) [1859880]
- [tools] selftests: Add tests for vrf and xfrms (Hangbin Liu) [1859880]
- [tools] selftests: pmtu: implement IPIP, SIT and ip6tnl PMTU discovery tests (Hangbin Liu) [1859880]
- [tools] selftests/net/forwarding: define libs as TEST_PROGS_EXTENDED (Hangbin Liu) [1859880]
- [tools] selftests/net/forwarding: add Makefile to install tests (Hangbin Liu) [1859880]
- [tools] selftests: nft_concat_range: Move option for 'list ruleset' before command (Hangbin Liu) [1859880]
- [tools] selftests: netfilter: use randomized netns names (Hangbin Liu) [1859880]
- [tools] kselftests: netfilter: fix leftover net/net-next merge conflict (Hangbin Liu) [1859880]
- [tools] selftests: netfilter: missing error check when setting up veth interface (Hangbin Liu) [1859880]
- [net] sctp: Don't advertise IPv4 addresses if ipv6only is set on the socket (Xin Long) [1860673]
- [net] sctp: check assoc before SCTP_ADDR_{MADE_PRIM, ADDED} event (Xin Long) [1860673]
- [net] sctp: fix typo sctp_ulpevent_nofity_peer_addr_change (Xin Long) [1860673]
- [net] sctp: Fix spelling in Kconfig help (Xin Long) [1860673]
- [net] sctp: Start shutdown on association restart if in SHUTDOWN-SENT state and socket is closed (Xin Long) [1860673]
- [net] sctp: Don't add the shutdown timer if its already been added (Xin Long) [1860673]
- [net] sctp: Fix SHUTDOWN CTSN Ack in the peer restart case (Xin Long) [1860673]
- [net] sctp: Fix bundling of SHUTDOWN with COOKIE-ACK (Xin Long) [1860673]
- [net] ip6_vti: use IS_REACHABLE to avoid some compile errors (Xin Long) [1840976 1835075]
- [net] xfrm: interface: use IS_REACHABLE to avoid some compile errors (Xin Long) [1840976 1835075]
- [net] xfrm: interface: not xfrmi_ipv6/ipip_handler twice (Xin Long) [1840976 1835075]
- [net] ip6_vti: not register vti_ipv6_handler twice (Xin Long) [1840976 1835075]
- [net] ip_vti: not register vti_ipip_handler twice (Xin Long) [1840976 1835075]
- [net] xfrm: interface: support IPIP and IPIP6 tunnels processing with .cb_handler (Xin Long) [1840976 1835075]
- [net] xfrm: interface: support IP6IP6 and IP6IP tunnels processing with .cb_handler (Xin Long) [1840976 1835075]
- [net] ipcomp: assign if_id to child tunnel from parent tunnel (Xin Long) [1840976 1835075]
- [net] ip6_vti: support IP6IP tunnel processing (Xin Long) [1840976 1835075]
- [net] ip6_vti: support IP6IP6 tunnel processing with .cb_handler (Xin Long) [1840976 1835075]
- [net] ip_vti: support IPIP6 tunnel processing (Xin Long) [1840976 1835075]
- [net] ip_vti: support IPIP tunnel processing with .cb_handler (Xin Long) [1840976 1835075]
- [net] tunnel6: add tunnel6_input_afinfo for ipip and ipv6 tunnels (Xin Long) [1840976 1835075]
- [net] tunnel4: add cb_handler to struct xfrm_tunnel (Xin Long) [1840976 1835075]
- [net] xfrm: add is_ipip to struct xfrm_input_afinfo (Xin Long) [1840976 1835075]
- [net] tunnel6: support for IPPROTO_MPLS (Xin Long) [1840976 1835075]
- [net] virtio_vsock: Enhance connection semantics (Stefano Garzarella) [1861735]
- [net] virtio_vsock: Fix race condition in virtio_transport_recv_pkt (Stefano Garzarella) [1858135]
- [net] vsock/virtio: annotate 'the_virtio_vsock' RCU pointer (Stefano Garzarella) [1861762]
- [vhost] vsock/virtio: fix multiple packet delivery to monitoring devices (Stefano Garzarella) [1861762]
- [vhost] vsock: fix packet delivery order to monitoring devices (Stefano Garzarella) [1861762]
- [vhost] vsock: accept only packets with the right dst_cid (Stefano Garzarella) [1861762]
- [vhost] vsock: refuse CID assigned to the guest->host transport (Stefano Garzarella) [1861762]
- [vhost] vsock: switch to a mutex for vhost_vsock_hash (Stefano Garzarella) [1861762]
- [net] vsock: fix timeout in vsock_accept() (Stefano Garzarella) [1861762]
- [net] vsock: Simplify '__vsock_release()' (Stefano Garzarella) [1861762]
- [netdrv] net/mlx5e: Fix kernel crash when setting vf VLANID on a VF dev (Alaa Hleihel) [1859477]
- [netdrv] net/mlx5e: Modify uplink state on interface up/down (Alaa Hleihel) [1861720 1859477]
- [netdrv] net/mlx5e: Fix missing cleanup of ethtool steering during rep rx cleanup (Alaa Hleihel) [1859477 1856660]
- [netdrv] ixgbe: Add ethtool support to enable 2.5 and 5.0 Gbps support (Ken Cox) [1835962]
- [x86] x86/purgatory: Add -fno-stack-protector (Lianbo Jiang) [1857528]
- [x86] x86/purgatory: Fail the build if purgatory.ro has missing symbols (Lianbo Jiang) [1857528]
- [x86] x86/purgatory: Do not use __builtin_memcpy and __builtin_memset (Lianbo Jiang) [1857528]
- [x86] x86/boot: Provide KASAN compatible aliases for string routines (Lianbo Jiang) [1857528]
- [x86] x86/purgatory: Disable various profiling and sanitizing options (Lianbo Jiang) [1857528]
- [x86] x86/boot: Restrict header scope to make Clang happy (Lianbo Jiang) [1857528]

* Wed Aug 05 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-231.el8]
- [x86] x86/entry/64: Update comments and sanity tests for create_gap (Jiri Olsa) [1850831]
- [x86] x86/alternatives: add missing insn.h include (Jiri Olsa) [1850831]
- [x86] x86/alternatives: Teach text_poke_bp() to emulate instructions (Jiri Olsa) [1850831]
- [x86] x86/paravirt: Standardize 'insn_buff' variable names (Jiri Olsa) [1850831]
- [x86] x86_64: Allow breakpoints to emulate call instructions (Jiri Olsa) [1850831]
- [x86] x86_64: Add gap to int3 to allow for call emulation (Jiri Olsa) [1850831]
- [x86] x86/alternatives: Sync bp_patching update for avoiding NULL pointer exception (Jiri Olsa) [1850831]
- [nvme] nvme: add a Identify Namespace Identification Descriptor list quirk (Gopal Tiwari) [1862136]
- [nvme] nvme: fix identify error status silent ignore (Gopal Tiwari) [1862136]
- [nvme] nvme: fix possible hang when ns scanning fails during error recovery (Gopal Tiwari) [1862136]
- [nvme] nvme: refactor nvme_identify_ns_descs error handling (Gopal Tiwari) [1862136]
- [infiniband] IB/rdmavt: Fix RQ counting issues causing use of an invalid RWQE (Kamal Heib) [1850314]
- [powerpc] powerpc/pseries: PCIE PHB reset (Steve Best) [1747345]
- [drm] drm/nouveau/kms: Handle -EINPROGRESS in nouveau_display_acpi_ntfy() (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms: Fix runtime PM leak in nouveau_display_acpi_ntfy() (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms: Invert conditionals in nouveau_display_acpi_ntfy() (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms: Use pm_runtime_put_autosuspend() in hpd_work (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms/fbcon: Use pm_runtime_put_autosuspend() in suspend work (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms/fbcon: Fix pm_runtime calls in nouveau_fbcon_output_poll_changed() (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms/fbcon: Correct pm_runtime calls in nouveau_fbcon_release() (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms: Fix rpm leak in nouveau_connector_hotplug() (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms: Handle -EINPROGRESS in nouveau_connector_hotplug() (Lyude Paul) [1827812]
- [drm] drm/nouveau/fbcon: fix module unload when fbcon init has failed for some reason (Lyude Paul) [1827812]
- [drm] drm/nouveau/kms/tu102: wait for core update to complete when assigning windows (Lyude Paul) [1827812]
- [drm] drm/nouveau/disp/gm200-: fix regression from HDA SOR selection changes (Lyude Paul) [1827812]
- [drm] drm/amd/powerplay: fix a crash when overclocking Vega M (Lyude Paul) [1827812]
- [drm] drm/amdgpu: Fix NULL dereference in dpm sysfs handlers (Lyude Paul) [1827812]
- [drm] drm/amdgpu: fix preemption unit test (Lyude Paul) [1827812]
- [drm] drm/amdgpu/gfx10: fix race condition for kiq (Lyude Paul) [1827812]
- [drm] drm/amd/display: add dmcub check on RENOIR (Lyude Paul) [1827812]
- [drm] drm/amd/display: Check DMCU Exists Before Loading (Lyude Paul) [1827812]
- [drm] drm/nouveau/nouveau: fix page fault on device private memory (Lyude Paul) [1827812]
- [drm] drm/nouveau/i2c/g94-: increase NV_PMGR_DP_AUXCTL_TRANSACTREQ timeout (Lyude Paul) [1827812]
- [drm] drm/i915/perf: Use GTT when saving/restoring engine GPR (Lyude Paul) [1827812]
- [drm] drm/i915/gvt: Fix two CFL MMIO handling caused by regression (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Only swap to a random sibling once upon creation (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Ignore irq enabling on the virtual engines (Lyude Paul) [1827812]
- [drm] drm/i915: Move cec_notifier to intel_hdmi_connector_unregister, v2 (Lyude Paul) [1827812]
- [drm] drm/amdgpu/display: create fake mst encoders ahead of time (v4) (Lyude Paul) [1827812]
- [drm] drm/amd/display: handle failed allocation during stream construction (Lyude Paul) [1827812]
- [drm] drm/amdgpu/sdma5: fix wptr overwritten in ->get_wptr() (Lyude Paul) [1827812]
- [drm] drm/amdgpu/powerplay: Modify SMC message name for setting power profile mode (Lyude Paul) [1827812]
- [drm] drm/i915: Also drop vm.ref along error paths for vma construction (Lyude Paul) [1827812]
- [drm] drm/i915: Drop vm.ref for duplicate vma on construction (Lyude Paul) [1827812]
- [drm] drm/amdgpu: asd function needs to be unloaded in suspend phase (Lyude Paul) [1827812]
- [drm] drm/amdgpu: add TMR destory function for psp (Lyude Paul) [1827812]
- [drm] drm/amdgpu: don't do soft recovery if gpu_recovery=0 (Lyude Paul) [1827812]
- [drm] drm/i915: Skip stale object handle for debugfs per-file-stats (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Pin the rings before marking active (Lyude Paul) [1827812]
- [drm] drm/radeon: fix double free (Lyude Paul) [1827812]
- [drm] drm: panel-orientation-quirks: Use generic orientation-data for Acer S1003 (Lyude Paul) [1827812]
- [drm] drm: panel-orientation-quirks: Add quirk for Asus T101HA panel (Lyude Paul) [1827812]
- [iommu] iommu/vt-d: Don't apply gfx quirks to untrusted devices (Lyude Paul) [1827812]
- [drm] drm/tegra: hub: Do not enable orphaned window group (Lyude Paul) [1827812]
- [drm] drm/ttm: Fix dma_fence refcnt leak when adding move fence (Lyude Paul) [1827812]
- [drm] drm/ttm: Fix dma_fence refcnt leak in ttm_bo_vm_fault_reserved (Lyude Paul) [1827812]
- [drm] drm/amdgpu/atomfirmware: fix vram_info fetching for renoir (Lyude Paul) [1827812]
- [drm] drm/amdgpu: use u rather than d for sclk/mclk (Lyude Paul) [1827812]
- [drm] drm/amd/display: Only revalidate bandwidth on medium and fast updates (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Mark timeline->cacheline as destroyed after rcu grace period (Lyude Paul) [1827812]
- [drm] drm/amd/display: Fix ineffective setting of max bpc property (Lyude Paul) [1827812]
- [drm] drm/amd/display: Fix incorrectly pruned modes with deep color (Lyude Paul) [1827812]
- [drm] drm/amdgpu: add fw release for sdma v5_0 (Lyude Paul) [1827812]
- [drm] drm/radeon: fix fb_div check in ni_init_smc_spll_table() (Lyude Paul) [1827812]
- [drm] drm/amd: fix potential memleak in err branch (Lyude Paul) [1827812]
- [drm] drm/amd/display: Enable output_bpc property on all outputs (Lyude Paul) [1827812]
- [drm] drm/amd/display: Use kfree() to free rgb_user in calculate_user_regamma_ramp() (Lyude Paul) [1827812]
- [drm] Revert "drm/amd/display: disable dcn20 abm feature for bring up" (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Move gen4 GT workarounds from init_clock_gating to workarounds (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Move vlv GT workarounds from init_clock_gating to workarounds (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Move ilk GT workarounds from init_clock_gating to workarounds (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Move snb GT workarounds from init_clock_gating to workarounds (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Move ivb GT workarounds from init_clock_gating to workarounds (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Move hsw GT workarounds from init_clock_gating to workarounds (Lyude Paul) [1827812]
- [drm] drm/i915/gt: Incrementally check for rewinding (Lyude Paul) [1827812]
- [drm] drm/i915/tc: fix the reset of ln0 (Lyude Paul) [1827812]
- [drm] drm/i915/icl+: Fix hotplug interrupt disabling after storm detection (Lyude Paul) [1827812]
- [drm] drm/amd/display: Use kvfree() to free coeff in build_regamma() (Lyude Paul) [1827812]
- [drm] drm/amdkfd: Use correct major in devcgroup check (Lyude Paul) [1827812]
- [drm] drm/connector: notify userspace on hotplug after register complete (Lyude Paul) [1827812]
- [drm] drm/i915: Whitelist context-local timestamp in the gen9 cmdparser (Lyude Paul) [1827812]
- [drm] drm/i915/gem: Avoid iterating an empty list (Lyude Paul) [1827812]
- [drm] drm/i915: Fix AUX power domain toggling across TypeC mode resets (Lyude Paul) [1827812]
- [drm] drm/dp_mst: Increase ACT retry timeout to 3s (Lyude Paul) [1827812]
- [drm] drm/ast: Don't check new mode if CRTC is being disabled (Lyude Paul) [1827812]
- [drm] drm/amdgpu: Replace invalid device ID with a valid device ID (Lyude Paul) [1827812]
- [drm] drm/amdgpu/display: use blanked rather than plane state for sync groups (Lyude Paul) [1827812]
- [drm] drm/qxl: Use correct notify port address when creating cursor ring (Lyude Paul) [1827812]
- [drm] drm/dp_mst: Reformat drm_dp_check_act_status() a bit (Lyude Paul) [1827812]
- [drm] drm/ast: fix missing break in switch statement for format->cppcase 4 (Lyude Paul) [1827812]
- [drm] drm/amd/display: Revalidate bandwidth before commiting DC updates (Lyude Paul) [1827812]
- [drm] drm/nouveau: gr/gk20a: Use firmware version 0 (Lyude Paul) [1827812]
- [drm] drm/amdgpu: Sync with VM root BO when switching VM to CPU update mode (Lyude Paul) [1827812]
- [drm] drm/amd/powerpay: Disable gfxoff when setting manual mode on picasso and raven (Lyude Paul) [1827812]
- [drm] drm/amd/display: Do not disable pipe split if mode is not supported (Lyude Paul) [1827812]
- [drm] drm/amd/display: dmcu wait loop calculation is incorrect in RV (Lyude Paul) [1827812]
- [drm] drm/amd/display: Correct updating logic of dcn21's pipe VM flags (Lyude Paul) [1827812]
- [drm] drm/ast: Allocate initial CRTC state of the correct size (Lyude Paul) [1827812]
- [drm] drm/hisilicon: Enforce 128-byte stride alignment to fix the hardware limitation (Lyude Paul) [1827812]
- [drm] drm/dp: Lenovo X13 Yoga OLED panel brightness fix (Lyude Paul) [1827812]
- [drm] drm/i915/dpcd_bl: Unbreak enable_dpcd_backlight modparam (Lyude Paul) [1827812]
- [drm] drm/i915: Force DPCD backlight mode for some Dell CML 2020 panels (Lyude Paul) [1827812]
- [drm] drm/i915: Force DPCD backlight mode on X1 Extreme 2nd Gen 4K AMOLED panel (Lyude Paul) [1827812]
- [drm] drm/dp: Introduce EDID-based quirks (Lyude Paul) [1827812]
- [drm] drm/amdgpu: Init data to avoid oops while reading pp_num_states (Lyude Paul) [1827812]
- [drm] drm/amd/display: fix virtual signal dsc setup (Lyude Paul) [1827812]
- [drm] drm/amd/display: Force watermark value propagation (Lyude Paul) [1827812]
- [drm] drm: bridge: adv7511: Extend list of audio sample rates (Lyude Paul) [1827812]
- [drm] drm/amdgpu: fix and cleanup amdgpu_gem_object_close v4 (Lyude Paul) [1827812]
- [drm] drm/vkms: Hold gem object while still in-use (Lyude Paul) [1827812]
- [drm] drm/amd/display: Not doing optimize bandwidth if flip pending (Lyude Paul) [1827812]
- [drm] drm/amd/display: remove invalid dc_is_hw_initialized function (Lyude Paul) [1827812]
- [drm] drm/amd/display: DP training to set properly SCRAMBLING_DISABLE (Lyude Paul) [1827812]
- [drm] drm/edid: Add Oculus Rift S to non-desktop list (Lyude Paul) [1827812]
- [drm] drm/amd/display: Fix potential integer wraparound resulting in a hang (Lyude Paul) [1827812]
- [drm] drm/amd/display: Added locking for atomic update stream and update planes (Lyude Paul) [1827812]
- [drm] drm/amd/display: Indicate dsc updates explicitly (Lyude Paul) [1827812]
- [drm] drm/amd/display: Split program front end part that occur outside lock (Lyude Paul) [1827812]
- [drm] drm/amd/display: drop cursor position check in atomic test (Lyude Paul) [1827812]
- [drm] drm/amd/amdgpu: Update update_config() logic (Lyude Paul) [1827812]
- [drm] drm/amdgpu: Use GEM obj reference for KFD BOs (Lyude Paul) [1827812]
- [drm] drm/amd/powerplay: perform PG ungate prior to CG ungate (Lyude Paul) [1827812]
- [drm] drm/amdgpu: drop unnecessary cancel_delayed_work_sync on PG ungate (Lyude Paul) [1827812]
- [drm] drm/i915: Propagate error from completed fences (Lyude Paul) [1827812]
- [drm] drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead of inheritance (Lyude Paul) [1827812]
- [drm] drm/amd/display: Prevent dpcd reads with passive dongles (Lyude Paul) [1827812]
- [drm] drm/amd/display: fix counter in wait_for_no_pipes_pending (Lyude Paul) [1827812]
- [gpu] vgaarb: Keep adding VGA device in queue (Lyude Paul) [1827812]

* Sun Aug 02 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-230.el8]
- [net] openvswitch: fixes potential deadlock in dp cleanup code (Eelco Chaudron) [1845662]
- [net] openvswitch: reorder masks array based on usage (Eelco Chaudron) [1845662]
- [net] openvswitch: ovs_ct_exit to be done under ovs_lock (Eelco Chaudron) [1860853]
- [net] ip6_gre: fix null-ptr-deref in ip6gre_init_net() (Hangbin Liu) [1860221]
- [net] ip6_gre: fix use-after-free in ip6gre_tunnel_lookup() (Hangbin Liu) [1860221]
- [net] mld: fix memory leak in ipv6_mc_destroy_dev() (Hangbin Liu) [1860221]
- [net] ipv6: Fix suspicious RCU usage warning in ip6mr (Hangbin Liu) [1860221]
- [net] ip6mr: Fix RCU list debugging warning (Hangbin Liu) [1860221]
- [net] revert "ipv6: add mtu lock check in __ip6_rt_update_pmtu" (Hangbin Liu) [1860221]
- [netdrv] macsec: avoid to set wrong mtu (Sabrina Dubroca) [1860944]
- [netdrv] team: fix hang in team_mode_get() (Hangbin Liu) [1860219]
- [include] xfrm: Fix crash when the hold queue is used. (Xin Long) [1860672]
- [net] xfrm: policy: fix IPv6-only espintcp compilation (Xin Long) [1860672]
- [net] xfrm: esp6: fix encapsulation header offset computation (Xin Long) [1860672]
- [net] xfrm: Fix double ESP trailer insertion in IPsec crypto offload. (Xin Long) [1860672]
- [net] esp4: improve xfrm4_beet_gso_segment() to be more readable (Xin Long) [1860672]
- [net] xfrm interface: don't take extra reference to netdev (Xin Long) [1860672]
- [net] xfrm interface: fix oops when deleting a x-netns interface (Xin Long) [1860672]
- [net] xfrm: remove the unnecessary .net_exit for xfrmi (Xin Long) [1860672]
- [net] xfrm: Always set XFRM_TRANSFORMED in xfrm{4, 6}_output_finish (Xin Long) [1860672]
- [include] xfrm: fix error in comment (Xin Long) [1860672]
- [net] sctp: shrink stream outq when fails to do addstream reconf (Xin Long) [1853535]
- [net] sctp: shrink stream outq only when new outcnt < old outcnt (Xin Long) [1853535]
- [net] tipc: fix kernel WARNING in tipc_msg_append() (Xin Long) [1844377]
- [net] tipc: fix NULL pointer dereference in streaming (Xin Long) [1844377]
- [net] tipc: add test for Nagle algorithm effectiveness (Xin Long) [1844377]
- [net] tipc: fix failed service subscription deletion (Xin Long) [1844377]
- [net] tipc: fix memory leak in service subscripting (Xin Long) [1844377]
- [net] tipc: fix large latency in smart Nagle streaming (Xin Long) [1844377]
- [net] mptcp: add receive buffer auto-tuning (Florian Westphal) [1858276]
- [tools] selftests: mptcp: add option to specify size of file to transfer (Florian Westphal) [1858276]
- [net] mptcp: fallback in case of simultaneous connect (Florian Westphal) [1858276]
- [net] mptcp: improve fallback to TCP (Florian Westphal) [1858276]
- [net] mptcp: fix unblocking connect() (Florian Westphal) [1858276]
- [net] mptcp: cache msk on MP_JOIN init_req (Florian Westphal) [1858276]
- [net] mptcp: remove msk from the token container at destruction time. (Florian Westphal) [1858276]
- [net] mptcp: fix races between shutdown and recvmsg (Florian Westphal) [1858276]
- [net] mptcp: fix race between MP_JOIN and close (Florian Westphal) [1858276]
- [net] mptcp: drop MPTCP_PM_MAX_ADDR (Florian Westphal) [1858276]
- [net] mptcp: bugfix for RM_ADDR option parsing (Florian Westphal) [1858276]
- [net] mptcp: drop MP_JOIN request sock on syn cookies (Florian Westphal) [1858276]
- [net] mptcp: avoid NULL-ptr derefence on fallback (Florian Westphal) [1858276]
- [net] mptcp: drop sndr_key in mptcp_syn_options (Florian Westphal) [1858276]
- [net] mptcp: MPTCP_HMAC_TEST should depend on MPTCP (Florian Westphal) [1858276]
- [net] mptcp: fix DSS map generation on fin retransmission (Florian Westphal) [1858276]
- [net] inet_connection_sock: clear inet_num out of destroy helper (Florian Westphal) [1858276]
- [net] mptcp: fix NULL ptr dereference in MP_JOIN error path (Florian Westphal) [1858276]
- [net] mptcp: avoid blocking in tcp_sendpages (Florian Westphal) [1858276]
- [net] mptcp: break and restart in case mptcp sndbuf is full (Florian Westphal) [1858276]
- [net] l2tp: remove skb_dst_set() from l2tp_xmit_skb() (Xin Long) [1832799]
- [net] rtnetlink: prevent underflows in do_setvfinfo() (Davide Caratti) [1854740]
- [net] netfilter: nf_tables: reintroduce the NFT_SET_CONCAT flag (Phil Sutter) [1847553]
- [net] netfilter: nf_tables: report EOPNOTSUPP on unsupported flags/object type (Phil Sutter) [1847553]
- [net] openvswitch: take into account de-fragmentation/gso_size in execute_check_pkt_len (Lorenzo Bianconi) [1851888]
- [tools] selftests: forwarding: mirror_lib: Use mausezahn (Davide Caratti) [1816443]
- [x86] perf/x86/rapl: Add Ice Lake RAPL support (Michael Petlan) [1841266]
- [arm64] arm64/mm: enable HugeTLB migration (Donghai Qiao) [1758717]
- [scsi] scsi: core: Run queue in case of I/O resource contention failure (Ewan Milne) [1854958]
- [message] scsi: mptscsih: Fix read sense data size (Tomas Henzl) [1850563]
- [netdrv] net: qed: fix buffer overflow on ethtool -d (Manish Chopra) [1858915]
- [x86] sched/cputime: Improve cputime_adjust() (Oleg Nesterov) [1859977]
- [kernel] uprobes: Change handle_swbp() to send SIGTRAP with si_code=SI_KERNEL, to fix GDB regression (Oleg Nesterov) [1855390]
- [x86] x86/asm: Fix MWAITX C-state hint value (Vladis Dronov) [1767064]
- [x86] x86/kexec: Fill in acpi_rsdp_addr from the first kernel (Kairui Song) [1684462]
- [x86] x86/kexec: Don't setup EFI info if EFI runtime is not enabled (Kairui Song) [1684462]
- [vfio] vfio/pci: fix racy on error and request eventfd ctx (Alex Williamson) [1858346]
- [platform] platform/x86: ISST: Increase timeout (Prarit Bhargava) [1854682]
- [mm] x86/mm: split vmalloc_sync_all() (Al Stone) [1851547]
- [acpi] ACPI: watchdog: Fix gas->access_width usage (Al Stone) [1851547]
- [acpi] ACPICA: Introduce ACPI_ACCESS_BYTE_WIDTH() macro (Al Stone) [1851547]

* Thu Jul 30 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-229.el8]
- [virt] kvm: x86: take as_id into account when checking PGD (Vitaly Kuznetsov) [1615704]
- [arm64] kvm: arm64: Stop clobbering x0 for HVC_SOFT_RESTART (Andrew Jones) [1855788]
- [arm64] kvm: arm64: pmu: Fix per-CPU access in preemptible context (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Fix kvm_reset_vcpu() return code being incorrect with SVE (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Annotate hyp NMI-related functions as __always_inline (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Remove host_cpu_context member from vcpu structure (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Move hyp_symbol_addr() to kvm_asm.h (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Handle PtrAuth traps early (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Save the host's PtrAuth keys in non-preemptible context (Andrew Jones) [1855788]
- [arm64] kvm: arm64: Stop save/restoring ACTLR_EL1 (Andrew Jones) [1855788]
- [kernel] firmware: smccc: Update link to latest SMCCC specification (Andrew Jones) [1855788]
- [kernel] arm/arm64: smccc-1.1: Handle function result as parameters (Andrew Jones) [1855788]
- [kernel] arm/arm64: smccc-1.1: Make return values unsigned long (Andrew Jones) [1855788]
- [video] Revert "hyperv_fb: Fix hibernation for the deferred IO feature" (Mohammed Gamal) [1858755]
- [netdrv] net/mlx5e: CT: Map 128 bits labels to 32 bit map ID (Alaa Hleihel) [1859540]
- [security] ima: move APPRAISE_BOOTPARAM dependency on ARCH_POLICY to runtime (Bruno Meneguele) [1847219]
- [scsi] scsi: lpfc: NVMe remote port devloss_tmo from lldd (Dick Kennedy) [1859344]
- [netdrv] net/mlx5e: Disable devlink port support for non-switchdev mode (Alaa Hleihel) [1858501 1852904 1849623]
- [tools] perf powerpc: Don't ignore sym-handling.c file (Michael Petlan) [1858133]
- [fs] ext4: reserve revoke credits in __ext4_new_inode (Lukas Czerner) [1856760]
- [include] jbd2: make jbd2_handle_buffer_credits() handle reserved handles (Lukas Czerner) [1856760]
- [fs] jbd2: avoid leaking transaction credits when unreserving handle (Lukas Czerner) [1856760]
- [fs] jbd2: Fine tune estimate of necessary descriptor blocks (Lukas Czerner) [1856760]
- [fs] jbd2: Provide trace event for handle restarts (Lukas Czerner) [1856760]
- [fs] ext4: Reserve revoke credits for freed blocks (Lukas Czerner) [1856760]
- [fs] jbd2: Make credit checking more strict (Lukas Czerner) [1856760]
- [fs] jbd2: Rename h_buffer_credits to h_total_credits (Lukas Czerner) [1856760]
- [fs] jbd2: add missing tracepoint for reserved handle (Lukas Czerner) [1856760]
- [fs] jbd2: Reserve space for revoke descriptor blocks (Lukas Czerner) [1856760]
- [fs] jbd2: Drop jbd2_space_needed() (Lukas Czerner) [1856760]
- [fs] jbd2: remove repeated assignments in __jbd2_log_wait_for_space() (Lukas Czerner) [1856760]
- [fs] jbd2: Account descriptor blocks into t_outstanding_credits (Lukas Czerner) [1856760]
- [include] jbd2: update locking documentation for transaction_t (Lukas Czerner) [1856760]
- [fs] jbd2: Factor out common parts of stopping and restarting a handle (Lukas Czerner) [1856760]
- [fs] jbd2: Drop pointless wakeup from jbd2_journal_stop() (Lukas Czerner) [1856760]
- [fs] jbd2: Drop pointless check from jbd2_journal_stop() (Lukas Czerner) [1856760]
- [fs] jbd2: Reorganize jbd2_journal_stop() (Lukas Czerner) [1856760]
- [fs] ext4, jbd2: Provide accessor function for handle credits (Lukas Czerner) [1856760]
- [fs] ext4: Provide function to handle transaction restarts (Lukas Czerner) [1856760]
- [fs] ext4: Avoid unnecessary revokes in ext4_alloc_branch() (Lukas Czerner) [1856760]
- [fs] ext4: Use ext4_journal_extend() instead of jbd2_journal_extend() (Lukas Czerner) [1856760]
- [fs] jbd2: Completely fill journal descriptor blocks (Lukas Czerner) [1856760]
- [fs] jbd2: Fixup stale comment in commit code (Lukas Czerner) [1856760]
- [include] jbd2: Fix possible overflow in jbd2_log_space_left() (Lukas Czerner) [1856760]
- [fs] ext4, jbd2: ensure panic by fix a race between jbd2 abort and ext4 error handlers (Lukas Czerner) [1856760]
- [fs] ext4: remove set but not used variable 'es' in ext4_jbd2.c (Lukas Czerner) [1856760]
- [fs] ext4: remove set but not used variable 'es' (Lukas Czerner) [1856760]
- [fs] ext4: save all error info in save_error_info() and drop ext4_set_errno() (Lukas Czerner) [1856760]
- [fs] ext4: save the error code which triggered an ext4_error() in the superblock (Lukas Czerner) [1856760]
- [fs] jbd2: clean __jbd2_journal_abort_hard() and __journal_abort_soft() (Lukas Czerner) [1856760]
- [fs] ext4: stop overwrite the errcode in ext4_setup_super (Lukas Czerner) [1856760]
- [fs] ext4: fix partial cluster initialization when splitting extent (Lukas Czerner) [1856760]
- [fs] ext4: avoid ext4_error()'s caused by ENOMEM in the truncate path (Lukas Czerner) [1856760]
- [fs] ext4: fix race between ext4_sync_parent() and rename() (Lukas Czerner) [1856760]
- [fs] ext4: clean up ext4_ext_convert_to_initialized() error handling (Lukas Czerner) [1856760]
- [fs] ext4: clean up GET_BLOCKS_PRE_IO error handling (Lukas Czerner) [1856760]
- [fs] ext4: fix error pointer dereference (Lukas Czerner) [1856760]
- [fs] ext4: Avoid freeing inodes on dirty list (Lukas Czerner) [1856760]
- [fs] writeback: Export inode_io_list_del() (Lukas Czerner) [1856760]
- [fs] ext4: fix buffer_head refcnt leak when ext4_iget() fails (Lukas Czerner) [1856760]
- [fs] ext4: fix EXT_MAX_EXTENT/INDEX to check for zeroed eh_max (Lukas Czerner) [1856760]
- [fs] ext4: fix a style issue in fs/ext4/acl.c (Lukas Czerner) [1856760]
- [fs] ext4: fix return-value types in several function comments (Lukas Czerner) [1856760]
- [fs] ext4: use non-movable memory for superblock readahead (Lukas Czerner) [1856760]
- [fs] ext4: fix incorrect group count in ext4_fill_super error message (Lukas Czerner) [1856760]
- [fs] ext4: fix incorrect inodes per group in error message (Lukas Czerner) [1856760]
- [fs] ext4: avoid ENOSPC when avoiding to reuse recently deleted inodes (Lukas Czerner) [1856760]
- [fs] ext4: fix a data race at inode->i_disksize (Lukas Czerner) [1856760]
- [fs] ext4: fix a data race at inode->i_blocks (Lukas Czerner) [1856760]
- [fs] ext4: clean up error return for convert_initialized_extent() (Lukas Czerner) [1856760]
- [fs] ext4: force buffer up-to-date while marking it dirty (Lukas Czerner) [1856760]
- [fs] ext4: fix race between writepages and enabling EXT4_EXTENTS_FL (Lukas Czerner) [1856760]
- [fs] ext4: rename s_journal_flag_rwsem to s_writepages_rwsem (Lukas Czerner) [1856760]
- [fs] ext4: potential crash on allocation error in ext4_alloc_flex_bg_array() (Lukas Czerner) [1856760]
- [fs] ext4: fix potential race between s_flex_groups online resizing and access (Lukas Czerner) [1856760]
- [fs] ext4: fix potential race between s_group_info online resizing and access (Lukas Czerner) [1856760]
- [fs] ext4: fix potential race between online resizing and write operations (Lukas Czerner) [1856760]
- [fs] ext4: add cond_resched() to __ext4_find_entry() (Lukas Czerner) [1856760]
- [fs] ext4: fix a data race in EXT4_I(inode)->i_disksize (Lukas Czerner) [1856760]
- [fs] ext4: fix checksum errors with indexed dirs (Lukas Czerner) [1856760]
- [fs] ext4: simplify checking quota limits in ext4_statfs() (Lukas Czerner) [1856760]
- [fs] ext4: choose hardlimit when softlimit is larger than hardlimit in ext4_statfs_project() (Lukas Czerner) [1856760]
- [fs] ext4: don't assume that mmp_nodename/bdevname have NUL (Lukas Czerner) [1856760]
- [fs] jbd2: make sure ESHUTDOWN to be recorded in the journal superblock (Lukas Czerner) [1856760]
- [fs] ext4, jbd2: ensure panic when aborting with zero errno (Lukas Czerner) [1856760]
- [fs] jbd2: switch to use jbd2_journal_abort() when failed to submit the commit record (Lukas Czerner) [1856760]
- [fs] jbd2_seq_info_next should increase position index (Lukas Czerner) [1856760]
- [fs] ext4,jbd2: fix comment and code style (Lukas Czerner) [1856760]
- [fs] ext4: fix extent_status trace points (Lukas Czerner) [1856760]
- [fs] ext4: fix extent_status fragmentation for plain files (Lukas Czerner) [1856760]
- [fs] jbd2: clear JBD2_ABORT flag before journal_reset to update log tail info when load journal (Lukas Czerner) [1856760]
- [fs] ext4: fix some nonstandard indentation in extents.c (Lukas Czerner) [1856760]
- [fs] ext4: fix documentation for ext4_ext_try_to_merge() (Lukas Czerner) [1856760]
- [fs] ext4: avoid fetching btime in ext4_getattr() unless requested (Lukas Czerner) [1856760]
- [fs] ext4: fix ext4_dax_read/write inode locking sequence for IOCB_NOWAIT (Lukas Czerner) [1856760]
- [fs] ext4: optimize __ext4_check_dir_entry() (Lukas Czerner) [1856760]
- [fs] ext4: check for directory entries too close to block end (Lukas Czerner) [1856760]
- [fs] ext4: fix a bug in ext4_wait_for_tail_page_commit (Lukas Czerner) [1856760]
- [fs] jbd2: Fix statistics for the number of logged blocks (Lukas Czerner) [1856760]
- [fs] ext4: Fix ext4_should_journal_data() for EA inodes (Lukas Czerner) [1856760]
- [fs] ext4: Fix credit estimate for final inode freeing (Lukas Czerner) [1856760]
- [fs] ext4: Do not iput inode under running transaction (Lukas Czerner) [1856760]
- [fs] ext4: Move marking of handle as sync to ext4_add_nondir() (Lukas Czerner) [1856760]
- [fs] ext4: update direct I/O read lock pattern for IOCB_NOWAIT (Lukas Czerner) [1856760]
- [fs] jbd2: flush_descriptor(): Do not decrease buffer head's ref count (Lukas Czerner) [1856760]
- [fs] ext4: fix prefetchw of NULL page (Lukas Czerner) [1856760]
- [fs] ext4: check for non-zero journal inum in ext4_calculate_overhead (Lukas Czerner) [1814574]
- [fs] ext4: do not commit super on read-only bdev (Lukas Czerner) [1814574]
- [kernel] isolcpus: Affine unbound kernel threads to housekeeping cpus (Marcelo Tosatti) [1791930]
- [kernel] kthread: Switch to cpu_possible_mask (Marcelo Tosatti) [1791930]
- [scsi] scsi: lpfc: Quieten some printks (Dick Kennedy) [1859338]
- [scsi] Revert "scsi: lpfc: Fix scsi host template for SLI3 vports" (Dick Kennedy) [1851189]
- [md] dm mpath: use double checked locking in fast path (Mike Snitzer) [1848651]
- [md] dm mpath: rename current_pgpath to pgpath in multipath_prepare_ioctl (Mike Snitzer) [1848651]
- [md] dm mpath: rework __map_bio() (Mike Snitzer) [1848651]
- [md] dm mpath: factor out multipath_queue_bio (Mike Snitzer) [1848651]
- [md] dm mpath: push locking down to must_push_back_rq() (Mike Snitzer) [1848651]
- [md] dm mpath: take m->lock spinlock when testing QUEUE_IF_NO_PATH (Mike Snitzer) [1848651]
- [md] dm mpath: changes from initial m->flags locking audit (Mike Snitzer) [1848651]
- [md] dm rq: don't call blk_mq_queue_stopped() in dm_stop_queue() (Mike Snitzer) [1848651]
- [md] dm: do not use waitqueue for request-based DM (Mike Snitzer) [1848651]
- [block] blk-mq: consider non-idle request as "inflight" in blk_mq_rq_inflight() (Mike Snitzer) [1848651]
- [powerpc] powerpc/fadump: fix race between pstore write and fadump crash trigger (Steve Best) [1820109]
- [tools] libbpf: Fix probe code to return EPERM if encountered (=?UTF-8?q?Toke=20H=C3=B8iland-J=C3=B8rgensen?=) [1856592]
- [tools] tools selftests/bpf: Fix vmlinux test for kprobe and trampoline probes (Jiri Olsa) [1855778]
- [net] net: Restrict receive packets queuing to housekeeping CPUs (Nitesh Narayan Lal) [1844520]
- [pci] PCI: Restrict probe functions to housekeeping CPUs (Nitesh Narayan Lal) [1844520]
- [lib] lib: Restrict cpumask_local_spread to houskeeping CPUs (Nitesh Narayan Lal) [1844520]

* Mon Jul 27 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-228.el8]
- [tools] selftests/powerpc: Purge extra count_pmc() calls of ebb selftests (Desnes Augusto Nunes do Rosario) [1739769]
- [netdrv] bonding: symmetric ICMP transmit (Jarod Wilson) [1760293]
- [netdrv] bonding: balance ICMP echoes in layer3+4 mode (Jarod Wilson) [1760362]
- [powerpc] powerpc/vas: Report proper error code for address translation failure (Steve Best) [1858160]
- [infiniband] IB/hfi1: Fix module use count flaw due to leftover module put calls (Kamal Heib) [1858388]
- [gpu] vgaarb: Add support for 64-bit frame buffer address (Karol Herbst) [1735217]
- [netdrv] ionic: centralize queue reset code (Jonathan Toppins) [1857851]
- [s390] s390/qeth: support net namespaces for L3 devices (Philipp Rudo) [1857311]
- [s390] s390/qeth: implement smarter resizing of the RX buffer pool (Philipp Rudo) [1857311]
- [s390] s390/qeth: refactor buffer pool code (Philipp Rudo) [1857311]
- [s390] s390/qeth: use page pointers to manage RX buffer pool (Philipp Rudo) [1857311]
- [s390] s390/qeth: cancel RX reclaim work earlier (Philipp Rudo) [1857311]
- [s390] s390/qeth: handle error when backing RX buffer (Philipp Rudo) [1857311]
- [s390] s390/qeth: don't reset default_out_queue (Philipp Rudo) [1857311]
- [s390] s390/qdio: fill SBALEs with absolute addresses (Philipp Rudo) [1857311]
- [s390] s390/qeth: fix off-by-one in RX copybreak check (Philipp Rudo) [1857311]
- [s390] s390/qeth: vnicc Fix EOPNOTSUPP precedence (Philipp Rudo) [1857311]
- [s390] s390/qeth: consolidate QDIO queue setup (Philipp Rudo) [1857311]
- [s390] s390/pci: Fix s390_mmio_read/write with MIO (Philipp Rudo) [1857315]
- [s390] scsi: zfcp: Fix panic on ERP timeout for previously dismissed ERP action (Philipp Rudo) [1857312]
- [net] net/smc: tolerate future SMCD versions (Philipp Rudo) [1854992]
- [fs] ext4: use RCU API in debug_print_tree (Lukas Czerner) [1837777]
- [fs] ext4: fix potential use after free after remounting with noblock_validity (Lukas Czerner) [1837777]
- [fs] ext4: add cond_resched() to ext4_protect_reserved_inode (Lukas Czerner) [1837777]
- [fs] fibmap: Reject negative block numbers (Carlos Maiolino) [1687121]
- [vfio] vfio/pci: Fix SR-IOV VF handling with MMIO blocking (Alex Williamson) [1837310] {CVE-2020-12888}
- [vfio] vfio-pci: Invalidate mmaps and block MMIO access on disabled memory (Alex Williamson) [1837310] {CVE-2020-12888}
- [vfio] vfio-pci: Fault mmaps to enable vma tracking (Alex Williamson) [1837310] {CVE-2020-12888}
- [vfio] vfio/type1: Support faulting PFNMAP vmas (Alex Williamson) [1837310] {CVE-2020-12888}
- [vfio] vfio/type1: Fix VA->PA translation for PFNMAP VMAs in vaddr_get_pfn() (Alex Williamson) [1837310] {CVE-2020-12888}
- [vfio] vfio/pci: call irq_bypass_unregister_producer() before freeing irq (Alex Williamson) [1837310] {CVE-2020-12888}
- [vfio] vfio_pci: Enable memory accesses before calling pci_map_rom (Alex Williamson) [1837310] {CVE-2020-12888}
- [x86] mm: Fix mremap not considering huge pmd devmap (Rafael Aquini) [1843441] {CVE-2020-10757}
- [x86] x86/speculation: PR_SPEC_FORCE_DISABLE enforcement for indirect branches (Waiman Long) [1847396 1846029] {CVE-2020-10768}
- [x86] x86/speculation: Prevent rogue cross-process SSBD shutdown (Waiman Long) [1847358 1846029] {CVE-2020-10766}
- [x86] x86/speculation: Avoid force-disabling IBPB based on STIBP and enhanced IBRS (Waiman Long) [1847379 1846029] {CVE-2020-10767}
- [x86] x86/speculation/mds: Mark mds_user_clear_cpu_buffers() __always_inline (Waiman Long) [1846029]
- [arm64] Return ENODEV when the selected speculation misfeature is unsupported (Waiman Long) [1846029]
- [x86] x86/speculation: Add support for STIBP always-on preferred mode (Waiman Long) [1846029]
- [x86] x86/speculation: Change misspelled STIPB to STIBP (Waiman Long) [1846029]

* Mon Jul 20 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-227.el8]
- [powerpc] powernv/iov: Ensure the pdn for VFs always contains a valid PE number (David Gibson) [1848235]
- [powerpc] don't use ioremap_prot() nor __ioremap() unless really needed (Greg Kurz) [1855957]
- [char] tpm: ibmvtpm: Wait for ready buffer before probing for TPM2 attributes (David Gibson) [1837283]
- [powerpc] Check prom_init for disallowed sections (Michael Roth) [1856099]
- [powerpc] prom_init: Move __prombss to it's own section and store it in .bss (Michael Roth) [1856099]
- [powerpc] prom_init: Move const structures to __initconst (Michael Roth) [1856099]
- [powerpc] prom_init: Make "default_colors" const (Michael Roth) [1856099]
- [powerpc] prom_init: Move ibm_arch_vec to __prombss (Michael Roth) [1856099]
- [fs] ext4: unregister sysfs path before destroying jbd2 journal (Lukas Czerner) [1814577]
- [powerpc] powerpc/pseries/svm: Fix incorrect check for shared_lppaca_size (Steve Best) [1856889]
- [netdrv] bnxt_en: fix NULL dereference in case SR-IOV configuration fails (Jonathan Toppins) [1856372]
- [security] kexec: Allow kexec_file() with appropriate IMA policy when locked down (Bruno Meneguele) [1854097]
- [x86] x86/apic/vector: Warn when vector space exhaustion breaks affinity (Neil Horman) [1714686]
- [tools] perf report TUI: Fix segmentation fault in perf_evsel__hists_browse() (Michael Petlan) [1855737]
- [fs] ext4: do not zeroout extents beyond i_disksize (Lukas Czerner) [1817816]
- [pci] PCI/DPC: Print IRQ number used by port (Myron Stowe) [1855343]
- [pci] PCI/AER: Use "aer" variable for capability offset (Myron Stowe) [1855343]
- [pci] PCI/AER: Remove redundant dev->aer_cap checks (Myron Stowe) [1855343]
- [pci] PCI/AER: Remove redundant pci_is_pcie() checks (Myron Stowe) [1855343]
- [pci] PCI/AER: Remove HEST/FIRMWARE_FIRST parsing for AER ownership (Myron Stowe) [1855343]
- [tools] selftests: bpf: use __u32 for sock::sk_pacing_rate (Yauheni Kaliuta) [1856324]
- [tools] libbpf: Handle GCC noreturn-turned-volatile quirk (Yauheni Kaliuta) [1854327]
- [netdrv] net/mlx5e: CT: Fix releasing ft entries (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Remove unused function param (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Return err_ptr from internal functions (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Expand tunnel register mappings (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Use mapping for zone restore register (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Re-use tuple modify headers for identical modify actions (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Export sharing of mod headers to a new file (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5: Add support for COPY steering action (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5: Accept flow rules without match (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Restore ct state from lookup in zone instead of tupleid (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Don't offload tuple rewrites for established tuples (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Use netdev_info instead of pr_info (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Allow header rewrite of 5-tuple and ct clear action (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Save ct entries tuples in hashtables (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5: CT: Remove unused variables (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5: Avoid eswitch header inclusion in fs core layer (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: vxlan: Use RCU for vxlan table lookup (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Remove unused mlx5e_xsk_first_unused_channel (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: CT: Fix memory leak in cleanup (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Fix port buffers cell size value (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Fix 50G per lane indication (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Fix CPU mapping after function reload to avoid aRFS RX crash (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Fix VXLAN configuration restore after function reload (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5: Fix eeprom support for SFP module (Alaa Hleihel) [1856057]
- [infiniband] IB/mlx5: Fix 50G per lane indication (Alaa Hleihel) [1856057]
- [netdrv] net/mlx5e: Do not include rwlock.h directly (Alaa Hleihel) [1856057]
- [fs] jbd2: fix data races at struct journal_head (Lukas Czerner) [1792518]
- [fs] jbd2: remove pointless assertion in __journal_remove_journal_head (Lukas Czerner) [1792518]
- [fs] jbd2: improve comments about freeing data buffers whose page mapping is NULL (Lukas Czerner) [1792518]
- [fs] jbd2: do not clear the BH_Mapped flag when forgetting a metadata buffer (Lukas Czerner) [1792518]
- [fs] jbd2: move the clearing of b_modified flag to the journal_unmap_buffer() (Lukas Czerner) [1792518]
- [fs] ext4: unlock on error in ext4_expand_extra_isize() (Lukas Czerner) [1817636] {CVE-2019-19767}
- [fs] ext4: fix support for inode sizes > 1024 bytes (Lukas Czerner) [1817636] {CVE-2019-19767}
- [fs] ext4: validate the debug_want_extra_isize mount option at parse time (Lukas Czerner) [1817636] {CVE-2019-19767}
- [fs] ext4: add more paranoia checking in ext4_expand_extra_isize handling (Lukas Czerner) [1817636] {CVE-2019-19767}
- [fs] ext4: unsigned int compared against zero (Lukas Czerner) [1836666] {CVE-2019-19319}
- [fs] ext4: protect journal inode's blocks using block_validity (Lukas Czerner) [1836666] {CVE-2019-19319}
- [powerpc] powerpc/kernel/sysfs: Add new config option PMU_SYSFS to enable PMU SPRs sysfs file creation (Michael Petlan) [1821284]
- [powerpc] powerpc/kernel/sysfs: Refactor current sysfs.c (Michael Petlan) [1821284]
- [kernel] irqdomain: Add the missing assignment of domain->fwnode for named fwnode (Mohammed Gamal) [1846666]
- [security] lockdown: Allow unprivileged users to see lockdown status (Vladis Dronov) [1805299]
- [edac] EDAC/ghes: Setup DIMM label from DMI and use it in error reports (Robert Richter) [1726153]

* Wed Jul 15 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-226.el8]
- [x86] kvm: nvmx: fixes for preemption timer migration (Paolo Bonzini) [1854831]
- [powerpc] pci/of: Parse unassigned resources (Greg Kurz) [1849921]
- [video] revert "hyperv: hyperv_fb: Support deferred IO for Hyper-V frame buffer driver" (Vitaly Kuznetsov) [1848840]
- [video] revert "hyperv: hyperv_fb: Use physical memory for fb on HyperV Gen 1 VMs" (Vitaly Kuznetsov) [1848840]
- [pci] hv: Retry PCI bus D0 entry on invalid device state (Mohammed Gamal) [1846666]
- [pci] hv: Fix the PCI HyperV probe failure path to release resource properly (Mohammed Gamal) [1846666]
- [pci] hv: Allocate a named fwnode instead of an address-based one (Mohammed Gamal) [1846666]
- [netdrv] tg3: driver sleeps indefinitely when EEH errors exceed eeh_max_freezes (Jonathan Toppins) [1850176]
- [scsi] scsi: lpfc: Fix kdump hang on PPC (Dick Kennedy) [1722596]
- [fs] nfsd: fix nfsdfs inode reference count leak ("J. Bruce Fields") [1846235]
- [fs] nfsd4: fix nfsdfs reference count loop ("J. Bruce Fields") [1846235]
- [kernel] sched: Defend cfs and rt bandwidth quota against overflow (Phil Auld) [1854180]
- [kernel] sched/core: Make some functions static (Phil Auld) [1854180]
- [kernel] sched/fair: Refill bandwidth before scaling (Phil Auld) [1854180]
- [kernel] sched/fair: Eliminate bandwidth race between throttling and distribution (Phil Auld) [1854180]
- [kernel] sched/fair: Fix race between runtime distribution and assignment (Phil Auld) [1854180]
- [kernel] sched/deadline: Initialize ->dl_boosted (Phil Auld) [1854179]
- [kernel] sched/core: Fix PI boosting between RT and DEADLINE tasks (Phil Auld) [1854179]
- [netdrv] ibmveth: Fix max MTU limit (Diego Domingos) [1846435]
- [kernel] sched/core: Fix ttwu() race (Phil Auld) [1854178]
- [tools] perf flamegraph: Explicitly set utf-8 encoding (Michael Petlan) [1849027]
- [kernel] sched/core: Check cpus_mask, not cpus_ptr in __set_cpus_allowed_ptr(), to fix mask corruption (Phil Auld) [1854174]
- [kernel] workqueue: Remove the warning in wq_worker_sleeping() (Phil Auld) [1854174]
- [kernel] sched/fair: Fix negative imbalance in imbalance calculation (Phil Auld) [1854174]
- [kernel] sched/fair: Optimize select_idle_core() (Phil Auld) [1854174]
- [x86] x86/PCI: Mark Intel C620 MROMs as having non-compliant BARs (Myron Stowe) [1854184]
- [netdrv] r8169: fix firmware not resetting tp->ocp_base (Josef Oskera) [1851960]
- [acpi] ACPI: configfs: Disallow loading ACPI tables when locked down (Lenny Szubowicz) [1852969]
- [arm64] Revert "bpf: Restrict bpf_probe_read{, str}() only to archs where they work" (Jiri Olsa) [1847837]
- [s390] s390/mm: Explicitly compare PAGE_DEFAULT_KEY against zero in storage_key_init_range (Jiri Olsa) [1847837]
- [net] Bluetooth: Modify LE window and interval for suspend (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix incorrect type for window and interval (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: Use DEFER_SETUP to group ECRED connections (Gopal Tiwari) [1838924]
- [net] Bluetooth: don't assume key size is 16 when the command fails (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: Add get_peer_pid callback (Gopal Tiwari) [1838924]
- [net] Bluetooth: Restore running state if suspend fails (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix incorrect branch in connection complete (Gopal Tiwari) [1838924]
- [net] Bluetooth: Do not cancel advertising when starting a scan (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: remove set but not used variable 'credits' (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: Fix a condition in l2cap_sock_recvmsg() (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: handle l2cap config request during open state (Gopal Tiwari) [1838924]
- [net] Bluetooth: clean up connection in hci_cs_disconnect (Gopal Tiwari) [1838924]
- [net] Bluetooth: Pause discovery and advertising during suspend (Gopal Tiwari) [1838924]
- [net] Bluetooth: Handle LE devices during suspend (Gopal Tiwari) [1838924]
- [net] Bluetooth: Handle BR/EDR devices during suspend (Gopal Tiwari) [1838924]
- [net] Bluetooth: Handle PM_SUSPEND_PREPARE and PM_POST_SUSPEND (Gopal Tiwari) [1838924]
- [net] Bluetooth: mgmt: add mgmt_cmd_status in add_advertising (Gopal Tiwari) [1838924]
- [net] Bluetooth: fix off by one in err_data_reporting cmd masks (Gopal Tiwari) [1838924]
- [net] Bluetooth: Use bt_dev_err for RPA generation failure message (Gopal Tiwari) [1838924]
- [net] Bluetooth: RFCOMM: fix ODEBUG bug in rfcomm_dev_ioctl (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: Add module option to enable ECRED mode (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: Add initial code for Enhanced Credit Based Mode (Gopal Tiwari) [1838924]
- [net] Bluetooth: L2CAP: Add definitions (Gopal Tiwari) [1838924]
- [net] Bluetooth: Increment management interface revision (Gopal Tiwari) [1838924]
- [net] Bluetooth: Make use of skb_pull to parse L2CAP signaling PDUs (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix calculation of SCO handle for packet processing (Gopal Tiwari) [1838924]
- [net] Bluetooth: guard against controllers sending zero'd events (Gopal Tiwari) [1838924]
- [net] Bluetooth: During le_conn_timeout disable EXT_ADV (Gopal Tiwari) [1838924]
- [net] Bluetooth: Remove adv set for directed advertising (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix Suspicious RCU usage warnings (Gopal Tiwari) [1838924]
- [net] Bluetooth: Use list_for_each_entry_rcu() to traverse RCU list in RCU read-side CS (Gopal Tiwari) [1838924]
- [net] Bluetooth: Replace zero-length array with flexible-array member (Gopal Tiwari) [1838924]
- [net] Bluetooth: fix passkey uninitialized when used (Gopal Tiwari) [1838924]
- [net] Bluetooth: RFCOMM: Use MTU auto tune logic (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix crash when using new BT_PHY option (Gopal Tiwari) [1838924]
- [net] Bluetooth: Disable Extended Adv if enabled (Gopal Tiwari) [1838924]
- [net] Bluetooth: Add BT_PHY socket option (Gopal Tiwari) [1838924]
- [net] Bluetooth: secure bluetooth stack from bluedump attack (Gopal Tiwari) [1838924]
- [net] Bluetooth: remove __get_channel/dir and __dir (Gopal Tiwari) [1838924]
- [net] Bluetooth: prefetch channel before killing sock (Gopal Tiwari) [1838924]
- [net] Bluetooth: optimize barrier usage for Rmw atomics (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix refcount use-after-free issue (Gopal Tiwari) [1838924]
- [net] Bluetooth: SMP: Fix SALT value in some comments (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix race condition in hci_release_sock() (Gopal Tiwari) [1838924]
- [net] Bluetooth: Move {min, max}_key_size debugfs into hci_debugfs_create_le (Gopal Tiwari) [1838924]
- [net] Bluetooth: Add missing checks for HCI_ISODATA_PKT packet type (Gopal Tiwari) [1838924]
- [net] Bluetooth: fix appearance typo in mgmt.c (Gopal Tiwari) [1838924]
- [net] Bluetooth: adding missing const decoration to mgmt_status_table (Gopal Tiwari) [1838924]
- [net] Bluetooth: Increment management interface revision (Gopal Tiwari) [1838924]
- [net] Bluetooth: monitor: Add support for ISO packets (Gopal Tiwari) [1838924]
- [net] Bluetooth: Make use of __check_timeout on hci_sched_le (Gopal Tiwari) [1838924]
- [net] Bluetooth: Implementation of MGMT_OP_SET_BLOCKED_KEYS (Gopal Tiwari) [1838924]
- [net] Bluetooth: remove redundant assignment to variable icid (Gopal Tiwari) [1838924]
- [net] Bluetooth: Auto tune if input MTU is set to 0 (Gopal Tiwari) [1838924]
- [net] Bluetooth: Remove usage of BT_ERR_RATELIMITED macro (Gopal Tiwari) [1838924]
- [net] Bluetooth: Adding a bt_dev_warn_ratelimited macro (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix memory leak in hci_connect_le_scan (Gopal Tiwari) [1838924]
- [net] Bluetooth: Allow combination of BDADDR_PROPERTY and INVALID_BDADDR quirks (Gopal Tiwari) [1838924]
- [net] Bluetooth: delete a stray unlock (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix advertising duplicated flags (Gopal Tiwari) [1838924]
- [net] net: use skb_queue_empty_lockless() in poll() handlers (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix not using LE_ADV_NONCONN_IND for instance 0 (Gopal Tiwari) [1838924]
- [net] Bluetooth: Fix using advertising instance duration as timeout (Gopal Tiwari) [1838924]
- [fs] compat_ioctl: move hci_sock handlers into driver (Gopal Tiwari) [1838924]
- [fs] compat_ioctl: move rfcomm handlers into driver (Gopal Tiwari) [1838924]
- [net] Bluetooth: hci_core: fix init for HCI_USER_CHANNEL (Gopal Tiwari) [1838924]
- [net] Bluetooth: Workaround directed advertising bug in Broadcom controllers (Gopal Tiwari) [1838924]
- [net] Bluetooth: missed cpu_to_le16 conversion in hci_init4_req (Gopal Tiwari) [1838924]
- [hid] Bluetooth: hidp: Fix assumptions on the return value of hidp_send_message (Gopal Tiwari) [1838924]
- [net] Bluetooth: mgmt: Use struct_size() helper (Gopal Tiwari) [1838924]
- [net] Bluetooth: Add support for utilizing Fast Advertising Interval (Gopal Tiwari) [1838924]
- [net] Bluetooth: 6lowpan: Make variable header_ops constant (Gopal Tiwari) [1838924]
- [net] Revert "Bluetooth: validate BLE connection interval updates" (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: print Intel fw build version in power-on boot (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h5: Switch from BT_ERR to bt_dev_err where possible (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: bfusb: Switch from BT_ERR to bt_dev_err where possible (Gopal Tiwari) [1838924]
- [net] Bluetooth: Enable erroneous data reporting if WBS is supported (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Replace devm_gpiod_get() with devm_gpiod_get_optional() (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Make bt_en and susclk not mandatory for QCA Rome (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btqca: Fix the NVM baudrate tag offcet for wcn3991 (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Not send vendor pre-shutdown command for QCA Rome (Gopal Tiwari) [1838924]
- [net] Bluetooth: Support querying for WBS support through MGMT (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Add flag to define wideband speech capability (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h4: Remove a redundant assignment in 'h4_flush()' (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h4: Fix a typo in a comment (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h5: Move variable into local scope (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Bug fixes while collecting controller memory dump (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h5: btrtl: Add support for RTL8822C (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: Fix a typo in Kconfig (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_uart: Replace zero-length array with flexible-array member (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_intel: Replace zero-length array with flexible-array member (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btintel: Replace zero-length array with flexible-array member (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Add support for 13d3:3548 Realtek 8822CE device (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Optimized code while enabling clocks for BT SOC (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Enable clocks required for BT SOC (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Use kvmalloc for FW allocations (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Enable power off/on support during hci down/up for QCA Rome (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Retry btsoc initialize when it fails (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Add QCA Rome power off support to the qca_power_shutdown() (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: enable IRQ capability from devicetree (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_vhci: Add support for ISO packets (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h4: Add support for ISO packets (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btsdio: Check for valid packet type (Gopal Tiwari) [1838924]
- [net] Bluetooth: Add definitions (Gopal Tiwari) [1838924]
- [net] Bluetooth: Add support for (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_h5: Add support for ISO packets (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Add qca_power_on() API to support both wcn399x and Rome power up (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btbcm : Fix warning about missing blank lines after declarations (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Remove set but not used variable 'opcode' (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Use vfree() instead of kfree() (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Add support for 04ca:3021 QCA_ROME device (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Collect controller memory dump during SSR (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: Drive RTS only for BCM43438 (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Replace of_device_get_match_data with device_get_match_data (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btbcm: Add missing static inline in header (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Disable runtime suspend on Realtek devices (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: fix memory leak on fw (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: fix non-atomic allocation in completion handler (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: Support pcm params in dts (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btbcm: Support pcm configuration (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: Disallow set_baudrate for BCM4354 (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Edit the logical value for Realtek Bluetooth reset (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btbcm: Use the BDADDR_PROPERTY quirk (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btbcm: Add entry for BCM4335A0 UART bluetooth (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btbcm: Add entry for BCM4334B0 UART Bluetooth (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: fix PM leak in error case of setup (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btqca: Rename ROME specific variables to generic variables (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btmtksdio: add MODULE_DEVICE_TABLE() (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: Fix invalid-free in bcsp_close() (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: add PM support (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: Add compatible string for BCM43540 (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: remove unneeded semicolon (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: Fix RTS handling during startup (Gopal Tiwari) [1838924]
- [bluetooth] Revert "Bluetooth: hci_qca: Add delay for wcn3990 stability" (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Remove return statement in btintel_reset_to_bootloader (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Split qca_power_setup() (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Use regulator bulk enable/disable (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Don't vote for specific voltage (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Update regulator_set_load() usage (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Add delay for wcn3990 stability (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Trigger Intel FW download error recovery (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btwilink: drop superseded driver (Gopal Tiwari) [1838924]
- [bluetooth] Revert "Bluetooth: hci_ll: set operational frequency earlier" (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Fix an issue for the incorrect error return code (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Use IS_ENABLED instead of #ifdef (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: print FW version after FW download (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: avoid unused function warning (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_nokia: Save a few cycles in 'nokia_enqueue()' (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Use cmd_timeout to reset Realtek device (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Fix an issue that failing to download the FW which size is over 32K bytes (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Remove trailing newline from calls to rtl_dev macros (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for QCA UART Radio (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Remove redundant prefix from calls to rtl_dev macros (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY (Gopal Tiwari) [1838924]
- [bluetooth] bluetooth: bcm: Add support for loading firmware for BCM4345C5 (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Add firmware version print (Gopal Tiwari) [1838924]
- [bluetooth] bluetooth: hci_bcm: Give more time to come out of reset (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: wait for Pre shutdown complete event before sending the Power off pulse (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_bcm: Fix -Wunused-const-variable warnings (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btusb: Fix suspend issue for Realtek devices (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Remove redundant initializations to zero (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: Make structure qca_proto constant (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: bpa10x: change return value (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: hci_qca: disable irqs when spinlock is acquired (Gopal Tiwari) [1838924]
- [bluetooth] Bluetooth: btrtl: Additional Realtek 8822CE Bluetooth devices (Gopal Tiwari) [1838924]

* Mon Jul 13 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-225.el8]
- [powerpc] powerpc/papr_scm: Implement support for PAPR_PDSM_HEALTH (Gustavo Duarte) [1782178]
- [powerpc] ndctl/papr_scm, uapi: Add support for PAPR nvdimm specific methods (Gustavo Duarte) [1782178]
- [powerpc] powerpc/papr_scm: Improve error logging and handling papr_scm_ndctl() (Gustavo Duarte) [1782178]
- [powerpc] powerpc/papr_scm: Fetch nvdimm health information from PHYP (Gustavo Duarte) [1782178]
- [lib] seq_buf: Export seq_buf_printf (Gustavo Duarte) [1782178]
- [firmware] efi: Restrict efivar_ssdt_load when the kernel is locked down (Lenny Szubowicz) [1852949]
- [netdrv] vmxnet3: allow rx flow hash ops only when rss is enabled (Cathy Avery) [1845417]
- [netdrv] net: vmxnet3: fix possible buffer overflow caused by bad DMA value in vmxnet3_get_rss() (Cathy Avery) [1845417]
- [netdrv] vmxnet3: use correct hdr reference when packet is encapsulated (Cathy Avery) [1845417]
- [netdrv] vmxnet3: update to version 4 (Cathy Avery) [1845417]
- [netdrv] vmxnet3: add geneve and vxlan tunnel offload support (Cathy Avery) [1845417]
- [netdrv] vmxnet3: add support to get/set rx flow hash (Cathy Avery) [1845417]
- [netdrv] vmxnet3: prepare for version 4 changes (Cathy Avery) [1845417]
- [netdrv] vmxnet3: let core reject the unsupported coalescing parameters (Cathy Avery) [1845417]
- [netdrv] vmxnet3: use new helper tcp_v6_gso_csum_prep (Cathy Avery) [1845417]
- [netdrv] vmxnet3: Remove always false conditional statement (Cathy Avery) [1845417]
- [kernel] kexec: do not verify the signature without the lockdown or mandatory signature (Lianbo Jiang) [1836148]
- [fs] block: Fix use-after-free in blkdev_get() (Ming Lei) [1847779]
- [kernel] kernel: rh_features: fix reading empty feature list from /proc (Jiri Benc) [1843064] {CVE-2020-10774}
- [netdrv] ice: cleanup unsigned loops (Jonathan Toppins) [1781403]
- [netdrv] ice: fix usage of incorrect variable (Jonathan Toppins) [1781403]
- [netdrv] ice: Fix bad register reads (Jonathan Toppins) [1781403]
- [netdrv] ice: check for compatibility between DDP package and firmware (Jonathan Toppins) [1781403]
- [netdrv] ice: Check if unicast MAC exists before setting VF MAC (Jonathan Toppins) [1781403]
- [netdrv] ice: print Rx MDD auto reset message before VF reset (Jonathan Toppins) [1781403]
- [netdrv] ice: Call ice_aq_set_mac_cfg (Jonathan Toppins) [1781403]
- [netdrv] ice: Implement aRFS (Jonathan Toppins) [1781403]
- [netdrv] ice: Restore filters following reset (Jonathan Toppins) [1781403]
- [netdrv] ice: Enable flex-bytes support (Jonathan Toppins) [1781403]
- [netdrv] ice: Support IPv6 Flow Director filters (Jonathan Toppins) [1781403]
- [netdrv] ice: Support IPv4 Flow Director filters (Jonathan Toppins) [1781403]
- [netdrv] ice: Support displaying ntuple rules (Jonathan Toppins) [1781403]
- [netdrv] ice: Initialize Flow Director resources (Jonathan Toppins) [1781403]
- [netdrv] ice: Rename build_ctob to ice_build_ctob (Jonathan Toppins) [1781405]
- [netdrv] ice: remove unnecessary backslash (Jonathan Toppins) [1781405]
- [netdrv] ice: remove unnecessary check (Jonathan Toppins) [1781405]
- [netdrv] ice: remove unnecessary expression that is always true (Jonathan Toppins) [1781405]
- [netdrv] ice: Fix check for removing/adding mac filters (Jonathan Toppins) [1781405]
- [netdrv] ice: refactor filter functions (Jonathan Toppins) [1781405]
- [netdrv] ice: Fix resource leak on early exit from function (Jonathan Toppins) [1781405]
- [netdrv] ice: cleanup vf_id signedness (Jonathan Toppins) [1781405]
- [netdrv] ice: Fix casting issues (Jonathan Toppins) [1781405]
- [netdrv] ice: Provide more meaningful error message (Jonathan Toppins) [1781405]
- [netdrv] ice: Fix probe/open race condition (Jonathan Toppins) [1781405]
- [netdrv] ice: only drop link once when setting pauseparams (Jonathan Toppins) [1781405]
- [netdrv] ice: Fix check for contiguous TCs (Jonathan Toppins) [1781405]
- [netdrv] ice: Don't reset and rebuild for Tx timeout on PFC enabled queue (Jonathan Toppins) [1781405]
- [netdrv] ice: Add VF promiscuous support (Jonathan Toppins) [1781405]
- [netdrv] ice: Add support for tunnel offloads (Jonathan Toppins) [1781405]
- [netdrv] ice: report netlist version in .info_get (Jonathan Toppins) [1781405]
- [netdrv] ice: add additional E810 device id (Jonathan Toppins) [1725447]
- [x86] x86/split_lock: Update to use X86_MATCH_INTEL_FAM6_MODEL() (Prarit Bhargava) [1482757]
- [x86] x86/intel_split_lock: Disable split lock detector by default in RHEL8 (Prarit Bhargava) [1482757]
- [x86] x86/split_lock: Provide handle_guest_split_lock() (Prarit Bhargava) [1482757]
- [x86] x86/split_lock: Add Tremont family CPU models (Prarit Bhargava) [1482757]
- [x86] x86/split_lock: Bits in IA32_CORE_CAPABILITIES are not architectural (Prarit Bhargava) [1482757]
- [tools] tools arch x86: Sync asm/cpufeatures.h with the kernel sources (Prarit Bhargava) [1482757]
- [tools] tools arch x86: Sync the msr-index.h copy with the kernel sources (Prarit Bhargava) [1482757]
- [x86] x86/split_lock: Avoid runtime reads of the TEST_CTRL MSR (Prarit Bhargava) [1482757]
- [x86] x86/split_lock: Rework the initialization flow of split lock detection (Prarit Bhargava) [1482757]
- [x86] x86/split_lock: Enable split lock detection by kernel (Prarit Bhargava) [1482757]
- [netdrv] drivers/net/b44: Change to non-atomic bit operations on pwol_mask (Prarit Bhargava) [1482757]
- [x86] x86/cpu: Align cpu_caps_cleared and cpu_caps_set to unsigned long (Prarit Bhargava) [1482757]
- [x86] x86/boot: Make the GDT 8-byte aligned (Prarit Bhargava) [1482757]
- [wireless] wlcore: simplify/fix/optimize reg_ch_conf_pending operations (Prarit Bhargava) [1482757]
- [uapi] prctl: PR_{G, S}ET_IO_FLUSHER to support controlling memory reclaim (Waiman Long) [1757240]

* Fri Jul 10 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-224.el8]
- [kernel] kernel: fork: avoid utilizing a non-initialized task_struct_rh pointer in the error exit path (Rafael Aquini) [1838475 1820041]
- [infiniband] RDMA/ipoib: Fix ABBA deadlock with ipoib_reap_ah() (Kamal Heib) [1846063]
- [infiniband] RDMA/ipoib: Return void from ipoib_ib_dev_stop() (Kamal Heib) [1846063]
- [powerpc] mm/pkeys: Make pkey access check work on execute_only_key (Greg Kurz) [1748772]
- [powerpc] mm/book3s64: Fix MADV_DONTNEED and parallel page fault race (Greg Kurz) [1748772]
- [mm] change pmdp_huge_get_and_clear_full take vm_area_struct as arg (Greg Kurz) [1748772]
- [powerpc] mm/book3s64: Avoid sending IPI on clearing PMD (Greg Kurz) [1748772]
- [powerpc] 64s: Fix THP PMD collapse serialisation (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Use pte_present instead of opencoding _PAGE_PRESENT check (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Use find_kvm_host_pte in kvmppc_get_hpa (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: use find_kvm_host_pte in kvmppc_book3s_instantiate_page (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Avoid using rmap to protect parallel page table update (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: use find_kvm_host_pte in pute_tce functions (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Use find_kvm_host_pte in h_enter (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Use find_kvm_host_pte in page fault handler (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Add helper for host page table walk (Greg Kurz) [1748772]
- [powerpc] kvm: ppc: Fix nested guest RC bits update (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Use kvm helpers to walk shadow or secondary table (Greg Kurz) [1748772]
- [powerpc] kvm/nested: Add helper to walk nested shadow linux page table (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: Add helper to walk partition scoped linux page table (Greg Kurz) [1748772]
- [powerpc] kvm/book3s: switch from raw_spin_*lock to arch_spin_lock (Greg Kurz) [1748772]
- [powerpc] perf/callchain: Use __get_user_pages_fast in read_user_stack_slow (Greg Kurz) [1748772]
- [powerpc] mce: Don't reload pte val in addr_to_pfn (Greg Kurz) [1748772]
- [powerpc] book3s64/hash: Use the pte_t address from the caller (Greg Kurz) [1748772]
- [powerpc] hash64: Restrict page table lookup using init_mm with __flush_hash_table_range (Greg Kurz) [1748772]
- [powerpc] mm/hash64: use _PAGE_PTE when checking for pte_present (Greg Kurz) [1748772]
- [powerpc] pkeys: Check vma before returning key fault error to the user (Greg Kurz) [1748772]
- [powerpc] pkeys: Avoid using lockless page table walk (Greg Kurz) [1748772]
- [powerpc] mmu: add is_strict_kernel_rwx() helper (Greg Kurz) [1748772]
- [powerpc] mm: move update_mmu_cache() into book3s hash utils (Greg Kurz) [1748772]
- [powerpc] mm: Move book3s32 specifics in subdirectory mm/book3s64 (Greg Kurz) [1748772]
- [powerpc] mm: move FSL_BOOK3 version of update_mmu_cache() (Greg Kurz) [1748772]
- [powerpc] mm: define empty update_mmu_cache() as static inline (Greg Kurz) [1748772]
- [powerpc] change CONFIG_PPC_STD_MMU to CONFIG_PPC_BOOK3S (Greg Kurz) [1748772]
- [powerpc] mm: don't use _PAGE_EXEC for calling hash_preload() (Greg Kurz) [1748772]
- [powerpc] change CONFIG_PPC_STD_MMU_32 to CONFIG_PPC_BOOK3S_32 (Greg Kurz) [1748772]
- [powerpc] handover page flags with a pgprot_t parameter (Greg Kurz) [1748772]
- [powerpc] mm: properly set PAGE_KERNEL flags in ioremap() (Greg Kurz) [1748772]
- [powerpc] 32: Add ioremap_wt() and ioremap_coherent() (Greg Kurz) [1748772]
- [netdrv] crypto/chcr: error seen if CONFIG_CHELSIO_TLS_DEVICE isn't set (Christoph von Recklinghausen) [1797945]
- [crypto] cxgb4/chcr: avoid -Wreturn-local-addr warning (Christoph von Recklinghausen) [1797945]
- [netdrv] cxgb4: fix EOTID leak when disabling TC-MQPRIO offload (Christoph von Recklinghausen) [1797945]
- [netdrv] cxgb4/chcr: Enable ktls settings at run time (Christoph von Recklinghausen) [1797945]
- [netdrv] cxgb4: cleanup error code in setup_sge_queues_uld() (Christoph von Recklinghausen) [1797945]
- [netdrv] cxgb4: add adapter hotplug support for ULDs (Christoph von Recklinghausen) [1797945]
- [crypto] Crypto: chelsio - Fixes a deadlock between rtnl_lock and uld_mutex (Christoph von Recklinghausen) [1797945]
- [netdrv] cxgb4/chcr: nic-tls stats in ethtool (Christoph von Recklinghausen) [1797945]
- [crypto] crypto/chcr: fix incorrect ipv6 packet length (Christoph von Recklinghausen) [1797945]
- [crypto] crypto/chcr: Add missing include file <linux/highmem.h> (Christoph von Recklinghausen) [1797945]
- [crypto] cxgb4/chcr: Add ipv6 support and statistics (Christoph von Recklinghausen) [1797945]
- [crypto] chcr: Handle first or middle part of record (Christoph von Recklinghausen) [1797945]
- [crypto] chcr: handle partial end part of a record (Christoph von Recklinghausen) [1797945]
- [crypto] cxgb4/chcr: complete record tx handling (Christoph von Recklinghausen) [1797945]
- [crypto] cxgb4/chcr: Save tx keys and handle HW response (Christoph von Recklinghausen) [1797945]
- [crypto] cxgb4/chcr : Register to tls add and del callback (Christoph von Recklinghausen) [1797945]
- [hwmon] hwmon: (acpi_power_meter) Change log level for 'unsafe software power cap' (Al Stone) [1749529]
- [netdrv] net/mlx4_core: fix a memory leak bug (Alaa Hleihel) [1846792]
- [netdrv] net/mlx4_core: Add missing iounmap() in error path (Alaa Hleihel) [1846792]
- [netdrv] net/mlx5: E-switch, Fix error unwinding flow for steering init failure (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: E-Switch, Enable chains only if regs loopback is enabled (Alaa Hleihel) [1848830 1846791]
- [netdrv] net/mlx5e: en_tc: Rely just on register loopback for tunnel restoration (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: E-Switch, Skip restore modify header between prios of same chain (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5e: CT: Fix ipv6 nat header rewrite actions (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Don't fail driver on failure to create debugfs (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Add missing mutex destroy (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Fix devlink objects and devlink device unregister sequence (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Wait for inactive autogroups (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Disable reload while removing the device (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5e: Fix ethtool hfunc configuration change (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5e: Fix repeated XSK usage on one channel (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: DR, Split RX and TX lock for parallel insertion (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: DR, Add a spinlock to protect the send ring (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: DR, Fix freeing in dr_create_rc_qp() (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Fix fatal error handling during device load (Alaa Hleihel) [1846791 1841363]
- [netdrv] net/mlx5: drain health workqueue in case of driver load error (Alaa Hleihel) [1846791 1841363]
- [netdrv] net/mlx5: Drain wq first during PCI device removal (Alaa Hleihel) [1846791]
- [netdrv] net/mlx5: Have single error unwinding path (Alaa Hleihel) [1846791]
- [netdrv] mlx5: reject unsupported coalescing params (Alaa Hleihel) [1846791]
- [crypto] Crypto: chelsio - Fixes a hang issue during driver registration (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - Use multiple txq/rxq per tfm to process the requests (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - Recalculate iv only if it is needed (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - un-register crypto algorithms (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - Endianess bug in create_authenc_wr (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - Print the chcr driver information while module load (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - This fixes the kernel panic which occurs during a libkcapi test (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - This fixes the libkcapi's cbc(aes) aio fail test cases (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - Resetting crypto counters during the driver unregister (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - fix writing tfm flags to wrong place (Vishal Kulkarni) [1845004]
- [crypto] crypto: chelsio - calculating tx_channel_id as per the max number of channels (Vishal Kulkarni) [1845004]
- [firmware] tpm: check event log version before reading final events (Jerry Snitselaar) [1839284]
- [char] tpm: Fix TIS locality timeout problems (Jerry Snitselaar) [1840789]

* Tue Jul 07 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-223.el8]
- [vfio] vfio/pci: Clear error and request eventfd ctx after releasing (Alex Williamson) [1847731]
- [fs] pNFS/flexfiles: Fix list corruption if the mirror count changes (Benjamin Coddington) [1852500]
- [netdrv] ionic: update the queue count on open (Michal Schmidt) [1846879]
- [tools] turbostat: Use sched_getcpu() instead of hardcoded cpu 0 (Prarit Bhargava) [1852123]
- [infiniband] RDMA/hfi1: Fix null-pointer dereference when calling mmu_notifier_register (Kamal Heib) [1850345]
- [platform] Revert "intel-speed-select: Firmware workarounds for Icelake" (Prarit Bhargava) [1820597]
- [powerpc] powerpc/crashkernel: Take "mem=" option into account (Pingfan Liu) [1747969]
- [tools] perf stat: Increase perf metric output resolution (Michael Petlan) [1844632]
- [tools] perf vendor events power9: Add missing metrics to POWER9 'cpi_breakdown' (Michael Petlan) [1844632]
- [tools] perf metrics: Fix parse errors in power8 metrics (Michael Petlan) [1844632]
- [tools] perf metrics: Fix parse errors in power9 metrics (Michael Petlan) [1844632]
- [s390] s390/kaslr: add support for R_390_JMP_SLOT relocation type (Claudio Imbrenda) [1850908]
- [s390] s390: prevent leaking kernel address in BEAR (Claudio Imbrenda) [1850907]
- [s390] s390/cpumf: Adjust registration of s390 PMU device drivers (Claudio Imbrenda) [1850906]
- [firmware] efi/x86: Add TPM related EFI tables to unencrypted mapping checks (Lenny Szubowicz) [1849922]
- [security] selinux: allow reading labels before policy is loaded (Ondrej Mosnacek) [1839819]
- [idle] intel_idle: Introduce 'use_acpi' module parameter (Prarit Bhargava) [1849666]
- [net] xsk: Add overflow check for u64 division, stored into u32 (Jiri Benc) [1838075]
- [tools] selftests: netdevsim: Always initialize 'RET' variable (Jiri Benc) [1838075]
- [netdrv] netdevsim: Ensure policer drop counter always increases (Jiri Benc) [1838075]
- [tools] selftests/bpf: Check for correct program attach/detach in xdp_attach test (Jiri Benc) [1838075]
- [tools] libbpf: Fix type of old_fd in bpf_xdp_set_link_opts (Jiri Benc) [1838075]
- [net] xsk: Add missing check on user supplied headroom size (Jiri Benc) [1838075]
- [net] xdp: Reset prog in dev_change_xdp_fd when fd is negative (Jiri Benc) [1838075]
- [netdrv] veth: rely on peer veth_rq for ndo_xdp_xmit accounting (Jiri Benc) [1838075]
- [netdrv] veth: rely on veth_rq in veth_xdp_flush_bq signature (Jiri Benc) [1838075]
- [net] page pool: allow to pass zero flags to page_pool_init() (Jiri Benc) [1838075]
- [tools] selftests/bpf: Add tests for attaching XDP programs (Jiri Benc) [1838075]
- [tools] libbpf: Add function to set link XDP fd while specifying old program (Jiri Benc) [1838075]
- [tools] Add EXPECTED_FD-related definitions in if_link.h (Jiri Benc) [1838075]
- [net] xdp: Support specifying expected existing program when attaching XDP (Jiri Benc) [1838075]
- [netdrv] veth: remove atomic64_add from veth_xdp_xmit hotpath (Jiri Benc) [1838075]
- [netdrv] veth: introduce more xdp counters (Jiri Benc) [1838075]
- [netdrv] veth: distinguish between rx_drops and xdp_drops (Jiri Benc) [1838075]
- [netdrv] veth: introduce more specialized counters in veth_stats (Jiri Benc) [1838075]
- [netdrv] veth: move xdp stats in a dedicated structure (Jiri Benc) [1838075]
- [net] xdp: Replace zero-length array with flexible-array member (Jiri Benc) [1838075]
- [net] bpf: inet_diag: Dump bpf_sk_storages in inet_diag_dump() (Jiri Benc) [1838075]
- [net] bpf: INET_DIAG support in bpf_sk_storage (Jiri Benc) [1838075]
- [net] inet_diag: Move the INET_DIAG_REQ_BYTECODE nlattr to cb->data (Jiri Benc) [1838075]
- [net] inet_diag: Refactor inet_sk_diag_fill(), dump(), and dump_one() (Jiri Benc) [1838075]
- [net] inet_diag: return classid for all socket types (Jiri Benc) [1838075]
- [net] inet_diag: fix reporting cgroup classid and fallback to priority (Jiri Benc) [1838075]
- [net] Remove unneeded export of a couple of xdp generic functions (Jiri Benc) [1838075]
- [net] page_pool: API cleanup and comments (Jiri Benc) [1838075]
- [net] bpf, sockmap: Replace zero-length array with flexible-array member (Jiri Benc) [1838075]
- [netdrv] geneve: allow changing DF behavior after creation (Sabrina Dubroca) [1847861]
- [net] netfilter: nf_tables: add missing ->release_ops() in error path of newrule() (Andrea Claudi) [1846236]
- [net] netfilter: nft_compat: use .release_ops and remove list of extension (Andrea Claudi) [1846236]
- [net] ipv6: fix IPV6_ADDRFORM operation logic (Hangbin Liu) [1842025]
- [net] ipv6: fix restrict IPV6_ADDRFORM operation (Hangbin Liu) [1842025]
- [net] netfilter: nat: fix error handling upon registering inet hook (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: fix module autoload for redir (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: fix module autoload with inet family (Florian Westphal) [1579145]
- [net] netfilter: nft_chain_nat: inet family is missing module ownership (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: Support auto-loading for inet nat (Florian Westphal) [1579145]
- [net] netfilter: nft_redir: fix module autoload with ip4 (Florian Westphal) [1579145]
- [net] netfilter: nat: fix udp checksum corruption (Florian Westphal) [1579145]
- [tools] kselftests: extend nft_nat with inet family based nat hooks (Florian Westphal) [1579145]
- [net] netfilter: nft_redir: add inet support (Florian Westphal) [1579145]
- [net] netfilter: nft_masq: add inet support (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: merge route type into core (Florian Westphal) [1579145]
- [net] netfilter: nat: add inet family nat support (Florian Westphal) [1579145]
- [net] netfilter: nat: don't register device notifier twice (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: merge ipv4 and ipv6 nat chain types (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: nat: merge nft_masq protocol specific modules (Florian Westphal) [1579145]
- [net] netfilter: nf_tables: nat: merge nft_redir protocol specific modules (Florian Westphal) [1579145]
- [net] netfilter: nat: remove nf_nat_l3proto.h and nf_nat_core.h (Florian Westphal) [1579145]
- [net] netfilter: nat: remove l3proto struct (Florian Westphal) [1579145]
- [net] netfilter: nat: remove csum_recalc hook (Florian Westphal) [1579145]
- [net] netfilter: nat: remove csum_update hook (Florian Westphal) [1579145]
- [net] netfilter: nat: remove l3 manip_pkt hook (Florian Westphal) [1579145]
- [net] netfilter: nat: remove nf_nat_l4proto.h (Florian Westphal) [1579145]
- [net] netfilter: nat: merge nf_nat_ipv4, 6 into nat core (Florian Westphal) [1579145]
- [net] netfilter: nat: fix spurious connection timeouts (Florian Westphal) [1579145]
- [net] netfilter: nat: move nlattr parse and xfrm session decode to core (Florian Westphal) [1579145]
- [net] netfilter: nat: merge ipv4 and ipv6 masquerade functionality (Florian Westphal) [1579145]
- [net] netfilter: kconfig: nat related expression depend on nftables core (Florian Westphal) [1579145]
- [net] netfilter: conntrack: fix bogus port values for other l4 protocols (Florian Westphal) [1579145]
- [net] netfilter: conntrack: avoid unneeded nf_conntrack_l4proto lookups (Florian Westphal) [1579145]
- [net] netfilter: conntrack: remove pernet l4 proto register interface (Florian Westphal) [1579145]
- [net] netfilter: conntrack: remove remaining l4proto indirect packet calls (Florian Westphal) [1579145]
- [net] netfilter: conntrack: remove module owner field (Florian Westphal) [1579145]
- [net] netfilter: conntrack: remove invert_tuple callback (Florian Westphal) [1579145]
- [net] netfilter: conntrack: remove pkt_to_tuple callback (Florian Westphal) [1579145]
- [net] netfilter: conntrack: udp: set stream timeout to 2 minutes (Florian Westphal) [1579145]
- [net] netfilter: conntrack: udp: only extend timeout to stream mode after 2s (Florian Westphal) [1579145]
- [net] netfilter: nat: un-export nf_nat_used_tuple (Florian Westphal) [1579145]
- [net] netfilter: nat: fix ICMP header corruption on ICMP errors (Florian Westphal) [1579145]
- [net] netfilter: nat: fix icmp id randomization (Florian Westphal) [1579145]
- [net] netfilter: nat: remove nf_nat_l4proto struct (Florian Westphal) [1579145]
- [net] netfilter: nat: remove l4proto->manip_pkt (Florian Westphal) [1579145]
- [net] netfilter: nat: remove l4proto->nlattr_to_range (Florian Westphal) [1579145]
- [net] netfilter: nat: remove l4proto->in_range (Florian Westphal) [1579145]
- [net] netfilter: nat: fold in_range indirection into caller (Florian Westphal) [1579145]
- [net] netfilter: nat: remove l4proto->unique_tuple (Florian Westphal) [1579145]
- [net] netfilter: nat: un-export nf_nat_l4proto_unique_tuple (Florian Westphal) [1579145]
- [net] netfilter: remove NF_NAT_RANGE_PROTO_RANDOM support (Florian Westphal) [1579145]
- [x86] kvm: x86/pmu: Tweak kvm_pmu_get_msr to pass 'struct msr_data' in (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: do not pass poisoned hva to __kvm_set_memory_region (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: fix sync_with_host() in smm_test (Vitaly Kuznetsov) [1849987]
- [x86] kvm: async_pf: Inject 'page ready' event only if 'page not present' was previously injected (Vitaly Kuznetsov) [1849987]
- [x86] revert "kvm: async_pf: Fix #DF due to inject "Page not Present" and "Page Ready" exceptions simultaneously" (Vitaly Kuznetsov) [1849987]
- [virt] kvm: async_pf: Cleanup kvm_setup_async_pf() (Vitaly Kuznetsov) [1849987]
- [x86] kvm: i8254: remove redundant assignment to pointer s (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: respect singlestep when emulating instruction (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: Don't probe KVM_CAP_HYPERV_ENLIGHTENED_VMCS when nested VMX is unsupported (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: do not substitute SVM/VMX check with KVM_CAP_NESTED_STATE check (Vitaly Kuznetsov) [1849987]
- [x86] kvm: nvmx: Consult only the "basic" exit reason when routing nested exit (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: Unexport x86_fpu_cache and make it static (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: Ignore KVM 5-level paging support for VM_MODE_PXXV48_4K (Vitaly Kuznetsov) [1849987]
- [virt] kvm: x86: Fix APIC page invalidation race (Vitaly Kuznetsov) [1849987]
- [x86] kvm: svm: fix calls to is_intercept (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: fix vmx_preemption_timer_test build with GCC10 (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: Add x86_64/debug_regs to .gitignore (Vitaly Kuznetsov) [1849987]
- [x86] revert "kvm: x86: work around leak of uninitialized stack contents" (Vitaly Kuznetsov) [1849987]
- [x86] kvm: vmx: Properly handle kvm_read/write_guest_virt*() result (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: emulate reserved nops from 0f/18 to 0f/1f (Vitaly Kuznetsov) [1849987]
- [tools] kvm: selftests: Fix build with "make ARCH=x86_64" (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: minor code refactor and comments fixup around dirty logging (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: avoid unnecessary rmap walks when creating/moving slots (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: remove unnecessary rmap walk of read-only memslots (Vitaly Kuznetsov) [1849987]
- [virt] kvm: Use vmemdup_user() (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: Move MPK feature detection to common code (Vitaly Kuznetsov) [1849987]
- [x86] kvm: x86: Assign correct value to array.maxnent (Vitaly Kuznetsov) [1849987]
- [x86] kvm: let kvm_destroy_vm_debugfs clean up vCPU debugfs directories (Vitaly Kuznetsov) [1849987]
- [x86] kvm: Handle reads of SandyBridge RAPL PMU MSRs rather than injecting #GP (Vitaly Kuznetsov) [1849987]
- [documentation] docs: virt/kvm: close inline string literal (Vitaly Kuznetsov) [1849987]
- [documentation] docs: kvm: Fix KVM_KVMCLOCK_CTRL API doc (Vitaly Kuznetsov) [1849987]
- [x86] arch/x86/kvm/svm/sev.c: change flag passed to GUP fast in sev_pin_memory() (Vitaly Kuznetsov) [1849987]
- [virt] kvm/eventfd: remove unneeded conversion to bool (Vitaly Kuznetsov) [1849987]
- [tools] selftests: fix kvm relocatable native/cross builds and installs (Vitaly Kuznetsov) [1849987]
- [virt] kvm: x86: move kvm_create_vcpu_debugfs after last failure point (Vitaly Kuznetsov) [1849987]
- [powerpc] xive: Share the event-queue page with the Hypervisor (Michael Roth) [1837232]
- [powerpc] kvm: ppc: book3s hv: Read ibm, secure-memory nodes (Michael Roth) [1837232]
- [powerpc] kvm: ppc: book3s hv: Relax check on H_SVM_INIT_ABORT (Michael Roth) [1837232]

* Wed Jul 01 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-222.el8]
- [scsi] scsi: be2iscsi: Use scnprintf() for avoiding potential buffer overflow (Maurizio Lombardi) [1849586]
- [edac] EDAC/i10nm: Update driver to support different bus number config register offsets (Aristeu Rozanski) [1838508]
- [edac] EDAC, {skx, i10nm}: Make some configurations CPU model specific (Aristeu Rozanski) [1838508]
- [fs] fuse: copy_file_range should truncate cache (Miklos Szeredi) [1849786]
- [fs] fuse: fix copy_file_range cache issues (Miklos Szeredi) [1849786]
- [fs] fuse: update attr_version counter on fuse_notify_inval_inode() (Miklos Szeredi) [1849786]
- [fs] fuse: don't check refcount after stealing page (Miklos Szeredi) [1849786]
- [fs] fuse: fix weird page warning (Miklos Szeredi) [1849786]
- [fs] fuse: use dump_page (Miklos Szeredi) [1849786]
- [fs] fuse: always allow query of st_dev (Miklos Szeredi) [1849786]
- [fs] fuse: always flush dirty data on close(2) (Miklos Szeredi) [1849786]
- [fs] fuse: invalidate inode attr in writeback cache mode (Miklos Szeredi) [1849786]
- [fs] virtiofs: schedule blocking async replies in separate worker (Miklos Szeredi) [1849786]
- [fs] fuse: Support RENAME_WHITEOUT flag (Miklos Szeredi) [1849786]
- [fs] fuse: don't overflow LLONG_MAX with end offset (Miklos Szeredi) [1849786]
- [fs] fix up iter on short count in fuse_direct_io() (Miklos Szeredi) [1849786]
- [fs] fuse: fix fuse_send_readpages() in the syncronous read case (Miklos Szeredi) [1849786]
- [fs] fuse: fix Kconfig indentation (Miklos Szeredi) [1849786]
- [fs] virtiofs: Use completions while waiting for queue to be drained (Miklos Szeredi) [1849786]
- [fs] virtiofs: Do not send forget request "struct list_head" element (Miklos Szeredi) [1849786]
- [fs] virtiofs: Use a common function to send forget (Miklos Szeredi) [1849786]
- [fs] virtiofs: Fix old-style declaration (Miklos Szeredi) [1849786]
- [fs] fuse: verify nlink (Miklos Szeredi) [1849786]
- [fs] fuse: verify write return (Miklos Szeredi) [1849786]
- [fs] fuse: verify attributes (Miklos Szeredi) [1849786]
- [fs] fuse: redundant get_fuse_inode() calls in fuse_writepages_fill() (Miklos Szeredi) [1849786]
- [fs] fuse: truncate pending writes on O_TRUNC (Miklos Szeredi) [1849786]
- [fs] fuse: flush dirty data/metadata before non-truncate setattr (Miklos Szeredi) [1849786]
- [fs] ovl: initialize error in ovl_copy_xattr (Miklos Szeredi) [1849770]
- [fs] ovl: fix redirect traversal on metacopy dentries (Miklos Szeredi) [1849770]
- [fs] ovl: initialize OVL_UPPERDATA in ovl_lookup() (Miklos Szeredi) [1849770]
- [fs] ovl: use only uppermetacopy state in ovl_lookup() (Miklos Szeredi) [1849770]
- [fs] ovl: simplify setting of origin for index lookup (Miklos Szeredi) [1849770]
- [fs] ovl: fix out of bounds access warning in ovl_check_fb_len() (Miklos Szeredi) [1849770]
- [fs] ovl: return required buffer size for file handles (Miklos Szeredi) [1849770]
- [fs] ovl: sync dirty data when remounting to ro mode (Miklos Szeredi) [1849770]
- [fs] ovl: resolve more conflicting mount options (Miklos Szeredi) [1849770]
- [fs] ovl: potential crash in ovl_fid_to_fh() (Miklos Szeredi) [1849770]
- [fs] ovl: clear ATTR_OPEN from attr->ia_valid (Miklos Szeredi) [1849770]
- [fs] ovl: clear ATTR_FILE from attr->ia_valid (Miklos Szeredi) [1849770]
- [documentation] ovl: document xino expected behavior (Miklos Szeredi) [1849770]
- [fs] ovl: enable xino automatically in more cases (Miklos Szeredi) [1849770]
- [fs] ovl: avoid possible inode number collisions with xino=on (Miklos Szeredi) [1849770]
- [fs] ovl: use a private non-persistent ino pool (Miklos Szeredi) [1849770]
- [fs] ovl: fix WARN_ON nlink drop to zero (Miklos Szeredi) [1849770]
- [fs] ovl: fix a typo in comment (Miklos Szeredi) [1849770]
- [fs] ovl: replace zero-length array with flexible-array member (Miklos Szeredi) [1849770]
- [fs] ovl: ovl_obtain_alias(): don't call d_instantiate_anon() for old (Miklos Szeredi) [1849770]
- [fs] ovl: strict upper fs requirements for remote upper fs (Miklos Szeredi) [1849770]
- [fs] ovl: check if upper fs supports RENAME_WHITEOUT (Miklos Szeredi) [1849770]
- [fs] ovl: allow remote upper (Miklos Szeredi) [1849770]
- [fs] ovl: decide if revalidate needed on a per-dentry basis (Miklos Szeredi) [1849770]
- [fs] ovl: separate detection of remote upper layer from stacked overlay (Miklos Szeredi) [1849770]
- [fs] ovl: restructure dentry revalidation (Miklos Szeredi) [1849770]
- [fs] ovl: ignore failure to copy up unknown xattrs (Miklos Szeredi) [1849770]
- [documentation] ovl: document permission model (Miklos Szeredi) [1849770]
- [fs] ovl: simplify i_ino initialization (Miklos Szeredi) [1849770]
- [fs] ovl: factor out helper ovl_get_root() (Miklos Szeredi) [1849770]
- [fs] ovl: fix out of date comment and unreachable code (Miklos Szeredi) [1849770]
- [fs] ovl: fix value of i_ino for lower hardlink corner case (Miklos Szeredi) [1849770]
- [fs] ovl: fix lockdep warning for async write (Miklos Szeredi) [1849770]
- [fs] ovl: fix some xino configurations (Miklos Szeredi) [1849770]
- [fs] ovl: fix lock in ovl_llseek() (Miklos Szeredi) [1849770]
- [fs] ovl: fix lseek overflow on 32bit (Miklos Szeredi) [1849770]
- [documentation] docs: filesystems: add overlayfs to index.rst (Miklos Szeredi) [1849770]
- [fs] ovl: add splice file read write helper (Miklos Szeredi) [1849770]
- [fs] ovl: implement async IO routines (Miklos Szeredi) [1849770]
- [fs] vfs: add vfs_iocb_iter_helper functions (Miklos Szeredi) [1849770]
- [fs] ovl: layer is const (Miklos Szeredi) [1849770]
- [fs] ovl: fix corner case of non-constant st_dev; st_ino (Miklos Szeredi) [1849770]
- [fs] ovl: fix corner case of conflicting lower layer uuid (Miklos Szeredi) [1849770]
- [fs] ovl: generalize the lower_fsarray (Miklos Szeredi) [1849770]
- [fs] ovl: simplify ovl_same_sb() helper (Miklos Szeredi) [1849770]
- [fs] ovl: generalize the lower_layersarray (Miklos Szeredi) [1849770]
- [fs] ovl: improving copy-up efficiency for big sparse file (Miklos Szeredi) [1849770]
- [fs] ovl: use ovl_inode_lock in ovl_llseek() (Miklos Szeredi) [1849770]
- [fs] ovl: use pr_fmt auto generate prefix (Miklos Szeredi) [1849770]
- [fs] ovl: fix wrong WARN_ON() in ovl_cache_update_ino() (Miklos Szeredi) [1849770]
- [fs] locks: print unsigned ino in /proc/locks (Miklos Szeredi) [1849770]
- [documentation] docs: filesystems: overlayfs: Fix restview warnings (Miklos Szeredi) [1849770]
- [fs] ovl: relax WARN_ON() on rename to self (Miklos Szeredi) [1849770]
- [fs] ovl: fix corner case of non-unique st_dev; st_ino (Miklos Szeredi) [1849770]
- [fs] ovl: don't use a temp buf for encoding real fh (Miklos Szeredi) [1849770]
- [fs] ovl: make sure that real fid is 32bit aligned in memory (Miklos Szeredi) [1849770]
- [fs] ovl: fix lookup failure on multi lower squashfs (Miklos Szeredi) [1849770]
- [fs] ovl: filter of trusted xattr results in audit (Miklos Szeredi) [1849770]
- [fs] ovl: Fix dereferencing possible ERR_PTR() (Miklos Szeredi) [1849770]
- [fs] ovl: fix regression caused by overlapping layers detection (Miklos Szeredi) [1849770]
- [fs] ovl: make i_ino consistent with st_ino in more cases (Miklos Szeredi) [1849770]
- [fs] ovl: fix typo in MODULE_PARM_DESC (Miklos Szeredi) [1849770]
- [fs] ovl: fix bogus -Wmaybe-unitialized warning (Miklos Szeredi) [1849770]
- [fs] ovl: don't fail with disconnected lower NFS (Miklos Szeredi) [1849770]
- [fs] ovl: detect overlapping layers (Miklos Szeredi) [1849770]
- [fs] ovl: using posix_acl_xattr_size() to get size instead of posix_acl_to_xattr() (Miklos Szeredi) [1849770]
- [fs] ovl: abstract ovl_inode lock with a helper (Miklos Szeredi) [1849770]
- [fs] ovl: remove the 'locked' argument of ovl_nlink_{start, end} (Miklos Szeredi) [1849770]
- [fs] ovl: relax requirement for non null uuid of lower fs (Miklos Szeredi) [1849770]
- [fs] ovl: fold copy-up helpers into callers (Miklos Szeredi) [1849770]
- [fs] ovl: untangle copy up call chain (Miklos Szeredi) [1849770]
- [fs] ovl: clean up error handling in ovl_get_tmpfile() (Miklos Szeredi) [1849770]
- [netdrv] ionic: tame the watchdog timer on reconfig (Jonathan Toppins) [1846879 1846280]
- [remoteproc] remoteproc: pull in slab.h (Jarod Wilson) [1849080]

* Thu Jun 25 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-221.el8]
- [x86] revert "kvm: vmx: Micro-optimize vmexit time when not exposing PMU" (Vitaly Kuznetsov) [1844099]
- [fs] nfsd4: kill warnings on testing stateids with mismatched clientids (Benjamin Coddington) [1765672]
- [fs] NFS: Ensure security label is set for root inode (Scott Mayhew) [1660798]
- [s390] kexec: Fix file verification on S390 (Lianbo Jiang) [1815369]
- [s390] kexec_file: split KEXEC_VERIFY_SIG into KEXEC_SIG and KEXEC_SIG_FORCE (Lianbo Jiang) [1815369]
- [netdrv] ibmvnic: continue to init in CRQ reset returns H_CLOSED (Steve Best) [1850179]
- [net] sunrpc: add missing newline when printing parameter 'auth_hashtable_size' by sysfs (Benjamin Coddington) [1849998]
- [net] sunrpc: clean up properly in gss_mech_unregister() (Benjamin Coddington) [1849998]
- [net] sunrpc: svcauth_gss_register_pseudoflavor must reject duplicate registrations (Benjamin Coddington) [1849998]
- [net] SUNRPC: Fix backchannel RPC soft lockups (Benjamin Coddington) [1849998]
- [fs] NFS: Fix a page leak in nfs_destroy_unlinked_subrequests() (Benjamin Coddington) [1849998]
- [fs] nfsd4: make drc_slab global, not per-net (Benjamin Coddington) [1849998]
- [net] SUNRPC: Fix GSS privacy computation of auth->au_ralign (Benjamin Coddington) [1849998]
- [net] SUNRPC: Add "@len" parameter to gss_unwrap() (Benjamin Coddington) [1849998]
- [fs] NFS: finish_automount() requires us to hold 2 refs to the mount record (Benjamin Coddington) [1849998]
- [fs] NFS: Fix use-after-free issues in nfs_pageio_add_request() (Benjamin Coddington) [1849998]
- [fs] NFS: alloc_nfs_open_context() must use the file cred when available (Benjamin Coddington) [1849998]
- [net] libceph: don't omit used_replica in target_copy() (Jeff Layton) [1847528]
- [net] libceph: don't omit recovery_deletes in target_copy() (Jeff Layton) [1847528]
- [net] libceph: move away from global osd_req_flags (Jeff Layton) [1847528]
- [fs] ceph: skip checking caps when session reconnecting and releasing reqs (Jeff Layton) [1847528]
- [fs] ceph: make sure mdsc->mutex is nested in s->s_mutex to fix dead lock (Jeff Layton) [1847528]
- [fs] ceph: don't return -ESTALE if there's still an open file (Jeff Layton) [1847528]
- [include] libceph, rbd: replace zero-length array with flexible-array (Jeff Layton) [1847528]
- [fs] ceph: allow rename operation under different quota realms (Jeff Layton) [1847528]
- [fs] ceph: normalize 'delta' parameter usage in check_quota_exceeded (Jeff Layton) [1847528]
- [fs] ceph: ceph_kick_flushing_caps needs the s_mutex (Jeff Layton) [1847528]
- [fs] ceph: request expedited service on session's last cap flush (Jeff Layton) [1847528]
- [fs] ceph: convert mdsc->cap_dirty to a per-session list (Jeff Layton) [1847528]
- [fs] ceph: reset i_requested_max_size if file write is not wanted (Jeff Layton) [1847528]
- [fs] ceph: throw a warning if we destroy session with mutex still locked (Jeff Layton) [1847528]
- [fs] ceph: fix potential race in ceph_check_caps (Jeff Layton) [1847528]
- [fs] ceph: document what protects i_dirty_item and i_flushing_item (Jeff Layton) [1847528]
- [fs] ceph: don't take i_ceph_lock in handle_cap_import (Jeff Layton) [1847528]
- [fs] ceph: don't release i_ceph_lock in handle_cap_trunc (Jeff Layton) [1847528]
- [fs] ceph: add comments for handle_cap_flush_ack logic (Jeff Layton) [1847528]
- [fs] ceph: split up __finish_cap_flush (Jeff Layton) [1847528]
- [fs] ceph: reorganize __send_cap for less spinlock abuse (Jeff Layton) [1847528]
- [fs] ceph: flush release queue when handling caps for unknown inode (Jeff Layton) [1847528]
- [net] libceph: ignore pool overlay and cache logic on redirects (Jeff Layton) [1847528]
- [x86] kvm: lapic: ensure APIC map is up to date on concurrent update requests (Igor Mammedov) [1835330]
- [x86] kvm: lapic: fix broken vcpu hotplug (Igor Mammedov) [1835330]
- [netdrv] net: hns3: add some error checking in hclge_tm module (Mark Langsdorf) [1809057] {CVE-2019-15925}
- [fs] udf: Fix mounting of Win7 created UDF filesystems (Oleksandr Natalenko) [1842400]
- [netdrv] net: qed: fixes crash while running driver in kdump kernel (Manish Chopra) [1727746]
- [netdrv] net: qed: Disable SRIOV functionality inside kdump kernel (Manish Chopra) [1727746]
- [netdrv] net: qed*: Reduce RX and TX default ring count when running inside kdump kernel (Manish Chopra) [1727746]
- [fs] cifs: dump Security Type info in DebugData (Leif Sahlberg) [1845390]
- [net] netfilter: flowtable: Make nf_flow_table_offload_add/del_cb inline (Marcelo Leitner) [1840938]
- [net] sched: act_ct: Make tcf_ct_flow_table_restore_skb inline (Marcelo Leitner) [1840938]
- [net] netfilter: flowtable: Add pending bit for offload work (Marcelo Leitner) [1842670]
- [net] Evict neighbor entries on carrier down (Ivan Vecera) [1845352]
- [net] bridge: explicitly zero is_sticky in fdb_create (Ivan Vecera) [1845350]
- [net] bridge: add support for sticky fdb entries (Ivan Vecera) [1845350]
- [net] remove indirect block netdev event registration (Marcelo Leitner) [1841300]
- [netdrv] bnxt_tc: update indirect block support (Marcelo Leitner) [1841300]
- [netdrv] nfp: update indirect block support (Marcelo Leitner) [1841300]
- [netdrv] mlx5: update indirect block support (Marcelo Leitner) [1841300]
- [net] use flow_indr_dev_setup_offload() (Marcelo Leitner) [1841300]
- [net] cls_api: add tcf_block_offload_init() (Marcelo Leitner) [1841300]
- [net] flow_offload: consolidate indirect flow_block infrastructure (Marcelo Leitner) [1841300]
- [net] netfilter: nf_flowtable: expose nf_flow_table_gc_cleanup() (Marcelo Leitner) [1841300]
- [fs] iomap: Handle memory allocation failure in readahead (Carlos Maiolino) [1828792]
- [fs] iomap: fix comments in iomap_dio_rw (Carlos Maiolino) [1828792]
- [fs] iomap: Remove pgoff from tracepoints (Carlos Maiolino) [1828792]
- [fs] fs: Fix page_mkwrite off-by-one errors (Carlos Maiolino) [1828792]
- [fs] iomap: stop using ioend after it's been freed in iomap_finish_ioend() (Carlos Maiolino) [1828792]
- [fs] iomap: fix sub-page uptodate handling (Carlos Maiolino) [1828792]
- [fs] iomap: remove unneeded variable in iomap_dio_rw() (Carlos Maiolino) [1828792]
- [fs] iomap: Do not create fake iter in iomap_dio_bio_actor() (Carlos Maiolino) [1828792]
- [fs] iomap: trace iomap_appply results (Carlos Maiolino) [1828792]
- [fs] fs/iomap: remove redundant check in iomap_dio_rw() (Carlos Maiolino) [1828792]
- [fs] iomap: use a srcmap for a read-modify-write I/O (Carlos Maiolino) [1828792]
- [fs] iomap: renumber IOMAP_HOLE to 0 (Carlos Maiolino) [1828792]
- [fs] iomap: use write_begin to read pages to unshare (Carlos Maiolino) [1828792]
- [fs] iomap: move the zeroing case out of iomap_read_page_sync (Carlos Maiolino) [1828792]
- [fs] iomap: ignore non-shared or non-data blocks in xfs_file_dirty (Carlos Maiolino) [1828792]
- [fs] iomap: always use AOP_FLAG_NOFS in iomap_write_begin (Carlos Maiolino) [1828792]
- [fs] iomap: remove the unused iomap argument to __iomap_write_end (Carlos Maiolino) [1828792]
- [fs] iomap: better document the IOMAP_F_* flags (Carlos Maiolino) [1828792]
- [fs] iomap: enhance writeback error message (Carlos Maiolino) [1828792]
- [fs] iomap: pass a struct page to iomap_finish_page_writeback (Carlos Maiolino) [1828792]
- [fs] iomap: cleanup iomap_ioend_compare (Carlos Maiolino) [1828792]
- [fs] iomap: move struct iomap_page out of iomap.h (Carlos Maiolino) [1828792]
- [fs] iomap: warn on inline maps in iomap_writepage_map (Carlos Maiolino) [1828792]
- [fs] iomap: lift the xfs writeback code to iomap (Carlos Maiolino) [1828792]
- [fs] iomap: lift common tracing code from xfs to iomap (Carlos Maiolino) [1828792]
- [fs] iomap: zero newly allocated mapped blocks (Carlos Maiolino) [1828792]
- [fs] xfs: remove the fork fields in the writepage_ctx and ioend (Carlos Maiolino) [1828792]
- [fs] xfs: turn io_append_trans into an io_private void pointer (Carlos Maiolino) [1828792]
- [fs] xfs: refactor the ioend merging code (Carlos Maiolino) [1828792]
- [fs] xfs: use a struct iomap in xfs_writepage_ctx (Carlos Maiolino) [1828792]
- [fs] xfs: set IOMAP_F_NEW more carefully (Carlos Maiolino) [1828792]
- [fs] xfs: initialize iomap->flags in xfs_bmbt_to_iomap (Carlos Maiolino) [1828792]
- [fs] xfs: Use iomap_dio_rw to wait for unaligned direct IO (Carlos Maiolino) [1828792]
- [fs] iomap: Allow forcing of waiting for running DIO in iomap_dio_rw() (Carlos Maiolino) [1828792]
- [fs] iomap: move the iomap_dio_rw ->end_io callback into a structure (Carlos Maiolino) [1828792]
- [fs] iomap: split size and error for iomap_dio_rw ->end_io (Carlos Maiolino) [1828792]
- [fs] iomap: fix Invalid License ID (Carlos Maiolino) [1828792]
- [fs] iomap: move internal declarations into fs/iomap/ (Carlos Maiolino) [1828792]
- [fs] iomap: move the main iteration code into a separate file (Carlos Maiolino) [1828792]
- [fs] iomap: move the buffered IO code into a separate file (Carlos Maiolino) [1828792]
- [fs] iomap: move the direct IO code into a separate file (Carlos Maiolino) [1828792]
- [fs] iomap: move the SEEK_HOLE code into a separate file (Carlos Maiolino) [1828792]
- [fs] iomap: move the file mapping reporting code into a separate file (Carlos Maiolino) [1828792]
- [fs] iomap: move the swapfile code into a separate file (Carlos Maiolino) [1828792]
- [fs] iomap: start moving code to fs/iomap/ (Carlos Maiolino) [1828792]
- [fs] iomap: move iomap_read_inline_data around (Carlos Maiolino) [1828792]
- [fs] iomap: convert to SPDX identifier (Carlos Maiolino) [1828792]
- [fs] iomap: remove duplicated include from iomap.c (Carlos Maiolino) [1828792]
- [netdrv] fjes: Handle workqueue allocation failure (Masayoshi Mizuma) [1830565] {CVE-2019-16231}

* Wed Jun 24 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-220.el8]
- [fs] NFSv4: Ensure the delegation cred is pinned when we call delegreturn (Benjamin Coddington) [1848933]
- [fs] NFSv4: Ensure the delegation is pinned in nfs_do_return_delegation() (Benjamin Coddington) [1848933]
- [fs] NFSv4.1 make cachethis=no for writes (Benjamin Coddington) [1848933]
- [fs] NFSv4: Fix revalidation of dentries with delegations (Benjamin Coddington) [1848933]
- [fs] NFSv4: Fix races between open and dentry revalidation (Benjamin Coddington) [1848933]
- [fs] NFS: Fix up directory verifier races (Benjamin Coddington) [1848933]
- [net] sunrpc: expiry_time should be seconds not timeval (Benjamin Coddington) [1848933]
- [fs] NFSv4.0: nfs4_do_fsinfo() should not do implicit lease renewals (Benjamin Coddington) [1848933]
- [fs] NFSv4: try lease recovery on NFS4ERR_EXPIRED (Benjamin Coddington) [1848933]
- [fs] NFS: Fix memory leaks (Benjamin Coddington) [1848933]
- [fs] nfs: optimise readdir cache page invalidation (Benjamin Coddington) [1848933]
- [fs] NFS: Switch readdir to using iterate_shared() (Benjamin Coddington) [1848933]
- [fs] NFS: Use kmemdup_nul() in nfs_readdir_make_qstr() (Benjamin Coddington) [1848933]
- [fs] NFS: Directory page cache pages need to be locked when read (Benjamin Coddington) [1848933]
- [fs] NFS: Fix memory leaks and corruption in readdir (Benjamin Coddington) [1848933]
- [net] SUNRPC: Use kmemdup_nul() in rpc_parse_scope_id() (Benjamin Coddington) [1848933]
- [fs] NFS: Replace various occurrences of kstrndup() with kmemdup_nul() (Benjamin Coddington) [1848933]
- [fs] NFSv4: Limit the total number of cached delegations (Benjamin Coddington) [1848933]
- [fs] NFSv4: Add accounting for the number of active delegations held (Benjamin Coddington) [1848933]
- [fs] NFSv4: Try to return the delegation immediately when marked for return on close (Benjamin Coddington) [1848933]
- [fs] NFS: Clear NFS_DELEGATION_RETURN_IF_CLOSED when the delegation is returned (Benjamin Coddington) [1848933]
- [fs] NFSv4: nfs_inode_evict_delegation() should set NFS_DELEGATION_RETURNING (Benjamin Coddington) [1848933]
- [fs] NFS: nfs_find_open_context() should use cred_fscmp() (Benjamin Coddington) [1848933]
- [fs] NFS: nfs_access_get_cached_rcu() should use cred_fscmp() (Benjamin Coddington) [1848933]
- [fs] NFSv3: FIx bug when using chacl and chmod to change acl (Benjamin Coddington) [1848933]
- [fs] NFSv4.x recover from pre-mature loss of openstateid (Benjamin Coddington) [1848933]
- [fs] NFS: Trust cached access if we've already revalidated the inode once (Benjamin Coddington) [1848933]
- [fs] NFS: Fix nfs_direct_write_reschedule_io() (Benjamin Coddington) [1848933]
- [fs] NFS: When resending after a short write, reset the reply count to zero (Benjamin Coddington) [1848933]
- [fs] NFS: Improve tracing of permission calls (Benjamin Coddington) [1848933]
- [fs] NFS/pnfs: Fix pnfs_generic_prepare_to_resend_writes() (Benjamin Coddington) [1848933]
- [fs] NFS: Fix up fsync() when the server rebooted (Benjamin Coddington) [1848933]
- [net] SUNRPC: Remove broken gss_mech_list_pseudoflavors() (Benjamin Coddington) [1848933]
- [fs] NFS: Revalidate the file mapping on all fatal writeback errors (Benjamin Coddington) [1848933]
- [fs] NFS: Revalidate the file size on a fatal write error (Benjamin Coddington) [1848933]
- [fs] nfs: NFS_SWAP should depend on SWAP (Benjamin Coddington) [1848933]
- [net] SUNRPC: constify copied structure (Benjamin Coddington) [1848933]
- [fs] fs/nfs, swapon: check holes in swapfile (Benjamin Coddington) [1848933]
- [net] SUNRPC: call_connect_status should handle -EPROTO (Benjamin Coddington) [1848933]
- [fs] NFS: Introduce trace events triggered by page writeback errors (Benjamin Coddington) [1848933]
- [net] SUNRPC: Capture signalled RPC tasks (Benjamin Coddington) [1848933]
- [fs] NFS: move dprintk after nfs_alloc_fattr in nfs3_proc_lookup (Benjamin Coddington) [1848933]
- [fs] NFS4: Remove unneeded semicolon (Benjamin Coddington) [1848933]
- [fs] nfs: encode nfsv4 timestamps as 64-bit (Benjamin Coddington) [1848933]
- [fs] nfs: remove timespec from xdr_encode_nfstime (Benjamin Coddington) [1848933]
- [fs] nfs: use timespec64 in nfs_fattr (Benjamin Coddington) [1848933]
- [net] sunrpc: convert to time64_t for expiry (Benjamin Coddington) [1848933]
- [fs] nfsd: use true, false for bool variable in nfssvc.c (Benjamin Coddington) [1848933]
- [fs] nfsd: use true, false for bool variable in nfs4proc.c (Benjamin Coddington) [1848933]
- [fs] nfsd: use true, false for bool variable in vfs.c (Benjamin Coddington) [1848933]
- [fs] nfsd: remove nfs4_reset_lease() declarations (Benjamin Coddington) [1848933]
- [fs] nfsd: use ktime_get_real_seconds() in nfs4_verifier (Benjamin Coddington) [1848933]
- [fs] nfsd: use boottime for lease expiry calculation (Benjamin Coddington) [1848933]
- [fs] nfsd: fix jiffies/time_t mixup in LRU list (Benjamin Coddington) [1848933]
- [fs] nfsd: fix delay timer on 32-bit architectures (Benjamin Coddington) [1848933]
- [fs] nfsd: use time64_t in nfsd_proc_setattr() check (Benjamin Coddington) [1848933]
- [fs] nfsd: pass a 64-bit guardtime to nfsd_setattr() (Benjamin Coddington) [1848933]
- [fs] nfsd: make 'boot_time' 64-bit wide (Benjamin Coddington) [1848933]
- [fs] nfsd: use timespec64 in encode_time_delta (Benjamin Coddington) [1848933]
- [fs] nfsd: handle nfs3 timestamps as unsigned (Benjamin Coddington) [1848933]
- [fs] nfsd: print 64-bit timestamps in client_info_show (Benjamin Coddington) [1848933]
- [fs] nfsd: use ktime_get_seconds() for timestamps (Benjamin Coddington) [1848933]
- [fs] nfsd: remove unnecessary assertion in nfsd4_encode_replay (Benjamin Coddington) [1848933]
- [fs] nfsd: Clone should commit src file metadata too (Benjamin Coddington) [1848933]
- [fs] nfsd4: Remove unneeded semicolon (Benjamin Coddington) [1848933]
- [fs] nfs: fix timstamp debug prints (Benjamin Coddington) [1848933]
- [net] nfs: use time64_t internally (Benjamin Coddington) [1848933]
- [fs] nfsd: Return the correct number of bytes written to the file (Benjamin Coddington) [1848933]
- [fs] nfsd: Fix up some unused variable warnings (Benjamin Coddington) [1848933]
- [kernel] blktrace: ensure our debugfs dir exists (Ming Lei) [1816559] {CVE-2019-19770}
- [kernel] blktrace: fix debugfs use after free (Ming Lei) [1816559] {CVE-2019-19770}
- [block] loop: be paranoid on exit and prevent new additions / removals (Ming Lei) [1816559] {CVE-2019-19770}
- [kernel] blktrace: annotate required lock on do_blk_trace_setup() (Ming Lei) [1816559] {CVE-2019-19770}
- [block] block: revert back to synchronous request_queue removal (Ming Lei) [1816559] {CVE-2019-19770}
- [block] block: clarify context for refcount increment helpers (Ming Lei) [1816559] {CVE-2019-19770}
- [block] block: add docs for gendisk / request_queue refcount helpers (Ming Lei) [1816559] {CVE-2019-19770}
- [kernel] blktrace: no need to check return value of debugfs_create functions (Ming Lei) [1816559] {CVE-2019-19770}
- [kernel] blktrace: Avoid sparse warnings when assigning q->blk_trace (Ming Lei) [1816559] {CVE-2019-19770}
- [kernel] blktrace: break out of blktrace setup on concurrent calls (Ming Lei) [1816559] {CVE-2019-19770}
- [nvme] nvme-fc: don't call nvme_cleanup_cmd() for AENs (Ewan Milne) [1847572]
- [nvme] nvme-fc: convert assoc_active flag to bit op (Ewan Milne) [1847572]
- [nvme] nvme-fc: Ensure private pointers are NULL if no data (Ewan Milne) [1847572]
- [nvme] nvme-multipath: do not reset on unknown status (Ewan Milne) [1847572]
- [documentation] x86/speculation: Add Ivy Bridge to affected list (Josh Poimboeuf) [1827192] {CVE-2020-0543}
- [documentation] x86/speculation: Add SRBDS vulnerability and mitigation documentation (Josh Poimboeuf) [1827192] {CVE-2020-0543}
- [x86] x86/speculation: Add Special Register Buffer Data Sampling (SRBDS) mitigation (Josh Poimboeuf) [1827192] {CVE-2020-0543}
- [x86] x86/cpu: Add 'table' argument to cpu_matches() (Josh Poimboeuf) [1827192] {CVE-2020-0543}
- [x86] x86/cpu: Add a steppings field to struct x86_cpu_id (Josh Poimboeuf) [1827192] {CVE-2020-0543}
- [x86] x86/cpu/bugs: Convert to new matching macros (Josh Poimboeuf) [1827192] {CVE-2020-0543}
- [crypto] crypto: simd - correctly take reqsize of wrapped skcipher into account (Mark Salter) [1830471]
- [fs] nfsd: depend on CRYPTO_MD5 for legacy client tracking (Benjamin Coddington) [1847468]
- [fs] nfsd: check for EBUSY from vfs_rmdir/vfs_unink (Benjamin Coddington) [1847468]
- [fs] NFS: Fallocate should use the nfs4_fattr_bitmap (Benjamin Coddington) [1847468]
- [fs] NFS: Return -ETXTBSY when attempting to write to a swapfile (Benjamin Coddington) [1847468]
- [fs] fs: nfs: sysfs: Remove NULL check before kfree (Benjamin Coddington) [1847468]
- [fs] NFS: remove unneeded semicolon (Benjamin Coddington) [1847468]
- [fs] NFSv4: add declaration of current_stateid (Benjamin Coddington) [1847468]
- [include] sunrpc: remove __KERNEL__ ifdefs (Benjamin Coddington) [1847468]
- [fs] nfsd: document callback_wq serialization of callback code (Benjamin Coddington) [1847468]
- [fs] nfsd: mark cb path down on unknown errors (Benjamin Coddington) [1847468]
- [net] SUNRPC: Avoid RPC delays when exiting suspend (Benjamin Coddington) [1847468]
- [fs] NFSv4: Don't retry the GETATTR on old stateid in nfs4_delegreturn_done() (Benjamin Coddington) [1847468]
- [fs] NFSv4: Handle NFS4ERR_OLD_STATEID in delegreturn (Benjamin Coddington) [1847468]
- [fs] NFSv4: Fix races between open and delegreturn (Benjamin Coddington) [1847468]
- [fs] NFS: nfs_inode_find_state_and_recover() fix stateid matching (Benjamin Coddington) [1847468]
- [fs] NFSv4: Fix nfs4_inode_make_writeable() (Benjamin Coddington) [1847468]
- [fs] NFSv4: nfs4_return_incompatible_delegation() should check delegation validity (Benjamin Coddington) [1847468]
- [fs] NFSv4: Don't reclaim delegations that have been returned or revoked (Benjamin Coddington) [1847468]
- [fs] NFSv4: Ignore requests to return the delegation if it was revoked (Benjamin Coddington) [1847468]
- [fs] NFSv4: Revoke the delegation on success in nfs4_delegreturn_done() (Benjamin Coddington) [1847468]
- [fs] NFSv4: Update the stateid seqid in nfs_revoke_delegation() (Benjamin Coddington) [1847468]
- [fs] NFSv4: Clear the NFS_DELEGATION_REVOKED flag in nfs_update_inplace_delegation() (Benjamin Coddington) [1847468]
- [fs] NFSv4: Hold the delegation spinlock when updating the seqid (Benjamin Coddington) [1847468]
- [fs] NFSv4: Don't remove the delegation from the super_list more than once (Benjamin Coddington) [1847468]
- [fs] NFS: Rename nfs_inode_return_delegation_noreclaim() (Benjamin Coddington) [1847468]
- [fs] NFSv4: fail nfs4_refresh_delegation_stateid() when the delegation was revoked (Benjamin Coddington) [1847468]
- [fs] NFSv4: Delegation recalls should not find revoked delegations (Benjamin Coddington) [1847468]
- [fs] NFSv4: nfs4_callback_getattr() should ignore revoked delegations (Benjamin Coddington) [1847468]
- [fs] NFSv4: Fix delegation handling in update_open_stateid() (Benjamin Coddington) [1847468]
- [fs] NFSv4.1: Don't rebind to the same source port when reconnecting to the server (Benjamin Coddington) [1847468]
- [fs] NFS/pnfs: Separate NFSv3 DS and MDS traffic (Benjamin Coddington) [1847468]
- [fs] pNFS: nfs3_set_ds_client should set NFS_CS_NOPING (Benjamin Coddington) [1847468]
- [fs] NFS: Add a flag to tell nfs_client to set RPC_CLNT_CREATE_NOPING (Benjamin Coddington) [1847468]
- [fs] NFS: Use non-atomic bit ops when initialising struct nfs_client_initdata (Benjamin Coddington) [1847468]
- [fs] NFSv3: Clean up timespec encode (Benjamin Coddington) [1847468]
- [fs] NFSv2: Clean up timespec encode (Benjamin Coddington) [1847468]
- [fs] NFSv2: Fix a typo in encode_sattr() (Benjamin Coddington) [1847468]
- [fs] NFSv4: NFSv4 callbacks also support 64-bit timestamps (Benjamin Coddington) [1847468]
- [fs] NFSv4: Encode 64-bit timestamps (Benjamin Coddington) [1847468]
- [fs] NFS: Convert struct nfs_fattr to use struct timespec64 (Benjamin Coddington) [1847468]
- [fs] NFS: If nfs_mountpoint_expiry_timeout < 0, do not expire submounts (Benjamin Coddington) [1847468]
- [net] SUNRPC: Add trace points to observe transport congestion control (Benjamin Coddington) [1847468]
- [net] SUNRPC: Eliminate log noise in call_reserveresult (Benjamin Coddington) [1847468]
- [fs] nfsd: remove private bin2hex implementation (Benjamin Coddington) [1847468]
- [fs] nfsd: remove set but not used variable 'len' (Benjamin Coddington) [1847468]
- [fs] NFSv3: fix rpc receive buffer size for MOUNT call (Steve Dickson) [1837034]
- [fs] NFS: remove unused macros (Steve Dickson) [1837034]
- [mm] mm, slab: fix sign conversion problem in memcg_uncharge_slab() (Waiman Long) [1849016]
- [mm] mm: fix false-positive OVERCOMMIT_GUESS failures (Waiman Long) [1849016]
- [mm] mm: remove CONFIG_MIGRATE_VMA_HELPER (Karol Herbst) [1847908]
- [nvdimm] libnvdimm: Export the target_node attribute for regions and namespaces (Jeff Moyer) [1783157]
- [dax] dax: Add numa_node to the default device-dax attributes (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Simplify root read-only definition for the 'resource' attribute (Jeff Moyer) [1783157]
- [dax] dax: Simplify root read-only definition for the 'resource' attribute (Jeff Moyer) [1783157]
- [dax] dax: Create a dax device_type (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Move nvdimm_bus_attribute_group to device_type (Jeff Moyer) [1783157]
- [acpi] libnvdimm: Move nvdimm_attribute_group to device_type (Jeff Moyer) [1783157]
- [acpi] libnvdimm: Move nd_mapping_attribute_group to device_type (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Move nd_region_attribute_group to device_type (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Move nd_numa_attribute_group to device_type (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Move nd_device_attribute_group to device_type (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Move region attribute group definition (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm: Move attribute groups to device type (Jeff Moyer) [1783157]
- [nvdimm] libnvdimm/region: Initialize bad block for volatile namespaces (Jeff Moyer) [1783157]
- [x86] x86/mce: Add Xeon Icelake to list of CPUs that support PPIN (Steve Best) [1848710]
- [powerpc] powerpc/kernel: Enables memory hot-remove after reboot on pseries guests (David Gibson) [1848844]
- [fs] cifs: multichannel: try to rebind when reconnecting a channel (Leif Sahlberg) [1842759]
- [fs] cifs: multichannel: use pointer for binding channel (Leif Sahlberg) [1842759]
- [fs] cifs: multichannel: move channel selection above transport layer (Leif Sahlberg) [1842759]
- [fs] cifs: move some variables off the stack in smb2_ioctl_query_info (Leif Sahlberg) [1842759]
- [fs] cifs: reduce stack use in smb2_compound_op (Leif Sahlberg) [1842759]
- [fs] cifs: multichannel: always zero struct cifs_io_parms (Leif Sahlberg) [1842759]
- [fs] smb3: default to minimum of two channels when multichannel specified (Leif Sahlberg) [1842759]
- [fs] cifs: multichannel: move channel selection in function (Leif Sahlberg) [1842759]
- [mm] x86/init: fix build with CONFIG_SWAP=n (Waiman Long) [1839415]
- [netdrv] ionic: add pcie_print_link_status (Jonathan Toppins) [1846506]
- [netdrv] ionic: no link check while resetting queues (Jonathan Toppins) [1846953]
- [netdrv] ionic: export features for vlans to use (Jonathan Toppins) [1846868]
- [netdrv] ionic: remove support for mgmt device (Jonathan Toppins) [1846506]
- [netdrv] ionic: wait on queue start until after IFF_UP (Jonathan Toppins) [1844924]
- [netdrv] ionic: add more ethtool stats (Jonathan Toppins) [1848149]
- [netdrv] ionic: more ionic name tweaks (Jonathan Toppins) [1848149]
- [netdrv] ionic: ionic_intr_free parameter change (Jonathan Toppins) [1848149]
- [netdrv] ionic: reset device at probe (Jonathan Toppins) [1848149]
- [netdrv] ionic: shorter dev cmd wait time (Jonathan Toppins) [1848149]
- [netdrv] ionic: add support for more xcvr types (Jonathan Toppins) [1848149]
- [netdrv] ionic: protect vf calls from fw reset (Jonathan Toppins) [1848149]
- [netdrv] ionic: updates to ionic FW api description (Jonathan Toppins) [1848149]
- [netdrv] ionic: support longer tx sg lists (Jonathan Toppins) [1848149]
- [netdrv] ionic: Use debugfs_create_bool() to export bool (Jonathan Toppins) [1848149]
- [netdrv] drivers:Remove inclusion of vermagic header (Jonathan Toppins) [1848149]
- [net] SUNRPC: Destroy the back channel when we destroy the host transport (Benjamin Coddington) [1846984]
- [net] SUNRPC: fix race to sk_err after xs_error_report (Benjamin Coddington) [1846984]
- [fs] NFS: Remove redundant mirror tracking in O_DIRECT (Benjamin Coddington) [1846984]
- [fs] nfs: Fix nfsi->nrequests count error on nfs_inode_remove_request (Benjamin Coddington) [1846984]
- [net] sunrpc: clean up indentation issue (Benjamin Coddington) [1846984]
- [fs] NFS: Optimise the default readahead size (Benjamin Coddington) [1846984]
- [fs] nfsd: fix nfs read eof detection (Benjamin Coddington) [1846984]
- [fs] nfsd: Make nfsd_reset_boot_verifier_locked static (Benjamin Coddington) [1846984]
- [fs] NFSv4: Handle NFS4ERR_OLD_STATEID in LOCKU (Benjamin Coddington) [1846984]
- [fs] NFSv4: Handle NFS4ERR_OLD_STATEID in CLOSE/OPEN_DOWNGRADE (Benjamin Coddington) [1846984]
- [fs] NFSv4: Fix OPEN_DOWNGRADE error handling (Benjamin Coddington) [1846984]
- [fs] pNFS: Handle NFS4ERR_OLD_STATEID on layoutreturn by bumping the state seqid (Benjamin Coddington) [1846984]
- [fs] NFSv4: Add a helper to increment stateid seqids (Benjamin Coddington) [1846984]
- [fs] NFSv4: Handle RPC level errors in LAYOUTRETURN (Benjamin Coddington) [1846984]
- [fs] NFSv4: Handle NFS4ERR_DELAY correctly in return-on-close (Benjamin Coddington) [1846984]
- [fs] NFSv4: Clean up pNFS return-on-close error handling (Benjamin Coddington) [1846984]
- [fs] NFS: remove unused check for negative dentry (Benjamin Coddington) [1846984]
- [fs] NFSv3: use nfs_add_or_obtain() to create and reference inodes (Benjamin Coddington) [1846984]
- [fs] NFS: Refactor nfs_instantiate() for dentry referencing callers (Benjamin Coddington) [1846984]
- [fs] nfs_instantiate(): prevent multiple aliases for directory inode (Benjamin Coddington) [1846984]
- [net] SUNRPC: Rename xdr_buf_read_netobj to xdr_buf_read_mic (Benjamin Coddington) [1846984]
- [fs] nfsd: degraded slot-count more gracefully as allocation nears exhaustion (Benjamin Coddington) [1846984]
- [fs] nfsd: handle drc over-allocation gracefully (Benjamin Coddington) [1846984]
- [net] SUNRPC: RPC level errors should always set task->tk_rpc_status (Benjamin Coddington) [1846984]
- [fs] nfsd: Support the server resetting the boot verifier (Benjamin Coddington) [1846984]
- [net] sunrpc: Use kzfree rather than its implementation (Benjamin Coddington) [1846984]
- [fs] nfsd: eliminate an unnecessary acl size limit (Benjamin Coddington) [1846984]
- [fs] Deprecate nfsd fault injection (Benjamin Coddington) [1846984]
- [fs] NFS: Have nfs4_proc_get_lease_time() call nfs4_call_sync_custom() (Benjamin Coddington) [1846984]
- [fs] NFS: Have nfs41_proc_secinfo_no_name() call nfs4_call_sync_custom() (Benjamin Coddington) [1846984]
- [fs] NFS: Have nfs41_proc_reclaim_complete() call nfs4_call_sync_custom() (Benjamin Coddington) [1846984]
- [fs] NFS: Have _nfs4_proc_secinfo() call nfs4_call_sync_custom() (Benjamin Coddington) [1846984]
- [fs] NFS: Have nfs4_proc_setclientid() call nfs4_call_sync_custom() (Benjamin Coddington) [1846984]
- [fs] NFS: Add an nfs4_call_sync_custom() function (Benjamin Coddington) [1846984]
- [fs] NFSv4: Fix a memory leak bug (Benjamin Coddington) [1846984]
- [net] xprtrdma: Fix bc_max_slots return value (Benjamin Coddington) [1846984]
- [net] SUNRPC: Inline xdr_commit_encode (Benjamin Coddington) [1846984]
- [net] SUNRPC: Remove rpc_wake_up_queued_task_on_wq() (Benjamin Coddington) [1846984]
- [fs] fs: nfs: Fix possible null-pointer dereferences in encode_attrs() (Benjamin Coddington) [1846984]
- [fs] nfsd: Fix the documentation for svcxdr_tmpalloc() (Benjamin Coddington) [1846984]
- [fs] nfsd: Remove unnecessary NULL checks (Benjamin Coddington) [1846984]
- [s390] vfio-ccw: make vfio_ccw_regops variables declarations static (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Add trace for CRW event (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Wire up the CRW irq and CRW region (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Introduce a new CRW region (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Refactor IRQ handlers (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Introduce a new schib region (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Refactor the unregister of the async regions (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Register a chp_event callback for vfio-ccw (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Introduce new helper functions to free/destroy regions (Cornelia Huck) [1660917]
- [documentation] vfio-ccw: document possible errors (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Enable transparent CCW IPL from DASD (Cornelia Huck) [1660917]
- [s390] cio: generate delayed uevent for vfio-ccw subchannels (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Use the correct style for SPDX License Identifier (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Rework the io_fctl trace (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Add a trace for asynchronous requests (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Trace the FSM jumptable (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Refactor how the traces are built (Cornelia Huck) [1660917]
- [s390] vfio-ccw: fix error return code in vfio_ccw_sch_init() (Cornelia Huck) [1660917]
- [s390] vfio-ccw: add some logging (Cornelia Huck) [1660917]
- [s390] vfio-ccw: make vfio_ccw_async_region_ops static (Cornelia Huck) [1660917]
- [documentation] documentation: fix vfio-ccw doc (Cornelia Huck) [1660917]
- [documentation] vfio-ccw: Update documentation for csch/hsch (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Don't call cp_free if we are processing a channel program (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Set pa_nr to 0 if memory allocation fails for pa_iova_pfn (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Fix memory leak and don't call cp_free in cp_init (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Fix misleading comment when setting orb.cmd.c64 (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Fix the conversion of Format-0 CCWs to Format-1 (Cornelia Huck) [1660917]
- [s390] cio: introduce driver_override on the css bus (Cornelia Huck) [1660917]
- [s390] vfio-ccw: make convert_ccw0_to_ccw1 static (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Remove copy_ccw_from_iova() (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Factor out the ccw0-to-ccw1 transition (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Copy CCW data outside length calculation (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Skip second copy of guest cp to host (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Move guest_cp storage into common struct (Cornelia Huck) [1660917]
- [s390] cio: Combine direct and indirect CCW paths (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Rearrange IDAL allocation in direct CCW (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Remove pfn_array_table (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Adjust the first IDAW outside of the nested loops (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Rearrange pfn_array and pfn_array_table arrays (Cornelia Huck) [1660917]
- [s390] cio: Use generalized CCW handler in cp_init() (Cornelia Huck) [1660917]
- [s390] cio: Generalize the TIC handler (Cornelia Huck) [1660917]
- [s390] cio: Refactor the routine that handles TIC CCWs (Cornelia Huck) [1660917]
- [s390] cio: Squash cp_free() and cp_unpin_free() (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Destroy kmem cache region on module exit (Cornelia Huck) [1660917]
- [documentation] docs: s390: convert docs to ReST and rename to *.rst (Cornelia Huck) [1660917]
- [s390] cio: Remove vfio-ccw checks of command codes (Cornelia Huck) [1660917]
- [s390] cio: Allow zero-length CCWs in vfio-ccw (Cornelia Huck) [1660917]
- [s390] cio: Don't pin vfio pages for empty transfers (Cornelia Huck) [1660917]
- [s390] cio: Initialize the host addresses in pfn_array (Cornelia Huck) [1660917]
- [s390] cio: Split pfn_array_alloc_pin into pieces (Cornelia Huck) [1660917]
- [s390] cio: Set vfio-ccw FSM state before ioeventfd (Cornelia Huck) [1660917]
- [s390] cio: Update SCSW if it points to the end of the chain (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Prevent quiesce function going into an infinite loop (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Release any channel program when releasing/removing vfio-ccw mdev (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Do not call flush_workqueue while holding the spinlock (Cornelia Huck) [1660917]
- [s390] vfio-ccw: add handling for async channel instructions (Cornelia Huck) [1660917]
- [s390] cio: export hsch to modules (Cornelia Huck) [1660917]
- [s390] vfio-ccw: add capabilities chain (Cornelia Huck) [1660917]
- [s390] vfio-ccw: protect the I/O region (Cornelia Huck) [1660917]
- [s390] vfio-ccw: rework ssch state handling (Cornelia Huck) [1660917]
- [s390] vfio-ccw: make it safe to access channel programs (Cornelia Huck) [1660917]
- [s390] vfio: ccw: only free cp on final interrupt (Cornelia Huck) [1660917]
- [s390] cio: Use cpa range elsewhere within vfio-ccw (Cornelia Huck) [1660917]
- [s390] cio: Fix vfio-ccw handling of recursive TICs (Cornelia Huck) [1660917]
- [s390] vfio-ccw: Don't assume there are more ccws after a TIC (Cornelia Huck) [1660917]
- [s390] vfio: ccw: Merge BUSY and BOXED states (Cornelia Huck) [1660917]
- [s390] cio: Fix cleanup when unsupported IDA format is used (Cornelia Huck) [1660917]
- [s390] cio: Fix cleanup of pfn_array alloc failure (Cornelia Huck) [1660917]
- [s390] vfio: ccw: Register mediated device once all structures are initialized (Cornelia Huck) [1660917]
- [s390] cio: make vfio_ccw_io_region static (Cornelia Huck) [1660917]
- [s390] cio: Fix how vfio-ccw checks pinned pages (Cornelia Huck) [1660917]
- [s390] cio: Refactor alloc of ccw_io_region (Cornelia Huck) [1660917]
- [s390] cio: Convert ccw_io_region to pointer (Cornelia Huck) [1660917]
- [netdrv] ibmvnic: Harden device login requests (Steve Best) [1847183]
- [mm] s390/cmm: fix information leak in cmm_timeout_handler() (Nico Pache) [1846532] {CVE-2020-10773}
- [fs] kernfs: fix potential null pointer dereference (Carlos Maiolino) [1847872]
- [netdrv] net: sfc: reject unsupported coalescing params (Jarod Wilson) [1844659]
- [netdrv] iavf: increase reset complete wait time (Stefan Assmann) [1844598]
- [netdrv] iavf: Fix reporting 2.5 Gb and 5Gb speeds (Stefan Assmann) [1844598]
- [netdrv] iavf: use appropriate enum for comparison (Stefan Assmann) [1844598]
- [netdrv] iavf: fix speed reporting over virtchnl (Stefan Assmann) [1844598]
- [block] blk-mq: fix blk_mq_all_tag_iter (Ming Lei) [1824037]
- [block] blk-mq: split out a __blk_mq_get_driver_tag helper (Ming Lei) [1824037]
- [block] blk-mq: drain I/O when all CPUs in a hctx are offline (Ming Lei) [1824037]
- [block] blk-mq: add blk_mq_all_tag_iter (Ming Lei) [1824037]
- [block] blk-mq: open code __blk_mq_alloc_request in blk_mq_alloc_request_hctx (Ming Lei) [1824037]
- [block] blk-mq: use BLK_MQ_NO_TAG in more places (Ming Lei) [1824037]
- [block] blk-mq: rename BLK_MQ_TAG_FAIL to BLK_MQ_NO_TAG (Ming Lei) [1824037]
- [block] blk-mq: move more request initialization to blk_mq_rq_ctx_init (Ming Lei) [1824037]
- [block] blk-mq: simplify the blk_mq_get_request calling convention (Ming Lei) [1824037]
- [block] blk-mq: remove a pointless queue enter pair in blk_mq_alloc_request_hctx (Ming Lei) [1824037]
- [block] blk-mq: remove a pointless queue enter pair in blk_mq_alloc_request (Ming Lei) [1824037]
- [block] blk-mq: move the call to blk_queue_enter_live out of blk_mq_get_request (Ming Lei) [1824037]
- [nvme] nvme: force complete cancelled requests (Ming Lei) [1824037]
- [block] blk-mq: blk-mq: provide forced completion method (Ming Lei) [1824037]
- [block] block: Limit number of items taken from the I/O scheduler in one go (Ming Lei) [1824037]
- [scsi] Revert "scsi: core: run queue if SCSI device queue isn't ready and queue is idle" (Ming Lei) [1824037]
- [block] blk-mq: Rerun dispatching in the case of budget contention (Ming Lei) [1824037]
- [block] blk-mq: Add blk_mq_delay_run_hw_queues() API call (Ming Lei) [1824037]
- [block] blk-mq: In blk_mq_dispatch_rq_list() "no budget" is a reason to kick (Ming Lei) [1824037]
- [block] blk-mq: Put driver tag in blk_mq_dispatch_rq_list() when no budget (Ming Lei) [1824037]
- [block] blk-mq: don't commit_rqs() if none were queued (Ming Lei) [1824037]
- [block] blk-mq: Remove some unused function arguments (Ming Lei) [1824037]
- [block] blk-mq-tag: document tag iteration helper return value (Ming Lei) [1824037]
- [block] blk-mq: Document the functions that iterate over requests (Ming Lei) [1824037]
- [block] loop: Better discard support for block devices (Ming Lei) [1824037]
- [block] loop: Report EOPNOTSUPP properly (Ming Lei) [1824037]
- [block] block: keep bdi->io_pages in sync with max_sectors_kb for stacked devices (Ming Lei) [1824037]
- [block] block, zoned: fix integer overflow with BLKRESETZONE et al (Ming Lei) [1824037]
- [block] block: Fix use-after-free issue accessing struct io_cq (Ming Lei) [1824037]
- [netdrv] cxgb4: add EOTID tracking and software context dump (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: tune burst buffer size for TC-MQPRIO offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: improve credits recovery in TC-MQPRIO Tx path (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix delete filter entry fail in unload path (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix large delays in PTP synchronization (Vishal Kulkarni) [1828665]
- [netdrv] net/cxgb4: Check the return from t4_query_params properly (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: free MQPRIO resources in shutdown path (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix MPS index overwrite when setting MAC address (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Add support to catch bits set in INT_CAUSE5 (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: remove set but not used variable 'tab' (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4/ptp: pass the sign of offset delta in FW CMD (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix Txq restart check during backpressure (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix throughput drop during Tx backpressure (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: rework TC filter rule insertion across regions (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: update T5/T6 adapter register ranges (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix checks for max queues to allocate (Vishal Kulkarni) [1828665]
- [netdrv] net/chelsio: Don't set N/A for not available FW (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Added tls stats prints (Vishal Kulkarni) [1828665]
- [netdrv] l2t_seq_next should increase position index (Vishal Kulkarni) [1828665]
- [netdrv] seq_tab_next() should increase position index (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: reject overlapped queues in TC-MQPRIO offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix Tx multi channel port rate limit (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4/cxgb4vf: fix flow control display for auto negotiation (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix refcount init for TC-MQPRIO offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4/chtls: fix ULD connection failures due to wrong TID base (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix missed high priority region calculation (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Fix kernel panic while accessing sge_info (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add support for high priority filters (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add stats for MQPRIO QoS offload Tx path (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add UDP segmentation offload support (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4/chcr: update SGL DMA unmap for USO (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add TC-MATCHALL classifier ingress offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: check rule prio conflicts before offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add TC-MATCHALL classifier egress offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: remove unneeded semicolon for switch block (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Fix an error code in cxgb4_mqprio_alloc_hw_resources() (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: make function 'cxgb4_mqprio_free_hw_resources' static (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: remove redundant assignment to hdr_len (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix 64-bit division on i386 (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Use match_string() helper to simplify the code (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add FLOWC based QoS offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add Tx and Rx path for ETHOFLD traffic (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: add ETHOFLD hardware queue support (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: parse and configure TC-MQPRIO offload (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: rework queue config and MSI-X allocation (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: query firmware for QoS offload resources (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Add pci reset handler (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4/l2t: Simplify 't4_l2e_free()' and '_t4_l2e_free()' (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: fix panic when attaching to ULD fail (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: request the TX CIDX updates to status page (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: Signedness bug in init_one() (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: no need to check return value of debugfs_create functions (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: smt: Use normal int for refcount (Vishal Kulkarni) [1828665]
- [netdrv] cxgb4: smt: Add lock for atomic_dec_and_test (Vishal Kulkarni) [1828665]
- [fs] xfs: clear PF_MEMALLOC before exiting xfsaild thread (Brian Foster) [1827912]

* Tue Jun 23 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-219.el8]
- [drm] drm/amd/display: Defer cursor lock until after VUPDATE (Lyude Paul) [1814893]
- [drm] drm/amd/display: Use cursor locking to prevent flip delays (Lyude Paul) [1814893]
- [drm] drm/amdgpu/display: Fix Pollock Variant Detection (Lyude Paul) [1814893]
- [drm] drm/amd/display: Fix RV2 Variant Detection (Lyude Paul) [1814893]
- [drm] drm/amdgpu/display: fix pci revision id fetching (Lyude Paul) [1814893]
- [drm] drm/nouveau/device: detect vGPUs (Lyude Paul) [1814893]
- [drm] drm/nouveau/device: detect if changing endianness failed (Lyude Paul) [1814893]
- [drm] drm/nouveau/device: rework mmio mapping code to get rid of second map (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/gm200-: detect and potentially disable HDA support on some SORs (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/gp100: split SOR implementation from gm200 (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp: modify OR allocation policy to account for HDA requirements (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp: split part of OR allocation logic into a function (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp: provide hint to OR allocation about HDA requirements (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/gt215-: fix race with audio driver runpm (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/hda/gv100-: NV_PDISP_SF_AUDIO_CNTRL0 register moved (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/hda/gf119-: select HDA device entry based on bound head (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/hda/gf119-: add HAL for programming device entry in SF (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/hda/gt215-: pass head to nvkm_ior.hda.eld() (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/gm200-: fix NV_PDISP_SOR_HDMI2_CTRL(n) selection (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/nv50-: Share DP SST mode_valid() handling with MST (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/nv50-: Move 8BPC limit for MST into nv50_mstc_get_modes() (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/gv100-: Add support for interlaced modes (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/nv50-: Probe SOR and PIOR caps for DP interlacing support (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/nv50-: Initialize core channel in nouveau_display_create() (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/gv100-: expose capabilities class (Lyude Paul) [1814893]
- [drm] drm/nouveau/disp/nv50-: increase timeout on pio channel free() polling (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/nv50-: wait for FIFO space on PIO channels (Lyude Paul) [1814893]
- [drm] drm/nouveau/nvif: protect waits against GPU falling off the bus (Lyude Paul) [1814893]
- [drm] drm/nouveau/nvif: access PTIMER through usermode class, if available (Lyude Paul) [1814893]
- [drm] drm/nouveau/ttm: evict other IO mappings when running out of BAR1 space (Lyude Paul) [1814893]
- [drm] drm/nouveau/kms/nv50-: clear SW state of disabled windows harder (Lyude Paul) [1814893]
- [drm] drm/i915/gen12: Add aux table invalidate for all engines (Lyude Paul) [1814893]
- [drm] drm/i915/gen12: Invalidate aux table entries forcibly (Lyude Paul) [1814893]
- [drm] drm/i915/gen12: Flush L3 (Lyude Paul) [1814893]
- [drm] drm/i915/gen12: Fix HDC pipeline flush (Lyude Paul) [1814893]
- [drm] Revert "drm/i915/tgl: Include ro parts of l3 to invalidate" (Lyude Paul) [1814893]
- [drm] drm/i915: Push MST link retraining to the hotplug work (Lyude Paul) [1814893]
- [drm] drm/i915: Flatten intel_dp_check_mst_status() a bit (Lyude Paul) [1814893]
- [drm] drm/i915/tc: Do not warn when aux power well of static TC ports timeout (Lyude Paul) [1814893]
- [drm] drm/i915/tc: Catch TC users accessing FIA registers without enable aux (Lyude Paul) [1814893]
- [drm] drm/i915/tc/tgl: Implement TC cold sequences (Lyude Paul) [1814893]
- [drm] drm/i915/tc: Skip ref held check for TC legacy aux power wells (Lyude Paul) [1814893]
- [drm] drm/i915/tc/icl: Implement TC cold sequences (Lyude Paul) [1814893]
- [drm] drm/i915/display: Split hsw_power_well_enable() into two (Lyude Paul) [1814893]
- [drm] drm/i915/display: Add intel_legacy_aux_to_power_domain() (Lyude Paul) [1814893]
- [drm] drm/i915/display: Move out code to return the digital_port of the aux ch (Lyude Paul) [1814893]
- [drm] drm/i915: Add missing deinitialization cases of load failure (Lyude Paul) [1814893]
- [drm] drm/i915: split intel_modeset_init() to pre/post irq install (Lyude Paul) [1814893]
- [drm] drm/i915: split i915_driver_modeset_probe() to pre/post irq install (Lyude Paul) [1814893]
- [drm] drm/i915: split i915_driver_modeset_remove() to pre/post irq uninstall (Lyude Paul) [1814893]
- [drm] drm/i915: split intel_modeset_driver_remove() to pre/post irq uninstall (Lyude Paul) [1814893]
- [drm] drm/i915: Extract skl SAGV checking (Lyude Paul) [1814893]
- [drm] drm/i915: Track active_pipes in bw_state (Lyude Paul) [1814893]
- [drm] drm/i915: Use bw state for per crtc SAGV evaluation (Lyude Paul) [1814893]
- [drm] drm/i915: Introduce intel_calc_active_pipes() (Lyude Paul) [1814893]
- [drm] drm/i915: Add pre/post plane updates for SAGV (Lyude Paul) [1814893]
- [drm] drm/i915: Prepare to extract gen specific functions from intel_can_enable_sagv (Lyude Paul) [1814893]
- [drm] drm/i915: Add intel_atomic_get_bw_*_state helpers (Lyude Paul) [1814893]
- [drm] drm/i915: Introduce skl_plane_wm_level accessor (Lyude Paul) [1814893]
- [drm] drm/i915: do AUD_FREQ_CNTRL state save on all gen9+ platforms (Lyude Paul) [1814893]
- [drm] drm/i915: Extend hotplug detect retry on TypeC connectors to 5 seconds (Lyude Paul) [1814893]
- [drm] drm/i915: Add a retry counter for hotplug detect retries (Lyude Paul) [1814893]
- [drm] drm/i915: Introduce intel_connector_hpd_pin() (Lyude Paul) [1814893]
- [drm] drm/i915: Prefer intel_connector over drm_connector in hotplug code (Lyude Paul) [1814893]
- [drm] drm/i915: Use intel_attached_encoder() (Lyude Paul) [1814893]
- [drm] drm/i915/ehl: Restrict w/a 1607087056 for EHL/JSL (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Initialize multicast register steering for workarounds (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Make Wa_14010229206 permanent (Lyude Paul) [1814893]
- [drm] drm/i915: Add Wa_1605460711 / Wa_1408767742 to ICL and EHL (Lyude Paul) [1814893]
- [drm] drm/i915: Apply Wa_1406680159:icl, ehl as an engine workaround (Lyude Paul) [1814893]
- [drm] drm/i915: Add Wa_1406306137:icl,ehl (Lyude Paul) [1814893]
- [drm] drm/i915: Add Wa_1604278689:icl,ehl (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Don't treat unslice registers as masked (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Make Wa_1606700617 permanent (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: WaDisableGPGPUMidThreadPreemption (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Move and restrict Wa_1408615072 (Lyude Paul) [1814893]
- [drm] drm/i915/gen11: Moving WAs to rcs_engine_wa_init() (Lyude Paul) [1814893]
- [drm] drm/i915: add Wa_14010594013: icl,ehl (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add Wa number to WaAllowPMDepthAndInvocationCountAccessFromUMD (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add note about Wa_1409142259 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Fix the Wa number of a fix (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add note about Wa_1607063988 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add note to Wa_1607297627 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Extend Wa_1606931601 for all steppings (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add Wa_1409085225, Wa_14010229206 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Implement Wa_1806527549 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Implement Wa_1409804808 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add Wa_1808121037 to tgl (Lyude Paul) [1814893]
- [drm] drm/i915: Use engine wa list for Wa_1607090982 (Lyude Paul) [1814893]
- [drm] drm/i915: Implement Wa_1607090982 (Lyude Paul) [1814893]
- [drm] drm/i915: Disable tesselation clock gating on tgl A0 (Lyude Paul) [1814893]
- [drm] drm/i915: Move ringbuffer WAs to engine workaround list (Lyude Paul) [1814893]
- [drm] drm/i915/gt: Skip rmw for masked registers (Lyude Paul) [1814893]
- [drm] drm/i915/selftests: Also wait for the scratch buffer to be bound (Lyude Paul) [1814893]
- [drm] drm/i915/dp: Return the right vswing tables (Lyude Paul) [1814893]
- [drm] drm/i915/dp/tgl+: Update combo phy vswing tables (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add definitions for VRR registers and bits (Lyude Paul) [1814893]
- [drm] drm/i915: use forced codec wake on all gen9+ platforms (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add new PCI IDs to TGL (Lyude Paul) [1814893]
- [drm] drm/i915/perf: Invalidate OA TLB on when closing perf stream (Lyude Paul) [1814893]
- [drm] Bump DRM backport version to 5.6.14 (Lyude Paul) [1814893]
- [drm] drm/i915/tgl+: Fix interrupt handling for DP AUX transactions (Lyude Paul) [1814893]
- [drm] drm/amd/amdgpu: add raven1 part to the gfxoff quirk list (Lyude Paul) [1814893]
- [drm] drm/amd/display: add basic atomic check for cursor plane (Lyude Paul) [1814893]
- [drm] Make the "Reducing compressed framebufer size" message be DRM_INFO_ONCE() (Lyude Paul) [1814893]
- [drm] drm/i915: Handle idling during i915_gem_evict_something busy loops (Lyude Paul) [1814893]
- [drm] drm/i915: Mark concurrent submissions with a weak-dependency (Lyude Paul) [1814893]
- [drm] drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest (Lyude Paul) [1814893]
- [drm] drm/amdgpu: force fbdev into vram (Lyude Paul) [1814893]
- [drm] drm/i915/gem: Remove object_is_locked assertion from unpin_from_display_plane (Lyude Paul) [1814893]
- [drm] drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC is disabled (Lyude Paul) [1814893]
- [drm] drm/i915/gt: Make timeslicing an explicit engine property (Lyude Paul) [1814893]
- [drm] drm/qxl: lost qxl_bo_kunmap_atomic_page in qxl_image_init_helper() (Lyude Paul) [1814893]
- [drm] drm/amd/display: Update downspread percent to match spreadsheet for DCN2.1 (Lyude Paul) [1814893]
- [drm] drm/amd/display: Defer cursor update around VUPDATE for all ASIC (Lyude Paul) [1814893]
- [drm] drm/amd/display: check if REFCLK_CNTL register is present (Lyude Paul) [1814893]
- [drm] drm/amd/powerplay: avoid using pm_en before it is initialized revised (Lyude Paul) [1814893]
- [drm] drm/amd/display: blank dp stream before re-train the link (Lyude Paul) [1814893]
- [drm] drm/i915/display: Load DP_TP_CTL/STATUS offset before use it (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: TBT AUX should use TC power well ops (Lyude Paul) [1814893]
- [drm] drm/i915/tgl: Add Wa_14010477008:tgl (Lyude Paul) [1814893]
- [drm] drm/amd/display: work around fp code being emitted outside of DC_FP_START/END (Lyude Paul) [1814893]
- [drm] drm/amdgpu: drop redundant cg/pg ungate on runpm enter (Lyude Paul) [1814893]
- [drm] drm/amdgpu: move kfd suspend after ip_suspend_phase1 (Lyude Paul) [1814893]
- [drm] drm/amdgpu: Fix oops when pp_funcs is unset in ACPI event (Lyude Paul) [1814893]
- [drm] drm/amdgpu: Correctly initialize thermal controller for GPUs with Powerplay table v0 (e.g Hawaii) (Lyude Paul) [1814893]
- [drm] drm/amd/powerplay: fix resume failed as smu table initialize early exit (Lyude Paul) [1814893]
- [drm] drm/bridge: anx6345: set correct BPC for display_info of connector (Lyude Paul) [1814893]
- [drm] drm/i915: Use proper fault mask in interrupt postinstall too (Lyude Paul) [1814893]
- [drm] drm/i915/selftests: Fix i915_address_space refcnt leak (Lyude Paul) [1814893]
- [drm] drm/qxl: qxl_release use after free (Lyude Paul) [1814893]
- [drm] drm/qxl: qxl_release leak in qxl_hw_surface_alloc() (Lyude Paul) [1814893]
- [drm] drm/qxl: qxl_release leak in qxl_draw_dirty_fb() (Lyude Paul) [1814893]
- [drm] drm/i915/gt: Check cacheline is valid before acquiring (Lyude Paul) [1814893]
- [drm] drm/i915/gem: Hold obj->vma.lock over for_each_ggtt_vma() (Lyude Paul) [1814893]
- [drm] drm/amd/display: Fix green screen issue after suspend (Lyude Paul) [1814893]
- [drm] drm/edid: Fix off-by-one in DispID DTD pixel clock (Lyude Paul) [1814893]
- [drm] drm/amdgpu: invalidate L2 before SDMA IBs (v2) (Lyude Paul) [1814893]
- [dma-buf] dma-buf: Fix SET_NAME ioctl uapi (Lyude Paul) [1814893]
- [drm] drm/scheduler: fix drm_sched_get_cleanup_job (Lyude Paul) [1814893]
- [drm] drm/amdgpu: fix wrong vram lost counter increment V2 (Lyude Paul) [1814893]
- [drm] drm/dp_mst: Zero assigned PBN when releasing VCPI slots (Lyude Paul) [1814893]
- [drm] drm/amd/display: Calculate scaling ratios on every medium/full update (Lyude Paul) [1814893]
- [drm] drm/amd/display: Update stream adjust in dc_stream_adjust_vmin_vmax (Lyude Paul) [1814893]
- [video] fbdev: potential information leak in do_fb_ioctl() (Lyude Paul) [1814893]
- [drm] drm/nouveau/gr/gp107, gp108: implement workaround for HW hanging during init (Lyude Paul) [1814893]
- [drm] drm/amdkfd: kfree the wrong pointer (Lyude Paul) [1814893]
- [drm] drm/nouveau: workaround runpm fail by disabling PCI power management on certain intel bridges (Lyude Paul) [1814893]
- [drm] drm/nouveau/svm: fix vma range check for migration (Lyude Paul) [1814893]
- [drm] drm/nouveau/svm: check for SVM initialized before migrating (Lyude Paul) [1814893]
- [drm] drm/amd/display: Don't try hdcp1.4 when content_type is set to type1 (Lyude Paul) [1814893]
- [drm] drm/ttm: flush the fence on the bo after we individualize the reservation object (Lyude Paul) [1814893]
- [drm] drm/i915/perf: Do not clear pollin for small user read buffers (Lyude Paul) [1814893]
- [drm] drm/nouveau/sec2/gv100-: add missing MODULE_FIRMWARE() (Lyude Paul) [1814893]
- [drm] drm/amdgpu: fix the hw hang during perform system reboot and reset (Lyude Paul) [1814893]
- [drm] drm/amdgpu/gfx9: add gfxoff quirk (Lyude Paul) [1814893]
- [drm] drm/amd/powerplay: force the trim of the mclk dpm_levels if OD is enabled (Lyude Paul) [1814893]
- [drm] drm/i915/gt: Fill all the unused space in the GGTT (Lyude Paul) [1814893]
- [drm] drm/i915/ggtt: do not set bits 1-11 in gen12 ptes (Lyude Paul) [1814893]
- [drm] drm/amdgpu: fix gfx hang during suspend with video playback (v2) (Lyude Paul) [1814893]
- [drm] drm/dp_mst: Fix clearing payload state on topology disable (Lyude Paul) [1814893]
- [drm] Revert "drm/dp_mst: Remove VCPI while disabling topology mgr" (Lyude Paul) [1814893]
- [drm] drm/i915/gt: Treat idling as a RPS downclock event (Lyude Paul) [1814893]
- [drm] drm/vboxvideo: Add missing remove_conflicting_pci_framebuffers call, v2 (Lyude Paul) [1814893]
- [drm] drm/i915/icl+: Don't enable DDI IO power on a TypeC port in TBT mode (Lyude Paul) [1814893]
- [drm] drm/amd/display: Check for null fclk voltage when parsing clock table (Lyude Paul) [1814893]
- [drm] drm/amdgpu: unify fw_write_wait for new gfx9 asics (Lyude Paul) [1814893]
- [drm] drm/amd/powerplay: implement the is_dpm_running() (Lyude Paul) [1814893]
- [drm] drm/amdgpu/powerplay: using the FCLK DPM table to set the MCLK (Lyude Paul) [1814893]
- [drm] drm: Remove PageReserved manipulation from drm_pci_alloc (Lyude Paul) [1814893]
- [drm] drm/bridge: analogix-anx78xx: Fix drm_dp_link helper removal (Lyude Paul) [1814893]
- [drm] drm/i915/gem: Flush all the reloc_gpu batch (Lyude Paul) [1814893]
- [drm] drm/i915/gen12: Disable preemption timeout (Lyude Paul) [1814893]
- [drm] drm/i915/display: Fix mode private_flags comparison at atomic_check (Lyude Paul) [1814893]
- [drm] drm/bridge: analogix-anx6345: Avoid duplicate -supply suffix (Lyude Paul) [1814893]
- [drm] drm/i915: Allow for different modes of interruptible i915_active_wait (Lyude Paul) [1814893]
- [gpu] DRM Backport 5.5 -> 5.6 (Lyude Paul) [1814893]
- [video] video: fbdev: intelfb: use const pointer for fb_ops (Lyude Paul) [1814893]
- [include] video: fbdev: make fbops member of struct fb_info a const pointer (Lyude Paul) [1814893]
- [video] video: fbdev: uvesafb: modify the static fb_ops directly (Lyude Paul) [1814893]
- [video] video: fbdev: nvidia: modify the static fb_ops directly (Lyude Paul) [1814893]
- [video] video: fbdev: mb862xx: modify the static fb_ops directly (Lyude Paul) [1814893]
- [video] video: fbdev: atyfb: modify the static fb_ops directly (Lyude Paul) [1814893]
- [video] video: fbmem: use const pointer for fb_ops (Lyude Paul) [1814893]
- [video] video: fbdev: vesafb: modify the static fb_ops directly (Lyude Paul) [1814893]
- [video] video: udlfb: don't restore fb_mmap after deferred IO cleanup (Lyude Paul) [1814893]
- [video] video: smscufx: don't restore fb_mmap after deferred IO cleanup (Lyude Paul) [1814893]
- [drm] drm/fb-helper: don't preserve fb_ops across deferred IO use (Lyude Paul) [1814893]
- [drm] drm/fb-helper: Remove drm_fb_helper_fbdev_{setup, teardown}() (Lyude Paul) [1814893]
- [video] video: fb_defio: preserve user fb_ops (Lyude Paul) [1814893]
- [drm] mm, drm/ttm: Fix vm page protection handling (Lyude Paul) [1814893]
- [dma-buf] udmabuf: Remove deleted map/unmap handlers (Lyude Paul) [1814893]
- [include] dma-buf: Remove kernel map/unmap hooks (Lyude Paul) [1814893]
- [drm] drm/udl: Remove udl implementation of GEM's free_object() (Lyude Paul) [1814893]
- [drm] drm/udl: Unmap buffer object after damage update (Lyude Paul) [1814893]
- [drm] drm/udl: Fix Kconfig indentation (Lyude Paul) [1814893]
- [drm] drm/udl: Replace fbdev code with generic emulation (Lyude Paul) [1814893]
- [drm] drm/udl: Remove struct udl_gem_object and functions (Lyude Paul) [1814893]
- [drm] drm/udl: Switch to SHMEM (Lyude Paul) [1814893]
- [drm] drm/udl: Allocate GEM object via struct drm_driver.gem_create_object (Lyude Paul) [1814893]
- [drm] drm/udl: Remove flags field from struct udl_gem_object (Lyude Paul) [1814893]
- [drm] drm/armada: Delete dma_buf->k(un)map implemenation (Lyude Paul) [1814893]
- [tee] drm/tee_shm: Drop dma_buf_k(unmap) support (Lyude Paul) [1814893]
- [samples] sample/vfio-mdev/mbocs: Remove dma_buf_k(un)map support (Lyude Paul) [1814893]
- [media] media/videobuf2: Drop dma_buf->k(un)map support (Lyude Paul) [1814893]
- [drm] drm/vmwgfx: Delete mmaping functions (Lyude Paul) [1814893]
- [dma-buf] dma-buf: Drop dma_buf_k(un)map (Lyude Paul) [1814893]
- [drm] drm/tegra: Remove dma_buf->k(un)map (Lyude Paul) [1814893]
- [drm] drm/omapdrm: Drop dma_buf->k(un)map (Lyude Paul) [1814893]
- [drm] drm/i915: Drop dma_buf->k(un)map (Lyude Paul) [1814893]
- [staging] staging/android/ion: delete dma_buf->kmap/unmap implemenation (Lyude Paul) [1814893]
- [drm] drm/i915: Remove dma_buf_kmap selftest (Lyude Paul) [1814893]
- [drm] drm/tegra: Delete host1x_bo_ops->k(un)map (Lyude Paul) [1814893]
- [gpu] drm/tegra: Map cmdbuf once for reloc processing (Lyude Paul) [1814893]
- [pinctrl] pinctrl: Allow modules to use pinctrl_register_mappings (Lyude Paul) [1814893]
- [include] lockdep: add might_lock_nested() (Lyude Paul) [1814893]
- [gpu] DRM Backport 5.4 -> 5.5 (Lyude Paul) [1814893]
- [security] device_cgroup: Export devcgroup_check_permission (Lyude Paul) [1814893]
- [video] fbdev: drop res_id parameter from remove_conflicting_pci_framebuffers (Lyude Paul) [1814893]
- [media] media: cec: check 'transmit_in_progress', not 'transmitting' (Lyude Paul) [1814893]
- [media] media: cec: avoid decrementing transmit_queue_sz if it is 0 (Lyude Paul) [1814893]
- [media] media: cec: CEC 2.0-only bcast messages were ignored (Lyude Paul) [1814893]
- [media] cec: add cec_adapter to cec_notifier_cec_adap_unregister() (Lyude Paul) [1814893]
- [media] media: cec-pin: add 'received' callback (Lyude Paul) [1814893]
- [media] media: cec: expose the new connector info API (Lyude Paul) [1814893]
- [media] media: cec/cec-adap.c: use new UI_CMD defines (Lyude Paul) [1814893]
- [media] media: cec-notifier: clear cec_adap in cec_notifier_unregister (Lyude Paul) [1814893]
- [media] media: cec-adap: return from cec_s_conn_info() if adap is invalid (Lyude Paul) [1814893]
- [media] media: cec-notifier: add new notifier functions (Lyude Paul) [1814893]
- [media] media: cec: add struct cec_connector_info support (Lyude Paul) [1814893]
- [media] media: cec-notifier: rename variables, check kstrdup and n->conn_name (Lyude Paul) [1814893]
- [media] media: cec-adap: fix regression in ping sanity check (Lyude Paul) [1814893]
- [media] media: cec: allow any initiator for Ping and Image/Text View On (Lyude Paul) [1814893]
- [media] media: cec: support CEC_MSG_FL_RAW (Lyude Paul) [1814893]
- [media] media: cec: add CEC_MSG_FL_RAW flag and msg_is_raw helper function (Lyude Paul) [1814893]
- [media] media: cec: move check from cec_transmit to cec_transmit_msg_fh (Lyude Paul) [1814893]
- [media] media: cec: cec_transmit_msg_fh: do sanity checks first (Lyude Paul) [1814893]
- [media] media: cec: mark devnode as registered before actually registering it (Lyude Paul) [1814893]
- [media] media: cec-notifier: add cec_notifier_parse_hdmi_phandle helper (Lyude Paul) [1814893]
- [media] media: Kconfig files: use the right help coding style (Lyude Paul) [1814893]
- [media] media: cec: fill in cec chardev kobject to ease debugging (Lyude Paul) [1814893]
- [media] media: cec: fix epoll() by calling poll_wait first (Lyude Paul) [1814893]
- [media] media: cec: keep track of outstanding transmits (Lyude Paul) [1814893]
- [media] media: cec: add debug_phys_addr module option (Lyude Paul) [1814893]
- [media] media: cec: report Vendor ID after initialization (Lyude Paul) [1814893]
- [media] media: cec-pin: fix broken tx_ignore_nack_until_eom error injection (Lyude Paul) [1814893]
- [media] media: cec: increase debug level for 'queue full' (Lyude Paul) [1814893]
- [media] media: cec: check for non-OK/NACK conditions while claiming a LA (Lyude Paul) [1814893]
- [media] media: cec: forgot to cancel delayed work (Lyude Paul) [1814893]
- [media] media: cec: name for RC passthrough device does not need 'RC for' (Lyude Paul) [1814893]
- [media] media: cec-gpio: select correct Signal Free Time (Lyude Paul) [1814893]
- [media] media: cec: fix the Signal Free Time calculation (Lyude Paul) [1814893]
- [media] media: cec: add new tx/rx status bits to detect aborts/timeouts (Lyude Paul) [1814893]
- [media] media: cec: remove cec-edid.c (Lyude Paul) [1814893]
- [media] media: cec/v4l2: move V4L2 specific CEC functions to V4L2 (Lyude Paul) [1814893]
- [media] media: cec: integrate cec_validate_phys_addr() in cec-api.c (Lyude Paul) [1814893]
- [media] media: cec: make cec_get_edid_spa_location() an inline function (Lyude Paul) [1814893]
- [media] media: use strscpy() instead of strlcpy() (Lyude Paul) [1814893]
- [media] media: cec: move compat_ioctl handling to cec-api.c (Lyude Paul) [1814893]
- [media] media: cec: add support for 5V signal testing (Lyude Paul) [1814893]
- [uapi] media: uapi/linux/cec.h: add 5V events (Lyude Paul) [1814893]
- [scsi] compat_ioctl: move more drivers to compat_ptr_ioctl (Lyude Paul) [1814893]
- [vhost] compat_ioctl: move drivers to compat_ptr_ioctl (Lyude Paul) [1814893]
- [rtc] compat_ioctl: move rtc handling into drivers/rtc/dev.c (Lyude Paul) [1814893]
- [fs] ceph: fix compat_ioctl for ceph_dir_operations (Lyude Paul) [1814893]
- [fs] compat_sys_ioctl(): make parallel to do_vfs_ioctl() (Lyude Paul) [1814893]
- [fs] compat: move FS_IOC_RESVSP_32 handling to fs/ioctl.c (Lyude Paul) [1814893]
- [fs] do_vfs_ioctl(): use saner types (Lyude Paul) [1814893]
- [fs] compat: itanic doesn't have one (Lyude Paul) [1814893]
- [fs] FIGETBSZ: fix compat (Lyude Paul) [1814893]
- [fs] fix compat handling of FICLONERANGE, FIDEDUPERANGE and FS_IOC_FIEMAP (Lyude Paul) [1814893]
- [gpu] DRM Backport 5.3 -> 5.4 (Lyude Paul) [1814893]
- [include] Add wait_var_event_interruptible() (Lyude Paul) [1814893]
- [kernel] kthread: Add __kthread_should_park() (Lyude Paul) [1814893]
- [kernel] PM / sleep: Refactor filesystems sync to reduce duplication (Lyude Paul) [1814893]
- [fpga] drivers: Introduce device lookup variants by of_node (Lyude Paul) [1814893]
- [s390] drivers: Introduce device lookup variants by name (Lyude Paul) [1814893]
- [base] drivers: Add generic helper to match by of_node (Lyude Paul) [1814893]
- [drm] kbuild: change *FLAGS_<basetarget>.o to take the path relative to $(obj) (Lyude Paul) [1814893]
- [video] fbdev: lock_fb_info cannot fail (Lyude Paul) [1814893]
- [video] fbdev/atyfb: lock_fb_info can't fail (Lyude Paul) [1814893]
- [video] fbdev: sysfs files can't disappear before the device is gone (Lyude Paul) [1814893]
- [video] fbcon: call fbcon_fb_(un)registered directly (Lyude Paul) [1814893]
- [video] fbcon: Remove fbcon_has_exited (Lyude Paul) [1814893]
- [video] fbcon: s/struct display/struct fbcon_display/ (Lyude Paul) [1814893]
- [video] fbdev: locking check for fb_set_suspend (Lyude Paul) [1814893]
- [tty] vt/fbcon: deinitialize resources in visual_init() after failed memory allocation (Lyude Paul) [1814893]
- [video] fbcon: Don't reset logo_shown when logo is currently shown (Lyude Paul) [1814893]
- [video] fbdev: fix WARNING in __alloc_pages_nodemask bug (Lyude Paul) [1814893]
- [video] fbdev: fix divide error in fb_var_to_videomode (Lyude Paul) [1814893]
- [video] fbdev: list all pci memory bars as conflicting apertures (Lyude Paul) [1814893]

* Sun Jun 21 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-218.el8]
- [block] Revert "block: end bio with BLK_STS_AGAIN in case of non-mq devs and REQ_NOWAIT" (Jeff Moyer) [1784478]
- [fs] io_uring: reset -EBUSY error when io sq thread is waken up (Jeff Moyer) [1784478]
- [fs] io_uring: don't add non-IO requests to iopoll pending list (Jeff Moyer) [1784478]
- [fs] io_uring: don't use kiocb.private to store buf_index (Jeff Moyer) [1784478]
- [fs] io_uring: cancel work if task_work_add() fails (Jeff Moyer) [1784478]
- [fs] io_uring: remove dead check in io_splice() (Jeff Moyer) [1784478]
- [fs] io_uring: fix FORCE_ASYNC req preparation (Jeff Moyer) [1784478]
- [fs] io_uring: don't prepare DRAIN reqs twice (Jeff Moyer) [1784478]
- [fs] io_uring: initialize ctx->sqo_wait earlier (Jeff Moyer) [1784478]
- [fs] io_uring: polled fixed file must go through free iteration (Jeff Moyer) [1784478]
- [fs] io_uring: fix zero len do_splice() (Jeff Moyer) [1784478]
- [fs] io_uring: don't use 'fd' for openat/openat2/statx (Jeff Moyer) [1784478]
- [fs] splice: move f_mode checks to do_{splice, tee}() (Jeff Moyer) [1784478]
- [fs] io_uring: handle -EFAULT properly in io_uring_setup() (Jeff Moyer) [1784478]
- [fs] io_uring: fix mismatched finish_wait() calls in io_uring_cancel_files() (Jeff Moyer) [1784478]
- [fs] io_uring: punt splice async because of inode mutex (Jeff Moyer) [1784478]
- [fs] io_uring: check non-sync defer_list carefully (Jeff Moyer) [1784478]
- [fs] io_uring: fix extra put in sync_file_range() (Jeff Moyer) [1784478]
- [fs] io_uring: use cond_resched() in io_ring_ctx_wait_and_kill() (Jeff Moyer) [1784478]
- [fs] io_uring: use proper references for fallback_req locking (Jeff Moyer) [1784478]
- [fs] io_uring: only force async punt if poll based retry can't handle it (Jeff Moyer) [1784478]
- [fs] io_uring: enable poll retry for any file with ->read_iter / ->write_iter (Jeff Moyer) [1784478]
- [fs] io_uring: statx must grab the file table for valid fd (Jeff Moyer) [1784478]
- [fs] io_uring: only restore req->work for req that needs do completion (Jeff Moyer) [1784478]
- [fs] io_uring: don't count rqs failed after current one (Jeff Moyer) [1784478]
- [fs] io_uring: kill already cached timeout.seq_offset (Jeff Moyer) [1784478]
- [fs] io_uring: fix cached_sq_head in io_timeout() (Jeff Moyer) [1784478]
- [fs] io_uring: only post events in io_poll_remove_all() if we completed some (Jeff Moyer) [1784478]
- [fs] io_uring: io_async_task_func() should check and honor cancelation (Jeff Moyer) [1784478]
- [fs] io_uring: check for need to re-wait in polled async handling (Jeff Moyer) [1784478]
- [fs] io_uring: correct O_NONBLOCK check for splice punt (Jeff Moyer) [1784478]
- [fs] io_uring: restore req->work when canceling poll request (Jeff Moyer) [1784478]
- [fs] io_uring: move all request init code in one place (Jeff Moyer) [1784478]
- [fs] io_uring: keep all sqe->flags in req->flags (Jeff Moyer) [1784478]
- [fs] io_uring: early submission req fail code (Jeff Moyer) [1784478]
- [fs] io_uring: track mm through current->mm (Jeff Moyer) [1784478]
- [fs] io_uring: remove obsolete @mm_fault (Jeff Moyer) [1784478]
- [fs] io_uring: punt final io_ring_ctx wait-and-free to workqueue (Jeff Moyer) [1784478]
- [fs] io_uring: fix fs cleanup on cqe overflow (Jeff Moyer) [1784478]
- [fs] io_uring: don't read user-shared sqe flags twice (Jeff Moyer) [1784478]
- [fs] io_uring: remove req init from io_get_req() (Jeff Moyer) [1784478]
- [fs] io_uring: alloc req only after getting sqe (Jeff Moyer) [1784478]
- [fs] io_uring: simplify io_get_sqring (Jeff Moyer) [1784478]
- [fs] io_uring: do not always copy iovec in io_req_map_rw() (Jeff Moyer) [1784478]
- [fs] io_uring: ensure openat sets O_LARGEFILE if needed (Jeff Moyer) [1784478]
- [fs] io_uring: initialize fixed_file_data lock (Jeff Moyer) [1784478]
- [fs] io_uring: remove redundant variable pointer nxt and io_wq_assign_next call (Jeff Moyer) [1784478]
- [fs] io_uring: fix ctx refcounting in io_submit_sqes() (Jeff Moyer) [1784478]
- [fs] io_uring: process requests completed with -EAGAIN on poll list (Jeff Moyer) [1784478]
- [fs] io_uring: remove bogus RLIMIT_NOFILE check in file registration (Jeff Moyer) [1784478]
- [fs] io_uring: use io-wq manager as backup task if task is exiting (Jeff Moyer) [1784478]
- [fs] io_uring: grab task reference for poll requests (Jeff Moyer) [1784478]
- [fs] io_uring: retry poll if we got woken with non-matching mask (Jeff Moyer) [1784478]
- [fs] io_uring: add missing finish_wait() in io_sq_thread() (Jeff Moyer) [1784478]
- [fs] io_uring: refactor file register/unregister/update handling (Jeff Moyer) [1784478]
- [fs] io_uring: cleanup io_alloc_async_ctx() (Jeff Moyer) [1784478]
- [fs] io_uring: fix missing 'return' in comment (Jeff Moyer) [1784478]
- [fs] io-wq: handle hashed writes in chains (Jeff Moyer) [1784478]
- [fs] io-uring: drop 'free_pfile' in struct io_file_put (Jeff Moyer) [1784478]
- [fs] io-uring: drop completion when removing file (Jeff Moyer) [1784478]
- [fs] io_uring: Fix ->data corruption on re-enqueue (Jeff Moyer) [1784478]
- [fs] io-wq: close cancel gap for hashed linked work (Jeff Moyer) [1784478]
- [uapi] io_uring: make spdxcheck.py happy (Jeff Moyer) [1784478]
- [fs] io_uring: honor original task RLIMIT_FSIZE (Jeff Moyer) [1784478]
- [fs] io_uring: make sure accept honor rlimit nofile (Jeff Moyer) [1784478]
- [fs] io_uring: make sure openat/openat2 honor rlimit nofile (Jeff Moyer) [1784478]
- [fs] io-wq: hash dependent work (Jeff Moyer) [1784478]
- [fs] io-wq: split hashing and enqueueing (Jeff Moyer) [1784478]
- [fs] io-wq: don't resched if there is no work (Jeff Moyer) [1784478]
- [fs] io_uring: NULL-deref for IOSQE_{ASYNC,DRAIN} (Jeff Moyer) [1784478]
- [fs] io-wq: remove duplicated cancel code (Jeff Moyer) [1784478]
- [fs] io_uring: fix truncated async read/readv and write/writev retry (Jeff Moyer) [1784478]
- [uapi] io_uring: dual license io_uring.h uapi header (Jeff Moyer) [1784478]
- [fs] io_uring: io_uring_enter(2) don't poll while SETUP_IOPOLL|SETUP_SQPOLL enabled (Jeff Moyer) [1784478]
- [fs] io_uring: Fix unused function warnings (Jeff Moyer) [1784478]
- [fs] io_uring: add end-of-bits marker and build time verify it (Jeff Moyer) [1784478]
- [fs] io_uring: provide means of removing buffers (Jeff Moyer) [1784478]
- [fs] io_uring: add IOSQE_BUFFER_SELECT support for IORING_OP_RECVMSG (Jeff Moyer) [1784478]
- [net] net: abstract out normal and compat msghdr import (Jeff Moyer) [1784478]
- [fs] io_uring: add IOSQE_BUFFER_SELECT support for IORING_OP_READV (Jeff Moyer) [1784478]
- [fs] io_uring: support buffer selection for OP_READ and OP_RECV (Jeff Moyer) [1784478]
- [fs] io_uring: add IORING_OP_PROVIDE_BUFFERS (Jeff Moyer) [1784478]
- [fs] io_uring: ensure RCU callback ordering with rcu_barrier() (Jeff Moyer) [1784478]
- [fs] io_uring: fix lockup with timeouts (Jeff Moyer) [1784478]
- [fs] io_uring: free fixed_file_data after RCU grace period (Jeff Moyer) [1784478]
- [fs] io_uring: buffer registration infrastructure (Jeff Moyer) [1784478]
- [fs] io_uring/io-wq: forward submission ref to async (Jeff Moyer) [1784478]
- [fs] io-wq: optimise out *next_work() double lock (Jeff Moyer) [1784478]
- [fs] io-wq: optimise locking in io_worker_handle_work() (Jeff Moyer) [1784478]
- [fs] io-wq: shuffle io_worker_handle_work() code (Jeff Moyer) [1784478]
- [fs] io_uring: get next work with submission ref drop (Jeff Moyer) [1784478]
- [fs] io_uring: remove @nxt from handlers (Jeff Moyer) [1784478]
- [fs] io_uring: make submission ref putting consistent (Jeff Moyer) [1784478]
- [fs] io_uring: clean up io_close (Jeff Moyer) [1784478]
- [fs] io_uring: Ensure mask is initialized in io_arm_poll_handler (Jeff Moyer) [1784478]
- [fs] io_uring: remove io_prep_next_work() (Jeff Moyer) [1784478]
- [fs] io_uring: remove extra nxt check after punt (Jeff Moyer) [1784478]
- [fs] io_uring: use poll driven retry for files that support it (Jeff Moyer) [1784478]
- [fs] io_uring: mark requests that we can do poll async in io_op_defs (Jeff Moyer) [1784478]
- [fs] io_uring: add per-task callback handler (Jeff Moyer) [1784478]
- [fs] io_uring: store io_kiocb in wait->private (Jeff Moyer) [1784478]
- [fs] io-wq: use BIT for ulong hash (Jeff Moyer) [1784478]
- [fs] io_uring: remove IO_WQ_WORK_CB (Jeff Moyer) [1784478]
- [fs] io-wq: remove unused IO_WQ_WORK_HAS_MM (Jeff Moyer) [1784478]
- [fs] io_uring: extract kmsg copy helper (Jeff Moyer) [1784478]
- [fs] io_uring: clean io_poll_complete (Jeff Moyer) [1784478]
- [fs] io_uring: add splice(2) support (Jeff Moyer) [1784478]
- [fs] io_uring: add interface for getting files (Jeff Moyer) [1784478]
- [fs] splice: make do_splice public (Jeff Moyer) [1784478]
- [fs] io_uring: remove req->in_async (Jeff Moyer) [1784478]
- [fs] io_uring: don't do full *prep_worker() from io-wq (Jeff Moyer) [1784478]
- [fs] io_uring: don't call work.func from sync ctx (Jeff Moyer) [1784478]
- [fs] io_uring: io_accept() should hold on to submit reference on retry (Jeff Moyer) [1784478]
- [fs] io_uring: consider any io_read/write -EAGAIN as final (Jeff Moyer) [1784478]
- [fs] io-wq: remove io_wq_flush and IO_WQ_WORK_INTERNAL (Jeff Moyer) [1784478]
- [fs] io-wq: fix IO_WQ_WORK_NO_CANCEL cancellation (Jeff Moyer) [1784478]
- [fs] io_uring: fix 32-bit compatability with sendmsg/recvmsg (Jeff Moyer) [1784478]
- [fs] io_uring: define and set show_fdinfo only if procfs is enabled (Jeff Moyer) [1784478]
- [fs] io_uring: drop file set ref put/get on switch (Jeff Moyer) [1784478]
- [fs] io_uring: import_single_range() returns 0/-ERROR (Jeff Moyer) [1784478]
- [fs] io_uring: pick up link work on submit reference drop (Jeff Moyer) [1784478]
- [fs] io-wq: ensure work->task_pid is cleared on init (Jeff Moyer) [1784478]
- [fs] io-wq: remove spin-for-work optimization (Jeff Moyer) [1784478]
- [fs] io_uring: fix poll_list race for SETUP_IOPOLL|SETUP_SQPOLL (Jeff Moyer) [1784478]
- [fs] io_uring: fix personality idr leak (Jeff Moyer) [1784478]
- [fs] io_uring: handle multiple personalities in link chains (Jeff Moyer) [1784478]
- [fs] io_uring: fix __io_iopoll_check deadlock in io_sq_thread (Jeff Moyer) [1784478]
- [fs] io_uring: prevent sq_thread from spinning when it should stop (Jeff Moyer) [1784478]
- [fs] io_uring: fix use-after-free by io_cleanup_req() (Jeff Moyer) [1784478]
- [fs] io_uring: remove unnecessary NULL checks (Jeff Moyer) [1784478]
- [fs] io_uring: add missing io_req_cancelled() (Jeff Moyer) [1784478]
- [fs] io_uring: prune request from overflow list on flush (Jeff Moyer) [1784478]
- [fs] io-wq: don't call kXalloc_node() with non-online node (Jeff Moyer) [1784478]
- [fs] io_uring: retain sockaddr_storage across send/recvmsg async punt (Jeff Moyer) [1784478]
- [fs] io_uring: cancel pending async work if task exits (Jeff Moyer) [1784478]
- [fs] io-wq: add io_wq_cancel_pid() to cancel based on a specific pid (Jeff Moyer) [1784478]
- [fs] io-wq: make io_wqe_cancel_work() take a match handler (Jeff Moyer) [1784478]
- [fs] io_uring: fix openat/statx's filename leak (Jeff Moyer) [1784478]
- [fs] io_uring: fix double prep iovec leak (Jeff Moyer) [1784478]
- [fs] io_uring: fix async close() with f_op->flush() (Jeff Moyer) [1784478]
- [fs] io_uring: allow AT_FDCWD for non-file openat/openat2/statx (Jeff Moyer) [1784478]
- [fs] io_uring: grab ->fs as part of async preparation (Jeff Moyer) [1784478]
- [fs] io-wq: add support for inheriting ->fs (Jeff Moyer) [1784478]
- [fs] io_uring: retry raw bdev writes if we hit -EOPNOTSUPP (Jeff Moyer) [1784478]
- [fs] io_uring: add cleanup for openat()/statx() (Jeff Moyer) [1784478]
- [fs] io_uring: fix iovec leaks (Jeff Moyer) [1784478]
- [fs] io_uring: remove unused struct io_async_open (Jeff Moyer) [1784478]
- [fs] io_uring: flush overflowed CQ events in the io_uring_poll() (Jeff Moyer) [1784478]
- [fs] io_uring: statx/openat/openat2 don't support fixed files (Jeff Moyer) [1784478]
- [fs] io_uring: fix deferred req iovec leak (Jeff Moyer) [1784478]
- [fs] io_uring: fix 1-bit bitfields to be unsigned (Jeff Moyer) [1784478]
- [fs] io_uring: get rid of delayed mm check (Jeff Moyer) [1784478]
- [fs] io_uring: cleanup fixed file data table references (Jeff Moyer) [1784478]
- [fs] io_uring: spin for sq thread to idle on shutdown (Jeff Moyer) [1784478]
- [fs] io_uring: put the flag changing code in the same spot (Jeff Moyer) [1784478]
- [fs] io_uring: iterate req cache backwards (Jeff Moyer) [1784478]
- [fs] io_uring: punt even fadvise() WILLNEED to async context (Jeff Moyer) [1784478]
- [fs] io_uring: fix sporadic double CQE entry for close (Jeff Moyer) [1784478]
- [fs] io_uring: remove extra ->file check (Jeff Moyer) [1784478]
- [fs] io_uring: don't map read/write iovec potentially twice (Jeff Moyer) [1784478]
- [fs] io_uring: use the proper helpers for io_send/recv (Jeff Moyer) [1784478]
- [fs] io_uring: prevent potential eventfd recursion on poll (Jeff Moyer) [1784478]
- [fs] eventfd: track eventfd_signal() recursion depth (Jeff Moyer) [1784478]
- [fs] io_uring: add BUILD_BUG_ON() to assert the layout of struct io_uring_sqe (Jeff Moyer) [1784478]
- [fs] io_uring: add ->show_fdinfo() for the io_uring file descriptor (Jeff Moyer) [1784478]
- [fs] io_uring: add support for epoll_ctl(2) (Jeff Moyer) [1784478]
- [fs] eventpoll: support non-blocking do_epoll_ctl() calls (Jeff Moyer) [1784478]
- [fs] eventpoll: abstract out epoll_ctl() handler (Jeff Moyer) [1784478]
- [fs] io_uring: fix linked command file table usage (Jeff Moyer) [1784478]
- [fs] io_uring: support using a registered personality for commands (Jeff Moyer) [1784478]
- [fs] io_uring: allow registering credentials (Jeff Moyer) [1784478]
- [fs] io_uring: add io-wq workqueue sharing (Jeff Moyer) [1784478]
- [fs] io-wq: allow grabbing existing io-wq (Jeff Moyer) [1784478]
- [fs] io_uring/io-wq: don't use static creds/mm assignments (Jeff Moyer) [1784478]
- [fs] io-wq: make the io_wq ref counted (Jeff Moyer) [1784478]
- [fs] io_uring: fix refcounting with batched allocations at OOM (Jeff Moyer) [1784478]
- [fs] io_uring: add comment for drain_next (Jeff Moyer) [1784478]
- [fs] io_uring: don't attempt to copy iovec for READ/WRITE (Jeff Moyer) [1784478]
- [fs] io_uring: don't cancel all work on process exit (Jeff Moyer) [1784478]
- [fs] Revert "io_uring: only allow submit from owning task" (Jeff Moyer) [1784478]
- [fs] io_uring: honor IOSQE_ASYNC for linked reqs (Jeff Moyer) [1784478]
- [fs] io_uring: prep req when do IOSQE_ASYNC (Jeff Moyer) [1784478]
- [fs] io_uring: use labeled array init in io_op_defs (Jeff Moyer) [1784478]
- [fs] io_uring: optimise sqe-to-req flags translation (Jeff Moyer) [1784478]
- [fs] io_uring: remove REQ_F_IO_DRAINED (Jeff Moyer) [1784478]
- [fs] io_uring: file switch work needs to get flushed on exit (Jeff Moyer) [1784478]
- [fs] io_uring: hide uring_fd in ctx (Jeff Moyer) [1784478]
- [fs] io_uring: remove extra check in __io_commit_cqring (Jeff Moyer) [1784478]
- [fs] io_uring: optimise use of ctx->drain_next (Jeff Moyer) [1784478]
- [fs] RHEL-only: Add IORING_OP_OPENAT2 opcode (Jeff Moyer) [1784478]
- [fs] io_uring: add support for probing opcodes (Jeff Moyer) [1784478]
- [fs] io_uring: account fixed file references correctly in batch (Jeff Moyer) [1784478]
- [fs] io_uring: add opcode to issue trace event (Jeff Moyer) [1784478]
- [fs] io_uring: enable option to only trigger eventfd for async completions (Jeff Moyer) [1784478]
- [fs] io_uring: change io_ring_ctx bool fields into bit fields (Jeff Moyer) [1784478]
- [fs] io_uring: file set registration should use interruptible waits (Jeff Moyer) [1784478]
- [fs] io_uring: Remove unnecessary null check (Jeff Moyer) [1784478]
- [fs] io_uring: add support for send(2) and recv(2) (Jeff Moyer) [1784478]
- [fs] io_uring: remove extra io_wq_current_is_worker() (Jeff Moyer) [1784478]
- [fs] io_uring: optimise commit_sqring() for common case (Jeff Moyer) [1784478]
- [fs] io_uring: optimise head checks in io_get_sqring() (Jeff Moyer) [1784478]
- [fs] io_uring: clamp to_submit in io_submit_sqes() (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_SETUP_CLAMP (Jeff Moyer) [1784478]
- [fs] io_uring: extend batch freeing to cover more cases (Jeff Moyer) [1784478]
- [fs] io_uring: wrap multi-req freeing in struct req_batch (Jeff Moyer) [1784478]
- [fs] io_uring: batch getting pcpu references (Jeff Moyer) [1784478]
- [include] pcpu_ref: add percpu_ref_tryget_many() (Jeff Moyer) [1784478]
- [fs] io_uring: add IORING_OP_MADVISE (Jeff Moyer) [1784478]
- [mm] mm: make do_madvise() available internally (Jeff Moyer) [1784478]
- [fs] io_uring: add IORING_OP_FADVISE (Jeff Moyer) [1784478]
- [fs] io_uring: allow use of offset == -1 to mean file position (Jeff Moyer) [1784478]
- [fs] io_uring: add non-vectored read/write commands (Jeff Moyer) [1784478]
- [fs] io_uring: improve poll completion performance (Jeff Moyer) [1784478]
- [fs] io_uring: split overflow state into SQ and CQ side (Jeff Moyer) [1784478]
- [fs] io_uring: add lookup table for various opcode needs (Jeff Moyer) [1784478]
- [fs] io_uring: remove two unnecessary function declarations (Jeff Moyer) [1784478]
- [fs] io_uring: move *queue_link_head() from common path (Jeff Moyer) [1784478]
- [fs] io_uring: rename prev to head (Jeff Moyer) [1784478]
- [fs] io_uring: add IOSQE_ASYNC (Jeff Moyer) [1784478]
- [fs] io-wq: support concurrent non-blocking work (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_OP_STATX (Jeff Moyer) [1784478]
- [fs] fs: make two stat prep helpers available (Jeff Moyer) [1784478]
- [fs] io_uring: avoid ring quiesce for fixed file set unregister and update (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_OP_CLOSE (Jeff Moyer) [1784478]
- [fs] io-wq: add support for uncancellable work (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_OP_OPENAT (Jeff Moyer) [1784478]
- [fs] fs: make build_open_flags() available internally (Jeff Moyer) [1784478]
- [fs] io_uring: add support for fallocate() (Jeff Moyer) [1784478]
- [fs] io_uring: fix compat for IORING_REGISTER_FILES_UPDATE (Jeff Moyer) [1784478]
- [fs] io_uring: only allow submit from owning task (Jeff Moyer) [1784478]
- [fs] io_uring: ensure workqueue offload grabs ring mutex for poll list (Jeff Moyer) [1784478]
- [fs] io_uring: clear req->result always before issuing a read/write request (Jeff Moyer) [1784478]
- [fs] io_uring: be consistent in assigning next work from handler (Jeff Moyer) [1784478]
- [fs] io-wq: cancel work if we fail getting a mm reference (Jeff Moyer) [1784478]
- [fs] io_uring: don't setup async context for read/write fixed (Jeff Moyer) [1784478]
- [fs] io_uring: remove punt of short reads to async context (Jeff Moyer) [1784478]
- [fs] io-wq: add cond_resched() to worker thread (Jeff Moyer) [1784478]
- [fs] io-wq: remove unused busy list from io_sqe (Jeff Moyer) [1784478]
- [fs] io_uring: pass in 'sqe' to the prep handlers (Jeff Moyer) [1784478]
- [fs] io_uring: standardize the prep methods (Jeff Moyer) [1784478]
- [fs] io_uring: read 'count' for IORING_OP_TIMEOUT in prep handler (Jeff Moyer) [1784478]
- [fs] io_uring: move all prep state for IORING_OP_{SEND, RECV}_MGS to prep handler (Jeff Moyer) [1784478]
- [fs] io_uring: move all prep state for IORING_OP_CONNECT to prep handler (Jeff Moyer) [1784478]
- [fs] io_uring: add and use struct io_rw for read/writes (Jeff Moyer) [1784478]
- [fs] io_uring: use u64_to_user_ptr() consistently (Jeff Moyer) [1784478]
- [fs] io_uring: io_wq_submit_work() should not touch req->rw (Jeff Moyer) [1784478]
- [fs] io_uring: don't wait when under-submitting (Jeff Moyer) [1784478]
- [fs] io_uring: warn about unhandled opcode (Jeff Moyer) [1784478]
- [fs] io_uring: read opcode and user_data from SQE exactly once (Jeff Moyer) [1784478]
- [fs] io_uring: make IORING_OP_TIMEOUT_REMOVE deferrable (Jeff Moyer) [1784478]
- [fs] io_uring: make IORING_OP_CANCEL_ASYNC deferrable (Jeff Moyer) [1784478]
- [fs] io_uring: make IORING_POLL_ADD and IORING_POLL_REMOVE deferrable (Jeff Moyer) [1784478]
- [fs] io_uring: make HARDLINK imply LINK (Jeff Moyer) [1784478]
- [fs] io_uring: any deferred command must have stable sqe data (Jeff Moyer) [1784478]
- [fs] io_uring: remove 'sqe' parameter to the OP helpers that take it (Jeff Moyer) [1784478]
- [fs] io_uring: fix pre-prepped issue with force_nonblock == true (Jeff Moyer) [1784478]
- [fs] io-wq: re-add io_wq_current_is_worker() (Jeff Moyer) [1784478]
- [fs] io_uring: fix sporadic -EFAULT from IORING_OP_RECVMSG (Jeff Moyer) [1784478]
- [fs] io_uring: fix stale comment and a few typos (Jeff Moyer) [1784478]
- [fs] io_uring: ensure we return -EINVAL on unknown opcode (Jeff Moyer) [1784478]
- [fs] io_uring: add sockets to list of files that support non-blocking issue (Jeff Moyer) [1784478]
- [net] net: make socket read/write_iter() honor IOCB_NOWAIT (Jeff Moyer) [1784478]
- [fs] io_uring: only hash regular files for async work execution (Jeff Moyer) [1784478]
- [fs] io_uring: run next sqe inline if possible (Jeff Moyer) [1784478]
- [fs] io_uring: don't dynamically allocate poll data (Jeff Moyer) [1784478]
- [fs] io_uring: deferred send/recvmsg should assign iov (Jeff Moyer) [1784478]
- [fs] io_uring: sqthread should grab ctx->uring_lock for submissions (Jeff Moyer) [1784478]
- [fs] io-wq: briefly spin for new work after finishing work (Jeff Moyer) [1784478]
- [fs] io-wq: remove worker->wait waitqueue (Jeff Moyer) [1784478]
- [fs] io_uring: allow unbreakable links (Jeff Moyer) [1784478]
- [fs] io_uring: fix a typo in a comment (Jeff Moyer) [1784478]
- [fs] io_uring: hook all linked requests via link_list (Jeff Moyer) [1784478]
- [fs] io_uring: fix error handling in io_queue_link_head (Jeff Moyer) [1784478]
- [fs] io_uring: use hash table for poll command lookups (Jeff Moyer) [1784478]
- [fs] io-wq: clear node->next on list deletion (Jeff Moyer) [1784478]
- [fs] io_uring: ensure deferred timeouts copy necessary data (Jeff Moyer) [1784478]
- [fs] io_uring: allow IO_SQE_* flags on IORING_OP_TIMEOUT (Jeff Moyer) [1784478]
- [fs] io_uring: handle connect -EINPROGRESS like -EAGAIN (Jeff Moyer) [1784478]
- [fs] io_uring: remove io_wq_current_is_worker (Jeff Moyer) [1784478]
- [fs] io_uring: remove parameter ctx of io_submit_state_start (Jeff Moyer) [1784478]
- [fs] io_uring: mark us with IORING_FEAT_SUBMIT_STABLE (Jeff Moyer) [1784478]
- [fs] io_uring: ensure async punted connect requests copy data (Jeff Moyer) [1784478]
- [fs] io_uring: ensure async punted sendmsg/recvmsg requests copy data (Jeff Moyer) [1784478]
- [fs] io_uring: ensure async punted read/write requests copy iovec (Jeff Moyer) [1784478]
- [fs] io_uring: add general async offload context (Jeff Moyer) [1784478]
- [fs] io_uring: transform send/recvmsg() -ERESTARTSYS to -EINTR (Jeff Moyer) [1784478]
- [fs] io_uring: use current task creds instead of allocating a new one (Jeff Moyer) [1784478]
- [fs] io_uring: fix missing kmap() declaration on powerpc (Jeff Moyer) [1784478]
- [fs] io_uring: add mapping support for NOMMU archs (Jeff Moyer) [1784478]
- [fs] io_uring: make poll->wait dynamically allocated (Jeff Moyer) [1784478]
- [fs] io-wq: shrink io_wq_work a bit (Jeff Moyer) [1784478]
- [fs] io-wq: fix handling of NUMA node IDs (Jeff Moyer) [1784478]
- [fs] io_uring: use kzalloc instead of kcalloc for single-element allocations (Jeff Moyer) [1784478]
- [fs] io_uring: cleanup io_import_fixed() (Jeff Moyer) [1784478]
- [fs] io_uring: inline struct sqe_submit (Jeff Moyer) [1784478]
- [fs] io_uring: store timeout's sqe->off in proper place (Jeff Moyer) [1784478]
- [net] net: disallow ancillary data for __sys_{send, recv}msg_file() (Jeff Moyer) [1784478]
- [net] net: separate out the msghdr copy from ___sys_{send, recv}msg() (Jeff Moyer) [1784478]
- [fs] io_uring: remove superfluous check for sqe->off in io_accept() (Jeff Moyer) [1784478]
- [fs] io_uring: async workers should inherit the user creds (Jeff Moyer) [1784478]
- [fs] io-wq: have io_wq_create() take a 'data' argument (Jeff Moyer) [1784478]
- [fs] io_uring: fix dead-hung for non-iter fixed rw (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_OP_CONNECT (Jeff Moyer) [1784478]
- [net] net: add __sys_connect_file() helper (Jeff Moyer) [1784478]
- [fs] io_uring: only return -EBUSY for submit on non-flushed backlog (Jeff Moyer) [1784478]
- [fs] io_uring: only !null ptr to io_issue_sqe() (Jeff Moyer) [1784478]
- [fs] io_uring: simplify io_req_link_next() (Jeff Moyer) [1784478]
- [fs] io_uring: pass only !null to io_req_find_next() (Jeff Moyer) [1784478]
- [fs] io_uring: remove io_free_req_find_next() (Jeff Moyer) [1784478]
- [fs] io_uring: add likely/unlikely in io_get_sqring() (Jeff Moyer) [1784478]
- [fs] io_uring: rename __io_submit_sqe() (Jeff Moyer) [1784478]
- [fs] io_uring: improve trace_io_uring_defer() trace point (Jeff Moyer) [1784478]
- [fs] io_uring: drain next sqe instead of shadowing (Jeff Moyer) [1784478]
- [fs] io_uring: close lookup gap for dependent next work (Jeff Moyer) [1784478]
- [fs] io_uring: allow finding next link independent of req reference count (Jeff Moyer) [1784478]
- [fs] io_uring: io_allocate_scq_urings() should return a sane state (Jeff Moyer) [1784478]
- [fs] io_uring: Always REQ_F_FREE_SQE for allocated sqe (Jeff Moyer) [1784478]
- [fs] io_uring: io_fail_links() should only consider first linked timeout (Jeff Moyer) [1784478]
- [fs] io_uring: Fix leaking linked timeouts (Jeff Moyer) [1784478]
- [fs] io_uring: remove redundant check (Jeff Moyer) [1784478]
- [fs] io_uring: break links for failed defer (Jeff Moyer) [1784478]
- [fs] io-wq: remove extra space characters (Jeff Moyer) [1784478]
- [fs] io-wq: wait for io_wq_create() to setup necessary workers (Jeff Moyer) [1784478]
- [fs] io_uring: request cancellations should break links (Jeff Moyer) [1784478]
- [fs] io_uring: correct poll cancel and linked timeout expiration completion (Jeff Moyer) [1784478]
- [fs] io_uring: remove dead REQ_F_SEQ_PREV flag (Jeff Moyer) [1784478]
- [fs] io_uring: fix sequencing issues with linked timeouts (Jeff Moyer) [1784478]
- [fs] io_uring: make req->timeout be dynamically allocated (Jeff Moyer) [1784478]
- [fs] io_uring: make io_double_put_req() use normal completion path (Jeff Moyer) [1784478]
- [fs] io_uring: cleanup return values from the queueing functions (Jeff Moyer) [1784478]
- [fs] io_uring: io_async_cancel() should pass in 'nxt' request pointer (Jeff Moyer) [1784478]
- [fs] io_uring: make POLL_ADD/POLL_REMOVE scale better (Jeff Moyer) [1784478]
- [fs] io-wq: remove now redundant struct io_wq_nulls_list (Jeff Moyer) [1784478]
- [fs] io_uring: Fix getting file for non-fd opcodes (Jeff Moyer) [1784478]
- [fs] io_uring: introduce req_need_defer() (Jeff Moyer) [1784478]
- [fs] io_uring: clean up io_uring_cancel_files() (Jeff Moyer) [1784478]
- [fs] io-wq: ensure free/busy list browsing see all items (Jeff Moyer) [1784478]
- [fs] io_uring: ensure registered buffer import returns the IO length (Jeff Moyer) [1784478]
- [fs] io_uring: Fix getting file for timeout (Jeff Moyer) [1784478]
- [fs] io-wq: ensure we have a stable view of ->cur_work for cancellations (Jeff Moyer) [1784478]
- [fs] io_wq: add get/put_work handlers to io_wq_create() (Jeff Moyer) [1784478]
- [fs] io_uring: check for validity of ->rings in teardown (Jeff Moyer) [1784478]
- [fs] io_uring: fix potential deadlock in io_poll_wake() (Jeff Moyer) [1784478]
- [fs] io_uring: use correct "is IO worker" helper (Jeff Moyer) [1784478]
- [fs] io_uring: make timeout sequence == 0 mean no sequence (Jeff Moyer) [1784478]
- [fs] io_uring: fix -ENOENT issue with linked timer with short timeout (Jeff Moyer) [1784478]
- [fs] io_uring: don't do flush cancel under inflight_lock (Jeff Moyer) [1784478]
- [fs] io_uring: flag SQPOLL busy condition to userspace (Jeff Moyer) [1784478]
- [fs] io_uring: make ASYNC_CANCEL work with poll and timeout (Jeff Moyer) [1784478]
- [fs] io_uring: provide fallback request for OOM situations (Jeff Moyer) [1784478]
- [fs] io_uring: convert accept4() -ERESTARTSYS into -EINTR (Jeff Moyer) [1784478]
- [fs] io_uring: fix error clear of ->file_table in io_sqe_files_register() (Jeff Moyer) [1784478]
- [fs] io_uring: separate the io_free_req and io_free_req_find_next interface (Jeff Moyer) [1784478]
- [fs] io_uring: keep io_put_req only responsible for release and put req (Jeff Moyer) [1784478]
- [fs] io_uring: remove passed in 'ctx' function parameter ctx if possible (Jeff Moyer) [1784478]
- [fs] io_uring: reduce/pack size of io_ring_ctx (Jeff Moyer) [1784478]
- [fs] io_uring: properly mark async work as bounded vs unbounded (Jeff Moyer) [1784478]
- [fs] io-wq: add support for bounded vs unbunded work (Jeff Moyer) [1784478]
- [fs] io-wq: io_wqe_run_queue() doesn't need to use list_empty_careful() (Jeff Moyer) [1784478]
- [fs] io_uring: add support for backlogged CQ ring (Jeff Moyer) [1784478]
- [fs] io_uring: pass in io_kiocb to fill/add CQ handlers (Jeff Moyer) [1784478]
- [fs] io_uring: make io_cqring_events() take 'ctx' as argument (Jeff Moyer) [1784478]
- [fs] io_uring: add support for linked SQE timeouts (Jeff Moyer) [1784478]
- [fs] io_uring: abstract out io_async_cancel_one() helper (Jeff Moyer) [1784478]
- [fs] io_uring: use inlined struct sqe_submit (Jeff Moyer) [1784478]
- [fs] io_uring: Use submit info inlined into req (Jeff Moyer) [1784478]
- [fs] io_uring: allocate io_kiocb upfront (Jeff Moyer) [1784478]
- [fs] io_uring: io_queue_link*() right after submit (Jeff Moyer) [1784478]
- [fs] io_uring: Merge io_submit_sqes and io_ring_submit (Jeff Moyer) [1784478]
- [fs] io_uring: kill dead REQ_F_LINK_DONE flag (Jeff Moyer) [1784478]
- [fs] io_uring: fixup a few spots where link failure isn't flagged (Jeff Moyer) [1784478]
- [fs] io_uring: enable optimized link handling for IORING_OP_POLL_ADD (Jeff Moyer) [1784478]
- [fs] io-wq: use proper nesting IRQ disabling spinlocks for cancel (Jeff Moyer) [1784478]
- [fs] io_uring: add completion trace event (Jeff Moyer) [1784478]
- [fs] io-wq: use kfree_rcu() to simplify the code (Jeff Moyer) [1784478]
- [fs] io_uring: set -EINTR directly when a signal wakes up in io_cqring_wait (Jeff Moyer) [1784478]
- [fs] io_uring: support for generic async request cancel (Jeff Moyer) [1784478]
- [fs] io_uring: ensure we clear io_kiocb->result before each issue (Jeff Moyer) [1784478]
- [fs] io_uring: io_wq_create() returns an error pointer, not NULL (Jeff Moyer) [1784478]
- [fs] io_uring: fix race with canceling timeouts (Jeff Moyer) [1784478]
- [fs] io_uring: support for larger fixed file sets (Jeff Moyer) [1784478]
- [fs] io_uring: protect fixed file indexing with array_index_nospec() (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_OP_ACCEPT (Jeff Moyer) [1784478]
- [net] net: add __sys_accept4_file() helper (Jeff Moyer) [1784478]
- [fs] io_uring: io_uring: add support for async work inheriting files (Jeff Moyer) [1784478]
- [fs] io_uring: replace workqueue usage with io-wq (Jeff Moyer) [1784478]
- [fs] io-wq: small threadpool implementation for io_uring (Jeff Moyer) [1784478]
- [fs] io_uring: Fix mm_fault with READ/WRITE_FIXED (Jeff Moyer) [1784478]
- [fs] io_uring: remove index from sqe_submit (Jeff Moyer) [1784478]
- [fs] io_uring: add set of tracing events (Jeff Moyer) [1784478]
- [fs] io_uring: add support for canceling timeout requests (Jeff Moyer) [1784478]
- [fs] io_uring: add support for absolute timeouts (Jeff Moyer) [1784478]
- [fs] io_uring: replace s->needs_lock with s->in_async (Jeff Moyer) [1784478]
- [fs] io_uring: allow application controlled CQ ring size (Jeff Moyer) [1784478]
- [fs] io_uring: add support for IORING_REGISTER_FILES_UPDATE (Jeff Moyer) [1784478]
- [fs] io_uring: allow sparse fixed file sets (Jeff Moyer) [1784478]
- [fs] io_uring: run dependent links inline if possible (Jeff Moyer) [1784478]
- [fs] io_uring: don't touch ctx in setup after ring fd install (Jeff Moyer) [1784478]
- [fs] io_uring: Fix leaked shadow_req (Jeff Moyer) [1784478]
- [fs] io_uring: fix bad inflight accounting for SETUP_IOPOLL|SETUP_SQTHREAD (Jeff Moyer) [1784478]
- [fs] io_uring: used cached copies of sq->dropped and cq->overflow (Jeff Moyer) [1784478]
- [fs] io_uring: Fix race for sqes with userspace (Jeff Moyer) [1784478]
- [fs] io_uring: Fix broken links with offloading (Jeff Moyer) [1784478]
- [fs] io_uring: Fix corrupted user_data (Jeff Moyer) [1784478]
- [fs] io_uring: correct timeout req sequence when inserting a new entry (Jeff Moyer) [1784478]
- [fs] io_uring : correct timeout req sequence when waiting timeout (Jeff Moyer) [1784478]
- [fs] io_uring: revert "io_uring: optimize submit_and_wait API" (Jeff Moyer) [1784478]
- [fs] io_uring: fix logic error in io_timeout (Jeff Moyer) [1784478]
- [fs] io_uring: fix up O_NONBLOCK handling for sockets (Jeff Moyer) [1784478]
- [fs] io_uring: consider the overflow of sequence for timeout req (Jeff Moyer) [1784478]
- [fs] io_uring: fix sequence logic for timeout requests (Jeff Moyer) [1784478]
- [fs] io_uring: only flush workqueues on fileset removal (Jeff Moyer) [1784478]
- [fs] io_uring: remove wait loop spurious wakeups (Jeff Moyer) [1784478]
- [fs] io_uring: fix reversed nonblock flag for link submission (Jeff Moyer) [1784478]
- [fs] io_uring: use __kernel_timespec in timeout ABI (Jeff Moyer) [1784478]
- [fs] io_uring: make CQ ring wakeups be more efficient (Jeff Moyer) [1784478]
- [fs] io_uring: compare cached_cq_tail with cq.head in_io_uring_poll (Jeff Moyer) [1784478]
- [fs] io_uring: correctly handle non ->{read, write}_iter() file_operations (Jeff Moyer) [1784478]
- [fs] io_uring: IORING_OP_TIMEOUT support (Jeff Moyer) [1784478]
- [fs] io_uring: use cond_resched() in sqthread (Jeff Moyer) [1784478]
- [fs] io_uring: fix potential crash issue due to io_get_req failure (Jeff Moyer) [1784478]
- [fs] io_uring: ensure poll commands clear ->sqe (Jeff Moyer) [1784478]
- [fs] io_uring: fix use-after-free of shadow_req (Jeff Moyer) [1784478]
- [fs] io_uring: use kmemdup instead of kmalloc and memcpy (Jeff Moyer) [1784478]
- [fs] io_uring: increase IORING_MAX_ENTRIES to 32K (Jeff Moyer) [1784478]
- [fs] io_uring: make sqpoll wakeup possible with getevents (Jeff Moyer) [1784478]
- [fs] io_uring: extend async work merging (Jeff Moyer) [1784478]
- [fs] io_uring: limit parallelism of buffered writes (Jeff Moyer) [1784478]
- [fs] io_uring: add io_queue_async_work() helper (Jeff Moyer) [1784478]
- [fs] io_uring: optimize submit_and_wait API (Jeff Moyer) [1784478]
- [fs] io_uring: add support for link with drain (Jeff Moyer) [1784478]
- [fs] io_uring: fix wrong sequence setting logic (Jeff Moyer) [1784478]
- [fs] io_uring: expose single mmap capability (Jeff Moyer) [1784478]
- [fs] io_uring: allocate the two rings together (Jeff Moyer) [1784478]
- [lib] percpu_ref: release percpu memory early without PERCPU_REF_ALLOW_REINIT (Jeff Moyer) [1784478]
- [fs] io_uring: initialize percpu refcounters using PERCU_REF_ALLOW_REINIT (Jeff Moyer) [1784478]
- [include] percpu_ref: introduce PERCPU_REF_ALLOW_REINIT flag (Jeff Moyer) [1784478]
- [fs] binder: fix use-after-free due to ksys_close() during fdget() (Jeff Moyer) [1784478]
- [init] RHEL-only: Enable io_uring for x86 builds (Jeff Moyer) [1784478]
- [arm64] compat: ARM64: always include asm-generic/compat.h (Jeff Moyer) [1784478]
- [include] asm-generic: Move common compat types to asm-generic/compat.h (Jeff Moyer) [1784478]

* Sat Jun 20 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-217.el8]
- [fs] coredump: fix crash when umh is disabled (Yauheni Kaliuta) [1845114]
- [kernel] umh: fix memory leak on execve failure (Yauheni Kaliuta) [1845114]
- [net] bpf: Replace zero-length array with flexible-array member (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix returned error sign when link doesn't support updates (Yauheni Kaliuta) [1845114]
- [net] bpf: sockmap: Don't attach programs to UDP sockets (Yauheni Kaliuta) [1845114]
- [net] bpf: cgroup: Allow multi-attach program to replace itself (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: use struct timespec instead of __kernel_timespec (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix bpf_link leak in ns_current_pid_tgid selftest (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix test_align verifier log patterns (Yauheni Kaliuta) [1845114]
- [net] bpf, cgroup: Return ENOLINK for auto-detached links on update (Yauheni Kaliuta) [1845114]
- [net] bpf: Refactor bpf_link update handling (Yauheni Kaliuta) [1845114]
- [tools] bpf, selftests: Add a verifier test for assigning 32bit reg states to 64bit ones (Yauheni Kaliuta) [1845114]
- [tools] bpf, selftests: Verifier bounds tests need to be updated (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix a verifier issue when assigning 32bit reg states to 64bit ones (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix use-after-free in fmod_ret check (Yauheni Kaliuta) [1845114]
- [net] flow_dissector: Drop BPF flow dissector prog ref on netns cleanup (Yauheni Kaliuta) [1845114]
- [tools] bpf: Prevent mmap()'ing read-only maps as writable (Yauheni Kaliuta) [1845114]
- [net] bpf: Enforce returning 0 for fentry/fexit progs (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Fix register naming in PT_REGS s390 macros (Yauheni Kaliuta) [1845114]
- [samples] samples: bpf: Fix build error (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix error return code in map_lookup_and_delete_elem() (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix sk_psock refcnt leak when receiving message (Yauheni Kaliuta) [1845114]
- [tools] tools/runqslower: Ensure own vmlinux.h is picked up first (Yauheni Kaliuta) [1845114]
- [net] bpf: Make bpf_link_fops static (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Respect the -d option in struct_ops cmd (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix leak in LINK_UPDATE and enforce empty old_prog_fd (Yauheni Kaliuta) [1845114]
- [tools] bpf: Fix reStructuredText markup (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Only check mode flags in get_xdp_id (Yauheni Kaliuta) [1845114]
- [tools] bpf, selftests: Add test for BPF_STX BPF_B storing R10 (Yauheni Kaliuta) [1845114]
- [x86] bpf, x86: Fix encoding for lower 8-bit registers in BPF_STX BPF_B (Yauheni Kaliuta) [1845114]
- [net] bpf: Forbid XADD on spilled pointers for unprivileged users (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Always specify expected_attach_type on program load if supported (Yauheni Kaliuta) [1845114]
- [net] bpf: remove unneeded conversion to bool in __mark_reg_unknown (Yauheni Kaliuta) [1845114]
- [tools] tools, bpftool: Fix struct_ops command invalid pointer free (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix use of sk->sk_reuseport from sk_assign (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Add test for bpf_get_link_xdp_id (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Fix bpf_get_link_xdp_id flags handling (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix a typo "inacitve" -> "inactive" (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Initialize *nl_pid so gcc 10 is happy (Yauheni Kaliuta) [1845114]
- [tools] bpf, lsm: Fix the file_mprotect LSM test (Yauheni Kaliuta) [1845114]
- [tools] bpf: Fix spelling mistake "arithmatic" -> "arithmetic" in test_verifier (Yauheni Kaliuta) [1845114]
- [lib] kbuild, btf: Fix dependencies for DEBUG_INFO_BTF (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Test FD-based cgroup attachment (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Add support for bpf_link-based cgroup attachment (Yauheni Kaliuta) [1845114]
- [net] bpf: Implement bpf_prog replacement for an active bpf_cgroup_link (Yauheni Kaliuta) [1845114]
- [net] bpf: Implement bpf_link-based cgroup BPF program attachment (Yauheni Kaliuta) [1845114]
- [tools] bpf: Test_verifier, add alu32 bounds tracking tests (Yauheni Kaliuta) [1845114]
- [tools] bpf: Test_verifier, #65 error message updates for trunc of boundary-cross (Yauheni Kaliuta) [1845114]
- [tools] bpf: Test_verifier, bpf_get_stack return value add <0 (Yauheni Kaliuta) [1845114]
- [tools] bpf: Test_progs, add test to catch retval refine error handling (Yauheni Kaliuta) [1845114]
- [net] bpf: Verifier, refine 32bit bound in do_refine_retval_range (Yauheni Kaliuta) [1845114]
- [include] bpf: Verifier, do explicit ALU32 bounds tracking (Yauheni Kaliuta) [1845114]
- [net] bpf: Verifier, do_refine_retval_range may clamp umin to 0 incorrectly (Yauheni Kaliuta) [1845114]
- [init] bpf, lsm: Make BPF_LSM depend on BPF_EVENTS (Yauheni Kaliuta) [1845114]
- [tools] selftests: bpf: Extend sk_assign tests for UDP (Yauheni Kaliuta) [1845114]
- [tools] selftests: bpf: Add test for sk_assign (Yauheni Kaliuta) [1845114]
- [net] bpf: Don't refcount LISTEN sockets in sk_assign() (Yauheni Kaliuta) [1845114]
- [net] net: Track socket refcounts in skb_steal_sock() (Yauheni Kaliuta) [1845114]
- [net] bpf: Add socket assign support (Yauheni Kaliuta) [1845114]
- [net] bpf: btf: Fix arg verification in btf_ctx_access() (Yauheni Kaliuta) [1845114]
- [net] bpf: Simplify reg_set_min_max_inv handling (Yauheni Kaliuta) [1845114]
- [documentation] bpf: lsm: Add Documentation (Yauheni Kaliuta) [1845114]
- [tools] bpf: lsm: Add selftests for BPF_PROG_TYPE_LSM (Yauheni Kaliuta) [1845114]
- [tools] tools/libbpf: Add support for BPF_PROG_TYPE_LSM (Yauheni Kaliuta) [1845114]
- [net] bpf: lsm: Implement attach, detach and execution (Yauheni Kaliuta) [1845114]
- [net] bpf: lsm: Provide attachment points for BPF LSM programs (Yauheni Kaliuta) [1845114]
- [net] bpf: Introduce BPF_PROG_TYPE_LSM (Yauheni Kaliuta) [1845114]
- [tools] selftests: Add test for overriding global data value before load (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Add setter for initial value for internal maps (Yauheni Kaliuta) [1845114]
- [net] bpf, net: Fix build issue when net ns not configured (Yauheni Kaliuta) [1845114]
- [net] bpf: Fix build warning regarding missing prototypes (Yauheni Kaliuta) [1845114]
- [tools] libbpf, xsk: Init all ring members in xsk_umem__create and xsk_socket__create (Yauheni Kaliuta) [1845114]
- [tools] bpf: Add selftest cases for ctx_or_null argument type (Yauheni Kaliuta) [1845114]
- [net] bpf: Enable retrival of pid/tgid/comm from bpf cgroup hooks (Yauheni Kaliuta) [1845114]
- [net] bpf: Enable bpf cgroup hooks to retrieve cgroup v2 and ancestor id (Yauheni Kaliuta) [1845114]
- [net] bpf: Allow to retrieve cgroup v1 classid from v2 hooks (Yauheni Kaliuta) [1845114]
- [net] bpf: Add netns cookie and enable it for bpf cgroup hooks (Yauheni Kaliuta) [1845114]
- [net] bpf: Enable perf event rb output for bpf cgroup progs (Yauheni Kaliuta) [1845114]
- [net] bpf: Enable retrieval of socket cookie for bind/post-bind hook (Yauheni Kaliuta) [1845114]
- [net] bpf: Remove unused vairable 'bpf_xdp_link_lops' (Yauheni Kaliuta) [1845114]
- [net] bpf: Factor out attach_type to prog_type mapping for attach/detach (Yauheni Kaliuta) [1845114]
- [net] bpf: Factor out cgroup storages operations (Yauheni Kaliuta) [1845114]
- [tools] bpf: Test_verifier, #70 error message updates for 32-bit right shift (Yauheni Kaliuta) [1845114]
- [net] bpf: Verifer, adjust_scalar_min_max_vals to always call update_reg_bounds() (Yauheni Kaliuta) [1845114]
- [net] bpf: Verifer, refactor adjust_scalar_min_max_vals (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Don't allocate 16M for log buffer by default (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Remove unused parameter `def` to get_map_field_int (Yauheni Kaliuta) [1845114]
- [documentation] bpf: Document bpf_inspect drgn tool (Yauheni Kaliuta) [1845114]
- [samples] samples, bpf: Refactor perf_event user program with libbpf bpf_link (Yauheni Kaliuta) [1845114]
- [samples] samples, bpf: Move read_trace_pipe to trace_helpers (Yauheni Kaliuta) [1845114]
- [tools] bpf: Add tests for bpf_sk_storage to bpf_tcp_ca (Yauheni Kaliuta) [1845114]
- [net] bpf: Add bpf_sk_storage support to bpf_tcp_ca (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix mix of tabs and spaces (Yauheni Kaliuta) [1845114]
- [net] bpf, tcp: Make tcp_bpf_recvmsg static (Yauheni Kaliuta) [1845114]
- [net] bpf, tcp: Fix unused function warnings (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Add struct_ops support (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Translate prog_id to its bpf prog_name (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Print as a string for char array (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Print the enum's name instead of value (Yauheni Kaliuta) [1845114]
- [tools] bpf, libbpf: Fix ___bpf_kretprobe_args1(x) macro definition (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Reset process and thread affinity after each test/sub-test (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix test_progs's parsing of test numbers (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix race in tcp_rtt test (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix nanosleep for real this time (Yauheni Kaliuta) [1845114]
- [tools] selftest/bpf: Fix compilation warning in sockmap_parse_prog.c (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Add vmlinux.h selftest exercising tracing of syscalls (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Provide CO-RE variants of PT_REGS macros (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Ignore incompatible types with matching name during CO-RE relocation (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Ensure consistent test failure output (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix spurious failures in accept due to EAGAIN (Yauheni Kaliuta) [1845114]
- [tools] tools/bpf: Move linux/types.h for selftests and bpftool (Yauheni Kaliuta) [1845114]
- [net] bpf: Add missing annotations for __bpf_prog_enter() and __bpf_prog_exit() (Yauheni Kaliuta) [1845114]
- [scripts] bpf_helpers_doc.py: Fix warning when compiling bpftool (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Fix usleep() implementation (Yauheni Kaliuta) [1845114]
- [net] bpf: Remove bpf_image tree (Yauheni Kaliuta) [1845114]
- [net] bpf: Add dispatchers to kallsyms (Yauheni Kaliuta) [1845114]
- [net] bpf: Add trampolines to kallsyms (Yauheni Kaliuta) [1845114]
- [net] bpf: Add bpf_ksym_add/del functions (Yauheni Kaliuta) [1845114]
- [net] bpf: Add prog flag to struct bpf_ksym object (Yauheni Kaliuta) [1845114]
- [net] bpf: Abstract away entire bpf_link clean up procedure (Yauheni Kaliuta) [1845114]
- [net] bpf: Add bpf_ksym_find function (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Make tcp_rtt test more robust to failures (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: test_progs: Don't leak server_fd in tcp_rtt (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: test_progs: fix client/server race in tcp_rtt (Yauheni Kaliuta) [1845114]
- [net] bpf: Move ksym_tnode to bpf_ksym (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Guarantee that useep() calls nanosleep() syscall (Yauheni Kaliuta) [1845114]
- [net] bpf: Move lnode list node to struct bpf_ksym (Yauheni Kaliuta) [1845114]
- [tools] tools: bpftool: Restore message on failure to guess program type (Yauheni Kaliuta) [1845114]
- [include] bpf: Add name to struct bpf_ksym (Yauheni Kaliuta) [1845114]
- [net] bpf: Add struct bpf_ksym (Yauheni Kaliuta) [1845114]
- [include] bpf: Add bpf_trampoline_ name prefix for DECLARE_BPF_DISPATCHER (Yauheni Kaliuta) [1845114]
- [mm] x86/mm: Rename is_kernel_text to __is_kernel_text (Yauheni Kaliuta) [1845114]
- [tools] bpf: Add bpf_xdp_output() helper (Yauheni Kaliuta) [1845114]
- [tools] tools/testing/selftests/bpf: Add self-tests for new helper bpf_get_ns_current_pid_tgid (Yauheni Kaliuta) [1845114]
- [net] bpf: Added new helper bpf_get_ns_current_pid_tgid (Yauheni Kaliuta) [1845114]
- [fs] fs/nsfs.c: Added ns_match (Yauheni Kaliuta) [1845114]
- [tools] tools: bpftool: Fix minor bash completion mistakes (Yauheni Kaliuta) [1845114]
- [tools] tools: bpftool: Allow all prog/map handles for pinning objects (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Split BTF presence checks into libbpf- and kernel-specific parts (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Add _bpftool and profiler.skel.h to .gitignore (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Skeleton should depend on libbpf (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Only build bpftool-prog-profile if supported by clang (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Use linux/types.h from source tree for profiler build (Yauheni Kaliuta) [1845114]
- [tools] tools/runqslower: Add BPF_F_CURRENT_CPU for running selftest on older kernels (Yauheni Kaliuta) [1845114]
- [x86] bpf: Fix trampoline generation for fmod_ret programs (Yauheni Kaliuta) [1845114]
- [net] bpf: Add bpf_link_new_file that doesn't install FD (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Bash completion for "bpftool prog profile" (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Documentation for bpftool prog profile (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Introduce "prog profile" command (Yauheni Kaliuta) [1845114]
- [tools] selftests: bpf: Enable UDP sockmap reuseport tests (Yauheni Kaliuta) [1845114]
- [tools] selftests: bpf: Add tests for UDP sockets in sockmap (Yauheni Kaliuta) [1845114]
- [tools] selftests: bpf: Don't listen() on UDP sockets (Yauheni Kaliuta) [1845114]
- [net] bpf: sockmap: Add UDP support (Yauheni Kaliuta) [1845114]
- [net] bpf: Add sockmap hooks for UDP sockets (Yauheni Kaliuta) [1845114]
- [net] bpf: sockmap: Simplify sock_map_init_proto (Yauheni Kaliuta) [1845114]
- [net] bpf: sockmap: Move generic sockmap hooks from BPF TCP (Yauheni Kaliuta) [1845114]
- [net] bpf: tcp: Guard declarations with CONFIG_NET_SOCK_MSG (Yauheni Kaliuta) [1845114]
- [net] bpf: tcp: Move assertions into tcp_bpf_get_proto (Yauheni Kaliuta) [1845114]
- [net] skmsg: Update saved hooks only once (Yauheni Kaliuta) [1845114]
- [net] bpf: sockmap: Only check ULP for TCP sockets (Yauheni Kaliuta) [1845114]
- [kernel] bpf: Fix bpf_prog_test_run_tracing for !CONFIG_NET (Yauheni Kaliuta) [1845114]
- [net] bpf: Remove unnecessary CAP_MAC_ADMIN check (Yauheni Kaliuta) [1845114]
- [tools] bpf: Add selftests for BPF_MODIFY_RETURN (Yauheni Kaliuta) [1845114]
- [tools] bpf: Add test ops for BPF_PROG_TYPE_TRACING (Yauheni Kaliuta) [1845114]
- [tools] tools/libbpf: Add support for BPF_MODIFY_RETURN (Yauheni Kaliuta) [1845114]
- [net] bpf: Attachment verification for BPF_MODIFY_RETURN (Yauheni Kaliuta) [1845114]
- [net] bpf: Introduce BPF_MODIFY_RETURN (Yauheni Kaliuta) [1845114]
- [x86] bpf: JIT helpers for fmod_ret progs (Yauheni Kaliuta) [1845114]
- [net] bpf: Refactor trampoline update code (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Support out-of-tree vmlinux builds for VMLINUX_BTF (Yauheni Kaliuta) [1845114]
- [tools] tools/runqslower: Drop copy/pasted BPF_F_CURRENT_CPU definiton (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Assume unsigned values for BTF_KIND_ENUM (Yauheni Kaliuta) [1845114]
- [tools] bpf: Switch BPF UAPI #define constants used from BPF program side to enums (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Test new __sk_buff field gso_size (Yauheni Kaliuta) [1845114]
- [tools] bpf: Sync uapi bpf.h to tools/ (Yauheni Kaliuta) [1845114]
- [net] bpf: Add gso_size to __sk_buff (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Add link pinning selftests (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Add bpf_link pinning/unpinning (Yauheni Kaliuta) [1845114]
- [net] bpf: Introduce pinnable bpf_link abstraction (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Merge selftests' bpf_trace_helpers.h into libbpf's bpf_tracing.h (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Fix use of PT_REGS_PARM macros with vmlinux.h (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Add header guards to generated vmlinux.h (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Add test for "bpftool feature" command (Yauheni Kaliuta) [1845114]
- [tools] selftests/tpm2: Add log and *.pyc to .gitignore (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Update bash completion for "bpftool feature" command (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Update documentation of "bpftool feature" command (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Make probes which emit dmesg warnings optional (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Move out sections to separate functions (Yauheni Kaliuta) [1845114]
- [tools] bpftool: Support struct_ops, tracing, ext prog types (Yauheni Kaliuta) [1845114]
- [scripts] scripts/bpf: Switch to more portable python3 shebang (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Print backtrace on SIGSEGV in test_progs (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Run reuseport tests only with supported socket types (Yauheni Kaliuta) [1845114]
- [net] bpf/stackmap: Dont trylock mmap_sem with PREEMPT_RT and interrupts disabled (Yauheni Kaliuta) [1845114]
- [net] bpf, lpm: Make locking RT friendly (Yauheni Kaliuta) [1845114]
- [net] bpf: Prepare hashtab locking for PREEMPT_RT (Yauheni Kaliuta) [1845114]
- [net] bpf: Factor out hashtab bucket lock operations (Yauheni Kaliuta) [1845114]
- [net] bpf: Replace open coded recursion prevention in sys_bpf() (Yauheni Kaliuta) [1845114]
- [net] bpf: Use recursion prevention helpers in hashtab code (Yauheni Kaliuta) [1845114]
- [include] bpf: Provide recursion prevention helpers (Yauheni Kaliuta) [1845114]
- [include] bpf: Use migrate_disable/enable in array macros and cgroup/lirc code (Yauheni Kaliuta) [1845114]
- [net] bpf: Use migrate_disable/enabe() in trampoline code (Yauheni Kaliuta) [1845114]
- [lib] bpf/tests: Use migrate disable instead of preempt disable (Yauheni Kaliuta) [1845114]
- [net] bpf: Use bpf_prog_run_pin_on_cpu() at simple call sites (Yauheni Kaliuta) [1845114]
- [include] bpf: Replace cant_sleep() with cant_migrate() (Yauheni Kaliuta) [1845114]
- [include] bpf: Provide bpf_prog_run_pin_on_cpu() helper (Yauheni Kaliuta) [1845114]
- [include] sched/rt: Provide migrate_disable/enable() inlines (Yauheni Kaliuta) [1845114]
- [include] sched: Provide cant_migrate() (Yauheni Kaliuta) [1845114]
- [net] bpf: Dont iterate over possible CPUs with interrupts disabled (Yauheni Kaliuta) [1845114]
- [net] bpf: Remove recursion prevention from rcu free callback (Yauheni Kaliuta) [1845114]
- [kernel] perf/bpf: Remove preempt disable around BPF invocation (Yauheni Kaliuta) [1845114]
- [kernel] bpf/trace: Remove redundant preempt_disable from trace_call_bpf() (Yauheni Kaliuta) [1845114]
- [kernel] bpf: disable preemption for bpf progs attached to uprobe (Yauheni Kaliuta) [1845114]
- [kernel] bpf/trace: Remove EXPORT from trace_call_bpf() (Yauheni Kaliuta) [1845114]
- [kernel] bpf/tracing: Remove redundant preempt_disable() in __bpf_trace_run() (Yauheni Kaliuta) [1845114]
- [net] bpf: Update locking comment in hashtab code (Yauheni Kaliuta) [1845114]
- [net] bpf: Enforce preallocation for instrumentation programs on RT (Yauheni Kaliuta) [1845114]
- [net] bpf: Tighten the requirements for preallocated hash maps (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Tests for sockmap/sockhash holding listening sockets (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Extend SK_REUSEPORT tests to cover SOCKMAP/SOCKHASH (Yauheni Kaliuta) [1845114]
- [documentation] docs/bpf: Update bpf development Q/A file (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Update xdp_bpf2bpf test to use new set_attach_target API (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Add support for dynamic program attach target (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Bump libpf current version to v0.0.8 (Yauheni Kaliuta) [1845114]
- [tools] libbpf: Relax check whether BTF is mandatory (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Change llvm flag -mcpu=probe to -mcpu=v3 (Yauheni Kaliuta) [1845114]
- [tools] selftests/bpf: Add bpf_read_branch_records() selftest (Yauheni Kaliuta) [1845114]
- [kernel] bpf: Add bpf_read_branch_records() helper (Yauheni Kaliuta) [1845114]
- [kernel] bpf: Allow bpf_perf_event_read_value in all BPF programs (Yauheni Kaliuta) [1845114]
- [dma] dma-direct: improve DMA mask overflow reporting (Don Dutile) [1816437]
- [dma] dma-direct: improve swiotlb error reporting (Don Dutile) [1816437]
- [dma] dma-direct: relax addressability checks in dma_direct_supported (Don Dutile) [1816437]
- [dma] dma-contiguous: CMA: give precedence to cmdline (Don Dutile) [1816437]
- [misc] lib/genalloc.c: rename addr_in_gen_pool to gen_pool_has_addr (Don Dutile) [1816437]
- [lib] lib/genalloc.c: export symbol addr_in_gen_pool (Don Dutile) [1816437]
- [acpi] dma-mapping: treat dev->bus_dma_mask as a DMA limit (Don Dutile) [1816437]
- [powerpc] dma-direct: unify the dma_capable definitions (Don Dutile) [1816437]
- [of] of/device: Really only set bus DMA mask when appropriate (Don Dutile) [1816437]
- [dma] dma-direct: exclude dma_direct_map_resource from the min_low_pfn check (Don Dutile) [1816437]
- [dma] dma-debug: clean up put_hash_bucket() (Don Dutile) [1816437]
- [iommu] dma-mapping: drop the dev argument to arch_sync_dma_for_* (Don Dutile) [1816437]
- [xen] swiotlb-xen: simplify cache maintainance (Don Dutile) [1816437]
- [xen] swiotlb-xen: simplify the DMA sync method implementations (Don Dutile) [1816437]
- [dma] dma-debug: increase HASH_SIZE (Don Dutile) [1816437]
- [dma] dma-debug: reorder struct dma_debug_entry fields (Don Dutile) [1816437]
- [dma] dma-mapping: merge the generic remapping helpers into dma-direct (Don Dutile) [1816437]
- [dma] dma-direct: provide mmap and get_sgtable method overrides (Don Dutile) [1816437]
- [dma] dma-direct: remove the dma_handle argument to __dma_direct_alloc_pages (Don Dutile) [1816437]
- [dma] dma-direct: remove __dma_direct_free_pages (Don Dutile) [1816437]
- [mm] dma/direct: turn ARCH_ZONE_DMA_BITS into a variable (Don Dutile) [1816437]
- [dma] dma-direct: check for overflows on 32 bit DMA addresses (Don Dutile) [1816437]
- [s390] s390/dma: provide proper ARCH_ZONE_DMA_BITS value (Don Dutile) [1816437]
- [mm] powerpc: fix off by one in max_zone_pfn initialization for ZONE_DMA (Don Dutile) [1816437]
- [powerpc] powerpc: enable a 30-bit ZONE_DMA for 32-bit pmac (Don Dutile) [1816437]
- [mm] arm64: rename variables used to calculate ZONE_DMA32's size (Don Dutile) [1816437]
- [mm] arm64: mm: use arm64_dma_phys_limit instead of calling max_zone_dma_phys() (Don Dutile) [1816437]
- [mm] arm64: mm: make CONFIG_ZONE_DMA32 configurable (Don Dutile) [1816437]
- [dma] kernel: dma-contiguous: mark CMA parameters __initdata/__initconst (Don Dutile) [1816437]
- [dma] dma-debug: add a schedule point in debug_dma_dump_mappings() (Don Dutile) [1816437]
- [dma] dma-debug: Use pr_warn instead of pr_warning (Don Dutile) [1816437]
- [dma] dma-mapping: fix false positivse warnings in dma_common_free_remap() (Don Dutile) [1816437]
- [xen] swiotlb-xen: ensure we have a single callsite for xen_dma_map_page (Don Dutile) [1816437]
- [iommu] dma-mapping: introduce a dma_common_find_pages helper (Don Dutile) [1816437]
- [iommu] dma-mapping: always use VM_DMA_COHERENT for generic DMA remap (Don Dutile) [1816437]
- [mm] vmalloc: lift the arm flag for coherent mappings to common code (Don Dutile) [1816437]
- [mm] dma-mapping: provide a better default ->get_required_mask (Don Dutile) [1816437]
- [dma] dma-mapping: remove the dma_declare_coherent_memory export (Don Dutile) [1816437]
- [dma] dma-mapping: remove the dma_mmap_from_dev_coherent export (Don Dutile) [1816437]
- [dma] dma-mapping: remove CONFIG_ARCH_NO_COHERENT_DMA_MMAP (Don Dutile) [1816437]
- [dma] dma-mapping: add a dma_can_mmap helper (Don Dutile) [1816437]
- [powerpc] dma-mapping: explicitly wire up ->mmap and ->get_sgtable (Don Dutile) [1816437]
- [mm] dma-mapping: move the dma_get_sgtable API comments from arm to common code (Don Dutile) [1816437]
- [dma] dma-mapping: introduce dma_get_merge_boundary() (Don Dutile) [1816437]
- [mm] dma-mapping: make dma_atomic_pool_init self-contained (Don Dutile) [1816437]
- [arm64] dma-mapping: remove arch_dma_mmap_pgprot (Don Dutile) [1816437]
- [scsi] scsi: ibmvscsi: Don't send host info in adapter info MAD after LPM (Steve Best) [1847078]
- [fs] NFS: Fix inode fileid checks in attribute revalidation code (Benjamin Coddington) [1846295]
- [fs] NFS: remove set but not used variable 'mapping' (Benjamin Coddington) [1846295]
- [fs] NFSv2: Fix write regression (Benjamin Coddington) [1846295]
- [fs] NFSv2: Fix eof handling (Benjamin Coddington) [1846295]
- [fs] NFS: Fix writepage(s) error handling to not report errors twice (Benjamin Coddington) [1846295]
- [fs] NFS: Fix spurious EIO read errors (Benjamin Coddington) [1846295]
- [fs] pNFS/flexfiles: Don't time out requests on hard mounts (Benjamin Coddington) [1846295]
- [net] SUNRPC: Handle EADDRINUSE and ENOBUFS correctly (Benjamin Coddington) [1846295]
- [fs] pNFS/flexfiles: Turn off soft RPC calls (Benjamin Coddington) [1846295]
- [fs] NFS: On fatal writeback errors, we need to call nfs_inode_remove_request() (Benjamin Coddington) [1846295]
- [fs] NFS: Fix initialisation of I/O result struct in nfs_pgio_rpcsetup (Benjamin Coddington) [1846295]
- [fs] NFSv4: Fix return value in nfs_finish_open() (Benjamin Coddington) [1846295]
- [fs] NFSv4: Fix return values for nfs4_file_open() (Benjamin Coddington) [1846295]
- [fs] NFS: Don't refresh attributes with mounted-on-file information (Benjamin Coddington) [1846295]
- [fs] NFSv4: Ensure state recovery handles ETIMEDOUT correctly (Benjamin Coddington) [1846295]
- [fs] NFSv4: Report the error from nfs4_select_rw_stateid() (Benjamin Coddington) [1846295]
- [fs] NFSv4: Print an error in the syslog when state is marked as irrecoverable (Benjamin Coddington) [1846295]
- [net] SUNRPC: Optimise transport balancing code (Benjamin Coddington) [1846295]
- [fs] NFSv4: Don't use the zero stateid with layoutget (Benjamin Coddington) [1846295]
- [net] SUNRPC: Fix up backchannel slot table accounting (Benjamin Coddington) [1846295]
- [net] SUNRPC: Skip zero-refcount transports (Benjamin Coddington) [1846295]
- [net] SUNRPC: Replace division by multiplication in calculation of queue length (Benjamin Coddington) [1846295]
- [fs] NFSv4: Validate the stateid before applying it to state recovery (Benjamin Coddington) [1846295]
- [fs] nfs4.0: Refetch lease_time after clientid update (Benjamin Coddington) [1846295]
- [fs] nfs4: Rename nfs41_setup_state_renewal (Benjamin Coddington) [1846295]
- [fs] nfs4: Make nfs4_proc_get_lease_time available for nfs4.0 (Benjamin Coddington) [1846295]
- [fs] nfs: Fix copy-and-paste error in debug message (Benjamin Coddington) [1846295]
- [fs] NFS: Replace 16 seq_printf() calls by seq_puts() (Benjamin Coddington) [1846295]
- [fs] NFS: Use seq_putc() in nfs_show_stats() (Benjamin Coddington) [1846295]
- [fs] nfsd: Fix misuse of strlcpy (Benjamin Coddington) [1846295]
- [net] SUNRPC: Drop redundant CONFIG_ from CONFIG_SUNRPC_DISABLE_INSECURE_ENCTYPES (Benjamin Coddington) [1846295]
- [fs] NFS: Cleanup if nfs_match_client is interrupted (Benjamin Coddington) [1846295]
- [fs] nfs: disable client side deduplication (Benjamin Coddington) [1846295]
- [fs] NFS: Clean up writeback code (Benjamin Coddington) [1846295]
- [net] SUNRPC: Remove warning in debugfs.c when compiling with W=1 (Benjamin Coddington) [1846295]
- [fs] NFS: Add sysfs support for per-container identifier (Benjamin Coddington) [1846295]
- [net] SUNRPC: Remove the bh-safe lock requirement on the rpc_wait_queue->lock (Benjamin Coddington) [1846295]
- [fs] NFS: Cleanup - add nfs_clients_exit to mirror nfs_clients_init (Benjamin Coddington) [1846295]
- [fs] NFS: Create a root NFS directory in /sys/fs/nfs (Benjamin Coddington) [1846295]
- [net] SUNRPC: Remove the bh-safe lock requirement on xprt->transport_lock (Benjamin Coddington) [1846295]
- [net] SUNRPC: Replace direct task wakeups from softirq context (Benjamin Coddington) [1846295]
- [net] SUNRPC: Replace the queue timer with a delayed work function (Benjamin Coddington) [1846295]
- [fs] NFSv4: Handle open for execute correctly (Benjamin Coddington) [1846295]
- [fs] nfs: dget_parent() never returns NULL (Benjamin Coddington) [1846295]
- [net] nfs: fix out-of-date connectathon talk URL (Benjamin Coddington) [1846295]
- [fs] nfsd4: remove outdated nfsd4_decode_time comment (Benjamin Coddington) [1846295]
- [fs] nfsd: Spelling s/EACCESS/EACCES/ (Benjamin Coddington) [1846295]
- [fs] lockd: Make two symbols static (Benjamin Coddington) [1846295]
- [fs] lockd: Show pid of lockd for remote locks (Benjamin Coddington) [1846295]
- [fs] lockd: Remove lm_compare_owner and lm_owner_key (Benjamin Coddington) [1846295]
- [fs] lockd: Convert NLM service fl_owner to nlm_lockowner (Benjamin Coddington) [1846295]
- [fs] lockd: prepare nlm_lockowner for use by the server (Benjamin Coddington) [1846295]
- [net] sunrpc: no need to check return value of debugfs_create functions (Benjamin Coddington) [1846295]
- [fs] nfsd: no need to check return value of debugfs_create functions (Benjamin Coddington) [1846295]
- [fs] xfs: add agf freeblocks verify in xfs_agf_verify (Brian Foster) [1837192] {CVE-2020-12655}
- [scsi] scsi: iscsi: Fix deadlock on recovery path during GFP_IO reclaim (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Register sysfs for iscsi workqueue (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Report unbind session event when the target has been removed (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: Fix error count for active session (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Report connection state in sysfs (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Add support for asynchronous iSCSI session destruction (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Perform connection failure entirely in kernel space (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Don't destroy session if there are outstanding connections (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Fix a potential deadlock in the timeout handler (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Don't send data to unbound connection (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: switch to SPDX tags (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: Hold back_lock when calling iscsi_complete_task (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: Use scsi_et_resid() where appropriate (Chris Leech) [1830140]
- [scsi] scsi: iscsi: Capture iscsi debug messages using tracepoints (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: Fix NULL pointer dereference in iscsi_eh_session_reset (Chris Leech) [1830140]
- [scsi] scsi: iscsi_tcp: Explicitly cast param in iscsi_sw_tcp_host_get_param (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: Annotate fall-through (Chris Leech) [1830140]
- [scsi] scsi: libiscsi: Annotate locking assumptions (Chris Leech) [1830140]
- [nvme] nvmet: fail outstanding host posted AEN req (David Milburn) [1833642]
- [nvme] nvmet: add async event tracing support (David Milburn) [1833642]
- [nvme] nvmet: cleanups the loop in nvmet_async_events_process (David Milburn) [1833642]
- [nvme] nvmet: fix memory leak when removing namespaces and controllers concurrently (David Milburn) [1833642]
- [netdrv] ibmvnic: Flush existing work items before device removal (Steve Best) [1846761]
- [kernel] signal: Extend exec_id to 64bits (Chris von Recklinghausen) [1834652] {CVE-2020-12826}

* Thu Jun 18 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-216.el8]
- [arm64] docs: fix broken references to text files (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Move __load_guest_stage2 to kvm_mmu.h (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Drop obsolete comment about sys_reg ordering (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Parametrize exception entry with a target EL (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Don't use empty structures as CPU reset state (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Move sysreg reset check to boot time (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Add missing reset handlers for PMU emulation (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Refactor vcpu_{read, write}_sys_reg (Andrew Jones) [1842468]
- [arm64] kvm: arm64: vgic-v3: Take cpu_if pointer directly instead of vcpu (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Remove obsolete kvm_virt_to_phys abstraction (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Fix incorrect comment on kvm_get_hyp_vector() (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Clean up cpu_init_hyp_mode() (Andrew Jones) [1842468]
- [arm64] cpufeature: Drop open encodings while extracting parange (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Make KVM_CAP_MAX_VCPUS compatible with the selected GIC version (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Support enabling dirty log gradually in small chunks (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Unify handling THP backed host memory (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Clean up the checking for huge mapping (Andrew Jones) [1842468]
- [arm64] kvm: arm/arm64: Release kvm->mmu_lock in loop to prevent starvation (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Sidestep stage2_unmap_vm() on vcpu reset when S2FWB is supported (Andrew Jones) [1842468]
- [arm64] kvm: Fix spelling in code comments (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Simplify __kvm_timer_set_cntvoff implementation (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Clean up kvm makefiles (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Change CONFIG_KVM to a menuconfig entry (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Update help text (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Kill off CONFIG_KVM_ARM_HOST (Andrew Jones) [1842468]
- [arm64] kvm: arm64: Move virt/kvm/arm to arch/arm64 (Andrew Jones) [1842468]
- [arm64] Unify WORKAROUND_SPECULATIVE_AT_{NVHE, VHE} (Andrew Jones) [1842468]
- [arm64] cpufeature: Add CPU capability for AArch32 EL1 support (Andrew Jones) [1842468]
- [net] SUNRPC: Fix a credential refcount leak (Benjamin Coddington) [1831672]
- [net] Revert "SUNRPC: Declare RPC timers as TIMER_DEFERRABLE" (Benjamin Coddington) [1831672]
- [net] net :sunrpc :clnt :Fix xps refcount imbalance on the error path (Benjamin Coddington) [1831672]
- [net] SUNRPC: Rebalance a kref in auth_gss.c (Benjamin Coddington) [1831672]
- [fs] NFS: Fix a double unlock from nfs_match, get_client (Benjamin Coddington) [1831672]
- [fs] nfs: pass the correct prototype to read_cache_page (Benjamin Coddington) [1831672]
- [fs] NFSv4: don't mark all open state for recovery when handling recallable state revoked flag (Benjamin Coddington) [1831672]
- [net] SUNRPC: Fix an error code in gss_alloc_msg() (Benjamin Coddington) [1831672]
- [net] SUNRPC: task should be exit if encode return EKEYEXPIRED more times (Benjamin Coddington) [1831672]
- [fs] NFS: make nfs_match_client killable (Benjamin Coddington) [1831672]
- [fs] nfsd: update callback done processing (Benjamin Coddington) [1831672]
- [fs] lockd: Store the lockd client credential in struct nlm_host (Benjamin Coddington) [1831672]
- [fs] NFS: When mounting, don't share filesystems between different user namespaces (Benjamin Coddington) [1831672]
- [fs] NFS: Convert NFSv2 to use the container user namespace (Benjamin Coddington) [1831672]
- [fs] NFSv4: Convert the NFS client idmapper to use the container user namespace (Benjamin Coddington) [1831672]
- [fs] NFS: Convert NFSv3 to use the container user namespace (Benjamin Coddington) [1831672]
- [net] SUNRPC: Use namespace of listening daemon in the client AUTH_GSS upcall (Benjamin Coddington) [1831672]
- [net] net: Remove some unneeded semicolon (Benjamin Coddington) [1831672]
- [net] SUNRPC: Use the client user namespace when encoding creds (Benjamin Coddington) [1831672]
- [fs] NFS: Store the credential of the mount process in the nfs_server (Benjamin Coddington) [1831672]
- [fs] SUNRPC: Cache cred of process creating the rpc_client (Benjamin Coddington) [1831672]
- [net] SUNRPC: Update comments based on recent changes (Benjamin Coddington) [1831672]
- [net] SUNRPC: Avoid digging into the ATOMIC pool (Benjamin Coddington) [1831672]
- [net] xprtrdma: Recognize XDRBUF_SPARSE_PAGES (Benjamin Coddington) [1831672]
- [fs] Fix nfs4.2 return -EINVAL when do dedupe operation (Benjamin Coddington) [1831672]
- [fs] NFS: Remove redundant open context from nfs_page (Benjamin Coddington) [1831672]
- [fs] NFS: Add a helper to return a pointer to the open context of a struct nfs_page (Benjamin Coddington) [1831672]
- [fs] NFS: Ensure that all nfs lock contexts have a valid open context (Benjamin Coddington) [1831672]
- [fs] NFS: Allow signal interruption of NFS4ERR_DELAYed operations (Benjamin Coddington) [1831672]
- [fs] pNFS: Add tracking to limit the number of pNFS retries (Benjamin Coddington) [1831672]
- [fs] NFS: Remove unused argument from nfs_create_request() (Benjamin Coddington) [1831672]
- [fs] NFS: Fix up NFS I/O subrequest creation (Benjamin Coddington) [1831672]
- [fs] NFS: Replace custom error reporting mechanism with generic one (Benjamin Coddington) [1831672]
- [fs] NFS: Don't inadvertently clear writeback errors (Benjamin Coddington) [1831672]
- [fs] NFS: Don't call generic_error_remove_page() while holding locks (Benjamin Coddington) [1831672]
- [fs] NFS: Don't interrupt file writeout due to fatal errors (Benjamin Coddington) [1831672]
- [fs] NFS: Add a mount option "softerr" to allow clients to see ETIMEDOUT errors (Benjamin Coddington) [1831672]
- [uapi] NFS: Move internal constants out of uapi/linux/nfs_mount.h (Benjamin Coddington) [1831672]
- [fs] NFS: Consider ETIMEDOUT to be a fatal error (Benjamin Coddington) [1831672]
- [net] SUNRPC: Add the 'softerr' rpc_client flag (Benjamin Coddington) [1831672]
- [net] SUNRPC: Ensure to ratelimit the "server not responding" syslog messages (Benjamin Coddington) [1831672]
- [net] SUNRPC: Start the first major timeout calculation at task creation (Benjamin Coddington) [1831672]
- [net] SUNRPC: Ensure that the transport layer respect major timeouts (Benjamin Coddington) [1831672]
- [net] SUNRPC: Declare RPC timers as TIMER_DEFERRABLE (Benjamin Coddington) [1831672]
- [net] SUNRPC: Simplify queue timeouts using timer_reduce() (Benjamin Coddington) [1831672]
- [net] SUNRPC: Fix up tracking of timeouts (Benjamin Coddington) [1831672]
- [net] SUNRPC: Add function rpc_sleep_on_timeout() (Benjamin Coddington) [1831672]
- [fs] SUNRPC: Remove unused argument 'action' from rpc_sleep_on_priority() (Benjamin Coddington) [1831672]
- [net] SUNRPC: Refactor rpc_sleep_on() (Benjamin Coddington) [1831672]
- [net] SUNRPC: Refactor xprt_request_wait_receive() (Benjamin Coddington) [1831672]
- [fs] nfsd: fh_drop_write in nfsd_unlink (Benjamin Coddington) [1831672]
- [fs] nfsd: avoid uninitialized variable warning (Benjamin Coddington) [1831672]
- [netdrv] Revert "net: phy: realtek: fix using paged operations with RTL8105e / RTL8208" (Josef Oskera) [1846022]
- [netdrv] ice: Fix Tx timeout when link is toggled on a VF's interface (Jonathan Toppins) [1843144]
- [netdrv] ice: add a devlink region for dumping NVM contents (Jonathan Toppins) [1843144]
- [nvme] nvme-fc: print proper nvme-fc devloss_tmo value (Gopal Tiwari) [1846049]
- [acpi] ACPI: EC: PM: Avoid flushing EC work when EC GPE is inactive (Al Stone) [1803969]
- [acpi] ACPI: EC: PM: Avoid premature returns from acpi_s2idle_wake() (Al Stone) [1803969]
- [acpi] ACPI: PM: Add acpi_register_wakeup_handler() (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Refine active GPEs check (Al Stone) [1803969]
- [acpi] ACPICA: Allow acpi_any_gpe_status_set() to skip one GPE (Al Stone) [1803969]
- [base] PM: sleep: wakeup: Skip wakeup_source_sysfs_remove() if device is not there (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Check fixed wakeup events in acpi_s2idle_wake() (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Fix comment in acpi_s2idle_prepare_late() (Al Stone) [1803969]
- [platform] platform/x86: sony-laptop: Make resuming thermal profile safer (Al Stone) [1803969]
- [platform] platform/x86: sony-laptop: SNC calls should handle BUFFER types (Al Stone) [1803969]
- [acpi] ACPI: Update Tiger Lake ACPI device IDs (Al Stone) [1803969]
- [acpi] ACPI: EC: Avoid printing confusing messages in acpi_ec_setup() (Al Stone) [1803969]
- [acpi] ACPI: EC: Fix flushing of pending work (Al Stone) [1803969]
- [base] PM / wakeup: Register wakeup class kobj after device is added (Al Stone) [1803969]
- [base] PM / wakeup: Fix sysfs registration error path (Al Stone) [1803969]
- [base] PM / wakeup: Unexport wakeup_source_sysfs_{add, remove}() (Al Stone) [1803969]
- [kernel] PM: suspend: Fix platform_suspend_prepare_noirq() (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Prevent spurious SCIs from waking up the system (Al Stone) [1803969]
- [acpi] ACPICA: Introduce acpi_any_gpe_status_set() (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Avoid possible race related to the EC GPE (Al Stone) [1803969]
- [acpi] ACPI: watchdog: Allow disabling WDAT at boot (Al Stone) [1803969]
- [acpi] ACPI / APD: Add clock frequency for Hisilicon Hip08-Lite I2C controller (Al Stone) [1803969]
- [acpi] ACPI: thermal: switch to use <linux/units.h> helpers (Al Stone) [1803969]
- [acpi] ACPI/IORT: Fix 'Number of IDs' handling in iort_id_map() (Al Stone) [1803969]
- [acpi] ACPI/IORT: Parse SSID property of named component node (Al Stone) [1803969]
- [iommu] iommu/arm-smmu-v3: Parse PASID devicetree property of platform devices (Al Stone) [1803969]
- [acpi] ACPICA: Update version to 20200110 (Al Stone) [1803969]
- [acpi] ACPICA: All acpica: Update copyrights to 2020 Including tool signons (Al Stone) [1803969]
- [acpi] ACPI: button: Add DMI quirk for Razer Blade Stealth 13 late 2019 lid switch (Al Stone) [1803969]
- [acpi] ACPI: PPTT: Consistently use unsigned int as parameter type (Al Stone) [1803969]
- [acpi] ACPI: EC: Reference count query handlers under lock (Al Stone) [1803969]
- [acpi] ACPICA: Update version to 20191213 (Al Stone) [1803969]
- [acpi] ACPICA: Dispatcher: always generate buffer objects for ASL create_field() operator (Al Stone) [1803969]
- [acpi] ACPICA: acpisrc: add unix line ending support for non-windows build (Al Stone) [1803969]
- [acpi] ACPICA: Disassembler: create buffer fields in ACPI_PARSE_LOAD_PASS1 (Al Stone) [1803969]
- [acpi] ACPICA: debugger: fix spelling mistake "adress" -> "address" (Al Stone) [1803969]
- [acpi] ACPI: video: Do not export a non working backlight interface on MSI MS-7721 boards (Al Stone) [1803969]
- [acpi] ACPI: fan: Add Tiger Lake ACPI device ID (Al Stone) [1803969]
- [acpi] ACPI: DPTF: Add Tiger Lake ACPI device IDs (Al Stone) [1803969]
- [acpi] ACPI: fan: Expose fan performance state information (Al Stone) [1803969]
- [acpi] ACPI / LPSS: Rename pwm_backlight pwm-lookup to pwm_soc_backlight (Al Stone) [1803969]
- [acpi] ACPI: video: Use native backlight on Lenovo E41-25/45 (Al Stone) [1803969]
- [acpi] ACPI: video: fix typo in comment (Al Stone) [1803969]
- [acpi] ACPI / battery: Deal better with neither design nor full capacity not being reported (Al Stone) [1803969]
- [acpi] ACPI / battery: Use design-cap for capacity calculations if full-cap is not available (Al Stone) [1803969]
- [acpi] ACPI / battery: Deal with design or full capacity being reported as -1 (Al Stone) [1803969]
- [acpi] ACPI/sleep: Convert acpi_wakeup_address into a function (Al Stone) [1803969]
- [acpi] ACPI: PM: Avoid attaching ACPI PM domain to certain devices (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Rework ACPI events synchronization (Al Stone) [1803969]
- [acpi] ACPI: EC: Rework flushing of pending work (Al Stone) [1803969]
- [acpi] ACPI: bus: Fix NULL pointer check in acpi_bus_get_private_data() (Al Stone) [1803969]
- [acpi] ACPI: Fix Kconfig indentation (Al Stone) [1803969]
- [acpi] ACPI: OSL: only free map once in osl.c (Al Stone) [1803969]
- [acpi] ACPI: button: Add DMI quirk for Acer Switch 10 SW5-032 lid-switch (Al Stone) [1803969]
- [acpi] ACPI: sysfs: Change ACPI_MASKABLE_GPE_MAX to 0x100 (Al Stone) [1803969]
- [acpi] ACPI: OSI: Shoot duplicate word (Al Stone) [1803969]
- [acpi] ACPI: HMAT: use u instead of d to print u32 values (Al Stone) [1803969]
- [acpi] ACPI: NUMA: HMAT: fix a section mismatch (Al Stone) [1803969]
- [acpi] ACPI: HMAT: don't mix pxm and nid when setting memory target processor_pxm (Al Stone) [1803969]
- [acpi] ACPI: NUMA: HMAT: Register "soft reserved" memory as an "hmem" device (Al Stone) [1803969]
- [acpi] ACPI: NUMA: HMAT: Register HMAT at device_initcall level (Al Stone) [1803969]
- [acpi] ACPI: NUMA: Establish a new drivers/acpi/numa/ directory (Al Stone) [1803969]
- [x86] x86/efi: EFI soft reservation to E820 enumeration (Al Stone) [1803969]
- [firmware] efi: Common enable/disable infrastructure for EFI soft reservation (Al Stone) [1803969]
- [firmware] efi: Enumerate EFI_MEMORY_SP (Al Stone) [1803969]
- [dax] device-dax: Add a driver for "hmem" devices (Al Stone) [1803969]
- [nvdimm] lib: Uplevel the pmem "region" ida to a global allocator (Al Stone) [1803969]
- [acpi] ACPICA: Update version to 20191018 (Al Stone) [1803969]
- [acpi] ACPICA: debugger: remove leading whitespaces when converting a string to a buffer (Al Stone) [1803969]
- [acpi] ACPICA: acpiexec: initialize all simple types and field units from user input (Al Stone) [1803969]
- [acpi] ACPICA: debugger: add field unit support for acpi_db_get_next_token (Al Stone) [1803969]
- [acpi] ACPICA: debugger: surround field unit output with braces '{' (Al Stone) [1803969]
- [acpi] ACPICA: debugger: add command to dump all fields of particular subtype (Al Stone) [1803969]
- [acpi] ACPICA: utilities: add flag to only display data when dumping buffers (Al Stone) [1803969]
- [acpi] ACPICA: make acpi_load_table() return table index (Al Stone) [1803969]
- [acpi] ACPICA: Add new external interface, acpi_unload_table() (Al Stone) [1803969]
- [acpi] ACPICA: More Clang changes (Al Stone) [1803969]
- [acpi] ACPICA: Win OSL: Replace get_tick_count with get_tick_count64 (Al Stone) [1803969]
- [acpi] ACPICA: Results from Clang (Al Stone) [1803969]
- [acpi] ACPI: EC: add support for hardware-reduced systems (Al Stone) [1803969]
- [acpi] ACPI: EC: tweak naming in preparation for GpioInt support (Al Stone) [1803969]
- [acpi] ACPI: button: Remove unused acpi_lid_notifier_register() functions (Al Stone) [1803969]
- [acpi] ACPI: button: Add DMI quirk for Asus T200TA (Al Stone) [1803969]
- [acpi] ACPI: button: Add DMI quirk for Medion Akoya E2215T (Al Stone) [1803969]
- [acpi] ACPI: button: Turn lid_blacklst DMI table into a generic quirk table (Al Stone) [1803969]
- [acpi] ACPI: button: Allow disabling LID support with the lid_init_state module option (Al Stone) [1803969]
- [acpi] ACPI: button: Refactor lid_init_state module parsing code (Al Stone) [1803969]
- [acpi] ACPI: LPSS: Add dmi quirk for skipping _DEP check for some device-links (Al Stone) [1803969]
- [acpi] ACPI: LPSS: Add LNXVIDEO -> BYT I2C1 to lpss_device_links (Al Stone) [1803969]
- [acpi] ACPI: LPSS: Add LNXVIDEO -> BYT I2C7 to lpss_device_links (Al Stone) [1803969]
- [acpi] ACPI / PMIC: Add Cherry Trail Crystal Cove PMIC OpRegion driver (Al Stone) [1803969]
- [acpi] ACPI / PMIC: Add byt prefix to Crystal Cove PMIC OpRegion driver (Al Stone) [1803969]
- [acpi] ACPI / PMIC: Do not register handlers for unhandled OpRegions (Al Stone) [1803969]
- [acpi] ACPI: processor_idle: Skip dummy wait if kernel is in guest (Al Stone) [1803969]
- [acpi] acpi: Use pr_warn instead of pr_warning (Al Stone) [1803969]
- [acpi] ACPI: CPPC: Set pcc_datato NULL in acpi_cppc_processor_exit() (Al Stone) [1803969]
- [mfd] rhel: constify some function arguments when searching for devices (Al Stone) [1803969]
- [acpi] ACPI: platform: Unregister stale platform devices (Al Stone) [1803969]
- [i2c] i2c: Revert incorrect conversion to use generic helper (Al Stone) [1803969]
- [base] drivers: Introduce device lookup variants by ACPI_COMPANION device (Al Stone) [1803969]
- [s390] drivers: s390/cio: Fix compilation warning about const qualifiers (Al Stone) [1803969]
- [s390] driver_find_device: Unify the match function with class_find_device() (Al Stone) [1803969]
- [acpi] ACPI / LPSS: Switch to use acpi_dev_hid_uid_match() (Al Stone) [1803969]
- [acpi] ACPI / utils: Move acpi_dev_get_first_match_dev() under CONFIG_ACPI (Al Stone) [1803969]
- [acpi] ACPI / utils: Describe function parameters in kernel-doc (Al Stone) [1803969]
- [acpi] ACPI: Always build evged in (Al Stone) [1803969]
- [acpi] ACPI: video: update doc for acpi_video_bus_DOS() (Al Stone) [1803969]
- [acpi] ACPI: PM: Drop Dell XPS13 9360 from LPS0 Idle _DSM blacklist (Al Stone) [1803969]
- [acpi] ACPI: HMAT: ACPI_HMAT_MEMORY_PD_VALID is deprecated since ACPI-6.3 (Al Stone) [1803969]
- [acpi] i2c: imx: ACPI support for NXP i2c controller (Al Stone) [1803969]
- [acpi] ACPI / PCI: fix acpi_pci_irq_enable() memory leak (Al Stone) [1803969]
- [acpi] ACPI: custom_method: fix memory leaks (Al Stone) [1803969]
- [acpi] ACPI: thermal: Remove redundant acpi_has_method() calls (Al Stone) [1803969]
- [acpi] ACPI / property: Fix acpi_graph_get_remote_endpoint() name in kerneldoc (Al Stone) [1803969]
- [acpi] ACPI / CPPC: do not require the _PSD method (Al Stone) [1803969]
- [acpi] ACPI: SBS: remove unused const variable 'SMBUS_PEC' (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Always set up EC GPE for system wakeup (Al Stone) [1803969]
- [platform] intel-hid: Disable button array during suspend-to-idle (Al Stone) [1803969]
- [platform] intel-hid: intel-vbtn: Avoid leaking wakeup_mode set (Al Stone) [1803969]
- [platform] platform/x86: intel-hid: Missing power button release on some Dell models (Al Stone) [1803969]
- [platform] platform/x86: intel-hid: Convert to use SPDX identifier (Al Stone) [1803969]
- [platform] platform/x86: intel-hid: Add support for Device Specific Methods (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Avoid rearming SCI for wakeup unnecessarily (Al Stone) [1803969]
- [base] PM / wakeup: Show wakeup sources stats in sysfs (Al Stone) [1803969]
- [kernel] PM / wakeup: Use wakeup_source_register() in wakelock.c (Al Stone) [1803969]
- [base] PM / wakeup: Drop wakeup_source_init(), wakeup_source_prepare() (Al Stone) [1803969]
- [base] PM: sleep: Fix possible overflow in pm_system_cancel_wakeup() (Al Stone) [1803969]
- [acpi] ACPI/PCI: Remove surplus parentheses from a return statement (Al Stone) [1803969]
- [acpi] ACPICA: Update version to 20190816 (Al Stone) [1803969]
- [acpi] ACPICA: Add "Windows 2019" string to _OSI support (Al Stone) [1803969]
- [acpi] ACPICA: Differentiate Windows 8.1 from Windows 8 (Al Stone) [1803969]
- [acpi] ACPICA: Fully deploy ACPI_PRINTF_LIKE macro (Al Stone) [1803969]
- [acpi] ACPICA: Fix issues with arg types within printf format strings (Al Stone) [1803969]
- [acpi] ACPICA: Macros: remove pointer math on a null pointer (Al Stone) [1803969]
- [acpi] ACPICA: Debugger: remove redundant assignment on obj_desc (Al Stone) [1803969]
- [acpi] ACPI / APEI: Release resources if gen_pool_add() fails (Al Stone) [1803969]
- [acpi] acpi: Use built-in RCU list checking for acpi_ioremaps list (Al Stone) [1803969]
- [acpi] HMAT: Skip publishing target info for nodes with no online memory (Al Stone) [1803969]
- [acpi] HMAT: Register attributes for memory hot add (Al Stone) [1803969]
- [acpi] HMAT: Register memory-side cache after parsing (Al Stone) [1803969]
- [acpi] ACPI / processor: don't print errors for processorIDs == 0xff (Al Stone) [1803969]
- [acpi] ACPI: PM: Print debug messages on device power state changes (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Execute LPS0 _DSM functions with suspended devices (Al Stone) [1803969]
- [acpi] ACPI: EC: PM: Make acpi_ec_dispatch_gpe() print debug message (Al Stone) [1803969]
- [acpi] ACPI: EC: PM: Consolidate some code depending on PM_SLEEP (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Eliminate acpi_sleep_no_ec_events() (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Switch EC over to polling during "noirq" suspend (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Add acpi.sleep_no_lps0 module parameter (Al Stone) [1803969]
- [acpi] ACPI: PM: s2idle: Rearrange lps0_device_attach() (Al Stone) [1803969]
- [acpi] ACPI / APEI: Get rid of NULL_UUID_LE constant (Al Stone) [1803969]
- [acpi] ACPI: PM: Set up EC GPE for system wakeup from drivers that need it (Al Stone) [1803969]
- [acpi] PM: sleep: Simplify suspend-to-idle control flow (Al Stone) [1803969]
- [kernel] PCI: irq: Introduce rearm_wake_irq() (Al Stone) [1803969]
- [acpi] ACPI: PM: Set s2idle_wakeup earlier and clear it later (Al Stone) [1803969]
- [acpi] ACPI: EC: Return bool from acpi_ec_dispatch_gpe() (Al Stone) [1803969]
- [acpi] ACPICA: Return u32 from acpi_dispatch_gpe() (Al Stone) [1803969]
- [kernel] kernel/sysctl.c: ignore out-of-range taint bits introduced via kernel.tainted (Rafael Aquini) [1845358]
- [documentation] kernel: add panic_on_taint (Rafael Aquini) [1845358]
- [mm] hugetlbfs: fix changes to command line processing (Baoquan He) [1823769]
- [documentation] hugetlbfs: clean up command line processing (Baoquan He) [1823769]
- [mm] hugetlbfs: remove hugetlb_add_hstate() warning for existing hstate (Baoquan He) [1823769]
- [mm] hugetlbfs: move hugepagesz= parsing to arch independent code (Baoquan He) [1823769]
- [mm] mm: simplify MEMORY_ISOLATION && COMPACTION || CMA into CONTIG_ALLOC (Baoquan He) [1823769]
- [mm] hugetlbfs: add arch_hugetlb_valid_size (Baoquan He) [1823769]
- [mm] arm64/hugetlb: Use macros for contiguous huge page sizes (Baoquan He) [1823769]
- [mm] arm64: hugetlb: Register hugepages during arch init (Baoquan He) [1823769]
- [fs] xfs: prohibit fs freezing when using empty transactions (Brian Foster) [1845099]
- [security] selinux: properly handle multiple messages in selinux_netlink_send() (Ondrej Mosnacek) [1839643] {CVE-2020-10751}
- [mm] bdi: add a ->dev_name field to struct backing_dev_info (Ming Lei) [1788378]
- [block] bdi: use bdi_dev_name() to get device name (Ming Lei) [1788378]
- [mm] bdi: move bdi_dev_name out of line (Ming Lei) [1788378]
- [fs] memcg: fix a crash in wb_workfn when a device disappears (Ming Lei) [1788378]

* Tue Jun 16 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-215.el8]
- [tools] libbpf: provide backported RHEL symbols as upstream aliases 2 (Yauheni Kaliuta) [1813372]
- [include] bpf: include/linux/bpf.h: fix spaces (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add test for freplace program with expected_attach_type (Yauheni Kaliuta) [1813372]
- [scripts] checkpatch: don't warn about new vsprintf pointer extension 'pe' (Yauheni Kaliuta) [1813372]
- [s390] s390: enable bpf jit by default when not built as always-on (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Copy runqslower to OUTPUT directory (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix memory leak in test selector (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix huge memory leak in libbpf_find_vmlinux_btf_id() (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add runqslower binary to .gitignore (Yauheni Kaliuta) [1813372]
- [net] bpf: Change kvfree to kfree in generic_map_lookup_batch() (Yauheni Kaliuta) [1813372]
- [tools] bpf, selftests: Use bpf_probe_read_kernel (Yauheni Kaliuta) [1813372]
- [net] bpf/cgroup: Replace rcu_swap_protected() with rcu_replace_pointer() (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix bug in mmap() implementation for BPF array map (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Validate frozen map contents stays frozen (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix handling of XADD on BTF memory (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Run SYN cookies with reuseport BPF test only for TCP (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Fix typo in bash-completion (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix handling of optional field_name in btf_dump__emit_type_decl (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Declare bpf_log_buf variables as static (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix a couple of broken test_btf cases (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Enforce returning 0 for fentry/fexit programs (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix BPF_KRETPROBE macro and use it in attach_probe test (Yauheni Kaliuta) [1813372]
- [net] bpf: Propagate expected_attach_type when verifying freplace programs (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix trampoline_count clean up logic (Yauheni Kaliuta) [1813372]
- [net] bpf: Explicitly memset some bpf info structures declared on the stack (Yauheni Kaliuta) [1813372]
- [net] bpf: Explicitly memset the bpf_attr structure (Yauheni Kaliuta) [1813372]
- [net] bpf: Sanitize the bpf_struct_ops tcp-cc name (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add test for the packed enum member in struct/union (Yauheni Kaliuta) [1813372]
- [net] bpf/btf: Fix BTF verification of enum members in struct/union (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix cgroup ref leak in cgroup_bpf_inherit on out-of-memory (Yauheni Kaliuta) [1813372]
- [net] bpf: Initialize storage pointers to NULL to prevent freeing garbage pointer (Yauheni Kaliuta) [1813372]
- [tools] selftests: bpf: Add test for JMP32 JSET BPF_X with upper bits set (Yauheni Kaliuta) [1813372]
- [x86] bpf, x32: Fix bug with JMP32 JSET BPF_X checking upper bits (Yauheni Kaliuta) [1813372]
- [net] bpf: Do not allow map_freeze in struct_ops map (Yauheni Kaliuta) [1813372]
- [net] bpf: Return better error value in delete_elem for struct_ops map (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add send_signal_sched_switch test (Yauheni Kaliuta) [1813372]
- [kernel] bpf: Fix deadlock with rq_lock in bpf_send_signal() (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix a potential deadlock with bpf_map_do_batch (Yauheni Kaliuta) [1813372]
- [net] bpf: Do not grab the bucket spinlock by default on htab batch ops (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Sanitise internal map names so they are not rejected by the kernel (Yauheni Kaliuta) [1813372]
- [tools] bpf, uapi: Remove text about bpf_redirect_map() giving higher performance (Yauheni Kaliuta) [1813372]
- [net] bpf, offload: Replace bitwise AND by logical AND in bpf_prog_offload_info_fill (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Mark SYN cookie test skipped for UDP sockets (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix error checking on reading the tcp_fastopen sysctl (Yauheni Kaliuta) [1813372]
- [net] bpf: Make btf_check_func_type_match() static (Yauheni Kaliuta) [1813372]
- [tools] bpf: Selftests build error in sockmap_basic.c (Yauheni Kaliuta) [1813372]
- [net] bpf: Improve bucket_log calculation logic (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Test freeing sockmap/sockhash with a socket in it (Yauheni Kaliuta) [1813372]
- [tools] tools/bpf/runqslower: Rebuild libbpf.a on libbpf source change (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix trampoline_count.c selftest compilation warning (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix modifier skipping logic (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Remove redundant "HAVE" prefix from the large INSN limit check (Yauheni Kaliuta) [1813372]
- [tools] runqslower: Fix Makefile (Yauheni Kaliuta) [1813372]
- [net] bpf: Reuse log from btf_prase_vmlinux() in btf_struct_ops_init() (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add test based on port range for BPF flow dissector (Yauheni Kaliuta) [1813372]
- [net] bpf: map_seq_next should always increase position index (Yauheni Kaliuta) [1813372]
- [tools] tools/bpf: Allow overriding llvm tools for runqslower (Yauheni Kaliuta) [1813372]
- [tools] selftest/bpf: Add test for allowed trampolines count (Yauheni Kaliuta) [1813372]
- [net] bpf: Allow to resolve bpf trampoline and dispatcher in unwind (Yauheni Kaliuta) [1813372]
- [net] bpf: Allow BTF ctx access for string pointers (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Improve handling of failed CO-RE relocations (Yauheni Kaliuta) [1813372]
- [tools] selftests: bpf: Reset global state between reuseport test runs (Yauheni Kaliuta) [1813372]
- [tools] selftests: bpf: Make reuseport test output more legible (Yauheni Kaliuta) [1813372]
- [tools] selftests: bpf: Ignore FIN packets for reuseport tests (Yauheni Kaliuta) [1813372]
- [tools] selftests: bpf: Use a temporary file in test_sockmap (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Print function linkage in BTF dump (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Improve bpftool changes detection (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Initialize duration variable before using (Yauheni Kaliuta) [1813372]
- [tools] bpf: tcp: Add bpf_cubic example (Yauheni Kaliuta) [1813372]
- [tools] bpf: Sync uapi bpf.h to tools/ (Yauheni Kaliuta) [1813372]
- [net] bpf: Add BPF_FUNC_jiffies64 (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add tests for program extensions (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add support for program extensions (Yauheni Kaliuta) [1813372]
- [net] bpf: Introduce dynamic program extensions (Yauheni Kaliuta) [1813372]
- [scripts] bpf, btf: Always output invariant hit in pahole DWARF to BTF transform (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Build urandom_read with LDFLAGS and LDLIBS (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix error path under memory pressure (Yauheni Kaliuta) [1813372]
- [net] bpf: don't bother with getname/kern_path - use user_path_at (Yauheni Kaliuta) [1813372]
- [tools] selftests: Refactor build to remove tools/lib/bpf from include path (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: Use consistent include paths for libbpf (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Use consistent include paths for libbpf (Yauheni Kaliuta) [1813372]
- [tools] runsqslower: Support user-specified libbpf include and object paths (Yauheni Kaliuta) [1813372]
- [tools] tools/runqslower: Remove tools/lib/bpf from include path (Yauheni Kaliuta) [1813372]
- [tools] selftests: Use consistent include paths for libbpf (Yauheni Kaliuta) [1813372]
- [tools] tools/runqslower: Use consistent include paths for libbpf (Yauheni Kaliuta) [1813372]
- [tools] selftests: Pass VMLINUX_BTF to runqslower Makefile (Yauheni Kaliuta) [1813372]
- [tools] tools/bpf/runqslower: Fix override option for VMLINUX_BTF (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: Don't try to remove user's homedir on clean (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Skip perf hw events test if the setup disabled it (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Don't check for btf fd in test_btf (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix memory leaks in generic update/delete batch ops (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Load btf_vmlinux only once per object (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix potential multiplication overflow in mmap() size calculation (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Simplify BTF initialization logic (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix error handling bug in btf_dump__new (Yauheni Kaliuta) [1813372]
- [net] bpf: Remove set but not used variable 'first_key' (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Revert bpf_helper_defs.h inclusion regression (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix test_progs send_signal flakiness with nmi mode (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix unneeded extra initialization in bpf_map_batch_common (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add whitelist/blacklist of test names to test_progs (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Support dumping a map with btf_vmlinux_value_type_id (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Add struct_ops map name (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Expose bpf_find_kernel_btf as a LIBBPF_API (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Fix missing BTF output for json during map dump (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Fix a leak of btf object (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add batch ops testing to array bpf map (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add batch ops testing for htab and htab_percpu map (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add libbpf support to batch ops (Yauheni Kaliuta) [1813372]
- [tools] tools/bpf: Sync uapi header bpf.h (Yauheni Kaliuta) [1813372]
- [net] bpf: Add batch ops to all htab bpf map (Yauheni Kaliuta) [1813372]
- [net] bpf: Add lookup and update batch ops to arraymap (Yauheni Kaliuta) [1813372]
- [net] bpf: Add generic support for update and delete batch ops (Yauheni Kaliuta) [1813372]
- [net] bpf: Add generic support for lookup batch op (Yauheni Kaliuta) [1813372]
- [net] bpf: Add bpf_map_{value_size, update_value, map_copy_value} functions (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add a test for attaching a bpf fentry/fexit trace to an XDP program (Yauheni Kaliuta) [1813372]
- [tools] tools/bpf: Add self tests for bpf_send_signal_thread() (Yauheni Kaliuta) [1813372]
- [kernel] bpf: Add bpf_send_signal_thread() helper (Yauheni Kaliuta) [1813372]
- [net] bpf: Fix seq_show for BPF_MAP_TYPE_STRUCT_OPS (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Build runqslower from selftests (Yauheni Kaliuta) [1813372]
- [tools] tools/bpf: Add runqslower tool to tools/bpf (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Apply preserve_access_index attribute to all types in BTF dump (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Conform selftests/bpf Makefile output to libbpf and bpftool (Yauheni Kaliuta) [1813372]
- [scripts] libbpf: Clean up bpf_helper_defs.h generation output (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add BPF_PROG, BPF_KPROBE, and BPF_KRETPROBE macros (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Poison kernel-only integer types (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add unit tests for global functions (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Modify a test to check global functions (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add a test for a large global function (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add fexit-to-skb test for global funcs (Yauheni Kaliuta) [1813372]
- [net] bpf: Introduce function-by-function verification (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Further clean up Makefile output (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Ensure bpf_helper_defs.h are taken from selftests dir (Yauheni Kaliuta) [1813372]
- [tools] libbpf,selftests/bpf: Fix clean targets (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Make bpf_map order and indices stable (Yauheni Kaliuta) [1813372]
- [tools] bpf: Document BPF_F_QUERY_EFFECTIVE flag (Yauheni Kaliuta) [1813372]
- [tools] bpf: Add bpf_dctcp example (Yauheni Kaliuta) [1813372]
- [tools] bpf: libbpf: Add STRUCT_OPS support (Yauheni Kaliuta) [1813372]
- [tools] bpf: Synch uapi bpf.h to tools/ (Yauheni Kaliuta) [1813372]
- [net] bpf: Add BPF_FUNC_tcp_send_ack helper (Yauheni Kaliuta) [1813372]
- [net] bpf: tcp: Support tcp_congestion_ops in bpf (Yauheni Kaliuta) [1813372]
- [net] bpf: Introduce BPF_MAP_TYPE_STRUCT_OPS (Yauheni Kaliuta) [1813372]
- [net] bpf: Introduce BPF_PROG_TYPE_STRUCT_OPS (Yauheni Kaliuta) [1813372]
- [net] bpf: Support bitfield read access in btf_struct_access (Yauheni Kaliuta) [1813372]
- [net] bpf: Add enum support to btf_ctx_access() (Yauheni Kaliuta) [1813372]
- [net] bpf: Avoid storing modifier to info->btf_id (Yauheni Kaliuta) [1813372]
- [net] bpf: Save PTR_TO_BTF_ID register state when spilling to stack (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Restore original comm in test_overhead (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Add misc section and probe for large INSN limit (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add probe for large INSN limit (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Make skeleton C code compilable with C++ compiler (Yauheni Kaliuta) [1813372]
- [tools] bpf: Print error message for bpftool cgroup show (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: Xdp_redirect_cpu fix missing tracepoint attach (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: xdpsock: Add option to specify transmit fill pattern (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: xdpsock: Add option to specify tx packet size (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: xdpsock: Add option to specify number of packets to send (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: xdpsock: Add option to specify batch size (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: xdpsock: Use common code to handle signal and main exit (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: xdpsock: Add duration option to specify how long to run (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Preserve errno in test_progs CHECK macros (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Test BPF_F_REPLACE in cgroup_attach_multi (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Convert test_cgroup_attach to prog_tests (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Introduce bpf_prog_attach_xattr (Yauheni Kaliuta) [1813372]
- [net] bpf: Support replacing cgroup-bpf program in MULTI mode (Yauheni Kaliuta) [1813372]
- [net] bpf: Remove unused new_flags in hierarchy_allows_attach() (Yauheni Kaliuta) [1813372]
- [net] bpf: Simplify __cgroup_bpf_attach (Yauheni Kaliuta) [1813372]
- [net] bpf: Remove unnecessary assertion on fp_old (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix another __u64 printf warning (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix printing of ulimit value (Yauheni Kaliuta) [1813372]
- [tools] libbpf: BTF is required when externs are present (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Allow to augment system Kconfig through extra optional config (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Put Kconfig externs into .kconfig section (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add bpf_link__disconnect() API to preserve underlying BPF resource (Yauheni Kaliuta) [1813372]
- [tools] bpf: Allow to change skb mark in test_run (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Work-around rst2man conversion bug (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Simplify format string to not use positional args (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Add gen subcommand manpage (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Remove BPF_EMBED_OBJ macro from libbpf.h (Yauheni Kaliuta) [1813372]
- [tools] bpftool, selftests/bpf: Embed object file inside skeleton (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Reduce log level for custom section names (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix libbpf_common.h when installing libbpf through 'make install' (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: More succinct Makefile output (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add zlib as a dependency in pkg-config template (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Print hint about ulimit when getting permission denied error (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: Attach XDP programs in driver mode by default (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: Set -fno-stack-protector when building BPF programs (Yauheni Kaliuta) [1813372]
- [samples] samples/bpf: Add missing -lz to TPROGS_LDLIBS (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Fix compilation warning on shadowed variable (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Fix build by renaming variables (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add flexible array relocation tests (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Support flexible arrays in CO-RE (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add tests for libbpf-provided externs (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Generate externs datasec in BPF skeleton (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Support libbpf-provided extern variables (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Extract internal map names into constants (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Add `gen skeleton` BASH completions (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add test validating data section to struct convertion layout (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Convert few more selftest to skeletons (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add BPF skeletons selftests and convert attach_probe.c (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Add skeleton codegen command (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add BPF object skeleton support (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Reduce log level of supported section names dump (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Postpone BTF ID finding for TRACING programs to load phase (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Refactor global data map initialization (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Expose BPF program's function name (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Expose BTF-to-C type declaration emitting API (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Expose btf__align_of() API (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Extract common user-facing helpers (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add BPF_EMBED_OBJ macro for embedding BPF .o files (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Move non-public APIs from libbpf.h to libbpf_internal.h (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Add generic bpf_program__attach() (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Don't require root for bpf_object__open() (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Match maps by name (Yauheni Kaliuta) [1813372]
- [tools] bpftool: Match programs by name (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Test wire_len/gso_segs in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1813372]
- [net] bpf: Expose __sk_buff wire_len/gso_segs to BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1813372]
- [x86] bpf, x86: Align dispatcher branch targets to 16B (Yauheni Kaliuta) [1813372]
- [tools] selftests: bpf: Add xdp_perf test (Yauheni Kaliuta) [1813372]
- [net] bpf: Start using the BPF dispatcher in BPF_TEST_RUN (Yauheni Kaliuta) [1813372]
- [net] bpf, xdp: Start using the BPF dispatcher for XDP (Yauheni Kaliuta) [1813372]
- [net] bpf: Introduce BPF dispatcher (Yauheni Kaliuta) [1813372]
- [net] bpf: Move trampoline JIT image allocation to a function (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Fix perf_buffer test on systems w/ offline CPUs (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add CPU mask parsing tests (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Switch reuseport tests for test_progs framework (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Move reuseport tests under prog_tests/ (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Pull up printing the test name into test runner (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Propagate errors during setup for reuseport tests (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Run reuseport tests in a loop (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Unroll the main loop in reuseport test (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Add helpers for getting socket family & type name (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Use sa_family_t everywhere in reuseport tests (Yauheni Kaliuta) [1813372]
- [tools] selftests/bpf: Let libbpf determine program type from section name (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Recognize SK_REUSEPORT programs from section name (Yauheni Kaliuta) [1813372]
- [arm64] bpf, x86, arm64: Enable jit by default when not built as always-on (Yauheni Kaliuta) [1813372]
- [net] bpf: Switch to offsetofend in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1813372]
- [tools] libbpf: Bump libpf current version to v0.0.7 (Yauheni Kaliuta) [1813372]
- [fs] vmalloc: fix remap_vmalloc_range() bounds checks (Yauheni Kaliuta) [1813370]
- [net] bpf: Prevent re-mmap()'ing BPF map as writable for initially r/o mapping (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: fix test_sysctl_prog with alu32 (Yauheni Kaliuta) [1813370]
- [powerpc] powerpc/bpf: Enable bpf_probe_read{, str}() on powerpc again (Yauheni Kaliuta) [1813370]
- [kernel] bpf: Restrict bpf_trace_printk()'s s usage and add pks, pus specifier (Yauheni Kaliuta) [1813370]
- [lib] printf: add support for printing symbolic error names (Yauheni Kaliuta) [1813370]
- [net] bpf: Add bpf_probe_read_{user, kernel}_str() to do_refine_retval_range (Yauheni Kaliuta) [1813370]
- [arm64] bpf: Restrict bpf_probe_read{, str}() only to archs where they work (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Fix accounting bug with direct->count in register_ftrace_direct() (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Return the first found result in lookup_rec() (Yauheni Kaliuta) [1813370]
- [net] bpf: Undo incorrect __reg_bound_offset32 handling (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix tnum constraints for 32-bit comparisons (Yauheni Kaliuta) [1813370]
- [x86] x86: Fix kernel-doc atomic.h warnings (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix trampoline usage in preempt (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Reintroduce missed build targets (Yauheni Kaliuta) [1813370]
- [trace] bpf: Reliably preserve btf_trace_xxx types (Yauheni Kaliuta) [1813370]
- [include] bpf: Avoid setting bpf insns pages read-only when prog is jited (Yauheni Kaliuta) [1813370]
- [scripts] bpf: Force .BTF section start to zero when dumping from vmlinux (Yauheni Kaliuta) [1813370]
- [scripts] bpf: Support pre-2.25-binutils objcopy for vmlinux BTF (Yauheni Kaliuta) [1813370]
- [net] bpfilter: remove superfluous testing message (Jiri Benc) [1819632]
- [net] bpfilter: fix dprintf usage for /dev/kmsg (Jiri Benc) [1819632]
- [net] bpf, sockmap: Remove bucket->lock from sock_{hash|map}_free (Jiri Benc) [1819632]
- [netdrv] veth: ignore peer tx_dropped when counting local rx_dropped (Jiri Benc) [1819632]
- [net] xsk: Publish global consumer pointers when NAPI is finished (Jiri Benc) [1819632]
- [kernel] bpf, xdp: Remove no longer required rcu_read_{un}lock() (Jiri Benc) [1819632]
- [netdrv] bpf, xdp: virtio_net use access ptr macro for xdp enable check (Jiri Benc) [1819632]
- [kernel] bpf, xdp: Update devmap comments to reflect napi/rcu usage (Jiri Benc) [1819632]
- [net] xsk, net: Make sock_def_readable() have external linkage (Jiri Benc) [1819632]
- [kernel] devmap: Adjust tracepoint for map-less queue flush (Jiri Benc) [1819632]
- [net] xdp: Use bulking for non-map XDP_REDIRECT and consolidate code paths (Jiri Benc) [1819632]
- [net] xdp: Move devmap bulk queue into struct net_device (Jiri Benc) [1819632]
- [net] xsk: Support allocations of large umems (Jiri Benc) [1819632]
- [tools] Sync uapi/linux/if_link.h (Jiri Benc) [1819632]
- [net] bpf: Return -EBADRQC for invalid map type in __bpf_tx_xdp_map (Jiri Benc) [1819632]
- [net] flow_dissector: fix document for skb_flow_get_icmp_tci (Jiri Benc) [1819632]
- [net] xsk: Use struct_size() helper (Jiri Benc) [1819632]
- [net] xsk: Add function naming comments and reorder functions (Jiri Benc) [1819632]
- [net] xsk: Remove unnecessary READ_ONCE of data (Jiri Benc) [1819632]
- [net] xsk: ixgbe: i40e: ice: mlx5: Xsk_umem_discard_addr to xsk_umem_release_addr (Jiri Benc) [1819632]
- [net] xsk: Change names of validation functions (Jiri Benc) [1819632]
- [net] xsk: Simplify the consumer ring access functions (Jiri Benc) [1819632]
- [net] xsk: Simplify xskq_nb_avail and xskq_nb_free (Jiri Benc) [1819632]
- [net] xsk: Eliminate the RX batch size (Jiri Benc) [1819632]
- [net] xsk: Standardize naming of producer ring access functions (Jiri Benc) [1819632]
- [net] xsk: Consolidate to one single cached producer pointer (Jiri Benc) [1819632]
- [net] xsk: Simplify detection of empty and full rings (Jiri Benc) [1819632]
- [net] xsk: Eliminate the lazy update threshold (Jiri Benc) [1819632]
- [net] xdp: Simplify __bpf_tx_xdp_map() (Jiri Benc) [1819632]
- [net] xdp: Remove map_to_flush and map swap detection (Jiri Benc) [1819632]
- [net] xdp: Make cpumap flush_list common for all map instances (Jiri Benc) [1819632]
- [net] xdp: Make devmap flush_list common for all map instances (Jiri Benc) [1819632]
- [net] xsk: Make xskmap flush_list common for all map instances (Jiri Benc) [1819632]
- [kernel] xdp: Fix graze->grace type-o in cpumap comments (Jiri Benc) [1819632]
- [kernel] xdp: Simplify cpumap cleanup (Jiri Benc) [1819632]
- [kernel] xdp: Simplify devmap cleanup (Jiri Benc) [1819632]
- [net] sysctl: Fix compiler warning when only cBPF is present (Jiri Benc) [1819631]
- [net] dsa: fix flow dissection on Tx path (Jiri Benc) [1819631]
- [net] page_pool: add the possibility to sync DMA memory for device (Jiri Benc) [1819631]
- [net] xsk: Fix xsk_poll()'s return type (Jiri Benc) [1819631]
- [tools] net-af_xdp: Use correct number of channels from ethtool (Jiri Benc) [1819631]
- [net] xdp: remove memory poison on free for struct xdp_mem_allocator (Jiri Benc) [1819631]
- [documentation] xsk: Extend documentation for Rx|Tx-only sockets and shared umems (Jiri Benc) [1819631]
- [net] xsk: Restructure/inline XSKMAP lookup/redirect/flush (Jiri Benc) [1819631]
- [kernel] xsk: Store struct xdp_sock as a flexible array member of the XSKMAP (Jiri Benc) [1819631]
- [include] xdp: Fix type of string pointer in __XDP_ACT_SYM_TAB (Jiri Benc) [1819631]
- [documentation] xsk: Improve documentation for AF_XDP (Jiri Benc) [1819631]
- [tools] Sync if_link.h (Jiri Benc) [1819631]
- [net] xdp: Trivial, fix spelling in function description (Jiri Benc) [1819631]
- [netdrv] netdevsim: Use scnprintf() for avoiding potential buffer overflow (Jiri Benc) [1819631]
- [netdrv] netdevsim: fix ptr_ret.cocci warnings (Jiri Benc) [1819631]
- [netdrv] netdevsim: remove unused sdev code (Jiri Benc) [1819631]
- [netdrv] netdevsim: use IS_ERR instead of IS_ERR_OR_NULL for debugfs (Jiri Benc) [1819631]
- [netdrv] netdevsim: fix stack-out-of-bounds in nsim_dev_debugfs_init() (Jiri Benc) [1819631]
- [netdrv] netdevsim: fix panic in nsim_dev_take_snapshot_write() (Jiri Benc) [1819631]
- [net] openvswitch: New MPLS actions for layer 2 tunnelling (Guillaume Nault) [1839760]
- [net] Rephrased comments section of skb_mpls_pop() (Guillaume Nault) [1839760]
- [net] skb_mpls_push() modified to allow MPLS header push at start of packet. (Guillaume Nault) [1839760]
- [net] Change in Openvswitch to support MPLS label depth of 3 in ingress direction (Guillaume Nault) [1839182]
- [block] block: fix use-after-free on cached last_lookup partition (Ming Lei) [1787968]

* Fri Jun 12 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-214.el8]
- [drm] drm/prime: fix extracting of the DMA addresses from a scatterlist (Jerry Snitselaar) [1815610]
- [iommu] iommu: Check for deferred attach in iommu_group_do_dma_attach() (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Add get_domain_info() helper (Jerry Snitselaar) [1815610]
- [iommu] iommu: Don't take group reference in iommu_alloc_default_domain() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Don't call .probe_finalize() under group->mutex (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Apply per-device dma_ops (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Allow PCI sub-hierarchy to use DMA domain (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Allow 32bit devices to uses DMA domain (Jerry Snitselaar) [1815610]
- [iommu] iommu: Do not probe devices on IOMMU-less busses (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix variable "iommu" set but not used (Jerry Snitselaar) [1815610]
- [iommu] iommu: Unexport iommu_group_get_for_dev() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Move more initialization to __iommu_probe_device() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Remove add_device()/remove_device() code-paths (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu: Convert to probe/release_device() call-backs (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu: Axe a useless test in 'arm_smmu_master_alloc_smes()' (Jerry Snitselaar) [1815610]
- [iommu] iommu/s390: Convert to probe/release_device() call-backs (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Convert to probe/release_device() call-backs (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Convert to probe/release_device() call-backs (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove dev_data->passthrough (Jerry Snitselaar) [1815610]
- [iommu] iommu: Export bus_iommu_probe() and make is safe for re-probing (Jerry Snitselaar) [1815610]
- [iommu] iommu: Move iommu_group_create_direct_mappings() out of iommu_group_add_device() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Split off default domain allocation from group assignment (Jerry Snitselaar) [1815610]
- [iommu] iommu: Move new probe_device path to separate function (Jerry Snitselaar) [1815610]
- [iommu] iommu: Keep a list of allocated groups in __iommu_probe_device() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Move default domain allocation to iommu_probe_device() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Add probe_device() and release_device() call-backs (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Return -ENODEV in add_device when device is not handled by IOMMU (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove dma_mask check from check_device() (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Wire up iommu_ops->def_domain_type (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Implement iommu_ops->def_domain_type call-back (Jerry Snitselaar) [1815610]
- [iommu] iommu: Add def_domain_type() callback in iommu_ops (Jerry Snitselaar) [1815610]
- [iommu] iommu: Move default domain allocation to separate function (Jerry Snitselaar) [1815610]
- [iommu] iommu: Fix reference count leak in iommu_group_alloc (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Remove real DMA lookup in find_domain (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Allocate domain info for real DMA sub-devices (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Only clear real DMA device's context entries (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix get_acpihid_device_id() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Switch to use acpi_dev_hid_uid_match() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix over-read of ACPI UID from IVRS table (Jerry Snitselaar) [1815610]
- [iommu] iommu: Fix deferred domain attachment (Jerry Snitselaar) [1815610]
- [include] iommu: Move fwspec->iommu_priv to struct dev_iommu (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu: Use accessor functions for iommu private data (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu: Refactor master_cfg/fwspec usage (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu-v3: Use accessor functions for iommu private data (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu-v3: Improve add_device() error handling (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu-v3: Return -EBUSY when trying to re-add a device (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu-v3: Fix resource_size check (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu-v3: Populate VMID field for CMDQ_OP_TLBI_NH_VA (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu-v3: Drop __GFP_ZERO flag from DMA allocation (Jerry Snitselaar) [1815610]
- [include] iommu: Introduce accessors for iommu private data (Jerry Snitselaar) [1815610]
- [acpi] ACPI/IORT: Remove direct access of dev->iommu_fwspec (Jerry Snitselaar) [1815610]
- [include] iommu: Define dev_iommu_fwspec_get() for !CONFIG_IOMMU_API (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Do not flush Device Table in iommu_map_page() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Update Device Table in increase_address_space() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Call domain_flush_complete() in update_domain() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Do not loop forever when trying to increase address space (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix race in increase_address_space()/fetch_pte() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix legacy interrupt remapping for x2APIC-enabled system (Jerry Snitselaar) [1815610]
- [iommu] iommu: Fix the memory leak in dev_iommu_free() (Jerry Snitselaar) [1815610]
- [include] iommu: Move iommu_fwspec to struct dev_iommu (Jerry Snitselaar) [1815610]
- [include] iommu: Rename struct iommu_param to dev_iommu (Jerry Snitselaar) [1815610]
- [iommu] iommu/of: Take a ref to the IOMMU driver during ->of_xlate() (Jerry Snitselaar) [1815610]
- [iommu] drivers/iommu: Take a ref to the IOMMU driver prior to ->add_device() (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix mm reference leak (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix the configuration of GCR3 table root pointer (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Silence RCU-list debugging warning in dmar_find_atsr() (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix page request descriptor size (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Populate debugfs if IOMMUs are detected (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Ignore devices with out-of-spec domain number (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix the wrong printing in RHSA parsing (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix debugfs register reads (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: quirk_ioat_snb_local_iommu: replace WARN_TAINT with pr_warn + add_taint (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: dmar_parse_one_rmrr: replace WARN_TAINT with pr_warn + add_taint (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: dmar: replace WARN_TAINT with pr_warn + add_taint (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Silence RCU-list debugging warnings (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix RCU-list bugs in intel_iommu_init() (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma: Fix MSI reservation allocation (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix a bug in intel_iommu_iova_to_phys() for huge page (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Disable IOMMU on Stoney Ridge systems (Jerry Snitselaar) [1815610]
- [iommu] iommu: intel: Use generic_iommu_put_resv_regions() (Jerry Snitselaar) [1815610]
- [iommu] iommu: amd: Use generic_iommu_put_resv_regions() (Jerry Snitselaar) [1815610]
- [iommu] iommu: arm: Use generic_iommu_put_resv_regions() (Jerry Snitselaar) [1815610]
- [iommu] iommu: Implement generic_iommu_put_resv_regions() (Jerry Snitselaar) [1815610]
- [iommu] iommu/iova: Silence warnings under memory pressure (Jerry Snitselaar) [1815610]
- [iommu] iommu: Fix Kconfig indentation (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Remove unnecessary WARN_ON_ONCE() (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Unnecessary to handle default identity domain (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Add RMRR base and end addresses sanity check (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Mark firmware tainted if RMRR fails sanity check (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Don't reject Host Bridge due to scope mismatch (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Loose requirement for flush queue initializaton (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Avoid iova flush queue in strict mode (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: trace: Extend map_sg trace event (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Avoid sending invalid page response (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix off-by-one in PASID allocation (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Avoid duplicated code for PASID setup (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Reject SVM bind for failed capability check (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Match CPU and IOMMU paging mode (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix CPU and IOMMU SVM feature matching checks (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Remove VMD child device sanity check (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Use pci_real_dma_dev() for mapping (Jerry Snitselaar) [1815610]
- [pci] PCI: Introduce pci_real_dma_dev() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove the unnecessary assignment (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove unused struct member (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Replace two consecutive readl calls with one readq (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix typos for PPR macros (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove local variables (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove unused variable (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Only support x2APIC with IVHD type 11h/40h (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Check feature support bit before accessing MSI capability registers (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Treat per-device exclusion ranges as r/w unity-mapped regions (Jerry Snitselaar) [1815610]
- [iommu] iommu: Use C99 flexible array in fwspec (Jerry Snitselaar) [1833512 1815610]
- [iommu] drivers/iommu: Allow IOMMU bus ops to be unregistered (Jerry Snitselaar) [1815610]
- [iommu] iommu/of: Request ACS from the PCI core when configuring IOMMU linkage (Jerry Snitselaar) [1815610]
- [iommu] drivers/iommu: Export core IOMMU API symbols to permit modular drivers (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Fix IOMMU perf counter clobbering during init (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma: fix variable 'cookie' set but not used (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Unlink device if failed to add to group (Jerry Snitselaar) [1815610]
- [iommu] iommu: Remove device link to group on failure (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Fix adding non-PCI devices to Intel IOMMU (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma: Relax locking in iommu_dma_prepare_msi() (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Remove incorrect PSI capability check (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma: Rationalise types for DMA masks (Jerry Snitselaar) [1815610]
- [iommu] iommu/iova: Init the struct iova to fix the possible memleak (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Check VT-d RMRR region in BIOS is reported as reserved (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Turn off translations at shutdown (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Support multiple PCI DMA aliases in IRQ Remapping (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Support multiple PCI DMA aliases in device table (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Do not re-fetch iommu->cmd_buf_tail (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Pass gfp flags to iommu_map_page() in amd_iommu_map() (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Simpify decoding logic for INVALID_PPR_REQUEST event (Jerry Snitselaar) [1815610]
- [drm] drm/prime: use dma length macro when mapping sg (Jerry Snitselaar) [1815610]
- [drm] drm/amdgpu: fix scatter-gather mapping with user pages (Jerry Snitselaar) [1815610]
- [drm] drm/radeon: fix scatter-gather mapping with user pages (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Convert AMD iommu driver to the dma-iommu api (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma-iommu: Use the dev->coherent_dma_mask (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma-iommu: Handle deferred devices (Jerry Snitselaar) [1815610]
- [include] iommu: KABI cleanup (Jerry Snitselaar) [1815610]
- [iommu] iommu: Add gfp parameter to iommu_ops::map (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Remove unnecessary locking from AMD iommu driver (Jerry Snitselaar) [1815610]
- [iommu] drivers: iommu: hyperv: Make HYPERV_IOMMU only available on x86 (Jerry Snitselaar) [1815610]
- [include] iommu/vt-d: Fix QI_DEV_IOTLB_PFSID and QI_DEV_EIOTLB_PFSID macros (Jerry Snitselaar) [1815610]
- [iommu] iommu: pass cell_count = -1 to of_for_each_phandle with cells_name (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu: Free context bitmap in the err path of arm_smmu_init_domain_context (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Return the correct dma mask when we are bypassing the IOMMU (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Apply the same IVRS IOAPIC workaround to Acer Aspire A315-41 (Jerry Snitselaar) [1815610]
- [iommu] iommu/arm-smmu: Mask TLBI address correctly (Jerry Snitselaar) [1815610]
- [iommu] iommu: Remove wrong default domain comments (Jerry Snitselaar) [1815610]
- [iommu] iommu/dma: Fix for dereferencing before null checking (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Declare Broadwell igfx dmar support snafu (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Add Scalable Mode fault information (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Use bounce buffer for untrusted devices (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Add trace events for device dma map/unmap (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Don't switch off swiotlb if bounce page is used (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Check whether device requires bounce buffer (Jerry Snitselaar) [1815610]
- [dma] swiotlb: Split size parameter to map/unmap APIs (Jerry Snitselaar) [1815610]
- [xen] swiotlb-xen: use ->map_page to implement ->map_sg (Jerry Snitselaar) [1815610]
- [xen] swiotlb-xen: make instances match their method names (Jerry Snitselaar) [1815610]
- [uapi] iommu: Add padding to struct iommu_fault (Jerry Snitselaar) [1815610]
- [iommu] iommu: Add recoverable fault reporting (Jerry Snitselaar) [1815610]
- [iommu] iommu: Introduce device fault report API (Jerry Snitselaar) [1815610]
- [include] driver core: Add per device iommu param (Jerry Snitselaar) [1815610]
- [uapi] iommu: Introduce device fault data (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Silence warnings under memory pressure (Jerry Snitselaar) [1815610]
- [iommu] iommu/amd: Override wrong IVRS IOAPIC on Raven Ridge systems (Jerry Snitselaar) [1815610]
- [iommu] iommu/vt-d: Use dma_direct for bypass devices (Jerry Snitselaar) [1815610]
- [dma] dma-direct: don't check swiotlb=force in dma_direct_map_resource (Jerry Snitselaar) [1815610]
- [mm] dma-mapping: remove the default map_resource implementation (Jerry Snitselaar) [1815610]
- [iommu] Revert "iommu/vt-d: Fix lock inversion between iommu->lock and device_domain_lock" (Jerry Snitselaar) [1815610 1813666]
- [dma] dma-direct: don't truncate dma_required_mask to bus addressing capabilities (Jerry Snitselaar) [1815610]
- [acpi] ACPI / utils: Introduce acpi_dev_hid_uid_match() helper (Jerry Snitselaar) [1815610]
- [security] efi: Only print errors about failing to get certs if EFI vars are found (Lenny Szubowicz) [1804969]
- [infiniband] RDMA/iw_cxgb4: Fix incorrect function parameters (Vishal Kulkarni) [1828676]
- [infiniband] RDMA/iw_cxgb4: initiate CLOSE when entering TERM (Vishal Kulkarni) [1828676]
- [infiniband] RDMA/iw_cgxb4: Fix an error handling path in 'c4iw_connect()' (Vishal Kulkarni) [1828676]
- [infiniband] RDMA/iw_cxgb4: Avoid freeing skb twice in arp failure case (Vishal Kulkarni) [1828676]
- [infiniband] iw_cxgb4: fix ECN check on the passive accept (Vishal Kulkarni) [1828676]
- [vfio] vfio/pci: fix memory leaks of eventfd ctx (Alex Williamson) [1837678]
- [vfio] vfio/pci: fix memory leaks in alloc_perm_bits() (Alex Williamson) [1837678]
- [vfio] vfio: avoid possible overflow in vfio_iommu_type1_pin_pages (Alex Williamson) [1837678]
- [vfio] vfio/mdev: make create attribute static (Alex Williamson) [1837678]
- [vfio] vfio/type1: remove hugepage checks in is_invalid_reserved_pfn() (Alex Williamson) [1837678]
- [vfio] vfio/type1: Initialize resv_msi_base (Alex Williamson) [1837678]
- [vfio] vfio_pci: Restore original state on release (Alex Williamson) [1837678]
- [uapi] vfio: re-arrange vfio region definitions (Alex Williamson) [1837678]
- [vfio] mdev: Send uevents around parent device registration (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Synchronize device create/remove with parent removal (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Avoid creating sysfs remove file on stale device removal (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Improve the create/remove sequence (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Avoid inline get and put parent helpers (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Fix aborting mdev child device removal if one fails (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Follow correct remove sequence (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Avoid masking error code to EBUSY (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Removed unused kref (Alex Williamson) [1837678]
- [vfio] vfio/mdev: Avoid release parent reference during error path (Alex Williamson) [1837678]
- [uapi] vfio-ccw: add handling for async channel instructions (Alex Williamson) [1837678]
- [uapi] vfio-ccw: add capabilities chain (Alex Williamson) [1837678]
- [vfio] vfio: Fix WARNING "do not call blocking ops when !TASK_RUNNING" (Alex Williamson) [1837678]
- [vfio] vfio/pci: use correct format characters (Alex Williamson) [1837678]
- [vfio] vfio: expand minor range when registering chrdev region (Alex Williamson) [1837678]
- [vfio] vfio/mdev: add static modifier to add_mdev_supported_type (Alex Williamson) [1837678]
- [vfio] vfio/type1: Remove map_try_harder() code path (Alex Williamson) [1837678]
- [vfio] vfio/pci: Fix potential memory leak in vfio_msi_cap_len (Alex Williamson) [1837678]
- [vfio] vfio: Mark expected switch fall-throughs (Alex Williamson) [1837678]
- [fs] gfs2: Only do glock put in gfs2_create_inode for free inodes (Robert S Peterson) [1831666]
- [fs] gfs2: Grab glock reference sooner in gfs2_add_revoke (Robert S Peterson) [1831666]
- [fs] Revert "gfs2: Don't demote a glock until its revokes are written" (Robert S Peterson) [1831666]
- [fs] signal: Fix wrong PIDTYPE_TGID check in send_sigio() & send_sigurg() (Waiman Long) [1845597]
- [md] dm mpath: add DM device name to Failing/Reinstating path log messages (Mike Snitzer) [1822975]
- [md] dm mpath: enhance queue_if_no_path debugging (Mike Snitzer) [1822975]
- [md] dm mpath: restrict queue_if_no_path state machine (Mike Snitzer) [1822975]
- [md] dm mpath: simplify __must_push_back (Mike Snitzer) [1822975]
- [md] dm: use DMDEBUG macros now that they use pr_debug variants (Mike Snitzer) [1822975]
- [include] dm: use dynamic debug instead of compile-time config option (Mike Snitzer) [1822975]
- [md] dm mpath: switch paths in dm_blk_ioctl() code path (Mike Snitzer) [1822975]
- [md] dm multipath: use updated MPATHF_QUEUE_IO on mapping for bio-based mpath (Mike Snitzer) [1822975]
- [tools] selftests: mlxsw: qos_mc_aware: Specify arping timeout as an integer (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Fix use-after-free of split/unsplit/type_set in case reload fails (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl_tcam: Position vchunk in a vregion list properly (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Fix some IS_ERR() vs NULL bugs (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Do not stop at FLOW_ACTION_VLAN_MANGLE (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Do not stop at FLOW_ACTION_PRIORITY (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: fix unintention integer overflow on left shift (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add test cases for devlink-trap policers (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Add support for setting of packet trap group parameters (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Switch to use correct packet trap group (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Do not initialize dedicated discard policer (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Add devlink-trap policer support (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Prepare policers for registration with devlink (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Track used packet trap policer IDs (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Extend QPCR register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_ptp: Fix build warnings (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Avoid uninitialized symbol errors (Ivan Vecera) [1821646]
- [netdrv] mlxsw: switchx2: Remove unnecessary conversion to bool (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core_acl: Avoid defining static variable in header file (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Remove unused RIF and FID families (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Add proper function documentation (Ivan Vecera) [1821646]
- [netdrv] mlxsw: i2c: Add missing field documentation (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_mr: Fix list iteration in error path (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: qos_dscp_router: Test no DSCP rewrite after pedit (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Offload FLOW_ACTION_MANGLE (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add DSCP, ECN, dscp_rw to QOS_ACTION (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Rename mlxsw_afa_qos_cmd to mlxsw_afa_qos_switch_prio_cmd (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Explicitly register packet trap groups (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Fix 64-bit division in mlxsw_sp_counter_resources_register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Offload FLOW_ACTION_PRIORITY (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add QOS_ACTION (Ivan Vecera) [1821646]
- [netdrv] mlxsw: pci: Only issue reset when system is ready (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add tc action hw_stats tests (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Expose devlink resource occupancy for counters (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Consolidate subpools initialization (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Move config validation along with resource register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Expose subpool sizes over devlink resources (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Add entry_size_res_id for each subpool and use it to query entry size (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Move sub_pools under per-instance pool struct (Ivan Vecera) [1821646]
- [tools] selftests: spectrum-2: Adjust tc_flower_scale limit according to current counter count (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_cnt: Query bank size from FW resources (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Increase register field length to 31 bits (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: RED: Test RED ECN nodrop offload (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Offload RED ECN nodrop mode (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl: Ask device for rule stats only if counter was created (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Support offloading of FIFO Qdisc (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Add handle parameter to ..._ops.replace (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Introduce struct mlxsw_sp_qdisc_state (Ivan Vecera) [1821646]
- [netdrv] net: mlxfw: Replace zero-length array with flexible-array member (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: qos_defprio: Use until_counter_is (Ivan Vecera) [1821646]
- [netdrv] mlxsw: pci: Wait longer before accessing the device after reset (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Update module_type values in PMTM register and map them to width (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: resource_scale: Invoke for Spectrum-3 (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Reduce router scale running time using offload indication (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Reduce running time using offload indication (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add shared buffer traffic test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add mlxsw lib (Ivan Vecera) [1821646]
- [tools] selftests: devlink_lib: Add devlink port helpers (Ivan Vecera) [1821646]
- [tools] selftests: devlink_lib: Check devlink info command is supported (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add shared buffer configuration test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Use busywait helper in rtnetlink test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Use busywait helper in vxlan test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Use busywait helper in blackhole routes test (Ivan Vecera) [1821646]
- [tools] selftests: devlink_trap_l3_drops: Avoid race condition (Ivan Vecera) [1821646]
- [tools] selftests: add a mirror test to mlxsw tc flower restrictions (Ivan Vecera) [1821646]
- [tools] selftests: add egress redirect test to mlxsw tc flower restrictions (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp_span_ops.buffsize_get for Spectrum-3 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Initialize advertised speeds to supported speeds (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Move the ECN-marked packet counter to ethtool (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_switchdev: Optimize SFN records processing (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Lookup and pass cookie down to devlink_trap_report() (Ivan Vecera) [1821646]
- [netdrv] mlxsw: pci: Extract cookie index for ACL discard trap packets (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core_acl_flex_actions: Implement flow_offload action cookie offload (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core_acl_flex_actions: Add trap with userdef action (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: fix spelling mistake: "progamming" -> "programming" (Ivan Vecera) [1821646]
- [tools] selftests: devlink_trap_acl_drops: Add ACL traps test (Ivan Vecera) [1821646]
- [tools] selftests: pass pref and handle to devlink_trap_drop_* helpers (Ivan Vecera) [1821646]
- [tools] selftests: introduce test for mlxsw tc flower restrictions (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Add ACL devlink-trap support (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Introduce dummy group with thin policer (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Extend MLXSW_RXL_DIS to register disabled trap group (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Allow to enable/disable rx_listener for trap (Ivan Vecera) [1821646]
- [netdrv] mlxsw: acl_flex_actions: Trap all ACL dropped packets to DISCARD_*_ACL traps (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl: Pass the ingress indication down to flex action (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Disable mixed bound blocks to contain action drop (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl: Track ingress and egress block bindings (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Prepare mlxsw_core_trap_action_set() to handle not only action (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Use listener->en/dis_action instead of hard-coded values (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Allow to register disabled traps using MLXSW_RXL_DIS (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Set unreg_action to be SET_FW_DEFAULT (Ivan Vecera) [1821646]
- [netdrv] mlxsw: pci: Remove unused values (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Remove priv from listener equality comparison (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl: Make block arg const where appropriate (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Make global arrays const as they should be (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Remove initialization to false of mlxsw_listener struct (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Convert is_event and is_ctrl bools to be single bits (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Remove dummy union name from struct mlxsw_listener (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Remove unused action field from mlxsw_rx_listener struct (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Move policer initialization to mlxsw_sp_trap_init() (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core_acl_flex_actions: Rename Trap / Discard Action to Trap Action (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Move functions to avoid their forward declarations (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Use err variable instead of directly checking func return value (Ivan Vecera) [1821646]
- [netdrv] net/mlx5: Add fsm_reactivate callback support (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Add reactivate flow support to FSM burn flow (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Use MLXFW_ERR_MSG macro for error reporting (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Convert pr_* to dev_* in mlxfw_fsm.c (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: More error messages coverage (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Improve FSM err message reporting and return codes (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Generic mlx FW flash status notify (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Remove RTNL where possible (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Take router lock from exported helpers (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Take router lock from inetaddr listeners (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Take router lock from netdev listener (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_dpipe: Take router lock from dpipe code (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Take router lock from inside routing code (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Introduce router lock (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Store NVE decapsulation configuration in router (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Expose router struct to internal users (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_mr: Protect multicast route list with a lock (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_mr: Protect multicast table list with a lock (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_mr: Publish multicast route after writing it to the device (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_nve: Make tunnel initialization symmetric (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Export function to check if RIF exists (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Prevent RIF access outside of routing code (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Prepare function for router lock introduction (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Prepare function for router lock introduction (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Do not assume RTNL is taken when resolving underlay device (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Do not assume RTNL is taken during RIF teardown (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Do not assume RTNL is taken during nexthop init (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_span: Only update mirroring agents if present (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Convert callers to use new mirroring API (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_span: Prepare work item to update mirroring agents (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_span: Use struct_size() to simplify allocation (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_span: Do no expose mirroring agents to entire driver (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Protect counter pool with a lock (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_kvdl: Protect allocations with a lock (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Replace zero-length array with flexible-array member (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: vxlan: Add test for error path (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: vxlan: Adjust test to recent changes (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: extack: Test creation of multiple VLAN-aware bridges (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: extack: Test bridge creation with VXLAN (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Remove deprecated test (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Reduce dependency between bridge and router code (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_switchdev: Remove VXLAN checks during FID membership (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_switchdev: Have VXLAN device take reference on FID (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack to bridge creation function (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_fid: Use 'refcount_t' for FID reference counting (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_dpipe: Add missing error path (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add validation of hardware device types for MGPIR register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Clear offload indication from IPv6 nexthops on abort (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add test cases for local table route replacement (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Fix 64-bit division error in mlxsw_sp_qdisc_tbf_rate_kbps (Ivan Vecera) [1821646]
- [netdrv] mlxsw: minimal: Fix an error handling path in 'mlxsw_m_port_create()' (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Support offloading of TBF Qdisc (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Configure shaper rate and burst size together (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Add lowest_shaper_bs to struct mlxsw_sp (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Increase MLXSW_REG_QEEC_MAS_DIS (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add max_shaper_bs to QoS ETS Element Configuration (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Extract a common leaf unoffload function (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Add mlxsw_sp_qdisc_get_class_stats() (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Extract a per-TC stat function (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl: Fix use-after-free during reload (Ivan Vecera) [1821646]
- [netdrv] spectrum: Add a delayed work to update SPAN buffsize according to speed (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Fix SPAN egress mirroring buffer size for Spectrum-2 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_span: Put buffsize update code into helper function (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Push code getting port speed into a helper (Ivan Vecera) [1821646]
- [tools] selftests: devlink_trap_tunnel_vxlan: Add test case for overlay_smac_is_mc (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add OVERLAY_SMAC_MC trap (Ivan Vecera) [1821646]
- [tools] selftests: devlink_trap_tunnel_ipip: Add test case for decap_error (Ivan Vecera) [1821646]
- [tools] selftests: devlink_trap_tunnel_vxlan: Add test case for decap_error (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add tunnel devlink-trap support (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Reorder cases according to enum order (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add ECN configurations with IPinIP tunnels (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add Tunneling IPinIP Decapsulation ECN Mapping Register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add Tunneling IPinIP Encapsulation ECN Mapping Register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add NON_ROUTABLE trap (Ivan Vecera) [1821646]
- [tools] selftests: devlink_trap_l3_drops: Add test cases of irif and erif disabled (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add irif and erif disabled traps (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Include MC TCs in Qdisc counters (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Wipe xstats.backlog of down ports (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: qos_mc_aware: Fix mausezahn invocation (Ivan Vecera) [1821646]
- [netdrv] mlxsw: switchx2: Do not modify cloned SKBs during xmit (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Do not modify cloned SKBs during xmit (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Do not enforce same firmware version for multiple ASICs (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add test for FIB offload API (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Set hardware flags for routes (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Separate nexthop offload indication from route (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Only require minimum firmware version (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Update firmware version to xx.2000.2714 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Ignore grafting of invisible FIFO (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Disable DIP_LINK_LOCAL check in hardware pipeline (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Disable SIP_DIP check in hardware pipeline (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Disable MC_DMAC check in hardware pipeline (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Disable SIP_CLASS_E check in hardware pipeline (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_dcb: Allow setting default port priority (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add QoS Port DSCP to Priority Mapping Register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Support offloading of ETS Qdisc (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Generalize PRIO offload to support ETS (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Rename MLXSW_REG_QEEC_HIERARCY_* enumerators (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_qdisc: Clarify a comment (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Use dedicated policer for VRRP packets (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Skip loopback RIFs during MAC validation (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Fix out-of-memory error in mfa2 flash burning (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Fix use of uninitialized adjacency index (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: After underlay moves, demote conflicting tunnels (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Check devlink device before running test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add router scale test for Spectrum-2 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Fix determining underlay for a GRE tunnel (Ivan Vecera) [1821646]
- [netdrv] net/mlxfw: Verify FSM error code translation doesn't exceed array size (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Allocate discard adjacency entry when needed (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Enable EMAD string TLV (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add support for using EMAD string TLV (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Extend EMAD information reported to devlink hwerr (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add support for EMAD string TLV parsing (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add EMAD string TLV (Ivan Vecera) [1821646]
- [netdrv] mlxsw: emad: Remove deprecated EMAD TLVs (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Parse TLVs' offsets of incoming EMADs (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Enable devlink reload only on probe (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add test cases for devlink-trap layer 3 exceptions (Ivan Vecera) [1821646]
- [tools] selftests: forwarding: devlink: Add functionality for trap exceptions test (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add layer 3 devlink-trap exceptions support (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add specific trap for packets routed via invalid nexthops (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add new FIB entry type for reject routes (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add test cases for devlink-trap layer 3 drops (Ivan Vecera) [1821646]
- [tools] selftests: devlink: Make devlink_trap_cleanup() more generic (Ivan Vecera) [1821646]
- [tools] selftests: devlink: Export functions to devlink library (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add layer 3 devlink-trap support (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Fix error return code in mlxsw_sp_port_module_info_init() (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Generalize split count check (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Iterate over all ports in gap during unsplit create (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Fix base port get for split count 4 and 8 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Use port_module_max_width to compute base port index (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Remember split base local port and use it in unsplit (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Introduce resource for getting offset of 4 lanes split port (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Push getting offsets of split ports into a helper (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Add sanity checks into module info get (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Pass mapping values in port mapping structure (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Use mapping of port being split for creating split ports (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Replace port_to_module array with array of structs (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Distinguish between unsplittable and split port (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Move max_width check up before count check (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Use PMTM register to get max module width (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add Port Module Type Mapping Register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Extend PMLP tx/rx lane value size to 4 bits (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Fix 64-bit division in mlxsw_sp_sb_prs_init (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Enforce firmware version for Spectrum-2 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Bump firmware version to 13.2000.2308 (Ivan Vecera) [1821646]
- [netdrv] mlxsw: pci: Increase PCI reset timeout for SN3800 systems (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Increase size of MPAR register (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Unpublish devlink parameters during reload (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_buffers: remove unneeded semicolon (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_buffers: Calculate the size of the main pool (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Use guaranteed buffer size as pool size limit (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Extend QSFP EEPROM size for ethtool (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add macro for getting QSFP module EEPROM page number (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_trap: Push Ethernet header before reporting trap (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add Spectrum-2 target scale for tc flower scale test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add a resource scale test for Spectrum-2 (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add Spectrum-2 mirror-to-gretap target scale test (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Generalize the parameters of mirror_gre test (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Register switched port analyzers (SPAN) as resource (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Add support for 400Gbps (50Gbps per lane) link modes (Ivan Vecera) [1821646]
- [netdrv] mlxsw: minimal: Add validation for FW version (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Push minor/subminor fw version check into helper (Ivan Vecera) [1821646]
- [netdrv] mlxsw: thermal: Provide optimization for QSFP modules number detection (Ivan Vecera) [1821646]
- [netdrv] mlxsw: hwmon: Provide optimization for QSFP modules number detection (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Extend MGPIR register with new field exposing the number of QSFP modules (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Propagate extack down to register_fib_notifier() (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Register port netdevices into net of core (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Take devlink net instead of init_net (Ivan Vecera) [1821646]
- [netdrv] mlxsw: PCI: Send EMAD traffic on a separate queue (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Use per-netns netdevice notifier registration (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Fail in case user specifies multiple mirror actions (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Clear VLAN filters during port initialization (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_buffers: Add the ability to query the CPU port's shared buffer (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Register CPU port with devlink (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_buffers: Prevent changing CPU port's configuration (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add a test case for devlink-trap (Ivan Vecera) [1821646]
- [tools] selftests: mlxsw: Add test cases for devlink-trap L2 drops (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Add devlink-trap support (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add trap group for layer 2 discards (Ivan Vecera) [1821646]
- [netdrv] mlxsw: Add layer 2 discard trap IDs (Ivan Vecera) [1821646]
- [netdrv] mlxsw: reg: Add new trap actions (Ivan Vecera) [1821646]
- [netdrv] mlxsw: core: Add API to set trap action (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Extend to support Spectrum-3 ASIC (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Forbid to offload match on reserved TCP flags bits (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_acl: Track rules that forbid egress block bind (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_flower: Forbid to offload mirred redirect on egress (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum_router: Increase scale of IPv6 nexthop groups (Ivan Vecera) [1821646]
- [netdrv] mlxsw: spectrum: Expose KVD size for Spectrum-2 (Ivan Vecera) [1821646]
- [netdrv] geneve: change from tx_error to tx_dropped on missing metadata (Jiri Benc) [1843412]
- [net] mptcp: use untruncated hash in ADD_ADDR HMAC (Florian Westphal) [1840167]
- [net] mptcp: use rightmost 64 bits in ADD_ADDR HMAC (Florian Westphal) [1840167]
- [tools] selftests: mptcp: pm: rm the right tmp file (Florian Westphal) [1840167]
- [net] mptcp: cope better with MP_JOIN failure (Florian Westphal) [1840167]
- [net] inet_connection_sock: factor out destroy helper. (Florian Westphal) [1840167]
- [net] mptcp: add new sock flag to deal with join subflows (Florian Westphal) [1840167]
- [net] mptcp: Initialize map_seq upon subflow establishment (Florian Westphal) [1840167]
- [net] mptcp: set correct vfs info for subflows (Florian Westphal) [1840167]
- [net] mptcp: fix uninitialized value access (Florian Westphal) [1840167]
- [net] mptcp: initialize the data_fin field for mpc packets (Florian Westphal) [1840167]
- [net] mptcp: fix 'use_ack' option access. (Florian Westphal) [1840167]
- [net] mptcp: avoid a WARN on bad input. (Florian Westphal) [1840167]
- [net] mptcp: move option parsing into mptcp_incoming_options() (Florian Westphal) [1840167]
- [net] mptcp: consolidate synack processing. (Florian Westphal) [1840167]
- [net] mptcp: replace mptcp_disconnect with a stub (Florian Westphal) [1840167]
- [net] mptcp: fix race in msk status update (Florian Westphal) [1840167]
- [net] tcp: mptcp: use mptcp receive buffer space to select rcv window (Florian Westphal) [1840167]
- [net] mptcp/pm_netlink.c : add check for nla_put_in/6_addr (Florian Westphal) [1840167]
- [net] mptcp: fix data_fin handing in RX path (Florian Westphal) [1840167]
- [net] mptcp: drop req socket remote_key* fields (Florian Westphal) [1840167]
- [net] mptcp: avoid flipping mp_capable field in syn_recv_sock() (Florian Westphal) [1840167]
- [net] mptcp: handle mptcp listener destruction via rcu (Florian Westphal) [1840167]
- [net] mptcp: fix 'Attempt to release TCP socket in state' warnings (Florian Westphal) [1840167]
- [net] mptcp: fix splat when incoming connection is never accepted before exit/close (Florian Westphal) [1840167]
- [net] mptcp: fix double-unlock in mptcp_poll (Florian Westphal) [1840167]
- [net] mptcp: add some missing pr_fmt defines (Florian Westphal) [1840167]
- [net] mptcp: fix "fn parameter not described" warnings (Florian Westphal) [1840167]
- [net] mptcp: re-check dsn before reading from subflow (Florian Westphal) [1840167]
- [net] mptcp: subflow: check parent mptcp socket on subflow state change (Florian Westphal) [1840167]
- [net] mptcp: fix tcp fallback crash (Florian Westphal) [1840167]
- [tools] selftests:mptcp: fix failure due to whitespace damage (Florian Westphal) [1840167]
- [tools] selftests: add test-cases for MPTCP MP_JOIN (Florian Westphal) [1840167]
- [tools] selftests: add PM netlink functional tests (Florian Westphal) [1840167]
- [net] mptcp: add netlink-based PM (Florian Westphal) [1840167]
- [net] mptcp: add and use MIB counter infrastructure (Florian Westphal) [1840167]
- [net] mptcp: allow dumping subflow context to userspace (Florian Westphal) [1840167]
- [net] mptcp: implement and use MPTCP-level retransmission (Florian Westphal) [1840167]
- [net] mptcp: rework mptcp_sendmsg_frag to accept optional dfrag (Florian Westphal) [1840167]
- [net] mptcp: allow partial cleaning of rtx head dfrag (Florian Westphal) [1840167]
- [net] mptcp: implement memory accounting for mptcp rtx queue (Florian Westphal) [1840167]
- [net] mptcp: introduce MPTCP retransmission timer (Florian Westphal) [1840167]
- [net] mptcp: queue data for mptcp level retransmission (Florian Westphal) [1840167]
- [net] mptcp: update per unacked sequence on pkt reception (Florian Westphal) [1840167]
- [net] mptcp: Implement path manager interface commands (Florian Westphal) [1840167]
- [net] mptcp: Add handling of outgoing MP_JOIN requests (Florian Westphal) [1840167]
- [net] mptcp: Add handling of incoming MP_JOIN requests (Florian Westphal) [1840167]
- [net] mptcp: Add path manager interface (Florian Westphal) [1840167]
- [net] mptcp: Add ADD_ADDR handling (Florian Westphal) [1840167]
- [net] tcp: annotate sk->sk_wmem_queued lockless reads (Florian Westphal) [1840167]
- [net] mptcp: don't hang in mptcp_sendmsg() after TCP fallback (Florian Westphal) [1840167]
- [net] mptcp: Remove set but not used variable 'can_ack' (Florian Westphal) [1840167]
- [net] mptcp: rename fourth ack field (Florian Westphal) [1840167]
- [net] mptcp: move msk state update to subflow_syn_recv_sock() (Florian Westphal) [1840167]
- [net] mptcp: drop unneeded checks (Florian Westphal) [1840167]
- [net] mptcp: create msk early (Florian Westphal) [1840167]
- [net] mptcp: don't hang before sending 'MP capable with data' (Florian Westphal) [1840167]
- [net] mptcp: don't grow mptcp socket receive buffer when rcvbuf is locked (Florian Westphal) [1840167]
- [tools] mptcp: selftests: add rcvbuf set option (Florian Westphal) [1840167]
- [net] mptcp: always include dack if possible. (Florian Westphal) [1840167]
- [net] mptcp: Only send DATA_FIN with final mapping (Florian Westphal) [1840167]
- [net] mptcp: Use per-subflow storage for DATA_FIN sequence number (Florian Westphal) [1840167]
- [net] mptcp: Check connection state before attempting send (Florian Westphal) [1840167]
- [net] mptcp: add dummy icsk_sync_mss() (Florian Westphal) [1840167]
- [net] mptcp: defer work schedule until mptcp lock is released (Florian Westphal) [1840167]
- [net] mptcp: avoid work queue scheduling if possible (Florian Westphal) [1840167]
- [net] mptcp: remove mptcp_read_actor (Florian Westphal) [1840167]
- [net] mptcp: add rmem queue accounting (Florian Westphal) [1840167]
- [net] mptcp: update mptcp ack sequence from work queue (Florian Westphal) [1840167]
- [net] mptcp: add work queue skeleton (Florian Westphal) [1840167]
- [net] mptcp: add and use mptcp_data_ready helper (Florian Westphal) [1840167]
- [net] xfrm: fix a NULL-ptr deref in xfrm_local_error (Xin Long) [1835208]
- [net] xfrm: add IPv6 support for espintcp (Sabrina Dubroca) [1446392]
- [net] xfrm: add support for UDPv6 encapsulation of ESP (Sabrina Dubroca) [1446392]
- [net] xfrm: ifdef setsockopt(UDP_ENCAP_ESPINUDP/UDP_ENCAP_ESPINUDP_NON_IKE) (Sabrina Dubroca) [1446392]
- [net] esp: Export esp_output_fill_trailer function (Sabrina Dubroca) [1446392]
- [net] udp: fix jump label misuse (Sabrina Dubroca) [1446392]
- [net] udp: implement complete book-keeping for encap_needed (Sabrina Dubroca) [1446392]
- [net] xfrm: espintcp: save and call old ->sk_destruct (Sabrina Dubroca) [1446392]
- [net] xfrm: add espintcp (RFC 8229) (Sabrina Dubroca) [1446392]
- [net] esp4: split esp_output_udp_encap and introduce esp_output_encap (Sabrina Dubroca) [1446392]
- [net] esp4: prepare esp_input_done2 for non-UDP encapsulation (Sabrina Dubroca) [1446392]
- [net] xfrm: add route lookup to xfrm4_rcv_encap (Sabrina Dubroca) [1446392]
- [net] xfrm: introduce xfrm_trans_queue_net (Sabrina Dubroca) [1446392]
- [net] add queue argument to __skb_wait_for_more_packets and __skb_{, try_}recv_datagram (Sabrina Dubroca) [1446392]
- [net] use skb_queue_empty_lockless() in busy poll contexts (Sabrina Dubroca) [1446392]
- [include] net: add skb_queue_empty_lockless() (Sabrina Dubroca) [1446392]
- [net] add READ_ONCE() annotation in __skb_wait_for_more_packets() (Sabrina Dubroca) [1446392]
- [net] datagram: remove rendundant 'peeked' argument (Sabrina Dubroca) [1446392]
- [tools] kvm: selftests: fix rdtsc() for vmx_tsc_adjust_test (Vitaly Kuznetsov) [1841490]
- [x86] kvm: lapic: Also cancel preemption timer when disarm LAPIC timer (Vitaly Kuznetsov) [1841490]
- [s390] kvm_host: unify VM_STAT and VCPU_STAT definitions in a single place (Vitaly Kuznetsov) [1841490]
- [x86] kvm/x86: Remove redundant function implementations (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: VMX preemption timer migration test (Vitaly Kuznetsov) [1841490]
- [tools] tools arch kvm: Sync kvm headers with the kernel sources (Vitaly Kuznetsov) [1841490]
- [tools] tools headers uapi: Update tools's copy of kvm.h headers (Vitaly Kuznetsov) [1841490]
- [tools] tools headers: Sync the various kvm.h header copies (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Fix VMX preemption timer migration (Vitaly Kuznetsov) [1841490]
- [uapi] x86/kvm/hyper-v: Explicitly align hcall param for kvm_hyperv_exit (Vitaly Kuznetsov) [1841490]
- [virt] kvm: introduce kvm_read_guest_offset_cached() (Vitaly Kuznetsov) [1841490]
- [virt] kvm: rename kvm_arch_can_inject_async_page_present() to kvm_arch_can_dequeue_async_page_present() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Replace zero-length array with flexible-array (Vitaly Kuznetsov) [1841490]
- [virt] revert "kvm: No need to retry for hva_to_pfn_remapped()" (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: implement KVM_GET_NESTED_STATE and KVM_SET_NESTED_STATE (Vitaly Kuznetsov) [1841490]
- [tools] selftests: kvm: fix smm test on SVM (Vitaly Kuznetsov) [1841490]
- [tools] selftests: kvm: add a SVM version of state-test (Vitaly Kuznetsov) [1841490]
- [tools] selftests: kvm: introduce cpu_has_svm() check (Vitaly Kuznetsov) [1841490]
- [x86] kvm: mmu: pass arbitrary CR0/CR4/EFER to kvm_init_shadow_mmu (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: leave guest mode when clearing EFER.SVME (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: split nested_vmcb_check_controls (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: remove HF_HIF_MASK (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: remove HF_VINTR_MASK (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: synthesize correct EXITINTINFO on vmexit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: preserve VGIF across VMCB switch (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: extract svm_set_gif (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: remove unnecessary if (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: synchronize VMCB controls updated by the processor on every vmexit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: restore clobbered INT_CTL fields after clearing VINTR (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: save all control fields in svm->nested (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: remove trailing padding for struct vmcb_control_area (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: pass vmcb_control_area to copy_vmcb_control_area (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: clean up tsc_offset update (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: move MMU setup to nested_prepare_vmcb_control (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: extract preparation of VMCB for nested run (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: extract load_nested_vmcb_control (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: move map argument out of enter_svm_guest_mode (Vitaly Kuznetsov) [1841490]
- [virt] kvm: check userspace_addr for all memslots (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: always update CR3 in VMCS (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: always update CR3 in VMCB (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: correctly inject INIT vmexits (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: remove exit_required (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: inject exceptions via svm_check_nested_events (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: enable event window in inject_pending_event (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: track manually whether an event has been injected (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: Preserve registers modifications done before nested_svm_vmexit() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Initialize tdp_level during vCPU creation (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: leave ASID aside in copy_vmcb_control_area (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: fix condition for filtering async PF (Vitaly Kuznetsov) [1841490]
- [x86] kvm: Fix the indentation to match coding style (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: replace "fall through" with "return" to indicate different case (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Take an unsigned 32-bit int for has_emulated_msr()'s index (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Remove superfluous brackets from case statement (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: allow KVM_STATE_NESTED_MTF_PENDING in kvm_state flags (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: simplify is_mmio_spte (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: don't expose MSR_IA32_UMWAIT_CONTROL unconditionally (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: enable X86_FEATURE_WAITPKG in KVM capabilities (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Set mmio_value to '0' if reserved #PF can't be generated (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: only do L1TF workaround on affected processors (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Fix off-by-one error in kvm_vcpu_ioctl_x86_setup_mce (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Migrate the VMX-preemption timer (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Change emulated VMX-preemption timer hrtimer to absolute (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Really make emulated nested preemption timer pinned (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Remove unused 'ops' param from nested_vmx_hardware_setup() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Remove unnecessary V_IRQ unsetting (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Merge svm_enable_vintr into svm_set_vintr (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Handle preemption timer fastpath (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: TSCDEADLINE MSR emulation fastpath (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: introduce kvm_can_use_hv_timer (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Optimize posted-interrupt delivery for timer fastpath (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Introduce more exit_fastpath_completion enum values (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Introduce kvm_vcpu_exit_request() helper (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Print symbolic names of VMX VM-Exit flags in traces (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Introduce generic fastpath handler (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Drop superfluous VMREAD of vmcs02.GUEST_SYSENTER_* (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Truncate writes to vmcs.SYSENTER_EIP/ESP for 32-bit vCPU (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Improve handle_external_interrupt_irqoff inline assembly (Vitaly Kuznetsov) [1841490]
- [documentation] kvm: documentation: Fix up cpuid page (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Sanity check on gfn before removal (Vitaly Kuznetsov) [1841490]
- [virt] kvm: No need to retry for hva_to_pfn_remapped() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Force ASYNC_PF_PER_VCPU to be power of two (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Remove unneeded __ASM_SIZE usage with POP instruction (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Add a helper to consolidate root sp allocation (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Drop KVM's hugepage enums in favor of the kernel's enums (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Move max hugepage level to a separate #define (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Tweak PSE hugepage handling to avoid 2M vs 4M conundrum (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Cleanup vcpu->arch.guest_xstate_size (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Tweak handling of failure code for nested VM-Enter failure (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Capture TDP level when updating CPUID (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Move nested EPT out of kvm_x86_ops.get_tdp_level() hook (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Add proper cache tracking for CR0 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Add proper cache tracking for CR4 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Unconditionally validate CR3 during nested transitions (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Save L1 TSC offset in 'struct kvm_vcpu_arch' (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Skip IBPB when temporarily switching between vmcs01 and vmcs02 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Skip IBPB when switching between vmcs01 and vmcs02 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Use accessor to read vmcs.INTR_INFO when handling exception (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: handle wrap around 32-bit address space (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Replace late check_nested_events() hack with more precise fix (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Use vmx_get_rflags() to query RFLAGS in vmx_interrupt_blocked() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Use vmx_interrupt_blocked() directly from vmx_handle_exit() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: WARN on injected+pending exception even in nested case (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: Preserve IRQ/NMI/SMI priority irrespective of exiting behavior (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: Report interrupts as allowed when in L2 and exit-on-interrupt is set (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Prioritize SMI over nested IRQ/NMI (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Preserve IRQ/NMI priority irrespective of exiting behavior (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Split out architectural interrupt/NMI/SMI blocking checks (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Split out architectural interrupt/NMI blocking checks (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: Move SMI vmexit handling to svm_check_nested_events() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: Report NMIs as allowed when in L2 and Exit-on-NMI is set (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Report NMIs as allowed when in L2 and Exit-on-NMI is set (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: replace is_smm checks with kvm_x86_ops.smi_allowed (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Make return for {interrupt_nmi, smi}_allowed() a bool instead of int (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Set KVM_REQ_EVENT if run is canceled with req_immediate_exit set (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Open a window for pending nested VMX preemption timer (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Preserve exception priority irrespective of exiting behavior (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Implement check_nested_events for NMI (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: immediately inject INTR vmexit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: leave halted state on vmexit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: introduce nested_run_pending (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Fix pkru save/restore when guest CR4.PKE=0, move it to x86.c (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Disable AVIC before setting V_IRQ (Vitaly Kuznetsov) [1841490]
- [virt] kvm: Introduce kvm_make_all_cpus_request_except() (Vitaly Kuznetsov) [1841490]
- [tools] kvm: vmx: pass correct DR6 for GD userspace exit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86, svm: isolate vcpu->arch.dr6 from vmcb->save.dr6 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: keep DR6 synchronized with vcpu->arch.dr6 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: trap #DB and #BP to userspace if guest debugging is on (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Add KVM_SET_GUEST_DEBUG test (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Fix single-step with KVM_SET_GUEST_DEBUG (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Set RTM for DB_VECTOR too for KVM_EXIT_DEBUG (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: fix DR6 delivery for various cases of #DB injection (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Declare KVM_CAP_SET_GUEST_DEBUG properly (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Fix build for evmcs.h (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Use KVM CPU capabilities to determine CR4 reserved bits (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Explicitly clear RFLAGS.CF and RFLAGS.ZF in VM-Exit RSB path (Vitaly Kuznetsov) [1841490]
- [x86] kvm: ioapic: Restrict lazy EOI update to edge-triggered interrupts (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Fixes posted interrupt check for IRQs delivery modes (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: fill in kvm_run->debug.arch.dr[67] (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Replace a BUG_ON(1) with BUG() to squash clang warning (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: do not allow VMRUN inside SMM (Vitaly Kuznetsov) [1841490]
- [virt] kvm: add capability for halt polling (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Store vmcs.EXIT_QUALIFICATION as an unsigned long, not u32 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Drop a redundant call to vmx_get_intr_info() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: move nested-related kvm_x86_ops to a separate struct (Vitaly Kuznetsov) [1841490]
- [x86] kvm: evmcs: check if nesting is enabled (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: check_nested_events is never NULL (Vitaly Kuznetsov) [1841490]
- [tools] selftests: kvm/set_memory_region_test: do not check RIP if the guest shuts down (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: avoid infinite loop on NPF from bad address (Vitaly Kuznetsov) [1841490]
- [x86] kvm: Remove redundant argument to kvm_arch_vcpu_ioctl_run (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nsvm: Check for CR0.CD and CR0.NW on VMRUN of nested guests (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Improve latency for single target IPI fastpath (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Optimize handling of VM-Entry failures in vmx_vcpu_run() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Remove non-functional "support" for CR3 target values (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Avoid an extra memslot lookup in try_async_pf() for L2 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Set @writable to false for non-visible accesses by L2 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Cache vmcs.EXIT_INTR_INFO using arch avail_reg flags (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Cache vmcs.EXIT_QUALIFICATION using arch avail_reg flags (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Drop manual clearing of segment cache on nested VMCS switch (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Reset register cache (available and dirty masks) on VMCS switch (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Invoke ept_save_pdptrs() if and only if PAE paging is enabled (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Rename exit_reason to vm_exit_reason for nested VM-Exit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Cast exit_reason to u16 to check for nested EXTERNAL_INTERRUPT (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Pull exit_reason from vcpu_vmx in nested_vmx_reflect_vmexit() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Drop a superfluous WARN on reflecting EXTERNAL_INTERRUPT (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Split VM-Exit reflection logic into L0 vs. L1 wants (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: match comment with return type for nested_vmx_exit_reflected (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Move nested VM-Exit tracepoint into nested_vmx_reflect_vmexit() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Move VM-Fail check out of nested_vmx_exit_reflected() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Uninline nested_vmx_reflect_vmexit(), i.e. move it to nested.c (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Move reflection check into nested_vmx_reflect_vmexit() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Use do_machine_check to pass MCE to the host (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Clean cr3/pgd handling in vmx_load_mmu_pgd() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Replace "cr3" with "pgd" in "new cr3/pgd" related code (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Free only the affected contexts when emulating INVEPT (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Don't flush TLB on nested VMX transition (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Skip MMU sync on nested VMX transition when possible (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Add module param to force TLB flush on root reuse (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Add separate override for MMU sync during fast CR3 switch (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Move fast_cr3_switch() side effects to __kvm_mmu_new_cr3() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Don't reload APIC access page if its control is disabled (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Retrieve APIC access page HPA only when necessary (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Reload APIC access page on nested VM-Exit only if necessary (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Selectively use TLB_FLUSH_CURRENT for nested VM-Enter/VM-Exit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86/mmu: Use KVM_REQ_TLB_FLUSH_CURRENT for MMU specific flushes (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Introduce KVM_REQ_TLB_FLUSH_CURRENT to flush current ASID (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Add helper to handle TLB flushes on nested VM-Enter/VM-Exit (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Rename ->tlb_flush() to ->tlb_flush_all() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Document the ASID logic in svm_flush_tlb() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Introduce vmx_flush_tlb_current() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Move nested_get_vpid02() to vmx/nested.h (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Move vmx_flush_tlb() to vmx.c (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Wire up ->tlb_flush_guest() directly to svm_flush_tlb() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Drop @invalidate_gpa param from kvm_x86_ops' tlb_flush() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Clean up vmx_flush_tlb_gva() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: make Hyper-V PV TLB flush use tlb_flush_guest() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Move "flush guest's TLB" logic to separate kvm_x86_ops hook (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Use vpid_sync_vcpu_addr() to emulate INVVPID with address (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Drop redundant capability checks in low level INVVPID helpers (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Handle INVVPID fallback logic in vpid_sync_vcpu_addr() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Move vpid_sync_vcpu_addr() down a few lines (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Use vpid_sync_context() directly when possible (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Skip global INVVPID fallback if vpid==0 in vpid_sync_context() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Sync SPTEs when injecting page/EPT fault into L1 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: cleanup kvm_inject_emulated_page_fault (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: introduce kvm_mmu_invalidate_gva (Vitaly Kuznetsov) [1841490]
- [x86] kvm: Disable objtool frame pointer checking for vmenter.S (Vitaly Kuznetsov) [1841490]
- [x86] kvm: Remove CREATE_IRQCHIP/SET_PIT2 race (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Export kvm_propagate_fault() (as kvm_inject_emulated_page_fault) (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Invalidate all roots when emulating INVVPID without EPT (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Invalidate all EPTP contexts when emulating INVEPT for L1 (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: Validate the EPTP when emulating INVEPT(EXTENT_CONTEXT) (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Flush all EPTP/VPID contexts on remote TLB flush (Vitaly Kuznetsov) [1841490]
- [tools] selftests: kvm: Add testcase for creating max number of memslots (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Make set_memory_region_test common to all architectures (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Add "zero" testcase to set_memory_region_test (Vitaly Kuznetsov) [1841490]
- [tools] selftests: kvm: Add vm_get_fd() in kvm_util (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Add "delete" testcase to set_memory_region_test (Vitaly Kuznetsov) [1841490]
- [tools] kvm: sefltests: Add explicit synchronization to move mem region test (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Add GUEST_ASSERT variants to pass values to host (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Add util to delete memory region (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Use kernel's list instead of homebrewed replacement (Vitaly Kuznetsov) [1841490]
- [tools] kvm: selftests: Take vcpu pointer instead of id in vm_vcpu_rm() (Vitaly Kuznetsov) [1841490]
- [x86] kvm: pass through CPUID(0x80000006) (Vitaly Kuznetsov) [1841490]
- [x86] kvm: x86: Return updated timer current count register from KVM_GET_LAPIC (Vitaly Kuznetsov) [1841490]
- [virt] kvm: remove redundant assignment to variable r (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Fix __svm_vcpu_run declaration (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Do not setup frame pointer in __svm_vcpu_run (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: Do not mark svm_vcpu_run with STACK_FRAME_NON_STANDARD (Vitaly Kuznetsov) [1841490]
- [x86] kvm: nvmx: reflect MTF VM-exits if injected by L1 (Vitaly Kuznetsov) [1841490]
- [kernel] kvm: Check validity of resolved slot when searching memslots (Vitaly Kuznetsov) [1841490]
- [x86] kvm: vmx: Enable machine check support for 32bit targets (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: move more vmentry code to assembly (Vitaly Kuznetsov) [1841490]
- [x86] kvm: svm: fix compilation with modular PSP and non-modular KVM (Vitaly Kuznetsov) [1841490]
- [x86] Increase KVM_MAX_VCPUS to 1024, KVM_MAX_VCPU_ID to 2048 (Eduardo Habkost) [1810811]
- [scsi] scsi: core: avoid host-wide host_busy counter for scsi_mq (Ewan Milne) [1761928]
- [gpio] gpio: xgene-sb: set valid IRQ type in to_irq() (Brian Masney) [1802402]
- [block] rbd: compression_hint option (Ilya Dryomov) [1835925]
- [include] libceph: support for alloc hint flags (Ilya Dryomov) [1835925]
- [net] libceph: read_from_replica option (Ilya Dryomov) [1835925]
- [net] libceph: support for balanced and localized reads (Ilya Dryomov) [1835925]
- [net] libceph: crush_location infrastructure (Ilya Dryomov) [1835925]
- [net] libceph: decode CRUSH device/bucket types and names (Ilya Dryomov) [1835925]
- [net] libceph: add non-asserting rbtree insertion helper (Ilya Dryomov) [1835925]
- [pci] PCI: pciehp: Fix MSI interrupt race (Myron Stowe) [1779610]
- [security] ima: Remove __init annotation from ima_pcrread() (Bruno Meneguele) [1843774]
- [security] ima: Call ima_calc_boot_aggregate() in ima_eventdigest_init() (Bruno Meneguele) [1843774]
- [security] ima: Directly assign the ima_default_policy pointer to ima_rules (Bruno Meneguele) [1843774]
- [documentation] powerpc/fadump: sysfs for fadump memory reservation (Diego Domingos) [1804202]
- [documentation] Documentation/ABI: Mark /sys/kernel/fadump_* sysfs files deprecated (Diego Domingos) [1804202]
- [documentation] powerpc/powernv: Move core and fadump_release_opalcore under new kobject (Diego Domingos) [1804202]
- [powerpc] powerpc/fadump: Reorganize /sys/kernel/fadump_* sysfs files (Diego Domingos) [1804202]
- [fs] sysfs: wrap __compat_only_sysfs_link_entry_to_kobj function to change the symlink name (Diego Domingos) [1804202]
- [documentation] Documentation/ABI: Add ABI documentation for /sys/kernel/fadump_* (Diego Domingos) [1804202]
- [hwtracing] intel_th: pci: Add Tiger Lake CPU support (Jiri Olsa) [1483079]
- [netdrv] e1000e: fix S0ix flows for cable connected case (Ken Cox) [1781385]
- [netdrv] e1000e: reject unsupported coalescing params (Ken Cox) [1781385]
- [netdrv] e1000e: Add support for Tiger Lake device (Ken Cox) [1781385]
- [netdrv] e1000e: Add support for Alder Lake (Ken Cox) [1781385]
- [netdrv] net: intel: e1000e: fix possible sleep-in-atomic-context bugs in e1000e_get_hw_semaphore() (Ken Cox) [1781385]
- [netdrv] e1000e: fix missing cpu_to_le64 on buffer_addr (Ken Cox) [1781385]
- [netdrv] e1000(e): use new helper tcp_v6_gso_csum_prep (Ken Cox) [1781385]
- [netdrv] e1000e: Revert "e1000e: Make watchdog use delayed work" (Ken Cox) [1781385]
- [netdrv] e1000e: Use netdev_info instead of pr_info for link messages (Ken Cox) [1781385]
- [netdrv] net: ethernet: intel: Demote MTU change prints to debug (Ken Cox) [1781385]
- [netdrv] e1000e: Fix compiler warning when CONFIG_PM_SLEEP is not set (Ken Cox) [1781385]
- [netdrv] net: ixgbevf: reject unsupported coalescing params (Ken Cox) [1781379]
- [netdrv] ixgbevf: Remove limit of 10 entries for unicast filter list (Ken Cox) [1781379]
- [netdrv] net: ixgbe: reject unsupported coalescing params (Ken Cox) [1781378]
- [netdrv] ixgbe: Use pci_get_dsn() (Ken Cox) [1781378]
- [netdrv] intel: Replace zero-length array with flexible-array member (Ken Cox) [1781378]
- [netdrv] ixgbe: Fix calculation of queue with VFs and flow director on interface flap (Ken Cox) [1781378]
- [netdrv] net: ethernet: intel: Demote MTU change prints to debug (Ken Cox) [1781378]
- [netdrv] ixgbe: protect TX timestamping from API misuse (Ken Cox) [1781378]
- [netdrv] ixgbe: Make use of cpumask_local_spread to improve RSS locality (Ken Cox) [1781378]
- [netdrv] ixgbe: Remove duplicate clear_bit() call (Ken Cox) [1781378]
- [netdrv] ixgbe: Add UDP segmentation offload support (Ken Cox) [1781378]
- [x86] x86/resctrl: Fix invalid attempt at removing the default resource group (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Clean up unused function parameter in mkdir path (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Fix a deadlock due to inaccurate reference (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Fix use-after-free due to inaccurate refcount of rdtgroup (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Fix use-after-free when deleting resource groups (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Add task resctrl information display (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Check monitoring static key in the MBM overflow handler (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Do not reconfigure exiting tasks (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Fix potential memory leak (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Fix an imbalance in domain_remove_cpu() (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Fix potential lockdep warning (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Prevent NULL pointer dereference when reading mondata (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Cleanup cbm_ensure_valid() (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Prevent possible overrun during bitmap operations (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Don't stop walking closids when a locksetup group is found (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Use _ASM_BX to avoid ifdeffery (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Remove unused variable (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Remove duplicate MSR_MISC_FEATURE_CONTROL definition (Alexander Beregalov) [1830948]
- [x86] x86/resctrl: Avoid confusion over the new X86_RESCTRL config (Alexander Beregalov) [1830948]
- [x86] x86/cache: Rename config option to CONFIG_X86_RESCTRL (Alexander Beregalov) [1830948]
- [tools] perf flamegraph: Use /bin/bash for report and record scripts (Michael Petlan) [1281843]
- [tools] perf script: Add flamegraph.py script (Michael Petlan) [1281843]
- [tools] perf script: Avoid NULL dereference on symbol (Michael Petlan) [1841130]
- [tools] tools/build: tweak unused value workaround (Michael Petlan) [1841130]
- [tools] perf stat: Fix no metric header if --per-socket and --metric-only set (Michael Petlan) [1841130]
- [tools] perf python: Check if clang supports -fno-semantic-interposition (Michael Petlan) [1841130]
- [tools] perf tools: Support Python 3.8+ in Makefile (Michael Petlan) [1841130]
- [tools] perf script: Fix invalid read of directory entry after closedir() (Michael Petlan) [1841130]
- [tools] perf script report: Fix SEGFAULT when using DWARF mode (Michael Petlan) [1841130]
- [tools] perf script: add -S/--symbols documentation (Michael Petlan) [1841130]
- [tools] perf pmu-events x86: Use CPU_CLK_UNHALTED.THREAD in Kernel_Utilization metric (Michael Petlan) [1841130]
- [tools] perf events parser: Add missing Intel CPU events to parser (Michael Petlan) [1841130]
- [tools] perf script: Allow --symbol to accept hexadecimal addresses (Michael Petlan) [1841130]
- [tools] perf top: Support hotkey to change sort order (Michael Petlan) [1841130]
- [tools] perf top: Support --group-sort-idx to change the sort order (Michael Petlan) [1841130]
- [tools] perf symbols: Fix arm64 gap between kernel start and module end (Michael Petlan) [1841130]
- [tools] perf build-test: Honour JOBS to override detection of number of cores (Michael Petlan) [1841130]
- [tools] perf script: Add --show-cgroup-events option (Michael Petlan) [1841130]
- [tools] perf top: Add --all-cgroups option (Michael Petlan) [1841130]
- [tools] perf record: Add --all-cgroups option (Michael Petlan) [1841130]
- [tools] perf record: Support synthesizing cgroup events (Michael Petlan) [1841130]
- [tools] perf report: Add 'cgroup' sort key (Michael Petlan) [1841130]
- [tools] perf cgroup: Maintain cgroup hierarchy (Michael Petlan) [1841130]
- [tools] perf tools: Basic support for CGROUP event (Michael Petlan) [1841130]
- [tools] perf tools: Add file-handle feature test (Michael Petlan) [1841130]
- [tools] perf python: Include rwsem.c in the pythong biding (Michael Petlan) [1841130]
- [tools] tools headers UAPI: Update tools's copy of linux/perf_event.h (Michael Petlan) [1841130]
- [tools] perf script: Introduce --deltatime option (Michael Petlan) [1841130]
- [tools] perf: Normalize gcc parameter when generating arch errno table (Michael Petlan) [1841130]
- [tools] perf parse-events: Add defensive NULL check (Michael Petlan) [1841130]
- [tools] perf callchain: Update docs regarding kernel/user space unwinding (Michael Petlan) [1841130]
- [tools] perf cpumap: Fix snprintf overflow check (Michael Petlan) [1841130]
- [tools] perf test: Test pmu-events aliases (Michael Petlan) [1841130]
- [tools] perf pmu: Make pmu_uncore_alias_match() public (Michael Petlan) [1841130]
- [tools] perf pmu: Add is_pmu_core() (Michael Petlan) [1841130]
- [tools] perf test: Add pmu-events test (Michael Petlan) [1841130]
- [tools] perf pmu: Refactor pmu_add_cpu_aliases() (Michael Petlan) [1841130]
- [tools] perf jevents: Support test events folder (Michael Petlan) [1841130]
- [tools] perf jevents: Add some test events (Michael Petlan) [1841130]
- [tools] perf tools: Unify a bit the build directory output (Michael Petlan) [1841130]
- [tools] perf metricgroup: Fix printing event names of metric group with multiple events incase of overlapping events (Michael Petlan) [1841130]
- [tools] perf stat: Align the output for interval aggregation mode (Michael Petlan) [1841130]
- [tools] perf report/top TUI: Support hotkeys to let user select any event for sorting (Michael Petlan) [1841130]
- [tools] perf report: Support a new key to reload the browser (Michael Petlan) [1841130]
- [tools] perf report: Allow specifying event to be used as sort key in --group output (Michael Petlan) [1841130]
- [tools] perf report/top TUI: Support hotkey 'a' for annotation of unresolved addresses (Michael Petlan) [1841130]
- [tools] perf report: Support interactive annotation of code without symbols (Michael Petlan) [1841130]
- [tools] perf report: Print al_addr when symbol is not found (Michael Petlan) [1841130]
- [tools] perf symbols: Consolidate symbol fixup issue (Michael Petlan) [1841130]
- [tools] perf parse-events: Fix 3 use after frees found with clang ASAN (Michael Petlan) [1841130]
- [tools] perf/tests: Add CET instructions to the new instructions test (Michael Petlan) [1841130]
- [tools] perf expr: Fix copy/paste mistake (Michael Petlan) [1841130]
- [tools] perf report: Fix no branch type statistics report issue (Michael Petlan) [1841130]
- [tools] perf tools: Give synthetic mmap events an inode generation (Michael Petlan) [1841130]
- [tools] perf test: Print if shell directory isn't present (Michael Petlan) [1841130]
- [tools] perf record: Fix binding of AIO user space buffers to nodes (Michael Petlan) [1841130]
- [tools] perf intel-pt: Update intel-pt.txt file with new location of the documentation (Michael Petlan) [1841130]
- [tools] perf intel-pt: Add Intel PT man page references (Michael Petlan) [1841130]
- [tools] perf intel-pt: Rename intel-pt.txt and put it in man page format (Michael Petlan) [1841130]
- [tools] perf doc: Set man page date to last git commit (Michael Petlan) [1841130]
- [tools] perf cs-etm: Fix unsigned variable comparison to zero (Michael Petlan) [1841130]
- [tools] perf cs-etm: Optimize copying last branches (Michael Petlan) [1841130]
- [tools] perf cs-etm: Correct synthesizing instruction samples (Michael Petlan) [1841130]
- [tools] perf cs-etm: Continuously record last branch (Michael Petlan) [1841130]
- [tools] perf cs-etm: Swap packets for instruction samples (Michael Petlan) [1841130]
- [tools] perf map: Use strstarts() to look for Android libraries (Michael Petlan) [1841130]
- [tools] perf vendor events intel: Add NO_NMI_WATCHDOG metric constraint (Michael Petlan) [1841130]
- [tools] perf metricgroup: Support metric constraint (Michael Petlan) [1841130]
- [tools] perf util: Factor out sysctl__nmi_watchdog_enabled() (Michael Petlan) [1841130]
- [tools] perf metricgroup: Factor out metricgroup__add_metric_weak_group() (Michael Petlan) [1841130]
- [tools] perf jevents: Support metric constraint (Michael Petlan) [1841130]
- [tools] perf block-info: Support color ops to print block percents in color (Michael Petlan) [1841130]
- [tools] perf block-info: Allow selecting which columns to report and its order (Michael Petlan) [1841130]
- [tools] perf diff: Use __block_info__cmp() to replace block_pair_cmp() (Michael Petlan) [1841130]
- [tools] perf expr: Make expr__parse() return -1 on error (Michael Petlan) [1841130]
- [tools] perf expr: Straighten expr__parse()/expr__find_other() interface (Michael Petlan) [1841130]
- [tools] perf expr: Increase EXPR_MAX_OTHER to support metrics with more than 15 variables (Michael Petlan) [1841130]
- [tools] perf expr: Move expr lexer to flex (Michael Petlan) [1841130]
- [tools] perf expr: Add expr.c object (Michael Petlan) [1841130]
- [tools] perf header: Add check for unexpected use of reserved membrs in event attr (Michael Petlan) [1841130]
- [tools] perf evsel: Support PERF_SAMPLE_BRANCH_HW_INDEX (Michael Petlan) [1841130]
- [tools] perf tools: Add hw_idx in struct branch_stack (Michael Petlan) [1841130]
- [tools] tools headers UAPI: Update tools's copy of linux/perf_event.h (Michael Petlan) [1841130]
- [tools] tools lib traceevent: Remove extra '\n' in print_event_time() (Michael Petlan) [1841130]
- [tools] perf annotate: Get rid of annotation->nr_jumps (Michael Petlan) [1841130]
- [tools] perf llvm: Add debug hint message about missing kernel-devel package (Michael Petlan) [1841130]
- [tools] perf stat: Show percore counts in per CPU output (Michael Petlan) [1841130]
- [tools] tools lib api fs: Move cgroupsfs_find_mountpoint() (Michael Petlan) [1841130]
- [kernel] perf/core: fix parent pid/tid in task exit events (Michael Petlan) [1841130]
- [x86] perf/x86/cstate: Add Jasper Lake CPU support (Michael Petlan) [1841130]
- [kernel] perf/core: Disable page faults when getting phys address (Michael Petlan) [1841130]
- [x86] perf/x86/intel/uncore: Add Ice Lake server uncore support (Michael Petlan) [1841130]
- [kernel] perf/cgroup: Correct indirection in perf_less_group_idx() (Michael Petlan) [1841130]
- [kernel] perf/core: Fix event cgroup tracking (Michael Petlan) [1841130]
- [init] perf/core: Add PERF_SAMPLE_CGROUP feature (Michael Petlan) [1841130]
- [kernel] perf/core: Add PERF_RECORD_CGROUP event (Michael Petlan) [1841130]
- [x86] x86 user stack frame reads: switch to explicit __get_user() (Michael Petlan) [1841130]
- [x86] perf/x86/intel/uncore: Factor out __snr_uncore_mmio_init_box (Michael Petlan) [1841130]
- [x86] perf/x86/intel/uncore: Add box_offsets for free-running counters (Michael Petlan) [1841130]
- [kernel] perf/core: Fix reversed NULL check in perf_event_groups_less() (Michael Petlan) [1841130]
- [kernel] perf/core: Fix endless multiplex timer (Michael Petlan) [1841130]
- [kernel] perf/cgroup: Order events in RB tree by cgroup id (Michael Petlan) [1841130]
- [kernel] perf/cgroup: Grow per perf_cpu_context heap storage (Michael Petlan) [1841130]
- [kernel] perf/core: Add per perf_cpu_context min_heap storage (Michael Petlan) [1841130]
- [kernel] perf/core: Use min_heap in visit_groups_merge() (Michael Petlan) [1841130]
- [lib] lib: Introduce generic min-heap (Michael Petlan) [1841130]
- [kernel] perf/cgroup: Reorder perf_cgroup_connect() (Michael Petlan) [1841130]
- [kernel] perf/core: Remove 'struct sched_in_data' (Michael Petlan) [1841130]
- [kernel] perf/core: Unify {pinned, flexible}_sched_in() (Michael Petlan) [1841130]
- [x86] perf/x86: Add Intel Tiger Lake uncore support (Michael Petlan) [1841130]
- [x86] perf/x86/intel: Output LBR TOS information correctly (Michael Petlan) [1841130]
- [powerpc] perf/core: Add new branch sample type for HW index of raw branch records (Michael Petlan) [1841130]
- [x86] perf/x86/intel: Avoid unnecessary PEBS_ENABLE MSR access in PMI (Michael Petlan) [1841130]
- [x86] x86/cpu: Add Jasper Lake to Intel family (Michael Petlan) [1841130]
- [fs] pstore/ram: Run without kernel crash dump region (Desnes Augusto Nunes do Rosario) [1824906]
- [fs] pstore/ram: Avoid NULL deref in ftrace merging failure path (Desnes Augusto Nunes do Rosario) [1824906]
- [fs] pstore: Convert buf_lock to semaphore (Desnes Augusto Nunes do Rosario) [1824906]
- [fs] pstore/ram: Correctly calculate usable PRZ bytes (Desnes Augusto Nunes do Rosario) [1824906]
- [drm] memremap: add an owner field to struct dev_pagemap (Don Dutile) [1816441]
- [mm] mm: devmap: refactor 1-based refcounting for ZONE_DEVICE pages (Don Dutile) [1816441]
- [mm] mm/swap: fix release_pages() when releasing devmap pages (Don Dutile) [1816441]
- [mm] mm: revert remove MEMORY_DEVICE_PUBLIC support in swap.c (Don Dutile) [1816441]
- [nvdimm] mm: Cleanup __put_devmap_managed_page() vs ->page_free() (Don Dutile) [1816441]
- [documentation] hv_netvsc: Update document for XDP support (Mohammed Gamal) [1815497]
- [netdrv] hv_netvsc: Fix XDP refcnt for synthetic and VF NICs (Mohammed Gamal) [1815497]
- [netdrv] hv_netvsc: Add XDP support (Mohammed Gamal) [1815497]
- [powerpc] kvm: ppc: book3s hv: Remove user-triggerable WARN_ON (Laurent Vivier) [1784050]
- [powerpc] kvm: ppc: book3s hv: Close race with page faults around memslot flushes (Laurent Vivier) [1784050]
- [powerpc] pseries/svm: Allow IOMMU to work in SVM (Michael Roth) [1730194]
- [powerpc] pseries/iommu: Separate FW_FEATURE_MULTITCE to put/stuff features (Michael Roth) [1730194]
- [powerpc] pseries: Allow not having ibm, hypertas-functions::hcall-multi-tce for DDW (Michael Roth) [1730194]
- [powerpc] revert "powerpc/pseries/iommu: Don't use dma_iommu_ops on secure guests" (Michael Roth) [1730194]
- [powerpc] ultravisor: Add PPC_UV config option (Michael Roth) [1730194]
- [mm] ksm: Export ksm_madvise() (Michael Roth) [1730194]
- [powerpc] configs: Enable secure guest support in pseries and ppc64 defconfigs (Michael Roth) [1730194]
- [powerpc] prom_init: Undo relocation before entering secure mode (Michael Roth) [1730194]
- [powerpc] pseries/svm: Force SWIOTLB for secure guests (Michael Roth) [1730194]
- [powerpc] pseries/iommu: Don't use dma_iommu_ops on secure guests (Michael Roth) [1730194]
- [powerpc] pseries/svm: Disable doorbells in SVM guests (Michael Roth) [1730194]
- [powerpc] pseries/svm: Export guest SVM status to user space via sysfs (Michael Roth) [1730194]
- [powerpc] pseries/svm: Use shared memory for Debug Trace Log (DTL) (Michael Roth) [1730194]
- [powerpc] prom_init: Pass the "os-term" message to hypervisor (Michael Roth) [1730194]
- [powerpc] Add support for adding an ESM blob to the zImage wrapper (Michael Roth) [1730194]
- [powerpc] pseries: Introduce option to build secure virtual machines (Michael Roth) [1730194]
- [s390] mm: Remove sev_active() function (Michael Roth) [1730194]
- [kernel] fs/core/vmcore: Move sev_active() reference to x86 arch code (Michael Roth) [1730194]
- [kernel] x86, s390/mm: Move sme_active() and sme_me_mask to x86-specific header (Michael Roth) [1730194]
- [kernel] dma-mapping: Remove dma_check_mask() (Michael Roth) [1730194]
- [kernel] swiotlb: Remove call to sme_active() (Michael Roth) [1730194]
- [x86] s390: Move ARCH_HAS_MEM_ENCRYPT definition to arch/Kconfig (Michael Roth) [1730194]
- [powerpc] xmon: don't access ASDR in VMs (Michael Roth) [1730194]
- [powerpc] xmon: Fix compile error in print_insn* functions (Michael Roth) [1730194]
- [mm] memremap: provide a not device managed memremap_pages (Michael Roth) [1730194]
- [mm] memremap: don't use a separate devm action for devmap_managed_enable_get (Michael Roth) [1730194]
- [mm] memremap: remove the dev field in struct dev_pagemap (Michael Roth) [1730194]
- [kernel] resource: add a not device managed request_free_mem_region variant (Michael Roth) [1730194]
- [mm] turn migrate_vma upside down (Michael Roth) [1730194]
- [kernel] mm: simplify ZONE_DEVICE page private data (Michael Roth) [1730194]
- [kernel] mm: remove hmm_devmem_add (Michael Roth) [1730194]
- [mm] remove hmm_vma_alloc_locked_page (Michael Roth) [1730194]
- [dax] device-dax: use the dev_pagemap internal refcount (Michael Roth) [1730194]
- [mm] export alloc_pages_vma (Michael Roth) [1730194]
- [netdrv] net/mlx5: Kconfig: Fix spelling typo (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: Introduce kconfig var for TC support (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: Move TC-specific code from en_main.c to en_tc.c (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: Extract neigh-specific code from en_rep.c to rep/neigh.c (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: Extract TC-specific code from en_rep.c to rep/tc.c (Alaa Hleihel) [1843359]
- [infiniband] net/mlx5: Refactor imm_inval_pkey field in cqe struct (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: Take DCBNL-related definitions into dedicated files (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5: E-Switch: Move eswitch chains to a new directory (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: remove duplicated check chain_index in mlx5e_rep_setup_ft_cb (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: add mlx5e_rep_indr_setup_ft_cb support (Alaa Hleihel) [1843359]
- [netdrv] net/mlx5e: refactor indr setup block (Alaa Hleihel) [1843359]
- [infiniband] IB/mlx5: Fix DEVX support for MLX5_CMD_OP_INIT2INIT_QP command (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Remove warning "devices are not on same switch HW" (Alaa Hleihel) [1842258]
- [infiniband] RDMA/mlx5: Add init2init as a modify command (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: replace EINVAL in mlx5e_flower_parse_meta() (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Fix MLX5_TC_CT dependencies (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Properly set default values when disabling adaptive moderation (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Fix stats update for matchall classifier (Alaa Hleihel) [1842258]
- [netdrv] net: sched: expose HW stats types per action used by drivers (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: en_tc: Fix cast to restricted __be32 warning (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: en_tc: Fix incorrect type in initializer warnings (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Allow partial data mask for tunnel options (Alaa Hleihel) [1842258]
- [include] net/mlx5: IPSec: Fix incorrect type for spi (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Accel: fpga tls fix cast to __be64 and incorrect argument types (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: cmd: Fix memset with byte count warning (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: DR: Fix incorrect type in return expression (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: DR: Fix cast to restricted __be32 (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: DR: Fix incorrect type in argument (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: IPoIB, Drop multicast packets that this interface sent (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: IPoIB, Enable loopback packets for IPoIB interfaces (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Fix error flow in case of function_setup failure (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: CT: Correctly get flow rule (Alaa Hleihel) [1842258 1840408]
- [netdrv] net/mlx5e: Update netdev txq on completions during closure (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Annotate mutex destroy for root ns (Alaa Hleihel) [1842258 1840408]
- [netdrv] net/mlx5: Don't maintain a case of del_sw_func being null (Alaa Hleihel) [1842258 1840408]
- [netdrv] net/mlx5: Fix cleaning unmanaged flow tables (Alaa Hleihel) [1842258 1840408]
- [netdrv] net/mlx5: Fix memory leak in mlx5_events_init (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Fix inner tirs handling (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: kTLS, Destroy key object after destroying the TIS (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5e: Fix allowed tc redirect merged eswitch offload cases (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Avoid processing commands before cmdif is ready (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Fix a race when moving command interface to events mode (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Add command entry handling completion (Alaa Hleihel) [1842258]
- [infiniband] RDMA/mlx5: Fix NULL pointer dereference in destroy_prefetch_work (Alaa Hleihel) [1842258]
- [netdrv] net/mlx5: Fix crash upon suspend/resume (Alaa Hleihel) [1842258 1841973]
- [netdrv] net/mlx5e: Fix devlink port netdev unregistration sequence (Alaa Hleihel) [1842258 1790226]
- [netdrv] net/mlx5e: Fix devlink port register sequence (Alaa Hleihel) [1842258 1790226]
- [netdrv] net/mlx5e: Use devlink virtual flavour for VF devlink port (Alaa Hleihel) [1842258 1790226]
- [netdrv] net/mlx5e: Add support for devlink-port in non-representors mode (Alaa Hleihel) [1842258 1790226]
- [netdrv] net/mlx5e: Rename representor get devlink port function (Alaa Hleihel) [1842258 1790226]
- [fs] nfsd4: add filename to states output ("J. Bruce Fields") [1475182]
- [fs] nfsd4: stid display should preserve on-the-wire byte order ("J. Bruce Fields") [1475182]
- [fs] nfsd4: common stateid-printing code ("J. Bruce Fields") [1475182]
- [fs] nfsd: remove read permission bit for ctl sysctl ("J. Bruce Fields") [1475182]
- [fs] nfsd: "\s" should be "s" ("J. Bruce Fields") [1475182]
- [fs] nfsd: initialize i_private before d_add ("J. Bruce Fields") [1475182]
- [fs] nfsd: use i_wrlock instead of rcu for nfsdfs i_private ("J. Bruce Fields") [1475182]
- [fs] nfsd: fix dentry leak upon mkdir failure ("J. Bruce Fields") [1475182]
- [fs] nfsd: Make __get_nfsdfs_client() static ("J. Bruce Fields") [1475182]
- [fs] nfsd: Make two functions static ("J. Bruce Fields") [1475182]
- [fs] nfsd: decode implementation id ("J. Bruce Fields") [1475182]
- [fs] nfsd: use 64-bit seconds fields in nfsd v4 code ("J. Bruce Fields") [1475182]
- [fs] nfsd: create xdr_netobj_dup helper ("J. Bruce Fields") [1475182]
- [fs] nfsd: allow forced expiration of NFSv4 clients ("J. Bruce Fields") [1475182]
- [fs] nfsd: create get_nfsdfs_clp helper ("J. Bruce Fields") [1475182]
- [fs] nfsd4: show layout stateids ("J. Bruce Fields") [1475182]
- [fs] nfsd: show lock and deleg stateids ("J. Bruce Fields") [1475182]
- [fs] nfsd4: add file to display list of client's opens ("J. Bruce Fields") [1475182]
- [fs] nfsd: add more information to client info file ("J. Bruce Fields") [1475182]
- [include] nfsd: escape high characters in binary data ("J. Bruce Fields") [1475182]
- [fs] nfsd: copy client's address including port number to cl_addr ("J. Bruce Fields") [1475182]
- [fs] nfsd4: add a client info file ("J. Bruce Fields") [1475182]
- [fs] nfsd: make client/ directory names small ints ("J. Bruce Fields") [1475182]
- [fs] nfsd: add nfsd/clients directory ("J. Bruce Fields") [1475182]
- [fs] nfsd4: use reference count to free client ("J. Bruce Fields") [1475182]
- [fs] nfsd: rename cl_refcount ("J. Bruce Fields") [1475182]
- [fs] nfsd: persist nfsd filesystem across mounts ("J. Bruce Fields") [1475182]

* Tue Jun 09 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-213.el8]
- [wireless] iwlwifi: pcie: handle QuZ configs with killer NICs as well (Jarod Wilson) [1844129 1842382]
- [net] mac80211: add ieee80211_is_any_nullfunc() (Jarod Wilson) [1844129]
- [net] mac80211: sta_info: Add lockdep condition for RCU list usage (Jarod Wilson) [1844129]
- [net] mac80211: fix channel switch trigger from unknown mesh peer (Jarod Wilson) [1844129]
- [wireless] rtw88: avoid unused function warnings (Jarod Wilson) [1844129]
- [wireless] brcmfmac: add stub for monitor interface xmit (Jarod Wilson) [1844129]
- [wireless] iwlwifi: actually check allocated conf_tlv pointer (Jarod Wilson) [1844129]
- [wireless] iwlwifi: fix WGDS check when WRDS is disabled (Jarod Wilson) [1844129]
- [wireless] iwlwifi: mvm: fix inactive TID removal return value usage (Jarod Wilson) [1844129]
- [wireless] iwlwifi: mvm: Do not declare support for ACK Enabled Aggregation (Jarod Wilson) [1844129]
- [wireless] iwlwifi: mvm: limit maximum queue appropriately (Jarod Wilson) [1844129]
- [wireless] iwlwifi: pcie: indicate correct RB size to device (Jarod Wilson) [1844129]
- [wireless] iwlwifi: mvm: beacon statistics shouldn't go backwards (Jarod Wilson) [1844129]
- [wireless] iwlwifi: pcie: actually release queue memory in TVQM (Jarod Wilson) [1844129]
- [wireless] mac80211: populate debugfs only after cfg80211 init (Jarod Wilson) [1844129]
- [net] mac80211: fix race in ieee80211_register_hw() (Jarod Wilson) [1844129]
- [net] nl80211: fix NL80211_ATTR_FTM_RESPONDER policy (Jarod Wilson) [1844129]
- [powerpc] powerpc/fadump: Account for memory_limit while reserving memory (Steve Best) [1840646]
- [mm] mm: make deferred init's max threads arch-specific (David Hildenbrand) [1818764]
- [mm] mm: parallelize deferred_init_memmap() (David Hildenbrand) [1818764]
- [mm] mm: don't track number of pages during deferred initialization (David Hildenbrand) [1818764]
- [kernel] padata: add basic support for multithreaded jobs (David Hildenbrand) [1818764]
- [kernel] padata: allocate work structures for parallel jobs from a pool (David Hildenbrand) [1818764]
- [init] padata: initialize earlier (David Hildenbrand) [1818764]
- [kernel] padata: remove exit routine (David Hildenbrand) [1818764]
- [documentation] padata: update documentation (David Hildenbrand) [1818764]
- [mm] mm: call cond_resched() from deferred_init_memmap() (David Hildenbrand) [1818764]
- [mm] mm: initialize deferred pages with interrupts enabled (David Hildenbrand) [1818764]
- [mm] mm/pagealloc.c: call touch_nmi_watchdog() on max order boundaries in deferred init (David Hildenbrand) [1818764]
- [mm] mm/page_alloc: fix watchdog soft lockups during set_zone_contiguous() (David Hildenbrand) [1818764]
- [mm] mm/page_alloc.c: fix regression with deferred struct page init (David Hildenbrand) [1818764]
- [mm] mm: initialize MAX_ORDER_NR_PAGES at a time instead of doing larger sections (David Hildenbrand) [1818764]
- [mm] mm: implement new zone specific memblock iterator (David Hildenbrand) [1818764]
- [mm] mm: drop meminit_pfn_in_nid as it is redundant (David Hildenbrand) [1818764]
- [kernel] audit: add subj creds to NETFILTER_CFG record to (Richard Guy Briggs) [1478533]
- [kernel] audit: make symbol 'audit_nfcfgs' static (Richard Guy Briggs) [1478533]
- [net] netfilter: add audit table unregister actions (Richard Guy Briggs) [1478533]
- [net] audit: tidy and extend netfilter_cfg x_tables (Richard Guy Briggs) [1478533]
- [x86] x86/efi: Allocate e820 buffer before calling efi_exit_boot_service (Lenny Szubowicz) [1824005]
- [mm] hugetlb_cgroup: fix possible illegal access to memory (Joel Savitz) [1835398]
- [kvm] KVM: s390: Remove false WARN_ON_ONCE for the PQAP instruction (Claudio Imbrenda) [1836184]
- [sound] ASoC: Intel: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [thermal] thermal: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [powercap] powercap/intel_rapl: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [platform] platform/x86: Convert to new CPU match macros (Prarit Bhargava) [1841649]
- [pci] PCI: intel-mid: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [mmc] mmc: sdhci-acpi: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [idle] intel_idle: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [extcon] extcon: axp288: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [edac] EDAC: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [acpi] ACPI: Convert to new X86 CPU match macros (Prarit Bhargava) [1841649]
- [x86] x86/platform: Convert to new CPU match macros (Prarit Bhargava) [1841649]
- [x86] x86/kernel: Convert to new CPU match macros (Prarit Bhargava) [1841649]
- [x86] x86/perf/events: Convert to new CPU match macros (Prarit Bhargava) [1841649]
- [x86] x86/cpu: Add consistent CPU match macros (Prarit Bhargava) [1841649]
- [fs] fix autofs regression caused by follow_managed() changes (Miklos Szeredi) [1784857]
- [fs] fs/namei.c: fix missing barriers when checking positivity (Miklos Szeredi) [1784857]
- [fs] fix dget_parent() fastpath race (Miklos Szeredi) [1784857]
- [fs] new helper: lookup_positive_unlocked() (Miklos Szeredi) [1784857]
- [fs] fs/namei.c: pull positivity check into follow_managed() (Miklos Szeredi) [1784857]
- [mm] x86/kasan: Fix boot with 5-level paging and KASAN (Baoquan He) [1838418]
- [netdrv] bnxt_en: Fix VLAN acceleration handling in bnxt_fix_features() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Return error when allocating zero size context memory (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Improve AER slot reset (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Reduce BNXT_MSIX_VEC_MAX value to supported CQs per PF (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Fix VF anti-spoof filter setup (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Fix "fw.mgmt" and "fw.nsci" info via devlink info_get cb (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add partno to devlink info_get cb (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Read partno and serialno of the board from VPD (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add fw.mgmt.api version to devlink info_get cb (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Reset rings if ring reservation fails during open() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Free context memory after disabling PCI in probe error path (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Return error if bnxt_alloc_ctx_mem() fails (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: fix memory leaks in bnxt_dcbnl_ieee_getets() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Fix Priority Bytes and Packets counters in ethtool -S (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Call devlink_port_type_clear() in remove() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Return -EAGAIN if fw command returns BUSY (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Modify some bnxt_hwrm_*_free() functions to void (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Remove unnecessary assignment of return code (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Clear DCB settings after firmware reset (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Process the NQ under NAPI continuous polling (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Simplify __bnxt_poll_cqs_done() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Handle all NQ notifications in bnxt_poll_p5() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Use pci_get_dsn() (Jonathan Toppins) [1790621]
- [netdrv] bnxt: reject unsupported coalescing params (Jonathan Toppins) [1790621]
- [netdrv] net/broadcom: Clean broadcom code from driver versions (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: fix error handling when flashing from file (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: reinitialize IRQs when MTU is modified (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: add newline to netdev_*() format strings (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Issue PCIe FLR in kdump kernel to cleanup pending DMAs (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Improve device shutdown method (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add support for devlink info command (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Rename switch_id to dsn (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add support to update progress of flash update (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Move devlink_register before registering netdev (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Register devlink irrespective of firmware spec version (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Refactor bnxt_dl_register() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Disable workaround for lost interrupts on 575XX B0 and newer chips (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Periodically check and remove aged-out ntuple filters (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Do not accept fragments for aRFS flow steering (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Support UDP RSS hashing on 575XX chips (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Improve bnxt_probe_phy() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Improve link up detection (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Call recovery done after reset is successfully done (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Remove unnecessary NULL checks for fw_health (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add support for flashing the device via devlink (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Allow PHY settings on multi-function or NPAR PFs if allowed by FW (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add async. event logic for PHY configuration changes (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Refactor the initialization of the ethtool link settings (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Skip disabling autoneg before PHY loopback when appropriate (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Assign more RSS context resources to the VFs (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Initialize context memory to the value specified by firmware (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add chip IDs for 57452 and 57454 chips (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Report health status update after reset is done (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Set MASTER flag during driver registration (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Update firmware interface spec to 1.10.1.12 (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Fix array overrun in bnxt_fill_l2_rewrite_fields() (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add support for NAT(L3/L4 rewrite) (Jonathan Toppins) [1790621]
- [netdrv] bnxt_en: Add support for L2 rewrite (Jonathan Toppins) [1790621]
- [netdrv] net/mlx5: E-switch, Protect eswitch mode changes (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: E-switch, Extend eswitch enable to handle num_vfs change (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: Split eswitch mode check to different helper function (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: Simplify mlx5_unload_one() and its callers (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: Simplify mlx5_register_device to return void (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: Avoid deriving mlx5_core_dev second time (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: E-switch, Annotate esw state_lock mutex destroy (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5: E-switch, Annotate termtbl_mutex mutex destroy (Alaa Hleihel) [1835595 1663246]
- [netdrv] net/mlx5e: CT: Fix offload with CT action after CT NAT action (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Fix missing pedit action after ct clear action (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: CT: remove set but not used variable 'unnew' (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: CT: Fix insert rules when TC_CT config isn't enabled (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Fix actions_match_supported() return (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: CT: Avoid false warning about rule may be used uninitialized (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch, Use correct type for chain, prio and level values (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-switch, Fix printing wrong error value (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Fix rejecting all egress rules not on vlan (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch: Fix using fwd and modify when firmware doesn't support it (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: Add missing inline to stub esw_add_restore_rule (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch, Enable restore table only if reg_c1 is supported (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch, free flow_group_in after creating the restore table (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-switch, Fix mutex init order (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: CT: Change idr to xarray to protect parallel tuple id allocation (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: CT: Use rhashtable's ct entries instead of a separate list (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: CT: Fix stack usage compiler warning (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: CT: Support clear action (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5e: CT: Handle misses after executing CT action (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5e: CT: Offload established flows (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5e: CT: Introduce connection tracking (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5: E-Switch, Support getting chain mapping (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5: E-Switch, Add support for offloading rules with no in_port (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5: E-Switch, Introduce global tables (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5e: en_rep: Create uplink rep root table after eswitch offloads table (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5: E-Switch, Enable reg c1 loopback when possible (Alaa Hleihel) [1790219 1663246]
- [netdrv] net/mlx5e: Restore tunnel metadata on miss (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5: E-Switch, Get reg_c1 value on miss (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5e: Support inner header rewrite with goto action (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5e: Disallow inserting vxlan/vlan egress rules without decap/pop (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5e: Move tc tunnel parsing logic with the rest at tc_tun module (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5e: Allow re-allocating mod header actions (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5: E-Switch, Restore chain id on miss (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5e: Rx, Split rep rx mpwqe handler from nic (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5: E-Switch, Mark miss packets with new chain id mapping (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5: E-Switch, Get reg_c0 value on CQE (Alaa Hleihel) [1790219 1790218 1663246]
- [infiniband] net/mlx5: E-Switch, Move source port on reg_c0 to the upper 16 bits (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5: Introduce mapping infra for mapping unique ids to data (Alaa Hleihel) [1790219 1790218 1663246]
- [netdrv] net/mlx5e: Add devlink fdb_large_groups parameter (Alaa Hleihel) [1790203 1663246]
- [netdrv] net/mlx5: Change the name of steering mode param id (Alaa Hleihel) [1790203 1663246]
- [netdrv] net/mlx5e: Fix an IS_ERR() vs NULL check (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: Verify goto chain offload support (Alaa Hleihel) [1663246]
- [include] net/mlx5: HW bit for goto chain offload support (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Remove redundant comment about goto slow path (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Reduce number of arguments in slow path handling (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Use NL_SET_ERR_MSG_MOD() extack for errors (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch, Allow goto earlier chain if FW supports it (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5e: Eswitch, Use per vport tables for mirroring (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: make the symbol 'ESW_POOLS' static (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch, Increase number of chains and priorities (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: E-Switch, Refactor chains and priorities (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: ft: Check prio and chain sanity for ft offload (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: ft: Use getter function to get ft chain (Alaa Hleihel) [1663246]
- [netdrv] net/mlx5: TC: Offload flow table rules (Alaa Hleihel) [1663246]

* Sun Jun 07 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-212.el8]
- [net] neigh: fix ARP retransmit timer guard (Hangbin Liu) [1767282]
- [net] xfrm: fix a warning in xfrm_policy_insert_list (Xin Long) [1820956]
- [net] netfilter: ipset: Fix subcounter update skip (Phil Sutter) [1834881]
- [netdrv] macvlan: return correct error value (Matteo Croce) [1806146]
- [net] core: properly remove skb from list (Ivan Vecera) [1839657]
- [tools] selftests: fix flower parent qdisc (Ivan Vecera) [1824071]
- [net] sch_choke: Remove classid from choke_skb_cb. (Ivan Vecera) [1824071]
- [net] sched: choke: Remove unused inline function choke_set_classid (Ivan Vecera) [1824071]
- [net] schedule: add action gate offloading (Ivan Vecera) [1824071]
- [net] qos: introduce a gate control flow action (Ivan Vecera) [1824071]
- [net] sched: fallback to qdisc noqueue if default qdisc setup fail (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: tc_actions.sh: add matchall mirror test (Ivan Vecera) [1824071]
- [net] sched: report ndo_setup_tc failures via extack (Ivan Vecera) [1824071]
- [net] sched : Remove unnecessary cast in kfree (Ivan Vecera) [1824071]
- [tools] selftests: tc-testing: Add a TDC test for pedit munge ip6 dsfield (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: pedit_dsfield: Add pedit munge ip6 dsfield (Ivan Vecera) [1824071]
- [net] sched: act_ct: update nf_conn_acct for act_ct SW offload in flowtable (Ivan Vecera) [1824071]
- [net] net_sched: gen_estimator: extend packet counter to 64bit (Ivan Vecera) [1824071]
- [net] flow_offload: skip hw stats check for FLOW_ACTION_HW_STATS_DONT_CARE (Ivan Vecera) [1824071]
- [net] net_sched: sch_skbprio: add message validation to skbprio_change() (Ivan Vecera) [1824071]
- [net] net_sched: fix tcm_parent in tc filter dump (Ivan Vecera) [1824071]
- [net] sch_sfq: validate silly quantum values (Ivan Vecera) [1824071]
- [net] sch_choke: avoid potential panic in choke_reset() (Ivan Vecera) [1824071]
- [net] fq_codel: fix TCA_FQ_CODEL_DROP_BATCH_SIZE sanity checks (Ivan Vecera) [1824071]
- [net] sched: etf: do not assume all sockets are full blown (Ivan Vecera) [1824071]
- [tools] tc-testing: remove duplicate code in tdc.py (Ivan Vecera) [1824071]
- [net] sched: Fix setting last executed chain on skb extension (Ivan Vecera) [1824071]
- [net] net_sched: fix a missing refcnt in tcindex_init() (Ivan Vecera) [1824071]
- [net] net_sched: add a temporary refcnt for struct tcindex_data (Ivan Vecera) [1824071]
- [net] sched: expose HW stats types per action used by drivers (Ivan Vecera) [1824071]
- [net] introduce nla_put_bitfield32() helper and use it (Ivan Vecera) [1824071]
- [tools] selftests: skbedit_priority: Test counters at the skbedit rule (Ivan Vecera) [1824071]
- [net] sched: act_pedit: Implement stats_update callback (Ivan Vecera) [1824071]
- [net] sched: act_skbedit: Implement stats_update callback (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: Add a forwarding test for pedit munge dsfield (Ivan Vecera) [1824071]
- [net] flow_offload.h: Fix a comment at flow_action_entry.mangle (Ivan Vecera) [1824071]
- [net] Fix CONFIG_NET_CLS_ACT=n and CONFIG_NFT_FWD_NETDEV={y, m} build (Ivan Vecera) [1824071]
- [net] netfilter: nft_fwd_netdev: allow to redirect to ifb via ingress (Ivan Vecera) [1824071]
- [net] cbs: Fix software cbs to consider packet sending time (Ivan Vecera) [1824071]
- [include] taprio: do not use BIT() in TCA_TAPRIO_ATTR_FLAG_* definitions (Ivan Vecera) [1824071]
- [net] cls_flower: Add extack support for flags key (Ivan Vecera) [1824071]
- [net] cls_flower: Add extack support for src and dst port range options (Ivan Vecera) [1824071]
- [net] cls_flower: Add extack support for mpls options (Ivan Vecera) [1824071]
- [include] net: sched: refine extack messages in tcf_change_indev (Ivan Vecera) [1824071]
- [net] sched: rename more stats_types (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: Add an skbedit priority selftest (Ivan Vecera) [1824071]
- [net] tc_skbedit: Make the skbedit priority offloadable (Ivan Vecera) [1824071]
- [include] tc_skbedit: Factor a helper out of is_tcf_skbedit_{mark, ptype}() (Ivan Vecera) [1824071]
- [include] net: sched: Do not assume RTNL is held in tunnel key action helpers (Ivan Vecera) [1824071]
- [net] sched: act_ct: Fix leak of ct zone template on replace (Ivan Vecera) [1824071]
- [net] net_sched: sch_fq: enable use of hrtimer slack (Ivan Vecera) [1824071]
- [net] net_sched: do not reprogram a timer about to expire (Ivan Vecera) [1824071]
- [net] net_sched: add qdisc_watchdog_schedule_range_ns() (Ivan Vecera) [1824071]
- [net] rename flow_action_hw_stats_types* -> flow_action_hw_stats* (Ivan Vecera) [1824071]
- [net] net_sched: cls_route: remove the right filter from hashtable (Ivan Vecera) [1824071]
- [tools] selftests: qdiscs: RED: Add nodrop tests (Ivan Vecera) [1824071]
- [net] sched: RED: Introduce an ECN nodrop mode (Ivan Vecera) [1824071]
- [net] sched: Allow extending set of supported RED flags (Ivan Vecera) [1824071]
- [tools] selftests: qdiscs: Add TDC test for RED (Ivan Vecera) [1824071]
- [tools] tc-testing: add ETS scheduler to tdc build configuration (Ivan Vecera) [1824071]
- [net] sched: act_ct: Enable hardware offload of flow table entires (Ivan Vecera) [1824071]
- [net] sched: act_ct: Support refreshing the flow table entries (Ivan Vecera) [1824071]
- [net] sched: act_ct: Support restoring conntrack info on skbs (Ivan Vecera) [1824071]
- [net] sched: act_ct: Instantiate flow table entry actions (Ivan Vecera) [1824071]
- [net] net_sched: keep alloc_hash updated after hash allocation (Ivan Vecera) [1824071]
- [net] net_sched: hold rtnl lock in tcindex_partial_destroy_work() (Ivan Vecera) [1824071]
- [include] flow_offload: restrict driver to pass one allowed bit to flow_action_hw_stats_types_check() (Ivan Vecera) [1824071]
- [netdrv] flow_offload: introduce "delayed" HW stats type and allow it in mlx5 (Ivan Vecera) [1824071]
- [include] flow_offload: turn hw_stats_type into dedicated enum (Ivan Vecera) [1824071]
- [include] flow_offload: use flow_action_for_each in flow_action_mixed_hw_stats_types_check() (Ivan Vecera) [1824071]
- [net] sched: pie: change tc_pie_xstats->prob (Ivan Vecera) [1824071]
- [net] taprio: Fix sending packets without dequeueing them (Ivan Vecera) [1824071]
- [net] sched: act_ct: fix lockdep splat in tcf_ct_flow_table_get (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: ETS: Use Qdisc counters (Ivan Vecera) [1824071]
- [net] sched: Make FIFO Qdisc offloadable (Ivan Vecera) [1824071]
- [include] pie: realign comment (Ivan Vecera) [1824071]
- [net] pie: remove pie_vars->accu_prob_overflows (Ivan Vecera) [1824071]
- [net] pie: remove unnecessary type casting (Ivan Vecera) [1824071]
- [net] pie: use term backlog instead of qlen (Ivan Vecera) [1824071]
- [tools] tc-testing: updated tdc tests for basic filter with canid extended match rules (Ivan Vecera) [1824071]
- [tools] tc-testing: list kernel options for basic filter with canid ematch. (Ivan Vecera) [1824071]
- [net] sched: act_ct: Use pskb_network_may_pull() (Ivan Vecera) [1824071]
- [net] sched: act_ct: Fix ipv6 lookup of offloaded connections (Ivan Vecera) [1824071]
- [net] sched: act_ct: Software offload of established flows (Ivan Vecera) [1824071]
- [net] sched: act_ct: Offload established connections to flow table (Ivan Vecera) [1824071]
- [net] sched: act_ct: Create nf flow table per zone (Ivan Vecera) [1824071]
- [net] taprio: add missing attribute validation for txtime delay (Ivan Vecera) [1824071]
- [net] fq: add missing attribute validation for orphan mask (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: tc_common: Convert to use busywait (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: Convert until_counter_is() to take expression (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: lib: Add tc_rule_handle_stats_get() (Ivan Vecera) [1824071]
- [include] net: flow_offload: Replace zero-length array with flexible-array member (Ivan Vecera) [1824071]
- [net] sched: Replace zero-length array with flexible-array member (Ivan Vecera) [1824071]
- [net] sched: act: count in the size of action flags bitfield (Ivan Vecera) [1824071]
- [tools] tc-testing: updated tdc tests for basic filter with u32 extended match rules (Ivan Vecera) [1824071]
- [tools] tc-testing: updated tdc tests for basic filter with u16 extended match rules (Ivan Vecera) [1824071]
- [tools] tc-testing: updated tdc tests for basic filter (Ivan Vecera) [1824071]
- [net] sched: correct flower port blocking (Ivan Vecera) [1824071]
- [net] sched: Support specifying a starting chain via tc skb ext (Ivan Vecera) [1824071]
- [net] sched: Change the block's chain list to an rcu list (Ivan Vecera) [1824071]
- [net] sched: Pass ingress block to tcf_classify_ingress (Ivan Vecera) [1824071]
- [net] sched: Introduce ingress classification function (Ivan Vecera) [1824071]
- [net] sched: flower: add missing validation of TCA_FLOWER_FLAGS (Ivan Vecera) [1824071]
- [net] sched: matchall: add missing validation of TCA_MATCHALL_FLAGS (Ivan Vecera) [1824071]
- [net] taprio: Fix dropping packets when using taprio + ETF offloading (Ivan Vecera) [1824071]
- [net] taprio: Use taprio_reset_tc() to reset Traffic Classes configuration (Ivan Vecera) [1824071]
- [net] taprio: Add missing policy validation for flags (Ivan Vecera) [1824071]
- [net] taprio: Fix still allowing changing the flags during runtime (Ivan Vecera) [1824071]
- [net] taprio: Fix enabling offload with wrong number of traffic classes (Ivan Vecera) [1824071]
- [net] sched: prevent a use after free (Ivan Vecera) [1824071]
- [tools] tc-testing: add missing 'nsPlugin' to basic.json (Ivan Vecera) [1824071]
- [net] sch_choke: Use kvcalloc (Ivan Vecera) [1824071]
- [tools] selftests: mlxsw: Add a RED selftest (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: lib.sh: Add start_tcp_traffic (Ivan Vecera) [1824071]
- [tools] selftests: mlxsw: Add a TBF selftest (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: lib: Allow reading TC rule byte counters (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: lib: Add helpers for busywaiting (Ivan Vecera) [1824071]
- [tools] selftests: Move two functions from mlxsw's qos_lib to lib (Ivan Vecera) [1824071]
- [net] sched: Make TBF Qdisc offloadable (Ivan Vecera) [1824071]
- [net] sched: sch_tbf: Don't overwrite backlog before dumping (Ivan Vecera) [1824071]
- [net] sched: add Flow Queue PIE packet scheduler (Ivan Vecera) [1824071]
- [net] sched: pie: export symbols to be reused by FQ-PIE (Ivan Vecera) [1824071]
- [net] sched: pie: fix alignment in struct instances (Ivan Vecera) [1824071]
- [net] sched: pie: fix commenting (Ivan Vecera) [1824071]
- [include] pie: improve comments and commenting style (Ivan Vecera) [1824071]
- [net] pie: rearrange structure members and their initializations (Ivan Vecera) [1824071]
- [include] pie: use u8 instead of bool in pie_vars (Ivan Vecera) [1824071]
- [include] pie: rearrange macros in order of length (Ivan Vecera) [1824071]
- [include] pie: use U64_MAX to denote (2^64 - 1) (Ivan Vecera) [1824071]
- [net] sched: pie: move common code to pie.h (Ivan Vecera) [1824071]
- [net] sched: use skb_list_walk_safe helper for gso segments (Ivan Vecera) [1824071]
- [tools] selftests: qdiscs: Add test coverage for ETS Qdisc (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: sch_ets: Add test coverage for ETS Qdisc (Ivan Vecera) [1824071]
- [tools] selftests: forwarding: Move start_/stop_traffic from mlxsw to lib.sh (Ivan Vecera) [1824071]
- [net] sch_ets: Make the ETS qdisc offloadable (Ivan Vecera) [1824071]
- [net] sch_ets: Add a new Qdisc (Ivan Vecera) [1824071]
- [include] net: pkt_cls: Clarify a comment (Ivan Vecera) [1824071]
- [net] sch_cake: drop unused variable tin_quantum_prio (Ivan Vecera) [1824071]
- [net] sched: act_ctinfo: fix memory leak (Ivan Vecera) [1824071]
- [net] sched: act_ife: initalize ife->metalist earlier (Ivan Vecera) [1824071]
- [net] sch_cake: avoid possible divide by zero in cake_enqueue() (Ivan Vecera) [1824071]
- [tools] tc-testing: initial tdc selftests for cls_u32 (Ivan Vecera) [1824071]
- [net] treewide: Use sizeof_field() macro (Ivan Vecera) [1824071]
- [tools] tc-testing: unbreak full listing of tdc testcases (Ivan Vecera) [1824071]
- [net] act_ct: support asymmetric conntrack (Ivan Vecera) [1824071]
- [net] sch_cake: Add missing NLA policy entry TCA_CAKE_SPLIT_GSO (Ivan Vecera) [1824071]
- [net] remove the unnecessary strict_start_type in some policies (Ivan Vecera) [1824071]
- [net] sched: pie: enable timestamp based delay calculation (Ivan Vecera) [1824071]
- [net] taprio: don't reject same mqprio settings (Ivan Vecera) [1824071]
- [tools] tc-testing: Introduced tdc tests for basic filter (Ivan Vecera) [1824071]
- [tools] tc-testing: updated pedit TDC tests (Ivan Vecera) [1824071]
- [net] net_sched: add TCA_STATS_PKT64 attribute (Ivan Vecera) [1824071]
- [net] net_sched: extend packet counter to 64bit (Ivan Vecera) [1824071]
- [include] net_sched: do not export gnet_stats_basic_packed to uapi (Ivan Vecera) [1824071]
- [tools] tc-testing: added tests with cookie for mpls TC action (Ivan Vecera) [1824071]
- [net] icmp: remove duplicate code (Ivan Vecera) [1824071]
- [include] icmp: add helpers to recognize ICMP error packets (Ivan Vecera) [1824071]
- [net] taprio: fix panic while hw offload sched list swap (Ivan Vecera) [1824071]
- [net] sched: Replace rcu_swap_protected() with rcu_replace_pointer() (Ivan Vecera) [1824071]
- [net] net_sched: sch_fq: avoid calling ktime_get_ns() if not needed (Ivan Vecera) [1824071]
- [net] net_sched: sch_fq: add dctcp-like marking (Ivan Vecera) [1824071]
- [net] net_sched: sch_fq: remove dead code dealing with retransmits (Ivan Vecera) [1824071]
- [net] sched: act_ct: fix build failure in RHEL8 (Ivan Vecera) [1824071]
- [net] don't return invalid table id error when we fall back to PF_UNSPEC (Sabrina Dubroca) [1814093]
- [net] netfilter: update include directives. (Marcelo Leitner) [1837856]
- [include] netfilter: fix include guards. (Marcelo Leitner) [1837856]
- [include] netfilter: add include guard to xt_connlabel.h (Marcelo Leitner) [1837856]
- [net] sk_msg: Don't use RCU_INIT_POINTER on sk_user_data (Sabrina Dubroca) [1819627]
- [tools] selftests/bpf: Fix build of sockmap_ktls.c (Sabrina Dubroca) [1819627]
- [net] Generate reuseport group ID on group creation (Sabrina Dubroca) [1819627]
- [net] bpf: Allow selecting reuseport socket from a SOCKMAP/SOCKHASH (Sabrina Dubroca) [1819627]
- [net] bpf, sockmap: Let all kernel-land lookup values in SOCKMAP/SOCKHASH (Sabrina Dubroca) [1819627]
- [net] bpf, sockmap: Return socket cookie on lookup from syscall (Sabrina Dubroca) [1819627]
- [net] bpf, sockmap: Don't set up upcalls and progs for listening sockets (Sabrina Dubroca) [1819627]
- [net] bpf, sockmap: Allow inserting listening TCP sockets into sockmap (Sabrina Dubroca) [1819627]
- [net] tcp_bpf: Don't let child socket inherit parent protocol ops on copy (Sabrina Dubroca) [1819627]
- [net] net, sk_msg: Clear sk_user_data pointer on clone if tagged (Sabrina Dubroca) [1819627]
- [net] net, sk_msg: Annotate lockless access to sk_prot on clone (Sabrina Dubroca) [1819627]
- [net] bpf, sockmap: bpf_tcp_ingress needs to subtract bytes from sg.size (Sabrina Dubroca) [1819627]
- [net] bpf, sockmap: msg_pop_data can incorrecty set an sge length (Sabrina Dubroca) [1819627]
- [net] tls: fix const assignment warning (Sabrina Dubroca) [1819627]
- [net] tls: Fix sk_psock refcnt leak in bpf_exec_tx_verdict() (Sabrina Dubroca) [1819627]
- [net] tls: Fix sk_psock refcnt leak when in tls_data_ready() (Sabrina Dubroca) [1819627]
- [tools] selftests/bpf: Test unhashing kTLS socket after removing from map (Sabrina Dubroca) [1819627]
- [include] bpf, sk_msg: Don't clear saved sock proto on restore (Sabrina Dubroca) [1819627]
- [include] bpf, sk_msg: Let ULP restore sk_proto and write_space callback (Sabrina Dubroca) [1819627]
- [net] tls: Annotate access to sk_prot with READ_ONCE/WRITE_ONCE (Sabrina Dubroca) [1819627]
- [net] tls: Read sk_prot once when building tls proto ops (Sabrina Dubroca) [1819627]
- [net] tls: Constify base proto ops used for building tls proto (Sabrina Dubroca) [1819627]
- [net] tls: Fix to avoid gettig invalid tls record (Sabrina Dubroca) [1819627]
- [net] tls: avoid spurious decryption error with HW resync (Sabrina Dubroca) [1819627]
- [net] tls: add helper for testing if socket is RX offloaded (Sabrina Dubroca) [1819627]
- [tools] selftests: net: tls: remove recv_rcvbuf test (Sabrina Dubroca) [1819627]
- [net] tls: use sg_next() to walk sg entries (Sabrina Dubroca) [1819627]
- [net] tls: remove the dead inplace_crypto code (Sabrina Dubroca) [1819627]
- [tools] selftests/tls: add a test for fragmented messages (Sabrina Dubroca) [1819627]
- [net] tls: Fix unused function warning (Sabrina Dubroca) [1819627]
- [net] tls: store decrypted on a single bit (Sabrina Dubroca) [1819627]
- [net] tls: store async_capable on a single bit (Sabrina Dubroca) [1819627]
- [net] tls: pass context to tls_device_decrypted() (Sabrina Dubroca) [1819627]
- [net] tls: make allocation failure unlikely (Sabrina Dubroca) [1819627]
- [net] tls: mark sk->err being set as unlikely (Sabrina Dubroca) [1819627]
- [net] sockmap: use bitmap for copy info (Sabrina Dubroca) [1819627]
- [net] tls: add TlsDeviceRxResync statistic (Sabrina Dubroca) [1819627]
- [net] tls: add TlsDecryptError stat (Sabrina Dubroca) [1819627]
- [net] tls: add statistics for installed sessions (Sabrina Dubroca) [1819627]
- [net] tls: add skeleton of MIB statistics (Sabrina Dubroca) [1819627]
- [net] tls: add device decrypted trace point (Sabrina Dubroca) [1819627]
- [net] tls: add tracing for device/offload events (Sabrina Dubroca) [1819627]
- [net] tls: allow compiling TLS TOE out (Sabrina Dubroca) [1819627]
- [net] tls: rename tls_hw_* functions tls_toe_* (Sabrina Dubroca) [1819627]
- [net] tls: move TOE-related code to a separate file (Sabrina Dubroca) [1819627]
- [net] tls: move tls_build_proto() on init path (Sabrina Dubroca) [1819627]
- [net] tls: use the full sk_proto pointer (Sabrina Dubroca) [1819627]
- [net] tls: rename tls_device to tls_toe_device (Sabrina Dubroca) [1819627]
- [net] tls: move TOE-related structures to a separate header (Sabrina Dubroca) [1819627]
- [net] tls: sleeping function from invalid context (Sabrina Dubroca) [1819627]
- [net] netfilter: nft_set_rbtree: Add missing expired checks (Phil Sutter) [1778020]
- [tools] selftests: netfilter: extend flowtable test script with dnat rule (Marcelo Leitner) [1811193]
- [tools] selftests: netfilter: extend flowtable test script for ipsec (Marcelo Leitner) [1811193]
- [tools] selftests: netfilter: add flowtable test script (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: set NF_FLOW_TEARDOWN flag on entry expiration (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Remove WQ_MEM_RECLAIM from workqueue (Marcelo Leitner) [1811193]
- [net] netfilter: nf_conntrack: add IPS_HW_OFFLOAD status bit (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Free block_cb when being deleted (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add counter support in HW offload (Marcelo Leitner) [1811193]
- [net] netfilter: conntrack: add nf_ct_acct_add() (Marcelo Leitner) [1811193]
- [net] netfilter: conntrack: export nf_ct_acct_update() (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Use work entry per offload command (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Use rw sem as flow block lock (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add counter support (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: add enum nft_flowtable_flags to uapi (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Fix incorrect tc_setup_type type (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: populate addr_type mask (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Fix flushing of offloaded flows on free (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: fix NULL pointer dereference in tunnel offload support (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: reload ip{v6}h in nf_flow_tuple_ip{v6} (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: reload ip{v6}h in nf_flow_nat_ip{v6} (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: dump NFTA_CHAIN_FLAGS attribute (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: free flowtable hooks on hook register error (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add tunnel encap/decap action offload support (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add indr block setup support (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add nf_flow_table_block_offload_init() (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add tunnel match offload support (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: skip offload setup if disabled (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Use nf_flow_offload_tuple for stats as well (Marcelo Leitner) [1811193]
- [net] flow_offload: Add flow_match_ct to get rule ct match (Marcelo Leitner) [1811193]
- [include] net/sched: act_ct: Enable hardware offload of flow table entires (Marcelo Leitner) [1811193]
- [include] net/sched: act_ct: Support refreshing the flow table entries (Marcelo Leitner) [1811193]
- [include] net/sched: act_ct: Support restoring conntrack info on skbs (Marcelo Leitner) [1811193]
- [net] sched: act_ct: Instantiate flow table entry actions (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Add API for registering to flow table events (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Fix setting forgotten NF_FLOW_HW_DEAD flag (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Fix missing flush hardware on table free (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: Fix hardware flush order on nf_flow_table_cleanup (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: fix check the chain offload flag (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: fix memory leak in nf_tables_parse_netdev_hooks() (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add nf_flow_table_offload_cmd() (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add nf_flow_offload_tuple() helper (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: refresh flow if hardware offload fails (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add nf_flowtable_hw_offload() helper function (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: use atomic bitwise operations for flow flags (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: remove dying bit, use teardown bit instead (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add nf_flow_offload_work_alloc() (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: restrict flow dissector match on meta ingress device (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: fetch stats only if flow is still alive (Marcelo Leitner) [1811193]
- [net] netfilter: flowtable: add nf_flowtable_time_stamp (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: unbind callbacks from flowtable destroy path (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: fix the nat port mangle. (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: check the status of dst_neigh (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: fix incorrect ethernet dst address (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: fix big-endian integer overflow (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: Correct memcpy size for flow_overload_mangle() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: return EOPNOTSUPP if rule specifies no actions (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: add IPv6 match description (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: Don't use offset uninitialized in flow_offload_port_{d, s}nat (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: Fix block_cb tc_setup_type as TC_SETUP_CLSFLOWER (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: Fix block setup as TC_SETUP_FT cmd (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: check if bind callback fails and unbind if hook registration fails (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: add nft_unregister_flowtable_hook() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: undo updates if transaction fails (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: release flow_rule on error from commit path (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: remove reference to flow rule from deletion path (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: add IPv6 support (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: add flow_action_entry_next() and use it (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: remove unnecessary parameter in flow_offload_fill_dir (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table_offload: Fix check ndo_setup_tc when setup_block (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: Check for the NETDEV_UNREGISTER event (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: hardware offload support (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: add flowtable offload control plane (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: detach routing information from flow description (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: skip tcp rst and fin packets (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flowtable: remove flow_offload_entry structure (Marcelo Leitner) [1811193]
- [include] netfilter: nf_flow_table: remove union from flow_offload structure (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: move conntrack object to struct flow_offload (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: skip EBUSY on chain update (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: bogus EOPNOTSUPP on basechain update (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: pass extack to nft_flow_cls_offload_setup() (Marcelo Leitner) [1811193]
- [net] netfilter: nft_meta: offload support for interface index (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: white-space fixes. (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: check for register data length mismatches (Marcelo Leitner) [1811193]
- [net] netfilter: nft_bitwise: Adjust parentheses to fix memcmp size argument (Marcelo Leitner) [1811193]
- [net] netfilter: nft_bitwise: add offload support (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: unbind if multi-device binding fails (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: add nft_flow_block_offload_init() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: add nft_chain_offload_cmd() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: restore basechain deletion (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: support for multiple devices per netdev hook (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: fix base chain stat rcu_dereference usage (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: remove rules on unregistered device only (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: add nft_flow_cls_offload_setup() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: Pass callback list to nft_setup_cb_call() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: add nft_flow_block_chain() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: increase maximum devices number per flowtable (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: allow netdevice to be used only once per flowtable (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: dynamically allocate hooks per net_device in flowtables (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: remove flowtable hook flush routine in netns exit routine (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: move priority to struct nf_flowtable (Marcelo Leitner) [1811193]
- [net] netfilter: nft_payload: fix missing check for matching length in offloads (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: set timeout before insertion into hashes (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: fix always true policy is unset check (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: add NFT_CHAIN_POLICY_UNSET and use it (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: remove rules when the device unregisters (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: refactor the nft_flow_offload_rule function (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: refactor the nft_flow_offload_chain function (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: add __nft_offload_get_chain function (Marcelo Leitner) [1811193]
- [net] netfilter: nft_{fwd, dup}_netdev: add offload support (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: avoid excessive stack usage (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: move indirect flow_block callback logic to core (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: set default timeout after successful insertion (Marcelo Leitner) [1811193]
- [net] netfilter: ctnetlink: honor IPS_OFFLOAD flag (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: clear skb tstamp before xmit (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: map basechain priority to hardware priority (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: teardown flow timeout race (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: conntrack picks up expired flows (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables_offload: support indr block call (Marcelo Leitner) [1811193]
- [net] flow_offload: add flow_block structure and use it (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: store data in offload context registers (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: fix offload for flows that are subject to xfrm (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: don't fail when updating base chain policy (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: add hardware offload support (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: delay chain policy update until transaction is complete (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: IPCB is only valid for ipv4 family (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: don't offload when sequence numbers need adjustment (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: set liberal tracking mode for tcp (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: ignore DF bit setting (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: remove unnecessary variable in flow_offload_tuple (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: add entry to flowtable after confirmation (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: fix checking method of conntrack helper (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: fix missing error check for rhashtable_insert_fast (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: do not flow offload deleted conntrack entries (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: simplify nf_flow_offload_gc_step() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: check ttl value in flow offload data path (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: fix netdev refcnt leak (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flowtable: skip device lookup from interface index (Marcelo Leitner) [1811193]
- [net] netfilter: conntrack: fix IPV6=n builds (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: fix interaction with vrf slave device (Marcelo Leitner) [1811193]
- [net] netfilter: nft_flow_offload: Fix reverse route lookup (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: make nf_flow_table_iterate() static (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: do not remove offload when other netns's interface is down (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: remove unnecessary parameter of nf_flow_table_cleanup() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_tables: use rhashtable_lookup() instead of rhashtable_lookup_fast() (Marcelo Leitner) [1811193]
- [net] netfilter: nf_flow_table: remove unnecessary nat flag check code (Marcelo Leitner) [1811193]
- [net] mptcp: mark tech preview and disable by default (Florian Westphal) [1835796]
- [net] mptcp: fix bogus socket flag values (Florian Westphal) [1835796]
- [net] mptcp: select CRYPTO (Florian Westphal) [1835796]
- [net] mptcp: Protect subflow socket options before connection completes (Florian Westphal) [1835796]
- [net] mptcp: make the symbol 'mptcp_sk_clone_lock' static (Florian Westphal) [1835796]
- [net] mptcp: fix use-after-free for ipv6 (Florian Westphal) [1835796]
- [net] mptcp: fix use-after-free on tcp fallback (Florian Westphal) [1835796]
- [net] mptcp: Fix undefined mptcp_handle_ipv6_mapped for modular IPV6 (Florian Westphal) [1835796]
- [net] mptcp: Fix incorrect IPV6 dependency check (Florian Westphal) [1835796]
- [net] mptcp: handle tcp fallback when using syn cookies (Florian Westphal) [1835796]
- [net] mptcp: avoid a lockdep splat when mcast group was joined (Florian Westphal) [1835796]
- [net] mptcp: fix panic on user pointer access (Florian Westphal) [1835796]
- [net] mptcp: defer freeing of cached ext until last moment (Florian Westphal) [1835796]
- [net] mptcp: Fix build with PROC_FS disabled. (Florian Westphal) [1835796]
- [tools] selftests: settings: tests can be in subsubdirs (Florian Westphal) [1835796]
- [net] mptcp: Fix code formatting (Florian Westphal) [1835796]
- [net] mptcp: do not inherit inet proto ops (Florian Westphal) [1835796]
- [net] add and use MPTCP_PROTO_KERN (Florian Westphal) [1835796]
- [net] mptcp: cope with later TCP fallback (Florian Westphal) [1835796]
- [net] mptcp: process MP_CAPABLE data option (Florian Westphal) [1835796]
- [net] mptcp: parse and emit MP_CAPABLE option according to v1 spec (Florian Westphal) [1835796]
- [net] mptcp: move from sha1 (v0) to sha256 (v1) (Florian Westphal) [1835796]
- [tools] mptcp: add basic kselftest for mptcp (Florian Westphal) [1835796]
- [net] mptcp: new sysctl to control the activation per NS (Florian Westphal) [1835796]
- [net] mptcp: allow collapsing consecutive sendpages on the same substream (Florian Westphal) [1835796]
- [net] mptcp: recvmsg() can drain data from multiple subflows (Florian Westphal) [1835796]
- [net] mptcp: add subflow write space signalling and mptcp_poll (Florian Westphal) [1835796]
- [net] mptcp: Implement MPTCP receive path (Florian Westphal) [1835796]
- [net] mptcp: Write MPTCP DSS headers to outgoing data packets (Florian Westphal) [1835796]
- [net] mptcp: Add setsockopt()/getsockopt() socket operations (Florian Westphal) [1835796]
- [net] mptcp: Add shutdown() socket operation (Florian Westphal) [1835796]
- [net] mptcp: Add key generation and token tree (Florian Westphal) [1835796]
- [net] mptcp: Create SUBFLOW socket for incoming connections (Florian Westphal) [1835796]
- [net] mptcp: Handle MP_CAPABLE options for outgoing connections (Florian Westphal) [1835796]
- [net] mptcp: Associate MPTCP context with TCP socket (Florian Westphal) [1835796]
- [net] mptcp: Handle MPTCP TCP options (Florian Westphal) [1835796]
- [net] mptcp: Add MPTCP socket stubs (Florian Westphal) [1835796]
- [net] netfilter: conntrack: fix infinite loop on rmmod (Florian Westphal) [1832381]
- [tools] selftests: add netdevsim devlink dev info test (Petr Oros) [1830928]
- [tools] selftests: test netdevsim reload forbid and fail (Petr Oros) [1830928]
- [netdrv] mlx4: fix "initializer element not constant" compiler error (Petr Oros) [1830928]
- [netdrv] netdevsim: dev: Fix memory leak in nsim_dev_take_snapshot_write (Petr Oros) [1830928]
- [net] devlink: fix return value after hitting end in region read (Petr Oros) [1830928]
- [net] devlink: Fix reporter's recovery condition (Petr Oros) [1830928]
- [documentation] docs: devlink: clarify the scope of snapshot id (Petr Oros) [1830928]
- [net] devlink: let kernel allocate region snapshot id (Petr Oros) [1830928]
- [net] devlink: factor out building a snapshot notification (Petr Oros) [1830928]
- [documentation] devlink: fix broken link warning (Petr Oros) [1830928]
- [net] devlink: use NL_SET_ERR_MSG_MOD instead of NL_SET_ERR_MSG (Petr Oros) [1830928]
- [include] devlink: Add macro for "fw.mgmt.api" to info_get cb. (Petr Oros) [1830928]
- [netdrv] netdevsim: support taking immediate snapshot via devlink (Petr Oros) [1830928]
- [net] devlink: implement DEVLINK_CMD_REGION_NEW (Petr Oros) [1830928]
- [net] devlink: track snapshot id usage count using an xarray (Petr Oros) [1830928]
- [net] devlink: report error once U32_MAX snapshot ids have been used (Petr Oros) [1830928]
- [net] devlink: extract snapshot id allocation to helper function (Petr Oros) [1830928]
- [net] devlink: use -ENOSPC to indicate no more room for snapshots (Petr Oros) [1830928]
- [net] devlink: add function to take snapshot while locked (Petr Oros) [1830928]
- [net] devlink: trivial: fix tab in function documentation (Petr Oros) [1830928]
- [net] devlink: convert snapshot destructor callback to region op (Petr Oros) [1830928]
- [net] devlink: prepare to support region operations (Petr Oros) [1830928]
- [documentation] devlink: expand the devlink-info documentation (Petr Oros) [1830928]
- [net] devlink: Introduce devlink port flavour virtual (Petr Oros) [1830928]
- [net] devlink: validate length of region addr/len (Petr Oros) [1830928]
- [net] devlink: validate length of param values (Petr Oros) [1830928]
- [net] core: Replace zero-length array with flexible-array member (Petr Oros) [1830928]
- [net] core: devlink.c: Use built-in RCU list checking (Petr Oros) [1830928]
- [net] devlink: Rely on driver eswitch thread safety instead of devlink (Petr Oros) [1830928]
- [net] core: devlink.c: Hold devlink->lock from the beginning of devlink_dpipe_table_register() (Petr Oros) [1830928]
- [net] devlink: Force enclosing array on binary fmsg data (Petr Oros) [1830928]
- [net] devlink: report 0 after hitting end in region read (Petr Oros) [1830928]
- [net] devlink: correct misspelling of snapshot (Petr Oros) [1830928]
- [tools] selftests: Add a test of large binary to devlink health test (Petr Oros) [1830928]
- [netdrv] netdevsim: Update dummy reporter's devlink binary interface (Petr Oros) [1830928]
- [net] devlink: Allow large formatted message of binary output (Petr Oros) [1830928]
- [tools] selftests: netdevsim: Add test cases for devlink-trap policers (Petr Oros) [1823743]
- [netdrv] netdevsim: Add support for setting of packet trap group parameters (Petr Oros) [1823743]
- [net] devlink: Allow setting of packet trap group parameters (Petr Oros) [1823743]
- [net] devlink: Add packet trap group parameters support (Petr Oros) [1823743]
- [netdrv] netdevsim: Add devlink-trap policer support (Petr Oros) [1823743]
- [documentation] Add description of packet trap policers (Petr Oros) [1823743]
- [net] devlink: Add packet trap policers support (Petr Oros) [1823743]
- [net] devlink: Add auto dump flag to health reporter (Petr Oros) [1823743]
- [net] devlink: Implicitly set auto recover flag when registering health reporter (Petr Oros) [1823743]
- [netdrv] netdevsim: Change dummy reporter auto recover default (Petr Oros) [1823743]
- [net] devlink: Only pass packet trap group identifier in trap structure (Petr Oros) [1823743]
- [net] devlink: Stop reference counting packet trap groups (Petr Oros) [1823743]
- [netdrv] netdevsim: Explicitly register packet trap groups (Petr Oros) [1823743]
- [net] devlink: Add API to register packet trap groups (Petr Oros) [1823743]
- [net] esp6: calculate transport_header correctly when sel.family != AF_INET6 (Xin Long) [1815980 1761579]
- [net] esp4: support ipv6 nexthdrs process for beet gso segment (Xin Long) [1815980 1761579]
- [net] esp6: support ipv6 nexthdrs process for beet gso segment (Xin Long) [1815980 1761579]
- [net] xfrm: remove the xfrm_state_put call becofe going to out_reset (Xin Long) [1815980 1761579]
- [net] esp6: get the right proto for transport mode in esp6_gso_encap (Xin Long) [1815980 1761579]
- [net] xfrm: do pskb_pull properly in __xfrm_transport_prep (Xin Long) [1815980 1761579]
- [net] xfrm: allow to accept packets with ipv6 NEXTHDR_HOP in xfrm_input (Xin Long) [1815980 1761579]
- [net] xfrm: add prep for esp beet mode offload (Xin Long) [1815980 1761579]
- [net] esp6: add gso_segment for esp6 beet mode (Xin Long) [1815980 1761579]
- [net] esp4: add gso_segment for esp4 beet mode (Xin Long) [1815980 1761579]
- [net] xfrm: kconfig: make xfrm depend on inet (Xin Long) [1815980 1761579]
- [net] xfrm: make xfrm modes builtin (Xin Long) [1815980 1761579]
- [net] xfrm: remove afinfo pointer from xfrm_mode (Xin Long) [1815980 1761579]
- [net] xfrm: remove output2 indirection from xfrm_mode (Xin Long) [1815980 1761579]
- [net] xfrm: remove input2 indirection from xfrm_mode (Xin Long) [1815980 1761579]
- [net] xfrm: remove gso_segment indirection from xfrm_mode (Xin Long) [1815980 1761579]
- [net] xfrm: remove xmit indirection from xfrm_mode (Xin Long) [1815980 1761579]
- [net] xfrm: remove output indirection from xfrm_mode (Xin Long) [1815980 1761579]
- [net] xfrm: remove input indirection from xfrm_mode (Xin Long) [1761579 1815980]
- [net] xfrm: prefer family stored in xfrm_mode struct (Xin Long) [1815980 1761579]
- [net] xfrm: place af number into xfrm_mode struct (Xin Long) [1761579 1815980]
- [net] xfrm: gso partial offload support (Xin Long) [1761579 1815980]
- [net] netfilter: cttimeout: remove set but not used variable 'l3num' (Florian Westphal) [1822085]
- [net] netfilter: conntrack: handle icmp pkt_to_tuple helper via direct calls (Florian Westphal) [1822085]
- [net] netfilter: conntrack: handle builtin l4proto packet functions via direct calls (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove net_id (Florian Westphal) [1822085]
- [net] netfilter: conntrack: gre: switch module to be built-in (Florian Westphal) [1822085]
- [net] netfilter: remove unused parameters in nf_ct_l4proto_[un]register_sysctl() (Florian Westphal) [1822085]
- [net] netfilter: conntrack: gre: convert rwlock to rcu (Florian Westphal) [1822085]
- [net] netfilter: nfnetlink_cttimeout: fetch timeouts for udplite and gre, too (Florian Westphal) [1822085]
- [net] netfilter: nfnetlink_cttimeout: pass default timeout policy to obj_to_nlattr (Florian Westphal) [1822085]
- [net] netfilter: conntrack: add nf_{tcp, udp, sctp, icmp, dccp, icmpv6, generic}_pernet() (Florian Westphal) [1822085]
- [net] netfilter: conntrack: clamp l4proto array size at largers supported protocol (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove l3->l4 mapping information (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove unused proto arg from netns init functions (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove error callback and handle icmp from core (Florian Westphal) [1822085]
- [net] netfilter: conntrack: avoid using ->error callback if possible (Florian Westphal) [1822085]
- [net] netfilter: conntrack: deconstify packet callback skb pointer (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove the l4proto->new() function (Florian Westphal) [1822085]
- [net] netfilter: conntrack: timeout interface depend on CONFIG_NF_CONNTRACK_TIMEOUT (Florian Westphal) [1822085]
- [net] netfilter: conntrack: pass nf_hook_state to packet and error handlers (Florian Westphal) [1822085]
- [net] netfilter: conntrack: place 'new' timeout in first location too (Florian Westphal) [1822085]
- [net] netfilter: nf_conntrack_h323: Remove deprecated config check (Florian Westphal) [1822085]
- [include] netfilter: nf_tables: merge route type into core (Florian Westphal) [1822085]
- [net] netfilter: ipv6: avoid indirect calls for IPV6=y case (Florian Westphal) [1822085]
- [net] netfilter: nat: remove module dependency on ipv6 core (Florian Westphal) [1822085]
- [net] netfilter: remove obsolete need_conntrack stub (Florian Westphal) [1822085]
- [net] netfilter: conntrack: avoid use-after free on rmmod (Florian Westphal) [1822085]
- [net] netfilter: conntrack: dccp, sctp: handle null timeout argument (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove duplicated include from nf_conntrack_proto_udp.c (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove l3proto abstraction (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove get_timeout() indirection (Florian Westphal) [1822085]
- [net] netfilter: conntrack: avoid l4proto pkt_to_tuple calls (Florian Westphal) [1822085]
- [net] netfilter: conntrack: avoid calls to l4proto invert_tuple (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove get_l4proto indirection from l3 protocol trackers (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove invert_tuple indirection from l3 protocol trackers (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove pkt_to_tuple indirection from l3 protocol trackers (Florian Westphal) [1822085]
- [net] netfilter: conntrack: remove ctnetlink callbacks from l3 protocol trackers (Florian Westphal) [1822085]
- [net] openvswitch: use nf_ct_get_tuplepr, invert_tuplepr (Florian Westphal) [1822085]
- [net] netfilter: utils: move nf_ip6_checksum* from ipv6 to utils (Florian Westphal) [1822085]
- [net] netfilter: utils: move nf_ip_checksum* from ipv4 to utils (Florian Westphal) [1822085]
- [net] netfilter: flowtables: use fixed renew timeout on teardown (Florian Westphal) [1822085]
- [netdrv] geneve: use the correct nlattr array in NL_SET_ERR_MSG_ATTR (Xin Long) [1809503]
- [netdrv] vxlan: use the correct nlattr array in NL_SET_ERR_MSG_ATTR (Xin Long) [1809503]
- [netdrv] geneve: Allow configuration of DF behaviour (Xin Long) [1809503]
- [netdrv] vxlan: Allow configuration of DF behaviour (Xin Long) [1809503]
- [netdrv] net: phy: realtek: fix using paged operations with RTL8105e / RTL8208 (Josef Oskera) [1841511]
- [netdrv] r8169: fix OCP access on RTL8117 (Josef Oskera) [1841511]
- [netdrv] r8169: re-establish support for RTL8401 chip version (Josef Oskera) [1841511]
- [netdrv] r8169: change back SG and TSO to be disabled by default (Josef Oskera) [1841511]
- [netdrv] r8169: factor out rtl8169_tx_map (Josef Oskera) [1841511]
- [netdrv] r8169: improve handling of TD_MSS_MAX (Josef Oskera) [1841511]
- [netdrv] r8169: fix PHY driver check on platforms w/o module softdeps (Josef Oskera) [1841511]
- [netdrv] r8169: re-enable MSI on RTL8168c (Josef Oskera) [1841511]
- [netdrv] r8169: don't use MSI before RTL8168d (Josef Oskera) [1841511]
- [netdrv] r8169: improve RTL8168b FIFO overflow workaround (Josef Oskera) [1841511]
- [netdrv] r8169: improve rtl_schedule_task (Josef Oskera) [1841511]
- [netdrv] r8169: simplify rtl_task (Josef Oskera) [1841511]
- [netdrv] r8169: add new helper rtl8168g_enable_gphy_10m (Josef Oskera) [1841511]
- [netdrv] net: r8169: reject unsupported coalescing params (Josef Oskera) [1841511]
- [netdrv] r8169: simplify getting stats by using netdev_stats_to_stats64 (Josef Oskera) [1841511]
- [netdrv] r8169: let rtl8169_mark_to_asic clear rx descriptor field opts2 (Josef Oskera) [1841511]
- [netdrv] r8169: remove now unneeded barrier in rtl_tx (Josef Oskera) [1841511]
- [netdrv] r8169: simplify usage of rtl8169_unmap_tx_skb (Josef Oskera) [1841511]
- [netdrv] r8169: ensure tx_skb is fully reset after calling rtl8169_unmap_tx_skb (Josef Oskera) [1841511]
- [netdrv] r8169: convert while to for loop in rtl_tx (Josef Oskera) [1841511]
- [netdrv] r8169: use pci_status_get_and_clear_errors (Josef Oskera) [1841511]
- [netdrv] r8169: add PCI_STATUS_PARITY to PCI status error bits (Josef Oskera) [1841511]
- [netdrv] r8169: improve rtl8169_start_xmit (Josef Oskera) [1841511]
- [netdrv] r8169: remove RTL_EVENT_NAPI constants (Josef Oskera) [1841511]
- [netdrv] r8169: use new helper tcp_v6_gso_csum_prep (Josef Oskera) [1841511]
- [netdrv] r8169: improve statistics of missed rx packets (Josef Oskera) [1841511]
- [netdrv] r8169: improve rtl_jumbo_config (Josef Oskera) [1841511]
- [netdrv] r8169: improve rtl8169_get_mac_version (Josef Oskera) [1841511]
- [netdrv] r8169: add helper rtl_pci_commit (Josef Oskera) [1841511]
- [netdrv] r8169: simplify setting netdev features (Josef Oskera) [1841511]
- [netdrv] r8169: remove setting PCI_CACHE_LINE_SIZE in rtl_hw_start_8169 (Josef Oskera) [1841511]
- [netdrv] r8169: remove unneeded check from rtl_link_chg_patch (Josef Oskera) [1841511]
- [netdrv] r8169: fix performance regression related to PCIe max read request size (Josef Oskera) [1841511]
- [netdrv] r8169: don't set min_mtu/max_mtu if not needed (Josef Oskera) [1841511]
- [netdrv] r8169: factor out PHY configuration to r8169_phy_config.c (Josef Oskera) [1841511]
- [netdrv] r8169: add r8169.h (Josef Oskera) [1841511]
- [netdrv] r8169: rename rtl_apply_firmware (Josef Oskera) [1841511]
- [netdrv] r8169: add phydev argument to rtl8168d_apply_firmware_cond (Josef Oskera) [1841511]
- [netdrv] r8169: use phy_read/write instead of rtl_readphy/writephy (Josef Oskera) [1841511]
- [netdrv] r8169: replace rtl_w0w1_phy (Josef Oskera) [1841511]
- [netdrv] r8169: replace rtl_patchphy (Josef Oskera) [1841511]
- [netdrv] r8169: move disabling MAC EEE for RTL8402/RTL8106e (Josef Oskera) [1841511]
- [netdrv] r8169: move setting ERI register 0x1d0 for RTL8106 (Josef Oskera) [1841511]
- [netdrv] r8169: switch to phylib functions in rtl_writephy_batch (Josef Oskera) [1841511]
- [netdrv] r8169: change argument type of RTL8168g-specific PHY config functions (Josef Oskera) [1841511]
- [netdrv] r8169: change argument type of EEE PHY functions (Josef Oskera) [1841511]
- [netdrv] r8169: move RTL8169scd Gigabyte PHY quirk (Josef Oskera) [1841511]
- [netdrv] r8169: remove not needed debug print in rtl8169_init_phy (Josef Oskera) [1841511]
- [netdrv] r8169: prepare for exporting rtl_hw_phy_config (Josef Oskera) [1841511]
- [netdrv] r8169: add constant EnAnaPLL (Josef Oskera) [1841511]
- [netdrv] r8169: move enabling EEE to rtl8169_init_phy (Josef Oskera) [1841511]
- [netdrv] r8169: remove MAC workaround in rtl8168e_2_hw_phy_config (Josef Oskera) [1841511]
- [netdrv] r8169: factor out rtl8168h_2_get_adc_bias_ioffset (Josef Oskera) [1841511]
- [netdrv] r8169: check that Realtek PHY driver module is loaded (Josef Oskera) [1841511]
- [netdrv] treewide: Use sizeof_field() macro (Josef Oskera) [1841511]
- [netdrv] r8169: fix rtl_hw_jumbo_disable for RTL8168evl (Josef Oskera) [1841511]
- [netdrv] r8169: add missing RX enabling for WoL on RTL8125 (Josef Oskera) [1841511]
- [netdrv] r8169: fix jumbo configuration for RTL8168evl (Josef Oskera) [1841511]
- [netdrv] r8169: add check for PHY_MDIO_CHG to rtl_nic_fw_data_ok (Josef Oskera) [1841511]
- [netdrv] r8169: use macro FIELD_SIZEOF in definition of FW_OPCODE_SIZE (Josef Oskera) [1841511]
- [netdrv] r8169: change mdelay to msleep in rtl_fw_write_firmware (Josef Oskera) [1841511]
- [netdrv] r8169: load firmware for RTL8168fp/RTL8117 (Josef Oskera) [1841511]
- [netdrv] r8169: improve conditional firmware loading for RTL8168d (Josef Oskera) [1841511]
- [netdrv] r8169: use r8168d_modify_extpage in rtl8168f_config_eee_phy (Josef Oskera) [1841511]
- [netdrv] r8169: add support for RTL8117 (Josef Oskera) [1841511]
- [netdrv] r8169: respect EEE user setting when restarting network (Josef Oskera) [1841511]
- [netdrv] r8169: remove rtl8168c_4_hw_phy_config (Josef Oskera) [1841511]
- [netdrv] r8169: add helper r8168d_modify_extpage (Josef Oskera) [1841511]
- [netdrv] r8169: switch to phylib functions in more places (Josef Oskera) [1841511]
- [netdrv] r8169: add helper r8168d_phy_param (Josef Oskera) [1841511]
- [netdrv] r8169: add helper r8168g_phy_param (Josef Oskera) [1841511]
- [netdrv] r8169: fix page read in r8168g_mdio_read (Josef Oskera) [1841511]
- [netdrv] r8169: fix wrong PHY ID issue with RTL8168dp (Josef Oskera) [1841511]
- [netdrv] r8169: use helper rtl_hw_aspm_clkreq_enable also in rtl_hw_start_8168g_2 (Josef Oskera) [1841511]
- [netdrv] r8169: improve rtl8169_rx_fill (Josef Oskera) [1841511]
- [netdrv] r8169: align fix_features callback with vendor driver (Josef Oskera) [1841511]
- [netdrv] r8169: never set PCI_EXP_DEVCTL_NOSNOOP_EN (Josef Oskera) [1841511]
- [netdrv] r8169: remove rtl_hw_start_8168bef (Josef Oskera) [1841511]
- [netdrv] r8169: remove rtl_hw_start_8168dp (Josef Oskera) [1841511]
- [netdrv] r8169: simplify setting PCI_EXP_DEVCTL_NOSNOOP_EN (Josef Oskera) [1841511]
- [netdrv] r8169: remove fiddling with the PCIe max read request size (Josef Oskera) [1841511]
- [netdrv] r8169: fix jumbo packet handling on resume from suspend (Josef Oskera) [1841511]
- [netdrv] r8169: don't set bit RxVlan on RTL8125 (Josef Oskera) [1841511]
- [netdrv] r8169: add support for EEE on RTL8125 (Josef Oskera) [1841511]
- [netdrv] r8169: add RTL8125 PHY initialization (Josef Oskera) [1841511]
- [netdrv] r8169: add support for RTL8125 (Josef Oskera) [1841511]
- [netdrv] r8169: don't use bit LastFrag in tx descriptor after send (Josef Oskera) [1841511]
- [netdrv] r8169: read common register for PCI commit (Josef Oskera) [1841511]
- [netdrv] r8169: move disabling interrupt coalescing to RTL8169/RTL8168 init (Josef Oskera) [1841511]
- [netdrv] r8169: factor out reading MAC address from registers (Josef Oskera) [1841511]
- [netdrv] r8169: restrict rtl_is_8168evl_up to RTL8168 chip versions (Josef Oskera) [1841511]
- [netdrv] r8169: change interrupt mask type to u32 (Josef Oskera) [1841511]
- [netdrv] r8169: improve DMA handling in rtl_rx (Josef Oskera) [1841511]
- [netdrv] r8169: fix DMA issue on MIPS platform (Josef Oskera) [1841511]
- [netdrv] r8169: sync EEE handling for RTL8168h with vendor driver (Josef Oskera) [1841511]
- [netdrv] r8169: use the generic EEE management functions (Josef Oskera) [1841511]
- [fs] gfs2: Even more gfs2_find_jhead fixes (Abhijith Das) [1828653]
- [kernel] sched/fair: Don't NUMA balance for kthreads (Phil Auld) [1842543]
- [kernel] sched/core: Offload wakee task activation if it the wakee is descheduling (Phil Auld) [1842543]
- [kernel] sched/core: Optimize ttwu() spinning on p->on_cpu (Phil Auld) [1842543]
- [fs] gfs2: Smarter iopen glock waiting (Andreas Grunbacher) [1582655]
- [fs] gfs2: Wake up when setting GLF_DEMOTE (Andreas Grunbacher) [1582655]
- [fs] gfs2: Check inode generation number in delete_work_func (Andreas Grunbacher) [1582655]
- [fs] gfs2: Move inode generation number check into gfs2_inode_lookup (Andreas Grunbacher) [1582655]
- [fs] gfs2: Minor gfs2_lookup_by_inum cleanup (Andreas Grunbacher) [1582655]
- [fs] gfs2: Try harder to delete inodes locally (Andreas Grunbacher) [1582655]
- [fs] gfs2: Give up the iopen glock on contention (Andreas Grunbacher) [1582655]
- [fs] gfs2: Turn gl_delete into a delayed work (Andreas Grunbacher) [1582655]
- [fs] gfs2: Keep track of deleted inode generations in LVBs (Andreas Grunbacher) [1582655]
- [fs] gfs2: Allow ASPACE glocks to also have an lvb (Andreas Grunbacher) [1582655]
- [fs] gfs2: Avoid access time thrashing in gfs2_inode_lookup (Andreas Grunbacher) [1582655]
- [fs] gfs2: Use IS_ERR_OR_NULL (Andreas Grunbacher) [1582655]
- [fpga] fpga: mark the intel fpga drivers as tech preview (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [firmware] firmware: stratix10-svc: Remove unneeded semicolon (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [firmware] firmware: Fix incompatible function behavior for RSU driver (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [firmware] firmware: add Intel Stratix10 remote system update driver (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [include] firmware: stratix10-svc: extend svc to support new RSU features (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [edac] EDAC/altera, firmware/intel: Add Stratix10 ECC DBE SMC call (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [firmware] firmware: stratix10-svc: fix wrong of_node_put() in init function (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [include] firmware: add remote status update client support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [firmware] firmware: add Intel Stratix10 service layer driver (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: pci: fix return value of cci_pci_sriov_configure (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: xilinx-pr-decoupler: Remove clk_get error message for probe defer (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: remove redundant dev_err message (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: remove set but not used variable 'afu' (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: remove set but not used variable 'fme' (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add power management support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add thermal management support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [documentation] Documentation: fpga: dfl: add descriptions for thermal/power management interfaces (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: Remove dev_err() usage after platform_get_irq() (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [documentation] Documentation: fpga: dfl: add descriptions for virtualization and new interfaces (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add global error reporting support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add STP (SignalTap) support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add error reporting support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: expose __afu_port_enable/disable function (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add userclock sysfs interfaces (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: convert platform_driver to use dev_groups (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: convert platform_driver to use dev_groups (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: make init callback optional (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: Add Stratix10 (V2) Support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: Preparation for V2 parts (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: Discover Vendor Specific offset (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-ps-spi: Fix getting of optional confd gpio (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add capability sysfs interfaces (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: make uinit callback optional (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add id_table for dfl private feature driver (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add AFU state related sysfs interfaces (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: pci: enable SRIOV support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add DFL_FPGA_FME_PORT_RELEASE/ASSIGN ioctl support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: use driver core functions, not sysfs ones (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-pr-ip: Make alt_pr_unregister function void (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: Fix function definition argument (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga-manager: altera-ps-spi: Fix build error (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: align PR buffer size per PR datawidth (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: remove copy_to_user() in ioctl for PR (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl-fme-mgr: fix FME_PR_INTFC_ID register address (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] drivers: fpga: Kconfig: pedantic cleanups (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [documentation] docs: fpga: convert docs to ReST and rename to *.rst (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 422 (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 285 (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: zynqmp-fpga: Correctly handle error pointer (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [include] include: fpga: adi-axi-common.h: add common regs & defs header (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: expand minor range when registering chrdev region (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: Add lockdep classes for pdata->lock (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: Pass the correct device to dma_mapping_error() (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: stratix10-soc: fix use-after-free on s10_init() (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] treewide: Add SPDX license identifier - Makefile/Kconfig (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] mm/gup: change GUP fast to use flags rather than a write 'bool' (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga manager: Adding FPGA Manager support for Xilinx zynqmp (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera_freeze_bridge: remove restriction to socfpga (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: mgr: altera-ps-spi: make array dummy static, shrinks object size (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: stratix10-soc: fix wrong of_node_put() in init function (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] Remove 'type' argument from access_ok() function (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: of-fpga-region: Use platform_set_drvdata (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl-fme-region: Use platform_get_drvdata() (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: add intel stratix10 soc fpga manager driver (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: mgr: altera-ps-spi: enable usage on non-dt platforms (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: fix probing for multiple FPGAs on the bus (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] zynq-fpga: Only route PR via PCAP when required (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: Fix registration for CvP incapable devices (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: remove set but not used variable 'priv' (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: altera-cvp: fix 'bad IO access' on x86_64 (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: add devm_fpga_region_create (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: bridge: add devm_fpga_bridge_create (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: mgr: add devm_fpga_mgr_create (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [documentation] docs: fpga: document fpga manager flags (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: bridge: fix obvious function documentation error (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: do not access region struct after fpga_region_unregister (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] drivers: fpga: fix two trivial spelling mistakes (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: fix return value check in in pr_mgmt_init() (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add DFL_FPGA_PORT_DMA_MAP/UNMAP ioctls support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add afu sub feature support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add DFL_FPGA_GET_API_VERSION/CHECK_EXTENSION ioctls support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add header sub feature support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: afu: add port ops support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add FPGA Accelerated Function Unit driver basic framework (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme-region: add support for compat_id (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add fpga region platform driver for FME (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add fpga bridge platform driver for FME (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme-mgr: add compat_id support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add fpga manager platform driver for FME (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add partial reconfiguration sub feature support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add DFL_FPGA_GET_API_VERSION/CHECK_EXTENSION ioctls support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: fme: add header sub feature support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add FPGA Management Engine driver basic framework (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl-pci: add enumeration for feature devices (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: add FPGA DFL PCIe device driver (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add dfl_fpga_check_port_id function (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add dfl_fpga_port_ops support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add feature device infrastructure (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add dfl_fpga_cdev_find_port (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: dfl: add chardev support for feature devices (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: add device feature list support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: region: add compat_id support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [include] fpga: mgr: add compat_id support (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [fpga] fpga: mgr: add status for fpga-manager (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [include] fpga: mgr: add region_id to fpga_image_info (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [documentation] docs: fpga: add a document for FPGA Device Feature List (DFL) Framework Overview (Luis Goncalves) [1689274 1660310 1494701 1494699]
- [mm] mm: Add a vmf_insert_mixed_prot() function (Dave Airlie) [1838335]
- [mm] mm: Add write-protect and clean utilities for address space ranges (Dave Airlie) [1838335]
- [mm] mm: Add a walk_page_mapping() function to the pagewalk code (Dave Airlie) [1838335]
- [mm] pagewalk: separate function pointers from iterator data (Dave Airlie) [1838335]
- [mm] mm: split out a new pagewalk.h header from mm.h (Dave Airlie) [1838335]
- [mm] mm: update ptep_modify_prot_commit to take old pte value as arg (Dave Airlie) [1838335]
- [x86] mm: update ptep_modify_prot_start/commit to take vm_area_struct as arg (Dave Airlie) [1838335]
- [mm] mm/mmu_notifier: add an interval tree notifier (Dave Airlie) [1838335]
- [mm] mm/mmu_notifier: define the header pre-processor parts even if disabled (Dave Airlie) [1838335]
- [mm] mm/mmu_notifiers: add a lockdep map for invalidate_range_start/end (Dave Airlie) [1838335]
- [misc] misc/sgi-gru: use mmu_notifier_get/put for struct gru_mm_struct (Dave Airlie) [1838335]
- [drm] drm/backport: add mmu notifier get/put support to drm backport (Dave Airlie) [1838335]
- [mm] mm/mmu_notifiers: add a get/put scheme for the registration (Dave Airlie) [1838335]
- [mm] mm/mmu_notifiers: do not speculatively allocate a mmu_notifier_mm (Dave Airlie) [1838335]
- [mm] mm/mmu_notifiers: hoist do_mmu_notifier_register down_write to the caller (Dave Airlie) [1838335]
- [mm] mm/mmu_notifier.c: remove mmu_notifier_synchronize() (Dave Airlie) [1838335]
- [infiniband] locking/lockdep: Rename lockdep_assert_held_exclusive() -> lockdep_assert_held_write() (Dave Airlie) [1838335]
- [include] mm/mmu_notifier: contextual information for event enums (Dave Airlie) [1838335]
- [mm] mm/memory_hotplug.c: only respect mem= parameter during boot stage (Baoquan He) [1838809 1781472]
- [scsi] scsi: mpt3sas: Remove unused including <linux/version.h> (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Fix double free warnings (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Disable DIF when prot_mask set to zero (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Capture IOC data for debugging purposes (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Use true, false for ioc->use_32bit_dma (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Remove NULL check before freeing function (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Update mpt3sas version to 33.101.00.00 (Tomas Henzl) [1790760]
- [scsi] mpt3sas: Fix memset in non-rdpq mode (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Fix reply queue count in non RDPQ mode (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Handle RDPQ DMA allocation in same 4G region (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Separate out RDPQ allocation to new function (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Rename function name is_MSB_are_same (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Don't change the DMA coherent mask after allocations (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: use true, false for bool variables (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Fix kernel panic observed on soft HBA unplug (Tomas Henzl) [1790760]
- [scsi] scsi: Replace zero-length array with flexible-array member (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Update drive version to 33.100.00.00 (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Remove usage of device_busy counter (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Print function name in which cmd timed out (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Optimize mpt3sas driver logging (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: print in which path firmware fault occurred (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Handle CoreDump state from watchdog thread (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Add support IOCs new state named COREDUMP (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: renamed _base_after_reset_handler function (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Add support for NVMe shutdown (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Update MPI Headers to v02.00.57 (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Fix double free in attach error handling (Tomas Henzl) [1790760]
- [scsi] scsi: mpt3sas: Clean up some indenting (Tomas Henzl) [1790760]
- [crypto] crypto: af_alg - cast ki_complete ternary op to int (Herbert Xu) [1837499]
- [netdrv] virtio-net: per-queue RPS config (Eugenio Perez) [1718086]
- [netdrv] virtio_net: Differentiate sk_buff and xdp_frame on freeing (Eugenio Perez) [1718086]
- [netdrv] virtio_net: Use xdp_return_frame to free xdp_frames on destroying vqs (Eugenio Perez) [1718086]
- [netdrv] virtio_net: enable napi_tx by default (Eugenio Perez) [1718086]
- [netdrv] virtio_net: Don't call free_old_xmit_skbs for xdp_frames (Eugenio Perez) [1718086]
- [netdrv] virtio_net: Don't enable NAPI when interface is down (Eugenio Perez) [1718086]
- [include] cpumask: make cpumask_next_wrap available without smp (Eugenio Perez) [1718086]
- [netdrv] virtio_net: Stripe queue affinities across cores (Eugenio Perez) [1718086]
- [virtio] virtio: Make vp_set_vq_affinity() take a mask (Eugenio Perez) [1718086]

* Thu Jun 04 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-211.el8]
- [netdrv] ice: add board identifier info to devlink .info_get (Jonathan Toppins) [1796682]
- [netdrv] ice: add basic handler for devlink .info_get (Jonathan Toppins) [1796682]
- [netdrv] ice: enable initial devlink support (Jonathan Toppins) [1796682]
- [netdrv] ice: implement full NVM read from ETHTOOL_GEEPROM (Jonathan Toppins) [1796682]
- [netdrv] ice: discover and store size of available flash (Jonathan Toppins) [1796682]
- [netdrv] ice: store NVM version info in extracted format (Jonathan Toppins) [1796682]
- [netdrv] ice: create function to read a section of the NVM and Shadow RAM (Jonathan Toppins) [1796682]
- [netdrv] ice: use __le16 types for explicitly Little Endian values (Jonathan Toppins) [1796682]
- [netdrv] ice: fix incorrect size description of ice_get_nvm_version (Jonathan Toppins) [1781388]
- [netdrv] ice: use variable name more descriptive than type (Jonathan Toppins) [1781388]
- [netdrv] ice: Use EOPNOTSUPP instead of ENOTSUPP (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix format specifier (Jonathan Toppins) [1781388]
- [netdrv] ice: fix use of deprecated strlcpy() (Jonathan Toppins) [1781388]
- [netdrv] ice: Increase mailbox receive queue length to maximum (Jonathan Toppins) [1781388]
- [netdrv] ice: Correct setting VLAN pruning (Jonathan Toppins) [1781388]
- [netdrv] ice: renegotiate link after FW DCB on (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix corner case when switching from IEEE to CEE (Jonathan Toppins) [1781388]
- [netdrv] ice: Display Link detected via Ethtool in safe mode (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix removing driver while bare-metal VFs pass traffic (Jonathan Toppins) [1781388]
- [netdrv] ice: Improve clarity of prints and variables (Jonathan Toppins) [1781388]
- [netdrv] ice: allow bigger VFs (Jonathan Toppins) [1781388]
- [netdrv] ice: Cleanup unneeded parenthesis (Jonathan Toppins) [1781388]
- [netdrv] ice: Use pci_get_dsn() (Jonathan Toppins) [1781388]
- [netdrv] ice: let core reject the unsupported coalescing parameters (Jonathan Toppins) [1781388]
- [netdrv] ice: fix define for E822 backplane device (Jonathan Toppins) [1781388]
- [netdrv] ice: add support for E823 devices (Jonathan Toppins) [1795812]
- [netdrv] ice: add backslash-n to strings (Jonathan Toppins) [1781388]
- [netdrv] ice: increase PF reset wait timeout to 300 milliseconds (Jonathan Toppins) [1781388]
- [netdrv] ice: Support XDP UMEM wake up mechanism (Jonathan Toppins) [1781388]
- [netdrv] ice: SW DCB, report correct max TC value (Jonathan Toppins) [1781388]
- [netdrv] ice: Report correct DCB mode (Jonathan Toppins) [1781388]
- [netdrv] ice: Add DCBNL ops required to configure ETS in CEE for SW DCB (Jonathan Toppins) [1781388]
- [netdrv] ice: Always clear the QRXFLXP_CNTXT register for VF Rx queues (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix for TCAM entry management (Jonathan Toppins) [1781388]
- [netdrv] ice: update malicious driver detection event handling (Jonathan Toppins) [1781388]
- [netdrv] ice: Validate config for SW DCB map (Jonathan Toppins) [1781388]
- [netdrv] ice: Wait for VF to be reset/ready before configuration (Jonathan Toppins) [1792691]
- [netdrv] ice: Don't reject odd values of usecs set by user (Jonathan Toppins) [1781388]
- [netdrv] ice: use true/false for bool types (Jonathan Toppins) [1781388]
- [netdrv] ice: add function argument description to function header comment (Jonathan Toppins) [1781388]
- [netdrv] ice: use proper format for function pointer as a function parameter (Jonathan Toppins) [1781388]
- [netdrv] ice: remove unnecessary fallthrough comments (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix virtchnl_queue_select bitmap validation (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix and refactor Rx queue disable for VFs (Jonathan Toppins) [1781388]
- [netdrv] ice: Handle LAN overflow event for VF queues (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix implicit queue mapping mode in ice_vsi_get_qs (Jonathan Toppins) [1781388]
- [netdrv] ice: Add support to enable/disable all Rx queues before waiting (Jonathan Toppins) [1781388]
- [netdrv] ice: Only allow tagged bcast/mcast traffic for VF in port VLAN (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix Port VLAN priority bits (Jonathan Toppins) [1781388]
- [netdrv] ice: Add helper to determine if VF link is up (Jonathan Toppins) [1781388]
- [netdrv] ice: Refactor port vlan configuration for the VF (Jonathan Toppins) [1781388]
- [netdrv] ice: Add initial support for QinQ (Jonathan Toppins) [1781388]
- [netdrv] ice: Trivial fixes (Jonathan Toppins) [1781388]
- [netdrv] ice: Use correct netif error function (Jonathan Toppins) [1781388]
- [netdrv] ice: Cleanup ice_vsi_alloc_q_vectors (Jonathan Toppins) [1781388]
- [netdrv] ice: Make print statements more compact (Jonathan Toppins) [1781388]
- [netdrv] ice: Use ice_pf_to_dev (Jonathan Toppins) [1781388]
- [netdrv] ice: Remove possible null dereference (Jonathan Toppins) [1781388]
- [netdrv] ice: update Unit Load Status bitmask to check after reset (Jonathan Toppins) [1781388]
- [netdrv] ice: fix and consolidate logging of NVM/firmware version information (Jonathan Toppins) [1781388]
- [netdrv] ice: Modify link message logging (Jonathan Toppins) [1781388]
- [netdrv] ice: Remove CONFIG_PCI_IOV wrap in ice_set_pf_caps (Jonathan Toppins) [1781388]
- [netdrv] ice: Remove ice_dev_onetime_setup() (Jonathan Toppins) [1781388]
- [netdrv] ice: Don't allow same value for Rx tail to be written twice (Jonathan Toppins) [1781388]
- [netdrv] ice: display supported and advertised link modes (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix switch between FW and SW LLDP (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix DCB rebuild after reset (Jonathan Toppins) [1781388]
- [netdrv] ice: Bump version (Jonathan Toppins) [1781401]
- [netdrv] ice: Implement ethtool get/set rx-flow-hash (Jonathan Toppins) [1781401]
- [netdrv] ice: Initilialize VF RSS tables (Jonathan Toppins) [1781401]
- [netdrv] ice: Optimize table usage (Jonathan Toppins) [1781401]
- [netdrv] ice: Enable writing filtering tables (Jonathan Toppins) [1781401]
- [netdrv] ice: Populate TCAM filter software structures (Jonathan Toppins) [1781401]
- [netdrv] ice: Allocate flow profile (Jonathan Toppins) [1781401]
- [netdrv] ice: Enable writing hardware filtering tables (Jonathan Toppins) [1781401]
- [netdrv] ice: remove redundant assignment to variable xmit_done (Jonathan Toppins) [1781388]
- [netdrv] ice: Removing hung_queue variable to use txqueue function parameter (Jonathan Toppins) [1781388]
- [netdrv] ice: Add device ids for E822 devices (Jonathan Toppins) [1781951]
- [netdrv] ice: Suppress Coverity warnings for xdp_rxq_info_reg (Jonathan Toppins) [1781388]
- [netdrv] ice: Add a boundary check in ice_xsk_umem() (Jonathan Toppins) [1781388]
- [netdrv] ice: add extra check for null Rx descriptor (Jonathan Toppins) [1781388]
- [netdrv] ice: suppress checked_return error (Jonathan Toppins) [1781388]
- [netdrv] ice: Demote MTU change print to debug (Jonathan Toppins) [1781388]
- [netdrv] ice: Enable ip link show on the PF to display VF unicast MAC(s) (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix VF link state when it's IFLA_VF_LINK_STATE_AUTO (Jonathan Toppins) [1781388]
- [netdrv] ice: Remove Rx flex descriptor programming (Jonathan Toppins) [1781388]
- [netdrv] ice: Return error on not supported ethtool -C parameters (Jonathan Toppins) [1781388]
- [netdrv] ice: Restore interrupt throttle settings after VSI rebuild (Jonathan Toppins) [1781388]
- [netdrv] ice: Set default value for ITR in alloc function (Jonathan Toppins) [1781388]
- [netdrv] ice: Add ice_for_each_vf() macro (Jonathan Toppins) [1781388]
- [netdrv] ice: Add code to keep track of current dflt_vsi (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix VF spoofchk (Jonathan Toppins) [1781388]
- [netdrv] ice: Support UDP segmentation offload (Jonathan Toppins) [1781388]
- [netdrv] ice: Update FW API minor version (Jonathan Toppins) [1781388]
- [netdrv] ice: remove pointless NULL check of port_info (Jonathan Toppins) [1781388]
- [netdrv] ice: Implement ethtool ops for channels (Jonathan Toppins) [1781388]
- [netdrv] ice: implement VF stats NDO (Jonathan Toppins) [1781388]
- [netdrv] ice: add helpers for virtchnl (Jonathan Toppins) [1781388]
- [netdrv] ice: Add ice_pf_to_dev(pf) macro (Jonathan Toppins) [1781388]
- [netdrv] ice: Do not use devm* functions for local uses (Jonathan Toppins) [1781388]
- [netdrv] ice: Refactor removal of VLAN promiscuous rules (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix setting coalesce to handle DCB configuration (Jonathan Toppins) [1781388]
- [netdrv] ice: Only disable VF state when freeing each VF resources (Jonathan Toppins) [1781388]
- [netdrv] ice: fix stack leakage (Jonathan Toppins) [1781388]
- [netdrv] ice: Don't modify stripping for add/del VLANs on VF (Jonathan Toppins) [1781388]
- [netdrv] ice: Disallow VF VLAN opcodes if VLAN offloads disabled (Jonathan Toppins) [1781388]
- [netdrv] ice: Correct capabilities reporting of max TCs (Jonathan Toppins) [1781388]
- [netdrv] ice: Store number of functions for the device (Jonathan Toppins) [1781388]
- [netdrv] ice: fix potential infinite loop because loop counter being too small (Jonathan Toppins) [1781388]
- [netdrv] ice: print opcode when printing controlq errors (Jonathan Toppins) [1781388]
- [netdrv] ice: use more accurate ICE_DBG mask types (Jonathan Toppins) [1781388]
- [netdrv] ice: Introduce and use ice_vsi_type_str (Jonathan Toppins) [1781388]
- [netdrv] ice: remove unnecessary conditional check (Jonathan Toppins) [1781388]
- [netdrv] ice: Update enum ice_flg64_bits to current specification (Jonathan Toppins) [1781388]
- [netdrv] ice: delay less (Jonathan Toppins) [1781388]
- [netdrv] ice: use pkg_dwnld_status instead of sq_last_status (Jonathan Toppins) [1781388]
- [netdrv] ice: Change max MSI-x vector_id check in cfg_irq_map (Jonathan Toppins) [1781388]
- [netdrv] ice: Check if VF is disabled for Opcode and other operations (Jonathan Toppins) [1781388]
- [netdrv] ice: configure software LLDP in ice_init_pf_dcb (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix to change Rx/Tx ring descriptor size via ethtool with DCBx (Jonathan Toppins) [1781388]
- [netdrv] ice: avoid setting features during reset (Jonathan Toppins) [1781388]
- [netdrv] ice: Implement DCBNL support (Jonathan Toppins) [1781388]
- [netdrv] ice: Add NDO callback to set the maximum per-queue bitrate (Jonathan Toppins) [1781388]
- [netdrv] ice: Use ice_ena_vsi and ice_dis_vsi in DCB configuration flow (Jonathan Toppins) [1781388]
- [netdrv] ice: Fix return value when SR-IOV is not supported (Jonathan Toppins) [1781388]
- [netdrv] ice: Rename VF function ice_vc_dis_vf to match its behavior (Jonathan Toppins) [1781388]
- [netdrv] ice: Get rid of ice_cleanup_header (Jonathan Toppins) [1781388]
- [netdrv] ice: print PCI link speed and width (Jonathan Toppins) [1781388]
- [netdrv] ice: print unsupported module message (Jonathan Toppins) [1781388]
- [netdrv] ice: write register with correct offset (Jonathan Toppins) [1781388]
- [netdrv] ice: Check for null pointer dereference when setting rings (Jonathan Toppins) [1781388]
- [netdrv] ice: save PCI state in probe (Jonathan Toppins) [1781388]
- [netdrv] ice: Adjust DCB INIT for SW mode (Jonathan Toppins) [1781388]
- [netdrv] ice: fix driver unload flow (Jonathan Toppins) [1781388]
- [netdrv] ice: handle DCBx non-contiguous TC request (Jonathan Toppins) [1781388]
- [netdrv] ice: Update Boot Configuration Section read of NVM (Jonathan Toppins) [1781388]
- [netdrv] ice: add ethtool -m support for reading i2c eeprom modules (Jonathan Toppins) [1781388]
- [netdrv] ice: allow 3k MTU for XDP (Jonathan Toppins) [1781388]
- [netdrv] ice: add build_skb() support (Jonathan Toppins) [1781388]
- [netdrv] ice: introduce frame padding computation logic (Jonathan Toppins) [1781388]
- [netdrv] ice: introduce legacy Rx flag (Jonathan Toppins) [1781388]
- [netdrv] ice: Add support for AF_XDP (Jonathan Toppins) [1730487]
- [netdrv] ice: Move common functions to ice_txrx_lib.c (Jonathan Toppins) [1781388]
- [netdrv] ice: Add support for XDP (Jonathan Toppins) [1730487]
- [netdrv] ice: get rid of per-tc flow in Tx queue configuration routines (Jonathan Toppins) [1781388]
- [netdrv] ice: Introduce ice_base.c (Jonathan Toppins) [1781388]
- [netdrv] net:Use skb accessors in network drivers (Jonathan Toppins) [1781388]
- [powerpc] powerpc/eeh: Remove eeh_add_device_tree_late() (Myron Stowe) [1840904]
- [powerpc] powerpc/eeh: Add sysfs files in late probe (Myron Stowe) [1840904]
- [powerpc] powerpc: Drop using struct of_pci_range.pci_space field (Myron Stowe) [1840904]
- [powerpc] powerpc/pci: Fold pcibios_setup_device() into pcibios_bus_add_device() (Myron Stowe) [1840904]
- [powerpc] powerpc/pci: Remove pcibios_setup_bus_devices() (Myron Stowe) [1840904]
- [powerpc] powerpc/pci: Fix pcibios_setup_device() ordering (Myron Stowe) [1840904]
- [powerpc] powerpc/pci: Remove legacy debug code (Myron Stowe) [1840904]
- [x86] x86/microcode/AMD: Increase microcode PATCH_MAX_SIZE (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Make stub function static inline (David Arcari) [1826966]
- [x86] x86/microcode/intel: Issue the revision updated message only on the BSP (David Arcari) [1826966]
- [x86] x86/microcode: Update late microcode in parallel (David Arcari) [1826966]
- [x86] x86/microcode/amd: Fix two -Wunused-but-set-variable warnings (David Arcari) [1826966]
- [x86] x86/microcode: Fix the microcode load on CPU hotplug for real (David Arcari) [1826966]
- [x86] x86/microcode, cpuhotplug: Add a microcode loader CPU hotplug callback (David Arcari) [1826966]
- [x86] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 353 (David Arcari) [1826966]
- [x86] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (David Arcari) [1826966]
- [x86] treewide: Add SPDX license identifier - Makefile/Kconfig (David Arcari) [1826966]
- [x86] x86/microcode: Fix the ancient deprecated microcode loading method (David Arcari) [1826966]
- [x86] x86/microcode/intel: Refactor Intel microcode blob loading (David Arcari) [1826966]
- [x86] x86/microcode: Announce reload operation's completion (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Update copyright (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Check the equivalence table size when scanning it (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Convert CPU equivalence table variable into a struct (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Check microcode container data in the late loader (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Fix container size's type (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Convert early parser to the new verification routines (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Change verify_patch()'s return value (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Move chipset-specific check into verify_patch() (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Move patch family check to verify_patch() (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Simplify patch family detection (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Concentrate patch verification (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Cleanup verify_patch_size() more (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Clean up per-family patch size checks (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Move verify_patch_size() up in the file (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Add microcode container verification (David Arcari) [1826966]
- [x86] x86/microcode/AMD: Subtract SECTION_HDR_SIZE from file leftover length (David Arcari) [1826966]
- [x86] x86/microcode: Make revision and processor flags world-readable (David Arcari) [1826966]
- [pci] PCI: Add pci_status_get_and_clear_errors (Josef Oskera) [1840535]
- [pci] PCI: Add constant PCI_STATUS_ERROR_BITS (Josef Oskera) [1840535]
- [arm64] arm64: dts: ls1046ardb: set RGMII interfaces to RGMII_ID mode (Petr Oros) [1816982]
- [arm64] arm64: dts: ls1043a-rdb: correct RGMII delay mode to rgmii-id (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: Fix pause frame negotiation (Petr Oros) [1816982]
- [netdrv] net: phy: propagate an error back to the callers of phy_sfp_probe (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: fix clock sink configuration on ATH8030 and ATH8035 (Petr Oros) [1816982]
- [netdrv] r8169: fix resume on cable plug-in (Petr Oros) [1816982]
- [documentation] dt-bindings: net: remove un-implemented property (Petr Oros) [1816982]
- [netdrv] net: phy: mdio-bcm-unimac: Fix clock handling (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: w/a for fld detect threshold bootstrapping issue (Petr Oros) [1816982]
- [netdrv] net: phy: sfp-bus.c: get rid of docs warnings (Petr Oros) [1816982]
- [netdrv] net: phy: mdio-mux-bcm-iproc: check clk_prepare_enable() return value (Petr Oros) [1816982]
- [netdrv] net: phy: fix MDIO bus PM PHY resuming (Petr Oros) [1816982]
- [of] drivers/of/of_mdio.c:fix of_mdiobus_register() (Petr Oros) [1816982]
- [netdrv] net: phy: bcm63xx: fix OOPS due to missing driver name (Petr Oros) [1816982]
- [netdrv] phylink: Improve error message when validate failed (Petr Oros) [1816982]
- [netdrv] net: phy: avoid clearing PHY interrupts twice in irq handler (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: don't interpret PHY status unless resolved (Petr Oros) [1816982]
- [netdrv] net: phy: mscc: fix firmware paths (Petr Oros) [1816982]
- [netdrv] net: phy: corrected the return value for genphy_check_and_restart_aneg and genphy_c45_check_and_restart_aneg (Petr Oros) [1816982]
- [documentation] docs: networking: phy: Rephrase paragraph for clarity (Petr Oros) [1816982]
- [netdrv] net: phy: Avoid multiple suspends (Petr Oros) [1816982]
- [netdrv] net: phy: broadcom: Fix a typo ("firsly") (Petr Oros) [1816982]
- [netdrv] net: phy: restore mdio regs in the iproc mdio driver (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: disable vddio regulator (Petr Oros) [1816982]
- [netdrv] net: mii_timestamper: fix static allocation by PHY driver (Petr Oros) [1816982]
- [of] net: mdio: of: fix potential NULL pointer derefernce (Petr Oros) [1816982]
- [netdrv] net: phy: add default ARCH_BCM_IPROC for MDIO_BCM_IPROC (Petr Oros) [1816982]
- [netdrv] net: phy: DP83822: Add support for additional DP83825 devices (Petr Oros) [1816982]
- [netdrv] phy: dp83826: Add phy IDs for DP83826N and 826NC (Petr Oros) [1816982]
- [netdrv] net: phy: add new version of phy_do_ioctl (Petr Oros) [1816982]
- [netdrv] net: phy: rename phy_do_ioctl to phy_do_ioctl_running (Petr Oros) [1816982]
- [netdrv] r8169: use generic ndo_do_ioctl handler phy_do_ioctl (Petr Oros) [1816982]
- [netdrv] net: phy: add generic ndo_do_ioctl handler phy_do_ioctl (Petr Oros) [1816982]
- [netdrv] net: phylink: allow in-band AN for USXGMII (Petr Oros) [1816982]
- [netdrv] net: phy: adin: fix a warning about msleep (Petr Oros) [1816982]
- [netdrv] net: phy: don't crash in phy_read/_write_mmd without a PHY driver (Petr Oros) [1816982]
- [netdrv] net: phylink: Allow 2.5BASE-T, 5GBASE-T and 10GBASE-T for the 10G link modes (Petr Oros) [1816982]
- [netdrv] net: phy: adin: const-ify static data (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Set FORCE_LINK_GOOD to default after reset (Petr Oros) [1816982]
- [netdrv] net: phy: Maintain MDIO device and bus statistics (Petr Oros) [1816982]
- [powerpc] powerpc: Add const qual to local_read() parameter (Petr Oros) [1816982]
- [include] u64_stats: provide u64_stats_t type (Petr Oros) [1816982]
- [documentation] Documentation: net-sysfs: Remove duplicate PHY device documentation (Petr Oros) [1816982]
- [netdrv] mdio_bus: Simplify reset handling and extend to non-DT systems (Petr Oros) [1816982]
- [netdrv] net: phy: Added IRQ print to phylink_bringup_phy() (Petr Oros) [1816982]
- [netdrv] net: phy: DP83822: Update Kconfig with DP83825I support (Petr Oros) [1816982]
- [netdrv] net: phy: DP83TC811: Fix typo in Kconfig (Petr Oros) [1816982]
- [netdrv] net: phylink: add support for polling MAC PCS (Petr Oros) [1816982]
- [netdrv] net: phylink: make QSGMII a valid PHY mode for in-band AN (Petr Oros) [1816982]
- [uapi] mii: Add helpers for parsing SGMII auto-negotiation (Petr Oros) [1816982]
- [netdrv] net: phylink: fix failure to register on x86 systems (Petr Oros) [1816982]
- [netdrv] net: phy: fixed_phy: switch to using fwnode_gpiod_get_index (Petr Oros) [1816982]
- [netdrv] net: phy: fixed_phy: fix use-after-free when checking link GPIO (Petr Oros) [1816982]
- [netdrv] net: phylink: switch to using fwnode_gpiod_get_index() (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: add support for configuring the RX delay on RTL8211F (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: add logging for the RGMII TX delay configuration (Petr Oros) [1816982]
- [netdrv] net: mdio: of: Register discovered MII time stampers (Petr Oros) [1816982]
- [documentation] dt-bindings: ptp: Introduce MII time stamping devices (Petr Oros) [1816982]
- [netdrv] net: Add a layer for non-PHY MII time stamping drivers (Petr Oros) [1816982]
- [netdrv] net: Introduce a new MII time stamping interface (Petr Oros) [1816982]
- [netdrv] net: phy: dp83640: Move the probe and remove methods around (Petr Oros) [1816982]
- [netdrv] net: netcp_ethss: Use the PHY time stamping interface (Petr Oros) [1816982]
- [net] net: ethtool: Use the PHY time stamping interface (Petr Oros) [1816982]
- [net] net: vlan: Use the PHY time stamping interface (Petr Oros) [1816982]
- [netdrv] net: macvlan: Use the PHY time stamping interface (Petr Oros) [1816982]
- [include] net: phy: Introduce helper functions for time stamping support (Petr Oros) [1816982]
- [include] of: mdio: Add missing inline to of_mdiobus_child_is_phy() dummy (Petr Oros) [1816982]
- [netdrv] net: phy: aquantia: add suspend / resume ops for AQR105 (Petr Oros) [1816982]
- [netdrv] net: phy: ensure that phy IDs are correctly typed (Petr Oros) [1816982]
- [include] mod_devicetable: fix PHY module format (Petr Oros) [1816982]
- [of] of: mdio: export of_mdiobus_child_is_phy (Petr Oros) [1816982]
- [netdrv] net: sfp: report error on failure to read sfp soft status (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: use genphy_check_and_restart_aneg() (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: use phy_modify_changed() (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: use existing clause 37 definitions (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: consolidate phy status reading (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: use positive logic for link state (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: initialise link partner state earlier (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: rearrange to use genphy_read_lpa() (Petr Oros) [1816982]
- [netdrv] net: phy: provide and use genphy_read_status_fixed() (Petr Oros) [1816982]
- [netdrv] net: phy: add genphy_check_and_restart_aneg() (Petr Oros) [1816982]
- [netdrv] net: phy: use phy_resolve_aneg_pause() (Petr Oros) [1816982]
- [netdrv] net: phy: remove redundant .aneg_done initialisers (Petr Oros) [1816982]
- [netdrv] net: phy: dp83869: Remove unneeded semicolon (Petr Oros) [1816982]
- [netdrv] net: phylink: extend clause 45 PHY validation workaround (Petr Oros) [1816982]
- [netdrv] net: phylink: improve clause 45 PHY ksettings_set implementation (Petr Oros) [1816982]
- [netdrv] net: phylink: fix interface passed to mac_link_up (Petr Oros) [1816982]
- [netdrv] net: phylink: propagate phy_attach_direct() return code (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Add rx-fifo-depth and tx-fifo-depth (Petr Oros) [1816982]
- [documentation] dt-bindings: dp83867: Convert fifo-depth to common fifo-depth and make optional (Petr Oros) [1816982]
- [netdrv] net: sfp: re-attempt probing for phy (Petr Oros) [1816982]
- [netdrv] net: sfp: error handling for phy probe (Petr Oros) [1816982]
- [netdrv] net: sfp: rename sm_retries (Petr Oros) [1816982]
- [netdrv] net: sfp: use a definition for the fault recovery attempts (Petr Oros) [1816982]
- [netdrv] net: sfp: add support for Clause 45 PHYs (Petr Oros) [1816982]
- [netdrv] net: phy: add Broadcom BCM84881 PHY driver (Petr Oros) [1816982]
- [netdrv] net: phylink: make Broadcom BCM84881 based SFPs work (Petr Oros) [1816982]
- [netdrv] net: phylink: delay MAC configuration for copper SFP modules (Petr Oros) [1816982]
- [netdrv] net: phylink: split phylink_sfp_module_insert() (Petr Oros) [1816982]
- [netdrv] net: phylink: split link_an_mode configured and current settings (Petr Oros) [1816982]
- [netdrv] net: phylink: support Clause 45 PHYs on SFP+ modules (Petr Oros) [1816982]
- [netdrv] net: phylink: re-split __phylink_connect_phy() (Petr Oros) [1816982]
- [netdrv] net: mdio-i2c: add support for Clause 45 accesses (Petr Oros) [1816982]
- [netdrv] net: sfp: move phy_start()/phy_stop() to phylink (Petr Oros) [1816982]
- [netdrv] net: sfp: add module start/stop upstream notifications (Petr Oros) [1816982]
- [netdrv] net: sfp: derive interface mode from ethtool link modes (Petr Oros) [1816982]
- [netdrv] net: sfp: remove incomplete 100BASE-FX and 100BASE-LX support (Petr Oros) [1816982]
- [netdrv] net: sfp: avoid tx-fault with Nokia GPON module (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: fix hfs boot in rgmii mode (Petr Oros) [1816982]
- [netdrv] phy: mdio-thunder: add missed pci_release_regions in remove (Petr Oros) [1816982]
- [netdrv] net: sfp: fix hwmon (Petr Oros) [1816982]
- [netdrv] net: sfp: fix unbind (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: fix using paged operations with RTL8105e / RTL8208 (Petr Oros) [1816982]
- [netdrv] net: phy: Use the correct style for SPDX License Identifier (Petr Oros) [1816982]
- [netdrv] net: phy: dp83869: Fix return paths to return proper values (Petr Oros) [1816982]
- [netdrv] net: phy: add helpers phy_(un)lock_mdio_bus (Petr Oros) [1816982]
- [netdrv] mdio_bus: don't use managed reset-controller (Petr Oros) [1816982]
- [netdrv] net: phy: initialise phydev speed and duplex sanely (Petr Oros) [1816982]
- [netdrv] net: phy: remove phy_ethtool_sset() (Petr Oros) [1816982]
- [netdrv] net: sfp: soft status and control support (Petr Oros) [1816982]
- [netdrv] net: sfp: add some quirks for GPON modules (Petr Oros) [1816982]
- [netdrv] net: sfp: add support for module quirks (Petr Oros) [1816982]
- [netdrv] net: phylink: fix link mode modification in PHY mode (Petr Oros) [1816982]
- [netdrv] net: phylink: update documentation on create and destroy (Petr Oros) [1816982]
- [netdrv] mdio_bus: Fix init if CONFIG_RESET_CONTROLLER=n (Petr Oros) [1816982]
- [netdrv] net: phy: dp83869: fix return of uninitialized variable ret (Petr Oros) [1816982]
- [netdrv] phy: mdio-sun4i: add missed regulator_disable in remove (Petr Oros) [1816982]
- [netdrv] mscc.c: fix semicolon.cocci warnings (Petr Oros) [1816982]
- [netdrv] net: phy: avoid matching all-ones clause 45 PHY IDs (Petr Oros) [1816982]
- [netdrv] net: phylink: update to use phy_support_asym_pause() (Petr Oros) [1816982]
- [netdrv] net: phy: marvell10g: add SFP+ support (Petr Oros) [1816982]
- [netdrv] net: phy: add core phylib sfp support (Petr Oros) [1816982]
- [netdrv] net: phy: dp83869: Add TI dp83869 phy (Petr Oros) [1816982]
- [documentation] dt-bindings: net: dp83869: Add TI dp83869 phy (Petr Oros) [1816982]
- [netdrv] mscc.c: Add support for additional VSC PHYs (Petr Oros) [1816982]
- [netdrv] net: sfp: fix spelling mistake "requies" -> "requires" (Petr Oros) [1816982]
- [netdrv] net: sfp: allow modules with slow diagnostics to probe (Petr Oros) [1816982]
- [netdrv] net: sfp: allow sfp to probe slow to initialise GPON modules (Petr Oros) [1816982]
- [netdrv] net: sfp: move module insert reporting out of probe (Petr Oros) [1816982]
- [netdrv] net: sfp: split power mode switching from probe (Petr Oros) [1816982]
- [netdrv] net: sfp: track upstream's attachment state in state machine (Petr Oros) [1816982]
- [netdrv] net: sfp: ensure TX_FAULT has deasserted before probing the PHY (Petr Oros) [1816982]
- [netdrv] net: sfp: allow fault processing to transition to other states (Petr Oros) [1816982]
- [netdrv] net: sfp: eliminate mdelay() from PHY probe (Petr Oros) [1816982]
- [netdrv] net: sfp: split the PHY probe from sfp_sm_mod_init() (Petr Oros) [1816982]
- [netdrv] net: sfp: control TX_DISABLE and phy only from main state machine (Petr Oros) [1816982]
- [netdrv] net: sfp: avoid power switch on address-change modules (Petr Oros) [1816982]
- [netdrv] net: sfp: parse SFP power requirement earlier (Petr Oros) [1816982]
- [netdrv] net: sfp: rename T_PROBE_WAIT to T_SERIAL (Petr Oros) [1816982]
- [netdrv] net: sfp: handle module remove outside state machine (Petr Oros) [1816982]
- [netdrv] net: sfp: rename sfp_sm_ins_next() as sfp_sm_mod_next() (Petr Oros) [1816982]
- [netdrv] net: sfp: move tx disable on device down to main state machine (Petr Oros) [1816982]
- [netdrv] net: sfp: move sfp sub-state machines into separate functions (Petr Oros) [1816982]
- [netdrv] net: sfp: fix sfp_bus_put() kernel documentation (Petr Oros) [1816982]
- [include] net: sfp: fix sfp_bus_add_upstream() warning (Petr Oros) [1816982]
- [netdrv] net: sfp: rework upstream interface (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: add missing dependency on CONFIG_REGULATOR (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: remove config_init for AR9331 (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: fix the PHY names (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: mention AR8033 as same as AR8031 (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: add device tree binding (Petr Oros) [1816982]
- [documentation] dt-bindings: net: phy: Add support for AT803X (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: fix Kconfig description (Petr Oros) [1816982]
- [netdrv] net: phylink: Fix phylink_dbg() macro (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: add downshift support for 88E1145 (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: add PHY tunable support for more PHY versions (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: add downshift support for M88E1111 (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: fix downshift function naming (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: fix typo in constant MII_M1011_PHY_SRC_DOWNSHIFT_MASK (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: support Wake on LAN (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: move dt parsing to probe (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: enable robust auto-mdix (Petr Oros) [1816982]
- [netdrv] net: phy: smsc: LAN8740: add PHY_RST_AFTER_CLK_EN flag (Petr Oros) [1816982]
- [netdrv] net: phy: broadcom: add 1000Base-X support for BCM54616S (Petr Oros) [1816982]
- [netdrv] net: phy: add support for clause 37 auto-negotiation (Petr Oros) [1816982]
- [netdrv] net: phy: modify assignment to OR for dev_flags in phy_attach_direct (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: remove superseded function marvell_set_downshift (Petr Oros) [1816982]
- [netdrv] net: phy: marvell: support downshift as PHY tunable (Petr Oros) [1816982]
- [netdrv] net: phy: avoid NPE if read_page/write_page callbacks are not available (Petr Oros) [1816982]
- [netdrv] net: phy: micrel: Update KSZ87xx PHY name (Petr Oros) [1816982]
- [netdrv] net: phy: micrel: Discern KSZ8051 and KSZ8795 PHYs (Petr Oros) [1816982]
- [netdrv] net: phy: Fix "link partner" information disappear issue (Petr Oros) [1816982]
- [netdrv] net: sfp: move fwnode parsing into sfp-bus layer (Petr Oros) [1816982]
- [netdrv] net: phylink: use more linkmode_* (Petr Oros) [1816982]
- [netdrv] phylink: fix kernel-doc warnings (Petr Oros) [1816982]
- [netdrv] net: phy: mscc: make arrays static, makes object smaller (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: use operating parameters from PHY-specific status (Petr Oros) [1816982]
- [netdrv] net: phy: extract pause mode (Petr Oros) [1816982]
- [netdrv] net: phy: extract link partner advertisement reading (Petr Oros) [1816982]
- [netdrv] net: phy: allow for reset line to be tied to a sleepy GPIO controller (Petr Oros) [1816982]
- [documentation] docs: networking: phy: Improve phrasing (Petr Oros) [1816982]
- [netdrv] net: phy: broadcom: Use bcm54xx_config_clock_delay() for BCM54612E (Petr Oros) [1816982]
- [netdrv] net: phy: broadcom: Fix RGMII delays configuration for BCM54210E (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: remove probe and struct at803x_priv (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: add ar9331 support (Petr Oros) [1816982]
- [of] of: mdio: Fix a signedness bug in of_phy_get_and_connect() (Petr Oros) [1816982]
- [netdrv] net/phy: fix DP83865 10 Mbps HDX loopback disable function (Petr Oros) [1816982]
- [netdrv] net: phy: adin: implement Energy Detect Powerdown mode via phy-tunable (Petr Oros) [1816982]
- [net] ethtool: implement Energy Detect Powerdown support via phy-tunable (Petr Oros) [1816982]
- [netdrv] net: mdio: switch to using gpiod_get_optional() (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Add SGMII mode type switching (Petr Oros) [1816982]
- [documentation] net: phy: dp83867: Add documentation for SGMII mode type (Petr Oros) [1816982]
- [netdrv] net: phylink: Fix flow control resolution (Petr Oros) [1816982]
- [netdrv] net: phy: Do not check Link status when loopback is enabled (Petr Oros) [1816982]
- [netdrv] net: phy: gmii2rgmii: Dont use priv field in phy device (Petr Oros) [1816982]
- [include] include: mdio: Add driver data helpers (Petr Oros) [1816982]
- [netdrv] net: phy: force phy suspend when calling phy_stop (Petr Oros) [1816982]
- [netdrv] phy: mdio-sun4i: use devm_platform_ioremap_resource() to simplify code (Petr Oros) [1816982]
- [netdrv] phy: mdio-mux-meson-g12a: use devm_platform_ioremap_resource() to simplify code (Petr Oros) [1816982]
- [netdrv] phy: mdio-moxart: use devm_platform_ioremap_resource() to simplify code (Petr Oros) [1816982]
- [netdrv] phy: mdio-hisi-femac: use devm_platform_ioremap_resource() to simplify code (Petr Oros) [1816982]
- [netdrv] phy: mdio-bcm-iproc: use devm_platform_ioremap_resource() to simplify code (Petr Oros) [1816982]
- [netdrv] net: phy: sfp: Add labels to hwmon sensors (Petr Oros) [1816982]
- [netdrv] net: phy: remove genphy_config_init (Petr Oros) [1816982]
- [netdrv] net: phy: remove calls to genphy_config_init (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: support NBase-T MMD EEE registers on RTL8125 (Petr Oros) [1816982]
- [uapi] net: phy: add EEE-related constants (Petr Oros) [1816982]
- [documentation] dt-bindings: net: add bindings for ADIN PHY driver (Petr Oros) [1816982]
- [netdrv] net: phy: adin: add ethtool get_stats support (Petr Oros) [1816982]
- [netdrv] net: phy: adin: implement downshift configuration via phy-tunable (Petr Oros) [1816982]
- [netdrv] net: phy: adin: implement PHY subsystem software reset (Petr Oros) [1816982]
- [netdrv] net: phy: adin: add EEE translation layer from Clause 45 to Clause 22 (Petr Oros) [1816982]
- [netdrv] net: phy: adin: add support MDI/MDIX/Auto-MDI selection (Petr Oros) [1816982]
- [netdrv] net: phy: adin: make RMII fifo depth configurable (Petr Oros) [1816982]
- [netdrv] net: phy: adin: make RGMII internal delays configurable (Petr Oros) [1816982]
- [netdrv] net: phy: adin: configure RGMII/RMII/MII modes on config (Petr Oros) [1816982]
- [netdrv] net: phy: adin: add {write,read}_mmd hooks (Petr Oros) [1816982]
- [netdrv] net: phy: adin: add support for interrupts (Petr Oros) [1816982]
- [netdrv] net: phy: adin: hook genphy_{suspend, resume} into the driver (Petr Oros) [1816982]
- [netdrv] net: phy: adin: add support for Analog Devices PHYs (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: add support for EEE registers on integrated PHY's (Petr Oros) [1816982]
- [netdrv] net: phy: swphy: emulate register MII_ESTATUS (Petr Oros) [1816982]
- [netdrv] net: phy: read MII_CTRL1000 in genphy_read_status only if needed (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: add NBase-T PHY auto-detection (Petr Oros) [1816982]
- [netdrv] net: phy: let phy_speed_down/up support speeds >1Gbps (Petr Oros) [1816982]
- [netdrv] net: phy: add phy_speed_down_core and phy_resolve_min_speed (Petr Oros) [1816982]
- [netdrv] net: phy: add __set_linkmode_max_speed (Petr Oros) [1816982]
- [netdrv] net: phy: realtek: add support for the 2.5Gbps PHY in RTL8125 (Petr Oros) [1816982]
- [netdrv] net: phy: add phy_modify_paged_changed (Petr Oros) [1816982]
- [netdrv] net: phy: prepare phylib to deal with PHY's extending Clause 22 (Petr Oros) [1816982]
- [netdrv] net: phy: simplify genphy_config_advert by using the linkmode_adv_to_xxx_t functions (Petr Oros) [1816982]
- [netdrv] net: phy: at803x: stop switching phy delay config needlessly (Petr Oros) [1816982]
- [netdrv] net: mdio-octeon: Fix Kconfig warnings and build errors (Petr Oros) [1816982]
- [netdrv] net: phy: xgene: use devm_platform_ioremap_resource() to simplify code (Petr Oros) [1816982]
- [netdrv] net: phy: Add mdio-aspeed (Petr Oros) [1816982]
- [netdrv] net: phy: phy_led_triggers: Fix a possible null-pointer dereference in phy_led_trigger_change_speed() (Petr Oros) [1816982]
- [netdrv] net: phylink: Fix flow control for fixed-link (Petr Oros) [1816982]
- [netdrv] net: phylink: don't start and stop SGMII PHYs in SFP modules twice (Petr Oros) [1816982]
- [netdrv] net: phy: Make use of linkmode_mod_bit helper (Petr Oros) [1816982]
- [netdrv] net: stmmac: enable clause 45 mdio support (Petr Oros) [1816982]
- [documentation] doc: phy: document some PHY_INTERFACE_MODE_xxx settings (Petr Oros) [1816982]
- [netdrv] Revert "net: phylink: set the autoneg state in phylink_phy_change" (Petr Oros) [1816982]
- [netdrv] net: phy: sfp: clean up a condition (Petr Oros) [1816982]
- [netdrv] net: phylink: set the autoneg state in phylink_phy_change (Petr Oros) [1816982]
- [netdrv] net: phy: Add more 1000BaseX support detection (Petr Oros) [1816982]
- [netdrv] net: phy: broadcom: Add genphy_suspend and genphy_resume for BCM5464 (Petr Oros) [1816982]
- [netdrv] net: sfp: add mutex to prevent concurrent state checks (Petr Oros) [1816982]
- [netdrv] net: sfp: Stop SFP polling and interrupt handling during shutdown (Petr Oros) [1816982]
- [netdrv] net: phy: Add detection of 1000BaseX link mode support (Petr Oros) [1816982]
- [netdrv] net: phy: remove state PHY_FORCING (Petr Oros) [1816982]
- [netdrv] net: phy: export phy_queue_state_machine (Petr Oros) [1816982]
- [netdrv] net: phy: add callback for custom interrupt handler to struct phy_driver (Petr Oros) [1816982]
- [netdrv] net: phy: enable interrupts when PHY is attached already (Petr Oros) [1816982]
- [netdrv] net: phy: sfp: enable i2c-bus detection on ACPI based systems (Petr Oros) [1816982]
- [netdrv] net: phy: tja11xx: Switch to HWMON_CHANNEL_INFO() (Petr Oros) [1816982]
- [netdrv] net: phylink: Add phylink_{printk, err, warn, info, dbg} macros (Petr Oros) [1816982]
- [netdrv] net: phylink: Add PHYLINK_DEV operation type (Petr Oros) [1816982]
- [netdrv] net: phylink: Add struct phylink_config to PHYLINK API (Petr Oros) [1816982]
- [netdrv] net: phylink: Add phylink_mac_link_{up, down} wrapper functions (Petr Oros) [1816982]
- [netdrv] net: phy: Add phy_standalone sysfs entry (Petr Oros) [1816982]
- [netdrv] net: phy: Check against net_device being NULL (Petr Oros) [1816982]
- [netdrv] net: phy: Guard against the presence of a netdev (Petr Oros) [1816982]
- [netdrv] net: phy: Add phy_sysfs_create_links helper function (Petr Oros) [1816982]
- [netdrv] net: sfp: remove sfp-bus use of netdevs (Petr Oros) [1816982]
- [netdrv] net: sfp: add mandatory attach/detach methods for sfp buses (Petr Oros) [1816982]
- [netdrv] net: phy: allow Clause 45 access via mii ioctl (Petr Oros) [1816982]
- [netdrv] net: phylink: support for link gpio interrupt (Petr Oros) [1816982]
- [netdrv] net: phylink: remove netdev from phylink mii ioctl emulation (Petr Oros) [1816982]
- [netdrv] net: phy: bcm87xx: improve bcm87xx_config_init and feature detection (Petr Oros) [1816982]
- [netdrv] net: phy: tja11xx: Add TJA11xx PHY driver (Petr Oros) [1816982]
- [netdrv] net: phy: aquantia: add USXGMII support and warn if XGMII mode is set (Petr Oros) [1816982]
- [documentation] dt-bindings: net: document new usxgmii phy mode (Petr Oros) [1816982]
- [include] net: phy: add interface mode PHY_INTERFACE_MODE_USXGMII (Petr Oros) [1816982]
- [netdrv] net: phy: lxt: Add suspend/resume support to LXT971 and LXT973 (Petr Oros) [1816982]
- [netdrv] net: phy: Make phy_basic_t1_features use base100t1 (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Allocate state struct in probe (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Validate FIFO depth property (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: IO impedance is not dependent on RGMII delay (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Use unsigned variables to store unsigned properties (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Rework delay rgmii delay handling (Petr Oros) [1816982]
- [netdrv] net: phy: dp83867: Add ability to disable output clock (Petr Oros) [1816982]
- [documentation] dt-bindings: phy: dp83867: Add documentation for disabling clock output (Petr Oros) [1816982]
- [documentation] dt-bindings: phy: dp83867: Describe how driver behaves w.r.t rgmii delay (Petr Oros) [1816982]
- [documentation] Documentation: net: phy: switch documentation to rst format (Petr Oros) [1816982]
- [of] of: mdio: Support fixed links in of_phy_get_and_connect() (Petr Oros) [1816982]
- [documentation] doc: add phylink documentation to the networking book (Petr Oros) [1816982]
- [include] net: phylink: update mac_config() documentation (Petr Oros) [1816982]
- [tools] libbpf: use .so dynamic symbols for abi check (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Install generated test progs (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Fix memory leak caused by not freeing entry in unregister_ftrace_direct() (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Support CO-RE relocations for LDX/ST/STX instructions (Yauheni Kaliuta) [1813370]
- [include] bpf: Add bpf_jit_blinding_enabled for !CONFIG_BPF_JIT (Yauheni Kaliuta) [1813370]
- [tools] tools, bpf_asm: Warn when jumps are out of range (Yauheni Kaliuta) [1813370]
- [include] bpf: Add typecast to bpf helpers to help BTF generation (Yauheni Kaliuta) [1813370]
- [trace] bpf: Add typecast to raw_tracepoints to help BTF generation (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix build on read-only filesystems (Yauheni Kaliuta) [1813370]
- [tools] bpf: Add further test_verifier cases for record_func_key (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix record_func_key to perform backtracking on r3 (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix missing prog untrack in release_maps (Yauheni Kaliuta) [1813370]
- [samples] samples: bpf: fix syscall_tp due to unused syscall (Yauheni Kaliuta) [1813370]
- [samples] samples: bpf: Replace symbol compare of trace_event (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Test function_graph tracer and bpf trampoline together (Yauheni Kaliuta) [1813370]
- [net] bpf: Make BPF trampoline use register_ftrace_direct() API (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Add modify_ftrace_direct() (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Add information on number of page groups allocated (Yauheni Kaliuta) [1813370]
- [x86] ftrace/x86: Tell objtool to ignore nondeterministic ftrace stack layout (Yauheni Kaliuta) [1813370]
- [x86] ftrace/x86: Add a counter to test function_graph with direct (Yauheni Kaliuta) [1813370]
- [x86] ftrace/x86: Add register_ftrace_direct() for custom trampolines (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Add another check for match in register_ftrace_direct() (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Add ftrace_find_direct_func() (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Add register_ftrace_direct() (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Separate out the copying of a ftrace_hash from __ftrace_hash_move() (Yauheni Kaliuta) [1813370]
- [kernel] ftrace: Separate out functionality from ftrace_location_range() (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix build in minimal configurations, again (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add a fexit/bpf2bpf test with target bpf prog no callees (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix a bug when getting subprog 0 jited image in check_attach_btf_id (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Bring back c++ include/link test (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Don't hard-code root cgroup id (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Fix broken xdp_rxq_info due to map order assumptions (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix readelf output parsing for Fedora (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix readelf output parsing on powerpc with recent binutils (Yauheni Kaliuta) [1813370]
- [tools] selftests: bpf: correct perror strings (Yauheni Kaliuta) [1813370]
- [tools] selftests: bpf: test_sockmap: handle file creation failures gracefully (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix build in minimal configurations (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix up generation of bpf_helper_defs.h (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix global variable relocation (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix static checker warning (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix usage of u32 in userspace code (Yauheni Kaliuta) [1813370]
- [net] bpf: Simplify __bpf_arch_text_poke poke type handling (Yauheni Kaliuta) [1813370]
- [tools] bpf: Introduce BPF_TRACE_x helper for the tracing tests (Yauheni Kaliuta) [1813370]
- [tools] bpf, testing: Add various tail call test cases (Yauheni Kaliuta) [1813370]
- [x86] bpf, x86: Emit patchable direct jump as tail call (Yauheni Kaliuta) [1813370]
- [net] bpf: Constant map key tracking for prog array pokes (Yauheni Kaliuta) [1813370]
- [net] bpf: Add poke dependency tracking for prog array maps (Yauheni Kaliuta) [1813370]
- [include] bpf: Add initial poke descriptor table for jit images (Yauheni Kaliuta) [1813370]
- [net] bpf: Move owner type, jited info into array auxiliary data (Yauheni Kaliuta) [1813370]
- [net] bpf: Move bpf_free_used_maps into sleepable section (Yauheni Kaliuta) [1813370]
- [x86] bpf, x86: Generalize and extend bpf_arch_text_poke for direct jumps (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add BPF trampoline performance test (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Ensure core_reloc_kernel is reading test_progs's data only (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add verifier tests for better jmp32 register bounds (Yauheni Kaliuta) [1813370]
- [net] bpf: Provide better register bounds after jmp32 instructions (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Integrate verbose verifier log into test_progs (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Support initialized global variables (Yauheni Kaliuta) [1813370]
- [tools] selftests, bpftool: Skip the build test if not in tree (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix various errors and warning reported by checkpatch.pl (Yauheni Kaliuta) [1813370]
- [tools] selftests, bpftool: Set EXIT trap after usage function (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Ensure no DWARF relocations for BPF object files (Yauheni Kaliuta) [1813370]
- [tools] tools, bpftool: Fix warning on ignored return value for 'read' (Yauheni Kaliuta) [1813370]
- [net] bpf: Switch bpf_map_{area_alloc, area_mmapable_alloc}() to u64 size (Yauheni Kaliuta) [1813370]
- [net] bpf: Make array_map_mmap static (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Enforce no-ALU32 for test_progs-no_alu32 (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Remove JITed image size limitations (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Use lg(f)rl when long displacement cannot be used (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Use lgrl instead of lg where possible (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Load literal pool register using larl (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Align literal pool entries (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Use relative long branches (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix memory leak on object 'data' (Yauheni Kaliuta) [1813370]
- [tools] selftests, bpf: Workaround an alu32 sub-register spilling issue (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add BPF_TYPE_MAP_ARRAY mmap() tests (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Make global data internal arrays mmap()-able, if possible (Yauheni Kaliuta) [1813370]
- [net] bpf: Add mmap() support for BPF_MAP_TYPE_ARRAY (Yauheni Kaliuta) [1813370]
- [netdrv] bpf: Convert bpf_prog refcnt to atomic64_t (Yauheni Kaliuta) [1813370]
- [netdrv] net: thunderx: set xdp_prog to NULL if bpf_prog_add fails (Yauheni Kaliuta) [1813370]
- [net] bpf: Switch bpf_map ref counter to atomic64_t so bpf_map_inc() never fails (Yauheni Kaliuta) [1813370]
- [lib] locking/atomic: Use s64 for atomic64 (Yauheni Kaliuta) [1813370]
- [include] atomics/treewide: Make conditional inc/dec ops optional (Yauheni Kaliuta) [1813370]
- [include] atomics/treewide: Make unconditional inc/dec ops optional (Yauheni Kaliuta) [1813370]
- [include] atomics/treewide: Make test ops optional (Yauheni Kaliuta) [1813370]
- [include] atomics/treewide: Make atomic64_fetch_add_unless() optional (Yauheni Kaliuta) [1813370]
- [powerpc] atomics/powerpc: Define atomic64_fetch_add_unless() (Yauheni Kaliuta) [1813370]
- [lib] atomics/generic: Define atomic64_fetch_add_unless() (Yauheni Kaliuta) [1813370]
- [include] atomics: Prepare for atomic64_fetch_add_unless() (Yauheni Kaliuta) [1813370]
- [include] atomics/treewide: Make atomic_fetch_add_unless() optional (Yauheni Kaliuta) [1813370]
- [include] atomics/treewide: Make atomic64_inc_not_zero() optional (Yauheni Kaliuta) [1813370]
- [include] atomics: Make conditional ops return 'bool' (Yauheni Kaliuta) [1813370]
- [net] atomics/treewide: Remove atomic_inc_not_zero_hint() (Yauheni Kaliuta) [1813370]
- [net] atomics/treewide: Rename __atomic_add_unless() => atomic_fetch_add_unless() (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add a test for attaching BPF prog to another BPF prog and subprog (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Extend test_pkt_access test (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add support for attaching BPF programs to other BPF programs (Yauheni Kaliuta) [1813370]
- [net] bpf: Support attaching tracing BPF program to other BPF programs (Yauheni Kaliuta) [1813370]
- [net] bpf: Compare BTF types of functions arguments with actual types (Yauheni Kaliuta) [1813370]
- [net] bpf: Annotate context types (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix race in btf_resolve_helper_id() (Yauheni Kaliuta) [1813370]
- [x86] bpf: Reserve space for BPF trampoline in BPF programs (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add stress test for maximum number of progs (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add combined fentry/fexit test (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add fexit tests for BPF trampoline (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add test for BPF trampoline (Yauheni Kaliuta) [1813370]
- [net] bpf: Add kernel test functions for fentry testing (Yauheni Kaliuta) [1813370]
- [tools] selftest/bpf: Simple test for fentry/fexit (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add support to attach to fentry/fexit tracing progs (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Introduce btf__find_by_name_kind() (Yauheni Kaliuta) [1813370]
- [net] bpf: Introduce BPF trampoline (Yauheni Kaliuta) [1813370]
- [x86] bpf: Add bpf_arch_text_poke() helper (Yauheni Kaliuta) [1813370]
- [x86] bpf: Refactor x86 JIT into helpers (Yauheni Kaliuta) [1813370]
- [documentation] bpf, doc: Change right arguments for JIT example code (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Add missing option to xdpsock usage (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Remove duplicate option from xdpsock (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Make sure JIT passes do not increase code size (Yauheni Kaliuta) [1813370]
- [net] bpf: Support doubleword alignment in bpf_jit_binary_alloc (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: adjust Makefile and README.rst (Yauheni Kaliuta) [1813370]
- [tools] bpf, testing: Add missing object file to TEST_FILES (Yauheni Kaliuta) [1813370]
- [tools] bpf, testing: Workaround a verifier failure for test_progs (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Use Rx-only and Tx-only sockets in xdpsock (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Allow for creating Rx or Tx only AF_XDP sockets (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Add XDP_SHARED_UMEM support to xdpsock (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Support XDP_SHARED_UMEM with external XDP program (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add tests for automatic map unpinning on load failure (Yauheni Kaliuta) [1813370]
- [samples] samples: bpf: update map definition to new syntax BTF-defined map (Yauheni Kaliuta) [1813370]
- [samples] samples: bpf: Update outdated error message (Yauheni Kaliuta) [1813370]
- [tools] bpf: Add cb access in kfree_skb test (Yauheni Kaliuta) [1813370]
- [net] bpf: Add array support to btf_struct_access (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Remove unused SEEN_RET0, SEEN_REG_AX and ret0_ip (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Wrap JIT macro parameter usages in parentheses (Yauheni Kaliuta) [1813370]
- [s390] s390/bpf: Use kvcalloc for addrs array (Yauheni Kaliuta) [1813370]
- [net] bpf: Account for insn->off when doing bpf_probe_read_kernel (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Simplify BPF_CORE_READ_BITFIELD_PROBED usage (Yauheni Kaliuta) [1813370]
- [tools] selftests/bps: Clean up removed ints relocations negative tests (Yauheni Kaliuta) [1813370]
- [tools] selftests: bpf: log direct file writes (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add field size relocation tests (Yauheni Kaliuta) [1813370]
- [tools] selftest/bpf: Add relocatable bitfield reading tests (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add support for field size relocations (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add support for relocatable bitfields (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Remove too strict field offset relo test cases (Yauheni Kaliuta) [1813370]
- [tools] bpf, testing: Add selftest to read/write sockaddr from user space (Yauheni Kaliuta) [1813370]
- [tools] bpf, testing: Convert prog tests to probe_read_{user, kernel}{, _str} helper (Yauheni Kaliuta) [1813370]
- [samples] bpf, samples: Use bpf_probe_read_user where appropriate (Yauheni Kaliuta) [1813370]
- [net] bpf: Switch BPF probe insns to bpf_probe_read_kernel (Yauheni Kaliuta) [1813370]
- [kernel] bpf: Add probe_read_{user, kernel} and probe_read_{user, kernel}_str helpers (Yauheni Kaliuta) [1813370]
- [kernel] bpf: Make use of probe_user_write in probe write helper (Yauheni Kaliuta) [1813370]
- [mm] uaccess: Add strict non-pagefault kernel-space read function (Yauheni Kaliuta) [1813370]
- [mm] uaccess: Add non-pagefault user-space write function (Yauheni Kaliuta) [1813370]
- [mm] uaccess: Add non-pagefault user-space read functions (Yauheni Kaliuta) [1813370]
- [tools] selftests: Add tests for automatic map pinning (Yauheni Kaliuta) [1813370]
- [net] bpf: Implement map_gen_lookup() callback for XSKMAP (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add support for prog_tracing (Yauheni Kaliuta) [1813370]
- [net] bpf: Replace prog_raw_tp+btf_id with prog_tracing (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix bpf jit kallsym access (Yauheni Kaliuta) [1813370]
- [documentation] bpf: Add s390 testing documentation (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Test narrow load from bpf_sysctl.write (Yauheni Kaliuta) [1813370]
- [net] bpf: Enforce 'return 0' in BTF-enabled raw_tp programs (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Restore $(OUTPUT)/test_stub.o rule (Yauheni Kaliuta) [1813370]
- [tools] selftest/bpf: Use -m{little, big}-endian for clang (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Fix .gitignore to ignore no_alu32/ (Yauheni Kaliuta) [1813370]
- [net] bpf: Prepare btf_ctx_access for non raw_tp use case (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Fix strncat bounds error in libbpf_prog_type_by_name (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Fix LDLIBS order (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Move test_section_names into test_progs and fix it (Yauheni Kaliuta) [1813370]
- [tools] tools/bpf: Turn on llvm alu32 attribute by default (Yauheni Kaliuta) [1813370]
- [tools] selftest/bpf: Get rid of a bunch of explicit BPF program type setting (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Make reference_tracking test use subtests (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Make a copy of subtest name (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add uprobe/uretprobe and tp/raw_tp section suffixes (Yauheni Kaliuta) [1813370]
- [tools] bpf, libbpf: Add kernel version section parsing back (Yauheni Kaliuta) [1813370]
- [kernel] bpf: Fix build error without CONFIG_NET (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix bpf_attr.attach_btf_id check (Yauheni Kaliuta) [1813370]
- [tools] selftest/bpf: Remove test_libbpf.sh and test_libbpf_open (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Move test_queue_stack_map.h into progs/ where it belongs (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Replace test_progs and test_maps w/ general rule (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add simple per-test targets to Makefile (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Switch test_maps to test_progs' test.h format (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Teach test_progs to cd into subdir (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Restore the netns after flow dissector reattach test (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add kfree_skb raw_tp test (Yauheni Kaliuta) [1813370]
- [net] bpf: Check types of arguments passed into helpers (Yauheni Kaliuta) [1813370]
- [net] bpf: Add support for BTF pointers to x86 JIT (Yauheni Kaliuta) [1813370]
- [net] bpf: Add support for BTF pointers to interpreter (Yauheni Kaliuta) [1813370]
- [net] bpf: Attach raw_tp program with BTF via type name (Yauheni Kaliuta) [1813370]
- [net] bpf: Implement accurate raw_tp context access via BTF (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Auto-detect btf_id of BTF-based raw_tracepoints (Yauheni Kaliuta) [1813370]
- [net] bpf: Add attach_btf_id attribute to program load (Yauheni Kaliuta) [1813370]
- [net] bpf: Process in-kernel BTF (Yauheni Kaliuta) [1813370]
- [tools] selftests: bpf: Add selftest for __sk_buff tstamp (Yauheni Kaliuta) [1813370]
- [net] bpf: Allow __sk_buff tstamp in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Remove obsolete pahole/BTF support detection (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Enforce libbpf build before BPF programs are built (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Add preparation steps and sysroot info to readme (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Add sysroot support (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Provide C/LDFLAGS to libbpf (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add C/LDFLAGS to libbpf.so and test_libpf targets (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Don't use cxx to test_libpf target (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Use target CC environment for HDR_PROBE (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Use own flags but not HOSTCFLAGS (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Base target programs rules on Makefile.target (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Add makefile.target for separate CC target build (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Drop unnecessarily inclusion for bpf_load (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Use __LINUX_ARM_ARCH__ selector for arm (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Use own EXTRA_CFLAGS for clang commands (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Use --target from cross-compile (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Fix cookie_uid_helper_example obj build (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Fix HDR_PROBE "echo" (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Handle invalid typedef emitted by old GCC (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Generate more efficient BPF_CORE_READ code (Yauheni Kaliuta) [1813370]
- [net] bpf: Fix cast to pointer from integer of different size warning (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Check that flow dissector can be re-attached (Yauheni Kaliuta) [1813370]
- [net] flow_dissector: Allow updating the flow dissector program atomically (Yauheni Kaliuta) [1813370]
- [include] bpf: Align struct bpf_prog_stats (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add read-only map values propagation tests (Yauheni Kaliuta) [1813370]
- [net] bpf: Track contents of read-only maps as scalars (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Convert test_btf_dump into test_progs test (Yauheni Kaliuta) [1813370]
- [samples] samples: bpf: Add max_pckt_size option at xdp_adjust_tail (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: add test for BPF flow dissector in the root namespace (Yauheni Kaliuta) [1813370]
- [net] bpf/flow_dissector: add mode to enforce global BPF flow dissector (Yauheni Kaliuta) [1813370]
- [samples] samples/bpf: Trivial - fix spelling mistake in usage (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Fix dependency ordering for attach_probe test (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Add cscope and tags targets to Makefile (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: switch tests to new bpf_object__open_{file, mem}() APIs (Yauheni Kaliuta) [1813370]
- [tools] bpf: Add loop test case with 32 bit reg comparison against 0 (Yauheni Kaliuta) [1813370]
- [x86] bpf, x86: Small optimization in comparing against imm0 (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Correct path to include msg + path (Yauheni Kaliuta) [1813370]
- [tools] selftests/bpf: Add static to enable_all_controllers() (Yauheni Kaliuta) [1813370]
- [tools] libbpf: provide backported RHEL symbols as upstream aliases (Yauheni Kaliuta) [1813370]
- [tools] libbpf: Bump current version to v0.0.6 (Yauheni Kaliuta) [1813370]
- [tools] libbpf: bump up version, 0.0.5 (Yauheni Kaliuta) [1813370]
- [net] cpumap: Avoid warning when CONFIG_DEBUG_PER_CPU_MAPS is enabled (Yauheni Kaliuta) [1823623 1813370]
- [vfio] vfio-pci: Mask cap zero (Alex Williamson) [1840248]
- [vfio] spapr_tce: Fix incorrect tce_iommu_group memory free (David Gibson) [1832386]
- [fs] CIFS: fiemap: do not return EINVAL if get nothing (Leif Sahlberg) [1837180]
- [fs] CIFS: Increment num_remote_opens stats counter even in case of smb2_query_dir_first (Leif Sahlberg) [1837180]
- [fs] cifs: potential unintitliazed error code in cifs_getattr() (Leif Sahlberg) [1837180]
- [fs] cifs: Use #define in cifs_dbg (Leif Sahlberg) [1837180]
- [fs] cifs: fix rename() by ensuring source handle opened with DELETE bit (Leif Sahlberg) [1837180]
- [fs] cifs: add missing mount option to /proc/mounts (Leif Sahlberg) [1837180]
- [fs] cifs: fix potential mismatch of UNC paths (Leif Sahlberg) [1837180]
- [fs] cifs: enable change notification for SMB2.1 dialect (Leif Sahlberg) [1837180]
- [fs] cifs: Fix mode output in debugging statements (Leif Sahlberg) [1837180]
- [fs] cifs: fix mount option display for sec=krb5i (Leif Sahlberg) [1837180]
- [fs] smb3: Add defines for new information level, FileIdInformation (Leif Sahlberg) [1837180]
- [fs] smb3: print warning once if posix context returned on open (Leif Sahlberg) [1837180]
- [fs] smb3: add one more dynamic tracepoint missing from strict fsync path (Leif Sahlberg) [1837180]
- [fs] cifs: fix mode bits from dir listing when mounted with modefromsid (Leif Sahlberg) [1837180]
- [fs] cifs: fix channel signing (Leif Sahlberg) [1837180]
- [fs] cifs: add SMB3 change notification support (Leif Sahlberg) [1837180]
- [fs] cifs: make multichannel warning more visible (Leif Sahlberg) [1837180]
- [fs] cifs: Add tracepoints for errors on flush or fsync (Leif Sahlberg) [1837180]
- [fs] cifs: log warning message (once) if out of disk space (Leif Sahlberg) [1837180]
- [fs] smb3: fix problem with null cifs super block with previous patch (Leif Sahlberg) [1837180]
- [fs] SMB3: Backup intent flag missing from some more ops (Leif Sahlberg) [1837180]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1837180]
- [fs] CIFS: Fix task struct use-after-free on reconnect (Leif Sahlberg) [1837180]
- [fs] cifs: use PTR_ERR_OR_ZERO() to simplify code (Leif Sahlberg) [1837180]
- [fs] cifs: add support for fallocate mode 0 for non-sparse files (Leif Sahlberg) [1837180]
- [fs] CIFS: Add support for setting owner info, dos attributes, and create time (Leif Sahlberg) [1837180]
- [fs] cifs: remove set but not used variable 'server' (Leif Sahlberg) [1837180]
- [fs] cifs: fix unitialized variable poential problem with network I/O cache lock patch (Leif Sahlberg) [1837180]
- [fs] cifs: Fix return value in __update_cache_entry (Leif Sahlberg) [1837180]
- [fs] cifs: Avoid doing network I/O while holding cache lock (Leif Sahlberg) [1837180]
- [fs] cifs: Fix potential deadlock when updating vol in cifs_reconnect() (Leif Sahlberg) [1837180]
- [fs] cifs: Merge is_path_valid() into get_normalized_path() (Leif Sahlberg) [1837180]
- [fs] cifs: Introduce helpers for finding TCP connection (Leif Sahlberg) [1837180]
- [fs] cifs: Get rid of kstrdup_const()'d paths (Leif Sahlberg) [1837180]
- [fs] cifs: Clean up DFS referral cache (Leif Sahlberg) [1837180]
- [fs] cifs: Don't use iov_iter::type directly (Leif Sahlberg) [1837180]
- [fs] cifs: set correct max-buffer-size for smb2_ioctl_init() (Leif Sahlberg) [1837180]
- [fs] fs/cifs/cifssmb.c: use true, false for bool variable (Leif Sahlberg) [1837180]
- [fs] fs/cifs/smb2ops.c: use true, false for bool variable (Leif Sahlberg) [1837180]

* Wed Jun 03 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-210.el8]
- [lib] XArray: Optimise xas_sibling() if !CONFIG_XARRAY_MULTI (Don Dutile) [1840916]
- [include] XArray: Fix incorrect comment in header file (Don Dutile) [1840916]
- [lib] XArray: Fix xas_pause for large multi-index entries (Don Dutile) [1840916]
- [lib] XArray: Fix xa_find_next for large multi-index entries (Don Dutile) [1840916]
- [lib] XArray tests: Add check_insert (Don Dutile) [1840916]
- [documentation] XArray: Add xa_for_each_range (Don Dutile) [1840916]
- [documentation] XArray: Improve documentation of search marks (Don Dutile) [1840916]
- [documentation] docs: remove :c:func: annotations from xarray.rst (Don Dutile) [1840916]
- [lib] XArray: Fix xas_find returning too many entries (Don Dutile) [1840916]
- [lib] XArray: Fix xa_find_after with multi-index entries (Don Dutile) [1840916]
- [lib] XArray: Fix infinite loop with entry at ULONG_MAX (Don Dutile) [1840916]
- [include] XArray: Add wrappers for nested spinlocks (Don Dutile) [1840916]
- [lib] XArray: Fix xas_pause at ULONG_MAX (Don Dutile) [1840916]
- [include] xarray.h: fix kernel-doc warning (Don Dutile) [1840916]
- [lib] XArray: Fix xas_next() with a single entry at 0 (Don Dutile) [1840916]
- [fs] mm: fix page cache convergence regression (Don Dutile) [1840916]
- [netdrv] ionic: call ionic_port_init after fw-upgrade (Jonathan Toppins) [1830969]
- [netdrv] ionic: leave netdev mac alone after fw-upgrade (Jonathan Toppins) [1830969]
- [netdrv] ionic: add device reset to fw upgrade down (Jonathan Toppins) [1830969]
- [netdrv] ionic: refresh devinfo after fw-upgrade (Jonathan Toppins) [1830969]
- [netdrv] ionic: no link check until after probe (Jonathan Toppins) [1830969]
- [netdrv] phy: avoid unnecessary link-up delay in polling mode (Petr Oros) [1785663]
- [x86] x86: Select HARDIRQS_SW_RESEND on x86 (David Arcari) [1840433]
- [pci] PCI/AER: Fix the broken interrupt injection (David Arcari) [1840433]
- [kernel] genirq: Provide interrupt injection mechanism (David Arcari) [1840433]
- [kernel] genirq: Sanitize state handling in check_irq_resend() (David Arcari) [1840433]
- [kernel] genirq: Add return value to check_irq_resend() (David Arcari) [1840433]
- [x86] x86/apic/vector: Force interupt handler invocation to irq context (David Arcari) [1840433]
- [kernel] genirq: Add protection against unsafe usage of generic_handle_irq() (David Arcari) [1840433]
- [kernel] genirq/debugfs: Add missing sanity checks to interrupt injection (David Arcari) [1840433]
- [include] genirq/irqdomain: Make sure all irq domain flags are distinct (David Arcari) [1840433]
- [x86] x86/apic/msi: Plug non-maskable MSI affinity race (David Arcari) [1840433]
- [char] char: ipmi: convert to use i2c_new_client_device() (Tony Camuso) [1832408]
- [char] ipmi: kcs: Fix aspeed_kcs_probe_of_v1() (Tony Camuso) [1832408]
- [char] ipmi: Add missing annotation for ipmi_ssif_lock_cond() and ipmi_ssif_unlock_cond() (Tony Camuso) [1832408]
- [char] ipmi: kcs: aspeed: Implement v2 bindings (Tony Camuso) [1832408]
- [char] ipmi: kcs: Finish configuring ASPEED KCS device before enable (Tony Camuso) [1832408]
- [char] ipmi: fix hung processes in __get_guid() (Tony Camuso) [1832408]
- [char] drivers: char: ipmi: ipmi_msghandler: Pass lockdep expression to RCU lists (Tony Camuso) [1832408]
- [char] ipmi_si: Avoid spurious errors for optional IRQs (Tony Camuso) [1832408]
- [base] driver core: platform: Export platform_get_irq_optional() (Tony Camuso) [1832408]
- [base] driver core: platform: Introduce platform_get_irq_optional() (Tony Camuso) [1832408]
- [x86] x86/efi: Update e820 with reserved EFI boot services data to fix kexec breakage (Kairui Song) [1779544]
- [powerpc] powerpc/nvdimm: use H_SCM_QUERY hcall on H_OVERLAP error (Pingfan Liu) [1792125]
- [powerpc] powerpc/nvdimm: Use HCALL error as the return value (Pingfan Liu) [1792125]
- [scsi] scsi: sd: Signal drive managed SMR disks (Ewan Milne) [1838784]
- [scsi] scsi: core: free sgtables in case command setup fails (Ewan Milne) [1838784]
- [scsi] scsi: core: Allow the state change from SDEV_QUIESCE to SDEV_BLOCK (Ewan Milne) [1838784]
- [scsi] scsi: sg: add sg_remove_request in sg_write (Ewan Milne) [1838784]
- [scsi] scsi: sg: add sg_remove_request in sg_common_write (Ewan Milne) [1838784]
- [scsi] scsi: sd: Fix optimal I/O size for devices that change reported values (Ewan Milne) [1838784]
- [scsi] scsi: move scsicam_bios_param to the end of scsicam.c (Ewan Milne) [1838784]
- [scsi] scsi: simplify scsi_bios_ptable (Ewan Milne) [1838784]
- [scsi] scsi: core: Use scnprintf() for avoiding potential buffer overflow (Ewan Milne) [1838784]
- [scsi] scsi: core: avoid repetitive logging of device offline messages (Ewan Milne) [1838784]
- [scsi] scsi: core: use kobj_to_dev (Ewan Milne) [1838784]
- [scsi] scsi: sd: Clear sdkp->protection_type if disk is reformatted without PI (Ewan Milne) [1838784]
- [scsi] scsi: core: Fix a compiler warning triggered by the SCSI logging code (Ewan Milne) [1838784]
- [scsi] scsi: core: Adjust DBD setting in MODE SENSE for caching mode page per LLD (Ewan Milne) [1838784]
- [scsi] scsi: sd_zbc: Improve report zones error printout (Ewan Milne) [1838784]
- [scsi] scsi: scsi_transport_sas: Fix memory leak when removing devices (Ewan Milne) [1838784]
- [scsi] scsi: scsi_debug: num_tgts must be >= 0 (Ewan Milne) [1838784]
- [scsi] scsi: core: Handle drivers which set sg_tablesize to zero (Ewan Milne) [1838784]
- [scsi] scsi: tracing: Fix handling of TRANSFER LENGTH == 0 for READ(6) and WRITE(6) (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_ioctl(): get rid of access_ok() (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_write(): get rid of access_ok()/__copy_from_user()/__get_user() (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_read(): get rid of access_ok()/__copy_..._user() (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_new_write(): don't bother with access_ok (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_write(): __get_user() can fail.. (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_new_write(): replace access_ok() + __copy_from_user() with copy_from_user() (Ewan Milne) [1838784]
- [scsi] scsi: sg: sg_ioctl(): fix copyout handling (Ewan Milne) [1838784]
- [scsi] scsi: core: scsi_trace: Use get_unaligned_be*() (Ewan Milne) [1838784]
- [scsi] drivers/scsi: Replace rcu_swap_protected() with rcu_replace_pointer() (Ewan Milne) [1838784]
- [scsi] scsi: sd: define variable dif as unsigned int instead of bool (Ewan Milne) [1838784]
- [scsi] scsi: core: try to get module before removing device (Ewan Milne) [1838784]
- [scsi] scsi: scsi_dh_alua: handle RTPG sense code correctly during state transitions (Ewan Milne) [1838784]
- [powerpc] powerpc/64: flush_inval_dcache_range() becomes flush_dcache_range() (Gustavo Duarte) [1834180]
- [x86] x86/ima: use correct identifier for SetupMode variable (Diego Domingos) [1781925]
- [lib] kobject: fix dereference before null check on kobj (Diego Domingos) [1781925]
- [include] MODSIGN: make new include file self contained (Diego Domingos) [1781925]
- [security] ima: initialize the "template" field with the default template (Diego Domingos) [1781925]
- [x86] x86/ima: Check EFI_RUNTIME_SERVICES before using (Diego Domingos) [1781925]
- [x86] x86/ima: check EFI SetupMode too (Diego Domingos) [1781925]
- [security] ima: Set file->f_mode instead of file->f_flags in ima_calc_file_hash() (Diego Domingos) [1781925]
- [security] evm: check hash algorithm passed to init_desc() (Diego Domingos) [1781925]
- [base] firmware: improve LSM/IMA security behaviour (Diego Domingos) [1781925]
- [lib] kobject: Add support for default attribute groups to kobj_type (Diego Domingos) [1781925]
- [samples] samples/kobject: Replace foo_ktype's default_attrs field with groups (Diego Domingos) [1781925]
- [x86] x86/ima: require signed kernel modules (Diego Domingos) [1781925]
- [security] powerpc: Load firmware trusted keys/hashes into kernel keyring (Diego Domingos) [1781925]
- [powerpc] powerpc: expose secure variables to userspace via sysfs (Diego Domingos) [1781925]
- [powerpc] powerpc/powernv: Add OPAL API interface to access secure variable (Diego Domingos) [1781925]
- [powerpc] powerpc/ima: fix secure boot rules in ima arch policy (Diego Domingos) [1781925]
- [security] ima: Set again build_ima_appraise variable (Diego Domingos) [1781925]
- [security] ima: Remove redundant policy rule set in add_rules() (Diego Domingos) [1781925]
- [powerpc] powerpc/ima: Indicate kernel modules appended signatures are enforced (Diego Domingos) [1781925]
- [powerpc] powerpc/ima: Update ima arch policy to check for blacklist (Diego Domingos) [1781925]
- [security] ima: Check against blacklisted hashes for files with modsig (Diego Domingos) [1781925]
- [security] ima: prevent a file already mmap'ed write to be mmap'ed execute (Diego Domingos) [1781925]
- [certs] certs: Add wrapper function to check blacklisted binary hash (Diego Domingos) [1781925]
- [security] ima: Make process_buffer_measurement() generic (Diego Domingos) [1781925]
- [powerpc] powerpc/ima: Define trusted boot policy (Diego Domingos) [1781925]
- [powerpc] powerpc: Detect the trusted boot state of the system (Diego Domingos) [1781925]
- [powerpc] powerpc/ima: Add support to initialize ima policy rules (Diego Domingos) [1781925]
- [powerpc] powerpc: Detect the secure boot mode of the system (Diego Domingos) [1781925]
- [security] ima: use struct_size() in kzalloc() (Diego Domingos) [1781925]
- [tools] sefltest/ima: support appended signatures (modsig) (Diego Domingos) [1781925]
- [security] ima: Fix use after free in ima_read_modsig() (Diego Domingos) [1781925]
- [security] ima: fix freeing ongoing ahash_request (Diego Domingos) [1781925]
- [security] ima: always return negative code for error (Diego Domingos) [1781925]
- [security] ima: Store the measurement again when appraising a modsig (Diego Domingos) [1781925]
- [security] ima: Define ima-modsig template (Diego Domingos) [1781925]
- [security] ima: Collect modsig (Diego Domingos) [1781925]
- [security] ima: Implement support for module-style appended signatures (Diego Domingos) [1781925]
- [security] ima: Factor xattr_verify() out of ima_appraise_measurement() (Diego Domingos) [1781925]
- [security] integrity: Introduce struct evm_xattr (Diego Domingos) [1781925]
- [security] ima: Add modsig appraise_type option for module-style appended signatures (Diego Domingos) [1781925]
- [kernel] MODSIGN: Export module signature definitions (Diego Domingos) [1781925]
- [kernel] modsign: log module name in the event of an error (Diego Domingos) [1781925]
- [kernel] KEXEC: Call ima_kexec_cmdline to measure the boot command line args (Diego Domingos) [1781925]
- [security] IMA: Define a new template field buf (Diego Domingos) [1781925]
- [security] IMA: Define a new hook to measure the kexec boot command line arguments (Diego Domingos) [1781925]
- [security] IMA: support for per policy rule template formats (Diego Domingos) [1781925]
- [security] integrity: Fix __integrity_init_keyring() section mismatch (Diego Domingos) [1781925]
- [security] x86/ima: fix the Kconfig dependency for IMA_ARCH_POLICY (Diego Domingos) [1781925]
- [security] ima: Make arch_policy_entry static (Diego Domingos) [1781925]
- [security] ima: show rules with IMA_INMASK correctly (Diego Domingos) [1781925]
- [security] ima: fix wrong signed policy requirement when not appraising (Diego Domingos) [1781925]
- [tools] selftests/kexec: update get_secureboot_mode (Diego Domingos) [1781925]
- [tools] selftests/kexec: make kexec_load test independent of IMA being enabled (Diego Domingos) [1781925]
- [tools] selftests/kexec: check kexec_load and kexec_file_load are enabled (Diego Domingos) [1781925]
- [tools] selftests/kexec: Add missing '=y' to config options (Diego Domingos) [1781925]
- [tools] selftests/kexec: kexec_file_load syscall test (Diego Domingos) [1781925]
- [tools] selftests/kexec: define "require_root_privileges" (Diego Domingos) [1781925]
- [tools] selftests/kexec: define common logging functions (Diego Domingos) [1781925]
- [tools] selftests/kexec: define a set of common functions (Diego Domingos) [1781925]
- [tools] selftests/kexec: cleanup the kexec selftest (Diego Domingos) [1781925]
- [tools] selftests/kexec: move the IMA kexec_load selftest to selftests/kexec (Diego Domingos) [1781925]
- [security] evm: remove set but not used variable 'xattr' (Diego Domingos) [1781925]
- [security] security: integrity: partial revert of make ima_main explicitly non-modular (Diego Domingos) [1781925]
- [security] ima: cleanup the match_token policy code (Diego Domingos) [1781925]
- [security] ima: Use inode_is_open_for_write (Diego Domingos) [1781925]
- [security] security: fs: make inode explicitly non-modular (Diego Domingos) [1781925]
- [security] security: audit and remove any unnecessary uses of module.h (Diego Domingos) [1781925]
- [security] security: integrity: make evm_main explicitly non-modular (Diego Domingos) [1781925]
- [security] security: integrity: make ima_main explicitly non-modular (Diego Domingos) [1781925]
- [tools] selftests/ima: kexec_load syscall test (Diego Domingos) [1781925]
- [security] ima: don't measure/appraise files on efivarfs (Diego Domingos) [1781925]
- [x86] x86/ima: retry detecting secure boot mode (Diego Domingos) [1781925]
- [x86] x86/ima: define arch_get_ima_policy() for x86 (Diego Domingos) [1781925]
- [kernel] kernel/kexec_file.c: remove some duplicated includes (Diego Domingos) [1781925]
- [security] ima: open a new file instance if no read permissions (Diego Domingos) [1781925]
- [security] security/integrity: constify some read-only data (Diego Domingos) [1781925]
- [documentation] security: fix LSM description location (Diego Domingos) [1781925]
- [security] evm: Allow non-SHA1 digital signatures (Diego Domingos) [1781925]
- [security] security: export security_kernel_load_data function (Diego Domingos) [1781925]
- [security] ima: based on policy warn about loading firmware (pre-allocated buffer) (Diego Domingos) [1781925]
- [security] ima: prevent kexec_load syscall based on runtime secureboot flag (Diego Domingos) [1781925]
- [security] module: replace the existing LSM hook in init_module (Diego Domingos) [1781925]
- [security] ima: based on policy require signed firmware (sysfs fallback) (Diego Domingos) [1781925]
- [security] ima: add support for arch specific policies (Diego Domingos) [1781925]
- [security] ima: based on policy require signed kexec kernel images (Diego Domingos) [1781925]
- [security] ima: refactor ima_init_policy() (Diego Domingos) [1781925]
- [include] sysfs: Fixes __BIN_ATTR_WO() macro (Diego Domingos) [1781925]
- [include] security: define new LSM hook named security_kernel_load_data (Diego Domingos) [1781925]
- [kernel] kexec: add call to LSM hook in original kexec_load syscall (Diego Domingos) [1781925]
- [base] firmware: add call to LSM hook before firmware sysfs fallback (Diego Domingos) [1781925]
- [security] ima: add build time policy (Diego Domingos) [1781925]
- [security] ima: Support platform keyring for kernel appraisal (Diego Domingos) [1781925]
- [security] integrity: Remove references to module keyring (Diego Domingos) [1781925]
- [powerpc] powerpc/kexec: Fix loading of kernel + initramfs with kexec_file_load() (Diego Domingos) [1781925]
- [security] ima: Use designated initializers for struct ima_event_data (Diego Domingos) [1781925]
- [security] ima: Update MAX_TEMPLATE_NAME_LEN to fit largest reasonable definition (Diego Domingos) [1781925]
- [certs] PKCS#7: Refactor verify_pkcs7_signature() (Diego Domingos) [1781925]
- [crypto] PKCS#7: Introduce pkcs7_get_digest() (Diego Domingos) [1781925]
- [security] integrity: Select CONFIG_KEYS instead of depending on it (Diego Domingos) [1781925]
- [powerpc] powerpc/powernv: Move opal_power_control_init() call in opal_init() (Diego Domingos) [1781925]
- [security] x86/efi: move common keyring handler functions to new file (Diego Domingos) [1781925]
- [security] x86/efi: remove unused variables (Diego Domingos) [1781925]
- [include] sysfs: add BIN_ATTR_WO() macro (Diego Domingos) [1781925]
- [x86] x86/ima: define arch_ima_get_secureboot (Diego Domingos) [1781925]
- [powerpc] powerpc/pci: unmap legacy INTx interrupts of passthrough IO adapters (Steve Best) [1840279]
- [powerpc] powerpc/xive: Clear the page tables for the ESB IO mapping (Steve Best) [1840279]
- [hv] hyper-v: Use UUID API for exporting the GUID (Mohammed Gamal) [1828451 1815498]
- [kernel] uuid: Add inline helpers to import / export UUIDs (Mohammed Gamal) [1828451 1815498]
- [hv] hv: Move AEOI determination to architecture dependent code (Mohammed Gamal) [1828451 1815498]
- [x86] hyper-v: Report crash data in die() when panic_on_oops is set (Mohammed Gamal) [1828451 1815498]
- [hv] x86/hyper-v: Report crash register data when sysctl_record_panic_msg is not set (Mohammed Gamal) [1828451 1815498]
- [x86] hyper-v: Report crash register data or kmsg before running crash kernel (Mohammed Gamal) [1828451 1815498]
- [hv] x86/hyper-v: Trigger crash enlightenment only once during system crash (Mohammed Gamal) [1828451 1815498]
- [hv] x86/hyper-v: Free hv_panic_page when fail to register kmsg dump (Mohammed Gamal) [1828451 1815498]
- [hv] x86/hyper-v: Unload vmbus channel in hv panic callback (Mohammed Gamal) [1828451 1815498]
- [hv] hv_debugfs: Make hv_debug_root static (Mohammed Gamal) [1828451 1815498]
- [hv] hyperv_vmbus.h: Replace zero-length array with flexible-array member (Mohammed Gamal) [1828451 1815498]
- [hv] hv: vmbus: Ignore CHANNELMSG_TL_CONNECT_RESULT(23) (Mohammed Gamal) [1828451 1815498]
- [hv] hv_balloon: Balloon up according to request page number (Mohammed Gamal) [1828451 1815498]
- [hv] hv_balloon: use generic_online_page() (Mohammed Gamal) [1828451 1815498]
- [mm] memory_hotplug: export generic_online_page() (Mohammed Gamal) [1828451 1815498]
- [hv] hv: vmbus: Fix crash handler reset of Hyper-V synic (Mohammed Gamal) [1828451 1815498]
- [hv] hv: Replace binary semaphore with mutex (Mohammed Gamal) [1828451 1815498]
- [hv] hv: balloon: Remove dependencies on guest page size (Mohammed Gamal) [1828451 1815498]
- [hv] hv: vmbus: Remove dependencies on guest page size (Mohammed Gamal) [1828451 1815498]
- [hv] hv: util: Specify ring buffer size using Hyper-V page size (Mohammed Gamal) [1828451 1815498]
- [hv] hv: Specify receive buffer size using Hyper-V page size (Mohammed Gamal) [1828451 1815498]
- [hv] hv: vmbus: Add module parameter to cap the VMBus version (Mohammed Gamal) [1828451 1815498]
- [hv] hv: vmbus: Enable VMBus protocol versions 4.1, 5.1 and 5.2 (Mohammed Gamal) [1828451 1815498]
- [hv] hv: vmbus: Introduce table of VMBus protocol versions (Mohammed Gamal) [1828451 1815498]
- [pci] hv: Replace zero-length array with flexible-array member (Mohammed Gamal) [1793636]
- [pci] hv: Decouple the func definition in hv_dr_state from VSP message (Mohammed Gamal) [1793636]
- [pci] hv: Add support for protocol 1.3 and support PCI_BUS_RELATIONS2 (Mohammed Gamal) [1793636]
- [pci] hv: Add missing kfree(hbus) in hv_pci_probe()'s error handling path (Mohammed Gamal) [1793636]
- [pci] hv: Remove unnecessary type casting from kzalloc (Mohammed Gamal) [1793636]
- [pci] hv: Avoid a kmemleak false positive caused by the hbus buffer (Mohammed Gamal) [1793636]
- [infiniband] RDMA/srpt: Fix disabling device management (Kamal Heib) [1840016]
- [misc] vhost: disable for OABI (Jason Wang) [1771441]
- [include] virtio: drop vringh.h dependency (Jason Wang) [1771441]
- [virtio] virtio_input: pull in slab.h (Jason Wang) [1771441]
- [char] virtio-rng: pull in slab.h (Jason Wang) [1771441]
- [block] virtio_blk: add a missing include (Jason Wang) [1771441]
- [vdpa] vdpa: fix comment of vdpa_register_device() (Jason Wang) [1771441]
- [vhost] vdpa: make vhost, virtio depend on menu (Jason Wang) [1771441]
- [include] vdpa: allow a 32 bit vq alignment (Jason Wang) [1771441]
- [vdpa] vdpasim: Return status in vdpasim_get_status (Jason Wang) [1771441]
- [vdpa] vdpa: remove unused variables 'ifcvf' and 'ifcvf_lm' (Jason Wang) [1771441]
- [vdpa] vdpa-sim: depend on HAS_DMA (Jason Wang) [1771441]
- [virtio] vdpa: move to drivers/vdpa (Jason Wang) [1771441]
- [virtio] virtio: Intel IFC VF driver for VDPA (Jason Wang) [1771441]
- [virtio] vdpasim: vDPA device simulator (Jason Wang) [1771441]
- [vhost] vhost: introduce vDPA-based backend (Jason Wang) [1771441]
- [virtio] virtio: introduce a vDPA based transport (Jason Wang) [1771441]
- [virtio] vDPA: introduce vDPA bus (Jason Wang) [1771441]
- [vhost] vringh: IOTLB support (Jason Wang) [1771441]
- [vhost] vhost: factor out IOTLB (Jason Wang) [1771441]
- [vhost] vhost: allow per device message handler (Jason Wang) [1771441]
- [misc] vhost: refine vhost and vringh kconfig (Jason Wang) [1771441]
- [vhost] vringh: fix copy direction of vringh_iov_push_kern() (Jason Wang) [1771441]
- [vhost] vhost: factor out setting vring addr and num (Jason Wang) [1771441]
- [vhost] vhost: introduce helpers to get the size of metadata area (Jason Wang) [1771441]
- [vhost] vhost: rename vq_iotlb_prefetch() to vq_meta_prefetch() (Jason Wang) [1771441]
- [vhost] vhost: fine grain userspace memory accessors (Jason Wang) [1771441]
- [vhost] vhost: generalize adding used elem (Jason Wang) [1771441]
- [misc] mic: vop: Allow building on more systems (Jason Wang) [1771441]
- [virtio] virtio: support VIRTIO_F_ORDER_PLATFORM (Jason Wang) [1771441]
- [uapi] vhost: split structs into a separate header file (Jason Wang) [1771441]
- [fs] compat_ioctl: add compat_ptr_ioctl() (Jason Wang) [1771441]
- [vhost] vhost: allow vhost-scsi driver to be built-in (Jason Wang) [1771441]
- [x86] arch/x86: Remove vendor specific CPU ID checks (Prarit Bhargava) [1840145]
- [tools] perf vendor events amd: Update Zen1 events to V2 (Wei Huang) [1790641]
- [tools] perf vendor events amd: Add Zen2 events (Wei Huang) [1790641]
- [tools] perf vendor events amd: Restrict model detection for zen1 based processors (Wei Huang) [1790641]
- [x86] perf/amd/uncore: Add support for Family 19h L3 PMU (Wei Huang) [1790641]
- [x86] perf/amd/uncore: Make L3 thread mask code more readable (Wei Huang) [1790641]
- [x86] perf/amd/uncore: Prepare L3 thread mask code for Family 19h (Wei Huang) [1790641]
- [scsi] scsi: fnic: Use scnprintf() for avoiding potential buffer overflow (Govindarajulu Varadarajan) [1797808]
- [scsi] scsi: fnic: do not queue commands during fwreset (Govindarajulu Varadarajan) [1797808]
- [scsi] scsi: fnic: fix invalid stack access (Govindarajulu Varadarajan) [1797808]
- [scsi] scsi: fnic: fix use after free (Govindarajulu Varadarajan) [1797808]
- [scsi] scsi: fnic: make array dev_cmd_err static const, makes object smaller (Govindarajulu Varadarajan) [1797808]

* Tue Jun 02 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-209.el8]
- [media] media: v4l: fix uapi mpeg slice params definition (Torez Smith) [1825410 1821835]
- [uapi] v4l2-controls: add a missing include (Torez Smith) [1825410 1821835]
- [dma] dma-mapping: remove dma_release_declared_memory (Torez Smith) [1825410 1821835]
- [usb] usb/ohci-tmio: remove the HCD_DMA flag (Torez Smith) [1825410 1821835]
- [usb] usb: add a HCD_DMA flag instead of guestimating DMA capabilities (Torez Smith) [1825410 1821835]
- [usb] usb: add a hcd_uses_dma helper (Torez Smith) [1825410 1821835]
- [usb] usb: don't create dma pools for HCDs with a localmem_pool (Torez Smith) [1825410 1821835]
- [usb] usb: host: ohci-tmio: Mark expected switch fall-throughs (Torez Smith) [1825410 1821835]
- [usb] USB: drop HCD_LOCAL_MEM flag (Torez Smith) [1825410 1821835]
- [usb] usb: host: ohci-tmio: init genalloc for local memory (Torez Smith) [1825410 1821835]
- [usb] dma-mapping: remove the DMA_MEMORY_EXCLUSIVE flag (Torez Smith) [1825410 1821835]
- [media] media: xirlink_cit: add missing descriptor sanity checks (Torez Smith) [1825410 1821835]
- [media] media: ttusb-dec: Fix info-leak in ttusb_dec_send_command() (Torez Smith) [1788005 1825410 1821835] {CVE-2019-19533}
- [media] media: usb: fix memory leak in af9005_identify_state (Torez Smith) [1825141 1825410 1821835] {CVE-2019-18809}
- [netdrv] cdc_ether: fix rndis support for Mediatek based smartphones (Torez Smith) [1825410 1821835]
- [netdrv] r8152: remove calling netif_napi_del (Torez Smith) [1825410 1821835]
- [netdrv] Revert "r8152: napi hangup fix after disconnect" (Torez Smith) [1825410 1821835]
- [netdrv] r8152: Set memory to all 0xFFs on failed reg reads (Torez Smith) [1825410 1821835]
- [netdrv] net: kalmia: fix memory leaks (Torez Smith) [1825410 1821835]
- [netdrv] cx82310_eth: fix a memory leak bug (Torez Smith) [1825410 1821835]
- [netdrv] lan78xx: Fix memory leaks (Torez Smith) [1825410 1821835]
- [netdrv] r8152: fix typo in register name (Torez Smith) [1825410 1821835]
- [netdrv] can: peak_usb: pcan_usb_pro: Fix info-leaks to USB devices (Torez Smith) [1825410 1821835]
- [netdrv] can: peak_usb: pcan_usb_fd: Fix info-leaks to USB devices (Torez Smith) [1825410 1821835]
- [netdrv] can: peak_usb: force the string buffer NULL-terminated (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: pegasus: fix improper read if get_registers() fail (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: qmi_wwan: Add the BroadMobi BM818 card (Torez Smith) [1825410 1821835]
- [netdrv] can: mark expected switch fall-throughs (Torez Smith) [1825410 1821835]
- [netdrv] can: peak_usb: fix potential double kfree_skb() (Torez Smith) [1825410 1821835]
- [netdrv] usb: qmi_wwan: add D-Link DWM-222 A2 device ID (Torez Smith) [1825410 1821835]
- [uapi] media: videodev2.h: change V4L2_PIX_FMT_BGRA444 define: fourcc was already in use (Torez Smith) [1825410 1821835]
- [netdrv] r8152: set RTL8152_UNPLUG only for real disconnection (Torez Smith) [1825410 1821835]
- [netdrv] r8152: move calling r8153b_rx_agg_chg_indicate() (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: asix: init MAC address buffers (Torez Smith) [1825410 1821835]
- [netdrv] r8152: fix the setting of detecting the linking change for runtime suspend (Torez Smith) [1825410 1821835]
- [media] media: hdpvr: fix locking and a missing msleep (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Fix out-of-bounds read (Torez Smith) [1825410 1821835]
- [uapi] media: videodev2.h: Fix shifting signed 32-bit value by 31 bits problem (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 468 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 238 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 235 (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: extend permitted QMAP mux_id value range (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: avoid RCU stalls on device disconnect when in QMAP mode (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: add network device usage statistics for qmimux devices (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: add support for QMAP padding in the RX path (Torez Smith) [1825410 1821835]
- [media] media: cx231xx-cards: Add Hauppauge 955Q variant (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: Add Hauppauge HVR1955/1975 devices (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: Add i2c client demod/tuner support (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: Add multiple dvb frontend support (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Fix access to uninitialized fields on probe error (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Include streaming interface number in debugfs dir name (Torez Smith) [1825410 1821835]
- [netdrv] can: usb: Kconfig: Remove duplicate menu entry (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: fix null-ptr-deref in class_unregister() (Torez Smith) [1825410 1821835]
- [media] media: cxusb: Revert "media: cxusb: add raw mode support for, Medion MD95700" (Torez Smith) [1825410 1821835]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 412 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 286 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 258 (Torez Smith) [1825410 1821835]
- [media] media: media/usb: set device_caps in struct video_device (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb/cxusb-analog.c: fix coccinelle warning, use ktime.h (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 174 (Torez Smith) [1825410 1821835]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 164 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 131 (Torez Smith) [1825410 1821835]
- [media] media: cx231xx-dvb: fix memory leak in dvb_fini() (Torez Smith) [1825410 1821835]
- [media] media: em28xx: use usb_to_input_id() rather than handrolling it (Torez Smith) [1825410 1821835]
- [media] media: em28xx: use common code for decoding nec scancodes (Torez Smith) [1825410 1821835]
- [media] media: em28xx: give RC device proper name (Torez Smith) [1825410 1821835]
- [media] media: cxusb: fix several coding style issues (Torez Smith) [1825410 1821835]
- [media] media: cxusb-analog: Fix some coding style issues (Torez Smith) [1825410 1821835]
- [media] media: cxusb: add raw mode support for Medion MD95700 (Torez Smith) [1825410 1821835]
- [media] media: cxusb: add analog mode support for Medion MD95700 (Torez Smith) [1825410 1821835]
- [media] media: cxusb: implement Medion MD95700 digital / analog coexistence (Torez Smith) [1825410 1821835]
- [media] media: usb:zr364xx:Fix KASAN:null-ptr-deref Read in zr364xx_vidioc_querycap (Torez Smith) [1825410 1821835]
- [media] media: pwc: convert to BIT macro (Torez Smith) [1825410 1821835]
- [media] media: cpia2_usb: first wake up, then free in disconnect (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: use a different format for warnings (Torez Smith) [1825410 1821835]
- [media] media: smsusb: better handle optional alignment (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 118 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 65 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 61 (Torez Smith) [1825410 1821835]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 55 (Torez Smith) [1825410 1821835]
- [media] media: remove redundant 'default n' from Kconfig-s (Torez Smith) [1825410 1821835]
- [media] media: af9035: Remove duplicate error reporting for dvbsky_usb_generic_rw (Torez Smith) [1825410 1821835]
- [media] media: dvbsky: Remove duplicate error reporting for dvbsky_usb_generic_rw (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb-v2: Report error on all error paths (Torez Smith) [1825410 1821835]
- [media] media: au0828: fix null dereference in error path (Torez Smith) [1825410 1821835]
- [media] media: dvb: usb: fix use after free in dvb_usb_device_exit (Torez Smith) [1825410 1821835]
- [media] media: usb: siano: Fix false-positive "uninitialized variable" warning (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: fix kernel crash after disconnect (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: ipheth: fix racing condition (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 24 (Torez Smith) [1825410 1821835]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 17 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Torez Smith) [1825410 1821835]
- [media] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 1 (Torez Smith) [1825410 1821835]
- [media] treewide: Add SPDX license identifier - Makefile/Kconfig (Torez Smith) [1825410 1821835]
- [media] treewide: Add SPDX license identifier for more missed files (Torez Smith) [1825410 1821835]
- [media] media: usb: siano: Fix general protection fault in smsusb (Torez Smith) [1825410 1821835]
- [media] media: prefix header search paths with $(srctree)/ (Torez Smith) [1825410 1821835]
- [media] media: remove unneeded header search paths (Torez Smith) [1825410 1821835]
- [netdrv] aqc111: cleanup mtu related logic (Torez Smith) [1825410 1821835]
- [netdrv] Revert "aqc111: fix writing to the phy on BE" (Torez Smith) [1825410 1821835]
- [netdrv] Revert "aqc111: fix double endianness swap on BE" (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: qmi_wwan: add Telit 0x1260 and 0x1261 compositions (Torez Smith) [1825410 1821835]
- [netdrv] aqc111: fix double endianness swap on BE (Torez Smith) [1825410 1821835]
- [netdrv] aqc111: fix writing to the phy on BE (Torez Smith) [1825410 1821835]
- [netdrv] aqc111: fix endianness issue in aqc111_change_mtu (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: smsc: fix warning reported by kbuild test robot (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: support of_get_mac_address new ERR_PTR error (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: ipheth: Remove unnecessary NULL pointer check (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: ipheth: Simplify device detection (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: new Wistron, ZTE and D-Link devices (Torez Smith) [1825410 1821835]
- [uapi] media: v4l: Add definitions for missing 16-bit RGB555 formats (Torez Smith) [1825410 1821835]
- [uapi] media: v4l: Add definitions for missing 16-bit RGB4444 formats (Torez Smith) [1825410 1821835]
- [uapi] media: v4l: Add definitions for missing 32-bit RGB formats (Torez Smith) [1825410 1821835]
- [netdrv] r8152: sync sa_family with the media type of network device (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: Prevent a buffer overflow (Torez Smith) [1825410 1821835]
- [media] media: au0828: stop video streaming only when last user stops (Torez Smith) [1825410 1821835]
- [media] media: au0828: Fix NULL pointer dereference in au0828_analog_stream_enable() (Torez Smith) [1825410 1821835]
- [media] media: au0828: fix enable and disable source audio and video inconsistencies (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Add quirk for Quectel dynamic config (Torez Smith) [1825410 1821835]
- [netdrv] r8152: Refresh MAC address during USBDEVFS_RESET (Torez Smith) [1825410 1821835]
- [netdrv] r8152: remove extra action copying ethernet address (Torez Smith) [1825410 1821835]
- [media] media: replace strncpy() by strscpy() (Torez Smith) [1825410 1821835]
- [media] media: usbvision: fix a potential NULL pointer dereference (Torez Smith) [1825410 1821835]
- [media] media: gspca: Kill URBs on USB device disconnect (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: add Olicard 600 (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Extend HWID table by QNAP device (Torez Smith) [1825410 1821835]
- [media] media: pwc-ctl: pChoose can't be NULL (Torez Smith) [1825410 1821835]
- [media] media: Kconfig files: use the right help coding style (Torez Smith) [1825410 1821835]
- [media] media: em28xx-input: make const array addr_list static (Torez Smith) [1825410 1821835]
- [media] media: dvb: Add support for the Avermedia TD310 (Torez Smith) [1825410 1821835]
- [media] media: dvb: init i2c already in it930x_frontend_attach (Torez Smith) [1825410 1821835]
- [media] media: dvbsky: Avoid leaking dvb frontend (Torez Smith) [1825410 1821835]
- [media] media: gspca: do not resubmit URBs when streaming has stopped (Torez Smith) [1825410 1821835]
- [media] media: au0828: minor fix to a misleading comment in _close() (Torez Smith) [1825410 1821835]
- [media] media: go7007: avoid clang frame overflow warning with KASAN (Torez Smith) [1825410 1821835]
- [media] media: cpia2: Fix use-after-free in cpia2_exit (Torez Smith) [1825410 1821835]
- [netdrv] peak_usb: fix clang build warning (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Add support for Quectel EG12/EM12 (Torez Smith) [1825410 1821835]
- [media] media: a few more typos at staging, pci, platform, radio and usb (Torez Smith) [1825410 1821835]
- [media] media: usb: fix several typos (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Use usb_make_path to fill in usb_info (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Fix smatch warning (Torez Smith) [1825410 1821835]
- [media] media: v4l: Add 32-bit packed YUV formats (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: cdc-phonet: use struct_size() in alloc_netdev() (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: rtl8150: mark expected switch fall-through (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: pegasus: Mark expected switch fall-through (Torez Smith) [1825410 1821835]
- [media] media: hdpvr: fix smatch warning (Torez Smith) [1825410 1821835]
- [media] media: usbvision: use u64 for the timestamp internally (Torez Smith) [1825410 1821835]
- [media] media: stkwebcam: use u64 for the timestamp internally (Torez Smith) [1825410 1821835]
- [media] media: cpia2: use u64 for the timestamp internally (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Avoid NULL pointer dereference at the end of streaming (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Fix 'type' check leading to overflow (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: asix: ax88772_bind return error when hw_reset fail (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: rtl8150: remove set but not used variable 'rx_stat' (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Extend HWID table by TRENDnet device (Torez Smith) [1825410 1821835]
- [uapi] media: videodev2.h: Add more field helper macros (Torez Smith) [1825410 1821835]
- [media] media: gspca: ov534-ov772x: remove unnecessary COM3 initialization (Torez Smith) [1825410 1821835]
- [media] media: gspca: ov534-ov722x: remove camera clock setup from bridge_init (Torez Smith) [1825410 1821835]
- [media] media: gspca: ov534-ov722x: remove mode specific video data registers from bridge_init (Torez Smith) [1825410 1821835]
- [media] media: gspca: ov534-ov772x: add SGBRG8 bayer mode support (Torez Smith) [1825410 1821835]
- [media] media: gspca: ov543-ov772x: move video format specific registers into bridge_start (Torez Smith) [1825410 1821835]
- [media] media: gspca: support multiple pixel formats in TRY_FMT (Torez Smith) [1825410 1821835]
- [media] media: gspca: support multiple pixel formats in ENUM_FRAMEINTERVALS (Torez Smith) [1825410 1821835]
- [media] media: gspca: ov534: replace msleep(10) with usleep_range (Torez Smith) [1825410 1821835]
- [uapi] media: v4l: uAPI: V4L2_BUF_TYPE_META_OUTPUT is an output buffer type (Torez Smith) [1825410 1821835]
- [media] media: gspca: mt9m111: Check write_bridge for timeout (Torez Smith) [1825410 1821835]
- [media] media: gspca: Check the return value of write_bridge for timeout (Torez Smith) [1825410 1821835]
- [media] media: usb: gspca: add a missed check for goto_low_power (Torez Smith) [1825410 1821835]
- [media] media: usb: gspca: add a missed return-value check for do_command (Torez Smith) [1825410 1821835]
- [media] media: v4l2-ctrls.c/uvc: zero v4l2_event (Torez Smith) [1825410 1821835]
- [media] media: usb: pwc: Don't use coherent DMA buffers for ISO transfer (Torez Smith) [1825410 1821835]
- [media] media: usb: pwc: Introduce TRACE_EVENTs for pwc_isoc_handler() (Torez Smith) [1825410 1821835]
- [netdrv] cdc_ether: trivial whitespace readability fix (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: add MTU default to qmap network interface (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Fix qmap header retrieval in qmimux_rx_fixup (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Add support for Fibocom NL678 series (Torez Smith) [1825410 1821835]
- [netdrv] lan78xx: Resolve issue with changing MAC address (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Added support for Telit LN940 series (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Added support for Fibocom NL668 series (Torez Smith) [1825410 1821835]
- [media] media: v4l: Add support for V4L2_BUF_TYPE_META_OUTPUT (Torez Smith) [1825410 1821835]
- [media] media: siano: Use kmemdup instead of duplicating its function (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: fix spelling mistake "statuss" -> "status" (Torez Smith) [1825410 1821835]
- [media] media: lmedm04: Move interrupt buffer to priv buffer (Torez Smith) [1825410 1821835]
- [media] media: lmedm04: Add missing usb_free_urb to free interrupt urb (Torez Smith) [1825410 1821835]
- [media] media: stkwebcam: Bugfix for wrong return values (Torez Smith) [1825410 1821835]
- [media] media: stkwebcam: Support for ASUS A6VM notebook added (Torez Smith) [1825410 1821835]
- [media] media: usb: dvb-usb: remove old friio driver (Torez Smith) [1825410 1821835]
- [media] media: lmedm04: use dvb_usbv2_generic_rw_locked (Torez Smith) [1825410 1821835]
- [media] media: lmedm04: Move usb buffer to lme2510_state (Torez Smith) [1825410 1821835]
- [media] media: rtl28xxu: add support for Sony CXD2837ER slave demod (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Utilise for_each_uvc_urb iterator (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Rename uvc_{un, }init_video() (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Split uvc_video_enable into two (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Move decode processing to process context (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Abstract streaming object lifetime (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: queue: Support asynchronous buffer handling (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: queue: Simplify spin-lock usage (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Protect queue internals with helper (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Convert decode functions to use new context structure (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Refactor URB descriptors (Torez Smith) [1825410 1821835]
- [media] media: em28xx: fix spelling mistake, "Cinnergy" -> "Cinergy" (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Refactor teardown of uvc on USB disconnect (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Add support for the CNF4 format (Torez Smith) [1825410 1821835]
- [documentation] media: v4l: Add 4bpp packed depth confidence format CNF4 (Torez Smith) [1825410 1821835]
- [media] media: usb: Use kmemdup instead of duplicating its function (Torez Smith) [1825410 1821835]
- [media] media: dvb: Use WARM definition from identify_state() (Torez Smith) [1825410 1821835]
- [media] media: dib0700: fix spelling mistake "Amplifyer" -> "Amplifier" (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb-v2: Fix incorrect use of transfer_flags URB_FREE_BUFFER (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Initialize wol_cfg with memset in aqc111_suspend (Torez Smith) [1825410 1821835]
- [netdrv] net: Don't default Aquantia USB driver to 'y' (Torez Smith) [1825410 1821835]
- [netdrv] can: ucan: fix spelling mistake: "resumbmitting" -> "resubmitting" (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Extend cdc_ether blacklist (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add ASIX's HW ids (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add support for wake on LAN by MAGIC packet (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Implement get/set_link_ksettings callbacks (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Initialize ethtool_ops structure (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add RX VLAN filtering support (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add support for VLAN_CTAG_TX/RX offload (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Implement set_rx_mode callback (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add support for TSO (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add support for enable/disable checksum offload (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add support for changing MTU (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add checksum offload support (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Implement RX data path (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Implement TX data path (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add support for getting and setting of MAC address (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Introduce link management (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Introduce PHY access (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Various callbacks implementation (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add implementation of read and write commands (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Add bind and empty unbind callbacks (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: aqc111: Driver skeleton for Aquantia AQtion USB to 5GbE (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: ipheth: fix potential recvmsg bug and recvmsg bug 2 (Torez Smith) [1825410 1821835]
- [media] media: pulse8-cec: return 0 when invalidating the logical address (Torez Smith) [1825410 1821835]
- [media] media: gspca: fix frame overflow error (Torez Smith) [1825410 1821835]
- [media] media: cropcap/g_selection split (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: smsc95xx: check for csum being in last four bytes (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: smsc95xx: fix memcpy for accessing rx-data (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: smsc95xx: simplify tx_fixup code (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: smsc95xx: fix rx packet alignment (Torez Smith) [1825410 1821835]
- [netdrv] can: ucan: remove duplicated include from ucan.c (Torez Smith) [1825410 1821835]
- [netdrv] can: ucan: remove set but not used variable 'udev' (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Fix accessing freed memory in kvaser_usb_start_xmit() (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Fix potential uninitialized variable use (Torez Smith) [1825410 1821835]
- [netdrv] net: smsc95xx: Fix MTU range (Torez Smith) [1825410 1821835]
- [netdrv] usbnet: smsc95xx: disable carrier check while suspending (Torez Smith) [1825410 1821835]
- [netdrv] net: cdc_ncm: remove set but not used variable 'ctx' (Torez Smith) [1825410 1821835]
- [netdrv] net: cdc_ncm: use tasklet_init() for tasklet_struct init (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Added support for Gemalto's Cinterion ALASxx WWAN interface (Torez Smith) [1825410 1821835]
- [media] media: pvrusb2: replace `printk` with `pr_*` (Torez Smith) [1825410 1821835]
- [media] media: cx231xx: fix potential sign-extension overflow on large shift (Torez Smith) [1825410 1821835]
- [media] Revert "media: dvbsky: use just one mutex for serializing device R/W ops" (Torez Smith) [1825410 1821835]
- [netdrv] net/usb: cancel pending work when unbinding smsc75xx (Torez Smith) [1825410 1821835]
- [netdrv] smsc95xx: Check for Wake-on-LAN modes (Torez Smith) [1825410 1821835]
- [netdrv] smsc75xx: Check for Wake-on-LAN modes (Torez Smith) [1825410 1821835]
- [netdrv] r8152: Check for supported Wake-on-LAN Modes (Torez Smith) [1825410 1821835]
- [netdrv] sr9800: Check for supported Wake-on-LAN modes (Torez Smith) [1825410 1821835]
- [netdrv] lan78xx: Check for supported Wake-on-LAN modes (Torez Smith) [1825410 1821835]
- [netdrv] ax88179_178a: Check for supported Wake-on-LAN modes (Torez Smith) [1825410 1821835]
- [netdrv] asix: Check for supported Wake-on-LAN modes (Torez Smith) [1825410 1821835]
- [media] media: v4l: Add definition for the Sunxi tiled NV12 format (Torez Smith) [1825410 1821835]
- [documentation] media: v4l: Add definitions for MPEG-2 slice format and metadata (Torez Smith) [1825410 1821835]
- [media] media: au0828: Fix incorrect error messages (Torez Smith) [1825410 1821835]
- [media] media: au0828: cannot kfree dev before usb disconnect (Torez Smith) [1825410 1821835]
- [netdrv] net: lan78xx: Avoid unnecessary self assignment (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: set DTR for modems in forced USB2 mode (Torez Smith) [1825410 1821835]
- [media] media: mxl111sf: declare its own pads (Torez Smith) [1825410 1821835]
- [media] media: au0828: use signals instead of hardcoding a pad number (Torez Smith) [1825410 1821835]
- [media] media: v4l2: taint pads with the signal types for consumer devices (Torez Smith) [1825410 1821835]
- [media] media: em28xx: make v4l2-compliance happier by starting sequence on zero (Torez Smith) [1825410 1821835]
- [media] media: em28xx: fix input name for Terratec AV 350 (Torez Smith) [1825410 1821835]
- [media] media: em28xx: use a default format if TRY_FMT fails (Torez Smith) [1825410 1821835]
- [media] media: em28xx: fix handler for vidioc_s_input() (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: remove redundant null pointer check before of_node_put (Torez Smith) [1825410 1821835]
- [media] media: usbvision: remove time_in_irq (Torez Smith) [1825410 1821835]
- [media] media: gspca: sq930x: use GFP_KERNEL in sd_dq_callback() (Torez Smith) [1825410 1821835]
- [media] media: replace strcpy() by strscpy() (Torez Smith) [1825410 1821835]
- [media] media: use strscpy() instead of strlcpy() (Torez Smith) [1825410 1821835]
- [documentation] media: videodev2.h: add new capabilities for buffer types (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Store device information pointer in struct uvc_device (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Rename UVC_QUIRK_INFO to UVC_INFO_QUIRK (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Fix uvc_alloc_entity() allocation alignment (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Fix spelling mistake: "entites" -> "entities" (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Remove unnecessary NULL check before debugfs_remove_recursive (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Make uvc_control_mapping menu_info field const (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Make some structs const (Torez Smith) [1825410 1821835]
- [netdrv] qmi_wwan: Support dynamic config on Quectel EP06 (Torez Smith) [1825410 1821835]
- [netdrv] lan78xx: Do not access skb_queue_head list pointers directly (Torez Smith) [1825410 1821835]
- [netdrv] net: lan78xx: Make declaration style consistent (Torez Smith) [1825410 1821835]
- [netdrv] net: lan78xx: Switch to SPDX identifier (Torez Smith) [1825410 1821835]
- [netdrv] net: lan78xx: Drop unnecessary strcpy in lan78xx_probe (Torez Smith) [1825410 1821835]
- [netdrv] net: lan78xx: Bail out if lan78xx_get_endpoints fails (Torez Smith) [1825410 1821835]
- [netdrv] net: usbnet: mark expected switch fall-through (Torez Smith) [1825410 1821835]
- [media] media: v4l2-ctrls: v4l2_ctrl_add_handler: add from_other_dev (Torez Smith) [1825410 1821835]
- [media] media: videodev2.h: add request_fd field to v4l2_ext_controls (Torez Smith) [1825410 1821835]
- [uapi] media: videodev2.h: Add new DV flag CAN_DETECT_REDUCED_FPS (Torez Smith) [1825410 1821835]
- [media] media: af9035: prevent buffer overflow on write (Torez Smith) [1825410 1821835]
- [netdrv] r8152: disable RX aggregation on new Dell TB16 dock (Torez Smith) [1825410 1821835]
- [netdrv] drivers/net/usb/r8152: remove the unneeded variable "ret" in rtl8152_system_suspend (Torez Smith) [1825410 1821835]
- [media] media: rtl28xxu: be sure that it won't go past the array size (Torez Smith) [1825410 1821835]
- [netdrv] net:usb: Use ARRAY_SIZE instead of calculating the array size (Torez Smith) [1825410 1821835]
- [media] media: au0828: fix spelling mistake: "completition" -> "completion" (Torez Smith) [1825410 1821835]
- [media] media: cx231xx: fix spelling mistake: "completition" -> "completion" (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb-v2: fix spelling mistake: "completition" -> "completion" (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb: fix spelling mistake: "completition" -> "completion" (Torez Smith) [1825410 1821835]
- [media] media: usb: hackrf: Replace GFP_ATOMIC with GFP_KERNEL (Torez Smith) [1825410 1821835]
- [media] media: usb: em28xx: Replace mdelay() with msleep() in em28xx_pre_card_setup() (Torez Smith) [1825410 1821835]
- [media] media: usb: em28xx: Replace GFP_ATOMIC with GFP_KERNEL in em28xx_init_usb_xfer() (Torez Smith) [1825410 1821835]
- [media] media: dw2102: Fix memleak on sequence of probes (Torez Smith) [1825410 1821835]
- [media] media: usbtv: use irqsave() in USB's complete callback (Torez Smith) [1825410 1821835]
- [media] media: go7007: use irqsave() in USB's complete callback (Torez Smith) [1825410 1821835]
- [media] media: cx231xx: use irqsave() in USB's complete callback (Torez Smith) [1825410 1821835]
- [documentation] media: v4l: Add new 10-bit packed grayscale format (Torez Smith) [1825410 1821835]
- [documentation] media: doc-rst: Add packed Bayer raw14 pixel formats (Torez Smith) [1825410 1821835]
- [media] media: em28xx: disable null packet filter for WinTVdualHD (Torez Smith) [1825410 1821835]
- [uapi] media: videodev2: get rid of VIDIOC_RESERVED (Torez Smith) [1825410 1821835]
- [media] media: em28xx: explicitly disable TS packet filter (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb/friio, dvb-usb-v2/gl861: decompose friio and merge with gl861 (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: sr9700: Replace mdelay() with msleep() in sr9700_bind() (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: pegasus: Replace mdelay() with msleep() in setup_pegasus_II() (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Send a control event when a Control Change interrupt arrives (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Handle control pipe protocol STALLs (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Remove a redundant check (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Also validate buffers in BULK mode (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Add KSMedia 8-bit IR format support (Torez Smith) [1825410 1821835]
- [media] media: uvcvideo: Fix minor spelling (Torez Smith) [1825410 1821835]
- [media] media: em28xx-cards: disable V4L2 mode for dual tuners (Torez Smith) [1825410 1821835]
- [media] media: em28xx: Remove duplicate PID (Torez Smith) [1825410 1821835]
- [media] media: em28xx: Fix DualHD disconnect oops (Torez Smith) [1825410 1821835]
- [media] media: em28xx: Fix dual transport stream operation (Torez Smith) [1825410 1821835]
- [media] media: dib0700: add code comment (Torez Smith) [1825410 1821835]
- [media] media: cx231xx: don't check number of messages in the driver (Torez Smith) [1825410 1821835]
- [media] media: em28xx: don't check number of messages in the driver (Torez Smith) [1825410 1821835]
- [media] media: hdpvr: don't check number of messages in the driver (Torez Smith) [1825410 1821835]
- [media] media: dvb-usb: don't check number of messages in the driver (Torez Smith) [1825410 1821835]
- [media] media: tm6000: don't check number of messages in the driver (Torez Smith) [1825410 1821835]
- [media] media: gl861: fix probe of dvb_usb_gl861 (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Simplify struct kvaser_cmd_cardinfo (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Add support for Kvaser USB hydra family (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Split driver into kvaser_usb_core.c and kvaser_usb_leaf.c (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Add SPDX GPL-2.0 license identifier (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Fix typos (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Improve logging messages (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Refactor kvaser_usb_init_one() (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Refactor kvaser_usb_get_endpoints() (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Add pointer to struct usb_interface into struct kvaser_usb (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Replace USB timeout constants with one define (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Rename message/msg to command/cmd (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Remove unused commands and defines (Torez Smith) [1825410 1821835]
- [netdrv] can: kvaser_usb: Remove unnecessary return (Torez Smith) [1825410 1821835]
- [netdrv] can: peak_usb: mark expected switch fall-throughs (Torez Smith) [1825410 1821835]
- [netdrv] can: ucan: add driver for Theobroma Systems UCAN devices (Torez Smith) [1825410 1821835]
- [netdrv] can: usb: Kconfig/Makefile: sort alphabetically (Torez Smith) [1825410 1821835]
- [media] media: gspca_kinect: cast sizeof to int for comparison (Torez Smith) [1825410 1821835]
- [media] media: videodev.h: add PIX_FMT_FWHT for use with vicodec (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: hso: use swap macro in hso_kick_transmit (Torez Smith) [1825410 1821835]
- [netdrv] net: usb: asix: allow optionally getting mac address from device tree (Torez Smith) [1825410 1821835]

* Thu May 28 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-208.el8]
- [hid] HID: Improve Windows Precision Touchpad detection (Benjamin Tissoires) [1811209]
- [hid] HID: multitouch: enable multi-input as a quirk for some devices (Benjamin Tissoires) [1811209]
- [hid] drivers/hid/hid-multitouch.c: fix a possible null pointer access (Benjamin Tissoires) [1811209]
- [hid] HID: multitouch: Add LG MELF0410 I2C touchscreen support (Benjamin Tissoires) [1811209]
- [hid] HID: multitouch: add support for the Smart Tech panel (Benjamin Tissoires) [1811209]
- [hid] HID: multitouch: do not filter mice nodes (Benjamin Tissoires) [1811209]
- [hid] HID: wacom: Report 2nd-gen Intuos Pro S center button status over BT (Benjamin Tissoires) [1835753]
- [hid] Revert "HID: wacom: generic: read the number of expected touches on a per collection basis" (Benjamin Tissoires) [1835753]
- [hid] HID: wacom: Read HID_DG_CONTACTMAX directly for non-generic devices (Benjamin Tissoires) [1835753]
- [hid] HID: wacom: Recognize new MobileStudio Pro PID (Benjamin Tissoires) [1835753]
- [hid] HID: wacom: generic: Treat serial number and related fields as unsigned (Benjamin Tissoires) [1835753]
- [hid] HID: wacom: add new MobileStudio Pro 13 support (Benjamin Tissoires) [1835753]
- [hid] HID: wacom: do not call hid_set_drvdata(hdev, NULL) (Benjamin Tissoires) [1835753]
- [hid] HID: wacom: support named keys on older devices (Benjamin Tissoires) [1835753]
- [target] scsi: target: iscsi: calling iscsit_stop_session() inside iscsit_close_session() has no effect (Maurizio Lombardi) [1840024]
- [target] scsi: target: fix hang when multiple threads try to destroy the same iscsi session (Maurizio Lombardi) [1840024]
- [target] scsi: target: remove boilerplate code (Maurizio Lombardi) [1840024]
- [target] scsi: target: use an enum to track emulate_ua_intlck_ctrl (Maurizio Lombardi) [1840024]
- [target] scsi: target: convert boolean se_dev_attrib types to bool (Maurizio Lombardi) [1840024]
- [target] scsi: target: fix unmap_zeroes_data boolean initialisation (Maurizio Lombardi) [1840024]
- [fs] page cache: Finish XArray conversion (Waiman Long) [1812073]
- [mm] mm: Convert __do_page_cache_readahead to XArray (Waiman Long) [1812073]
- [mm] mm: Convert is_page_cache_freeable to XArray (Waiman Long) [1812073]
- [mm] mm: memcontrol: clean up and document effective low/min calculations (Waiman Long) [1812073]
- [mm] mm: memcontrol: fix memory.low proportional distribution (Waiman Long) [1812073]
- [mm] mm: kmem: rename (__)memcg_kmem_(un)charge_memcg() to __memcg_kmem_(un)charge() (Waiman Long) [1812073]
- [mm] mm: memcg/slab: cache page number in memcg_(un)charge_slab() (Waiman Long) [1812073]
- [mm] mm: kmem: switch to nr_pages in (__)memcg_kmem_charge_memcg() (Waiman Long) [1812073]
- [mm] mm: kmem: rename memcg_kmem_(un)charge() into memcg_kmem_(un)charge_page() (Waiman Long) [1812073]
- [mm] mm: kmem: cleanup memcg_kmem_uncharge_memcg() arguments (Waiman Long) [1812073]
- [mm] mm: kmem: cleanup (__)memcg_kmem_charge_memcg() arguments (Waiman Long) [1812073]
- [mm] mm: memcg/slab: use mem_cgroup_from_obj() (Waiman Long) [1812073]
- [kernel] mm: fork: fix kernel_stack memcg stats for various stack implementations (Waiman Long) [1812073]
- [mm] memcg: fix NULL pointer dereference in __mem_cgroup_usage_unregister_event (Waiman Long) [1812073]
- [mm] mm: clean up and clarify lruvec lookup procedure (Waiman Long) [1812073]
- [mm] mm: memcontrol: try harder to set a new memory.high (Waiman Long) [1812073]
- [mm] mm: memcontrol: remove dead code from memory_max_write() (Waiman Long) [1812073]
- [mm] mm, memcg: clean up reclaim iter array (Waiman Long) [1812073]
- [mm] mm, memcg: make scan aggression always exclude protection (Waiman Long) [1812073]
- [mm] mm, memcg: make memory.emin the baseline for utilisation determination (Waiman Long) [1812073]
- [mm] mm, memcg: proportional memory.{low, min} reclaim (Waiman Long) [1812073]
- [mm] memcg, kmem: do not fail __GFP_NOFAIL charges (Waiman Long) [1812073]
- [mm] mm: workingset: fix vmstat counters for shadow nodes (Waiman Long) [1812073]
- [mm] mm: memcontrol: use CSS_TASK_ITER_PROCS at mem_cgroup_scan_tasks() (Waiman Long) [1812073]
- [kernel] fork, memcg: alloc_thread_stack_node needs to set tsk->stack (Waiman Long) [1812073]
- [mm] mm/memcontrol.c: fix bad line in comment (Waiman Long) [1812073]
- [kernel] fork, memcg: fix cached_stacks case (Waiman Long) [1812073]
- [mm] mm: don't raise MEMCG_OOM event due to failed high-order allocation (Waiman Long) [1812073]
- [mm] mm: vmscan: memcontrol: remove mem_cgroup_select_victim_node() (Waiman Long) [1812073]
- [mm] mm: vmscan: do not share cgroup iteration between reclaimers (Waiman Long) [1812073]
- [mm] mm: vmscan: do not iterate all mem cgroups for global direct reclaim (Waiman Long) [1812073]
- [mm] mm: workingset: use cheaper __inc_lruvec_state in irqsafe node reclaim (Waiman Long) [1812073]
- [tools] xarray: Fix early termination of xas_for_each_marked (Waiman Long) [1812073]
- [lib] mm: Convert workingset to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert filemap_range_has_page to XArray (Waiman Long) [1812073]
- [mm] page cache: Remove stray radix comment (Waiman Long) [1812073]
- [mm] page cache: Convert delete_batch to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert filemap_map_pages to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert find_get_entries_tag to XArray (Waiman Long) [1812073]
- [mm] page cache; Convert find_get_pages_range_tag to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert find_get_pages_contig to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert find_get_pages_range to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert find_get_entries to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert find_get_entry to XArray (Waiman Long) [1812073]
- [mm] page cache: Convert page deletion to XArray (Waiman Long) [1812073]
- [include] page cache: Add and replace pages using the XArray (Waiman Long) [1812073]
- [mm] page cache: Convert hole search to XArray (Waiman Long) [1812073]
- [kernel] docs: cgroup-v1: Document the cpuset_v2_mode mount option (Waiman Long) [1812073]
- [kernel] cgroup1: don't call release_agent when it is "" (Waiman Long) [1812073]
- [kernel] cgroup: Iterate tasks that did not finish do_exit() (Waiman Long) [1812073]
- [kernel] cgroup: cgroup_procs_next should increase position index (Waiman Long) [1812073]
- [kernel] cgroup-v1: cgroup_pidlist_next should update position index (Waiman Long) [1812073]
- [kernel] cgroup: init_tasks shouldn't be linked to the root cgroup (Waiman Long) [1812073]
- [kernel] cgroup: Prevent double killing of css when enabling threaded cgroup (Waiman Long) [1812073]
- [kernel] cgroup: fix function name in comment (Waiman Long) [1812073]
- [kernel] cgroup: freezer: don't change task and cgroups status unnecessarily (Waiman Long) [1812073]
- [kernel] cgroup: use cgroup->last_bstat instead of cgroup->bstat_pending for consistency (Waiman Long) [1812073]
- [kernel] cgroup: remove cgroup_enable_task_cg_lists() optimization (Waiman Long) [1812073]
- [kernel] cgroup: pids: use atomic64_t for pids->limit (Waiman Long) [1812073]
- [kernel] cgroup: Optimize single thread migration (Waiman Long) [1812073]
- [kernel] cgroup: Update comments about task exit path (Waiman Long) [1812073]
- [kernel] cgroup: short-circuit current_cgns_cgroup_from_root() on the default hierarchy (Waiman Long) [1812073]
- [kernel] Use kvmalloc in cgroups-v1 (Waiman Long) [1812073]
- [kernel] cgroup: minor tweak for logic to get cgroup css (Waiman Long) [1812073]
- [kernel] cgroup: Replace a seq_printf() call by seq_puts() in cgroup_print_ss_mask() (Waiman Long) [1812073]
- [kernel] cgroup: Fix css_task_iter_advance_css_set() cset skip condition (Waiman Long) [1812073]
- [kernel] cgroup: css_task_iter_skip()'d iterators must be advanced before accessed (Waiman Long) [1812073]
- [include] cgroup: Include dying leaders with live threads in PROCS iterations (Waiman Long) [1812073]
- [kernel] cgroup: Implement css_task_iter_skip() (Waiman Long) [1812073]
- [kernel] cgroup/pids: turn cgroup_subsys->free() into cgroup_subsys->release() to fix the accounting (Waiman Long) [1586281 1812073]
- [platform] intel-speed-select: Firmware workarounds for Icelake (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Fix invalid core mask (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Increase CPU count (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Fix json perf-profile output output (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Update version (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Enable clos for turbo-freq enable (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Check support status before enable (Prarit Bhargava) [1840289]
- [tools] tools/power/x86/intel-speed-select: Change debug to error (Prarit Bhargava) [1840289]
- [platform] intel_speed_select: internal-only-debug-patch (Prarit Bhargava) [1840289]

* Wed May 27 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-207.el8]
- [nvdimm] libnvdimm/region: Fix build error (Diego Domingos) [1779218]
- [nvdimm] libnvdimm/region: Introduce an 'align' attribute (Diego Domingos) [1779218]
- [nvdimm] libnvdimm/region: Introduce NDD_LABELING (Diego Domingos) [1779218]
- [nvdimm] libnvdimm/namespace: Enforce memremap_compat_align() (Diego Domingos) [1779218]
- [nvdimm] libnvdimm/pfn: Prevent raw mode fallback if pfn-infoblock valid (Diego Domingos) [1779218]
- [mm] mm/memremap_pages: Introduce memremap_compat_align() (Diego Domingos) [1779218]
- [x86] x86/unwind/orc: Fix unwind_get_return_address_ptr() for inactive tasks (Josh Poimboeuf) [1755143]
- [x86] x86/unwind/orc: Fix error handling in __unwind_start() (Josh Poimboeuf) [1755143]
- [x86] x86/unwind/orc: Fix premature unwind stoppage due to IRET frames (Josh Poimboeuf) [1755143]
- [x86] x86/unwind/orc: Fix error path for bad ORC entry type (Josh Poimboeuf) [1755143]
- [x86] x86/unwind/orc: Prevent unwinding before ORC initialization (Josh Poimboeuf) [1755143]
- [x86] x86/unwind/orc: Don't skip the first frame for inactive tasks (Josh Poimboeuf) [1755143]
- [x86] x86/unwind: Prevent false warnings for non-current tasks (Josh Poimboeuf) [1755143]
- [x86] x86/unwind/orc: Convert global variables to static (Josh Poimboeuf) [1755143]
- [x86] x86/entry/64: Fix unwind hints in rewind_stack_do_exit() (Josh Poimboeuf) [1755143]
- [x86] x86/entry/64: Fix unwind hints in __switch_to_asm() (Josh Poimboeuf) [1755143]
- [x86] x86/entry/64: Fix unwind hints in kernel exit path (Josh Poimboeuf) [1755143]
- [x86] x86/entry/64: Fix unwind hints in register clearing code (Josh Poimboeuf) [1755143]
- [tools] objtool: Fix stack offset tracking for indirect CFAs (Josh Poimboeuf) [1755143]
- [s390] s390: nvme reipl (Philipp Rudo) [1525179]
- [s390] s390: nvme ipl (Philipp Rudo) [1525179]
- [infiniband] RDMA/bnxt_re: make bnxt_re_ib_init static (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Wait for all the CQ events before freeing CQ data structures (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Remove unnecessary sched count (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Fix lifetimes in bnxt_re_task (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Use ib_device_try_get() (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Remove a redundant 'memset' (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Remove set but not used variables 'pg' and 'idx' (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Remove set but not used variable 'dev_attr' (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Remove set but not used variable 'pg_size' (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Use driver_unregister and unregistration API (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor device add/remove functionalities (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Using vmalloc requires including vmalloc.h (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: use ibdev based message printing functions (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor doorbell management functions (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor notification queue management code (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor command queue management code (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor net ring allocation function (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor hardware queue memory allocation (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Replace chip context structure with pointer (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Refactor queue pair creation code (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: remove ioremap_nocache and devm_ioremap_nocache (Selvin Xavier) [1790622]
- [infiniband] RDMA/bnxt_re: Enable SRIOV VF support on Broadcom's 57500 adapter series (Selvin Xavier) [1790622]
- [netdrv] net: be2net: reject unsupported coalescing params (Petr Oros) [1790633]
- [netdrv] treewide: Use sizeof_field() macro (Petr Oros) [1790633]
- [netdrv] net: emulex: benet: indent a Kconfig depends continuation line (Petr Oros) [1790633]
- [infiniband] i40iw: fix null pointer dereference on a null wqe pointer (Stefan Assmann) [1839718]
- [infiniband] RDMA/providers: Fix return value when QP type isn't supported (Stefan Assmann) [1839718]
- [infiniband] RDMA: Replace zero-length array with flexible-array member (Stefan Assmann) [1839718]
- [infiniband] i40iw: Do an RCU lookup in i40iw_add_ipv4_addr (Stefan Assmann) [1839718]
- [infiniband] IB/core: Introduce ib_reg_user_mr (Stefan Assmann) [1839718]
- [infiniband] RDMA/i40iw: fix a potential NULL pointer dereference (Stefan Assmann) [1839718]
- [infiniband] i40iw: Remove setting of VMA private data and use rdma_user_mmap_io (Stefan Assmann) [1839718]
- [infiniband] RDMA/i40iw: Fix potential use after free (Stefan Assmann) [1839718]
- [powerpc] powerpc/pseries: Fix of_read_drc_info_cell() to point at next record (Diego Domingos) [1779198]
- [powerpc] powerpc/pseries: Enable support for ibm, drc-info property (Diego Domingos) [1779198]
- [pci] PCI: rpaphp: Correctly match ibm, my-drc-index to drc-name when using drc-info (Diego Domingos) [1779198]
- [pci] PCI: rpaphp: Avoid a sometimes-uninitialized warning (Diego Domingos) [1779198]
- [pci] PCI: rpaphp: Annotate and correctly byte swap DRC properties (Diego Domingos) [1779198]
- [pci] PCI: rpaphp: Add drc-info support for hotplug slot registration (Diego Domingos) [1779198]
- [pci] PCI: rpaphp: Don't rely on firmware feature to imply drc-info support (Diego Domingos) [1779198]
- [pci] PCI: rpaphp: Fix up pointer to first drc-info entry (Diego Domingos) [1779198]
- [powerpc] powerpc/pseries: Add cpu DLPAR support for drc-info property (Diego Domingos) [1779198]
- [powerpc] powerpc/pseries: Fix drc-info mappings of logical cpus to drc-index (Diego Domingos) [1779198]
- [powerpc] powerpc/pseries: Fix bad drc_index_start value parsing of drc-info entry (Diego Domingos) [1779198]
- [kernel] sched/fair: Optimize enqueue_task_fair() (Phil Auld) [1780466]
- [kernel] sched/fair: Fix enqueue_task_fair() warning some more (Phil Auld) [1780466]
- [kernel] sched/fair: Fix enqueue_task_fair warning (Phil Auld) [1780466]
- [kernel] sched/fair: Fix reordering of enqueue/dequeue_task_fair() (Phil Auld) [1780466]
- [kernel] sched/fair: Reorder enqueue/dequeue_task_fair path (Phil Auld) [1780466]
- [fs] ceph: demote quotarealm lookup warning to a debug message (Jeff Layton) [1827767]
- [fs] ceph: fix double unlock in handle_cap_export() (Jeff Layton) [1827767]
- [fs] ceph: fix special error code in ceph_try_get_caps() (Jeff Layton) [1827767]
- [fs] ceph: fix endianness bug when handling MDS session feature bits (Jeff Layton) [1827767]
- [fs] ceph: fix potential bad pointer deref in async dirops cb's (Jeff Layton) [1827767]
- [block] rbd: don't mess with a page vector in rbd_notify_op_lock() (Jeff Layton) [1827767]
- [block] rbd: don't test rbd_dev->opts in rbd_dev_image_release() (Jeff Layton) [1827767]
- [block] rbd: call rbd_dev_unprobe() after unwatching and flushing notifies (Jeff Layton) [1827767]
- [block] rbd: avoid a deadlock on header_rwsem when flushing notifies (Jeff Layton) [1827767]
- [fs] ceph: fix snapshot directory timestamps (Jeff Layton) [1827767]
- [fs] ceph: wait for async creating inode before requesting new max size (Jeff Layton) [1827767]
- [fs] ceph: don't skip updating wanted caps when cap is stale (Jeff Layton) [1827767]
- [fs] ceph: request new max size only when there is auth cap (Jeff Layton) [1827767]
- [fs] ceph: cleanup return error of try_get_cap_refs() (Jeff Layton) [1827767]
- [fs] ceph: return ceph_mdsc_do_request() errors from __get_parent() (Jeff Layton) [1827767]
- [fs] ceph: check all mds' caps after page writeback (Jeff Layton) [1827767]
- [fs] ceph: update i_requested_max_size only when sending cap msg to auth mds (Jeff Layton) [1827767]
- [fs] ceph: simplify calling of ceph_get_fmode() (Jeff Layton) [1827767]
- [fs] ceph: remove delay check logic from ceph_check_caps() (Jeff Layton) [1827767]
- [fs] ceph: consider inode's last read/write when calculating wanted caps (Jeff Layton) [1827767]
- [fs] ceph: always renew caps if mds_wanted is insufficient (Jeff Layton) [1827767]
- [fs] ceph: update dentry lease for async create (Jeff Layton) [1827767]
- [fs] ceph: attempt to do async create when possible (Jeff Layton) [1827767]
- [fs] ceph: cache layout in parent dir on first sync create (Jeff Layton) [1827767]
- [fs] ceph: add new MDS req field to hold delegated inode number (Jeff Layton) [1827767]
- [fs] ceph: decode interval_sets for delegated inos (Jeff Layton) [1827767]
- [fs] ceph: make ceph_fill_inode non-static (Jeff Layton) [1827767]
- [fs] ceph: perform asynchronous unlink if we have sufficient caps (Jeff Layton) [1827767]
- [fs] ceph: don't take refs to want mask unless we have all bits (Jeff Layton) [1827767]
- [fs] ceph: cap tracking for async directory operations (Jeff Layton) [1827767]
- [fs] ceph: make __take_cap_refs non-static (Jeff Layton) [1827767]
- [fs] ceph: add infrastructure for waiting for async create to complete (Jeff Layton) [1827767]
- [fs] ceph: track primary dentry link (Jeff Layton) [1827767]
- [fs] ceph: add flag to designate that a request is asynchronous (Jeff Layton) [1827767]
- [fs] ceph: more caps.c lockdep assertions (Jeff Layton) [1827767]
- [fs] ceph: clean up kick_flushing_inode_caps() (Jeff Layton) [1827767]
- [net] libceph: directly skip to the end of redirect reply (Jeff Layton) [1827767]
- [net] libceph: simplify ceph_monc_handle_map() (Jeff Layton) [1827767]
- [fs] ceph: return ETIMEDOUT errno to userland when request timed out (Jeff Layton) [1827767]
- [fs] ceph: re-org copy_file_range and fix some error paths (Jeff Layton) [1827767]
- [fs] ceph: move to a dedicated slabcache for mds requests (Jeff Layton) [1827767]
- [fs] ceph: reorganize fields in ceph_mds_request (Jeff Layton) [1827767]
- [fs] ceph: replace zero-length array with flexible-array member (Jeff Layton) [1827767]
- [block] rbd: enable multiple blk-mq queues (Jeff Layton) [1827767]
- [block] rbd: embed image request in blk-mq pdu (Jeff Layton) [1827767]
- [block] rbd: acquire header_rwsem just once in rbd_queue_workfn() (Jeff Layton) [1827767]
- [block] rbd: get rid of img_request_layered_clear() (Jeff Layton) [1827767]
- [block] rbd: kill img_request kref (Jeff Layton) [1827767]
- [fs] ceph: check if file lock exists before sending unlock request (Jeff Layton) [1827767]
- [fs] ceph: move ceph_osdc_{read, write}pages to ceph.ko (Jeff Layton) [1827767]
- [fs] ceph: don't ClearPageChecked in ceph_invalidatepage() (Jeff Layton) [1827767]
- [block] rbd: remove barriers from img_request_layered_{set, clear, test}() (Jeff Layton) [1827767]
- [fs] libceph: drop CEPH_DEFINE_SHOW_FUNC (Jeff Layton) [1827767]
- [fs] ceph: check inode type for CEPH_CAP_FILE_{CACHE, RD, REXTEND, LAZYIO} (Jeff Layton) [1827767]
- [fs] ceph: add refcounting for Fx caps (Jeff Layton) [1827767]
- [fs] ceph: register MDS request with dir inode from the start (Jeff Layton) [1827767]
- [fs] ceph: fix memory leak in ceph_cleanup_snapid_map() (Jeff Layton) [1827767]
- [net] libceph: fix alloc_msg_with_page_vector() memory leaks (Jeff Layton) [1827767]
- [include] ceph: check POOL_FLAG_FULL/NEARFULL in addition to OSDMAP_FULL/NEARFULL (Jeff Layton) [1827767]
- [fs] ceph: canonicalize server path in place (Jeff Layton) [1827767]
- [fs] ceph: do not execute direct write in parallel if O_APPEND is specified (Jeff Layton) [1827767]
- [block] rbd: set the 'device' link in sysfs (Jeff Layton) [1827767]
- [fs] ceph: move net/ceph/ceph_fs.c to fs/ceph/util.c (Jeff Layton) [1827767]
- [fs] ceph: print name of xattr in __ceph_{get, set}xattr() douts (Jeff Layton) [1827767]
- [fs] ceph: print r_direct_hash in hex in __choose_mds() dout (Jeff Layton) [1827767]
- [fs] ceph: use copy-from2 op in copy_file_range (Jeff Layton) [1827767]
- [fs] ceph: close holes in structs ceph_mds_session and ceph_mds_request (Jeff Layton) [1827767]
- [block] rbd: work around -Wuninitialized warning (Jeff Layton) [1827767]
- [fs] ceph: allocate the correct amount of extra bytes for the session features (Jeff Layton) [1827767]
- [fs] ceph: rename get_session and switch to use ceph_get_mds_session (Jeff Layton) [1827767]
- [fs] ceph: remove the extra slashes in the server path (Jeff Layton) [1827767]
- [fs] ceph: add possible_max_rank and make the code more readable (Jeff Layton) [1827767]
- [fs] ceph: print dentry offset in hex and fix xattr_version type (Jeff Layton) [1827767]
- [fs] ceph: only touch the caps which have the subset mask requested (Jeff Layton) [1827767]
- [fs] ceph: don't clear I_NEW until inode metadata is fully populated (Jeff Layton) [1827767]
- [fs] ceph: retry the same mds later after the new session is opened (Jeff Layton) [1827767]
- [fs] ceph: check availability of mds cluster on mount after wait timeout (Jeff Layton) [1827767]
- [fs] ceph: keep the session state until it is released (Jeff Layton) [1827767]
- [fs] ceph: add __send_request helper (Jeff Layton) [1827767]
- [fs] ceph: ensure we have a new cap before continuing in fill_inode (Jeff Layton) [1827767]
- [fs] ceph: drop unused ttl_from parameter from fill_inode (Jeff Layton) [1827767]
- [fs] ceph: fix possible long time wait during umount (Jeff Layton) [1827767]
- [fs] ceph: only choose one MDS who is in up:active state without laggy (Jeff Layton) [1827767]
- [fs] ceph: fix mdsmap cluster available check based on laggy number (Jeff Layton) [1827767]
- [fs] ceph: remove unnecessary assignment in ceph_pre_init_acls() (Jeff Layton) [1827767]
- [fs] ceph: delete redundant douts in con_get/put() (Jeff Layton) [1827767]
- [fs] ceph: hold extra reference to r_parent over life of request (Jeff Layton) [1827767]
- [fs] ceph: add more debug info when decoding mdsmap (Jeff Layton) [1827767]
- [fs] ceph: switch to global cap helper (Jeff Layton) [1827767]
- [fs] ceph: trigger the reclaim work once there has enough pending caps (Jeff Layton) [1827767]
- [fs] ceph: show tasks waiting on caps in debugfs caps file (Jeff Layton) [1827767]
- [fs] fs: ceph: Delete timespec64_trunc() usage (Jeff Layton) [1827767]
- [block] rbd: ask for a weaker incompat mask for read-only mappings (Jeff Layton) [1827767]
- [block] rbd: don't query snapshot features (Jeff Layton) [1827767]
- [block] rbd: remove snapshot existence validation code (Jeff Layton) [1827767]
- [block] rbd: don't establish watch for read-only mappings (Jeff Layton) [1827767]
- [block] rbd: don't acquire exclusive lock for read-only mappings (Jeff Layton) [1827767]
- [block] rbd: disallow read-write partitions on images mapped read-only (Jeff Layton) [1827767]
- [block] rbd: treat images mapped read-only seriously (Jeff Layton) [1827767]
- [block] rbd: introduce RBD_DEV_FLAG_READONLY (Jeff Layton) [1827767]
- [block] rbd: introduce rbd_is_snap() (Jeff Layton) [1827767]
- [fs] ceph: don't leave ino field in ceph_mds_request_head uninitialized (Jeff Layton) [1827767]
- [fs] ceph: tone down loglevel on ceph_mdsc_build_path warning (Jeff Layton) [1827767]
- [fs] ceph: fix geting random mds from mdsmap (Jeff Layton) [1827767]
- [block] rbd: fix spelling mistake "requeueing" -> "requeuing" (Jeff Layton) [1827767]
- [fs] ceph: make several helper accessors take const pointers (Jeff Layton) [1827767]
- [net] libceph: drop unnecessary check from dispatch() in mon_client.c (Jeff Layton) [1827767]
- [fs] ceph: don't allow copy_file_range when stripe_count != 1 (Jeff Layton) [1827767]
- [fs] ceph: allow object copies across different filesystems in the same cluster (Jeff Layton) [1827767]
- [fs] ceph: pass filp to ceph_get_caps() (Jeff Layton) [1827767]
- [fs] ceph: allow copy_file_range when src and dst inode are same (Jeff Layton) [1827767]
- [fs] ceph: increment change_attribute on local changes (Jeff Layton) [1827767]
- [fs] ceph: make 'nocopyfrom' a default mount option (Jeff Layton) [1827767]
- [fs] vfs: allow copy_file_range to copy across devices (Jeff Layton) [1827767]
- [fs] vfs: no fallback for ->copy_file_range (Jeff Layton) [1827767]
- [fs] ceph: add destination file data sync before doing any remote copy (Jeff Layton) [1827767]
- [fs] ceph: new mount option to disable usage of copy-from op (Jeff Layton) [1827767]
- [fs] ceph: support copy_file_range file operation (Jeff Layton) [1827767]
- [include] libceph: support the RADOS copy-from operation (Jeff Layton) [1827767]
- [fs] cachefiles: Fix race between read_waiter and read_copier involving op->to_do (Dave Wysochanski) [1832644]
- [char] security: keys: trusted: fix lost handle flush (Jerry Snitselaar) [1815609]
- [security] KEYS: trusted: Remove set but not used variable 'keyhndl' (Jerry Snitselaar) [1815609]
- [char] KEYS: trusted: Move TPM2 trusted keys code (Jerry Snitselaar) [1815609]
- [security] KEYS: trusted: Create trusted keys subsystem (Jerry Snitselaar) [1815609]
- [security] KEYS: Use common tpm_buf for trusted and asymmetric keys (Jerry Snitselaar) [1815609]
- [char] tpm: Move tpm_buf code to include/linux/ (Jerry Snitselaar) [1815609]
- [char] tpm/tpm_tis: Free IRQ if probing fails (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: Revert tpm_tis_spi_mod.ko to tpm_tis_spi.ko (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: Add tpm_version_major sysfs file (Jerry Snitselaar) [1815609]
- [char] tpm: Handle negative priv->response_len in tpm_common_read() (Jerry Snitselaar) [1815609]
- [char] tpm: fix invalid locking in NONBLOCKING mode (Jerry Snitselaar) [1815609]
- [char] tpm_crb: fix fTPM on AMD Zen+ CPUs (Jerry Snitselaar) [1815609]
- [char] tpm: use GFP_KERNEL instead of GFP_HIGHMEM for tpm_buf (Jerry Snitselaar) [1815609]
- [char] tpm: add check after commands attribs tab allocation (Jerry Snitselaar) [1815609]
- [char] tpm: tpm_tis_spi: Drop THIS_MODULE usage from driver struct (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: tpm_tis_spi: Cleanup includes (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: tpm_tis_spi: Support cr50 devices (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: tpm_tis_spi: Introduce a flow control callback (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: Add a flag to indicate TPM power is managed by firmware (Jerry Snitselaar) [1815609]
- [char] tpm_tis: override durations for STM tpm with firmware 1.2.8.28 (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: provide a way to override the chip returned durations (Jerry Snitselaar) [1815609]
- [char] tpm: Remove duplicate code from caps_show() in tpm-sysfs.c (Jerry Snitselaar) [1815609 1788758]
- [char] tpm: tpm2_bios_measurements_next should increase position index (Jerry Snitselaar) [1815609 1795739]
- [char] tpm: tpm1_bios_measurements_next should increase position index (Jerry Snitselaar) [1815609 1795739]
- [char] tpm: Don't make log failures fatal (Jerry Snitselaar) [1815609 1795739]
- [char] tpm: Initialize crypto_id of allocated_banks to HASH_ALGO__LAST (Jerry Snitselaar) [1815609 1795739]
- [include] efi/tpm: Don't access event->count when it isn't mapped (Jerry Snitselaar) [1815609 1795739]
- [firmware] efi/tpm: Return -EINVAL when determining tpm final events log size fails (Jerry Snitselaar) [1815609 1795739]
- [firmware] efi/tpm: Fix sanity check of unsigned tbl_size being less than zero (Jerry Snitselaar) [1815609 1795739]
- [firmware] efi/tpm: Only set 'efi_tpm_final_log_size' after successful event log parsing (Jerry Snitselaar) [1815609 1795739]
- [firmware] efi/tpm: Don't traverse an event log with no events (Jerry Snitselaar) [1815609 1795739]
- [char] tpm: Don't duplicate events from the final event log in the TCG2 log (Jerry Snitselaar) [1815609 1795739]
- [firmware] Abstract out support for locating an EFI config table (Jerry Snitselaar) [1815609 1795739]
- [firmware] efi: Attempt to get the TCG2 event log in the boot stub (Jerry Snitselaar) [1815609 1795739]
- [char] tpm: Append the final event log to the TPM event log (Jerry Snitselaar) [1815609 1795739]
- [firmware] tpm: Reserve the TPM final events table (Jerry Snitselaar) [1815609 1795739]
- [char] tpm: Abstract crypto agile event size calculations (Jerry Snitselaar) [1815609 1795739]
- [netdrv] bnx2x: Fix accounting of vlan resources among the PFs (Manish Chopra) [1791026]
- [netdrv] bnx2x: Use appropriate define for vlan credit (Manish Chopra) [1791026]
- [netdrv] bnx2x: Fix logic to get total no. of PFs per engine (Manish Chopra) [1791026]
- [netdrv] bnx2x: Do not handle requests from VFs after parity (Manish Chopra) [1791026]
- [netdrv] qed: remove redundant assignment to variable 'rc' (Manish Chopra) [1791024]
- [netdrv] qed: Fix use after free in qed_chain_free (Manish Chopra) [1791024]
- [netdrv] qed: Fix race condition between scheduling and destroying the slowpath workqueue (Manish Chopra) [1791024]
- [netdrv] qede: remove some unused code in function qede_selftest_receive_traffic (Manish Chopra) [1791024]
- [netdrv] qede: Fix race between rdma destroy workqueue and link change event (Manish Chopra) [1791024]
- [netdrv] qed: Fix timestamping issue for L2 unicast ptp packets (Manish Chopra) [1791024]
- [netdrv] qed: Remove set but not used variable 'p_link' (Manish Chopra) [1791024]
- [netdrv] qed: Fix a error code in qed_hw_init() (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 debug features (Manish Chopra) [1791024]
- [netdrv] qed: rt init valid initialization changed (Manish Chopra) [1791024]
- [netdrv] qed: Debug feature: ilt and mdump (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 Add fw overlay feature (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 HSI changes (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 iscsi/fcoe changes (Manish Chopra) [1791024]
- [netdrv] qed: Add abstraction for different hsi values per chip (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 Additional ll2 type (Manish Chopra) [1791024]
- [netdrv] qed: Use dmae to write to widebus registers in fw_funcs (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 Parser offsets modified (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 Queue Manager changes (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 Expose new registers and change windows (Manish Chopra) [1791024]
- [netdrv] qed: FW 8.42.2.0 Internal ram offsets modifications (Manish Chopra) [1791024]
- [netdrv] qede: Disable hardware gro when xdp prog is installed (Manish Chopra) [1791024]
- [netdrv] qed: remove redundant assignments to rc (Manish Chopra) [1791024]
- [netdrv] qed: Optimize execution time for nvm attributes configuration (Manish Chopra) [1791024]
- [netdrv] qed: fix spelling mistake "queuess" -> "queues" (Manish Chopra) [1791024]
- [fs] fs/binfmt_elf.c: allocate initialized memory in fill_thread_core_info() (Bhupesh Sharma) [1832060] {CVE-2020-10732}
- [tty] vt: selection, push sel_lock up (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: selection, push console lock down (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [staging] staging: speakup: refactor to use existing code in vt (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: selection: allow functions to be called from inside kernel (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: don't reinvent min() (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: selection, close sel_buffer race (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: fix broken display when running aptitude (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: selection: take screen contents from uniscr if available (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [tty] vt: preserve unicode values corresponding to screen characters (Chris von Recklinghausen) [1831037] {CVE-2020-8648}
- [input] Input: add safety guards to input_set_keycode() (Chris von Recklinghausen) [1828223] {CVE-2019-20636}

* Tue May 26 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-206.el8]
- [scsi] scsi: bnx2i: fix potential use after free (Nilesh Javali) [1792114]
- [tools] perf python: Fix clang detection to strip out options passed in $CC (Michael Petlan) [1818841]
- [tools] libperf: Add counting example (Michael Petlan) [1818841]
- [tools] perf report/top TUI: Fix title line formatting (Michael Petlan) [1818841]
- [tools] perf probe: Do not depend on dwfl_module_addrsym() (Michael Petlan) [1818841]
- [tools] perf probe: Fix to delete multiple probe event (Michael Petlan) [1818841]
- [tools] perf parse-events: Fix reading of invalid memory in event parsing (Michael Petlan) [1818841]
- [tools] perf python: Fix clang detection when using CC=clang-version (Michael Petlan) [1818841]
- [tools] perf map: Fix off by one in strncpy() size argument (Michael Petlan) [1818841]
- [tools] tools: Let O= makes handle a relative path with -C option (Michael Petlan) [1818841]
- [tools] tools: Fix off-by 1 relative directory includes (Michael Petlan) [1818841]
- [tools] perf jevents: Fix leak of mapfile memory (Michael Petlan) [1818841]
- [tools] perf bench: Clear struct sigaction before sigaction() syscall (Michael Petlan) [1818841]
- [tools] perf bench futex-wake: Restore thread count default to online CPU count (Michael Petlan) [1818841]
- [tools] perf top: Fix stdio interface input handling with glibc 2.28+ (Michael Petlan) [1818841]
- [tools] perf diff: Fix undefined string comparision spotted by clang's -Wstring-compare (Michael Petlan) [1818841]
- [tools] perf symbols: Don't try to find a vmlinux file when looking for kernel modules (Michael Petlan) [1818841]
- [tools] perf bench: Share some global variables to fix build with gcc 10 (Michael Petlan) [1818841]
- [tools] perf parse-events: Use asprintf() instead of strncpy() to read tracepoint files (Michael Petlan) [1818841]
- [tools] perf env: Do not return pointers to local variables (Michael Petlan) [1818841]
- [tools] perf tests bp_account: Make global variable static (Michael Petlan) [1818841]
- [tools] perf annotate: Fix segfault with source toggle (Michael Petlan) [1818841]
- [tools] perf annotate: Align struct annotate_args (Michael Petlan) [1818841]
- [tools] perf annotate: Simplify disasm_line allocation and freeing code (Michael Petlan) [1818841]
- [tools] perf annotate: Remove privsize from symbol__annotate() args (Michael Petlan) [1818841]
- [tools] perf probe: Check return value of strlist__add() for -ENOMEM (Michael Petlan) [1818841]
- [tools] perf config: Document missing config options (Michael Petlan) [1818841]
- [tools] perf annotate: Fix perf config option description (Michael Petlan) [1818841]
- [tools] perf annotate: Prefer cmdline option over default config (Michael Petlan) [1818841]
- [tools] perf annotate: Make perf config effective (Michael Petlan) [1818841]
- [tools] perf config: Introduce perf_config_u8() (Michael Petlan) [1818841]
- [tools] perf annotate: Fix --show-nr-samples for tui/stdio2 (Michael Petlan) [1818841]
- [tools] perf annotate: Fix --show-total-period for tui/stdio2 (Michael Petlan) [1818841]
- [tools] perf annotate/tui: Re-render title bar after switching back from script browser (Michael Petlan) [1818841]
- [tools] perf arch powerpc: Sync powerpc syscall.tbl with the kernel sources (Michael Petlan) [1818841]
- [tools] perf auxtrace: Add auxtrace_record__read_finish() (Michael Petlan) [1818841]
- [tools] perf arm-spe: Fix endless record after being terminated (Michael Petlan) [1818841]
- [tools] perf cs-etm: Fix endless record after being terminated (Michael Petlan) [1818841]
- [tools] perf intel-bts: Fix endless record after being terminated (Michael Petlan) [1818841]
- [tools] perf intel-pt: Fix endless record after being terminated (Michael Petlan) [1818841]
- [tools] perf test: Fix test trace+probe_vfs_getname.sh on s390 (Michael Petlan) [1818841]
- [tools] perf bpf: Remove bpf/ subdir from bpf.h headers used to build bpf events (Michael Petlan) [1818841]
- [tools] perf llvm: Fix script used to obtain kernel make directives to work with new kbuild (Michael Petlan) [1818841]
- [tools] perf tools: Add arm64 version of get_cpuid() (Michael Petlan) [1818841]
- [tools] perf trace: Resolve prctl's 'option' arg strings to numbers (Michael Petlan) [1818841]
- [tools] perf beauty prctl: Export the 'options' strarray (Michael Petlan) [1818841]
- [tools] perf maps: Move kmap::kmaps setup to maps__insert() (Michael Petlan) [1818841]
- [tools] perf maps: Fix map__clone() for struct kmap (Michael Petlan) [1818841]
- [tools] perf maps: Mark ksymbol DSOs with kernel type (Michael Petlan) [1818841]
- [tools] perf maps: Mark module DSOs with kernel type (Michael Petlan) [1818841]
- [tools] perf symbols: Convert symbol__is_idle() to use strlist (Michael Petlan) [1818841]
- [tools] perf symbols: Update the list of kernel idle symbols (Michael Petlan) [1818841]
- [tools] perf stat: Don't report a null stalled cycles per insn metric (Michael Petlan) [1818841]
- [tools] perf probe: Add ustring support for perf probe command (Michael Petlan) [1818841]
- [tools] perf: Make perf able to build with latest libbfd (Michael Petlan) [1818841]
- [tools] perf test: Fix test case Merge cpu map (Michael Petlan) [1818841]
- [tools] perf parse: Copy string to perf_evsel_config_term (Michael Petlan) [1818841]
- [tools] perf parse: Refactor 'struct perf_evsel_config_term' (Michael Petlan) [1818841]
- [tools] perf: Use consistent include paths for libbpf (Michael Petlan) [1818841]
- [tools] perf beauty sockaddr: Fix augmented syscall format warning (Michael Petlan) [1818841]
- [tools] perf/ui/gtk: Fix gtk2 build (Michael Petlan) [1818841]
- [tools] perf ui gtk: Add missing zalloc object (Michael Petlan) [1818841]
- [tools] perf tools: Use define api.pure full instead of pure-parser (Michael Petlan) [1818841]
- [tools] perf tools: Support --prefix/--prefix-strip (Michael Petlan) [1818841]
- [tools] perf report: Clarify in help that --children is default (Michael Petlan) [1818841]
- [tools] tools build: Fix test-clang.cpp with Clang 8+ (Michael Petlan) [1818841]
- [tools] perf clang: Fix build with Clang 9 (Michael Petlan) [1818841]
- [tools] tools lib: Fix builds when glibc contains strlcpy() (Michael Petlan) [1818841]
- [tools] perf report/top: Make 'e' visible in the help and make it toggle showing callchains (Michael Petlan) [1818841]
- [tools] perf report/top: Do not offer annotation for symbols without samples (Michael Petlan) [1818841]
- [tools] perf report/top: Allow pressing hotkeys in the options popup menu (Michael Petlan) [1818841]
- [tools] tools ui popup: Allow returning hotkeys (Michael Petlan) [1818841]
- [tools] perf hists browser: Allow passing an initial hotkey (Michael Petlan) [1818841]
- [tools] perf report/top: Add 'k' hotkey to zoom directly into the kernel map (Michael Petlan) [1818841]
- [tools] perf hists browser: Generalize the do_zoom_dso() function (Michael Petlan) [1818841]
- [tools] perf report/top: Improve toggle callchain menu option (Michael Petlan) [1818841]
- [tools] perf report/top: Add menu entry for toggling callchain expansion (Michael Petlan) [1818841]
- [tools] perf report/top: Make ENTER consistently bring up menu (Michael Petlan) [1818841]
- [tools] perf hists browser: Restore ESC as "Zoom out" of DSO/thread/etc (Michael Petlan) [1818841]
- [tools] tools lib api fs: Fix gcc9 stringop-truncation compilation error (Michael Petlan) [1818841]
- [tools] libperf: Add man pages (Michael Petlan) [1818841]
- [tools] libperf: Move to tools/lib/perf (Michael Petlan) [1818841]
- [tools] perf tests bp_signal: Show expected versus obtained values (Michael Petlan) [1818841]
- [tools] perf sched timehist: Add support for filtering on CPU (Michael Petlan) [1818841]
- [tools] perf record: Adapt affinity to machines with #CPUs > 1K (Michael Petlan) [1818841]
- [tools] perf mmap: Declare type for cpu mask of arbitrary length (Michael Petlan) [1818841]
- [tools] tools bitmap: Implement bitmap_equal() operation at bitmap API (Michael Petlan) [1818841]
- [x86] perf/amd/uncore: Replace manual sampling check with CAP_NO_INTERRUPT flag (Michael Petlan) [1818841]
- [x86] perf/x86/intel: Fix inaccurate period in context switch for auto-reload (Michael Petlan) [1818841]
- [x86] perf/x86/amd: Add missing L2 misses event spec to AMD Family 17h's event map (Michael Petlan) [1818841]
- [x86] perf/x86/msr: Add Tremont support (Michael Petlan) [1818841]
- [x86] perf/x86/cstate: Add Tremont support (Michael Petlan) [1818841]
- [x86] perf/x86/intel: Add Elkhart Lake support (Michael Petlan) [1818841]
- [include] kernel/events: Add a missing prototype for arch_perf_update_userpage() (Michael Petlan) [1818841]
- [x86] perf/x86/amd: Add support for Large Increment per Cycle Events (Michael Petlan) [1818841]
- [x86] perf/x86/amd: Constrain Large Increment per Cycle events (Michael Petlan) [1818841]
- [x86] perf/x86/intel/rapl: Add Comet Lake support (Michael Petlan) [1818841]
- [x86] perf/x86/intel: Explicitly include asm/io.h to use virt_to_phys() (Michael Petlan) [1818841]
- [x86] x86/cpu: Add Elkhart Lake to Intel family (Michael Petlan) [1818841]
- [x86] x86/timer: Don't skip PIT setup when APIC is disabled or in legacy mode (David Arcari) [1837490]
- [x86] x86/intel: Disable HPET on Intel Ice Lake platforms (David Arcari) [1837490]
- [x86] x86/timer: Force PIT initialization when !X86_FEATURE_ARAT (David Arcari) [1837490]
- [x86] x86/timer: Skip PIT initialization on modern chipsets (David Arcari) [1837490]
- [x86] x86/apic: Rename 'lapic_timer_frequency' to 'lapic_timer_period' (David Arcari) [1837490]
- [x86] x86/apic: Unify duplicated local apic timer clockevent initialization (David Arcari) [1837490]
- [vhost] vsock: kick send_pkt worker once device is started (Stefano Garzarella) [1835651]
- [tools] redhat: update kvm/{arm, arm64} headers in tools (Gavin Shan) [1833572]
- [tools] kvm: selftests: aarch64: Use stream when given (Gavin Shan) [1833572]
- [virt] kvm: arm64: Fix 32bit PC wrap-around (Gavin Shan) [1833572]
- [virt] kvm: arm64: vgic-v4: Initialize GICv4.1 even in the absence of a virtual ITS (Gavin Shan) [1833572]
- [arm64] kvm: arm64: Save/restore sp_el0 as part of __guest_enter (Gavin Shan) [1833572]
- [virt] kvm: arm64: vgic-its: Fix memory leak on the error path of vgic_add_lpi() (Gavin Shan) [1833572]
- [virt] kvm: arm64: vgic-v3: Retire all pending LPIs on vcpu destroy (Gavin Shan) [1833572]
- [virt] kvm: arm: vgic-v2: Only use the virtual state when userspace accesses pending bits (Gavin Shan) [1833572]
- [virt] kvm: arm: vgic: Only use the virtual state when userspace accesses enable bits (Gavin Shan) [1833572]
- [virt] kvm: arm: vgic: Synchronize the whole guest on GIC{D, R}_I{S, C}ACTIVER read (Gavin Shan) [1833572]
- [virt] kvm: arm64: psci: Forbid 64bit functions for 32bit guests (Gavin Shan) [1833572]
- [virt] kvm: arm64: psci: Narrow input registers when using 32bit functions (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Update effective affinity of virtual SGIs (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Add support for VPENDBASER's Dirty+Valid signaling (Gavin Shan) [1833572]
- [virt] kvm: arm: vgic: Fix limit condition when writing to GICD_I[CS]ACTIVER (Gavin Shan) [1833572]
- [virt] kvm: arm64: gicv4.1: Expose HW-based SGIs in debugfs (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Eagerly vmap vPEs (Gavin Shan) [1833572]
- [arm64] kvm: arm64: gicv4.1: Allow non-trapping WFI when using HW SGIs (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Add VSGI property setup (Gavin Shan) [1833572]
- [virt] kvm: arm64: gicv4.1: Reload VLPI configuration on distributor enable/disable (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Add VSGI allocation/teardown (Gavin Shan) [1833572]
- [virt] kvm: arm64: gicv4.1: Plumb SGI implementation selection in the distributor (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Move doorbell management to the GICv4 abstraction layer (Gavin Shan) [1833572]
- [virt] kvm: arm64: gicv4.1: Allow SGIs to switch between HW and SW interrupts (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Plumb set_vcpu_affinity SGI callbacks (Gavin Shan) [1833572]
- [virt] kvm: arm64: gicv4.1: Add direct injection capability to SGI registers (Gavin Shan) [1833572]
- [virt] kvm: arm64: gicv4.1: Let doorbells be auto-enabled (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Plumb get/set_irqchip_state SGI callbacks (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Plumb mask/unmask SGI callbacks (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Add initial SGI configuration (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Plumb skeletal VSGI irqchip (Gavin Shan) [1833572]
- [irqchip] gic-v3: Move irq_domain_update_bus_token to after checking for NULL domain (Gavin Shan) [1833572]
- [kernel] irqchip/gic-v4: Use Inner-Shareable attributes for virtual pending tables (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Map the ITS SGIR register page (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Advertise support v4.1 to KVM (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Ensure mutual exclusion betwen invalidations on the same RD (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Wait for completion of redistributor's INVALL operation (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Ensure mutual exclusion between vPE affinity change and RD access (Gavin Shan) [1833572]
- [irqchip] gic-v4.1: Skip absent CPUs while iterating over redistributors (Gavin Shan) [1833572]
- [irqchip] gic-v3: Use SGIs without active state if offered (Gavin Shan) [1833572]
- [irqchip] gic-v4: Provide irq_retrigger to avoid circular locking dependency (Gavin Shan) [1833572]
- [irqchip] gic-v3-its: Probe ITS page size for all GITS_BASERn registers (Gavin Shan) [1833572]
- [irqchip] gic-v3-its: Fix access width for gicr_syncr (Gavin Shan) [1833572]
- [documentation] kvm: arm/arm64: Always capitalize ITS (Gavin Shan) [1833572]
- [nvme] nvme-pci: align io queue count with allocted nvme_queue in nvme_probe (Gopal Tiwari) [1837824]
- [rtc] rtc: cmos: Stop using shared IRQ (Pingfan Liu) [1829667]

* Mon May 25 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-205.el8]
- [netdrv] enic: prevent waking up stopped tx queues over watchdog reset (Govindarajulu Varadarajan) [1797807]
- [kernel] crash_core: Increase crashkernel=auto size for x86_64 & S390 (Kairui Song) [1746644]
- [netdrv] net: iavf: reject unsupported coalescing params (Stefan Assmann) [1781341]
- [netdrv] iavf: Enable support for up to 16 queues (Stefan Assmann) [1781341]
- [netdrv] iavf: use tc_cls_can_offload_and_chain0() instead of chain check (Stefan Assmann) [1781341]
- [netdrv] treewide: Use sizeof_field() macro (Stefan Assmann) [1781341]
- [netdrv] i40e: Remove unneeded conversion to bool (Stefan Assmann) [1781334]
- [netdrv] net: i40e: reject unsupported coalescing params (Stefan Assmann) [1781334]
- [netdrv] intel: Replace zero-length array with flexible-array member (Stefan Assmann) [1781334]
- [netdrv] i40e: Fix the conditional for i40e_vc_validate_vqs_bitmaps (Stefan Assmann) [1781334]
- [netdrv] i40e: fix spelling mistake "to" -> "too" (Stefan Assmann) [1781334]
- [netdrv] i40e: Set PHY Access flag on X722 (Stefan Assmann) [1781334]
- [netdrv] i40e: Fix virtchnl_queue_select bitmap validation (Stefan Assmann) [1781334]
- [netdrv] i40e: Removing hung_queue variable to use txqueue function parameter (Stefan Assmann) [1781334]
- [netdrv] treewide: Use sizeof_field() macro (Stefan Assmann) [1781334]
- [netdrv] i40e: need_wakeup flag might not be set for Tx (Stefan Assmann) [1781334]
- [netdrv] i40e: Fix receive buffer starvation for AF_XDP (Stefan Assmann) [1781334]
- [netdrv] i40e: fix potential RX buffer starvation for AF_XDP (Stefan Assmann) [1781334]
- [block] null_blk: Fix changing the number of hardware queues (Ming Lei) [1835602]
- [block] block: reset mapping if failed to update hardware queue count (Ming Lei) [1835602]
- [block] block: alloc map and request for new hardware queue (Ming Lei) [1835602]
- [block] block: save previous hardware queue count before udpate (Ming Lei) [1835602]
- [block] block: free both rq_map and request (Ming Lei) [1835602]
- [block] blk-mq: Fix a recently introduced regression in blk_mq_realloc_hw_ctxs() (Ming Lei) [1835602]
- [documentation] Documentation: admin-guide: PM: Add intel_idle document (Steve Best) [1485545]
- [idle] intel_idle: Use ACPI _CST on server systems (Steve Best) [1485545]
- [idle] intel_idle: Add module parameter to prevent ACPI _CST from being used (Steve Best) [1485545]
- [idle] intel_idle: Allow ACPI _CST to be used for selected known processors (Steve Best) [1485545]
- [idle] intel_idle: Use ACPI _CST for processor models without C-state tables (Steve Best) [1485545]
- [idle] intel_idle: Refactor intel_idle_cpuidle_driver_init() (Steve Best) [1485545]
- [infiniband] RDMA/uverbs: Move IB_EVENT_DEVICE_FATAL to destroy_uobj (Kamal Heib) [1786608]
- [infiniband] RDMA/uverbs: Do not discard the IB_EVENT_DEVICE_FATAL event (Kamal Heib) [1786608]
- [infiniband] RDMA/core: Fix double put of resource (Kamal Heib) [1786608]
- [infiniband] IB/core: Fix potential NULL pointer dereference in pkey cache (Kamal Heib) [1786608]
- [infiniband] IB/hfi1: Fix another case where pq is left on waitlist (Kamal Heib) [1786608]
- [infiniband] RDMA/rxe: Always return ERR_PTR from rxe_create_mmap_info() (Kamal Heib) [1786608]
- [infiniband] RDMA/core: Fix race between destroy and release FD object (Kamal Heib) [1786608]
- [infiniband] IB/rdmavt: Always return ERR_PTR from rvt_create_mmap_info() (Kamal Heib) [1786608]
- [infiniband] RDMA/core: Fix overwriting of uobj in case of error (Kamal Heib) [1786608]
- [infiniband] RDMA/core: Prevent mixed use of FDs between shared ufiles (Kamal Heib) [1786608]
- [infiniband] RDMA/uverbs: Fix a race with disassociate and exit_mmap() (Kamal Heib) [1786608]
- [infiniband] RDMA/siw: Fix potential siw_mem refcnt leak in siw_fastreg_mr() (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Fix an error check in cm_alloc_id_priv() (Kamal Heib) [1786608]
- [net] svcrdma: Fix trace point use-after-free race (Kamal Heib) [1786608]
- [infiniband] IB/hfi1: Call kobject_put() when kobject_init_and_add() fails (Kamal Heib) [1786608]
- [infiniband] RDMA/rxe: Set sys_image_guid to be aligned with HW IB devices (Kamal Heib) [1786608]
- [infiniband] IB/hfi1: Use scnprintf() for avoiding potential buffer overflow (Kamal Heib) [1786608]
- [infiniband] IB/hfi1: Remove kobj from hfi1_devdata (Kamal Heib) [1786608]
- [infiniband] IB/rdmavt: Delete unused routine (Kamal Heib) [1786608]
- [infiniband] RDMA/rxe: Fix configuration of atomic queue pair attributes (Kamal Heib) [1786608]
- [infiniband] IB/hfi1: Fix memory leaks in sysfs registration and unregistration (Kamal Heib) [1819051 1786608]
- [net] svcrdma: Fix leak of transport addresses (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Update num_paths in cma_resolve_iboe_route error flow (Kamal Heib) [1786608]
- [infiniband] RDMA/siw: Suppress uninitialized var warning (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Add missing locking around id.state in cm_dup_req_handler (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Read id.state under lock when doing pr_debug() (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Remove a race freeing timewait_info (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Fix checking for allowed duplicate listens (Kamal Heib) [1786608]
- [infiniband] RDMA/cm: Fix ordering of xa_alloc_cyclic() in ib_create_cm_id() (Kamal Heib) [1786608]
- [net] svcrdma: Fix double svc_rdma_send_ctxt_put() in an error path (Kamal Heib) [1786608]
- [infiniband] RDMA/core: Remove the duplicate header file (Kamal Heib) [1786608]
- [infiniband] RDMA/siw: Fix passive connection establishment (Kamal Heib) [1786608]
- [infiniband] RDMA/ucma: Put a lock around every call to the rdma_cm layer (Kamal Heib) [1786608]
- [infiniband] RDMA/siw: Fix setting active_{speed, width} attributes (Kamal Heib) [1798583 1786608]
- [scsi] qla2xxx: Update driver version to 10.01.00.25.08.3-k (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Delete all sessions before unregister local nvme port (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix hang when issuing nvme disconnect-all in NPIV (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: make 1-bit bit-fields unsigned int (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix MPI failure AEN (8200) handling (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Move free of fcport out of interrupt context (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix I/Os being passed down when FC device is being deleted (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Set Nport ID for N2N (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Handle NVME status iocb correctly (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Remove restriction of FC T10-PI and FC-NVMe (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Serialize fc_port alloc in N2N (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix NPIV instantiation after FW dump (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Force semaphore on flash validation failure (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: add more FW debug information (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Update BPM enablement semantics (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use a dedicated interrupt handler for 'handshake-required' ISPs (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Return appropriate failure through BSG Interface (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix FCP-SCSI FC4 flag passing error (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Add 16.0GT for PCI String (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use QLA_FW_STOPPED macro to propagate flag (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Add fixes for mailbox command (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix control flags for login/logout IOCB (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Save rscn_gen for new fcport (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use correct ISP28xx active FW region (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use endian macros to assign static fields in fwdump header (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Add endianizer macro calls to fc host stats (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use get_unaligned_*() instead of open-coding these functions (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix the endianness of the qla82xx_get_fw_size() return type (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Improve readability of the code that handles qla_flt_header (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix mtcp dump collection failure (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix stuck session in GNL (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix RIDA Format-2 (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Consolidate fabric scan (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Correct fcport flags handling (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix stuck login session using prli_pend_timer (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use common routine to free fcport struct (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Add D-Port Diagnostic reason explanation logs (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix update_fcport for current_topology (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Cleanup unused async_logout_done (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Add a shadow variable to hold disc_state history of fcport (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Retry PLOGI on FC-NVMe PRLI failure (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix fabric scan hang (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Remove defer flag to indicate immeadiate port loss (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Add debug dump of LOGO payload and ELS IOCB (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Ignore PORT UPDATE after N2N PLOGI (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Don't defer relogin unconditonally (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Send Notify ACK after N2N PLOGI (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Configure local loop for N2N target (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix PLOGI payload and ELS IOCB dump length (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Don't call qlt_async_event twice (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Allow PLOGI in target mode (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Change discovery state before PLOGI (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Drop superfluous INIT_WORK of del_work (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Initialize free_work before flushing it (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Use explicit LOGO in target mode (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Ignore NULL pointer in tcm_qla2xxx_free_mcmd (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: Fix qla2x00_request_irqs() for MSI (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: unregister ports after GPN_FT failure (Nilesh Javali) [1789526]
- [scsi] scsi: qla2xxx: fix rports not being mark as lost in sync fabric scan (Nilesh Javali) [1789526]
- [s390] s390/kexec_file: fix initrd location for kdump kernel (Lianbo Jiang) [1835097]

* Sat May 23 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-204.el8]
- [sound] ALSA: ALSA - update sound configuration (Jaroslav Kysela) [1797509]
- [sound] ALSA: Revert "ALSA: Use the legacy HDA driver as default for Intel DSP platforms" (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: IPC: dai-intel: move ALH declarations in header file (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: add core id to sof_ipc_comp (Jaroslav Kysela) [1797509]
- [sound] ALSA: compress: bump the version (Jaroslav Kysela) [1797509]
- [sound] ALSA: compress: add alac & ape decoder params (Jaroslav Kysela) [1797509]
- [sound] ALSA: compress: Add wma decoder params (Jaroslav Kysela) [1797509]
- [sound] ALSA: compress: add wma codec profiles (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: remove X86 dependency (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: depend on ACPI || OF (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: depend on ACPI (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix regmap dependencies and align with other serial links (Jaroslav Kysela) [1797509]
- [sound] ALSA: treewide: Add SPDX license identifier - Makefile/Kconfig (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix kconfig help format (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: Kconfig: fix help format (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: remove useless prototypes (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: mipi_disco: Switch to use fwnode_property_count_uXX() (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: don't program ports when a stream that has not been prepared (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: fix support for multiple Slaves on the same link (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: do not update parameters during DISABLED-PREPARED transition (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: only prepare stream when it is configured (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: update state machine and add state checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: Documentation: soundwire: Ensure that code is inside the code blocks (Jaroslav Kysela) [1797509]
- [sound] ALSA: Documentation: soundwire: fix stream.rst markup warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: Documentation: soundwire: Add documentation for multi link (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: remove redundant pr_err traces (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: remove unnecessary variable initializations (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: fix disable sequence (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: fix bad unlock balance (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: use sdw_write instead of update (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix PDI/stream mapping for Bulk (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus_type: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: export helpers to find row and column values (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: check first if Slaves become UNATTACHED (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: Add read_only_wordlength flag to port properties (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix device number leak on errors (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: sdw_slave: track unattach_request to handle all init sequences (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: sdw_slave: add initialization_complete definition (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: sdw_slave: add enumeration_complete structure (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: sdw_slave: add probe_complete structure and new fields (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: remove bitfield for unique_id, use u8 (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: make stream name a const pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: Add compute_params callback (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: provide correct return value on error (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: add helper macros for devID fields (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: don't treat CMD_IGNORED as error on ClockStop (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: add clock stop helpers (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix io error when processing alert event (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: avoid multiple assignments (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: disable pm_runtime in sdw_slave_delete (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: add helper to clear Slave status to UNATTACHED (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: write Slave Device Number without runtime_pm (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: add PM/no-PM versions of read/write functions (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: improve dynamic debug comments for enumeration (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: split handling of Device0 events (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix race condition with initialization_complete signaling (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix race condition with enumeration_complete signaling (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix race condition with probe_complete signaling (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: ignore uniqueID when irrelevant (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: slave: add helper to extract slave ID (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: slave: fix scanf format (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: slave: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: core: add device tree support for slave devices (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: set initial value to port_status (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: clear FIFO to avoid pop noise issue on playback start (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: multi-link support (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: commit changes in the exit_reset() sequence (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: remove automatic command retries (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: remove PREQ_DELAY assignment (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: enable NORMAL operation in cdns_init() (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: reorder MCP_CONFIG settings (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: make SSP interval programmable (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: move clock/SSP related inits to dedicated function (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: merge routines to clear/set bits (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: mask Slave interrupt before stopping clock (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: fix a io timeout issue in S3 test (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: add clock_stop/restart routines (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: handle error cases with CONFIG_UPDATE (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: add interface to check clock status (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: simplifiy cdns_init() (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: s/update_config/config_update (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: fix kernel-doc parameter descriptions (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: remove useless variable incrementation (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: update kernel-doc parameter descriptions (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: handle multiple status reports per Slave (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: remove config update for interrupt setting (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: log more useful information during timeouts (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: clear interrupt status before enabling interrupt (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: filter out bad interrupts (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: make clock stop exit configurable on init (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: free all resources on hw_free() (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: add sdw_stream_setup helper for .startup callback (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: add trigger support in sdw dai driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: add prepare support in sdw dai driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: rename res field as link_res (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix factor of two in MCLK handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: update stream callbacks for hwparams/free stream operations (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: update interfaces between ASoC and SoundWire (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix typo in comments (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: use correct header for io calls (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel_init: add kernel module parameter to filter out links (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel_init: add checks on link numbers (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: filter SoundWire controller device search (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: remove empty line after braces (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel_init: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: add helper for initialization (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix intel_register_dai PDI offsets and numbers (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel/cadence: add flag for interrupt enable (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: remove playback/capture stream_name (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: remove DAI_ID_RANGE definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: add missing headers for cross-compilation (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: handle disabled links (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: add debugfs register dump (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: remove unused variables (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: more alignment fixes (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: add hw_reset capability in debugfs (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel/cadence: fix startup sequence (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: improve PDI allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: don't filter out PDI0/1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence/intel: simplify PDI/port mapping (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: add debugfs register dump (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: move shutdown() callback and don't export symbol (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix alignment issues in header files (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix SPDX license for header files (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: add kernel parameter to override interrupt mask (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: fix divider setting in clock register (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: make use of mclk_freq property (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: use firmware defaults for frame shape (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: revisit interrupt settings (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: fix definitions for INTSTAT0/1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: fix register definition for SLAVE_STATE (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: simplify bus clash interrupt clear (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: check the number of bidir PDIs (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: log Slave status mask on errors (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: use rate_limited dynamic debug (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: remove spurious newline (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: fix boolean comparisons (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: balance parentheses (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence_master: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cdns: Fix compilation error on arm64 (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: cadence: remove empty line after braces (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: read mclk_freq property from firmware (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix channel number reported by hardware (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: prevent possible dereference in hw_params (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: remove BIOS work-arounds (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: set dai min and max channels correctly (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: Intel: add log for number of PCM and PDM PDIs (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: add debugfs support (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: add new mclk_freq field for properties (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: include mod_devicetable.h to avoid compiling warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: rename/clarify MIPI DisCo properties (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: clarify comment (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: mipi-disco: fix clock stop modes (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: mipi-disco: remove master_count property for masters (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: remove master data port properties (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: add port-related definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: wrap macro argument in parenthesis (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: rename 'freq' fields (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: mipi_disco: fix master/link error (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: mipi_disco: fix boolean comparisons (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: mipi_disco: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: fix out of boundary access on port properties (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: add a blank line between functions (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix more typos (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: more alignment fixes (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: remove empty line before/after braces (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: add missing newlines in dynamic debug logs (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: stream: remove useless initialization of local variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix boolean comparison (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: protect macro parameters (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix implicit header use of module.h/export.h (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: intel: fix inversion in devm_kcalloc parameters (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: remove spurious newline (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix boolean comparisons (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: remove useless parentheses (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix typos in comments (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: bus: fix alignment issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: remove useless initializations (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: fix SPDX license for header files (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm-dai: Add SNDRV_PCM_INFO_BATCH flag (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm-dai: add support for ALAC and APE decoders (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm-dai: add support to wma decoder (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: only enable dais from device tree (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm: add support for alac and ape configs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm: add support to wma config (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm: pass codec profile to q6asm_open_write (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qdsp6: q6routing: remove default routing (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sprd: Allow the MCDT driver to build into modules (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: q6dsp6: q6afe-dai: add missing channels to MI2S DAIs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: lpass-platform: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: common: Silence duplicate parse error messages (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: sdm845: handle soundwire stream (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: Update dependencies for Arizona machine drivers (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: qcom: add support for get_sdw_stream() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: use for_each_rtd_codecs/cpus_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soundwaire: qcom: use for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: soundwire: qcom: add support for SoundWire controller (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: sdm845: use for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rockchip: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: s3c24xx-i2s: Fix build after removal of DAI suspend/resume (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: Silence warnings during deferred probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: fsi: Restore devm_ioremap() alignment (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: dma: set bus width to data width for monaural data (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: Fix "status check failed" spam for multi-SSI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: Don't treat master SSI in multi SSI setup as parent (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: Fix parent SSI start/stop in multi-SSI mode (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: Fix HDMI channel mapping for multi-SSI mode (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sprd: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: i2s: manage rebind issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: i2s: improve error management on probe deferral (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: i2s: manage error when getting reset controller (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: manage error when getting reset controller (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: improve error management on probe deferral (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: fix sai probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: soc/stm/stm32_sub_sai: Add missing '\n' in log messages (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: Add missing cleanup (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: manage rebind issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: fix regmap status check (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: improve error management on probe deferral (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: manage error when getting reset controller (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sunxi: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sun8i-codec: Remove unused dev from codec struct (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: Support DAPM events for built-in microphone (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tegra: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: davinci-mcasp: remove redundant assignment to variable ret (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Add support for platforms using UDMA (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: Add udma-pcm platform driver for UDMA (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: txx9: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: uniphier: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ux500: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xtensa: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: zte: zx-spdif: remove redundant dev_err message (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: zte: zx-tdm: remove redundant variables dev (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: use for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mxs: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: use for_each_rtd_codecs/cpus_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: use for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: use SND_SOC_DAPM_PINCTRL in TDM out (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: apply some refactors (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: pull TDM GPIO pins down when probed (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: change supported formats of DL2 and UL1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219: add speaker switch (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650: support HDMI jack reporting (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: kirkwood: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740-i2s: Add support for the JZ4770 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740-i2s: Add support for the JZ4760 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740-i2s: Avoid passing enum as match data (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740-i2s: Add local dev variable in probe function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740: Use of_device_get_match_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740-i2s: Fix divider written at incorrect offset in register (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: img: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: generic: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: simple-card-utils: use for_each_pcm_streams() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: simple-card: Add support for codec2codec DAI links (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: fsl_asrc_dma: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dwc: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dwc: dwc-i2s: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: cirrus: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bcm: Fix pointer cast warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bcm: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: brcm: Add DSL/PON SoC audio driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: au1x: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mchp-i2s-mcc: make signed 1 bit bitfields unsigned (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Allow I2S wake event after ACP is powerd On (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: acp3x-pcm-dma: clean up two indentation issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: AMD: Clear format bits before setting them (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Adding TDM support in hw_params (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Fix button configuration (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoc: amd: acp3x: Add missing include <linux/io.h> (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Fix compile warning of argument type (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoc: amd: Add DMIC switch capability to machine driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Add machine driver for Raven based platform (Jaroslav Kysela) [1797509]
- [sound] ALSA: usx2y: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: usx2y: Fix potential NULL dereference (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add registration quirk for Kingston HyperX Cloud Alpha S (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Apply async workaround for Scarlett 2i4 2nd gen (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Correct a typo of NuPrime DAC-10 USB ID (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add Pioneer DJ DJM-250MK2 quirk (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add quirk for Focusrite Scarlett 2i2 (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Use pcm_for_each_format() macro for PCM format iterations (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix missing braces in some struct inits (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix usb audio refcnt leak when getting spdif (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add connector notifier delegation (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add static mapping table for ALC1220-VB-based mobos (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Check mapping at creating connector controls, too (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add mixer workaround for TRX40 and co (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Don't create jack controls for PCM terminals (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Don't override ignore_ctl_error value from the map (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Filter error from connector kctl ops, too (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix mixer controls' USB interface for Kingston HyperX Amp (0951:16d8) (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Parse source ID of UAC2 effect unit (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: audio-v2: Add uac2_effect_unit_descriptor definition (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Don't create a mixer element with bogus volume range (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix case when USB MIDI interface has more than one extra endpoint descriptor (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-midi: Replace zero-length array with flexible-array member (Jaroslav Kysela) [1797509]
- [sound] ALSA: line6: Fix POD HD500 audio playback (Jaroslav Kysela) [1797509]
- [sound] ALSA: line6: Fix endless MIDI read loop (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Filter out unsupported sample rates on Focusrite devices (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add support for Presonus Studio 1810c (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add support for MOTU MicroBook IIc (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Inform devices that need delayed registration (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add delayed_register option (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Rewrite registration quirk handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Create a registration quirk for Kingston HyperX Amp (0951:16d8) (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd9335: fix address map representation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: Remove some unnecessary NULL checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: remove unused headers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: fix High Accuracy Buck enable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: Remove set but not unused variable 'hph_comp_ctrl7' (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm0010: Replace zero-length array with flexible-array member (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8960: Fix wrong clock after suspend & resume (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: wsa881x: remove soundwire stream handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: wsa881x: request gpio direction before setting (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wsa881x: mark read_only_wordlength flag (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8974: remove unused variables (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm_adsp: Use scnprintf() for the limited buffer output (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas571x: disable regulators on failed probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Fixed incorrect amp_level setting (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Add support for ISENSE and VSENSE (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Add entries for the TAS2563 audio amplifier (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Add support for digital volume control (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sgtl5000: Fix VAG power-on handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1015: modify some structure to be static (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Fix SND_SOC_ALL_CODECS imply ac97 fallout (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm89xx: Add missing dependency (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: fix unmet dependencies (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Fix SND_SOC_ALL_CODECS imply misc fallout (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: adau7118: Fix Kconfig warning without CONFIG_I2C (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Fix SND_SOC_ALL_CODECS imply I2C fallout (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Fix SND_SOC_ALL_CODECS imply SPI fallout (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682-sdw: fix 'defined but not used' pm functions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Make rt5682_clock_config static (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Fix build error without CONFIG_I2C (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: move DAI clock registry to I2S mode (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Add a property for DMIC delay (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Add a property for DMIC clock rate (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: remove noisy debug messages (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: fix the random recording noise of headset (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Fine tune the HP performance in soundwire mode (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Revise the DAC1 volume setting (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Revise the function name (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Add the soundwire support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Use imply for SND_SOC_ALL_CODECS (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Add CCF usage for providing I2S clks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Enable PLL2 function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: Add the field "is_sdw" of private data (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5659: remove redundant assignment to variable idx (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5645: Add platform-data for Medion E1239T (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1308-sdw: use slot and rx_mask to configure stream (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1308-sdw: add set_tdm_slot() support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1015: fix typo for bypass boost control (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rl6231: Add new supports on rl6231 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rockchip: Make RK3328 GPIO_MUTE control explicit (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: MT6660: make spdxcheck.py happy (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: MT6660 update to 1.0.8_G (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98357a: Add ACPI HID MAX98360A (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98357a: move control of SD_MODE to DAPM (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: hdac_hdmi: Fix incorrect use of list_for_each_entry (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: hdac_hdmi: (cosmetic) remove redundant variable initialisations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: cs4270: pull reset GPIO low then high (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: allow operation without i915 gfx (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix ordering bug in resume flow (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: add parameter to control SoundWire clock stop quirks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: initial SoundWire machine driver autodetect (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: add SoundWire stream config/free callbacks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Account for compress streams when servicing IRQs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Fix stream cleanup on hw free (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda-loader: clear the IPC ack bit after FW_PURGE done (Jaroslav Kysela) [1797509]
- [sound] ALSA: Asoc: SOF: Intel: hda: check SoundWire wakeen interrupt in irq thread (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: add WAKEEN interrupt support for SoundWire (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: merge IPC, stream and SoundWire interrupt handlers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: add SoundWire configuration interface (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Expose SDnFMT helpers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Fix probe point getter (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: pcm: skip DMA buffer pre-allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Turn "firmware boot complete" message into a dbg message (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: ipc: check ipc return value before data copy (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sof: sof-audio: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Do not reset hw_params for streams that ignored suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: audio: Add helper to check if only D0i3 streams are active (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Add i.MX8QM device descriptor (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Remove SOF_IPC_EXT_DMA_BUFFER (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Make sof_ipc_ext_data enum more rigid (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: fix uninitialised "work" with VirtIO (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: (cosmetic) use for_each_pcm_streams() in sof_dai_load() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: connect dai widget to all cpu-dais (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove unnecessary ROM IPC filter function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda-dai: add stream capability (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda-ctrl: add reset cycle before parsing capabilities (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: call codec wake at chip init (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: do not leave clock gating off upon error (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: disable SoundWire interrupts on suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sof: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: Improve DSP state logging (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: use snd_sof_dsp_set_power_state() op (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: Allow trace DMA in S0 when DSP is in D0I3 for debug (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: Amend the DSP state transition diagram (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: cnl: Implement feature to support DSP D0i3 in S0 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: remove unnecessary waitq before loading firmware (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: add min/max channels for SSP on Baytrail/Broadwell (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove SND_SOC_SOF_HDA_COMMON_HDMI_CODEC (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Probe compress operations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Fix Kconfig indentation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx8: Add ops for i.MX8QM (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Rename i.MX8 platform to i.MX8X (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Provide probe debugfs support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Move DSP power state transitions to platform-specific ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: pm: Introduce DSP power states (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: pm: Unify suspend/resume routines (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Add Probe compress CPU DAIs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Generic probe compress operations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Implement Probe IPC API (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: use for_each_rtd_codecs/cpus_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: kbl_da7219_max98927: use for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: cml_rt1011_rt5682: use for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: haswell: Remove ignore_suspend flag from SSP0 dai link (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: BXT: switch pcm512x based boards to sof_pcm512x (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: CHT: add support for pcm512x boards (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: soc-acpi-intel-icl-match: remove useless 'rt1308_2_adr' (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: soc-acpi-intel-cml-match: remove useless 'rt1308_2_adr' (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_pcm512x: drop reverse deps for SND_HDA_CODEC_HDMI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_rt5682: Add support for tgl-max98373-rt5682 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_rt5682: Add rt1015 speaker amp support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: drop reverse deps for SND_HDA_CODEC_HDMI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_sdw: Add Volteer support with RT5682 SNDW helper function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: add sof_sdw machine driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: add match table for TGL RT5682 SoundWire driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: soc-acpi: update topology and driver name for SoundWire platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: Add mach table for tgl-max98373-rt5682 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-acpi: expand description of _ADR-based devices (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Await purge request ack on CNL (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Allow for ROM init retry on CNL platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: skylake: (cosmetic) remove redundant variable initialisations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Enable codec wakeup during chip init (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Select hda configuration permissively (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Remove superfluous chip initialization (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Shield against no-NHLT configurations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: sof_da7219_max98373: Add speaker switch (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_da7219_max98373: Add support for max98360a speaker amp (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_ssm4567: disable route checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel/skl/hda - add no-HDMI cases to generic HDA driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Make glk+rt5682 echo ref dynamic (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: don't use GFP_ATOMIC for machine driver contexts (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN MPWIN895CL tablet (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: broadwell: Remove ignore_suspend flag from SSP0 dai link (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: broadwell: Revert back SSP0 link to use dummy components (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: Remove ignore_suspend flag from SSP0 dai link (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: Revert SSP0 link to use dummy components (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5650: Remove ignore_suspend flag from SSP0 dai link (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5650: Revert SSP0 link to use dummy components (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: (cosmetic) simplify structure member access (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: atom: Fix uninitialized variable compiler warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: mrfld: return error codes when an error occurs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro for DAI pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_pcm512x: make HDMI optional for all platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_pcm512x: add support for SOF platforms with pcm512x (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: mrfld: fix incorrect check on p->sink (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: atom: Check drv->lock is locked in sst_fill_and_send_cmd_unlocked (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: atom: Take the drv->lock mutex before calling sst_send_slot_map() (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Use scnprintf() for string truncation (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Allow setting preallocation again for x86 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Fix endianness issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check return value of soc_tplg_dai_config (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check return value of pcm_new_ver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Add missing memory checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check soc_tplg_add_route return value (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check return value of soc_tplg_*_create (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check return value of soc_tplg_create_tlv (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: use name_prefix for new kcontrol (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Perform component check upfront (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fix regwmask (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-generic-dmaengine-pcm: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dapm: Merge for_each_rtd_cpu/codec_dais() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: Remove dapm_connect_dai_link_widgets helper (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: Move error message to avoid some duplication (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: select sleep_state when initializing PINCTRL widget (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: connect virtual mux with default value (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: fixup dapm kcontrol widget (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dai: revert all changes to DAI startup/shutdown sequence (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dai: fix DAI startup/shutdown sequence (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dai: return proper error for get_sdw_stream() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dai: add get_sdw_stream() callback (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: export DPCM runtime update functions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dpcm: allow start or stop during pause for backend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: Merge for_each_rtd_cpu/codec_dais() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: (cosmetic) simplify dpcm_prune_paths() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: Merge for_each_rtd_cpu/codec_dais() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: Merge CPU/Codec for soc_dai_pcm_new() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: Fix regression introducing multiple copies of DAI widgets (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add asoc_rtd_to_cpu/codec() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: Merge CPU/Codec DAIs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dapm: add for_each_card_widgets() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dapm: add for_each_card_dapms() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc.h: remove non plural form for_each_xxx macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc.h: add for_each_rtd_codecs/cpus_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc: use for_each_rtd_codecs/cpus_dai() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: disable route checks for legacy devices (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Add initial support for multiple CPU DAIs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fix card registration regression (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dapm: don't use rtd->cpu_dai on for_each_rtd_cpu_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Add multiple CPU DAI support in DAPM (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Add dapm_add_valid_dai_widget helper (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: Do Digital Mute for both CPU/Codec in same timing (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: check DAI's activity more simply (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: tidyup dulicate handing at dpcm_fe_dai_startup() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use snd_soc_dai_get_pcm_stream() at dpcm_set_fe_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add dpcm_fe_dai_cleanup() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: move dpcm_fe_dai_close() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm: Export parameter intersection logic (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: remove duplicate be check from dpcm_add_paths() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use defined stream (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm: check if cpu-dai supports a given stream (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Return error if the function does not support multi-cpu (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Add multiple CPU DAI support for PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: fix state tracking error in snd_soc_component_open/close() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: move dpcm_path_put() to soc-pcm.c (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: merge dpcm_run_new/old_update() into dpcm_fe_runtime_update() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add snd_soc_dai_get_widget() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: cleanup soc_pcm_apply_msb() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add snd_soc_dai_get_pcm_stream() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm/soc-compress: don't use snd_soc_dapm_stream_stop() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dpcm: remove confusing trace in dpcm_get_be() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm: Fix possible buffer overflow in dpcm state sysfs output (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use for_each_pcm_streams() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: merge playback/cature_active into stream_active (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use goto and remove multi return (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add snd_soc_dpcm_can_be() and remove duplicate code (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: remove snd_soc_dpcm_be_get/set_state() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: remove soc_dpcm_be_digital_mute() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use dpcm_get_be() at dpcm_end_walk_at_be() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use dai_get_widget() at dpcm_end_walk_at_be() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: use dai_get_widget() at dpcm_get_be() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: move dai_get_widget() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: fix regression in soc_new_pcm() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: tidyup soc_pcm_open() order (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: move soc_pcm_close() next to soc_pcm_open() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: adjustment for DAI member 0 reset (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: call snd_soc_component_open/close() once (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: don't use bit-OR'ed error (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm/soc-compress: use snd_soc_dapm_stream_stop() for SND_SOC_DAPM_STREAM_STOP (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add for_each_dapm_widgets() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add snd_soc_runtime_action() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: call snd_soc_dai_startup()/shutdown() once (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: ensure component names are unique (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: allow a dt node to provide several components (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu8000: Fix the cast to __user pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: opti9xx: shut up gcc-10 range warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire-tascam: Add missing annotation for tscm_hwdep_read_queue() (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire-tascam: Add missing annotation for tscm_hwdep_read_locked() (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire: use KBUILD_MODNAME for struct driver.name instead of string (Jaroslav Kysela) [1797509]
- [sound] ALSA: via82xx: Fix endianness annotations (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdsp: remove redundant assignment to variable err (Jaroslav Kysela) [1797509]
- [sound] ALSA: korg1212: fix if-statement empty body warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1724: Fix invalid access for enumerated ctl items (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Two front mics on a Lenovo ThinkCenter (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add new codec supported for ALC245 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Fix unexpected init_amp override (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable the headset mic on Asus FX505DT (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add quirk for MSI GL63 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add HP new mute led supported for ALC236 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add supported new mute Led for HP (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add quirk for Lenovo Carbon X1 8th gen (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Remove now-unnecessary XPS 13 headphone noise fixups (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Set principled PC Beep configuration for ALC256 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - a fake key event is triggered by running shutup (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek: Enable mute LED on an HP system (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable the headset of Acer N50-600 with ALC662 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable headset mic of Acer X2660G with ALC662 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek: Fix pop noise on ALC225 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: Move ELD parse and jack reporting into update_eld() (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: Move runtime PM resume into hdmi_present_sense_via_verbs() (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: Don't use standard hda_jack for generic HDMI jacks (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: Reduce hda_jack_tbl lookup at unsol event handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: drm/nouveau: Fix regression by audio component transition (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: fix without unlocked before return (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: fix race in monitor detection during probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi: Add module option to disable audio component binding (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/ca0132 - Replace zero-length array with flexible-array member (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/ca0132 - Add Recon3Di quirk to handle integrated sound on EVGA X99 Classified motherboard (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Match both PCI ID and SSID for driver blacklist (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Remove ASUS ROG Zenith from the blacklist (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: call runtime_allow() for all hda controllers (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Explicitly permit using autosuspend if runtime PM is supported (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Keep the controller initialization even if no codecs found (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Release resources at error in delayed probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Honor PM disablement in PM freeze and thaw_noirq ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Don't release card at firmware loading error (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Add driver blacklist (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: remove redundant assignment to variable timeout (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda_codec: Replace zero-length array with flexible-array member (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Always use jackpoll helper for jack update after resume (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Skip controller resume if not needed (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Fix potential access overflow in beep helper (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: default enable CA0132 DSP support (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: Fix endianness annotations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctxfi: Remove unnecessary cast in kfree (Jaroslav Kysela) [1797509]
- [sound] ALSA: ali5451: remove redundant variable capture_flag (Jaroslav Kysela) [1797509]
- [sound] ALSA: dummy: Use standard macros for fixing PCM format cast (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Fix PCM format assignment (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Use a macro for parameter masks to reduce the needed cast (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Minor refactoring (Jaroslav Kysela) [1797509]
- [sound] ALSA: dmaengine_pcm: No need to take runtime reference twice in pcm_pointer (Jaroslav Kysela) [1797509]
- [sound] ALSA: dmaengine_pcm: Consider DMA cache caused delay in pointer callback (Jaroslav Kysela) [1797509]
- [sound] ALSA: dmaengine_pcm: Consider DMA cache caused delay in pointer callback (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm_dmaengine: Use pcm_for_each_format() macro for PCM format iteration (Jaroslav Kysela) [1797509]
- [sound] ALSA: core: Replace zero-length array with flexible-array member (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Fix superfluous snprintf() usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Place the plugin buffer overflow checks correctly (for 5.7) (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Fix regression by buffer overflow fix (again) (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Remove WARNING from snd_pcm_plug_alloc() checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Simplify plugin frame size calculations (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Avoid plugin buffer overflow (Jaroslav Kysela) [1797509]
- [sound] ALSA: info: remove redundant assignment to variable c (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Unlock mutex temporarily for sleeping at read/write (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Use standard macros for fixing PCM format cast (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Add a standalone version of snd_pcm_limit_hw_rates (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: More helper macros for reducing snd_pcm_format_t cast (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm.h: add for_each_pcm_streams() (Jaroslav Kysela) [1797509]
- [sound] ALSA: core: Add snd_device_get_state() helper (Jaroslav Kysela) [1797509]
- [sound] ALSA: core: Implement compress page allocation and free routines (Jaroslav Kysela) [1797509]
- [sound] ALSA: core: Expand DMA buffer information (Jaroslav Kysela) [1797509]
- [sound] ALSA: uapi: Fix sparse warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: control: Fix incompatible protocol error (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctl: bump protocol version up to v2.1.0 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctl: remove unused macro for timestamping of elem_value (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: use __u32 instead of uint32_t in uapi headers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: uapi: remove unused sof header files (Jaroslav Kysela) [1797509]
- [sound] ALSA: uapi: Drop unneeded typedefs (Jaroslav Kysela) [1797509]
- [sound] ALSA: uapi: Add linux/types.h include back (but carefully) (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdspm: Drop linux/types.h inclusion in uapi header (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Spelling s/configr/configur/ (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: fix for_rtd_codec_dai_rollback() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dpcm: tidyup for_each_dpcm_xx() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: simple_card_utils.h: Fix potential multiple redefinition error (Jaroslav Kysela) [1797509]
- [sound] ALSA: rawmidi: Avoid bit fields for state flags (Jaroslav Kysela) [1797509]
- [sound] ALSA: memalloc: Drop snd_dma_pci_data() macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: solo6x10: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: cs231xx: Clean up ALSA PCM API usages (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: em28xx: Clean up ALSA PCM API usages (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: delete unused proc_fs.h include (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: em28xx-audio: use GFP_KERNEL for memory allocation during init (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: go7007: Clean up ALSA PCM API usages (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: tm6000: Clean up ALSA PCM API usages (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: usbtv: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: solo6x10: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: tw686x: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: media: tw686x: audio: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: Allow const arrays for legacy resource management helpers (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcmcia: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: pdaudiocf: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: pdaudiocf: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: pdaudiocf: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcmcia: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: pdaudiocf: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: parisc: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: parisc: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: parisc: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire-tascam: fix corruption due to spin lock without restoration in SoftIRQ context (Jaroslav Kysela) [1797509]
- [sound] ALSA: oxfw: fix for Stanton SCS.1d (Jaroslav Kysela) [1797509]
- [sound] ALSA: oxfw: don't add MIDI/PCM interface when packet streaming is unavailable (Jaroslav Kysela) [1797509]
- [sound] ALSA: oxfw: fix return value in error path of isochronous resources reservation (Jaroslav Kysela) [1797509]
- [sound] ALSA: oxfw: use ENXIO for not-supported cases (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire-motu: fix double unlocked 'motu->mutex' (Jaroslav Kysela) [1797509]
- [sound] ALSA: fireface: fix return value in error path of isochronous resources reservation (Jaroslav Kysela) [1797509]
- [sound] ALSA: dice: loosen stream format check for MIDI conformant data channel (Jaroslav Kysela) [1797509]
- [sound] ALSA: dice: fix fallback from protocol extension into limited functionality (Jaroslav Kysela) [1797509]
- [sound] ALSA: dice: add support for Alesis MasterControl (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: firewire: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: emux: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: spi: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: spi: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: spi: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: spi: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: spi: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: sparc: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: sparc: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: sparc: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: sparc: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: sparc: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: sparc: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Apply 48kHz fixed rate playback for Jabra Evolve 65 headset (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: add quirks for Line6 Helix devices fw>=2.82 (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add clock validity quirk for Denon MC7000/MCX8000 (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Apply sample rate quirk for Audioengine D1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix UAC2/3 effect unit parsing (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Annotate endianess in Scarlett gen2 quirk (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix endianess in descriptor validation (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: add implicit fb quirk for MOTU M Series (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: unlock on error in probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: fix sync-ep altsetting sanity check (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add boot quirk for MOTU M Series (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: update old-style static const declaration (Jaroslav Kysela) [1797509]
- [sound] ALSA: bcd2000: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: usx2y: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: caiaq: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Use lower hex numbers for IDs (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Apply the sample rate quirk for Bose Companion 5 (Jaroslav Kysela) [1797509]
- [sound] ALSA: usx2y: Constify struct snd_usb_audio_quirk entries (Jaroslav Kysela) [1797509]
- [sound] ALSA: line6: Constify snd_ratden definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: Constify snd_pcm_hardware definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: fix Corsair Virtuoso mixer label collision (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: fix set_format altsetting sanity check (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: set the interface format after resume on Dell WD19 (Jaroslav Kysela) [1797509]
- [sound] ALSA: usx2y: Adjust indentation in snd_usX2Y_hwdep_dsp_status (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: usx2y: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ua101: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: line6: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: hiface: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: caiaq: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: 6fire: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix Focusrite Scarlett 6i6 gen1 - input handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix NULL dereference at parsing BADD (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix Scarlett 6i6 Gen 2 port data (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Add skip_validation option (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix incorrect size check for processing/extension units (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix incorrect NULL check in create_yamaha_midi_quirk() (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: not submit urb for stopped endpoint (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Fix missing error check at mixer resolution test (Jaroslav Kysela) [1797509]
- [sound] ALSA: ua101: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: hiface: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: caiaq: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: 6fire: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb-audio: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: 6fire: Drop the dead code (Jaroslav Kysela) [1797509]
- [sound] ALSA: usb: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: intel_hdmi: Remove dev_err() on platform_get_irq() failure (Jaroslav Kysela) [1797509]
- [sound] ALSA: x86: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdml-lpe-audio: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: xen: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: atmel: Constify snd_ac97_bus_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: arm: Constify snd_ac97_bus_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: arm: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: aoa: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: aoa: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: aoa: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: aoa: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ac97: Constify snd_ac97_bus_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: wss: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: wss: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: wavefront: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: sc6000: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: sb: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: sb: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: opti9xx: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: opti9xx: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: opl3sa2: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: msnd: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: gus: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: gus: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: es18xx: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: es18xx: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1688: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1688: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1688: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs423x: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs4236: fix error return comparison of an unsigned integer (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmi8330: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmi8328: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: isa: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: isa: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ad1816a: constify copied structure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ad1816a: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: isa: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xlnx: Use devm_platform_ioremap_resource() in xlnx_formatter_pcm_probe() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xtensa: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xtensa: xtfpga-i2s: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xilinx: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xilinx: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xilinx: xlnx_formatter_pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: uniphier: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: uniphier: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: uniphier: aio-dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: txx9: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: txx9: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: txx9: txx9aclc: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: sdma-pcm: Add back the flags parameter for non standard dma names (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tegra: disable rx_fifo after disable stream (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tegra: add a TDM configuration callback (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sunxi: sun4i-codec: remove unneeded semicolon (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: fix race condition in irq handler (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: retry synchronization in sync state (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: manage rebind issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: fix possible circular locking (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: add restriction on mmap support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: fix sysclk management on shutdown (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: sai: clean up indentation issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: dfsdm: fix 16 bits record (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm: stm32_adfsdm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sprd: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sprd: sprd-pcm-dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: ipc: Fix memory leak in sof_set_get_large_ctrl_data (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: fix the CONFIG_ prefix missing (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx8: fix memory allocation failure check on priv->pd_dev (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: utils: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-utils: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-ops: use snd_soc_card_get_kcontrol() at snd_soc_limit_volume() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: generic-dmaengine-pcm: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: generic-dmaengine: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-generic-dmaengine-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: do error check after rsnd_channel_normalization() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: dma: fix SSI9 4/5/6/7 busif dma address (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsi: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: fsi: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rcar: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: core.c: add WARN_ON() on rsnd_channel_normalization() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: add missing of_node_put() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: Reinitialize bit clock inversion flag for every format setting (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: rsnd: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: siu_pcm: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: siu_pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dma-sh7760: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sh: dma-sh7760: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: Use pr_warn instead of pr_warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: idma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: Rename Arndale card driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: arndale: Add support for WM1811 CODEC (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: arndale: Simplify DAI link initialization (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: Enable SHDN to fix headset detection (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rockchip_max98090: Add HDMI jack support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rockchip_max98090: Optionally support HDMI use case (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6routing: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm-dai: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: lpass-platform: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: pxa2xx-i2s: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: pxa-ssp: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: poodle: Spelling s/enpoints/endpoints/, s/connetion/connection/ (Jaroslav Kysela) [1797509]
- [sound] ALSA: spi: pxa2xx: No need to keep pointer to platform device (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pxa: mmp-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: g12a: add tohdmitx reset (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: axg-fifo: relax period size constraints (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: axg-fifo: improve depth handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: axg-fifo: fix fifo threshold setup (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: meson: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183: support WoV (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mt8183: fix audio playback slowly after playback during bootup (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mtk-btcvsd: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: kirkwood: fix device remove ordering (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740: Remove unused match variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: kirkwood: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: kirkwood: fix IRQ error handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: kirkwood: kirkwood-dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740: Drop lb60 board code (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: simple-card: fixup simple_dai_link_of_dpcm() comment (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: audio-graph: fixup graph_dai_link_of_dpcm() comment (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_sai: Fix noise when using EDMA (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_mqs: Move static keyword to the front of declarations (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_mqs: Fix error handling in probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_mqs: remove set but not used variable 'bclk' (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_esai: Add spin lock to protect reset, stop and start (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: fsl_dma: fix build failure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: fsl_dma: don't use snd_soc_rtdcom_lookup() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: imx-pcm-fiq: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: mpc5200_dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: fsl_dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: fsl_asrc_dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8958: use <asm/unaligned.h> to simplify code (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tlv320aic32x4: add a check for devm_clk_get (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd9335: clean up indentation issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoc: tas2770: Remove unused defines and variables (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Fix misuse of GENMASK macro (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt6358: support WoV (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-digital: add missing MIX2 path for RX1/2 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-analog: Add earpiece (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-analog: Fix RX1 selection in RDAC2 MUX (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_asrc: refine the setting of internal clock divider (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_asrc: Fix error with S24_3LE format bitstream in i.MX8 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_asrc: update supported sample format (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_asrc: Use in(out)put_format instead of in(out)put_word_width (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_mqs: Add MQS component driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dwc: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dwc: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dwc: dwc-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8994: Add support for MCLKn clock gating (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8994: Add support for setting MCLK clock rate (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Fix sample rate error message (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Return invalid for when bitwidth is invalid (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2562: Introduce the TAS2562 amplifier (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2770: clean up an indentation issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2770: Fix snd_soc_update_bits error handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tas2770: Remove unneeded read of the TDM_CFG3 register (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoc: tas2770: Fix build error without GPIOLIB (Jaroslav Kysela) [1797509]
- [sound] ALSA: tas2770: fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: tas2770: add tas2770 smart PA kernel driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5663: clean up indentation issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5650: Add Kahlee platform specfic changes (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm3168a: Fix serial mode dependent format support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm3168a: Use fixup instead of constraint for channels and formats (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm3168a: The codec does not support S32_LE (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASOC: adau7118: Change regulators id (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASOC: Add ADAU7118 8 Channel PDM-to-I2S/TDM Converter driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: adau1761: Add ALC controls (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: adau1761: Add PGA Slew time control (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bcm: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bcm: cygnus-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: au1x: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: au1x: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: au1x: dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: au1x: dbdma2: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel_ssc_dai: Remove wrong spinlock usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel: atmel-pcm-pdc: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: ACP needs to be powered off in BIOS (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Additional DAI for I2S SP instance (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Fix simultaneous playback and capture (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: acp3x: Fix return value check in acp3x_dai_probe() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: add ACP3x TDM mode support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Buffer Size instead of MAX Buffer (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Fix for Subsequent Playback issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd MMAP_INTERLEAVED Support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Added ACP3x system resume and runtime pm (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Handle ACP3x I2S-SP Interrupts (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Enabling I2S instance in DMA and DAI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Refactoring of DAI from DMA driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: acp3x-pcm-dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: acp3x: clean up indentation issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: acp-pcm-dma: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8741: Fix typo in Kconfig prompt (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Fix snd_sof_ipc_stream_posn() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1015: modify pre-divider for sysclk (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1015: add operation callback function for rt1015_dai (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-component: tidyup snd_soc_pcm_component_sync_stop() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: Correct DAPM handling of active widgets during shutdown (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Fix available clock counter incrementation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm/soc-compress: don't use snd_soc_dapm_stream_stop() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm512x: Fix unbalanced regulator enable call in probe error path (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Fix memleak in soc_tplg_manifest_load() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Fix memleak in soc_tplg_link_elems_load() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: skl: Fix possible buffer overflow in debug outputs (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: skl: Fix pin debug prints (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sun8i-codec: Fix setting DAI data format (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: remove snd_soc_dapm_put_enum_double_locked (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: revert invalid fix for handling SHDN (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codec2codec: avoid invalid/double-free of pcm runtime (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: move i915 init earlier (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Add system_suspend_target field to struct snd_sof_dev (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel: fix atmel_ssc_set_audio link failure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_sai: Fix exiting path on probing failure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: Add missing COMMON_CLK dependency to SND_SOC_ALL_CODECS (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: Add missing COMMON_CLK dependency (Jaroslav Kysela) [1797509]
- [sound] ALSA: treewide: remove redundant IS_ERR() before error code check (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: add PCI ID for JasperLake (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt715: Add __maybe_unused to PM callbacks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt711: Add __maybe_unused to PM callbacks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt700: Add __maybe_unused to PM callbacks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1308-sdw: Add __maybe_unused to PM callbacks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: consistent HDMI codec probing code (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: soc-acpi-intel-icl-match: fix rt715 ADR (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: pci: add missing default_fw_name of JasperLake (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: trace: fix unconditional free in trace release (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: core: release resources on errors in probe_continue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: core: free trace on errors (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: fix an Oops, caused by invalid topology (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: do not disable i915 power during probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: refactor i915_get/put functions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1015: Remove unnecessary const (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: silence lockdep warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove null_snd_soc_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add soc_rtd_trigger() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add soc_rtd_hw_free() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add soc_rtd_hw_params() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add soc_rtd_prepare() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add soc_rtd_shutdown() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: add soc_rtd_startup() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1015: add rt1015 amplifier driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: fix soc_tplg_fe_link_create() - link->dobj initialization order (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_common: Fix global-out-of-bounds bug (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Add MediaTek MT6660 Speaker Amp Driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: fix deadlock in max98090_dapm_put_enum_double() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dapm: add snd_soc_dapm_put_enum_double_locked (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: revert "ASoC: max98090: fix lockdep warning" (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove bus_control (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove DAI suspend/resume (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ux500: ux500_msp_dai: remove unused DAI .suspend/.resume (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: i2s: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dwc: dwc-i2s: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: uniphier: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: omap-mcpdm: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sti: sti_uniperif: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: spdif: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: s3c24xx-i2s: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: jz4740: jz4740-i2s: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: cirrus: ep93xx-i2s: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel: atmel_ssc_dai: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bcm: cygnus-ssp: move .suspend/.resume to component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-generic-dmaengine-pcm: Fix error handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: crash in snd_soc_dapm_new_dai (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: Remove unnecessary string buffers and snprintf calls (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Remove unnecessary string buffers and snprintf calls (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Remove code duplication in byt_rt5640_codec_fixup (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-analog: Add MIC BIAS Internal3 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-analog: Simplify MIC BIAS Internal (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt715: fix return value check in rt715_sdw_probe() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt711: fix return value check in rt711_sdw_probe() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt700: fix return value check in rt700_sdw_probe() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt715: remove unused including <linux/version.h> (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: Fix SKL dai count (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm_adsp: Correct cache handling of new kernel control API (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sgtl5000: add multi endpoint support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_asrc: Add support for imx8qm & imx8qxp (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sgtl5000: Fix VDDA and VDDIO comparison (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: Add jz4770-codec driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: remove unused variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: removed unused variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: skl_rt286: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_ssm4567: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_max98357a: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASOC: Intel: kbl_rt5663_rt5514_max98927: remove useless initialization (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_rt5514_max98927: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_max98927: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_rt5660: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: remove unnecessary initialization (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: test return value on route add (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: removed unused variables (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bxt_rt298: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bxt_da7219_max98357a: rename shadowed variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda-dai: fix compilation warning in pcm_prepare (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt715: remove warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt715: use dev_to_sdw_dev() instead of to_sdw_slave_device() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt700: remove unused including <linux/version.h> (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1308-sdw: add rt1308 SdW amplifier driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: atmel: fix build error with CONFIG_SND_ATMEL_SOC_DMA=m (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-digital: Reset RX interpolation path after use (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-analog: Fix MIC BIAS Internal1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sti: fix possible sleep-in-atomic (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: msm8916-wcd-analog: Fix selected events for MIC BIAS External1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdac_hda: Fix error in driver removal after failed probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: fix HDA codec driver probe with multiple controllers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: lower print level to dbg if we will reinit DSP (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: reference SoundWire machine lists (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: support alternate list of machines (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: add match tables for TGL w/ SoundWire (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: add match tables for CNL/CFL/CML w/ SoundWire (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: add match tables for ICL w/ SoundWire (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: soc-acpi: declare new tables for SoundWire (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-acpi: add _ADR-based link descriptors (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-acpi: add link_mask field (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: fix PCM playback through ALSA OSS emulation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5650: change cpu_dai and platform components for SOF (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: broadwell: change cpu_dai and platform components for SOF (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: change cpu_dai and platform components for SOF (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: fix Kconfig dependencies (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt711: remove unused including <linux/version.h> (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt715: add RT715 codec driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: txx9: Remove unused rtd variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm/soc-compress: use snd_soc_dapm_stream_stop() for SND_SOC_DAPM_STREAM_STOP (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-dapm: add snd_soc_dapm_stream_stop() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add snd_soc_close_delayed_work() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: do pinctrl_pm_select_xxx() as component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove duplicate pinctrl operation when suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: care .ignore_suspend for Component suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: rename snd_soc_rtdcom_add() to snd_soc_rtd_add_component() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt700: add rt700 codec driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove snd_soc_rtdcom_list (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: Drop incorrectly applied duplicate commit (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt711: add rt711 codec driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: codecs: add wsa881x amplifier support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: fix lockdep warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: fix incorrect helper in max98090_dapm_put_enum_double() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: fix incorrect helper in max98090_dapm_put_enum_double() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: gtm601: fix build warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: loader: add dynamic debug trace (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: pci: change the default firmware path when the community key is used (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Fix NULL dereference at freeing (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sof_rt5682: Ignore the speaker amp when there isn't one (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Fix Irbis NB41 netbook quirk (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5640: Fix NULL dereference on module unload (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-topology: fix endianness issues (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: hda_dsp_common: use NULL pointer assignment, not 0 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: Fix compile-testing RT1011/RT5682 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx8: use resource_size (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: constify copied structure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: amd: Create multiple I2S platform device endpoint (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: sdm845: add support to DB845c and Lenovo Yoga (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: add audio routings (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: add capture dapm widgets (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: add playback dapm widgets (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: add basic controls (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wcd934x: add support to wcd9340/wcd9341 codec (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: gtm601: add Broadmobi bm818 sound profile (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: remove unused variable 'constraints_16000' and 'ch_mono' (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdac_hda: Update hdac hda dai table to include intel-hdmi-hifi4 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: Add iDisp4 DAI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx8: Fix dsp_box offset (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_audmix: add missed pm_runtime_disable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: fix input pin state management (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: stm32: spdifrx: fix inconsistent lock state (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: Fix access to uninitialized list heads (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: Set dpcm_playback / dpcm_capture (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: Remove empty suspend function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: Add Broadwell rt5650 machine driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: move arch_ops under ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Prevent use-after-free in snd_soc_get_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx: Read SAI parameters and send them to DSP (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx: Describe SAI parameters to be sent to DSP (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: fix incorrect HDMI Kconfig dependency (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: drop HDA codec upon probe failure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Add machine driver for da7219_max98373 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: log compiler name and version information (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: define struct with compiler name and version (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Introduce state machine for FW boot (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: remove references to Haswell (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: cml_rt1011_rt5682: fix codec_conf by removing legacy style (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: hda-dai: fix oops on hda_link .hw_free (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: fix fault at driver unload after failed probe (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: compress: Add pm_runtime support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: skylake: Remove superfluous bus ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove legacy style of codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: rx51: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: speyside: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: lowland: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: samsung: bells: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650-rt5676: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650-rt5514: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: skl_nau88l25_ssm4567: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: kbl_rt5663_rt5514_max98927: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: kbl_rt5663_max98927: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: kbl_da7219_max98927: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl: imx-audmix: use snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: support snd_soc_dai_link_component for codec_conf (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8962: fix lambda value (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Drop snd_soc_pcm_lib_ioctl() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: haswell: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: baytrail: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: xtensa: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5514-spi: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: tidyup for CONFIG_DEBUG_FS (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: tidyup for CONFIG_DMI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge soc_set_name_prefix() and soc_set_of_name_prefix() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: byt: fixup topology filename for BYT-CR (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: soc_set_name_prefix(): get component device_node at out of loop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: soc_set_name_prefix(): tidyup loop condition (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: rename soc_link_init() to soc_init_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add missing return value check for soc_link_init() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move soc_link_init() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: rename soc_link_dai_pcm_new() to soc_dai_pcm_new() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move soc_link_dai_pcm_new() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: rename snd_soc_remove_dai_link() to snd_soc_remove_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: rename snd_soc_add_dai_link() to snd_soc_add_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move snd_soc_find_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: find rtd via dai_link pointer at snd_soc_get_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move snd_soc_get_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove snd_soc_get_dai_substream() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove snd_soc_disconnect_sync() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove dai_link_list (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc.h: dobj is used only when SND_SOC_TOPOLOGY (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: add SND_SOC_BYTES_E (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: add codec_mask module parameter (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Add asynchronous sample rate converter topology support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: work-around incorrect ACPI HID for CML boards (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: split cht and byt debug window sizes (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: loader: fix snd_sof_fw_parse_ext_data (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: loader: snd_sof_fw_parse_ext_data log warning on unknown header (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: simple-card: Don't create separate link when platform is present (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check return value for soc_tplg_pcm_create() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: topology: Check return value for snd_soc_add_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: Explicitly include linux/io.h for virt_to_phys() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: nocodec: Amend arguments for sof_nocodec_setup() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Remove unused drv_name in sof_pdata (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: remove nocodec_fw_filename (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Make creation of machine device from SOF core optional (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: intel: hda: Modify signature for hda_codec_probe_bus() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: partition audio-related parts from SOF core (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Drop superfluous snd_pcm_sgbuf_ops_page (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Introduce default_fw_filename member in sof_dev_desc (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: core: move check for runtime callbacks to core (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: core: modify the signature for snd_sof_create_page_table (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: sof: pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: remove snd_sof_init_topology() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove unnecessary string buffers and snprintf calls (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: remove unused variable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel/skl/hda - export number of digital microphones via control components (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdmi-codec: set plugged_cb to NULL when component removing (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdmi-codec: re-introduce mutex locking again (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdmi-codec: drop mutex locking again (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fix soc-core.c kernel-doc warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: solve MSI issues by merging ipc and stream irq handlers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Improve the sysclk selection (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: cs42l51: add dac mux widget in codec routes (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: Calculate DALIGN inversion at run-time (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tlv320aic31xx: Add Volume Soft Stepping control (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: save and restore SHDN when changing sensitive registers (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_sai: add IRQF_SHARED (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tlv320aic31xx: Add HP output driver pop reduction controls (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: common: refine hw_params and hw_prepare (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: mediatek: common: add some helpers to control mtk_memif (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdac_hdmi: Drop support for Icelake (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: make common HDMI driver default (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: common: Add mach table for tgl-max98357a-rt5682 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: sof_rt5682: Add support for tgl-max98357a-rt5682 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: sof_rt5682: Add quirk for number of HDMI DAI's (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: only flush inited work during free (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Update quirk for Teclast X89 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: Init pcm runtime work early to avoid warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: sst: Add missing include <linux/io.h> (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: fix possible race conditions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: exit workaround earlier if PLL is locked (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98090: remove msleep in PLL unlocked workaround (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8904: fix automatic sysclk configuration (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Fix build error without CONFIG_SPI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: Fix unload for SAI/ESAI (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: BYT: fix a copy/paste mistake in byt_dump() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: AMD: Enable clk in startup intead of hw_params (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: fix i2c arbitration lost issue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: DMI long name - avoid to add board name if matches with product name (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: improve the DMI long card code in asoc-core (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rsnd: fix DALIGN register for SSIU (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: component: Add sync_stop PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm: Make ioctl ops optional (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: check symmetry before hw_params (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm3168a: Update the RST gpio handling to align with documentation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: add control components management (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: remove soc_pcm_private_free() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: fixup dead-lock at snd_soc_unregister_component() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: fix RIP warning on card removal (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-component: tidyup snd_soc_pcm_component_new/free() parameter (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Update quirk for Acer Switch 10 SW5-012 2-in-1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm_adsp: Expose mixer control API (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: tlv320aic31xx: configure output common-mode voltage (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Fix CFL and CML FW nocodec binary names (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Fix build break (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm3168a: Add support for optional RST gpio handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm5100: add missed pm_runtime_disable (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm2200: add missed operations in remove and probe failure (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm-dai: add support to flac decoder (Jaroslav Kysela) [1797509]
- [sound] ALSA: compress: add flac decoder params (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: qcom: q6asm: add support to flac config (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: rt5677_check_hotword() can be static (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: fix the charge pump capacitor discharges (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Use dma_request_chan() directly for channel request (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: dmaengine: Use dma_request_chan() directly for channel request (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: care card_probed at soc_cleanup_card_resources() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move snd_soc_unbind_card() next to snd_soc_bind_card() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: call snd_soc_dapm_shutdown() at soc_cleanup_card_resources() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5645: Fixed typo for buddy jack support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8904: fix regcache handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: tidyup soc_probe_aux_devices() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_bind_card() and snd_soc_instantiate_card() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge soc_remove_component() and soc_cleanup_component() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_remove_dai_link() and soc_unbind_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_add_dai_link() and soc_bind_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_unregister_dai() and soc_del_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_register_dai() and soc_add_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove soc_is_dai_link_bound() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Jack: Fix NULL pointer dereference in snd_soc_jack_report (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: free kcontrol memory on error (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: PM: only suspend to D0I3 when needed (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: add helper to check if we should enter d0i3 suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: PM: add check before setting d0_substate (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: PM: add state machine to comments (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: use fallback for firmware name (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: acpi-match: split CNL tables in three (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Fix CFL and CML FW nocodec binary names (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5682: cancel jack_detect_work if hs_jack is set to null (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5645: Fixed buddy jack support (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: wm8904: configure sysclk/FLL automatically (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_rt5514_max98927: Add dmic format constraint (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Add DA7213 audio codec as selectable option (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Wait for DSP to boot before loading firmware (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Set ADC clock to use PLL and enable ASRC (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bdw-rt5677: Turn on MCLK1 for DSP via DAPM (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Allow VAD to be shut on/off at all times (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Disable irq at suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Stop and restart DSP over suspend/resume (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Mark reg RT5677_PWR_ANLG2 as volatile (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Add DAPM audio path for hotword stream (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Enable jack detect while DSP is running (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: bdw-rt5677: Add a DAI link for rt5677 SPI PCM device (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: fsl_audmix: Add spin lock to protect tdms (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5514-spi: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5514-spi: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: set L1SEN on S0ix suspend (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: fix missing NULL pointer check (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: Fix compile warning with CONFIG_DEBUG_FS=n (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: Fix bytes control size checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove topology specific operation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: call snd_soc_register_dai() from snd_soc_register_dais() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: don't call snd_soc_dapm_new_dai_widgets() at snd_soc_register_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: have legacy_dai_naming at snd_soc_register_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add snd_soc_unregister_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move snd_soc_unregister_dais() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move snd_soc_register_dai() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: use snd_soc_lookup_component() at snd_soc_unregister_component() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove snd_soc_component_add/del() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add snd_soc_del_component_unlocked() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: tidyup snd_soc_lookup_component() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move snd_soc_lookup_component() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add soc_unbind_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: call soc_bind_dai_link() under snd_soc_add_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove duplicated soc_is_dai_link_bound() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: typo fix at soc_dai_link_sanity_check() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: tidyup soc_init_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move soc_init_dai_link() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add for_each_rtd_components() and replace (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove for_each_rtdcom_safe() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: Use different sequence for start/stop trigger (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: snd_soc_unbind_card() cleanup (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add snd_soc_pcm_lib_ioctl() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: setup card->rtd_num at snd_soc_instantiate_card() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: use devm_xxx for component related resource (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add soc_setup_card_name() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove soc_remove_dai_links() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: use devm_kzalloc() for rtd (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: Clarify usage of ignore_machine (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove snd_soc_rtdcom_del_all() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: tidyup soc_new_pcm_runtime() alloc order (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: topology: set trigger order for FE DAI link (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm: update FE/BE trigger order based on the command (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: max98373: replace gpio_request with devm_gpio_request (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Skylake: mark HDAudio codec support as deprecated (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: use def_tristate, avoid using select (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: imx: fix reverse CONFIG_SND_SOC_SOF_OF dependency (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Kconfig: add EXPERT dependency for developer options, clarify help (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: add mutual exclusion between SOF and legacy Baytrail driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Broadwell: clarify mutual exclusion with legacy driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: Baytrail: clarify mutual exclusion with Atom/SST driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: SOF: Intel: hda: Simplify the hda_dsp_wait_d0i3c_done() function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: Add acpi match for rt1011 based m/c driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: ux500: Remove redundant variable "status" (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: hdac_hda: fix race in device removal (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: set the different setting for QFN/WLCSP package (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: some minor changes to improve readability (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: add the range check for temperature_calib from device property (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: remove unnecessary tabs using spaces instead (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: fix spelling mistake "temperture" -> "temperature" (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: Read and apply r0 and temperature device property (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: set tx/rx slots from tx/rx_mask in TDM case (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: improve the rt1011_set_dai_fmt() function (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt1011: remove redundant code in kcontrol (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: remove unneeded snd_soc_tplg_component_remove() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677-spi: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Load firmware via SPI using delayed work (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677-spi: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677-spi: fixup compile warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677-spi: fix sparse warnings (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Add missing null check for failed allocation of rt5677_dsp (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: rt5677: Add a PCM device for streaming hotword via SPI (Jaroslav Kysela) [1797509]
- [sound] ALSA: serial-u16550: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: opl4: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: seq: oss: Constify snd_seq_oss_callback definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: opl3: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: opl3: Constify snd_opl3_drum_voice definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: mts64: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: dummy: Constify snd_pcm_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: dummy: Fix PCM format loop in proc output (Jaroslav Kysela) [1797509]
- [sound] ALSA: dummy: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: drivers: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Fix dependency on timer API (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: do not override bus codec_mask in link_get() (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Reset stream if DMA RUN bit not cleared (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: No preallocation on x86 platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Update kernel-doc function parameter descriptions (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Comment about snd_hdac_bus_update_rirb() and spinlock (Jaroslav Kysela) [1797509]
- [sound] ALSA: via82xx: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: trident: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme32: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcxhr: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: intel8x0: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Apply aligned MMIO access only conditionally (Jaroslav Kysela) [1797509]
- [sound] ALSA: remove ioremap_nocache and devm_ioremap_nocache (Jaroslav Kysela) [1797509]
- [sound] ALSA: au88x0: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: atiixp: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: asihpi: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable the headset of ASUS B9450FA with ALC294 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus Master (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add Headset Button supported for ThinkPad X1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add Headset Mic supported (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Fix a regression for mute led on Lenovo Carbon X1 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Use scnprintf() for printing texts for sysfs/procfs (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Apply quirk for yet another MSI laptop (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Apply quirk for MSI GP63, too (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Fix silent output on MSI-GL73 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add more codec supported Headset Button (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Clear RIRB status before reading WP (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Fixed one of HP ALC671 platform Headset Mic supported (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Fix DP-MST support for NVIDIA codecs (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdsp: Make the firmware loading ioctl a bit more readable (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: Fix annotation and cast for the recent uapi header change (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Add JasperLake PCI ID and codec vid (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Add Clevo W65_67SB the power_save blacklist (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs46xx: fix spelling mistake "to" -> "too" (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Add docking station support for Lenovo Thinkpad T420s (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - add retry logic to parse_intel_hdmi() (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add Headset Mic supported for HP cPC (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/analog - Minor optimization for SPDIF mux connections (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: patch_hdmi: remove warnings with empty body (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: correct kernel-doc parameter descriptions (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Manage concurrent reg access more properly (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: enable regmap internal locking (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Fix a typo in comments (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Disable regmap internal locking (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: patch_realtek: fix empty macro usage in if block (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Rename back to dmic_detect option (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: echoaudio: remove set but not used variable 'chip' (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add quirk for the bass speaker on Lenovo Yoga X1 7th gen (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Set EAPD control to default for ALC222 (Jaroslav Kysela) [1797509]
- [sound] ALSA: via82xx: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: fm801: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: ens137x: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: echoaudio: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs4281: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: azt3328: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: ak4531: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: lx6464es: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: aw2: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmipci: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1968: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1938: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: atiixp: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: asihpi: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctxfi: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: ca0106: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs46xx: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: korg1212: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: nm256: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: ymfpci: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: mixart: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcxhr: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme9652: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdspm: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdsp: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1712: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: riptide: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: au88x0: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: ac97: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: intel8x0: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: vx: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Apply mic mute LED quirk for Dell E7xx laptops, too (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add new codec supported for ALCS1200A (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - constify and cleanup static NodeID tables (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Constify snd_pci_quirk tables (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Constify snd_pci_quirk tables (Jaroslav Kysela) [1797509]
- [sound] ALSA: fm801: Constify snd_fm801_tea575x_gpios (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1968: Constify snd_es1968_tea575x_gpios (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: Constify snd_emu_chip_details (Jaroslav Kysela) [1797509]
- [sound] ALSA: bt87x: Constify snd_bt87x_boards (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1712: Constify wm-specific tables (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice17xx: Constify snd_ice1712_card_info (Jaroslav Kysela) [1797509]
- [sound] ALSA: ca0106: Constify snd_ca0106_details (Jaroslav Kysela) [1797509]
- [sound] ALSA: ca0106: Constify snd_ca0106_category_str items (Jaroslav Kysela) [1797509]
- [sound] ALSA: ac97: Constify snd_ac97_res_table definition (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Constify snd_kcontrol_new items (Jaroslav Kysela) [1797509]
- [sound] ALSA: vx: Constify snd_vx_hardware and snd_vx_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: info: Make snd_info_entry_ops as const (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Constify snd_ac97_bus_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: ac97: Treat snd_ac97_bus_ops as const (Jaroslav Kysela) [1797509]
- [sound] ALSA: Constify snd_timer_hardware definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Constify snd_pcm_hardware definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: constify copied structure (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable the bass speaker of ASUS UX431FLC (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1724: Fix sleep-in-atomic in Infrasonic Quartet support code (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add Bass Speaker and fixed dac for bass speaker (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Apply sync-write workaround to old Intel platforms, too (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: echoaudio: remove usage of dimen menber of elem_value structure (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - fix atpx_present when CLASS is not VGA (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: Make uapi/emu10k1.h compilable again (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Add headset Mic no shutup for ALC283 (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmipci: Allow disabling MPU port via module option (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Downgrade error message for single-cmd fallback (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Fix regression by strip mask fix (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/ca0132 - Fix work handling in delayed HP detection (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/ca0132 - Avoid endless loop (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/ca0132 - Keep power on during processing DSP response (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Unify get_response handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Use waitqueue for RIRB in HDA-core helper, too (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: tegra: Fix unused variable compile warning (Jaroslav Kysela) [1797509]
- [sound] ALSA: hdsp: Make uapi/hdsp.h compilable again (Jaroslav Kysela) [1797509]
- [sound] ALSA: vx222: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcxhr: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: mixart: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: lx6464es: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ymfpci: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: via82xx: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: trident: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: sonicvibes: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: sis7019: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme9652: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme96: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme32: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: riptide: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: oxygen: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: nm256: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: maestro3: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: lola: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: korg1212: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: intel8x0: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1724: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1712: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: fm801: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1968: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1938: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ens137x: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: echoaudio: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctxfi: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs5535audio: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs46xx: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs4281: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmipci: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ca0106: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: bt87x: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: azt3328: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: aw2: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: au88x0: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: atiixp: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: als300: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ali5451: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: ad1889: Support PCM sync_stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Line-out jack doesn't work on a Dell AIO (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - Fix duplicate unref of pci_dev (Jaroslav Kysela) [1797509]
- [sound] ALSA: echoaudio: simplify get_audio_levels (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - Keep old slot assignment behavior for Intel platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Modify stream stripe mask only when needed (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - fixup for the bass speaker on Lenovo Carbon X1 7th gen (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - preserve non-MST PCM routing for Intel platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - fix kernel oops caused by invalid PCM idx (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Fix inverted bass GPIO pin on Acer 8951G (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Dell headphone has noise on unmute for ALC236 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - fix regression in connect list handling (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - enable automatic runtime pm for AMD HDMI codecs by default (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - enable runtime pm for newer AMD display audio (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - Add new pci ids for AMD GPU display audio (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - fix vgaswitcheroo detection for AMD (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable internal speaker of ASUS UX431FLC (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - Clear codec->relaxed_resume flag at unbinding (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Disable audio component for legacy Nvidia HDMI codecs (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Move some alc236 pintbls to fallback table (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/realtek - Move some alc256 pintbls to fallback table (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Add mute led support for HP ProBook 645 G4 (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Add DP-MST support for NVIDIA codecs (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Add DP-MST support for non-acomp codecs (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Add DP-MST jack support (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - Rename snd_hda_pin_sense to snd_hda_jack_pin_sense (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda - remove forced polling workaround for CFL and CNL (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - remove redundant code comments (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - fix port numbering for ICL and TGL platforms (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/hdmi - Clean up Intel platform-specific fixup checks (Jaroslav Kysela) [1797509]
- [sound] ALSA: au88x0: Fix incorrect device pointer for preallocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - fix pin setup on Tigerlake (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Add Cometlake-S PCI ID (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme32: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: hdmi - add Tigerlake support (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda/ca0132 - Fix possible workqueue stall (Jaroslav Kysela) [1797509]
- [sound] ALSA: seq: Fix concurrent access to queue current tick/time (Jaroslav Kysela) [1797509]
- [sound] ALSA: seq: Avoid concurrent access to queue flags (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Fix double hw_free calls (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Fix sparse warnings wrt snd_pcm_state_t (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Fix memory leak at closing a stream without hw_free (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Set per-card upper limit of PCM buffer allocations (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Make snd_pcm_hw_constraints_init() and _complete() static (Jaroslav Kysela) [1797509]
- [sound] ALSA: seq: Fix racy access for queue timer in proc read (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: fix nsec/sec initialization confusion (Jaroslav Kysela) [1797509]
- [sound] ALSA: control: potential uninitialized return value (Jaroslav Kysela) [1797509]
- [sound] ALSA: rawmidi: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: oss: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: jack: More constification (Jaroslav Kysela) [1797509]
- [sound] ALSA: info: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: seq: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: More constifications (Jaroslav Kysela) [1797509]
- [sound] ALSA: control: Add verification for kctl accesses (Jaroslav Kysela) [1797509]
- [sound] ALSA: mixer: oss: Constify snd_mixer_oss_assign_table definition (Jaroslav Kysela) [1797509]
- [sound] ALSA: seq: Constify struct snd_midi_op (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Constify snd_timer_hardware definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: core: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: core: Treat snd_device_ops as const (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctl: allow TLV read operation for callback type of element in locked case (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctl: remove dimen member from elem_info structure (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Avoid possible info leaks from PCM stream buffers (Jaroslav Kysela) [1797509]
- [sound] ALSA: control: remove useless assignment in .info callback of PCM chmap element (Jaroslav Kysela) [1797509]
- [sound] ALSA: uapi: Fix typos and header inclusion in asound.h (Jaroslav Kysela) [1797509]
- [sound] ALSA: bump uapi version numbers (Jaroslav Kysela) [1797509]
- [sound] ALSA: add new 32-bit layout for snd_pcm_mmap_status/control (Jaroslav Kysela) [1797509]
- [sound] ALSA: move snd_pcm_ioctl_sync_ptr_compat into pcm_native.c (Jaroslav Kysela) [1797509]
- [sound] ALSA: Avoid using timespec for struct snd_ctl_elem_value (Jaroslav Kysela) [1797509]
- [sound] ALSA: Avoid using timespec for struct snd_timer_tread (Jaroslav Kysela) [1797509]
- [sound] ALSA: Avoid using timespec for struct snd_rawmidi_status (Jaroslav Kysela) [1797509]
- [sound] ALSA: Avoid using timespec for struct snd_pcm_status (Jaroslav Kysela) [1797509]
- [sound] ALSA: Avoid using timespec for struct snd_timer_status (Jaroslav Kysela) [1797509]
- [sound] ALSA: Replace timespec with timespec64 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-pcm: fixup dpcm_prune_paths() loop continue (Jaroslav Kysela) [1797509]
- [sound] ALSA: ps3: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: pmac: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ymfpci: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: via82xx: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: trident: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: sonicvibes: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: sis7019: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: riptide: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: oxygen: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: mixart: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: maestro3: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: lx6464es: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: lola: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: intel8x0: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1724: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ice1712: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: fm801: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1938: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ens137x: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: emu10k1x: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: echoaudio: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ctxfi: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs5535: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: cs4281: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmipci: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ca0106: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: bt87x: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: azt3328: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: aw2: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: atiixp: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: asihpi: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: als4000: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: parisc: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: wss: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: gus: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: sb: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: es18xx: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1688: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: cmi8330: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ad1816a: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcsp: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: atmel: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: aaci: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: aoa: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: aoa: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: echoaudio: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: es1968: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: rme: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: als300: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ali5451: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ad1889: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: hda: Use standard waitqueue for RIRB wakeup (Jaroslav Kysela) [1797509]
- [sound] ALSA: pci: Drop superfluous snd_pcm_sgbuf_ops_page (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: atom: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: sst-mfld-platform-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: sst-baytrail-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: Drop superfluous snd_pcm_sgbuf_ops_page (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: sst-haswell-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: skylake: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: Avoid non-standard macro usage (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: intel: skl-pcm: remove snd_pcm_ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: drivers: Constify snd_ac97_bus_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: drivers: Constify snd_device_ops definitions (Jaroslav Kysela) [1797509]
- [sound] ALSA: drivers: Drop superfluous ioctl PCM ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: ml403: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: vx: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: vx: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: dummy: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: drivers: Remove superfluous snd_dma_continuous_data() (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Use managed buffer allocation (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Avoid pointer dereference before null-check (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Avoid unexpected timer event callback tasklets (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Remove redundant locking in timer open function (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Support runtime change of snd_timer via info interface (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Support selection of snd_timer instead of jiffies (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Move CABLE_VALID_BOTH to the top of file (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Rename all jiffies timer specific functions (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Use callback functions for timer specific implementations (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Support return of error code for timer start and stop (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Describe units of variables (Jaroslav Kysela) [1797509]
- [sound] ALSA: aloop: Convert to the common vmalloc memalloc (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge soc_free_pcm_runtime() and soc_rtd_free() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge soc_new_pcm_runtime() and soc_rtd_init() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: create rtd->codec_dais first (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: call list_del(&rtd->list) at soc_free_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge soc_add_pcm_runtime() into soc_new_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: move soc_free_pcm_runtime() (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: use list_del_init and move it back to soc_cleanup_component (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: core: delete component->card_list in soc_remove_component only (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-component: remove snd_pcm_ops from component driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: add new pcm_construct/pcm_destruct (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-core: merge snd_pcm_ops member to component driver (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: soc-component.h: remove GPL explanation from header (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: oss: Avoid potential buffer overflows (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Add card sync_irq field (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Add the support for sync-stop operation (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Move PCM_RUNTIME_CHECK() macro into local header (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Allow NULL ioctl ops (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Introduce managed buffer allocation mode (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Fix stream lock usage in snd_pcm_period_elapsed() (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Fix the breakage of slave link open (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Unexport snd_pcm_sgbuf_ops_page (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Yet another missing check of non-cached buffer type (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Fix possible race at assigning a timer instance (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Make snd_timer_close() returning void (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Unify master/slave linking code (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Fix incorrectly assigned timer instance (Jaroslav Kysela) [1797509]
- [sound] ALSA: timer: Limit max amount of slave instances (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Create proc files only for non-empty preallocations (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Warn if doubly preallocated (Jaroslav Kysela) [1797509]
- [sound] ALSA: pcm: Handle special page mapping in the default mmap handler (Jaroslav Kysela) [1797509]
- [sound] ALSA: memalloc: Add vmalloc buffer allocation support (Jaroslav Kysela) [1797509]
- [sound] ALSA: memalloc: Allow NULL device for SNDRV_DMA_TYPE_CONTINUOUS type (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: pcm_dmaengine: Extract snd_dmaengine_pcm_refine_runtime_hwparams (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel - do not describe I/O configuration in the long card name (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel - use control components to describe card config (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: make common HDMI driver the default for SOF (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: sof_rt5682: use dependency on SOF_HDA_LINK (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: Geminilake is only supported by SOF (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: fix configs for bxt-da7219-max98057a (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: remove select SND_HDA_DSP_LOADER (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: Intel: boards: Add CML m/c using RT1011 and RT5682 (Jaroslav Kysela) [1797509]
- [sound] ALSA: ASoC: compress: fix unsigned integer overflow check (Jaroslav Kysela) [1797509]
- [sound] ALSA: Revert "ALSA: usb-audio: set the interface format after resume on Dell WD19" (Jaroslav Kysela) [1797509]

* Fri May 22 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-203.el8]
- [crypto] crypto: ccp - use file mode for sev ioctl permissions (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Cleanup sp_dev_master in psp_dev_destroy() (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Cleanup misc_dev on sev_exit() (Vladis Dronov) [1765717]
- [crypto] crypto: remove CRYPTO_TFM_RES_BAD_KEY_LEN (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - move SEV vdata to a dedicated data structure (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - create a generic psp-dev file (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - rename psp-dev files to sev-dev (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - set max RSA modulus size for v3 platform devices as well (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - add SEV command privilege separation (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - fix uninitialized list head (Vladis Dronov) [1765717]
- [crypto] crypto: user - fix memory leak in crypto_report (Vladis Dronov) [1829808 1765717] {CVE-2019-19062}
- [crypto] crypto: ccp - Release all allocated memory if sha type is invalid (Vladis Dronov) [1825134 1765717] {CVE-2019-18808}
- [crypto] crypto: ccp - invoke fallback for XTS ciphertext stealing (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Remove unnecessary linux/pci.h include (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Include DMA declarations explicitly (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - use devm_platform_ioremap_resource() to simplify code (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Clean up and exit correctly on allocation failure (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Log an error message when ccp-crypto fails to load (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Ignore tag length when decrypting GCM ciphertext (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Add support for valid authsize values less than 16 (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Fix oops by properly managing allocated structures (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Reduce maximum stack usage (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Include the module name in system log messages (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Add a module parameter to control registration for DMA (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - module parameter to limit the number of enabled CCPs (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Add a module parameter to specify a queue count (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Make CCP debugfs support optional (Vladis Dronov) [1765717]
- [crypto] crypto: ctr - add helper for performing a CTR encryption walk (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - memset structure fields to zero before reuse (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Fix 3DES complaint from ccp-crypto module (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - fix AES CFB error exposed by new test vectors (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - AES CFB mode is a stream cipher (Vladis Dronov) [1765717]
- [crypto] treewide: Add SPDX license identifier - Makefile/Kconfig (Vladis Dronov) [1765717]
- [crypto] crypto: shash - remove shash_desc::flags (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - no need to check return value of debugfs_create functions (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Remove forward declaration (Vladis Dronov) [1765717]
- [crypto] crypto: ccp - Remove VLA usage of skcipher (Vladis Dronov) [1765717]
- [crypto] crypto: skcipher - Introduce crypto_sync_skcipher (Vladis Dronov) [1765717]
- [infiniband] IB/mlx4: Test return value of calls to ib_get_cached_pkey (Alaa Hleihel) [1767259]
- [netdrv] net/mlx4_core: Fix use of ENOSPC around mlx4_counter_alloc() (Alaa Hleihel) [1767259]
- [infiniband] RDMA/mlx4: Initialize ib_spec on the stack (Alaa Hleihel) [1767259]
- [powerpc] powerpc/powernv: Re-enable imc trace-mode in kernel (Desnes Augusto Nunes do Rosario) [1725201]
- [powerpc] powerpc/perf: Implement a global lock to avoid races between trace, core and thread imc events (Desnes Augusto Nunes do Rosario) [1725201]
- [powerpc] powerpc/perf: Return accordingly on invalid chip-id in (Desnes Augusto Nunes do Rosario) [1725201]
- [powerpc] powerpc/perf: Remove PM_BR_CMPL_ALT from power9 event list (Desnes Augusto Nunes do Rosario) [1725201]
- [powerpc] powerpc/perf: Add generic compat mode pmu driver (Desnes Augusto Nunes do Rosario) [1725201]
- [powerpc] powerpc/perf: init pmu from core-book3s (Desnes Augusto Nunes do Rosario) [1725201]
- [fs] NFS: Fix fscache super_cookie index_key from changing after umount (Dave Wysochanski) [1790933]
- [fs] NFSv4: Fix fscache cookie aux_data to ensure change_attr is included (Dave Wysochanski) [1793560]
- [fs] nfs: fscache: use timespec64 in inode auxdata (Dave Wysochanski) [1793560]
- [documentation] i2c: replace i2c_new_probed_device with an ERR_PTR variant (David Arcari) [1835245]
- [documentation] docs: stop suggesting strlcpy (David Arcari) [1835245]
- [scsi] scsi: hpsa: Update driver version (Joseph Szczypek) [1815628]
- [scsi] scsi: hpsa: correct race condition in offload enabled (Joseph Szczypek) [1815628]
- [kernel] audit: log audit netlink multicast bind and unbind (Richard Guy Briggs) [1829622]
- [ipc] ipc/mqueue.c: change __do_notify() to bypass check_kill_permission() (Oleg Nesterov) [1808931]
- [scsi] scsi: megaraid_sas: Update driver version to 07.714.04.00-rc1 (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: TM command refire leads to controller firmware crash (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Replace undefined MFI_BIG_ENDIAN macro with __BIG_ENDIAN_BITFIELD macro (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Remove IO buffer hole detection logic (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Limit device queue depth to controller queue depth (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid: Use true, false for bool variables (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid: make two symbols static in megaraid_sas_base.c (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid: make some symbols static in megaraid_sas_fusion.c (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid: make some symbols static in megaraid_sas_fp.c (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Use scnprintf() for avoiding potential buffer overflow (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: silence a warning (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: fix indentation issue (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Update driver version to 07.713.01.00-rc1 (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Use Block layer API to check SCSI device in-flight IO requests (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Limit the number of retries for the IOCTLs causing firmware fault (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Do not initiate OCR if controller is not in ready state (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Re-Define enum DCMD_RETURN_STATUS (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Do not set HBA Operational if FW is not in operational state (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Do not kill HBA if JBOD Seqence map or RAID map is disabled (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Do not kill host bus adapter, if adapter is already dead (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Update optimal queue depth for SAS and NVMe devices (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Set no_write_same only for Virtual Disk (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Reset adapter if FW is not in READY state after device resume (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Make poll_aen_lock static (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: remove unused variables 'debugBlk', 'fusion' (Tomas Henzl) [1791041]
- [scsi] scsi: megaraid_sas: Unique names for MSI-X vectors (Tomas Henzl) [1791041]

* Wed May 20 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-202.el8]
- [crypto] crypto: drbg - fix error return code in drbg_alloc_state() (Vladis Dronov) [1822458]
- [fs] fs: call fsnotify_sb_delete after evict_inodes (Jay Shin) [1834741]
- [fs] fs: avoid softlockups in s_inodes iterators (Jay Shin) [1834741]
- [fs] fs/drop_caches.c: avoid softlockups in drop_pagecache_sb() (Jay Shin) [1834741]
- [net] net/smc: remove set but not used variables 'del_llc, del_llc_resp' (Philipp Rudo) [1725886]
- [net] net/smc: remove unused inline function smc_curs_read (Philipp Rudo) [1725886]
- [net] net/smc: log important pnetid and state change events (Philipp Rudo) [1725886]
- [net] net/smc: save SMC-R peer link_uid (Philipp Rudo) [1725886]
- [net] net/smc: create improved SMC-R link_uid (Philipp Rudo) [1725886]
- [net] net/smc: improve termination processing (Philipp Rudo) [1725886]
- [net] net/smc: add termination reason and handle LLC protocol violation (Philipp Rudo) [1725886]
- [net] net/smc: asymmetric link tagging (Philipp Rudo) [1725886]
- [net] net/smc: assign link to a new connection (Philipp Rudo) [1725886]
- [net] net/smc: send DELETE_LINK, ALL message and wait for send to complete (Philipp Rudo) [1725886]
- [net] net/smc: wait for departure of an IB message (Philipp Rudo) [1725886]
- [net] net/smc: handle incoming CDC validation message (Philipp Rudo) [1725886]
- [net] net/smc: send failover validation message (Philipp Rudo) [1725886]
- [net] net/smc: switch connections to alternate link (Philipp Rudo) [1725886]
- [net] net/smc: save state of last sent CDC message (Philipp Rudo) [1725886]
- [net] net/smc: enqueue local LLC messages (Philipp Rudo) [1725886]
- [net] net/smc: delete link processing as SMC server (Philipp Rudo) [1725886]
- [net] net/smc: delete link processing as SMC client (Philipp Rudo) [1725886]
- [net] net/smc: llc_del_link_work and use the LLC flow for delete link (Philipp Rudo) [1725886]
- [net] net/smc: delete an asymmetric link as SMC server (Philipp Rudo) [1725886]
- [net] net/smc: final part of add link processing as SMC server (Philipp Rudo) [1725886]
- [net] net/smc: rkey processing for a new link as SMC server (Philipp Rudo) [1725886]
- [net] net/smc: first part of add link processing as SMC server (Philipp Rudo) [1725886]
- [net] net/smc: final part of add link processing as SMC client (Philipp Rudo) [1725886]
- [net] net/smc: rkey processing for a new link as SMC client (Philipp Rudo) [1725886]
- [net] net/smc: first part of add link processing as SMC client (Philipp Rudo) [1725886]
- [net] smc: Remove unused function (Philipp Rudo) [1725886]
- [net] net/smc: llc_add_link_work to handle ADD_LINK LLC requests (Philipp Rudo) [1725886]
- [net] net/smc: allocate index for a new link (Philipp Rudo) [1725886]
- [net] net/smc: introduce smc_pnet_find_alt_roce() (Philipp Rudo) [1725886]
- [net] net/smc: remove DELETE LINK processing from smc_core.c (Philipp Rudo) [1725886]
- [net] net/smc: take link down instead of terminating the link group (Philipp Rudo) [1725886]
- [net] net/smc: add smcr_port_err() and smcr_link_down() processing (Philipp Rudo) [1725886]
- [net] net/smc: add smcr_port_add() and smcr_link_up() processing (Philipp Rudo) [1725886]
- [net] net/smc: remember PNETID of IB device for later device matching (Philipp Rudo) [1725886]
- [net] net/smc: mutex to protect the lgr against parallel reconfigurations (Philipp Rudo) [1725886]
- [net] net/smc: extend smc_llc_send_add_link() and smc_llc_send_delete_link() (Philipp Rudo) [1725886]
- [net] net/smc: map and register buffers for a new link (Philipp Rudo) [1725886]
- [net] net/smc: unmapping of buffers to support multiple links (Philipp Rudo) [1725886]
- [net] net/smc: multiple link support for rmb buffer registration (Philipp Rudo) [1725886]
- [net] net/smc: remove obsolete link state DELETING (Philipp Rudo) [1725886]
- [net] net/smc: remove handling of CONFIRM_RKEY_CONTINUE (Philipp Rudo) [1725886]
- [net] net/smc: adapt SMC remote DELETE_RKEY processing to use the LLC flow (Philipp Rudo) [1725886]
- [net] net/smc: adapt SMC remote CONFIRM_RKEY processing to use the LLC flow (Philipp Rudo) [1725886]
- [net] net/smc: new smc_rtoken_set functions for multiple link support (Philipp Rudo) [1725886]
- [net] net/smc: move the TEST_LINK response processing into event handler (Philipp Rudo) [1725886]
- [net] net/smc: multiple link support and LLC flow for smc_llc_do_delete_rkey (Philipp Rudo) [1725886]
- [net] net/smc: multiple link support and LLC flow for smc_llc_do_confirm_rkey (Philipp Rudo) [1725886]
- [net] net/smc: adapt SMC client code to use the LLC flow (Philipp Rudo) [1725886]
- [net] net/smc: adapt SMC server code to use the LLC flow (Philipp Rudo) [1725886]
- [net] net/smc: add logic to evaluate CONFIRM_LINK messages to LLC layer (Philipp Rudo) [1725886]
- [net] net/smc: introduce link group type (Philipp Rudo) [1725886]
- [net] net/smc: enqueue all received LLC messages (Philipp Rudo) [1725886]
- [net] net/smc: add event-based llc_flow framework (Philipp Rudo) [1725886]
- [net] net/smc: move llc layer related init and clear into smc_llc.c (Philipp Rudo) [1725886]
- [net] net/smc: use mutex instead of rwlock_t to protect buffers (Philipp Rudo) [1725886]
- [net] net/smc: process llc responses in tasklet context (Philipp Rudo) [1725886]
- [net] net/smc: use worker to process incoming llc messages (Philipp Rudo) [1725886]
- [net] net/smc: simplify link deactivation (Philipp Rudo) [1725886]
- [net] net/smc: move testlink work to system work queue (Philipp Rudo) [1725886]
- [net] net/smc: add new link state and related helpers (Philipp Rudo) [1725886]
- [net] net/smc: multi-link support for smc_rmb_rtoken_handling() (Philipp Rudo) [1725886]
- [net] net/smc: convert static link ID instances to support multiple links (Philipp Rudo) [1725886]
- [net] net/smc: convert static link ID to dynamic references (Philipp Rudo) [1725886]
- [net] net/smc: introduce link_idx for link group array (Philipp Rudo) [1725886]
- [net] net/smc: separate function for link initialization (Philipp Rudo) [1725886]
- [net] net/smc: rework pnet table to support SMC-R failover (Philipp Rudo) [1725886]
- [net] net/smc: improve peer ID in CLC decline for SMC-R (Philipp Rudo) [1725886]
- [net] net/smc: rework peer ID handling (Philipp Rudo) [1725886]
- [net] net/smc: reduce port_event scheduling (Philipp Rudo) [1725886]
- [net] net/smc: simplify normal link termination (Philipp Rudo) [1725886]
- [net] net/smc: remove unused parameter of smc_lgr_terminate() (Philipp Rudo) [1725886]
- [net] net/smc: do not delete lgr from list twice (Philipp Rudo) [1725886]
- [net] net/smc: use termination worker under send_lock (Philipp Rudo) [1725886]
- [net] net/smc: improve smc_lgr_cleanup() (Philipp Rudo) [1725886]
- [pci] PCI: Add new PCI_VPD_RO_KEYWORD_SERIALNO macro (Jonathan Toppins) [1834900]
- [pci] PCI: Introduce pci_get_dsn (Jonathan Toppins) [1834900]
- [scsi] scsi: lpfc: Remove redundant initialization to variable rc (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Update lpfc version to 12.8.0.1 (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Fix MDS Diagnostic Enablement definition (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Fix noderef and address space warnings (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Remove unnecessary lockdep_assert_held calls (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Change default queue allocation for reduced memory consumption (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Fix negation of else clause in lpfc_prep_node_fc4type (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Remove re-binding of nvme rport during registration (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: Maintain atomic consistency of queue_claimed flag (Dick Kennedy) [1835310]
- [scsi] scsi: lpfc: remove duplicate unloading checks (Dick Kennedy) [1835310]
- [scsi] scsi: qedf: Get dev info after updating the params (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Fix crash when MFW calls for protocol stats while function is still probing (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Add schedule recovery handler (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Implement callback for bw_update (Nilesh Javali) [1792113]
- [netdrv] scsi: qed: Send BW update notifications to the protocol drivers (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Honor status qualifier in FCP_RSP per spec (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Acquire rport_lock for resetting the delay_timestamp (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Increase the upper limit of retry delay (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Keep track of num of pending flogi (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Simplify mutex_unlock() usage (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Add port_id getter (Nilesh Javali) [1792113]
- [scsi] scsi: qedf: Remove always false 'tmp_prio < 0' statement (Nilesh Javali) [1792113]
- [include] NFSv4.1: fix handling of backchannel binding in BIND_CONN_TO_SESSION (Steve Dickson) [1828592]
- [edac] EDAC/amd64: Drop some family checks for newer systems (Aristeu Rozanski) [1779822 1735611]
- [edac] EDAC/amd64: Add family ops for Family 19h Models 00h-0Fh (Aristeu Rozanski) [1779822 1735611]
- [x86] x86/amd_nb: Add Family 19h PCI IDs (Aristeu Rozanski) [1779822 1735611]
- [edac] EDAC/mce_amd: Always load on SMCA systems (Aristeu Rozanski) [1779822 1735611]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new Load Store unit McaType (Aristeu Rozanski) [1779822 1735611]
- [edac] EDAC/amd64: Save max number of controllers to family type (Aristeu Rozanski) [1779822 1735611]
- [edac] EDAC/amd64: Gather hardware information early (Aristeu Rozanski) [1779822 1735611]
- [edac] EDAC/amd64: Make struct amd64_family_type global (Aristeu Rozanski) [1779822 1735611]
- [fs] nfsd: Add tracepoints for update of the expkey and export cache entries (Dave Wysochanski) [1775408]
- [fs] nfsd: Add tracepoints for exp_find_key() and exp_get_by_name() (Dave Wysochanski) [1775408]
- [fs] nfsd: Add tracing to nfsd_set_fh_dentry() (Dave Wysochanski) [1775408]
- [net] SUNRPC: Clean up: Replace dprintk and BUG_ON call sites in svcauth_gss.c (Dave Wysochanski) [1775408]
- [net] svcrdma: Create a generic tracing class for displaying xdr_buf layout (Dave Wysochanski) [1775408]
- [net] SUNRPC: Capture completion of all RPC tasks (Dave Wysochanski) [1775408]
- [net] SUNRPC: Trace gssproxy upcall results (Dave Wysochanski) [1775408]
- [trace] fix null pointer deref in tracepoints in back channel (Dave Wysochanski) [1775408]
- [fs] NFS: Clean up generic file commit tracepoint (Dave Wysochanski) [1775408]
- [fs] NFS: Clean up generic writeback tracepoints (Dave Wysochanski) [1775408]
- [fs] NFS: Clean up generic file read tracepoints (Dave Wysochanski) [1775408]
- [fs] pNFS/flexfiles: Add tracing for layout errors (Dave Wysochanski) [1775408]
- [fs] pNFS/flexfiles: Record resend attempts on I/O failure (Dave Wysochanski) [1775408]
- [fs] NFS: Fix fix of show_nfs_errors (Dave Wysochanski) [1775408]
- [fs] NFSv4: Improve read/write/commit tracing (Dave Wysochanski) [1775408]
- [fs] NFS4: Report callback authentication errors (Dave Wysochanski) [1775408]
- [fs] NFS4: Trace lock reclaims (Dave Wysochanski) [1775408]
- [fs] NFS4: Trace state recovery operation (Dave Wysochanski) [1775408]
- [fs] NFS: Add a tracepoint in nfs_fh_to_dentry() (Dave Wysochanski) [1775408]
- [fs] pnfs/flexfiles: Add tracepoints for detecting pnfs fallback to MDS (Dave Wysochanski) [1775408]
- [fs] NFS: Record task, client ID, and XID in xdr_status trace points (Dave Wysochanski) [1775408]
- [fs] NFS: Display symbolic status code names in trace log (Dave Wysochanski) [1775408]
- [fs] NFS: Fix show_nfs_errors macros again (Dave Wysochanski) [1775408]
- [fs] NFS4: Add a trace event to record invalid CB sequence IDs (Dave Wysochanski) [1775408]
- [media] media: v4l: event: Add subscription to list before calling "add" operation (Jarod Wilson) [1828805] {CVE-2019-9458}
- [media] media: v4l: event: Prevent freeing event subscriptions while accessed (Jarod Wilson) [1828805] {CVE-2019-9458}
- [vhost] vhost: Check docket sk_family instead of call getname (Vladis Dronov) [1823301] {CVE-2020-10942}
- [documentation] kvm: ppc: book3s hv: Add a capability for enabling secure guests (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: H_SVM_INIT_START must call UV_RETURN (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Check caller of H_SVM_* Hcalls (David Gibson) [1814624]
- [powerpc] Introduce the MSR_S bit (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Skip kvmppc_uvmem_free if Ultravisor is not supported (David Gibson) [1814624]
- [powerpc] kvm: ppc: Kill kvmppc_ops::mmu_destroy() and kvmppc_mmu_destroy() (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s pr: Move kvmppc_mmu_init() into PR KVM (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Treat TM-related invalid form instructions on P9 like the valid ones (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Use RADIX_PTE_INDEX_SIZE in Radix MMU code (David Gibson) [1814624]
- [powerpc] kvm: no need to check return value of debugfs_create functions (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s pr: Fix -Werror=return-type build failure (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Release lock on page-out failure path (David Gibson) [1814624]
- [powerpc] mm: Remove kvm radix prefetch workaround for Power9 DD2.2 (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: xive: Fix typo in comment (David Gibson) [1814624]
- [documentation] kvm: ppc: book3s hv: Implement H_SVM_INIT_ABORT hcall (David Gibson) [1814624]
- [powerpc] kvm: ppc: Add skip_page_out parameter to uvmem functions (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3e: Replace current->mm by kvm->mm (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s: Replace current->mm by kvm->mm (David Gibson) [1814624]
- [mm] add account_locked_vm utility function (David Gibson) [1814624]
- [powerpc] kvm: ppc: Remove set but not used variable 'ra', 'rs', 'rt' (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Don't do ultravisor calls on systems without ultravisor (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Support reset of secure guest (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Handle memory plug/unplug to secure VM (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Radix changes for secure guest (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Shared pages support for secure guests (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Support for running secure guests (David Gibson) [1814624]
- [powerpc] pseries/svm: Unshare all pages before kexecing a new kernel (David Gibson) [1814624]
- [powerpc] pseries/svm: Use shared memory for LPPACA structures (David Gibson) [1814624]
- [powerpc] pseries: Add and use LPPACA_SIZE constant (David Gibson) [1814624]
- [powerpc] pseries/svm: Add helpers for UV_SHARE_PAGE and UV_UNSHARE_PAGE (David Gibson) [1814624]
- [powerpc] prom_init: Add the ESM call to prom_init (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Reject mflags=2 (LPCR[AIL]=2) ADDR_TRANS_MODE mode (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Implement LPCR[AIL]=3 mode for injected interrupts (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Reuse kvmppc_inject_interrupt for async guest delivery (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s: Replace reset_msr mmu op with inject_interrupt arch op (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s: Define and use SRR1_MSR_BITS (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: xive: Show VP id in debugfs (David Gibson) [1814624]
- [powerpc] kvm: ppc: e500: Replace current->mm by kvm->mm (David Gibson) [1814624]
- [powerpc] kvm: ppc: Report single stepping capability (David Gibson) [1814624]
- [powerpc] kvm: Fix kvmppc_vcore->in_guest value in kvmhv_switch_to_host (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: use smp_mb() when setting/clearing host_ipi flag (David Gibson) [1814624]
- [powerpc] 64s: Set reserved PCR bits (David Gibson) [1814624]
- [powerpc] Fix definition of PCR bits to work with old binutils (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s: Invalidate multiple TCEs at once (David Gibson) [1814624]
- [powerpc] powernv/ioda: Split out TCE invalidation from TCE updates (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Don't lose pending doorbell request on migration on P9 (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Check for MMU ready on piggybacked virtual cores (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Define usage types for rmap array in guest memslot (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Don't push XIVE context when not using XIVE device (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s hv: Fix race in re-enabling XIVE escalation interrupts (David Gibson) [1814624]
- [powerpc] kvm: ppc: book3s pr: Fix software breakpoints (David Gibson) [1814624]
- [powerpc] kvm: ppc: Remove leftover comment from emulate_loadstore.c (David Gibson) [1814624]
- [x86] hyperv: Properly suspend/resume reenlightenment notifications (Mohammed Gamal) [1815475]
- [kernel] pm: hibernate: Freeze kernel threads in software_resume() (Mohammed Gamal) [1815475]
- [kernel] pm: hibernate: Propagate the return value of hibernation_restore() (Mohammed Gamal) [1815475]
- [x86] hyperv: Suspend/resume the VP assist page for hibernation (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Fix Suspend-to-Idle for Generation-2 VM (Mohammed Gamal) [1815475]
- [net] hv_sock: Add the support of hibernation (Mohammed Gamal) [1815475]
- [video] hyperv_fb: Fix hibernation for the deferred IO feature (Mohammed Gamal) [1815475]
- [video] hyperv_fb: Add the support of hibernation (Mohammed Gamal) [1815475]
- [scsi] storvsc: Add the support of hibernation (Mohammed Gamal) [1815475]
- [netdrv] hv_netvsc: Add the support of hibernation (Mohammed Gamal) [1815475]
- [pci] hv: Change pci_protocol_version to per-hbus (Mohammed Gamal) [1815475]
- [pci] hv: Add hibernation support (Mohammed Gamal) [1815475]
- [input] hyperv-keyboard: Add the support of hibernation (Mohammed Gamal) [1815475]
- [hid] hyperv: NULL check before some freeing functions is not needed (Mohammed Gamal) [1815475]
- [hid] hyperv: Add the support of hibernation (Mohammed Gamal) [1815475]
- [clocksource] hyper-v: Suspend/resume Hyper-V clocksource for hibernation (Mohammed Gamal) [1815475]
- [x86] hyperv: Suspend/resume the hypercall page for hibernation (Mohammed Gamal) [1815475]
- [x86] hyperv: Implement hv_is_hibernation_supported() (Mohammed Gamal) [1815475]
- [hv] hv_utils: Add the support of hibernation (Mohammed Gamal) [1815475]
- [hv] hv_utils: Support host-initiated hibernation request (Mohammed Gamal) [1815475]
- [hv] hv_utils: Support host-initiated restart request (Mohammed Gamal) [1815475]
- [hv] hv_balloon: Add the support of hibernation (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Fix harmless building warnings without CONFIG_PM_SLEEP (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Resume after fixing up old primary channels (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Suspend after cleaning up hv_sock and sub channels (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Clean up hv_sock channels by force upon suspend (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Suspend/resume the vmbus itself for hibernation (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Ignore the offers when resuming from hibernation (Mohammed Gamal) [1815475]
- [hv] hv: vmbus: Implement suspend/resume for VSC drivers for hibernation (Mohammed Gamal) [1815475]
- [net] ipv4: really enforce backoff for redirects (Paolo Abeni) [1834184]
- [net] netfilter: nat: never update the UDP checksum when it's 0 (Guillaume Nault) [1794714]
- [net] sched: allow flower to match erspan options (Xin Long) [1830482]
- [net] sched: allow flower to match vxlan options (Xin Long) [1830482]
- [net] sched: add erspan option support to act_tunnel_key (Xin Long) [1830482]
- [net] sched: add vxlan option support to act_tunnel_key (Xin Long) [1830482]
- [netdrv] netdevsim: disable devlink reload when resources are being used (Ivan Vecera) [1829778]
- [netdrv] netdevsim: fix using uninitialized resources (Ivan Vecera) [1829778]
- [netdrv] drivers/net: netdevsim depends on INET (Ivan Vecera) [1829778]
- [netdrv] netdevsim: fix nsim_fib6_rt_create() error path (Ivan Vecera) [1829778]
- [tools] selftests: netdevsim: Add test for FIB offload API (Ivan Vecera) [1829778]
- [tools] selftests: forwarding: Add helpers and tests for FIB offload (Ivan Vecera) [1829778]
- [tools] selftests: mlxsw: Add a self-test for port-default priority (Ivan Vecera) [1829778]
- [netdrv] netdevsim: fib: Add dummy implementation for FIB offload (Ivan Vecera) [1829778]
- [net] ipv6: Add "offload" and "trap" indications to routes (Ivan Vecera) [1829778]
- [net] ipv4: Add "offload" and "trap" indications to routes (Ivan Vecera) [1829778]
- [net] ipv4: Encapsulate function arguments in a struct (Ivan Vecera) [1829778]
- [net] ipv4: Replace route in list before notifying (Ivan Vecera) [1829778]
- [tools] selftests: netdevsim: Extend devlink trap test to include flow action cookie (Petr Oros) [1823745]
- [netdrv] netdevsim: add ACL trap reporting cookie as a metadata (Petr Oros) [1823745]
- [net] devlink: extend devlink_trap_report() to accept cookie and pass (Petr Oros) [1823745]
- [net] drop_monitor: extend by passing cookie from driver (Petr Oros) [1823745]
- [net] devlink: add trap metadata type for cookie (Petr Oros) [1823745]
- [net] devlink: add ACL generic packet traps (Petr Oros) [1823745]
- [net] devlink: Add overlay source MAC is multicast trap (Petr Oros) [1823745]
- [net] devlink: Add tunnel generic packet traps (Petr Oros) [1823745]
- [net] devlink: Add non-routable packet trap (Petr Oros) [1823745]
- [netdrv] mlxsw: spectrum_router: Prevent incorrect replacement of local table routes (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Remove FIB entry list from FIB node (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Consolidate identical functions (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Make route creation and destruction symmetric (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Eliminate dead code (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Remove unnecessary checks (Ivan Vecera) [1828994]
- [net] ipv6: Remove old route notifications and convert listeners (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Start using new IPv6 route notifications (Ivan Vecera) [1828994]
- [net] ipv6: Handle multipath route deletion notification (Ivan Vecera) [1828994]
- [net] ipv6: Handle route deletion notification (Ivan Vecera) [1828994]
- [net] ipv6: Only Replay routes of interest to new listeners (Ivan Vecera) [1828994]
- [net] ipv6: Notify multipath route if should be offloaded (Ivan Vecera) [1828994]
- [net] ipv6: Notify route if replacing currently offloaded one (Ivan Vecera) [1828994]
- [net] ipv6: Notify newly added route if should be offloaded (Ivan Vecera) [1828994]
- [include] net: fib_notifier: Add temporary events to the FIB notification chain (Ivan Vecera) [1828994]
- [net] ipv4: Remove old route notifications and convert listeners (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Start using new IPv4 route notifications (Ivan Vecera) [1828994]
- [netdrv] mlxsw: spectrum_router: Don't rely on missing extack to symbolize dump (Ivan Vecera) [1828994]
- [net] ipv4: Only Replay routes of interest to new listeners (Ivan Vecera) [1828994]
- [net] ipv4: Handle route deletion notification during flush (Ivan Vecera) [1828994]
- [net] ipv4: Handle route deletion notification (Ivan Vecera) [1828994]
- [net] ipv4: Notify newly added route if should be offloaded (Ivan Vecera) [1828994]
- [net] ipv4: Notify route if replacing currently offloaded one (Ivan Vecera) [1828994]
- [net] ipv4: Extend FIB alias find function (Ivan Vecera) [1828994]
- [net] ipv4: Notify route after insertion to the routing table (Ivan Vecera) [1828994]
- [include] net: fib_notifier: Add temporary events to the FIB notification chain (Ivan Vecera) [1828994]
- [net] vti6: Fix memory leak of skb if input policy check fails (Xin Long) [1829720]
- [net] xfrm: policy: Fix doulbe free in xfrm_policy_timer (Xin Long) [1829720]
- [net] xfrm: add the missing verify_sec_ctx_len check in xfrm_add_acquire (Xin Long) [1829720]
- [net] xfrm: fix uctx len check in verify_sec_ctx_len (Xin Long) [1829720]
- [net] xfrm: handle NETDEV_UNREGISTER for xfrm device (Xin Long) [1829720]
- [net] xfrm: interface: do not confirm neighbor when do pmtu update (Xin Long) [1829720]
- [documentation] xfrm: update doc about xfrm[46]_gc_thresh (Xin Long) [1829720]
- [documentation] devlink: remove trigger command from devlink-region.rst (Petr Oros) [1822570]
- [include] devlink: promote "fw.bundle_id" to a generic info version (Petr Oros) [1822570]
- [documentation] devlink: document devlink info versions reported by bnxt_en driver (Petr Oros) [1822570]
- [include] devlink: add macro for "fw.roce" (Petr Oros) [1822570]
- [documentation] Fix typo in devlink documentation (Petr Oros) [1822570]
- [documentation] devlink: fix typos in qed documentation (Petr Oros) [1822570]
- [documentation] devlink: document region snapshot triggering from userspace (Petr Oros) [1822570]
- [documentation] devlink: introduce devlink-dpipe.rst documentation file (Petr Oros) [1822570]
- [documentation] devlink: add a devlink-resource.rst documentation file (Petr Oros) [1822570]
- [netdrv] devlink: rename and expand devlink-trap-netdevsim.rst (Petr Oros) [1822570]
- [documentation] devlink: add documentation for ionic device driver (Petr Oros) [1822570]
- [documentation] devlink: add a file documenting devlink regions (Petr Oros) [1822570]
- [documentation] devlink: add a driver-specific file for the qed driver (Petr Oros) [1822570]
- [documentation] devlink: add parameter documentation for the mlx4 driver (Petr Oros) [1822570]
- [documentation] devlink: document info versions for each driver (Petr Oros) [1822570]
- [documentation] devlink: convert driver-specific files to reStructuredText (Petr Oros) [1822570]
- [documentation] devlink: mention reloading in devlink-params.rst (Petr Oros) [1822570]
- [documentation] devlink: add documentation for generic devlink parameters (Petr Oros) [1822570]
- [documentation] devlink: convert devlink-params.txt to reStructuredText (Petr Oros) [1822570]
- [documentation] devlink: rename devlink-info-versions.rst and add a header (Petr Oros) [1822570]
- [documentation] devlink: convert devlink-health.txt to rst format (Petr Oros) [1822570]
- [documentation] devlink: move devlink documentation to subfolder (Petr Oros) [1822570]
- [include] devlink: add macro for "fw.psid" (Petr Oros) [1822570]
- [netdrv] ethtool: Add support for 400Gbps (50Gbps per lane) link modes (Ivan Vecera) [1828942]
- [netdrv] phy: Add support for 100BaseT1 and 1000BaseT1 (Ivan Vecera) [1828942]
- [net] phy: improve definition of __ETHTOOL_LINK_MODE_MASK_NBITS (Ivan Vecera) [1828942]
- [net] netfilter: nf_tables: simplify NLM_F_CREATE handling (Phil Sutter) [1812666]
- [net] devlink: Add layer 3 generic packet exception traps (Petr Oros) [1828737]
- [net] devlink: Add layer 3 generic packet traps (Petr Oros) [1828737]
- [net] netfilter: nf_tables: fix infinite loop when expr is not available (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: autoload modules from the abort path (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: remove WARN and add NLA_STRING upper limits (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: store transaction list locally while requesting module (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: use-after-free in failing rule with bound set (Phil Sutter) [1757933]
- [net] netfilter: nft_meta: skip EAGAIN if nft_meta_bridge is not a module (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: force module load in case select_ops() returns -EAGAIN (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: add nft_expr_type_request_module() (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: bogus EBUSY in helper removal from transaction (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: fix set double-free in abort path (Phil Sutter) [1757933]
- [net] netfilter: nft_compat: don't use refcount_inc on newly allocated entry (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: unbind set in rule from commit path (Phil Sutter) [1757933]
- [net] netfilter: nft_compat: destroy function must not have side effects (Phil Sutter) [1757933]
- [net] netfilter: nft_compat: make lists per netns (Phil Sutter) [1757933]
- [net] netfilter: nft_compat: use refcnt_t type for nft_xt reference count (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: fix suspicious RCU usage in nft_chain_stats_replace() (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: asynchronous release (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: split set destruction in deactivate and destroy phase (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: flow event notifier must use transaction mutex (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: use dedicated mutex to guard transactions (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: avoid global info storage (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: take module reference when starting a batch (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: make valid_genid callback mandatory (Phil Sutter) [1757933]
- [net] netfilter: nf_tables: add and use helper for module autoload (Phil Sutter) [1757933]

* Tue May 19 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-201.el8]
- [kernel] sched: Fix missing bracket in membarrier_switch_mm from mismerge (Phil Auld) [1745111]
- [fs] nfs: fix NULL deference in nfs4_get_valid_delegation ("J. Bruce Fields") [1831553]
- [acpi] PCI/AER: Use only _OSC to determine AER ownership (Myron Stowe) [1712820]
- [pci] PCI/EDR: Log only ACPI_NOTIFY_DISCONNECT_RECOVER events (Myron Stowe) [1712820]
- [pci] PCI/AER: Rationalize error status register clearing (Myron Stowe) [1712820]
- [pci] PCI/DPC: Add Error Disconnect Recover (EDR) support (Myron Stowe) [1712820]
- [pci] PCI/DPC: Expose dpc_process_error(), dpc_reset_link() for use by EDR (Myron Stowe) [1712820]
- [pci] PCI/AER: Add pci_aer_raw_clear_status() to unconditionally clear Error Status (Myron Stowe) [1712820]
- [pci] PCI/DPC: Cache DPC capabilities in pci_init_capabilities() (Myron Stowe) [1712820]
- [pci] PCI/ERR: Return status of pcie_do_recovery() (Myron Stowe) [1712820]
- [pci] PCI/ERR: Remove service dependency in pcie_do_recovery() (Myron Stowe) [1712820]
- [pci] PCI/DPC: Move DPC data into struct pci_dev (Myron Stowe) [1712820]
- [pci] PCI/ERR: Update error status after reset_link() (Myron Stowe) [1712820]
- [pci] PCI/ERR: Combine pci_channel_io_frozen cases (Myron Stowe) [1712820]
- [pci] PCI/ASPM: Reduce severity of common clock config message (Myron Stowe) [1712820]
- [pci] PCI/ASPM: Clear the correct bits when enabling L1 substates (Myron Stowe) [1712820]
- [pci] PCI/PM: Print config space of devices before suspend (Myron Stowe) [1712820]
- [pci] PCI/AER: Initialize aer_fifo (Myron Stowe) [1712820]
- [pci] PCI/AER: Factor message prefixes with dev_fmt() (Myron Stowe) [1712820]
- [pci] PCI/AER: Log which device prevents error recovery (Myron Stowe) [1712820]
- [security] ima: Switch to ima_hash_algo for boot aggregate (Jerry Snitselaar) [1786441]
- [mm] mm: mempolicy: require at least one nodeid for MPOL_PREFERRED (Rafael Aquini) [1834435] {CVE-2020-11565}
- [tools] perf maps: Add missing unlock to maps__insert() error case (Michael Petlan) [1818838]
- [tools] perf dso: Fix dso comparison (Michael Petlan) [1818838]
- [tools] perf block-info: Fix wrong block address comparison in block_info__cmp() (Michael Petlan) [1818838]
- [tools] libperf: Setup initial evlist::all_cpus value (Michael Petlan) [1818838]
- [tools] perf report: Fix no libunwind compiled warning break s390 issue (Michael Petlan) [1818838]
- [tools] perf hists: Fix variable name's inconsistency in hists__for_each() macro (Michael Petlan) [1818838]
- [tools] perf map: Set kmap->kmaps backpointer for main kernel map chunks (Michael Petlan) [1818838]
- [tools] perf report: Fix incorrectly added dimensions as switch perf data file (Michael Petlan) [1818838]
- [tools] tools lib traceevent: Fix memory leakage in filter_event (Michael Petlan) [1818838]
- [tools] perf vendor events s390: Remove name from L1D_RO_EXCL_WRITES description (Michael Petlan) [1818838]
- [tools] perf vendor events s390: Fix counter long description for DTLB1_GPAGE_WRITES (Michael Petlan) [1818838]
- [tools] libtraceevent: Allow custom libdir path (Michael Petlan) [1818838]
- [tools] perf top: Do not bail out when perf_env__read_cpuid() returns ENOSYS (Michael Petlan) [1818838]
- [tools] perf arch: Make the default get_cpuid() return compatible error (Michael Petlan) [1818838]
- [tools] perf inject: Fix processing of ID index for injected instruction tracing (Michael Petlan) [1818838]
- [tools] perf report: Bail out --mem-mode if mem info is not available (Michael Petlan) [1818838]
- [tools] perf report: Make -F more strict like -s (Michael Petlan) [1818838]
- [tools] perf report/top TUI: Replace pr_err() with ui__error() (Michael Petlan) [1818838]
- [tools] libtraceevent: Copy pkg-config file to output folder when using O= (Michael Petlan) [1818838]
- [tools] libtraceevent: Fix lib installation with O= (Michael Petlan) [1818838]
- [tools] perf kvm: Clarify the 'perf kvm' -i and -o command line options (Michael Petlan) [1818838]
- [tools] perf machine: Fill map_symbol->maps in append_inlines() to fix segfault (Michael Petlan) [1818838]
- [tools] perf jit: Move test functionality in to a test (Michael Petlan) [1818838]
- [tools] perf stat: Use affinity for enabling/disabling events (Michael Petlan) [1818838]
- [tools] perf evsel: Add functions to enable/disable for a specific CPU (Michael Petlan) [1818838]
- [tools] perf stat: Use affinity for reading (Michael Petlan) [1818838]
- [tools] perf stat: Use affinity for opening events (Michael Petlan) [1818838]
- [tools] perf stat: Factor out open error handling (Michael Petlan) [1818838]
- [tools] perf stat: Use affinity for closing file descriptors (Michael Petlan) [1818838]
- [tools] perf evsel: Add functions to close evsel on a CPU (Michael Petlan) [1818838]
- [tools] perf evsel: Add iterator to iterate over events ordered by CPU (Michael Petlan) [1818838]
- [tools] perf evlist: Maintain evlist->all_cpus (Michael Petlan) [1818838]
- [tools] perf cpumap: Maintain cpumaps ordered and without dups (Michael Petlan) [1818838]
- [tools] perf script: Fix brstackinsn for AUXTRACE (Michael Petlan) [1818838]
- [tools] perf affinity: Add infrastructure to save/restore affinity (Michael Petlan) [1818838]
- [tools] perf pmu: Use file system cache to optimize sysfs access (Michael Petlan) [1818838]
- [tools] perf regs: Make perf_reg_name() return "unknown" instead of NULL (Michael Petlan) [1818838]
- [tools] perf diff: Use llabs() with 64-bit values (Michael Petlan) [1818838]
- [tools] perf diff: Use llabs() with 64-bit values (Michael Petlan) [1818838]
- [tools] perf tests: Rename tests/map_groups.c to tests/maps.c (Michael Petlan) [1818838]
- [tools] perf tests: Rename thread-mg-share to thread-maps-share (Michael Petlan) [1818838]
- [tools] perf maps: Rename map_groups.h to maps.h (Michael Petlan) [1818838]
- [tools] perf maps: Rename 'mg' variables to 'maps' (Michael Petlan) [1818838]
- [tools] perf map_symbol: Rename ms->mg to ms->maps (Michael Petlan) [1818838]
- [tools] perf addr_location: Rename al->mg to al->maps (Michael Petlan) [1818838]
- [tools] perf thread: Rename thread->mg to thread->maps (Michael Petlan) [1818838]
- [tools] perf maps: Merge 'struct maps' with 'struct map_groups' (Michael Petlan) [1818838]
- [tools] x86/insn: perf tools: Add some more instructions to the new instructions test (Michael Petlan) [1818838]
- [tools] perf map: Remove unused functions (Michael Petlan) [1818838]
- [tools] perf map: Remove needless struct forward declarations (Michael Petlan) [1818838]
- [tools] perf map: Ditch leftover map__reloc_vmlinux() prototype (Michael Petlan) [1818838]
- [tools] perf script: Move map__fprintf_srccode() to near its only user (Michael Petlan) [1818838]
- [tools] perf parse: Fix potential memory leak when handling tracepoint errors (Michael Petlan) [1818838]
- [tools] libtraceevent: Fix memory leakage in copy_filter_type (Michael Petlan) [1818838]
- [tools] libtraceevent: Fix header installation (Michael Petlan) [1818838]
- [tools] perf intel-bts: Does not support AUX area sampling (Michael Petlan) [1818838]
- [tools] perf intel-pt: Add support for decoding AUX area samples (Michael Petlan) [1818838]
- [tools] perf intel-pt: Add support for recording AUX area samples (Michael Petlan) [1818838]
- [tools] perf pmu: When using default config, record which bits of config were changed by the user (Michael Petlan) [1818838]
- [tools] perf auxtrace: Add support for queuing AUX area samples (Michael Petlan) [1818838]
- [tools] perf session: Add facility to peek at all events (Michael Petlan) [1818838]
- [tools] perf auxtrace: Add support for dumping AUX area samples (Michael Petlan) [1818838]
- [tools] perf inject: Cut AUX area samples (Michael Petlan) [1818838]
- [tools] perf record: Add aux-sample-size config term (Michael Petlan) [1818838]
- [tools] perf record: Add support for AUX area sampling (Michael Petlan) [1818838]
- [tools] perf auxtrace: Add support for AUX area sample recording (Michael Petlan) [1818838]
- [tools] perf auxtrace: Move perf_evsel__find_pmu() (Michael Petlan) [1818838]
- [tools] perf record: Add a function to test for kernel support for AUX area sampling (Michael Petlan) [1818838]
- [tools] perf tools: Add kernel AUX area sampling definitions (Michael Petlan) [1818838]
- [tools] perf report: Jump to symbol source view from total cycles view (Michael Petlan) [1818838]
- [tools] perf util: Move block TUI function to ui browsers (Michael Petlan) [1818838]
- [tools] perf dso: Move dso_id from 'struct map' to 'struct dso' (Michael Petlan) [1818838]
- [tools] perf dsos: Remove unused dsos__find() method (Michael Petlan) [1818838]
- [tools] perf map: Move comparision of map's dso_id to a separate function (Michael Petlan) [1818838]
- [tools] perf map: Pass a dso_id to map__new() (Michael Petlan) [1818838]
- [tools] perf map: Move maj/min/ino/ino_generation to separate struct (Michael Petlan) [1818838]
- [tools] perf parse: Report initial event parsing error (Michael Petlan) [1818838]
- [tools] x86/insn: perf tools: Add some instructions to the new instructions test (Michael Petlan) [1818838]
- [tools] perf map: Move seldom used ->flags field to second cacheline (Michael Petlan) [1818838]
- [tools] perf map: Use bitmap for booleans (Michael Petlan) [1818838]
- [tools] libtraceevent: Fix parsing of event o and X argument types (Michael Petlan) [1818838]
- [tools] perf callchain: Fix segfault in thread__resolve_callchain_sample() (Michael Petlan) [1818838]
- [tools] perf map_groups: Auto sort maps by name, if needed (Michael Petlan) [1818838]
- [tools] perf machine: No need to check if kernel module maps pre-exist (Michael Petlan) [1818838]
- [tools] perf record: No need to process the synthesized MMAP events twice (Michael Petlan) [1818838]
- [tools] perf map: No need to adjust the long name of modules (Michael Petlan) [1818838]
- [tools] perf map_groups: Add a front end cache for map lookups by name (Michael Petlan) [1818838]
- [tools] perf maps: Do not use an rbtree to sort by map name (Michael Petlan) [1818838]
- [tools] perf maps: Purge the entries from maps->names in __maps__purge() (Michael Petlan) [1818838]
- [tools] perf vendor events power9: Fix commas so PMU event files are valid JSON (Michael Petlan) [1818838]
- [tools] perf vendor events power8: Fix commas so PMU event files are valid JSON (Michael Petlan) [1818838]
- [tools] perf vendor events arm64: Fix commas so PMU event files are valid JSON (Michael Petlan) [1818838]
- [tools] perf parse: Use YYABORT to clear stack after failure, plugging leaks (Michael Petlan) [1818838]
- [tools] perf tool: Provide an option to print perf_event_open args and return value (Michael Petlan) [1818838]
- [tools] perf map: Remove ->groups from 'struct map' (Michael Petlan) [1818838]
- [tools] perf map: Combine maps__fixup_overlappings with its only use (Michael Petlan) [1818838]
- [tools] perf annotate: Stop using map->groups, use map_symbol->mg instead (Michael Petlan) [1818838]
- [tools] perf tools: Add a 'struct map_groups' pointer to 'struct map_symbol' (Michael Petlan) [1818838]
- [tools] perf symbols: Use kmaps(map)->machine when we know its a kernel map (Michael Petlan) [1818838]
- [tools] pref tools: Make 'struct addr_map_symbol' contain 'struct map_symbol' (Michael Petlan) [1818838]
- [tools] perf callchain: Use 'struct map_symbol' in 'struct callchain_cursor_node' (Michael Petlan) [1818838]
- [tools] perf unwind: Use 'struct map_symbol' in 'struct unwind_entry' (Michael Petlan) [1818838]
- [tools] perf annotate: Pass a 'map_symbol' in places receiving a pair of 'map' and 'symbol' pointers (Michael Petlan) [1818838]
- [tools] perf tools: Add map_groups to 'struct addr_location' (Michael Petlan) [1818838]
- [tools] perf map_groups: Pass the object to map_groups__find_ams() (Michael Petlan) [1818838]
- [tools] perf symbols: Stop using map->groups, we can use kmaps instead (Michael Petlan) [1818838]
- [tools] perf map: Use map->dso->kernel + map__kmaps() in map__kmaps() (Michael Petlan) [1818838]
- [tools] perf report: Sort by sampled cycles percent per block for tui (Michael Petlan) [1818838]
- [tools] perf report: Support --percent-limit for --total-cycles (Michael Petlan) [1818838]
- [tools] perf report: Sort by sampled cycles percent per block for stdio (Michael Petlan) [1818838]
- [tools] perf hist: Support block formats with compare/sort/display (Michael Petlan) [1818838]
- [tools] perf hist: Count the total cycles of all samples (Michael Petlan) [1818838]
- [tools] perf block: Cleanup and refactor block info functions (Michael Petlan) [1818838]
- [tools] perf diff: Don't use hack to skip column length calculation (Michael Petlan) [1818838]
- [tools] perf tests: Fix out of bounds memory access (Michael Petlan) [1818838]
- [tools] perf record: Add support for limit perf output file size (Michael Petlan) [1818838]
- [tools] perf annotate: Fix heap overflow (Michael Petlan) [1818838]
- [tools] perf machine: Add kernel_dso() method (Michael Petlan) [1818838]
- [tools] perf symbols: Remove needless checks for map->groups->machine (Michael Petlan) [1818838]
- [tools] perf parse: Add a deep delete for parse event terms (Michael Petlan) [1818838]
- [tools] perf parse: If pmu configuration fails free terms (Michael Petlan) [1818838]
- [tools] perf parse: Before yyabort-ing free components (Michael Petlan) [1818838]
- [tools] perf parse: Add destructors for parse event terms (Michael Petlan) [1818838]
- [tools] perf parse: Ensure config and str in terms are unique (Michael Petlan) [1818838]
- [tools] perf parse: Add parse events handle error (Michael Petlan) [1818838]
- [tools] perf inject: Make --strip keep evsels (Michael Petlan) [1818838]
- [tools] perf tools: Fix cross compile for ARM64 (Michael Petlan) [1818838]
- [tools] perf stat: Add --per-node agregation support (Michael Petlan) [1818838]
- [tools] perf env: Add perf_env__numa_node() (Michael Petlan) [1818838]
- [tools] perf tools: Splice events onto evlist even on error (Michael Petlan) [1818838]
- [tools] libsubcmd: Use -O0 with DEBUG=1 (Michael Petlan) [1818838]
- [tools] libsubcmd: Move EXTRA_FLAGS to the end to allow overriding existing flags (Michael Petlan) [1818838]
- [tools] perf map_groups: Introduce for_each_entry() and for_each_entry_safe() iterators (Michael Petlan) [1818838]
- [tools] perf maps: Add for_each_entry()/_safe() iterators (Michael Petlan) [1818838]
- [tools] perf map: Allow map__next() to receive a NULL arg (Michael Petlan) [1818838]
- [tools] perf map: Check if the map still has some refcounts on exit (Michael Petlan) [1818838]
- [tools] perf dso: Add dso__data_write_cache_addr() (Michael Petlan) [1818838]
- [tools] perf dso: Refactor dso_cache__read() (Michael Petlan) [1818838]
- [tools] perf auxtrace: Add auxtrace_cache__remove() (Michael Petlan) [1818838]
- [tools] perf jevents: Fix resource leak in process_mapfile() and main() (Michael Petlan) [1818838]
- [tools] perf kvm: Use evlist layer api when possible (Michael Petlan) [1818838]
- [tools] perf tests: Fix a typo (Michael Petlan) [1818838]
- [tools] perf tools: Avoid a malloc() for array events (Michael Petlan) [1818838]
- [tools] perf tools: Move ALLOC_LIST into a function (Michael Petlan) [1818838]
- [tools] perf evsel: Avoid close(-1) (Michael Petlan) [1818838]
- [tools] perf evsel: Always preserve errno while cleaning up perf_event_open failures (Michael Petlan) [1818838]
- [tools] perf cs-etm: Fix definition of macro TO_CS_QUEUE_NR (Michael Petlan) [1818838]
- [tools] perf llvm: Make .o saving a debug message, not an info one (Michael Petlan) [1818838]
- [tools] perf record: Put a copy of kcore into the perf.data directory (Michael Petlan) [1818838]
- [tools] perf data: Support single perf.data file directory (Michael Petlan) [1818838]
- [tools] perf session: Fix indent in perf_session__new()" (Michael Petlan) [1818838]
- [tools] perf data: Rename directory "header" file to "data" (Michael Petlan) [1818838]
- [tools] perf data: Move perf_dir_version into data.h (Michael Petlan) [1818838]
- [tools] perf data: Correctly identify directory data files (Michael Petlan) [1818838]
- [tools] perf trace: Use STUL_STRARRAY_FLAGS with mmap (Michael Petlan) [1818838]
- [tools] perf trace: Wire up strarray__strtoul_flags() (Michael Petlan) [1818838]
- [tools] libbeauty: Introduce strarray__strtoul_flags() (Michael Petlan) [1818838]
- [tools] libbeauty: Make the mmap_flags strarray visible outside of its beautifier (Michael Petlan) [1818838]
- [tools] perf trace: Use strtoul for the fcntl 'cmd' argument (Michael Petlan) [1818838]
- [tools] libbeauty: Introduce syscall_arg__strtoul_strarrays() (Michael Petlan) [1818838]
- [tools] libperf: Add pr_err() macro (Michael Petlan) [1818838]
- [tools] libperf: Do not export perf_evsel__init()/perf_evlist__init() (Michael Petlan) [1818838]
- [tools] libperf: Keep count of failed tests (Michael Petlan) [1818838]
- [tools] libperf: Add tests_mmap_cpus test (Michael Petlan) [1818838]
- [tools] libperf: Add tests_mmap_thread test (Michael Petlan) [1818838]
- [tools] libperf: Link static tests with libapi.a (Michael Petlan) [1818838]
- [tools] libperf: Move mask setup to perf_evlist__mmap_ops() (Michael Petlan) [1818838]
- [tools] libperf: Move mmap allocation to perf_evlist__mmap_ops::get (Michael Petlan) [1818838]
- [tools] libperf: Introduce perf_evlist__for_each_mmap() (Michael Petlan) [1818838]
- [tools] perf tests: Disable bp_signal testing for arm64 (Michael Petlan) [1818838]
- [tools] perf tests bp_account: Add dedicated checking helper is_supported() (Michael Petlan) [1818838]
- [tools] perf tests: Remove needless headers for bp_account (Michael Petlan) [1818838]
- [tools] perf list: Hide deprecated events by default (Michael Petlan) [1818838]
- [tools] perf trace: Pass a syscall_arg to syscall_arg_fmt->strtoul() (Michael Petlan) [1818838]
- [tools] perf trace: Honour --max-events in processing syscalls:sys_enter_* (Michael Petlan) [1818838]
- [tools] libbeauty: Introduce syscall_arg__strtoul_strarray() (Michael Petlan) [1818838]
- [tools] perf trace: Initialize evsel_trace->fmt for syscalls:sys_enter_* tracepoints (Michael Petlan) [1818838]
- [tools] perf trace: Introduce 'struct evsel__trace' for evsel->priv needs (Michael Petlan) [1818838]
- [tools] perf trace: Hide evsel->access further, simplify code (Michael Petlan) [1818838]
- [tools] perf trace: Introduce accessors to trace specific evsel->priv (Michael Petlan) [1818838]
- [tools] perf trace: Show error message when not finding a field used in a filter expression (Michael Petlan) [1818838]
- [tools] perf trace: Hook the 'vec' tracepoint argument with the x86 IRQ vectors scnprintf/strtoul (Michael Petlan) [1818838]
- [tools] perf trace beauty: Add the glue for the autogenerated x86 IRQ vector array (Michael Petlan) [1818838]
- [tools] libbeauty: Add a strarray__scnprintf_suffix() method (Michael Petlan) [1818838]
- [tools] libbeauty: Hook up the x86 irq_vectors table generator (Michael Petlan) [1818838]
- [tools] libbeauty: Add a generator for x86's IRQ vectors -> strings (Michael Petlan) [1818838]
- [tools] tools arch x86: Grab a copy of the file containing the IRQ vector defines (Michael Petlan) [1818838]
- [tools] perf vendor events arm64: Add some missing events for Hisi hip08 HHA PMU (Michael Petlan) [1818838]
- [tools] perf vendor events arm64: Add some missing events for Hisi hip08 L3C PMU (Michael Petlan) [1818838]
- [tools] perf vendor events arm64: Add some missing events for Hisi hip08 DDRC PMU (Michael Petlan) [1818838]
- [tools] perf vendor events arm64: Fix Hisi hip08 DDRC PMU eventname (Michael Petlan) [1818838]
- [tools] perf trace: Support tracepoint dynamic char arrays (Michael Petlan) [1818838]
- [tools] perf trace: Filter own pid to avoid a feedback look in 'perf trace record -a' (Michael Petlan) [1818838]
- [tools] perf string: Export asprintf__tp_filter_pids() (Michael Petlan) [1818838]
- [tools] perf trace: Introduce --errno-summary (Michael Petlan) [1818838]
- [tools] perf trace: Add syscall failure stats to -s/--summary and -S/--with-summary (Michael Petlan) [1818838]
- [tools] perf stat: Support --all-kernel/--all-user (Michael Petlan) [1818838]
- [tools] perf annotate: Fix objdump --no-show-raw-insn flag (Michael Petlan) [1818838]
- [tools] perf annotate: Don't pipe objdump output through 'expand' command (Michael Petlan) [1818838]
- [tools] perf annotate: Don't pipe objdump output through 'grep' command (Michael Petlan) [1818838]
- [tools] perf annotate: Use libsubcmd's run-command.h to fork objdump (Michael Petlan) [1818838]
- [tools] perf annotate: Avoid reallocation in objdump parsing (Michael Petlan) [1818838]
- [tools] perf report: Add warning when libunwind not compiled in (Michael Petlan) [1818838]
- [tools] perf test: Avoid infinite loop for task exit case (Michael Petlan) [1818838]
- [tools] perf test: Report failure for mmap events (Michael Petlan) [1818838]
- [tools] perf script: Fix --reltime with --time (Michael Petlan) [1818838]
- [tools] perf tools: Allow to build with -ltcmalloc (Michael Petlan) [1818838]
- [tools] perf diff: Report noisy for cycles diff (Michael Petlan) [1818838]
- [tools] perf tools: Propagate CFLAGS to libperf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_evlist__filter_pollfd() from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Introduce perf_evlist__purge() (Michael Petlan) [1818838]
- [tools] libperf: Introduce perf_evlist__exit() (Michael Petlan) [1818838]
- [tools] libperf: Move the pollfd allocation from tools/perf to libperf (Michael Petlan) [1818838]
- [tools] libperf: Centralize map refcnt setting (Michael Petlan) [1818838]
- [tools] perf evlist: Switch to libperf's mmap interface (Michael Petlan) [1818838]
- [tools] perf evlist: Introduce perf_evlist__mmap_cb_mmap() (Michael Petlan) [1818838]
- [tools] perf evlist: Introduce perf_evlist__mmap_cb_get() (Michael Petlan) [1818838]
- [tools] perf tools: Introduce perf_evlist__mmap_cb_idx() (Michael Petlan) [1818838]
- [tools] libperf: Introduce perf_evlist_mmap_ops::mmap callback (Michael Petlan) [1818838]
- [tools] libperf: Add perf_evlist_mmap_ops::get callback (Michael Petlan) [1818838]
- [tools] libperf: Introduce perf_evlist_mmap_ops::idx callback (Michael Petlan) [1818838]
- [tools] libperf: Introduce perf_evlist__mmap_ops() (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_evlist__mmap()/munmap() from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__read_event() from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__read_done() from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__read_init() from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__consume() function from tools/perf (Michael Petlan) [1818838]
- [tools] perf tools: Use perf_mmap way to detect aux mmap (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__put() function from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__unmap() function from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__get() function from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__mmap() function from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Adopt perf_mmap__mmap_len() function from tools/perf (Michael Petlan) [1818838]
- [tools] libperf: Add 'struct perf_mmap_param' (Michael Petlan) [1818838]
- [tools] libperf: Add perf_mmap__init() function (Michael Petlan) [1818838]
- [tools] perf tools: Avoid 'sample_reg_masks' being const + weak (Michael Petlan) [1818838]
- [tools] perf beauty: Introduce strtoul() for x86 MSRs (Michael Petlan) [1818838]
- [tools] perf trace: Expand strings in filters to integers (Michael Petlan) [1818838]
- [tools] perf trace: Introduce a strtoul() method for 'struct strarrays' (Michael Petlan) [1818838]
- [tools] perf trace: Add a strtoul() method to 'struct syscall_arg_fmt' (Michael Petlan) [1818838]
- [tools] perf trace: Introduce --filter for tracepoint events (Michael Petlan) [1818838]
- [tools] perf evlist: Introduce append_tp_filter_pid() and append_tp_filter_pids() (Michael Petlan) [1818838]
- [tools] perf evlist: Introduce append_tp_filter() method (Michael Petlan) [1818838]
- [tools] perf evlist: Factor out asprintf routine to build a tracepoint pid filter (Michael Petlan) [1818838]
- [tools] perf trace: Associate the "msr" tracepoint arg name with x86_MSR__scnprintf() (Michael Petlan) [1818838]
- [tools] perf trace beauty: Add the glue for the autogenerated MSR arrays (Michael Petlan) [1818838]
- [tools] perf trace: Allow associating scnprintf routines with well known arg names (Michael Petlan) [1818838]
- [tools] perf beauty: Hook up the x86 MSR table generator (Michael Petlan) [1818838]
- [tools] perf trace beauty: Add a x86 MSR cmd id->str table generator (Michael Petlan) [1818838]
- [tools] perf beauty: Make strarray's offset be u64 (Michael Petlan) [1818838]
- [tools] perf trace: Allow choosing how to augment the tracepoint arguments (Michael Petlan) [1818838]
- [tools] perf trace: Enclose all events argument lists with () (Michael Petlan) [1818838]
- [tools] perf trace: Add array of chars scnprintf beautifier (Michael Petlan) [1818838]
- [tools] perf trace: Add the syscall_arg_fmt pointer to syscall_arg (Michael Petlan) [1818838]
- [tools] perf trace: Move some scnprintf methods from syscall to syscall_arg_fmt (Michael Petlan) [1818838]
- [tools] perf trace: Allocate an array of beautifiers for tracepoint args (Michael Petlan) [1818838]
- [tools] perf trace: Factor out the initialization of syscal_arg_fmt->scnprintf (Michael Petlan) [1818838]
- [tools] perf script: Allow --time with --reltime (Michael Petlan) [1818838]
- [tools] perf scripts python: exported-sql-viewer.py: Add Time chart by CPU (Michael Petlan) [1818838]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability for Call tree to open at a specified task and time (Michael Petlan) [1818838]
- [tools] perf scripts python: exported-sql-viewer.py: Tidy up Call tree call_time (Michael Petlan) [1818838]
- [tools] perf scripts python: exported-sql-viewer.py: Add global time range calculations (Michael Petlan) [1818838]
- [tools] perf scripts python: exported-sql-viewer.py: Add HBoxLayout and VBoxLayout (Michael Petlan) [1818838]
- [tools] perf scripts python: exported-sql-viewer.py: Add LookupModel() (Michael Petlan) [1818838]
- [tools] perf trace augmented_syscalls: Do not show syscalls when none was asked for (Michael Petlan) [1818838]
- [tools] perf trace: Postpone parsing .perfconfig trace.add_events to after --verbose is processed (Michael Petlan) [1818838]
- [tools] perf trace: Generalize the syscall_fmt find routines (Michael Petlan) [1818838]
- [tools] perf trace: Separate 'struct syscall_fmt' definition from syscall_fmts variable (Michael Petlan) [1818838]
- [tools] perf trace: Make evlist__set_evsel_handler() affect just entries without a handler (Michael Petlan) [1818838]
- [tools] perf evlist: Adopt __set_tracepoint_handlers method from perf_session (Michael Petlan) [1818838]
- [tools] perf top: Initialize perf_env->cpuid, needed by the per arch annotation init routine (Michael Petlan) [1818838]
- [tools] perf env: Add routine to read the env->cpuid from the running machine (Michael Petlan) [1818838]
- [kernel] perf/cgroups: Install cgroup events to correct cpuctx (Michael Petlan) [1818838]
- [kernel] perf/core: Fix mlock accounting in perf_mmap() (Michael Petlan) [1818838]
- [x86] perf/x86/intel/uncore: Remove PCIe3 unit for SNR (Michael Petlan) [1818838]
- [x86] perf/x86/intel/uncore: Fix missing marker for snr_uncore_imc_freerunning_events (Michael Petlan) [1818838]
- [x86] perf/x86/intel/uncore: Add PCI ID of IMC for Xeon E3 V5 Family (Michael Petlan) [1818838]
- [kernel] perf: Correctly handle failed perf_get_aux_event() (Michael Petlan) [1818838]
- [x86] perf/x86/intel: Fix PT PMI handling (Michael Petlan) [1818838]
- [x86] perf/x86/intel/bts: Fix the use of page_private() (Michael Petlan) [1818838]
- [x86] perf/x86: Fix potential out-of-bounds access (Michael Petlan) [1818838]
- [x86] perf/x86: Implement immediate enforcement of /sys/devices/cpu/rdpmc value of 0 (Michael Petlan) [1818838]
- [kernel] perf/core: Make the mlock accounting simple again (Michael Petlan) [1818838]
- [kernel] perf/core: Fix the mlock accounting, again (Michael Petlan) [1818838]
- [x86] perf/x86/intel/pt: Prevent redundant WRMSRs (Michael Petlan) [1818838]
- [x86] perf/x86/intel/pt: Opportunistically use single range output mode (Michael Petlan) [1818838]
- [x86] perf/x86/intel/pt: Add sampling support (Michael Petlan) [1818838]
- [x86] perf/x86/intel/pt: Factor out pt_config_start() (Michael Petlan) [1818838]
- [kernel] perf/aux: Allow using AUX data in perf samples (Michael Petlan) [1818838]
- [kernel] perf/core: Fix unlock balance in perf_init_event() (Michael Petlan) [1818838]
- [x86] perf/x86/amd: Remove set but not used variable 'active' (Michael Petlan) [1818838]
- [kernel] perf/core: Optimize perf_init_event() for TYPE_SOFTWARE (Michael Petlan) [1818838]
- [kernel] perf/core: Optimize perf_init_event() (Michael Petlan) [1818838]
- [kernel] perf/core: Optimize perf_install_in_event() (Michael Petlan) [1818838]
- [x86] perf/x86: Synchronize PMU task contexts on optimized context switches (Michael Petlan) [1818838]
- [x86] perf/x86/intel: Implement LBR callstack context synchronization (Michael Petlan) [1818838]
- [x86] perf/x86: Install platform specific ->swap_task_ctx() adapter (Michael Petlan) [1818838]
- [x86] perf/core, perf/x86: Introduce swap_task_ctx() method at 'struct pmu' (Michael Petlan) [1818838]
- [kernel] perf/ring_buffer: Matching the memory allocate and free, in rb_alloc() (Michael Petlan) [1818838]
- [kernel] perf/ring_buffer: Modify the parameter type of perf_mmap_free_page() (Michael Petlan) [1818838]
- [documentation] Documentation: Document sysfs interfaces purr, spurr, idle_purr, idle_spurr (Steve Best) [1783286]
- [powerpc] powerpc/sysfs: Show idle_purr and idle_spurr for every CPU (Steve Best) [1783286]
- [powerpc] powerpc/pseries: Account for SPURR ticks on idle CPUs (Steve Best) [1783286]
- [powerpc] powerpc/idle: Store PURR snapshot in a per-cpu global variable (Steve Best) [1783286]
- [powerpc] powerpc: Move idle_loop_prolog()/epilog() functions to header file (Steve Best) [1783286]
- [kernel] padata: add separate cpuhp node for CPUHP_PADATA_DEAD (Herbert Xu) [1671674]
- [kernel] padata: fix uninitialized return value in padata_replace() (Herbert Xu) [1671674]
- [kernel] padata: remove reorder_objects (Herbert Xu) [1671674]
- [crypto] padata: remove cpumask change notifier (Herbert Xu) [1671674]
- [kernel] padata: always acquire cpu_hotplug_lock before pinst->lock (Herbert Xu) [1671674]
- [kernel] padata: validate cpumask without removed CPU during offline (Herbert Xu) [1671674]
- [crypto] crypto: pcrypt - Avoid deadlock by using per-instance padata queues (Herbert Xu) [1671674]
- [kernel] padata: Remove unused padata_remove_cpu (Herbert Xu) [1671674]
- [crypto] crypto: pcrypt - Fix user-after-free on module unload (Herbert Xu) [1671674]
- [kernel] padata: Remove broken queue flushing (Herbert Xu) [1671674]
- [kernel] padata: remove cpu_index from the parallel_queue (Herbert Xu) [1671674]
- [kernel] padata: unbind parallel jobs from specific CPUs (Herbert Xu) [1671674]
- [kernel] padata: use separate workqueues for parallel and serial work (Herbert Xu) [1671674]
- [crypto] padata, pcrypt: take CPU hotplug lock internally in padata_alloc_possible (Herbert Xu) [1671674]
- [crypto] crypto: pcrypt - remove padata cpumask notifier (Herbert Xu) [1671674]
- [crypto] padata: make padata_do_parallel find alternate callback CPU (Herbert Xu) [1671674]
- [kernel] workqueue: require CPU hotplug read exclusion for apply_workqueue_attrs (Herbert Xu) [1671674]
- [kernel] workqueue: unconfine alloc/apply/free_workqueue_attrs() (Herbert Xu) [1671674]
- [crypto] padata: allocate workqueue internally (Herbert Xu) [1671674]
- [kernel] padata: initialize pd->cpu with effective cpumask (Herbert Xu) [1671674]
- [kernel] padata: purge get_cpu and reorder_via_wq from padata_do_serial (Herbert Xu) [1671674]
- [kernel] padata: Replace delayed timer with immediate workqueue in padata_reorder (Herbert Xu) [1671674]
- [kernel] padata: use smp_mb in padata_reorder to avoid orphaned padata jobs (Herbert Xu) [1671674]
- [kernel] tracing: Avoid memory leak in process_system_preds() (Jerome Marchand) [1829953] {CVE-2019-19072}
- [kernel] tracing: Have error path in predicate_parse() free its allocated memory (Jerome Marchand) [1829953] {CVE-2019-19072}
- [kernel] tracing: Avoid memory leak in predicate_parse() (Jerome Marchand) [1829953] {CVE-2019-19072}
- [kernel] tracing: Fix memory leak in create_filter() (Jerome Marchand) [1829953] {CVE-2019-19072}
- [tools] KVM: selftests: s390x: Provide additional num-guest-pages adjustment (Philipp Rudo) [1792266]
- [s390] s390/protvirt: fix compilation issue (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Fix PV check in deliverable_irqs() (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Return last valid slot if approx index is out-of-bounds (Philipp Rudo) [1792266]
- [kvm] KVM: s390: vsie: Fix delivery of addressing exceptions (Philipp Rudo) [1792266]
- [mm] s390/gmap: return proper error code on ksm unsharing (Philipp Rudo) [1792266]
- [s390] KVM: s390: mark sie block as 512 byte aligned (Philipp Rudo) [1792266]
- [tools] selftests: KVM: s390: check for registers to NOT change on reset (Philipp Rudo) [1792266]
- [tools] selftests: KVM: s390: test more register variants for the reset ioctl (Philipp Rudo) [1792266]
- [tools] selftests: KVM: s390: fix early guest crash (Philipp Rudo) [1792266]
- [tools] selftests: KVM: s390: fixup fprintf format error in reset.c (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Also reset registers in sync regs for initial cpu reset (Philipp Rudo) [1792266]
- [kvm] KVM: s390: introduce module parameter kvm.use_gisa (Philipp Rudo) [1792266]
- [documentation] KVM: s390: protvirt: Add KVM api documentation (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: introduce and enable KVM_CAP_S390_PROTECTED (Philipp Rudo) [1792266]
- [documentation] DOCUMENTATION: Protected virtual machine introduction and IPL (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Add UV cpu reset calls (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: do not inject interrupts after start (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Mask PSW interrupt bits for interception 104 and 112 (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Support cmd 5 operation state (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Report CPU state to Ultravisor (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: UV calls in support of diag308 0, 1 (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Add program exception injection (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Only sync fmt4 registers (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Do only reset registers that are accessible (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: disallow one_reg (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: STSI handling (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Write sthyi data to instruction data area (Philipp Rudo) [1792266]
- [kvm] KVM: s390/mm: handle guest unpin events (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: handle secure guest prefix pages (Philipp Rudo) [1792266]
- [kvm] KVM: S390: protvirt: Introduce instruction data area bounce buffer (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Add new gprs location handling (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Handle spec exception loops (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Add SCLP interrupt handling (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Implement interrupt injection (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Instruction emulation (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Handle SE notification interceptions (Philipp Rudo) [1792266]
- [mm] KVM: s390/mm: Make pages accessible before destroying the guest (Philipp Rudo) [1792266]
- [mm] KVM: s390: protvirt: Secure memory is not mergeable (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Add initial vm and cpu lifecycle handling (Philipp Rudo) [1792266]
- [s390] KVM: s390: add new variants of UV CALL (Philipp Rudo) [1792266]
- [kvm] KVM: s390: protvirt: Add UV debug trace (Philipp Rudo) [1792266]
- [kvm] KVM: s390/interrupt: do not pin adapter interrupt pages (Philipp Rudo) [1792266]
- [s390] s390/protvirt: Add sysfs firmware interface for Ultravisor information (Philipp Rudo) [1792266]
- [s390] s390/mm: add (non)secure page access exceptions handlers (Philipp Rudo) [1792266]
- [s390] s390/mm: provide memory management functions for protected KVM guests (Philipp Rudo) [1792266]
- [s390] s390/protvirt: add ultravisor initialization (Philipp Rudo) [1792266]
- [s390] s390/protvirt: introduce host side setup (Philipp Rudo) [1792266]
- [documentation] KVM: s390: rstify new ioctls in api.rst (Philipp Rudo) [1792266]
- [s390] s390/uv: Fix handling of length extensions (Philipp Rudo) [1792266]
- [tools] selftests: KVM: testing the local IRQs resets (Philipp Rudo) [1792266]
- [tools] selftests: KVM: s390x: Add reset tests (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Add new reset vcpu API (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Cleanup initial cpu reset (Philipp Rudo) [1792266]
- [kvm] KVM: s390: do not clobber registers during guest reset/store status (Philipp Rudo) [1792266]
- [kvm] KVM: s390: ENOTSUPP -> EOPNOTSUPP fixups (Philipp Rudo) [1792266]
- [s390] s390/uv: use EOPNOTSUPP instead of ENOTSUPP (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Do not yield when target is already running (Philipp Rudo) [1792266]
- [kvm] KVM: s390: count invalid yields (Philipp Rudo) [1792266]
- [kvm] KVM: s390: mark __insn32_query() as __always_inline (Philipp Rudo) [1792266]
- [kvm] KVM: s390: fix __insn32_query() inline assembly (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Cleanup kvm_arch_init error path (Philipp Rudo) [1792266]
- [kvm] KVM: s390: Remove unused parameter from __inject_sigp_restart() (Philipp Rudo) [1792266]
- [mm] mm/gup/writeback: add callbacks for inaccessible pages (Philipp Rudo) [1792266]
- [scsi] scsi: libiscsi: fall back to sendmsg for slab pages (Maurizio Lombardi) [1825775]
- [fs] smb3: fix default permissions on new files when mounting with modefromsid (Leif Sahlberg) [1833374]
- [fs] gfs2: don't call quota_unhold if quotas are not locked (Robert S Peterson) [1830043]
- [fs] gfs2: move privileged user check to gfs2_quota_lock_check (Robert S Peterson) [1830043]
- [fs] gfs2: remove check for quotas on in gfs2_quota_check (Robert S Peterson) [1830043]
- [fs] gfs2: Change BUG_ON to an assert_withdraw in gfs2_quota_change (Robert S Peterson) [1830043]
- [fs] gfs2: Fix problems regarding gfs2_qa_get and _put (Robert S Peterson) [1830043]
- [powerpc] powerpc/eeh: Fix deadlock handling dead PHB (Sam Bobroff) [1774820]
- [powerpc] powerpc/powernv/eeh: Fix oops when probing cxl devices (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Slightly simplify eeh_add_to_parent_pe() (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Remove unused return path from eeh_pe_dev_traverse() (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Fix crash when edev->pdev changes (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Convert log messages to eeh_edev_* macros (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Introduce EEH edev logging macros (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Add bdfn field to eeh_dev (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Refactor around eeh_probe_devices() (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: EEH for pSeries hot plug (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Initialize EEH address cache earlier (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Improve debug messages around device addition (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh: Clear stale EEH_DEV_NO_HANDLER flag (Sam Bobroff) [1774820]
- [powerpc] powerpc/64: Adjust order in pcibios_init() (Sam Bobroff) [1774820]
- [powerpc] powerpc/pci: Add pci_find_controller_for_domain() (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh_cache: Bump log level of eeh_addr_cache_print() (Sam Bobroff) [1774820]
- [powerpc] powerpc/eeh_cache: Add pr_debug() prints for insert/remove (Sam Bobroff) [1774820]

* Sun May 17 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-200.el8]
- [gpio] gpiolib: acpi: Add quirk to ignore EC wakeups on HP x2 10 CHT + AXP288 model (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Add quirk to ignore EC wakeups on HP x2 10 BYT + AXP288 model (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Rework honor_wakeup option into an ignore_wake option (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Correct comment for HP x2 10 honor_wakeup quirk (David Arcari) [1829900]
- [gpio] gpiolib: Fix irq_disable() semantics (David Arcari) [1829900]
- [gpio] gpiolib: fix gpio_do_set_config() (David Arcari) [1829900]
- [gpio] gpiolib: remove unnecessary argument from set_config call (David Arcari) [1829900]
- [gpio] Revert "gpiolib: remove set but not used variable 'config'" (David Arcari) [1829900]
- [gpio] Revert "gpiolib: Remove duplicated function gpio_do_set_config()" (David Arcari) [1829900]
- [gpio] treewide: remove redundant IS_ERR() before error code check (David Arcari) [1829900]
- [gpio] gpiolib: hold gpio devices lock until ->descs array is initialised (David Arcari) [1829900]
- [gpio] gpio: Drop the chained IRQ handler assign function (David Arcari) [1829900]
- [gpio] gpio: xlp: Pass irqchip when adding gpiochip (David Arcari) [1829900]
- [pinctrl] pinctrl: qcom: Pass irqchip when adding gpiochip (David Arcari) [1829900]
- [pinctrl] pinctrl: iproc: allow for error from platform_get_irq() (David Arcari) [1829900]
- [pinctrl] pinctrl: bcm-iproc: Pass irqchip when adding gpiochip (David Arcari) [1829900]
- [gpio] gpio: pl061: Pass irqchip when adding gpiochip (David Arcari) [1829900]
- [gpio] gpio: pl061: Move irq_chip definition inside struct pl061 (David Arcari) [1829900]
- [gpio] gpiolib: Lower verbosity when allocating hierarchy irq (David Arcari) [1829900]
- [gpio] gpiolib: Remove duplicated function gpio_do_set_config() (David Arcari) [1829900]
- [include] gpio: Fix the no return statement warning (David Arcari) [1829900]
- [gpio] gpiolib: remove set but not used variable 'config' (David Arcari) [1829900]
- [gpio] gpiolib: Set lockdep class for hierarchical irq domains (David Arcari) [1829900]
- [gpio] gpiolib: Add the support for the msi parent domain (David Arcari) [1829900]
- [gpio] gpiolib: Add support for the irqdomain which doesn't use irq_fwspec as arg (David Arcari) [1829900]
- [gpio] gpiolib: use gpiochip_get_desc() in gpio_ioctl() (David Arcari) [1829900]
- [gpio] gpiolib: use gpiochip_get_desc() in lineevent_create() (David Arcari) [1829900]
- [gpio] gpiolib: use gpiochip_get_desc() in linehandle_create() (David Arcari) [1829900]
- [gpio] gpiolib: convert the type of hwnum to unsigned int in gpiochip_get_desc() (David Arcari) [1829900]
- [gpio] gpiolib: have a single place of calling set_config() (David Arcari) [1829900]
- [gpio] gpiolib: use 'unsigned int' instead of 'unsigned' in gpio_set_config() (David Arcari) [1829900]
- [gpio] gpio: gpiolib: fix confusing indention (David Arcari) [1829900]
- [mmc] mmc: core: Rework cd-gpio handling (David Arcari) [1829900]
- [mmc] mmc: core: Rework wp-gpio handling (David Arcari) [1829900]
- [gpio] gpio: add gpiod_toggle_active_low() (David Arcari) [1829900]
- [gpio] gpiolib: Make use of assign_bit() API (David Arcari) [1829900]
- [gpio] gpiolib: Add GPIOCHIP_NAME definition (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Add honor_wakeup module-option + quirk mechanism (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Turn dmi_system_id table into a generic quirk table (David Arcari) [1829900]
- [gpio] gpiolib: fix up emulated open drain outputs (David Arcari) [1829900]
- [gpio] gpio: Fix error message on out-of-range GPIO in lookup table (David Arcari) [1829900]
- [gpio] gpiolib: of: Make of_gpio_spi_cs_get_count static (David Arcari) [1829900]
- [gpio] gpio: Handle counting of Freescale chipselects (David Arcari) [1829900]
- [gpio] gpio: of: Fix bogus reference to gpiod_get_count() (David Arcari) [1829900]
- [gpio] gpiolib: Grammar s/manager/managed/ (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Make acpi_gpiochip_alloc_event always return AE_OK (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Print pin number on acpi_gpiochip_alloc_event errors (David Arcari) [1829900]
- [gpio] gpiolib: fix coding style in gpiod_hog() (David Arcari) [1829900]
- [gpio] gpio: add new SET_CONFIG ioctl() to gpio chardev (David Arcari) [1829900]
- [gpio] gpiolib: move validation of line handle flags into helper function (David Arcari) [1829900]
- [gpio] gpiolib: add support for biasing output lines (David Arcari) [1829900]
- [gpio] gpiolib: add support for disabling line bias (David Arcari) [1829900]
- [gpio] gpiolib: add support for pull up/down to lineevent_create (David Arcari) [1829900]
- [gpio] gpio: expose pull-up/pull-down line flags to userspace (David Arcari) [1829900]
- [gpio] Revert "gpio: expose pull-up/pull-down line flags to userspace" (David Arcari) [1829900]
- [gpio] gpiolib: No need to call gpiochip_remove_pin_ranges() twice (David Arcari) [1829900]
- [include] gpio: Add definition for GPIO direction (David Arcari) [1829900]
- [gpio] gpiolib: Switch order of valid mask and hw init (David Arcari) [1829900]
- [gpio] gpio: of: don't warn if ignored GPIO flag matches the behavior (David Arcari) [1829900]
- [gpio] gpio: fix kernel-doc for of_gpio_need_valid_mask() (David Arcari) [1829900]
- [gpio] gpio: expose pull-up/pull-down line flags to userspace (David Arcari) [1829900]
- [gpio] gpiolib: introduce fwnode_gpiod_get_index() (David Arcari) [1829900]
- [gpio] gpiolib: introduce devm_fwnode_gpiod_get_index() (David Arcari) [1829900]
- [gpio] gpiolib: sanitize flags before allocating memory in lineevent_create() (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Add Terra Pad 1061 to the run_edge_events_on_boot_blacklist (David Arcari) [1829900]
- [gpio] gpio: fix getting nonexclusive gpiods from DT (David Arcari) [1829900]
- [gpio] gpiolib: don't clear FLAG_IS_OUT when emulating open-drain/open-source (David Arcari) [1829900]
- [gpio] gpiolib: of: add a fallback for wlf, reset GPIO name (David Arcari) [1829900]
- [gpio] gpio: remove explicit comparison with 0 (David Arcari) [1829900]
- [gpio] gpio: devres: Switch to EXPORT_SYMBOL_GPL() (David Arcari) [1829900]
- [gpio] gpio: of: Switch to EXPORT_SYMBOL_GPL() (David Arcari) [1829900]
- [gpio] gpio: of: Make of_gpio_simple_xlate() private (David Arcari) [1829900]
- [gpio] gpio: of: Make of_get_named_gpiod_flags() private (David Arcari) [1829900]
- [gpio] gpiolib: acpi: make acpi_can_fallback_to_crs() static (David Arcari) [1829900]
- [gpio] gpio: of: Normalize return code variable name (David Arcari) [1829900]
- [gpio] gpio: gpiolib: Normalize return code variable name (David Arcari) [1829900]
- [include] gpio: Move gpiochip_lock/unlock_as_irq to gpio/driver.h (David Arcari) [1829900]
- [gpio] gpio: Use callback presence to determine need of valid_mask (David Arcari) [1829900]
- [gpio] gpio: Pass mask and size with the init_valid_mask() (David Arcari) [1829900]
- [pinctrl] pinctrl: msm: Add ability for drivers to supply a reserved GPIO list (David Arcari) [1829900]
- [pinctrl] pinctrl: msm: Use init_valid_mask exported function (David Arcari) [1829900]
- [include] gpio: stubs in headers should be inline (David Arcari) [1829900]
- [gpio] gpio: Add support for hierarchical IRQ domains (David Arcari) [1829900]
- [kernel] genirq: introduce irq_domain_translate_twocell (David Arcari) [1829900]
- [gpio] gpio: refactor gpiochip_allocate_mask() with bitmap_alloc() (David Arcari) [1829900]
- [gpio] gpio: of: Fix hard-assigned valid_mask for OF case (David Arcari) [1829900]
- [sound] gpiolib-acpi: Move acpi_dev_add_driver_gpios() et al to consumer.h (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Split ACPI stuff to gpiolib-acpi.h (David Arcari) [1829900]
- [include] gpiolib: of: Reshuffle contents of consumer.h for new library layout (David Arcari) [1829900]
- [include] pinctrl: remove unneeded #ifdef around declarations (David Arcari) [1829900]
- [hwmon] hwmon: pmbus: ucd9000: remove unneeded include (David Arcari) [1829900]
- [include] gpio: remove less important #ifdef around declarations (David Arcari) [1829900]
- [gpio] gpio: of: Break out OF-only code (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Add gpiolib_acpi_run_edge_events_on_boot option and blacklist (David Arcari) [1829900]
- [gpio] gpiolib: of: fix fallback quirks handling (David Arcari) [1829900]
- [gpio] gpio: fix line flag validation in lineevent_create (David Arcari) [1829900]
- [gpio] gpio: fix line flag validation in linehandle_create (David Arcari) [1829900]
- [gpio] gpio: Fix irqchip initialization order (David Arcari) [1829900]
- [gpio] gpio: of: fix Freescale SPI CS quirk handling (David Arcari) [1829900]
- [gpio] gpiolib: never report open-drain/source lines as 'input' to user-space (David Arcari) [1829900]
- [include] gpio: Fix build error of function redefinition (David Arcari) [1829900]
- [gpio] gpiolib: Preserve desc->flags when setting state (David Arcari) [1829900]
- [include] gpio: don't WARN() on NULL descs if gpiolib is disabled (David Arcari) [1829900]
- [gpio] gpiolib: fix incorrect IRQ requesting of an active-low lineevent (David Arcari) [1829900]
- [gpio] Revert "gpio/spi: Fix spi-gpio regression on active high CS" (David Arcari) [1829900]
- [gpio] gpiolib: of: fix a memory leak in of_gpio_flags_quirks() (David Arcari) [1829900]
- [gpio] gpiolib: Use spinlock_t instead of struct spinlock (David Arcari) [1829900]
- [gpio] gpiolib: Clarify use of non-sleeping functions (David Arcari) [1829900]
- [gpio] gpiolib: Fix references to gpiod_et_*value_cansleep() variants (David Arcari) [1829900]
- [include] gpiolib: Document new gpio_chip.init_valid_mask field (David Arcari) [1829900]
- [gpio] gpio/spi: Fix spi-gpio regression on active high CS (David Arcari) [1829900]
- [gpio] gpio: No need to cast away return value of debugfs_create_file() (David Arcari) [1829900]
- [include] gpio: Add comments on #if/#else/#endif (David Arcari) [1829900]
- [regulator] gpio: Fix return value mismatch of function gpiod_get_from_of_node() (David Arcari) [1829900]
- [gpio] gpio: Drop the parent_irq from gpio_irq_chip (David Arcari) [1829900]
- [gpio] gpio: of: parse stmmac PHY reset line specific active-low property (David Arcari) [1829900]
- [gpio] gpio: pass lookup and descriptor flags to request_own (David Arcari) [1829900]
- [gpio] gpio: of: Handle the Freescale SPI CS (David Arcari) [1829900]
- [gpio] gpio: Fix gpiochip_add_data_with_key() error path (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Respect pin bias setting (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Add acpi_gpio_update_gpiod_lookup_flags() helper (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Set pin value, based on bias, more accurately (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Change type of dflags (David Arcari) [1829900]
- [gpio] gpiolib: Introduce GPIO_LOOKUP_FLAGS_DEFAULT (David Arcari) [1829900]
- [gpio] gpiolib: Make use of enum gpio_lookup_flags consistent (David Arcari) [1829900]
- [include] gpiolib: Indent entry values of enum gpio_lookup_flags (David Arcari) [1829900]
- [gpio] gpio: of: Optimize quirk checks (David Arcari) [1829900]
- [gpio] gpio: mmio: Drop bgpio_dir_inverted (David Arcari) [1829900]
- [gpio] gpio: Set proper argument value to set_config (David Arcari) [1829900]
- [gpio] gpio: Remove obsolete comment about gpiochip_free_hogs() usage (David Arcari) [1829900]
- [gpio] gpio: mmio: Fix bgpio_get_set & bgpio_get_set_multiple (David Arcari) [1829900]
- [gpio] gpio: mmio: Support two direction registers (David Arcari) [1829900]
- [gpio] gpiolib: Don't WARN on gpiod_put() for optional GPIO (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Fix references in kernel doc and amend (David Arcari) [1829900]
- [gpio] gpio: of: Fix of_gpiochip_add() error path (David Arcari) [1829900]
- [gpio] gpio: of: Check for "spi-cs-high" in child instead of parent node (David Arcari) [1829900]
- [gpio] gpio: of: Check propname before applying "cs-gpios" quirks (David Arcari) [1829900]
- [gpio] Revert "gpio: use new gpio_set_config() helper in more places" (David Arcari) [1829900]
- [gpio] gpio: of: Handle both enable-gpio{,s} (David Arcari) [1829900]
- [gpio] gpio: of: Restrict enable-gpio quirk to regulator-gpio (David Arcari) [1829900]
- [gpio] gpio: of: Apply regulator-gpio quirk only to enable-gpios (David Arcari) [1829900]
- [gpio] gpio: add core support for pull-up/pull-down configuration (David Arcari) [1829900]
- [gpio] gpio: use new gpio_set_config() helper in more places (David Arcari) [1829900]
- [gpio] gpio: rename gpio_set_drive_single_ended() to gpio_set_config() (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Correct kernel doc of struct acpi_gpio_event (David Arcari) [1829900]
- [gpio] gpio: of: Fix logic inversion (David Arcari) [1829900]
- [gpio] gpio: add irq domain activate/deactivate functions (David Arcari) [1829900]
- [gpio] gpiolib: fix line event timestamps for nested irqs (David Arcari) [1829900]
- [gpio] gpiolib-acpi: Preserve non direction flags when updating gpiod_flags (David Arcari) [1829900]
- [gpio] gpiolib-acpi: Remove unnecessary WARN_ON from acpi_gpiochip_free_interrupts (David Arcari) [1829900]
- [gpio] gpiolib-acpi: remove unused variable 'err', cleans up build warning (David Arcari) [1829900]
- [mmc] mmc: core: don't override the CD GPIO level when "cd-inverted" is set (David Arcari) [1829900]
- [arm64] arm64: dts: meson: Fix mmc cd-gpios polarity (David Arcari) [1829900]
- [gpio] gpio/mmc/of: Respect polarity in the device tree (David Arcari) [1829900]
- [include] gpiolib: Fix return value of gpio_to_desc() stub if !GPIOLIB (David Arcari) [1829900]
- [documentation] Documentation: gpio: fix function links in the HTML docs (David Arcari) [1829900]
- [documentation] docs: driver-model: convert docs to ReST and rename to *.rst (David Arcari) [1829900]
- [documentation] docs: gpio: driver.rst: fix a bad tag (David Arcari) [1829900]
- [documentation] gpio: Fix minor grammar errors in documentation (David Arcari) [1829900]
- [documentation] gpio: Update documentation (David Arcari) [1829900]
- [gpio] gpio: Pass a flag to gpiochip_request_own_desc() (David Arcari) [1829900]
- [gpio] gpio: Add devm_gpiod_unhinge() (David Arcari) [1829900]
- [gpio] gpio: devres: Handle nonexclusive GPIOs (David Arcari) [1829900]
- [gpio] gpio: Enable nonexclusive gpiods from DT nodes (David Arcari) [1829900]
- [gpio] gpiolib-acpi: Only defer request_irq for GpioInt ACPI event handlers (David Arcari) [1829900]
- [gpio] gpio: OF: Parse MMC-specific CD and WP properties (David Arcari) [1829900]
- [gpio] gpio: restore original GPLv2+ license of gpiolib-of.c sources (David Arcari) [1829900]
- [include] gpio: drop broken to_gpio_irq_chip() helper (David Arcari) [1829900]
- [gpio] gpio: drop devm_gpio_chip_match() (David Arcari) [1829900]
- [gpio] gpio: don't free unallocated ida on gpiochip_add_data_with_key() error path (David Arcari) [1829900]
- [gpio] gpiolib: Fix possible use after free on label (David Arcari) [1829900]
- [documentation] Documentation: gpio: driver: fix wire name for I2C (David Arcari) [1829900]
- [documentation] gpio/driver.rst: document gpiochip_disable/enable_irq() (David Arcari) [1829900]
- [gpio] gpio: drop devm_gpiochip_remove() (David Arcari) [1829900]
- [gpio] gpio: Clarify kerneldoc on gpiochip_set_chained_irqchip() (David Arcari) [1829900]
- [gpio] gpio: Remove unused 'irqchip' argument to gpiochip_set_cascaded_irqchip() (David Arcari) [1829900]
- [gpio] gpio: Drop parent irq assignment during cascade setup (David Arcari) [1829900]
- [gpio] gpiolib: Initialize gdev field before is used (David Arcari) [1829900]
- [gpio] gpio: Assign gpio_irq_chip::parents to non-stack pointer (David Arcari) [1829900]
- [gpio] gpio: fix doc string for devm_gpiochip_add_data() to not talk about irq_chip (David Arcari) [1829900]
- [gpio] gpio: mockup: fix indicated direction (David Arcari) [1829900]
- [gpio] gpiolib: Show correct direction from the beginning (David Arcari) [1829900]
- [gpio] gpiolib: Add init_valid_mask exported function (David Arcari) [1829900]
- [gpio] gpio: Slightly more helpful debugfs (David Arcari) [1829900]
- [gpio] Accept partial 'gpio-line-names' property (David Arcari) [1829900]
- [gpio] gpio: Restore indentation of continued lines (David Arcari) [1829900]
- [gpio] gpio: Propagate errors from gpiod_set_array_value_complex() (David Arcari) [1829900]
- [gpio] gpiolib: Fix incorrect use of find_next_zero_bit() (David Arcari) [1829900]
- [gpio] gpiolib: Fix missing updates of bitmap index (David Arcari) [1829900]
- [gpio] gpio: Add comments on single direction chips (David Arcari) [1829900]
- [gpio] gpiolib: Fix gpio_direction_* for single direction GPIOs (David Arcari) [1829900]
- [gpio] gpio: Rename devres implementation file (David Arcari) [1829900]
- [gpio] gpio: Use SPDX header for core library (David Arcari) [1829900]
- [gpio] gpiolib: Fix array members of same chip processed separately (David Arcari) [1829900]
- [gpio] gpiolib: Free the last requested descriptor (David Arcari) [1829900]
- [gpio] gpio: Get rid of legacy header (David Arcari) [1829900]
- [gpio] gpiolib: check if irqchip already has the irq hook replacements (David Arcari) [1829900]
- [gpio] gpiolib: use better errno if get_direction is not available (David Arcari) [1829900]
- [documentation] gpiolib: Implement fast processing path in get/set array (David Arcari) [1829900]
- [documentation] Documentation: gpio: Fix reference to gpiod_get_array() (David Arcari) [1829900]
- [gpio] gpiolib: Pass array info to get/set array functions (David Arcari) [1829900]
- [gpio] gpiolib: Identify arrays matching GPIO hardware (David Arcari) [1829900]
- [gpio] gpiolib: Pass bitmaps, not integer arrays, to get/set array (David Arcari) [1829900]
- [gpio] gpiolib: Don't support irq sharing for userspace (David Arcari) [1829900]
- [gpio] gpio: of: Handle SPI chipselect legacy bindings (David Arcari) [1829900]
- [gpio] gpiolib: override irq_enable/disable (David Arcari) [1829900]
- [gpio] gpiolib: add flag to indicate if the irq is disabled (David Arcari) [1829900]
- [gpio] gliolib: set hooks in gpiochip_set_irq_hooks() (David Arcari) [1829900]
- [gpio] gpiolib: export gpiochip_irq_reqres/relres() (David Arcari) [1829900]
- [include] gpio: fix kernel-doc notation warning for 'request_key' (David Arcari) [1829900]
- [gpio] gpio: Fix crash due to registration race (David Arcari) [1829900]
- [gpio] gpio: Convert to using pOFn instead of device_node.name (David Arcari) [1829900]
- [gpio] gpiolib-acpi: Register GpioInt ACPI event handlers from a late_initcall (David Arcari) [1829900]
- [gpio] gpiolib: acpi: Switch to cansleep version of GPIO library call (David Arcari) [1829900]
- [gpio] gpiolib: Avoid calling chip->request() for unused gpios (David Arcari) [1829900]
- [gpio] gpio: mmio: Fix up inverted direction registers (David Arcari) [1829900]
- [gpio] gpiolib: Fix of_node inconsistency (David Arcari) [1829900]
- [gpio] gpiolib: Don't shadow error code of gpiochip_lock_as_irq() (David Arcari) [1829900]
- [include] gpiolib: Use GPIOD_OUT_{LOW, HIGH} macros in open drain ones (David Arcari) [1829900]
- [gpio] gpiolib: probe deferral error reporting (David Arcari) [1829900]
- [include] Input: gpio_keys - add missing include to gpio_keys.h (David Arcari) [1829900]
- [gpio] gpiolib: remove an unnecessary TODO (David Arcari) [1829900]
- [gpio] gpiolib: don't allow userspace to set values of input lines (David Arcari) [1829900]
- [gpio] gpiolib: Join one line back for better readability (David Arcari) [1829900]
- [gpio] gpiolib: Consistent use of ->get_direction() inside gpiolib (David Arcari) [1829900]
- [gpio] gpiolib: Defer on non-DT find_chip_by_name() failure (David Arcari) [1829900]
- [gpio] gpiolib: Respect error code of ->get_direction() (David Arcari) [1829900]
- [gpio] gpiolib: Join string literals back (David Arcari) [1829900]
- [include] gpio.h: fix location of gpio legacy documentation (David Arcari) [1829900]
- [fs] gfs2: Fix use-after-free in gfs2_logd after withdraw (Robert S Peterson) [1831695]
- [fs] gfs2: Fix BUG during unmount after file system withdraw (Robert S Peterson) [1831695]
- [fs] gfs2: Fix error exit in do_xmote (Robert S Peterson) [1831695]
- [fs] gfs2: fix withdraw sequence deadlock (Robert S Peterson) [1831695]
- [mm] s390/mm: fix page table upgrade vs 2ndary address mode accesses (Vladis Dronov) [1828154] {CVE-2020-11884}
- [media] media: serial_ir: Fix use-after-free in serial_ir_init_module (Vladis Dronov) [1802396] {CVE-2019-19543}
- [mm] mm/memory_hotplug: fix remove_memory() lockdep splat (Christoph von Recklinghausen) [1830942]
- [mm] mm/page_alloc.c: initialize memmap of unavailable memory directly (Christoph von Recklinghausen) [1782827]
- [fs] fs/proc/page.c: allow inspection of last section and fix end detection (Christoph von Recklinghausen) [1782827]
- [mm] mm/page_alloc.c: fix uninitialized memmaps on a partially populated last section (Christoph von Recklinghausen) [1782827]
- [powerpc] kvm: ppc: book3s hv: Handle non-present PTEs in page fault functions (David Gibson) [1820402]
- [vfio] vfio-pci/nvlink2: Allow fallback to ibm, mmio-atsd[0] (David Gibson) [1819169]
- [s390] s390/cpuinfo: fix wrong output when CPU0 is offline (Philipp Rudo) [1812982]
- [s390] s390/topology: remove offline CPUs from CPU topology masks (Philipp Rudo) [1812982]
- [hwtracing] intel_th: pci: Add Comet Lake PCH-V support (Tony Camuso) [1822983]
- [kernel] kprobes: Fix optimize_kprobe()/unoptimize_kprobe() cancellation logic (Waiman Long) [1833383]
- [kernel] kprobes: Set unoptimized flag after unoptimizing code (Waiman Long) [1833383]
- [kernel] kprobes: Prohibit probing on BUG() and WARN() address (Waiman Long) [1833383]
- [kernel] kprobes: Fix potential deadlock in kprobe_optimizer() (Waiman Long) [1833383]
- [fs] gfs2: More gfs2_find_jhead fixes (Abhijith Das) [1828653]
- [kernel] audit: fix a net reference leak in audit_list_rules_send() (Richard Guy Briggs) [1827327]
- [kernel] audit: fix a net reference leak in audit_send_reply() (Richard Guy Briggs) [1827327]
- [kernel] audit: check the length of userspace generated audit records (Richard Guy Briggs) [1827303]
- [s390] s390/pci: do not set affinity for floating irqs (Philipp Rudo) [1834319]
- [netdrv] mlx5: Remove the unsupported mark from ConnectX-6 Dx device (Alaa Hleihel) [1789382 1782831]
- [netdrv] mlx5: Update list of unsupported devices (Alaa Hleihel) [1823685 1789382]
- [infiniband] RDMA/mlx5: Verify that QP is created with RQ or SQ (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Fix udata response upon SRQ creation (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Set of completion request bit should not clear other adjacent bits (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: en_accel, Add missing net/geneve.h include (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix q counters on uplink representors (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Fix command entry leak in Internal Error State (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Fix forced completion access non initialized command entry (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: DR, On creation set CQ's arm_db member to right value (Alaa Hleihel) [1789384 1789382]
- [infiniband] RDMA/mlx5: Set GRH fields in query QP on RoCE (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Get the latest values from counters in switchdev mode (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Don't trigger IRQ multiple times on XSK wakeup to avoid WQ overruns (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Fix failing fw tracer allocation on s390 (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix pfnum in devlink port attribute (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix nest_level for vlan pop action (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Add missing release firmware call (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Fix frequent ioread PCI access during recovery (Alaa Hleihel) [1789382]
- [netdrv] flow_offload: check for basic action hw stats type (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Remove unused argument from parse_tc_pedit_action() (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Use netdev_warn() instead of pr_err() for errors (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: DR, Remove unneeded functions deceleration (Alaa Hleihel) [1789384 1789382]
- [netdrv] net/mlx5: DR, Improve log messages (Alaa Hleihel) [1789384 1789382]
- [netdrv] net/mlx5: DR, Change matcher priority parameter type (Alaa Hleihel) [1789384 1789382]
- [netdrv] net/mlx5: Eswitch, avoid redundant mask (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Don't allow forwarding between uplink (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Replace tunnel mpls capability bits for tunnel_offloads (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Fix missing congestion control debugfs on rep rdma device (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Optimize u64 division on 32-bit arches (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Prevent UMR usage with RO only when we have RO caps (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Fix group version management (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: E-Switch, Hold mutex when querying drop counter in legacy mode (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Tidy up and fix reverse christmas ordring (Alaa Hleihel) [1831133 1789382]
- [netdrv] net/mlx5: Expose port speed when possible (Alaa Hleihel) [1831133 1789382]
- [include] net/mlx5: Expose link speed directly (Alaa Hleihel) [1831133 1789382]
- [netdrv] net/mlx5e: Use netdev_warn() for errors for added prefix (Alaa Hleihel) [1789382]
- [include] net/mlx5: fix spelling mistake "reserverd" -> "reserved" (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: sparse: warning: Using plain integer as NULL pointer (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: sparse: warning: incorrect type in assignment (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: RX, Use indirect calls wrapper for handling compressed completions (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: RX, Use indirect calls wrapper for posting descriptors (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Change inline mode correctly when changing trust state (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Add context to the preactivate hook (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Allow mlx5e_switch_priv_channels to fail and recover (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Remove unneeded netif_set_real_num_tx_queues (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix configuration of XPS cpumasks and netdev queues in corner cases (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Use preactivate hook to set the indirection table (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Rename hw_modify to preactivate (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Encapsulate updating netdev queues into a function (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Add missing LRO cap check (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Define one flow for TXQ selection when TCs are configured (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Block delay drop to unprivileged users (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Fix access to wrong pointer while performing flush due to error (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Do not recover from a non-fatal syndrome (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix ICOSQ recovery flow with Striding RQ (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix missing reset of SW metadata in Striding RQ reset (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Enhance ICOSQ WQE info fields (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5_core: Set IB capability mask1 to fix ib_srpt connection failure (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Fix the number of hwcounters of a dynamic counter (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Clear LAG notifier pointer after unregister (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix endianness handling in pedit mask (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: kTLS, Fix wrong value in record tracker enum (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: kTLS, Fix TCP seq off-by-1 issue in TX resync flow (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: DR, Fix postsend actions write length (Alaa Hleihel) [1789384 1789382]
- [infiniband] IB/mlx5: Fix implicit ODP race (Alaa Hleihel) [1789382]
- [netdrv] mlx5: register lag notifier for init network namespace only (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix crash in recovery flow without devlink reporter (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Reset RQ doorbell counter before moving RQ state from RST to RDY (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Fix sleep while atomic in mlx5_eswitch_get_vepa (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Use div64_u64 for num_var_hw_entries calculation (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Prevent overflow in mmap offset calculations (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Fix async events cleanup flows (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Return failure when rts2rts_qp_counters_set_id is not supported (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Deprecate usage of generic TLS HW capability bit (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: TX, Error completion is for last WQE in batch (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: IPsec, fix memory leak at mlx5_fpga_ipsec_delete_sa_ctx (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: IPsec, Fix esp modify function attribute (Alaa Hleihel) [1789382]
- [infiniband] RDMA/core: Make the entire API tree static (Alaa Hleihel) [1789382]
- [netdrv] mlx5: Use dev_net netdevice notifier registrations (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Return the administrative GUID if exists (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: DR, Allow connecting flow table to a lower/same level table (Alaa Hleihel) [1789384 1789382]
- [netdrv] net/mlx5: DR, Modify header copy support (Alaa Hleihel) [1789384 1789382]
- [netdrv] net/mlx5: DR, Modify set action limitation extension (Alaa Hleihel) [1789384 1789382]
- [netdrv] net/mlx5e: Add mlx5e_flower_parse_meta support (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Fix printk format warning (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Allow creating autogroups with reserved entries (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Add ignore level support fwd to table rules (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: fs_core: Introduce unmanaged flow tables (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Refactor mlx5_create_auto_grouped_flow_table (Alaa Hleihel) [1789383 1789382]
- [include] net/mlx5e: Expose FEC feilds and related capability bit (Alaa Hleihel) [1789382]
- [include] net/mlx5: Add mlx5_ifc definitions for connection tracking support (Alaa Hleihel) [1789382]
- [include] net/mlx5: Add copy header action struct layout (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Expose resource dump register mapping (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Add structures and defines for MIRC register (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Read MCAM register groups 1 and 2 (Alaa Hleihel) [1789382]
- [include] net/mlx5: Add structures layout for new MCAM access reg groups (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Expose RoCE accelerator counters (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Set relaxed ordering when requested (Alaa Hleihel) [1789382]
- [include] net/mlx5: Expose relaxed ordering bits (Alaa Hleihel) [1789382]
- [include] net/mlx5: Add RoCE accelerator counters (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Fix handling of IOVA != user_va in ODP paths (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Mask out unsupported ODP capabilities for kernel QPs (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Don't fake udata for kernel path (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Add ODP WQE handlers for kernel QPs (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: Simplify devx async commands (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Add mmap support for VAR (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Introduce VAR object and its alloc/destroy methods (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Extend caps stage to handle VAR capabilities (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Expose vDPA emulation device capabilities (Alaa Hleihel) [1789382]
- [include] net/mlx5: Add Virtio Emulation related device capabilities (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Use async EQ setup cleanup helpers for multiple EQs (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Reduce No CQ found log level from warn to debug (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Increase the max number of channels to 128 (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Support accept action on nic table (Alaa Hleihel) [1789382]
- [netdrv] mlx5: work around high stack usage with gcc (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: limit the function in local scope (Alaa Hleihel) [1789382]
- [infiniband] RDMA/mlx5: use true, false for bool variable (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Unify ODP MR code paths to allow extra flexibility (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Fix outstanding_pi index for GSI qps (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5: Add devlink reload (Alaa Hleihel) [1789382]
- [netdrv] net/mlx5e: Set netdev name space on creation (Alaa Hleihel) [1789382]
- [infiniband] IB/mlx5: Load profile according to RoCE enablement state (Alaa Hleihel) [1790200 1789382]
- [netdrv] net/mlx5: Handle "enable_roce" devlink param (Alaa Hleihel) [1790200 1789382]
- [fs] gfs2: Another gfs2_walk_metadata fix (Andreas Grunbacher) [1826419]
- [nvme] nvmet-tcp: optimize tcp stack TX when data digest is used (Chris Leech) [1829540]
- [nvme] nvmet-tcp: fix maxh2cdata icresp parameter (Chris Leech) [1829540]
- [nvme] nvmet-tcp: set SO_PRIORITY for accepted sockets (Chris Leech) [1829540]
- [nvme] nvmet-tcp: set MSG_MORE only if we actually have more to send (Chris Leech) [1829540]
- [nvme] nvme-tcp: fix possible crash in recv error flow (Chris Leech) [1829540]
- [nvme] nvme-tcp: don't poll a non-live queue (Chris Leech) [1829540]
- [nvme] nvme-tcp: fix possible crash in write_zeroes processing (Chris Leech) [1829540]
- [nvme] nvme-tcp: Add warning on state change failure at nvme_tcp_setup_ctrl (Chris Leech) [1829540]
- [nvme] nvme: Make nvme_uninit_ctrl symmetric to nvme_init_ctrl (Chris Leech) [1829540]
- [nvme] nvme: Fix ctrl use-after-free during sysfs deletion (Chris Leech) [1829540]
- [nvme] nvme-tcp: break from io_work loop if recv failed (Chris Leech) [1829540]
- [nvme] nvme-tcp: move send failure to nvme_tcp_try_send (Chris Leech) [1829540]
- [nvme] nvme-tcp: optimize queue io_cpu assignment for multiple queue maps (Chris Leech) [1829540]
- [nvme] nvme-tcp: Set SO_PRIORITY for all host sockets (Chris Leech) [1829540]
- [nvme] nvme/tcp: fix bug on double requeue when send fails (Chris Leech) [1829540]
- [nvme] Revert "nvme: Restart request timers in resetting state" (Chris Leech) [1829540]
- [acpi] ACPI: processor: Export acpi_processor_evaluate_cst() (Steve Best) [1826415]
- [acpi] ACPI: processor: Make ACPI_PROCESSOR_CSTATE depend on ACPI_PROCESSOR (Steve Best) [1826415]
- [acpi] ACPI: processor: Clean up acpi_processor_evaluate_cst() (Steve Best) [1826415]
- [acpi] ACPI: processor: Introduce acpi_processor_evaluate_cst() (Steve Best) [1826415]
- [acpi] ACPI: processor: Export function to claim _CST control (Steve Best) [1826415]
- [s390] s390/ftrace: fix potential crashes when switching tracers (Philipp Rudo) [1831796]
- [net] net/smc: cancel event worker during device removal (Philipp Rudo) [1780665]
- [net] net/smc: check for valid ib_client_data (Philipp Rudo) [1780665]
- [net] net/smc: fix cleanup for linkgroup setup failures (Philipp Rudo) [1780665]
- [net] net/smc: no peer ID in CLC decline for SMCD (Philipp Rudo) [1780665]
- [net] net/smc: transfer fasync_list in case of fallback (Philipp Rudo) [1780665]
- [net] net/smc: fix leak of kernel memory to user space (Philipp Rudo) [1780665]
- [net] net/smc: allow unprivileged users to read pnet table (Philipp Rudo) [1780665]
- [net] net/smc: unregister ib devices in reboot_event (Philipp Rudo) [1780665]
- [net] net/smc: add fallback check to connect() (Philipp Rudo) [1780665]
- [net] net/smc: shorten lgr_cnt initialization (Philipp Rudo) [1780665]
- [net] net/smc: fix fastopen for non-blocking connect() (Philipp Rudo) [1780665]
- [net] net/smc: remove unused constant (Philipp Rudo) [1780665]
- [net] net/smc: use rcu_barrier() on module unload (Philipp Rudo) [1780665]
- [net] net/smc: guarantee removal of link groups in reboot (Philipp Rudo) [1780665]
- [net] net/smc: introduce bookkeeping of SMCR link groups (Philipp Rudo) [1780665]
- [net] net/smc: immediate termination for SMCR link groups (Philipp Rudo) [1780665]
- [net] net/smc: wait for tx completions before link freeing (Philipp Rudo) [1780665]
- [net] net/smc: abnormal termination without orderly flag (Philipp Rudo) [1780665]
- [net] net/smc: no WR buffer wait for terminating link group (Philipp Rudo) [1780665]
- [net] net/smc: introduce bookkeeping of SMCD link groups (Philipp Rudo) [1780665]
- [net] net/smc: abnormal termination of SMCD link groups (Philipp Rudo) [1780665]
- [net] net/smc: immediate termination for SMCD link groups (Philipp Rudo) [1780665]
- [net] net/smc: fix final cleanup sequence for SMCD devices (Philipp Rudo) [1780665]
- [net] net/smc: fix refcount non-blocking connect() -part 2 (Philipp Rudo) [1780665]
- [net] net/smc: fix ethernet interface refcounting (Philipp Rudo) [1780665]
- [net] net/smc: fix refcounting for non-blocking connect() (Philipp Rudo) [1780665]
- [net] net/smc: fix closing of fallback SMC sockets (Philipp Rudo) [1780665]
- [net] net/smc: remove close abort worker (Philipp Rudo) [1780665]
- [net] net/smc: introduce link group termination worker (Philipp Rudo) [1780665]
- [net] net/smc: improve abnormal termination of link groups (Philipp Rudo) [1780665]
- [net] net/smc: tell peers about abnormal link group termination (Philipp Rudo) [1780665]
- [net] net/smc: improve link group freeing (Philipp Rudo) [1780665]
- [net] net/smc: improve abnormal termination locking (Philipp Rudo) [1780665]
- [net] net/smc: terminate link group without holding lgr lock (Philipp Rudo) [1780665]
- [net] net/smc: cancel send and receive for terminated socket (Philipp Rudo) [1780665]
- [net] net/smc: receive pending data after RCV_SHUTDOWN (Philipp Rudo) [1780665]
- [net] net/smc: receive returns without data (Philipp Rudo) [1780665]
- [net] net/smc: fix SMCD link group creation with VLAN id (Philipp Rudo) [1780665]
- [net] net/smc: improve close of terminated socket (Philipp Rudo) [1780665]
- [net] net/smc: no new connections on disappearing devices (Philipp Rudo) [1780665]
- [net] net/smc: increase device refcount for added link group (Philipp Rudo) [1780665]
- [net] net/smc: separate locks for SMCD and SMCR link group lists (Philipp Rudo) [1780665]
- [net] net/smc: separate SMCD and SMCR link group lists (Philipp Rudo) [1780665]
- [net] net/smc: original socket family in inet_sock_diag (Philipp Rudo) [1780665]
- [infiniband] RDMA/bnxt_re: Use rdma_read_gid_hw_context to retrieve HW gid index (Kamal Heib) [1828601]
- [infiniband] RDMA/core: Add helper function to retrieve driver gid context from gid attr (Kamal Heib) [1828601]
- [media] media: videobuf2-v4l2: drop WARN_ON in vb2_warn_zero_bytesused() (Vladis Dronov) [1825616] {CVE-2019-9455}
- [net] SUNRPC: Fix initialisation of struct rpc_xprt_switch (Steve Dickson) [1683394]
- [net] SUNRPC: add links for all client xprts to debugfs (Steve Dickson) [1683394]
- [net] SUNRPC: enhance rpc_clnt_show_stats() to report on all xprts (Steve Dickson) [1683394]
- [net] SUNRPC: Fix transport accounting when caller specifies an rpc_xprt (Steve Dickson) [1683394]
- [fs] NFS: send state management on a single connection (Steve Dickson) [1683394]
- [net] SUNRPC: Add basic load balancing to the transport switch (Steve Dickson) [1683394]
- [net] SUNRPC: Fix up task signalling (Steve Dickson) [1683394]
- [fs] NFS: Allow multiple connections to a NFSv2 or NFSv3 server (Steve Dickson) [1683394]
- [fs] NFS: Display the "nconnect" mount option if it is set (Steve Dickson) [1683394]
- [fs] pNFS: Allow multiple connections to the DS (Steve Dickson) [1683394]
- [fs] NFSv4: Allow multiple connections to NFSv4.x (x>0) servers (Steve Dickson) [1683394]
- [fs] NFS: Add a mount option to specify number of TCP connections to use (Steve Dickson) [1683394]
- [net] SUNRPC: Allow creation of RPC clients with multiple connections (Steve Dickson) [1683394]
- [net] netlabel: cope with NULL catmap (Paolo Abeni) [1827251] {CVE-2020-10711}
- [scsi] scsi: qla2xxx: fix a potential NULL pointer dereference ("Ewan D. Milne") [1829250] {CVE-2019-16233}
- [input] Input: ff-memless - kill timer in destroy() (Chris von Recklinghausen) [1815024] {CVE-2019-19524}

* Wed May 13 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-199.el8]
- [netdrv] net/mlx5e: kTLS, Do not send decrypted-marked SKBs via non-accel path (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: kTLS, Remove redundant posts in TX resync flow (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: kTLS, Fix corner-case checks in TX resync flow (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-Switch, Prevent ingress rate configuration of uplink rep (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Update the list of the PCI supported devices (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Fix lowest FDB pool size (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Fix hairpin RSS table size (Alaa Hleihel) [1789380]
- [netdrv] Revert "net/mlx5: Support lockless FTE read lookups" (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Move devlink registration before interfaces load (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Always print health reporter message to dmesg (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Avoid duplicating rule destinations (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Fix device memory flows (Alaa Hleihel) [1789380]
- [netdrv] treewide: Use sizeof_field() macro (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: E-switch, Fix Ingress ACL groups in switchdev mode for prio tag (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Fix build error without IPV6 (Alaa Hleihel) [1789380]
- [netdrv] net: use rhashtable_lookup() instead of rhashtable_lookup_fast() (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Remove redundant pointer check (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: TC, Stub out ipv6 tun create header function (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: DR, Add support for Geneve packets SW steering (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: DR, Add HW bits and definitions for Geneve flex parser (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: DR, Refactor VXLAN GPE flex parser tunnel code for SW steering (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Don't write read-only fields in MODIFY_HCA_VPORT_CONTEXT command (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Implement callbacks for getting VFs GUID attributes (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Rx, Update page pool numa node when changed (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Support extended number of strides for Striding RQ (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Remove redundant NULL initializations (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Add new chain for netfilter flow table offload (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Refactor creating fast path prio chains (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Accumulate levels for chains prio namespaces (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Define fdb tc levels per prio (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Rename FDB_* tc related defines to FDB_TC_* defines (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Simplify fdb chain and prio eswitch defines (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Support flow counters offset for bulk counters (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Dump of fw_fatal use updated devlink binary interface (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Rename profile and init methods (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: fix spelling mistake "metdata" -> "metadata" (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: fix kvfree of uninitialized pointer spec (Alaa Hleihel) [1789380]
- [infiniband] IB: mlx5: no need to check return value of debugfs_create functions (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: LAG, Use port enumerators (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: rate limit alloc_ent error messages (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Add ToS (DSCP) header rewrite support (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Bit sized fields rewrite support (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: WQ, Move short getters into header file (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: TX, Dump WQs wqe descriptors on CQE with error events (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Support lockless FTE read lookups (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Do not hold group lock while allocating FTE in software (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Verify that rule has at least one fwd/drop action (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Remove unneeded variable in mlx5_unload_one (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: FPGA, support network cards with standalone FPGA (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Introduce and use mlx5_core_is_vf() (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Refactor ingress acl configuration (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Restrict metadata disablement to offloads mode (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-switch, Offloads shift ACL programming during enable/disable vport (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-switch, Offloads introduce and use per vport acl tables APIs (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Move ACL drop counters life cycle close to ACL lifecycle (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-switch, Legacy introduce and use per vport acl tables APIs (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-switch, Prepare code to handle vport enable error (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Tide up state_lock and vport enabled flag usage (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Move legacy drop counter and rule under legacy structure (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Move metdata fields under offloads structure (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: Introduce and use mlx5_esw_is_manager_vport() (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-switch, Introduce and use vlan rule config helper (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-Switch, Rename ingress acl config in offloads mode (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5: E-Switch, Rename egress config to generic name (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Test write combining support (Alaa Hleihel) [1789380]
- [netdrv] net: Fix misspellings of "configure" and "configuration" (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Do not race with mlx5_ib_invalidate_range during create and destroy (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Do not store implicit children in the odp_mkeys xarray (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Rework implicit ODP destroy (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Avoid double lookups on the pagefault path (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Reduce locking in implicit_mr_get_data() (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Use an xarray for the children of an implicit ODP (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Split implicit handling from pagefault_mr (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Set the HW IOVA of the child MRs to their place in the tree (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Lift implicit_mr_alloc() into the two routines that call it (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Rework implicit_mr_get_data (Alaa Hleihel) [1789380]
- [netdrv] RDMA/mlx5: Delete struct mlx5_priv->mkey_table (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Use a dedicated mkey xarray for ODP (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Split sig_err MR data into its own xarray (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Use SRCU properly in ODP prefetch (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Align usage of QP1 create flags with rest of mlx5 defines (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Add capability for max sge to get optimized performance (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Introduce and use mkey context setting helper routine (Alaa Hleihel) [1789380]
- [include] net/mlx5: Expose optimal performance scatter entries capability (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Remove unnecessary else statement (Alaa Hleihel) [1789380]
- [infiniband] IB/mlx5: Remove unnecessary return statement (Alaa Hleihel) [1789380]
- [infiniband] RDMA/mlx5: Group boolean parameters to take less space (Alaa Hleihel) [1789380]
- [netdrv] net/mlx5e: Add missing capability bit check for IP-in-IP (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Fix ingress rate configuration for representors (Alaa Hleihel) [1789378]
- [netdrv] mlx5: reject unsupported external timestamp flags (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Replace kfree with kvfree when free vhca stats (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Remove incorrect match criteria assignment line (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Enhance TX resync flow (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Save a copy of the crypto info (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Remove unneeded cipher type checks (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Limit DUMP wqe size (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Fix missing SQ edge fill (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Fix page refcnt leak in TX resync error flow (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Save by-value copy of the record frags (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Save only the frag page to release at completion (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Size of a Dump WQE is fixed (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Release reference on DUMPed fragments in shutdown flow (Alaa Hleihel) [1789378]
- [infiniband] RDMA/mlx5: Put live in the correct place for ODP MRs (Alaa Hleihel) [1789378]
- [infiniband] RDMA/odp: Lift umem_mutex out of ib_umem_odp_unmap_dma_pages() (Alaa Hleihel) [1789378]
- [netdrv] drivers: net: Fix Kconfig indentation (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: DR, Remove redundant dev_name print from err log (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: DR, Remove useless set memory to zero use memset() (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: kTLS, Remove unused function parameter (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Use PTR_ERR_OR_ZERO rather than its implementation (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Use ipv6_stub to avoid dependency with ipv6 being a module (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Kconfig: Fix MLX5_CORE dependency with PCI_HYPERV_INTERFACE (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Fix static checker warning of potential pointer math issue (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Remove unlikely() from WARN*() condition (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Support TSO and TX checksum offloads for IP-in-IP tunnels (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Improve stateless offload capability check (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Support RSS for IP-in-IP and IPv6 tunneled packets (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Change function's position to a more fitting file (Alaa Hleihel) [1789378]
- [infiniband] IB/mlx5: Add page fault handler for DC initiator WQE (Alaa Hleihel) [1789378]
- [infiniband] IB/mlx5: Remove check of FW capabilities in ODP page fault handling (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Set ODP capabilities for DC transport to max (Alaa Hleihel) [1789378]
- [infiniband] RDMA/mlx5: RDMA_RX flow type support for user applications (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Fix return code in case of hyperv wrong size read (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Add mlx5e HV VHCA stats agent (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Add HV VHCA control agent (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Add HV VHCA infrastructure (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Add wrappers for HyperV PCIe operations (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Add trace point for neigh update (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Add trace point for neigh used value update (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Add tc flower tracepoints (Alaa Hleihel) [1789378]
- [infiniband] RDMA/mlx5: Use odp instead of mr->umem in pagefault_mr (Alaa Hleihel) [1789378]
- [infiniband] RDMA/mlx5: Use ib_umem_start instead of umem.address (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Create bypass and loopback flow steering namespaces for RDMA RX (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Add per-namespace flow table default miss action support (Alaa Hleihel) [1789378]
- [include] net/mlx5: Expose IP-in-IP capability bit (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Improve functions documentation (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Report and recover from CQE with error on RQ (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: RX, Handle CQE with error at the earliest stage (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Report and recover from rx timeout (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Report and recover from CQE error on ICOSQ (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Split open/close ICOSQ into stages (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Add support to rx reporter diagnose (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Add helper functions for reporter's basics (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Add cq info to tx reporter diagnose (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Extend tx reporter diagnostics output (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Extend tx diagnose function (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Generalize tx reporter's functionality (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Change naming convention for reporter's functions (Alaa Hleihel) [1790198 1789378]
- [netdrv] net/mlx5e: Rename reporter header file (Alaa Hleihel) [1790198 1789378]
- [infiniband] RDMA/mlx5: Annotate lock dependency in bind/unbind slave port (Alaa Hleihel) [1789378]
- [infiniband] IB/mlx5: Expose XRQ legacy commands over the DEVX interface (Alaa Hleihel) [1789378]
- [infiniband] IB/mlx5: Add legacy events to DEVX list (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Add XRQ legacy commands opcodes (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: Use debug message instead of warn (Alaa Hleihel) [1789378]
- [netdrv] mlx5: no need to check return value of debugfs_create functions (Alaa Hleihel) [1789378]
- [infiniband] mlx5: Use refcount_t for refcount (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Allow dropping specific tunnel packets (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: TX reporter cleanup (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Set tx reporter only on successful creation (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Rx, checksum handling refactoring (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Tx, Soften inline mode VLAN dependencies (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: XDP, Slight enhancement for WQE fetch function (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: XDP, Close TX MPWQE session when no room for inline packet left (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: Tx, Strict the room needed for SQ edge NOPs (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5: E-Switch, add ingress rate support (Alaa Hleihel) [1789378]
- [infiniband] RDMA/mlx5: Remove DEBUG ODP code (Alaa Hleihel) [1789378]
- [infiniband] IB/mlx5: Add CREATE_PSV/DESTROY_PSV for devx interface (Alaa Hleihel) [1789378]
- [infiniband] IB/mlx5: Avoid unnecessary typecast (Alaa Hleihel) [1789378]
- [netdrv] net/mlx5e: xsk: dynamically allocate mlx5e_channel_param (Alaa Hleihel) [1789378]
- [netdrv] net: Use skb accessors in network drivers (Alaa Hleihel) [1789378]
- [char] tpm: Export tpm2_get_cc_attrs_tbl for ibmvtpm driver as module (David Gibson) [1781915]
- [char] tpm: ibmvtpm: Add support for TPM2 (David Gibson) [1781915]
- [char] tpm: of: Handle IBM, vtpm20 case when getting log parameters (David Gibson) [1781915]
- [wireless] iwlwifi: mvm: Do not require PHY_SKU NVM section for 3168 devices (Jarod Wilson) [1807052]
- [wireless] mwifiex: set needed_headroom, not hard_header_len (Jarod Wilson) [1807052]
- [wireless] ath9k: Handle txpower changes even when TPC is disabled (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x02: fix coverage_class type (Jarod Wilson) [1807052]
- [wireless] rtw88: Use kfree_skb() instead of kfree() (Jarod Wilson) [1807052]
- [wireless] brcmfmac: abort and release host after error (Jarod Wilson) [1807052]
- [wireless] ath11k: Silence clang -Wsometimes-uninitialized in ath11k_update_per_peer_stats_from_txcompl (Jarod Wilson) [1807052]
- [wireless] ath10k: Call cpu_latency_qos_*() instead of pm_qos_*() (Jarod Wilson) [1807052]
- [net] mac80211: fix authentication with iwlwifi/mvm (Jarod Wilson) [1807052]
- [net] mac80211: set IEEE80211_TX_CTRL_PORT_CTRL_PROTO for nl80211 TX (Jarod Wilson) [1807052]
- [net] mac80211: mark station unauthorized before key removal (Jarod Wilson) [1807052]
- [net] mac80211: Check port authorization in the ieee80211_tx_dequeue() case (Jarod Wilson) [1807052]
- [net] cfg80211: Do not warn on same channel at the end of CSA (Jarod Wilson) [1807052]
- [net] mac80211: drop data frames without key on encrypted links (Jarod Wilson) [1807052]
- [net] nl80211: fix NL80211_ATTR_CHANNEL_WIDTH attribute type (Jarod Wilson) [1807052]
- [wireless] iwlwifi: don't send GEO_TX_POWER_LIMIT if no wgds table (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: add 0x2526/0x401* devices back to cfg detection (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8188ee: Fix regression due to commit d1d1a96bdb44 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: cfg: use antenna diversity with all AX101 devices (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: Fix rate scale NSS configuration (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg: don't abort if sending DBGC_SUSPEND_RESUME fails (Jarod Wilson) [1807052]
- [wireless] iwlwifi: yoyo: don't add TLV offset when reading FIFOs (Jarod Wilson) [1807052]
- [wireless] iwlwifi: check allocated pointer when allocating conf_tlvs (Jarod Wilson) [1807052]
- [wireless] iwlwifi: consider HE capability when setting LDPC (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: take the required lock when clearing time event data (Jarod Wilson) [1807052]
- [net] mac80211: Do not send mesh HWMP PREQ if HWMP is disabled (Jarod Wilson) [1807052]
- [net] nl80211: add missing attribute validation for channel switch (Jarod Wilson) [1807052]
- [net] nl80211: add missing attribute validation for beacon report scanning (Jarod Wilson) [1807052]
- [net] nl80211: add missing attribute validation for critical protocol indication (Jarod Wilson) [1807052]
- [wireless] mt76: fix array overflow on receiving too many fragments for a packet (Jarod Wilson) [1807052]
- [net] mac80211: rx: avoid RCU list traversal under mutex (Jarod Wilson) [1807052]
- [net] nl80211: explicitly include if_vlan.h (Jarod Wilson) [1807052]
- [net] mac80211: Remove a redundant mutex unlock (Jarod Wilson) [1807052]
- [net] cfg80211: check reg_rule for NULL in handle_channel_custom() (Jarod Wilson) [1807052]
- [net] nl80211: fix potential leak in AP start (Jarod Wilson) [1807052]
- [net] mac80211: fix wrong 160/80+80 MHz setting (Jarod Wilson) [1807052]
- [net] cfg80211: add missing policy for NL80211_ATTR_STATUS_CODE (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: fix max_nss in mt7615_eeprom_parse_hw_cap (Jarod Wilson) [1807052]
- [net] cfg80211: check wiphy driver existence for drvinfo report (Jarod Wilson) [1807052]
- [net] mac80211: consider more elements in parsing CRC (Jarod Wilson) [1807052]
- [net] mac80211: fix quiet mode activation in action frames (Jarod Wilson) [1807052]
- [net] mac80211: use more bits for ack_frame_id (Jarod Wilson) [1807052]
- [wireless] rtw88: Fix return value of rtw_wow_check_fw_status (Jarod Wilson) [1807052]
- [wireless] iwlwifi: d3: read all FW CPUs error info (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix TDLS discovery with the new firmware API (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: Check the sta is not NULL in iwl_mvm_cfg_he_sta() (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: avoid use after free for pmsr request (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: update the DTS measurement type (Jarod Wilson) [1807052]
- [wireless] iwlwifi: don't throw error when trying to remove IGTK (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: Fix thermal zone registration (Jarod Wilson) [1807052]
- [wireless] iwlwifi: use <linux/units.h> helpers (Jarod Wilson) [1807052]
- [wireless] mwifiex: Fix possible buffer overflows in mwifiex_cmd_append_vsie_tlv() (Jarod Wilson) [1807052]
- [wireless] mwifiex: Fix possible buffer overflows in mwifiex_ret_wmm_get_status() (Jarod Wilson) [1807052]
- [wireless] mwifiex: fix unbalanced locking in mwifiex_process_country_ie() (Jarod Wilson) [1807052]
- [wireless] rtlwifi: btcoex: fix spelling mistake "initilized" -> "initialized" (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723ae: remove unused variables (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: remove unused variables (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8821ae: remove unused variables (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8188ee: remove redundant assignment to variable cond (Jarod Wilson) [1807052]
- [wireless] brcmfmac: Remove always false 'idx < 0' statement (Jarod Wilson) [1807052]
- [wireless] rtw88: use shorter delay time to poll PS state (Jarod Wilson) [1807052]
- [wireless] rtw88: fix potential NULL skb access in TX ISR (Jarod Wilson) [1807052]
- [wireless] brcmfmac: add initial support for monitor mode (Jarod Wilson) [1807052]
- [wireless] brcmfmac: simplify building interface combinations (Jarod Wilson) [1807052]
- [wireless] brcmfmac: sdio: Fix OOB interrupt initialization on brcm43362 (Jarod Wilson) [1807052]
- [wireless] brcmfmac: use true,false for bool variable (Jarod Wilson) [1807052]
- [wireless] rtw88: use true,false for bool variable (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8821ae: Make functions static & rm sw.h (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723be: Make functions static & rm sw.h (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723ae: Make functions static & rm sw.h (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192se: Remove sw.h header (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: Make functions static & rm sw.h (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192cu: Remove sw.h header (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ce: Make functions static & rm sw.h (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8188ee: Make functions static & rm sw.h (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192cu: Fix typo (Jarod Wilson) [1807052]
- [wireless] rtw88: change max_num_of_tx_queue() definition to inline in pci.h (Jarod Wilson) [1807052]
- [wireless] rtw88: assign NULL to skb after being kfree()'ed (Jarod Wilson) [1807052]
- [wireless] rtw88: use rtw_hci_stop() instead of rtwdev->hci.ops->stop() (Jarod Wilson) [1807052]
- [wireless] rtw88: remove unused vif pointer in struct rtw_vif (Jarod Wilson) [1807052]
- [wireless] rtw88: remove unused variable 'in_lps' (Jarod Wilson) [1807052]
- [wireless] rtw88: remove unused spinlock (Jarod Wilson) [1807052]
- [wireless] rtw88: 8822c: update power sequence to v15 (Jarod Wilson) [1807052]
- [wireless] rtw88: fix TX secondary channel offset of 40M if current bw is 20M or 40M (Jarod Wilson) [1807052]
- [wireless] rtw88: fix rate mask for 1SS chip (Jarod Wilson) [1807052]
- [wireless] rtw88: Add wowlan net-detect support (Jarod Wilson) [1807052]
- [wireless] rtw88: Add wowlan pattern match support (Jarod Wilson) [1807052]
- [wireless] rtw88: support wowlan feature for 8822c (Jarod Wilson) [1807052]
- [wireless] rtw88: load wowlan firmware if wowlan is supported (Jarod Wilson) [1807052]
- [wireless] rtw88: add interface config for 8822c (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: reset dma when reset pci trx ring (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: reset ring index when release skbs in tx ring (Jarod Wilson) [1807052]
- [wireless] ath10k: Use device_get_match_data() to simplify code (Jarod Wilson) [1807052]
- [wireless] ath10k: Add newlines to printk messages (Jarod Wilson) [1807052]
- [wireless] ath10k: Correct the DMA direction for management tx buffers (Jarod Wilson) [1807052]
- [wireless] mwifiex: drop most magic numbers from mwifiex_process_tdls_action_frame() (Jarod Wilson) [1807052]
- [wireless] ath11k: fix up some error paths (Jarod Wilson) [1807052]
- [wireless] ath11k: make sure to also report the RX bandwidth inside radiotap (Jarod Wilson) [1807052]
- [wireless] ath11k: avoid null pointer dereference when pointer band is null (Jarod Wilson) [1807052]
- [wireless] ath11k: Add missing pdev rx rate stats (Jarod Wilson) [1807052]
- [wireless] ath11k: ensure ts.flags is initialized before bit-wise or'ing in values (Jarod Wilson) [1807052]
- [wireless] ath11k: set TxBf parameters after vdev start (Jarod Wilson) [1807052]
- [wireless] ath11k: enable HE tlvs in ppdu stats for pktlog lite (Jarod Wilson) [1807052]
- [wireless] ath11k: fix debugfs build failure (Jarod Wilson) [1807052]
- [wireless] ath10k: Don't call SCM interface for statically mapped msa region (Jarod Wilson) [1807052]
- [wireless] Revert "ath10k: fix DMA related firmware crashes on multiple devices" (Jarod Wilson) [1807052]
- [wireless] ath10k: drop RX skb with invalid length for sdio (Jarod Wilson) [1807052]
- [wireless] ath10k: use true,false for bool variable (Jarod Wilson) [1807052]
- [wireless] ath10k: Add optional qdss clk (Jarod Wilson) [1807052]
- [wireless] ath10k: pci: Fix comment on ath10k_pci_dump_memory_sram (Jarod Wilson) [1807052]
- [wireless] ath10k: pci: Only dump ATH10K_MEM_REGION_TYPE_IOREG when safe (Jarod Wilson) [1807052]
- [wireless] ath9k: use true,false for bool variable (Jarod Wilson) [1807052]
- [net] net: mac80211: use skb_list_walk_safe helper for gso segments (Jarod Wilson) [1807052]
- [wireless] net: iwlwifi: use skb_list_walk_safe helper for gso segments (Jarod Wilson) [1807052]
- [wireless] iwlwifi: add device name to device_info (Jarod Wilson) [1807052]
- [wireless] iwlwifi: implement a new device configuration table (Jarod Wilson) [1807052]
- [wireless] iwlwifi: assume the driver_data is a trans_cfg, but allow full cfg (Jarod Wilson) [1807052]
- [wireless] iwlwifi: prph: remove some unused register definitions (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: print out extended secboot status before dump (Jarod Wilson) [1807052]
- [wireless] iwlwifi: incorporate firmware filename into version (Jarod Wilson) [1807052]
- [wireless] iwlwifi: yoyo: check for the domain on all TLV types during init (Jarod Wilson) [1807052]
- [wireless] iwlwifi: add new iwlax411 struct for type SoSnj (Jarod Wilson) [1807052]
- [wireless] iwlwifi: yoyo: remove the iwl_dbg_tlv_gen_active_trigs() function (Jarod Wilson) [1807052]
- [wireless] iwlwifi: yoyo: remove unnecessary active triggers status flag (Jarod Wilson) [1807052]
- [wireless] iwlwifi: yoyo: don't allow changing the domain via debugfs (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: Update BEACON_TEMPLATE_CMD firmware API (Jarod Wilson) [1807052]
- [wireless] iwlwifi: remove CSR registers abstraction (Jarod Wilson) [1807052]
- [wireless] iwlwifi: remove some outdated iwl22000 configurations (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: validate queue ID before array deref/bit ops (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: use partial pages if applicable (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: map only used part of RX buffers (Jarod Wilson) [1807052]
- [wireless] iwlwifi: allocate more receive buffers for HE devices (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: add support for responder config command version 7 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: add support for location range request version 8 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: remove support for fw scan api v11 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: don't skip a TX FIFO when dumping (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: update powersave correctly for D3 (Jarod Wilson) [1807052]
- [wireless] ath11k: Use sizeof_field() instead of FIELD_SIZEOF() (Jarod Wilson) [1807052]
- [wireless] ath11k: explicitly cast wmi commands to their correct struct type (Jarod Wilson) [1807052]
- [wireless] orinoco: avoid assertion in case of NULL pointer (Jarod Wilson) [1807052]
- [wireless] brcmfmac: Keep OOB wake-interrupt disabled when it shouldn't be enabled (Jarod Wilson) [1807052]
- [wireless] brcmfmac: Fix memory leak in brcmf_usbdev_qinit (Jarod Wilson) [1807052]
- [wireless] brcmfmac: not set mbss in vif if firmware does not support MBSS (Jarod Wilson) [1807052]
- [wireless] brcmfmac: add RSDB condition when setting interface combinations (Jarod Wilson) [1807052]
- [wireless] brcmfmac: add support for BCM4359 SDIO chipset (Jarod Wilson) [1807052]
- [wireless] brcmfmac: make errors when setting roaming parameters non-fatal (Jarod Wilson) [1807052]
- [wireless] brcmfmac: fix rambase for 4359/9 (Jarod Wilson) [1807052]
- [wireless] brcmfmac: set F2 blocksize and watermark for 4359 (Jarod Wilson) [1807052]
- [wireless] brcmfmac: reset two D11 cores if chip has two D11 cores (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: use generic rtl_signal_scale_mapping (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192cu: use generic rtl_signal_scale_mapping (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ce: use generic rtl_signal_scale_mapping (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: use generic rtl_query_rxpwrpercentage (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192cu: use generic rtl_query_rxpwrpercentage (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ce: use generic rtl_query_rxpwrpercentage (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: fix interface sanity check (Jarod Wilson) [1807052]
- [wireless] brcmfmac: fix interface sanity check (Jarod Wilson) [1807052]
- [wireless] brcmfmac: set interface carrier to off by default (Jarod Wilson) [1807052]
- [wireless] mwifiex: delete unused mwifiex_get_intf_num() (Jarod Wilson) [1807052]
- [wireless] rt2x00usb: Fix a warning message in 'rt2x00usb_watchdog_tx_dma()' (Jarod Wilson) [1807052]
- [wireless] brcmfmac: Fix use after free in brcmf_sdio_readframes() (Jarod Wilson) [1807052]
- [wireless] rt2x00: use RESET state bit to prevent IV changes on restart (Jarod Wilson) [1807052]
- [wireless] rt2x00: implement reconfig_complete (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl_pci: Fix -Wcast-function-type (Jarod Wilson) [1807052]
- [wireless] brcmsmac: Remove always false 'channel < 0' statement (Jarod Wilson) [1807052]
- [wireless] rtlwifi: Remove last definitions of local bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723be: Remove usage of private bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723ae: Remove usage of private bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: Remove usage of private bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl88821ae: Remove usage of private bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: Remove dependence on special bit manipulation macros for common driver (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ce: rtl8192c_com: Remove usage of private bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8188ee: Remove usage of private bit manipulation (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Remove usage of private bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Convert inline routines to little-endian words (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Convert macros that set descriptor (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Replace local bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Remove unused GET_XXX and SET_XXX macros (Jarod Wilson) [1807052]
- [wireless] brcmfmac: Fix memory leak in brcmf_p2p_create_p2pdev() (Jarod Wilson) [1807052]
- [wireless] ath9k: fix storage endpoint lookup (Jarod Wilson) [1807052]
- [wireless] ath11k: Remove unneeded semicolon (Jarod Wilson) [1807052]
- [wireless] ath11k: remove an unneeded NULL check (Jarod Wilson) [1807052]
- [wireless] ath11k: checking for NULL vs IS_ERR() (Jarod Wilson) [1807052]
- [wireless] ath11k: delete a stray unlock in ath11k_dbg_htt_stats_req() (Jarod Wilson) [1807052]
- [wireless] ath11k: fix missing free of skb on error return path (Jarod Wilson) [1807052]
- [wireless] ath11k: fix uninitialized variable radioup (Jarod Wilson) [1807052]
- [wireless] ath11k: fix memory leak on reg_info (Jarod Wilson) [1807052]
- [wireless] ath11k: Remove unnecessary enum scan_priority (Jarod Wilson) [1807052]
- [wireless] ath11k: fix several spelling mistakes (Jarod Wilson) [1807052]
- [wireless] ath11k: add some missing __packed qualifiers (Jarod Wilson) [1807052]
- [wireless] ath11k: set the BA buffer size to 256 when HE is enabled (Jarod Wilson) [1807052]
- [wireless] ath11k: fix pdev when invoking ath11k_wmi_send_twt_enable_cmd() (Jarod Wilson) [1807052]
- [wireless] ath11k: optimize ath11k_hal_tx_status_parse (Jarod Wilson) [1807052]
- [wireless] ath11k: optimise ath11k_dp_tx_completion_handler (Jarod Wilson) [1807052]
- [wireless] ath11k: move some tx_status parsing to debugfs code (Jarod Wilson) [1807052]
- [wireless] ath11k: rename ath11k_wmi_base instances from wmi_sc to wmi_ab (Jarod Wilson) [1807052]
- [wireless] ath11k: drop memset when setting up a tx cmd desc (Jarod Wilson) [1807052]
- [wireless] ath11k: disable PS for STA interfaces by default upon bringup (Jarod Wilson) [1807052]
- [wireless] ath11k: add wmi helper for turning STA PS on/off (Jarod Wilson) [1807052]
- [wireless] ath10k: Fix some typo in some warning messages (Jarod Wilson) [1807052]
- [wireless] ath11k: register HE mesh capabilities (Jarod Wilson) [1807052]
- [net] netlink: rename nl80211_validate_nested() to nla_validate_nested() (Jarod Wilson) [1807052]
- [wireless] wireless/mediatek: Replace rcu_swap_protected() with rcu_replace_pointer() (Jarod Wilson) [1807052]
- [wireless] ath: add support for special 0x0 regulatory domain (Jarod Wilson) [1807052]
- [wireless] ath10k: change bundle count for max rx bundle for sdio (Jarod Wilson) [1807052]
- [wireless] ath10k: enable napi on RX path for sdio (Jarod Wilson) [1807052]
- [wireless] ath11k: fix indentation in ath11k_mac_prepare_he_mode() (Jarod Wilson) [1807052]
- [wireless] ath11k: Setup REO destination ring before sending wmi_init command (Jarod Wilson) [1807052]
- [wireless] ath11k: Move mac80211 hw allocation before wmi_init command (Jarod Wilson) [1807052]
- [wireless] ath11k: Skip update peer stats for management packets (Jarod Wilson) [1807052]
- [wireless] ath11k: update tx duration in station info (Jarod Wilson) [1807052]
- [wireless] ath11k: fix vht guard interval mapping (Jarod Wilson) [1807052]
- [wireless] ath11k: fix memory leak in monitor mode (Jarod Wilson) [1807052]
- [wireless] ath11k: Advertise MPDU start spacing as no restriction (Jarod Wilson) [1807052]
- [wireless] ath11k: Update tx and rx chain count properly on drv_set_antenna (Jarod Wilson) [1807052]
- [wireless] ath11k: add necessary peer assoc params in wmi dbg (Jarod Wilson) [1807052]
- [wireless] ath11k: unlock mutex during failure in qmi fw ready (Jarod Wilson) [1807052]
- [wireless] ath11k: add support for controlling tx power to a station (Jarod Wilson) [1807052]
- [wireless] ath11k: update bawindow size in delba process (Jarod Wilson) [1807052]
- [wireless] ath11k: avoid use_after_free in ath11k_dp_rx_msdu_coalesce API (Jarod Wilson) [1807052]
- [wireless] ath11k: avoid burst time conversion logic (Jarod Wilson) [1807052]
- [wireless] ath11k: pktlog: fix sending/using the pdev id (Jarod Wilson) [1807052]
- [wireless] ath11k: qmi clean up in ath11k_qmi_wlanfw_wlan_cfg_send() (Jarod Wilson) [1807052]
- [wireless] ath11k: qmi clean up ce and HTC service config update (Jarod Wilson) [1807052]
- [wireless] ath11k: tracing: fix ath11k tracing (Jarod Wilson) [1807052]
- [wireless] ath10k: enable wow feature for sdio chip (Jarod Wilson) [1807052]
- [wireless] ath10k: change log level for mpdu status of sdio chip (Jarod Wilson) [1807052]
- [wireless] ath10k: set WMI_PEER_AUTHORIZE after a firmware crash (Jarod Wilson) [1807052]
- [wireless] ath10k: set max mtu to 1500 for sdio chip (Jarod Wilson) [1807052]
- [wireless] ath10k: enable firmware log by default for sdio (Jarod Wilson) [1807052]
- [wireless] ath11k: Fix target crash due to WBM_IDLE_LINK ring desc shortage (Jarod Wilson) [1807052]
- [wireless] ath11k: Fixing TLV length issue in peer pktlog WMI command (Jarod Wilson) [1807052]
- [wireless] ath11k: Fix skb_panic observed during msdu coalescing (Jarod Wilson) [1807052]
- [wireless] ath11k: remove unused tx ring counters (Jarod Wilson) [1807052]
- [wireless] ath11k: avoid WMM param truncation (Jarod Wilson) [1807052]
- [wireless] ath11k: optimize RX path latency (Jarod Wilson) [1807052]
- [wireless] ath11k: update tcl cmd descriptor parameters for STA mode (Jarod Wilson) [1807052]
- [wireless] ath11k: fix wmi service ready ext tlv parsing (Jarod Wilson) [1807052]
- [wireless] ath11k: fix resource leak in ath11k_mac_sta_state (Jarod Wilson) [1807052]
- [wireless] ath11k: Fix htt stats sounding info and pdev cca stats (Jarod Wilson) [1807052]
- [wireless] ath10k: move non-fatal warn logs to dbg level (Jarod Wilson) [1807052]
- [wireless] ath11k: add spatial reuse support (Jarod Wilson) [1807052]
- [wireless] ath11k: add TWT support (Jarod Wilson) [1807052]
- [wireless] ath11k: add HE support (Jarod Wilson) [1807052]
- [wireless] ath11k: Remove dead code while handling amsdu packets (Jarod Wilson) [1807052]
- [wireless] ath11k: fix missed bw conversion in tx completion (Jarod Wilson) [1807052]
- [wireless] ath11k: convert message from info to dbg (Jarod Wilson) [1807052]
- [wireless] ath11k: ignore event 0x6017 (Jarod Wilson) [1807052]
- [wireless] ath11k: add RX stats support for radiotap (Jarod Wilson) [1807052]
- [wireless] ath11k: driver for Qualcomm IEEE 802.11ax devices (Jarod Wilson) [1807052]
- [wireless] ath10k: fix RX of frames with broken FCS in monitor mode (Jarod Wilson) [1807052]
- [wireless] ath10k: report rssi of each chain to mac80211 for sdio (Jarod Wilson) [1807052]
- [wireless] ath10k: Handle "invalid" BDFs for msm8998 devices (Jarod Wilson) [1807052]
- [wireless] ath10k: Fix qmi init error handling (Jarod Wilson) [1807052]
- [wireless] ath10k: add NL80211_FEATURE_ND_RANDOM_MAC_ADDR for NLO (Jarod Wilson) [1807052]
- [wireless] ath10k: Handle when FW doesn't support QMI_WLFW_HOST_CAP_REQ_V01 (Jarod Wilson) [1807052]
- [wireless] ath10k: add large size for BMI download data for SDIO (Jarod Wilson) [1807052]
- [wireless] ath10k: correct the tlv len of ath10k_wmi_tlv_op_gen_config_pno_start (Jarod Wilson) [1807052]
- [wireless] ath10k: sdio: remove struct ath10k_sdio_rx_data::status (Jarod Wilson) [1807052]
- [wireless] ath10k: sdio: cosmetic cleanup (Jarod Wilson) [1807052]
- [wireless] ath10k: add workqueue for RX path of sdio (Jarod Wilson) [1807052]
- [wireless] ath10k: change max RX bundle size from 8 to 32 for sdio (Jarod Wilson) [1807052]
- [wireless] ath10k: enable RX bundle receive for sdio (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: don't send the IWL_MVM_RXQ_NSSN_SYNC notif to Rx queues (Jarod Wilson) [1807052]
- [net] cfg80211: fix page refcount issue in A-MSDU decap (Jarod Wilson) [1807052]
- [net] cfg80211: check for set_wiphy_params (Jarod Wilson) [1807052]
- [net] cfg80211: fix memory leak in cfg80211_cqm_rssi_update (Jarod Wilson) [1807052]
- [net] cfg80211: fix memory leak in nl80211_probe_mesh_link (Jarod Wilson) [1807052]
- [net] cfg80211: fix deadlocks in autodisconnect work (Jarod Wilson) [1807052]
- [net] wireless: wext: avoid gcc -O3 warning (Jarod Wilson) [1807052]
- [net] mac80211: Fix TKIP replay protection immediately after key setup (Jarod Wilson) [1807052]
- [net] cfg80211: Fix radar event during another phy CAC (Jarod Wilson) [1807052]
- [net] wireless: fix enabling channel 12 for custom regulatory domain (Jarod Wilson) [1807052]
- [net] mac80211: mesh: restrict airtime metric to peered established plinks (Jarod Wilson) [1807052]
- [wireless] Revert "iwlwifi: mvm: fix scan config command size" (Jarod Wilson) [1807052]
- [wireless] iwlwifi: fw: make pos static in iwl_sar_get_ewrd_table() loop (Jarod Wilson) [1807052]
- [wireless] iwlwifi: remove lar_disable module parameter (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg: force stop the debug monitor HW (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: always disable L0S states (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: rename L0S_ENABLED bit to L0S_DISABLED (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix potential SKB leak on TXQ TX (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix SKB leak on invalid queue (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: extend hardware workaround to context-info (Jarod Wilson) [1807052]
- [wireless] iwlwifi: Don't ignore the cap field upon mcc update (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: report TX rate to mac80211 directly for RS offload (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix NVM check for 3168 devices (Jarod Wilson) [1807052]
- [wireless] iwlwifi: fix TLV fragment allocation loop (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: allocate smaller dev_cmd for TX headers (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: detect the DMA bug and warn if it happens (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: work around DMA hardware bug (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: move page tracking into get_page_hdr() (Jarod Wilson) [1807052]
- [wireless] iwlwifi: don't send PPAG command if disabled (Jarod Wilson) [1807052]
- [wireless] mt76: Off by one in mt76_calc_rx_airtime() (Jarod Wilson) [1807052]
- [wireless] mt76: fix LED link time failure (Jarod Wilson) [1807052]
- [net] mac80211: Turn AQL into an NL80211_EXT_FEATURE (Jarod Wilson) [1807052]
- [net] mac80211: airtime: Fix an off by one in ieee80211_calc_rx_airtime() (Jarod Wilson) [1807052]
- [net] cfg80211: fix double-free after changing network namespace (Jarod Wilson) [1807052]
- [net] mac80211: fix TID field in monitor mode transmit (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: move power gating workaround earlier in the flow (Jarod Wilson) [1807052]
- [wireless] Revert "iwlwifi: assign directly to iwl_trans->cfg in QuZ detection" (Jarod Wilson) [1807052]
- [wireless] wireles: Use sizeof_field() macro (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x0: fix default mac address overwrite (Jarod Wilson) [1807052]
- [wireless] ath9k: use iowrite32 over __raw_writel (Jarod Wilson) [1807052]
- [net] mac80211: Use Airtime-based Queue Limits (AQL) on packet dequeue (Jarod Wilson) [1807052]
- [net] mac80211: Implement Airtime-based Queue Limit (AQL) (Jarod Wilson) [1807052]
- [net] mac80211: Import airtime calculation code from mt76 (Jarod Wilson) [1807052]
- [net] mac80211: consider QoS Null frames for STA_NULLFUNC_ACKED (Jarod Wilson) [1807052]
- [net] mac80211: expose HW conf flags through debugfs (Jarod Wilson) [1807052]
- [net] mac80211: Add new sta_info getter by sta/vif addrs (Jarod Wilson) [1807052]
- [net] mac80211: add a comment about monitor-to-dev injection (Jarod Wilson) [1807052]
- [wireless] drivers: net: Fix Kconfig indentation, continued (Jarod Wilson) [1807052]
- [wireless] mt76: fix fix ampdu locking (Jarod Wilson) [1807052]
- [wireless] mt76: mt76u: fix endpoint definition order (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: read {tx,rx} mask from eeprom (Jarod Wilson) [1807052]
- [wireless] mt76: move mt76_get_antenna in mt76_core module (Jarod Wilson) [1807052]
- [wireless] mt76: fix possible out-of-bound access in mt7615_fill_txs/mt7603_fill_txs (Jarod Wilson) [1807052]
- [wireless] Revert "mt76: mt76x0e: don't use hw encryption for MT7630E" (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: disable radar pattern detector during scanning (Jarod Wilson) [1807052]
- [wireless] mt76: move interface_modes definition in mt76_core module (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: add ibss support (Jarod Wilson) [1807052]
- [wireless] mt76: move SUPPORTS_REORDERING_BUFFER hw property in mt76_register_device (Jarod Wilson) [1807052]
- [wireless] mt76: use mt76_dev in mt76_is_{mmio,usb} (Jarod Wilson) [1807052]
- [wireless] mt76: Remove set but not used variable 'idx' (Jarod Wilson) [1807052]
- [wireless] mt76: mt76u: rely on a dedicated stats workqueue (Jarod Wilson) [1807052]
- [wireless] mt76: mt76u: rely on usb_interface instead of usb_dev (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: remove unneeded semicolon (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x0: remove 350ms delay in mt76x0_phy_calibrate (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x02u: update ewma pkt len in mt76x02u_tx_prepare_skb (Jarod Wilson) [1807052]
- [wireless] mt76: remove obsolete .add_buf() from struct mt76_queue_ops (Jarod Wilson) [1807052]
- [wireless] mt76: add sanity check for a-mpdu rx wcid index (Jarod Wilson) [1807052]
- [wireless] mt76: refactor cc_lock locking scheme (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x0: eeprom: add support for MAC address from OF (Jarod Wilson) [1807052]
- [wireless] mt76: avoid enabling interrupt if NAPI poll is still pending (Jarod Wilson) [1807052]
- [wireless] mt76: fix aggregation stop issue (Jarod Wilson) [1807052]
- [wireless] mt76: drop rcu read lock in mt76_rx_aggr_stop (Jarod Wilson) [1807052]
- [wireless] mt76: add missing locking around ampdu action (Jarod Wilson) [1807052]
- [wireless] mt76: do not use devm API for led classdev (Jarod Wilson) [1807052]
- [wireless] mt76: enable airtime fairness (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: track tx/rx airtime for airtime fairness (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: introduce mt7615_mac_wtbl_update routine (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: fix survey channel busy time (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: report tx_time, bss_rx and busy time to mac80211 (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x02: track approximate tx airtime for airtime fairness and survey (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x02: move MT_CH_TIME_CFG init to mt76x02_mac_cc_reset (Jarod Wilson) [1807052]
- [wireless] mt76: unify channel survey update code (Jarod Wilson) [1807052]
- [wireless] mt76: mt7603: switch to a different counter for survey busy time (Jarod Wilson) [1807052]
- [wireless] mt76: mt7603: track tx airtime for airtime fairness and survey (Jarod Wilson) [1807052]
- [wireless] mt76: track rx airtime for airtime fairness and survey (Jarod Wilson) [1807052]
- [wireless] mt76: store current channel survey_state in struct mt76_dev (Jarod Wilson) [1807052]
- [wireless] mt76: rename mt76_driver_ops txwi_flags to drv_flags and include tx aligned4 (Jarod Wilson) [1807052]
- [wireless] mt76: report rx a-mpdu subframe status (Jarod Wilson) [1807052]
- [wireless] mt76: mt7603: remove q_rx field from struct mt7603_dev (Jarod Wilson) [1807052]
- [wireless] mt76: mt7603: collect aggregation stats (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: collect aggregation stats (Jarod Wilson) [1807052]
- [wireless] mt76: move aggr_stats array in mt76_dev (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: add queue entry in debugfs (Jarod Wilson) [1807052]
- [wireless] mt76: move queue debugfs entry to driver specific code (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x02u: move mt76x02u_mac_start in mt76x02-usb module (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x0u: reset counter starting the device (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x2: move mt76x02_mac_reset_counters in mt76x02_mac_start (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x02: move mac_reset_counter in mt76x02_lib module (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: enable SCS by default (Jarod Wilson) [1807052]
- [wireless] mt76: mt76x0e: make array mt76x0_chan_map static const, makes object smaller (Jarod Wilson) [1807052]
- [wireless] mt76: usb: add lockdep_assert_held in __mt76u_vendor_request (Jarod Wilson) [1807052]
- [wireless] mt76: remove empty flag in mt76_txq_schedule_list (Jarod Wilson) [1807052]
- [wireless] mt76: use cancel_delayed_work_sync in mt76_rx_aggr_shutdown (Jarod Wilson) [1807052]
- [wireless] mt76: remove aggr_work field from struct mt76_wcid (Jarod Wilson) [1807052]
- [wireless] mt76: mt7615: fix control frame rx in monitor mode (Jarod Wilson) [1807052]
- [wireless] iwlwifi: bump FW API to 52 for 22000 series (Jarod Wilson) [1807052]
- [wireless] iwlwifi: check kasprintf() return value (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: remove outdated comment referring to wake lock (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: trace IOVA for iwlwifi_dev_tx_tb (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dvm: excessive if in rs_bt_update_lq() (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: Report tx/rx antennas (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: rx: use rxq queue_size instead of constant (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: remove left-over non-functional email alias (Jarod Wilson) [1807052]
- [wireless] iwlwifi: config: remove max_rx_agg_size (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: make some RX functions static (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: support scan req FW API ver 13 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: fix support for transmitting SKBs with fraglist (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: Remove set but not used variable 'vif', 'dev', 'len' (Jarod Wilson) [1807052]
- [wireless] brcmfmac: remove monitor interface when detaching (Jarod Wilson) [1807052]
- [wireless] brcmfmac: disable PCIe interrupts before bus reset (Jarod Wilson) [1807052]
- [wireless] rtw88: allows to enable/disable HCI link PS mechanism (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: enable CLKREQ function if host supports it (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: use for loop instead of while loop for DBI/MDIO (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: use macros to access PCI DBI/MDIO registers (Jarod Wilson) [1807052]
- [wireless] rtlwifi: set proper udelay within rf_serial_read (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rf_lock use non-irqsave spin_lock (Jarod Wilson) [1807052]
- [wireless] brcmfmac: remove set but not used variable 'mpnum', 'nsp', 'nmp' (Jarod Wilson) [1807052]
- [wireless] rtw88: remove duplicated include from ps.c (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: Remove set but not used variable 'rsr' (Jarod Wilson) [1807052]
- [wireless] brcmsmac: remove unnecessary return (Jarod Wilson) [1807052]
- [wireless] net: wireless: ti: remove local VENDOR_ID and DEVICE_ID definitions (Jarod Wilson) [1807052]
- [wireless] net: wireless: ti: wl1251 use new SDIO_VENDOR_ID_TI_WL1251 definition (Jarod Wilson) [1807052]
- [wireless] net: wireless: ti: wl1251 add device tree support (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix non-ACPI function (Jarod Wilson) [1807052]
- [wireless] iwlwifi: 22000: fix some indentation (Jarod Wilson) [1807052]
- [wireless] iwlwifi: remove IWL_DEVICE_22560/IWL_DEVICE_FAMILY_22560 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: sync the iwl_mvm_session_prot_notif layout (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: start CTDP budget from 2400mA (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: don't skip mgmt tid when flushing all tids (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: scan: enable adaptive dwell in p2p (Jarod Wilson) [1807052]
- [wireless] iwlwifi: refactor the SAR tables from mvm to acpi (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: support scan req cmd ver 12 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: make new scan req versioning flow (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix unaligned read of rx_pkt_status (Jarod Wilson) [1807052]
- [wireless] iwlwifi: remove redundant assignment to variable bufsz (Jarod Wilson) [1807052]
- [wireless] iwlwifi: bump FW API to 51 for 22000 series (Jarod Wilson) [1807052]
- [wireless] iwlwifi: FW API: reference enum in docs of modify_mask (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: print rate_n_flags in a pretty format (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: adapt the code to use api ver 11 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: Create function to build scan cmd (Jarod Wilson) [1807052]
- [wireless] iwlwifi: scan: create function for scan scheduling params (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: support dump collection upon assert during D3 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: pcie: make iwl_pcie_gen2_update_byte_tbl static (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: in VHT connection use only VHT capabilities (Jarod Wilson) [1807052]
- [wireless] iwlwifi: nvm: update iwl_uhb_nvm_channels (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: remove else-if in iwl_send_phy_cfg_cmd() (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix support for single antenna diversity (Jarod Wilson) [1807052]
- [wireless] ath10k: qmi: Sleep for a while before assigning MSA memory (Jarod Wilson) [1807052]
- [wireless] ath10k: Revert "ath10k: add cleanup in ath10k_sta_state()" (Jarod Wilson) [1807052]
- [wireless] mwifiex: Re-work support for SDIO HW reset (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: Add support for Edimax EW-7611ULB (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Fix missing enable interrupt flag (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Fix missing callback that tests for hw release of buffer (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192de: Fix missing code to retrieve RX buffer address (Jarod Wilson) [1807052]
- [net] mac80211: Use debugfs_create_xul() helper (Jarod Wilson) [1807052]
- [net] cfg80211: VLAN offload support for set_key and set_sta_vlan (Jarod Wilson) [1807052]
- [net] mac80211: Shrink the size of ack_frame_id to make room for tx_time_est (Jarod Wilson) [1807052]
- [net] mac80211: don't re-parse elems in ieee80211_assoc_success() (Jarod Wilson) [1807052]
- [net] mac80211: move store skb ack code to its own function (Jarod Wilson) [1807052]
- [wireless] ath10k: disable cpuidle during downloading firmware (Jarod Wilson) [1807052]
- [wireless] ath10k: fix potential issue of peer stats allocation (Jarod Wilson) [1807052]
- [wireless] ath10k: fix get invalid tx rate for Mesh metric (Jarod Wilson) [1807052]
- [wireless] rtw88: signal completion even on firmware-request failure (Jarod Wilson) [1807052]
- [wireless] rtw88: fix potential NULL pointer access for firmware (Jarod Wilson) [1807052]
- [wireless] rtlwifi: fix memory leak in rtl92c_set_fw_rsvdpagepkt() (Jarod Wilson) [1807052]
- [wireless] rt2800: remove errornous duplicate condition (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8225se: remove some unused const variables (Jarod Wilson) [1807052]
- [wireless] brcmsmac: remove set but not used variables (Jarod Wilson) [1807052]
- [wireless] rtw88: raise LPS threshold to 50, for less power consumption (Jarod Wilson) [1807052]
- [wireless] ath5k: eeprom: Remove unneeded variable (Jarod Wilson) [1807052]
- [wireless] ath10k: remove unneeded semicolon (Jarod Wilson) [1807052]
- [wireless] mt7601u: use DEFINE_DEBUGFS_ATTRIBUTE to define debugfs fops (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8821ae: Drop condition with no effect (Jarod Wilson) [1807052]
- [wireless] b43: dma: Fix use true/false for bool type variable (Jarod Wilson) [1807052]
- [wireless] b43: main: Fix use true/false for bool type (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192c: Drop condition with no effect (Jarod Wilson) [1807052]
- [wireless] rtw88: remove redundant null pointer check on arrays (Jarod Wilson) [1807052]
- [wireless] rtw88: avoid FW info flood (Jarod Wilson) [1807052]
- [wireless] rtw88: fix potential read outside array boundary (Jarod Wilson) [1807052]
- [wireless] rtw88: rearrange if..else statements for rx rate indexes (Jarod Wilson) [1807052]
- [wireless] rtw88: use rtw_phy_pg_cfg_pair struct, not arrays (Jarod Wilson) [1807052]
- [wireless] rtw88: 8822b: add RFE type 3 support (Jarod Wilson) [1807052]
- [wireless] rtw88: fix sparse warnings for power tracking (Jarod Wilson) [1807052]
- [wireless] rtw88: fix sparse warnings for DPK (Jarod Wilson) [1807052]
- [wireless] net: Fix various misspellings of "connect" (Jarod Wilson) [1807052]
- [wireless] net: Fix misspellings of "configure" and "configuration" (Jarod Wilson) [1807052]
- [wireless] rtw88: fix GENMASK_ULL for u64 (Jarod Wilson) [1807052]
- [wireless] iwlwifi: rx: use new api to get band from rx mpdu (Jarod Wilson) [1807052]
- [wireless] iwlwifi: nvm: create function to convert channel index to nl80211_band (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: Invert the condition for OFDM rate (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: create function to convert nl80211 band to phy band (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: use vzalloc to allocate dumping memory regions (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: add user trigger support (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: add notification for missed VAP (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: fix old-style declaration (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: use the new session protection command (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: remove leftover rs_remove_sta_debugfs() prototype (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: add support for new version for D0I3_END_CMD (Jarod Wilson) [1807052]
- [wireless] iwlwifi: mvm: consider ieee80211 station max amsdu value (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: support FW notification dumping in case of missed beacon (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: remove old API and some related code (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: rename external debug configuration file (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: support FW response/notification region type (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: support domain changing via debugfs (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: add periodic trigger new API support (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: implement monitor allocation flow (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: implement time point handling (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: add TLV allocation new API support (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: use new API in dump info (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: add error tables dumping support (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: add monitor dumping support (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg: remove multi buffers infra (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: use new trigger TLV in dump flow (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: use new region TLV in dump flow (Jarod Wilson) [1807052]
- [wireless] iwlwifi: dbg_ini: load external dbg cfg after internal cfg is loaded (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: fix warnings for symbol not declared (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: remove set but not used variable 'rate_mask' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: Remove unnecessary NULL check in rtl_regd_init (Jarod Wilson) [1807052]
- [wireless] rtw88: add phy_info debugfs to show Tx/Rx physical status (Jarod Wilson) [1807052]
- [wireless] rtw88: add set_bitrate_mask support (Jarod Wilson) [1807052]
- [wireless] rtw88: Enable 802.11ac beamformee support (Jarod Wilson) [1807052]
- [wireless] rtw88: add power tracking support (Jarod Wilson) [1807052]
- [wireless] rtw88: use macro to check the current band (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: fix RTL8723BU connection failure issue after warm reboot (Jarod Wilson) [1807052]
- [wireless] rtw88: mark rtw_fw_hdr __packed (Jarod Wilson) [1807052]
- [wireless] net/wireless: Delete unnecessary checks before the macro call "dev_kfree_skb" (Jarod Wilson) [1807052]
- [wireless] wireless: Remove call to memset after dma_alloc_coherent (Jarod Wilson) [1807052]
- [wireless] rtw88: include interrupt.h for tasklet_struct (Jarod Wilson) [1807052]
- [wireless] rtw88: use a for loop in rtw_power_mode_change(), not goto (Jarod Wilson) [1807052]
- [wireless] rtw88: coex: Set 4 slot mode for A2DP (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: config phy after chip info is setup (Jarod Wilson) [1807052]
- [wireless] rtw88: Use rtw_write8_set to set SYS_FUNC (Jarod Wilson) [1807052]
- [wireless] rtw88: add NL80211_EXT_FEATURE_CAN_REPLACE_PTK0 support (Jarod Wilson) [1807052]
- [wireless] rtw88: config 8822c multicast address in MAC init flow (Jarod Wilson) [1807052]
- [wireless] ath10k: Correct error handling of dma_map_single() (Jarod Wilson) [1807052]
- [wireless] ath: rename regulatory rules (Jarod Wilson) [1807052]
- [wireless] ath10k: fix memory leak for tpc_stats_final (Jarod Wilson) [1807052]
- [wireless] ath10k: fix array out-of-bounds access (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192se: Convert inline routines to little-endian words (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192se: Convert macros that set descriptor (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192se: Replace local bit manipulation macros (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192se: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: Remove set but not used variable 'err' (Jarod Wilson) [1807052]
- [wireless] ath10k: fix null dereference on pointer crash_data (Jarod Wilson) [1807052]
- [wireless] ath10k: enable transmit data ack RSSI for QCA9884 (Jarod Wilson) [1807052]
- [net] mac80211: minstrel_ht: rename prob_ewma to prob_avg, use it for the new average (Jarod Wilson) [1807052]
- [net] mac80211: minstrel_ht: replace rate stats ewma with a better moving average (Jarod Wilson) [1807052]
- [net] mac80211: minstrel: remove divisions in tx status path (Jarod Wilson) [1807052]
- [net] nl80211: trivial: Remove redundant loop (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: Remove set but not used variable 'cur_tx_wp' (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: make arrays static, makes object smaller (Jarod Wilson) [1807052]
- [wireless] rtw88: Fix an error message (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: add bluetooth co-existence support for single antenna (Jarod Wilson) [1807052]
- [wireless] mwifiex: pcie: Fix memory leak in mwifiex_pcie_alloc_cmdrsp_buf (Jarod Wilson) [1829230 1807052] {CVE-2019-19056}
- [wireless] rtlwifi: rtl8723: Remove set but not used variable 'own' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: btcoex: Remove set but not used variables 'wifi_busy', 'bt_info_ext' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: btcoex: Remove set but not used variable 'result' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8188ee: Remove set but not used variable 'h2c_parameter' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8188ee: Remove set but not used variables 'v3', 'rtstatus', 'reg_ecc', 'reg_ec4', 'reg_eac', 'b_pathb_ok' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192c: Remove set but not used variables 'reg_ecc', 'reg_eac' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723ae: Remove set but not used variables 'reg_ecc', 'reg_ec4', 'reg_eac', 'b_pathb_ok' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8821ae: Remove set but not used variables 'rtstatus', 'bd' (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: Improve TX performance of RTL8723BU on rtl8xxxu driver (Jarod Wilson) [1807052]
- [wireless] brcmfmac: add support for SAE authentication offload (Jarod Wilson) [1807052]
- [wireless] rtw88: fix error handling when setup efuse info (Jarod Wilson) [1807052]
- [wireless] rtw88: fix NSS of hw_cap (Jarod Wilson) [1807052]
- [wireless] rtw88: use struct rtw_fw_hdr to access firmware header (Jarod Wilson) [1807052]
- [wireless] rtw88: raise firmware version debug level (Jarod Wilson) [1807052]
- [wireless] rtw88: configure TX queue EDCA parameters (Jarod Wilson) [1807052]
- [wireless] rtw88: Don't set RX_FLAG_DECRYPTED if packet has no encryption (Jarod Wilson) [1807052]
- [wireless] rtw88: fix beaconing mode rsvd_page memory violation issue (Jarod Wilson) [1807052]
- [wireless] rtw88: flush hardware tx queues (Jarod Wilson) [1807052]
- [wireless] rtw88: add TX-AMSDU support (Jarod Wilson) [1807052]
- [wireless] rtw88: report tx rate to mac80211 stack (Jarod Wilson) [1807052]
- [wireless] rtw88: take over rate control from mac80211 (Jarod Wilson) [1807052]
- [wireless] rtw88: add driver TX queue support (Jarod Wilson) [1807052]
- [wireless] rtw88: allows to set RTS in TX descriptor (Jarod Wilson) [1807052]
- [wireless] rtw88: check firmware leave lps successfully (Jarod Wilson) [1807052]
- [wireless] mac80211: simplify TX aggregation start (Jarod Wilson) [1807052]
- [net] mac80211: pass internal sta to ieee80211_tx_frags() (Jarod Wilson) [1807052]
- [net] mac80211: IBSS: avoid unneeded return value processing (Jarod Wilson) [1807052]
- [wireless] ar5523: check NULL before memcpy() in ar5523_cmd() (Jarod Wilson) [1807052]
- [wireless] ath10k: add support for hardware rfkill (Jarod Wilson) [1807052]
- [wireless] ath10k: restore QCA9880-AR1A (v1) detection (Jarod Wilson) [1807052]
- [wireless] ath10k: fix offchannel tx failure when no ath10k_mac_tx_frm_has_freq (Jarod Wilson) [1807052]
- [wireless] cw1200: Fix a signedness bug in cw1200_load_firmware() (Jarod Wilson) [1807052]
- [wireless] rtw88: remove misleading module parameter rtw_fw_support_lps (Jarod Wilson) [1807052]
- [wireless] rtw88: add deep PS PG mode for 8822c (Jarod Wilson) [1807052]
- [wireless] rtw88: select deep PS mode when module is inserted (Jarod Wilson) [1807052]
- [wireless] rtw88: not to enter LPS by coex strategy (Jarod Wilson) [1807052]
- [wireless] rtw88: add deep power save support (Jarod Wilson) [1807052]
- [wireless] rtw88: leave PS state for dynamic mechanism (Jarod Wilson) [1807052]
- [wireless] rtw88: LPS enter/leave should be protected by lock (Jarod Wilson) [1807052]
- [wireless] rtw88: remove unused lps state check helper (Jarod Wilson) [1807052]
- [wireless] rtw88: not to control LPS by each vif (Jarod Wilson) [1807052]
- [wireless] rtw88: not to enter or leave PS under IRQ (Jarod Wilson) [1807052]
- [wireless] rtw88: pci: reset H2C queue indexes in a single write (Jarod Wilson) [1807052]
- [wireless] rtw88: remove redundant flag check helper function (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8723be: Remove set but not used variables 'reg_ecc', 'reg_eac' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: Remove set but not used variables 'reg_ecc', 'reg_eac' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: rtl8192ee: Remove set but not used variables 'short_gi', 'buf_len' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: Remove set but not used variables 'dataempty', 'hoffset' (Jarod Wilson) [1807052]
- [wireless] rtlwifi: Remove set but not used variable 'rtstate' (Jarod Wilson) [1807052]
- [wireless] rtl8xxxu: prevent leaking urb (Jarod Wilson) [1829887 1807052] {CVE-2019-19068}
- [wireless] net/wireless: Use kmemdup rather than duplicating its implementation (Jarod Wilson) [1807052]
- [wireless] ath9k_htc: Discard undersized packets (Jarod Wilson) [1807052]
- [wireless] ath9k_htc: Modify byte order for an error message (Jarod Wilson) [1807052]
- [wireless] ath9k_hw: fix uninitialized variable data (Jarod Wilson) [1807052]
- [wireless] ath10k: fix backtrace on coredump (Jarod Wilson) [1807052]
- [wireless] ath10k: coredump: fix IRAM addr for QCA9984, QCA4019, QCA9888 and QCA99x0 (Jarod Wilson) [1807052]
- [wireless] ath10k: switch to ieee80211_tx_dequeue_ni (Jarod Wilson) [1807052]
- [wireless] ath10k: change sw version print format to hex (Jarod Wilson) [1807052]
- [wireless] ath10k: print supported MCS rates within service ready event (Jarod Wilson) [1807052]
- [wireless] ath10k: print service ready returned channel range (Jarod Wilson) [1807052]
- [wireless] ath10k: add 2ghz channel arguments to service ready structure (Jarod Wilson) [1807052]
- [wireless] ath9k: remove unused including <linux/version.h> (Jarod Wilson) [1807052]
- [wireless] mwifiex: use 'total_ie_len' in mwifiex_update_bss_desc_with_ie() (Jarod Wilson) [1807052]
- [wireless] rtlwifi: Remove excessive check in _rtl_ps_inactive_ps() (Jarod Wilson) [1807052]
- [wireless] rtlwifi: prevent memory leak in rtl_usb_probe (Jarod Wilson) [1829850 1807052] {CVE-2019-19063}
- [wireless] rtlwifi: rtl8723ae: Remove unused 'rtstatus' variable (Jarod Wilson) [1807052]
- [wireless] mt7601u: fix bbp version check in mt7601u_wait_bbp_ready (Jarod Wilson) [1807052]
- [wireless] rtw88: 8822c: fix boolreturn.cocci warnings (Jarod Wilson) [1807052]
- [wireless] brcmsmac: remove duplicated if condition (Jarod Wilson) [1807052]
- [wireless] brcmfmac: fix suspend/resume when power is cut off (Jarod Wilson) [1807052]
- [wireless] brcmfmac: don't WARN when there are no requests (Jarod Wilson) [1807052]
- [wireless] brcmsmac: remove a useless test (Jarod Wilson) [1807052]
- [wireless] brcmfmac: send port authorized event for FT-802.1X (Jarod Wilson) [1807052]
- [wireless] ath10k: fix memory leak (Jarod Wilson) [1807052]
- [wireless] ath10k: remove the warning of sdio not full support (Jarod Wilson) [1807052]
- [wireless] ath: Use dev_get_drvdata where possible (Jarod Wilson) [1807052]
- [wireless] ath: fix various spelling mistakes (Jarod Wilson) [1807052]
- [wireless] ath10k: fix missing checks for bmi reads and writes (Jarod Wilson) [1807052]
- [wireless] ath10k: Add support to provide higher range mem chunks in wmi init command (Jarod Wilson) [1807052]
- [wireless] ath10k: Add peer param map for tlv and non-tlv (Jarod Wilson) [1807052]
- [wireless] ath10k: Enable MSA region dump support for WCN3990 (Jarod Wilson) [1807052]
- [wireless] ath10k: Add xo calibration support for wifi rf clock (Jarod Wilson) [1807052]
- [wireless] ath10k: fix spelling mistake "eanble" -> "enable" (Jarod Wilson) [1807052]
- [wireless] ath10k: add cleanup in ath10k_sta_state() (Jarod Wilson) [1807052]
- [wireless] ath10k: revalidate the msa region coming from firmware (Jarod Wilson) [1807052]
- [wireless] ath10k: use ath10k_pci_soc_ functions for all warm_reset instances (Jarod Wilson) [1807052]
- [wireless] ath10k: Use ARRAY_SIZE (Jarod Wilson) [1807052]
- [wireless] ath10k: avoid leaving .bss_info_changed prematurely (Jarod Wilson) [1807052]
- [wireless] ath10k: Use standard bulk clock API in snoc (Jarod Wilson) [1807052]
- [wireless] ath10k: Use standard regulator bulk API in snoc (Jarod Wilson) [1807052]
- [wireless] ath10k: snoc: skip regulator operations (Jarod Wilson) [1807052]
- [wireless] ath10k: Fix HOST capability QMI incompatibility (Jarod Wilson) [1807052]
- [wireless] ath10k: Check if station exists before forwarding tx airtime report (Jarod Wilson) [1807052]
- [include] include/linux/units.h: add helpers for kelvin to/from Celsius conversion (Jarod Wilson) [1807052]

* Tue May 12 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-198.el8]
- [x86] x86/PCI: Define to_pci_sysdata() even when !CONFIG_PCI (Myron Stowe) [1788364 1783436]
- [pci] PCI: vmd: Add two VMD Device IDs (Myron Stowe) [1788364 1783436]
- [pci] x86/PCI: Expose VMD's pci_dev in struct pci_sysdata (Myron Stowe) [1788364 1783436]
- [x86] x86/PCI: Add to_pci_sysdata() helper (Myron Stowe) [1788364 1783436]
- [pci] PCI: vmd: Add device id for VMD device 8086:9A0B (Myron Stowe) [1788364 1783436]
- [pci] PCI: vmd: Add bus 224-255 restriction decode (Myron Stowe) [1788364 1783436]
- [fs] fuse: copy_file_range needs to strip setuid bits and update timestamps (Eric Sandeen) [1721881]
- [fs] vfs: allow copy_file_range to copy across devices (Eric Sandeen) [1721881]
- [fs] vfs: add missing checks to copy_file_range (Eric Sandeen) [1721881]
- [mm] vfs: remove redundant checks from generic_remap_checks() (Eric Sandeen) [1721881]
- [fs] vfs: introduce generic_file_rw_checks() (Eric Sandeen) [1721881]
- [fs] vfs: no fallback for ->copy_file_range (Eric Sandeen) [1721881]
- [fs] vfs: introduce generic_copy_file_range() (Eric Sandeen) [1721881]
- [ptp] ptp: add VMware virtual PTP clock driver (Prarit Bhargava) [1829706]
- [powerpc] powerpc/powernv/ioda: Handle failures correctly in pnv_pci_ioda_iommu_bypass_supported() (Michael Roth) [1805101]
- [powerpc] powerpc/pseries/dma: Enable SWIOTLB (Michael Roth) [1805101]
- [powerpc] powerpc/pseries/dma: Allow SWIOTLB (Michael Roth) [1805101]
- [powerpc] powerpc/powernv: Fix build with IOMMU_API=n (Michael Roth) [1805101]
- [powerpc] powerpc/powernv: Remove unused pnv_npu_try_dma_set_bypass() function (Michael Roth) [1805101]
- [powerpc] powerpc/dma: Fix invalid DMA mmap behavior (Michael Roth) [1805101]
- [powerpc] powerpc/dma: trim the fat from <asm/dma-mapping.h> (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove set_dma_offset (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove get_dma_offset (Michael Roth) [1805101]
- [powerpc] powerpc/dma: use the generic direct mapping bypass (Michael Roth) [1805101]
- [powerpc] powerpc/powernv/npu: Remove NPU DMA ops (Michael Roth) [1805101]
- [powerpc] powerpc/dma: use the dma_direct mapping routines (Michael Roth) [1805101]
- [powerpc] powerpc/dma: use the dma-direct allocator for coherent platforms (Michael Roth) [1805101]
- [powerpc] swiotlb: remove swiotlb_dma_supported (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove dma_nommu_dma_supported (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove dma_nommu_get_required_mask (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove dma_nommu_mmap_coherent (Michael Roth) [1805101]
- [powerpc] powerpc/dma: use phys_to_dma instead of get_dma_offset (Michael Roth) [1805101]
- [powerpc] dma-mapping, powerpc: simplify the arch dma_set_mask override (Michael Roth) [1805101]
- [powerpc] powerpc/dma: fix an off-by-one in dma_capable (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove max_direct_dma_addr (Michael Roth) [1805101]
- [powerpc] powerpc/dma: move pci_dma_dev_setup_swiotlb to fsl_pci.c (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove get_pci_dma_ops (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove the iommu fallback for coherent allocations (Michael Roth) [1805101]
- [powerpc] powerpc/pci: remove the dma_set_mask pci_controller ops methods (Michael Roth) [1805101]
- [misc] cxl: drop the dma_set_mask callback from vphb (Michael Roth) [1805101]
- [powerpc] KABI: re-use deprecated field for iommu_bypass_supported function pointer (Michael Roth) [1805101]
- [powerpc] powerpc/dma: stop overriding dma_get_required_mask (Michael Roth) [1805101]
- [dma] KABI: add fake includes for headers used in arch/powerpc/kernel/dma.c (Michael Roth) [1805101]
- [powerpc] powerpc/powernv: use the generic iommu bypass code (Michael Roth) [1805101]
- [powerpc] powerpc/powernv: Remove PCI_MSI ifdef checks (Michael Roth) [1805101]
- [powerpc] powerpc/powernv: remove pnv_npu_dma_set_mask (Michael Roth) [1805101]
- [powerpc] powerpc/powernv: remove pnv_pci_ioda_pe_single_vendor (Michael Roth) [1805101]
- [powerpc] powerpc/dart: use the generic iommu bypass code (Michael Roth) [1805101]
- [powerpc] powerpc/dart: remove dead cleanup code in iommu_init_early_dart (Michael Roth) [1805101]
- [powerpc] powerpc/cell: use the generic iommu bypass code (Michael Roth) [1805101]
- [powerpc] powerpc/cell: move dma direct window setup out of dma_configure (Michael Roth) [1805101]
- [powerpc] powerpc/pseries: use the generic iommu bypass code (Michael Roth) [1805101]
- [powerpc] powerpc/pseries: unwind dma_get_required_mask_pSeriesLP a bit (Michael Roth) [1805101]
- [powerpc] powerpc/dma: handle iommu bypass in dma_iommu_ops (Michael Roth) [1805101]
- [powerpc] powerpc/dma: untangle vio_dma_mapping_ops from dma_iommu_ops (Michael Roth) [1805101]
- [dma] dma-direct: we might need GFP_DMA for 32-bit dma masks (Michael Roth) [1805101]
- [powerpc] powerpc/dma: split the two __dma_alloc_coherent implementations (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove the unused dma_iommu_ops export (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove the unused ISA_DMA_THRESHOLD export (Michael Roth) [1805101]
- [powerpc] powerpc/dma: remove the unused ARCH_HAS_DMA_MMAP_COHERENT define (Michael Roth) [1805101]
- [powerpc] powerpc/dma: properly wire up the unmap_page and unmap_sg methods (Michael Roth) [1805101]
- [powerpc] powerpc: allow NOT_COHERENT_CACHE for amigaone (Michael Roth) [1805101]
- [powerpc] powerpc/fadump: consider reserved ranges while reserving memory (Steve Best) [1813701]
- [powerpc] powerpc/fadump: use static allocation for reserved memory ranges (Steve Best) [1813701]
- [fs] audit: Report suspicious O_CREAT usage (partial) (Eric Sandeen) [1797843]
- [fs] vfs: fix do_last() regression (Eric Sandeen) [1797843]
- [fs] do_last(): fetch directory ->i_mode and ->i_uid before it's too late (Eric Sandeen) [1797843]
- [fs] namei: allow restricted O_CREAT of FIFOs and regular files (Eric Sandeen) [1797843]
- [netdrv] fm10k: use txqueue parameter in fm10k_tx_timeout (Neil Horman) [1781387]
- [netdrv] fm10k: Use sizeof_field() macro (Neil Horman) [1781387]
- [netdrv] fm10k: update driver version to match out-of-tree (Neil Horman) [1781387]
- [netdrv] fm10k: add support for ndo_get_vf_stats operation (Neil Horman) [1781387]
- [netdrv] fm10k: add missing field initializers to TLV attributes) (Neil Horman) [1781387]
- [netdrv] fm10k: use a local variable for the frag pointer (Neil Horman) [1781387]
- [netdrv] ethernet: Delete unnecessary checks before the macro call "dev_kfree_skb" (Neil Horman) [1781387]
- [netdrv] fm10k: no need to check return value of debugfs_create functions (Neil Horman) [1781387]
- [security] KEYS: Avoid false positive ENOMEM error on key read (Waiman Long) [1807693]
- [security] KEYS: Don't write out to userspace while holding key semaphore (Waiman Long) [1807693]
- [security] selinux: allow per-file labeling for CephFS (Ondrej Mosnacek) [1823764]
- [scsi] scsi: qedi: make qedi_ll2_buf_size static (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Fix termination timeouts in session logout (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Add modules param to enable qed iSCSI debug (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Do not flush offload work if ARP not resolved (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Use correct msix count for fastpath vectors (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Avoid unnecessary endpoint allocation on link down (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Remove additional char from boot target iqnname (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Add PCI shutdown handler support (Nilesh Javali) [1792111]
- [scsi] scsi: qedi: Add MFW error recovery process (Nilesh Javali) [1792111]
- [netdrv] ibmvnic: Skip fatal error reset after passive init (Steve Best) [1830989]
- [ata] ahci: Add Intel Comet Lake PCH-V PCI ID (David Milburn) [1802690]
- [ata] ahci: Add Intel Comet Lake PCH-H PCI ID (David Milburn) [1802690]
- [ata] ahci: Add Intel Comet Lake H RAID PCI ID (David Milburn) [1802690]
- [x86] x86, sched: Move check for CPU type to caller function (Prarit Bhargava) [1828260]
- [x86] x86, sched: Don't enable static key when starting secondary CPUs (Prarit Bhargava) [1828260]
- [x86] x86, sched: Account for CPUs with less than 4 cores in freq. invariance (Prarit Bhargava) [1828260]
- [x86] x86, sched: Bail out of frequency invariance if base frequency is unknown (Prarit Bhargava) [1828260]
- [lib] scsi: klist: Make it safe to use klists in atomic context (Waiman Long) [1829027]
- [char] random: try to actively add entropy rather than passively wait for it (Neil Horman) [1778762]
- [md] dm writecache: fix data corruption when reloading the target (Mike Snitzer) [1830129]
- [kernel] smp: Allow smp_call_function_single_async() to insert locked csd (Peter Xu) [1830014]
- [scsi] scsi: ibmvscsi: Fix WARN_ON during event pool release (Steve Best) [1829242]
- [block] block: avoid to check null profile pointer to see if it is in 3rd party module (Ming Lei) [1829464]
- [tools] perf scripting perl: Add common_callchain to fix argument order (Michael Petlan) [1809191]
- [netdrv] ionic: fix unused assignment (Jonathan Toppins) [1780645]
- [netdrv] ionic: add dynamic_debug header (Jonathan Toppins) [1780645]
- [netdrv] ionic: set station addr only if needed (Jonathan Toppins) [1780645]
- [netdrv] ionic: replay filters after fw upgrade (Jonathan Toppins) [1780645]
- [netdrv] ionic: remove lifs on fw reset (Jonathan Toppins) [1780645]
- [netdrv] ionic: disable the queues on link down (Jonathan Toppins) [1780645]
- [netdrv] ionic: check for queues before deleting (Jonathan Toppins) [1780645]
- [netdrv] ionic: clean tx queue of unfinished requests (Jonathan Toppins) [1780645]
- [netdrv] ionic: move irq request to qcq alloc (Jonathan Toppins) [1780645]
- [netdrv] ionic: move debugfs add/delete to match alloc/free (Jonathan Toppins) [1780645]
- [netdrv] ionic: check for linkup in watchdog (Jonathan Toppins) [1780645]
- [netdrv] ionic: decouple link message from netdev state (Jonathan Toppins) [1780645]
- [netdrv] ionic: check for NULL structs on teardown (Jonathan Toppins) [1780645]
- [netdrv] ionic: clean irq affinity on queue deinit (Jonathan Toppins) [1780645]
- [netdrv] ionic: ignore eexist on rx filter add (Jonathan Toppins) [1780645]
- [netdrv] ionic: only save good lif dentry (Jonathan Toppins) [1780645]
- [netdrv] ionic: leave dev cmd request contents alone on FW timeout (Jonathan Toppins) [1780645]
- [netdrv] ionic: add timeout error checking for queue disable (Jonathan Toppins) [1780645]
- [netdrv] ionic: make spdxcheck.py happy (Jonathan Toppins) [1780645]
- [netdrv] ionic: add decode for IONIC_RC_ENOSUPP (Jonathan Toppins) [1780645]
- [netdrv] ionic: print data for unknown xcvr type (Jonathan Toppins) [1780645]
- [netdrv] ionic: remove adminq napi instance (Jonathan Toppins) [1780645]
- [netdrv] ionic: deinit rss only if selected (Jonathan Toppins) [1780645]
- [netdrv] ionic: stop devlink warn on mgmt device (Jonathan Toppins) [1780645]
- [netdrv] net: ionic: Use scnprintf() for avoiding potential buffer overflow (Jonathan Toppins) [1780645]
- [netdrv] netdev:pass the stuck queue to the timeout handler (Jonathan Toppins) [1780645]
- [netdrv] ionic: drop ethtool driver version (Jonathan Toppins) [1780645]
- [netdrv] ionic: add support for device id 0x1004 (Jonathan Toppins) [1780645]
- [netdrv] ionic: print pci bus lane info (Jonathan Toppins) [1780645]
- [netdrv] ionic: support ethtool rxhash disable (Jonathan Toppins) [1780645]
- [netdrv] ionic: clean up bitflag usage (Jonathan Toppins) [1780645]
- [netdrv] ionic: improve irq numa locality (Jonathan Toppins) [1780645]
- [netdrv] ionic: remove pragma packed (Jonathan Toppins) [1780645]
- [netdrv] ionic: keep ionic dev on lif init fail (Jonathan Toppins) [1780645]
- [netdrv] ionic: fix vf op lock usage (Jonathan Toppins) [1780645]
- [netdrv] ionic: let core reject the unsupported coalescing parameters (Jonathan Toppins) [1780645]
- [netdrv] ionic: fix fw_status read (Jonathan Toppins) [1780645]
- [netdrv] ionic: use new helper tcp_v6_gso_csum_prep (Jonathan Toppins) [1780645]
- [netdrv] ionic: fix rxq comp packet type mask (Jonathan Toppins) [1780645]
- [netdrv] ionic: clear compiler warning on hb use before set (Jonathan Toppins) [1780645]
- [netdrv] ionic: restrict received packets to mtu size (Jonathan Toppins) [1780645]
- [netdrv] ionic: add Rx dropped packet counter (Jonathan Toppins) [1780645]
- [netdrv] ionic: drop use of subdevice tags (Jonathan Toppins) [1780645]
- [netdrv] ionic: support sr-iov operations (Jonathan Toppins) [1780645]
- [netdrv] ionic: ionic_if bits for sr-iov support (Jonathan Toppins) [1780645]
- [netdrv] ionic: keep users rss hash across lif reset (Jonathan Toppins) [1780645]
- [netdrv] ionic: Remove set but not used variable 'sg_desc' (Jonathan Toppins) [1780645]
- [netdrv] ionic: update driver version (Jonathan Toppins) [1780645]
- [netdrv] ionic: implement support for rx sgl (Jonathan Toppins) [1780645]
- [netdrv] ionic: add a watchdog timer to monitor heartbeat (Jonathan Toppins) [1780645]
- [netdrv] ionic: add heartbeat check (Jonathan Toppins) [1780645]
- [netdrv] ionic: reverse an interrupt coalesce calculation (Jonathan Toppins) [1780645]
- [netdrv] ionic: fix up struct name comments (Jonathan Toppins) [1780645]
- [netdrv] dynamic_debug: provide dynamic_hex_dump stub (Jonathan Toppins) [1780645]
- [netdrv] ionic: fix stats memory dereference (Jonathan Toppins) [1780645]
- [netdrv] ionic: add lif_quiesce to wait for queue activity to stop (Jonathan Toppins) [1780645]
- [netdrv] ionic: implement ethtool set-fec (Jonathan Toppins) [1780645]
- [netdrv] ionic: report users coalesce request (Jonathan Toppins) [1780645]
- [netdrv] ionic: use wait_on_bit_lock() rather than open code (Jonathan Toppins) [1780645]
- [netdrv] ionic: simplify returns in devlink info (Jonathan Toppins) [1780645]
- [netdrv] ionic: select CONFIG_NET_DEVLINK (Jonathan Toppins) [1780645]
- [netdrv] ionic: Fix an error code in ionic_lif_alloc() (Jonathan Toppins) [1780645]
- [netdrv] ionic: Remove unnecessary ternary operator in ionic_debugfs_add_ident (Jonathan Toppins) [1780645]
- [netdrv] ionic: Remove unused including <linux/version.h> (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add coalesce and other features (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add RSS support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add driver stats (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add netdev-event handling (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add Tx and Rx handling (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add initial ethtool support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add async link status check and basic stats (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add Rx filter and rx_mode ndo support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add management of rx filters (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add the basic NDO callbacks for netdev support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add notifyq support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add adminq action (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add basic adminq support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add interrupts and doorbells (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add basic lif support (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add port management commands (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add hardware init and device commands (Jonathan Toppins) [1780645]
- [netdrv] ionic: Add basic framework for IONIC Network device driver (Jonathan Toppins) [1780645]
- [netdrv] net: sfp: add more extended compliance codes (Jonathan Toppins) [1780645]
- [scsi] scsi: core: Add DID_ALLOC_FAILURE and DID_MEDIUM_ERROR to hostbyte_table (Maurizio Lombardi) [1819061]
- [netdrv] igc: Add debug messages to MAC filter code (Corinna Vinschen) [1781384]
- [netdrv] igc: Refactor igc_del_mac_filter() (Corinna Vinschen) [1781384]
- [netdrv] igc: Refactor igc_mac_entry_can_be_used() (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove igc_*_mac_steering_filter() wrappers (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove IGC_MAC_STATE_QUEUE_STEERING (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove 'queue' check in igc_del_mac_filter() (Corinna Vinschen) [1781384]
- [netdrv] igc: Improve address check in igc_del_mac_filter() (Corinna Vinschen) [1781384]
- [netdrv] igc: Refactor igc_rar_set_index() (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix igc_uc_unsync() (Corinna Vinschen) [1781384]
- [netdrv] igc: Change igc_add_mac_filter() returning value (Corinna Vinschen) [1781384]
- [netdrv] igc: Check unsupported flag in igc_add_mac_filter() (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove duplicate code in MAC filtering logic (Corinna Vinschen) [1781384]
- [netdrv] igc: Add new device IDs for i225 part (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix default MAC address filter override (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove dead code related to flower filter (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix NFC queue redirection support (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove copper fiber switch control (Corinna Vinschen) [1781384]
- [netdrv] igc: Enable NETIF_F_HW_TC flag (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix double definition (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix overwrites when dumping registers (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove forward declaration (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove unused CTRL_EXT_LINK_MODE_MASK (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove unused MDIC_DEST mask (Corinna Vinschen) [1781384]
- [netdrv] igc: Add support for ETF offloading (Corinna Vinschen) [1781384]
- [netdrv] igc: Add support for taprio offloading (Corinna Vinschen) [1781384]
- [netdrv] igc: Add GSO partial support (Corinna Vinschen) [1781384]
- [netdrv] net: igc: let core reject the unsupported coalescing parameters (Corinna Vinschen) [1781384]
- [netdrv] intel: Replace zero-length array with flexible-array member (Corinna Vinschen) [1781384]
- [netdrv] igc: Add comment (Corinna Vinschen) [1781384]
- [netdrv] igc: Add WOL support (Corinna Vinschen) [1781384]
- [netdrv] igc: Add pcie error handler support (Corinna Vinschen) [1781384]
- [netdrv] igc: Complete to commit Add basic skeleton for PTP (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix the typo in comment (Corinna Vinschen) [1781384]
- [netdrv] igc: Add dump options (Corinna Vinschen) [1781384]
- [netdrv] igc: Complete to commit Add legacy power management support (Corinna Vinschen) [1781384]
- [netdrv] igc: make non-global functions static (Corinna Vinschen) [1781384]
- [netdrv] igc: Add PHY power management control (Corinna Vinschen) [1781384]
- [netdrv] RHEL-only: Revert "igc: add additional delay during phy hw reset" (Corinna Vinschen) [1781384]
- [netdrv] igc: Add support for TSO (Corinna Vinschen) [1781384]
- [netdrv] igc: Add SKU for i225 device (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove unused definition (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix typo in a comment (Corinna Vinschen) [1781384]
- [netdrv] igc: Use Start of Packet signal from PHY for timestamping (Corinna Vinschen) [1781384]
- [netdrv] igc: Add support for ethtool GET_TS_INFO command (Corinna Vinschen) [1781384]
- [netdrv] igc: Add support for TX timestamping (Corinna Vinschen) [1781384]
- [netdrv] igc: Add support for RX timestamping (Corinna Vinschen) [1781384]
- [netdrv] igc: Add basic skeleton for PTP (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_sw_init (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_write_itr (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_assign_vector (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_free_q_vector (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_free_q_vectors (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_irq_disable (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_irq_enable (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_configure_msix (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_set_rx_mode (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_set_interrupt_capability (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_alloc_mapped_page (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_configure (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_set_default_mac_filter (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_power_down_link (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove no need declaration of the igc_clean_tx_ring (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove serdes comments from a description of methods (Corinna Vinschen) [1781384]
- [netdrv] igc: Add legacy power management support (Corinna Vinschen) [1781384]
- [netdrv] igc: Add 64 bit DMA access support (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix parameter descriptions for a several functions (Corinna Vinschen) [1781384]
- [netdrv] igc: Fix the parameter description for igc_alloc_rx_buffers (Corinna Vinschen) [1781384]
- [netdrv] igc: Remove excess parameter description from igc_is_non_eop (Corinna Vinschen) [1781384]
- [netdrv] igc: Prefer to use the pci_release_mem_regions method (Corinna Vinschen) [1781384]
- [netdrv] igc: Improve the DMA mapping flow (Corinna Vinschen) [1781384]
- [netdrv] igc: Add scatter gather support (Corinna Vinschen) [1781384]
- [netdrv] treewide: Use sizeof_field() macro (Corinna Vinschen) [1781384]
- [netdrv] igb/igc: use ktime accessors for skb->tstamp (Corinna Vinschen) [1781384]
- [netdrv] net: ethernet: intel: Demote MTU change prints to debug (Corinna Vinschen) [1781384]
- [netdrv] igb/igc: Don't warn on fatal read failures when the device is removed (Corinna Vinschen) [1781384]
- [netdrv] net: igb: let core reject the unsupported coalescing parameters (Corinna Vinschen) [1781381]
- [netdrv] intel: Replace zero-length array with flexible-array member (Corinna Vinschen) [1781381]
- [netdrv] igb: Fix SGMII SFP module discovery for 100FX/LX (Corinna Vinschen) [1781381]
- [netdrv] igb: dont drop packets if rx flow control is enabled (Corinna Vinschen) [1781381]
- [netdrv] treewide: Use sizeof_field() macro (Corinna Vinschen) [1781381]
- [netdrv] igb/igc: use ktime accessors for skb->tstamp (Corinna Vinschen) [1781381]
- [netdrv] net: ethernet: intel: Demote MTU change prints to debug (Corinna Vinschen) [1781381]
- [netdrv] igb: Fix constant media auto sense switching when no cable is connected (Corinna Vinschen) [1781381]
- [netdrv] igb: Enable media autosense for the i350 (Corinna Vinschen) [1781381]
- [netdrv] igb/igc: Don't warn on fatal read failures when the device is removed (Corinna Vinschen) [1781381]
- [netdrv] igb: Add UDP segmentation offload support (Corinna Vinschen) [1781381]
- [netdrv] net: igbvf: reject unsupported coalescing params (Corinna Vinschen) [1781382]
- [netdrv] net: ethernet: intel: Demote MTU change prints to debug (Corinna Vinschen) [1781382]
- [ata] ahci: Do not export local variable ahci_em_messages (Prarit Bhargava) [1826320]
- [scripts] modpost: check for static EXPORT_SYMBOL* functions (Prarit Bhargava) [1826320]
- [kernel] torture: Remove exporting of internal functions (Prarit Bhargava) [1826320]
- [input] Input: synaptics-rmi4 - remove the exporting of rmi_2d_sensor_set_input_params (Prarit Bhargava) [1826320]
- [netdrv] net: phy: make exported variables non-static (Prarit Bhargava) [1826320]
- [scsi] scsi: libsas: remove the exporting of sas_wait_eh (Prarit Bhargava) [1826320]
- [drm] drm/client: remove the exporting of drm_client_close (Prarit Bhargava) [1826320]
- [scripts] modpost: always show verbose warning for section mismatch (Prarit Bhargava) [1826320]
- [net] netfilter: nf_nat_ipv4: remove obsolete EXPORT_SYMBOL (Prarit Bhargava) [1826320]
- [crypto] crypto: skcipher - remove the exporting of skcipher_walk_next (Prarit Bhargava) [1826320]
- [scsi] scsi: scsi_debug: Fix a recently introduced regression (Ming Lei) [1822001]
- [block] scsi: block: remove bidi support (Ming Lei) [1822001]
- [scsi] scsi: block: remove req->special (Ming Lei) [1822001]
- [scsi] scsi: stop setting up request->special (Ming Lei) [1822001]
- [scsi] scsi: remove bidirectional command support (Ming Lei) [1822001]
- [scsi] scsi: remove the SCSI OSD library (Ming Lei) [1822001]
- [fs] scsi: fs: remove exofs (Ming Lei) [1822001]
- [block] scsi: bsg-lib: handle bidi requests without block layer help (Ming Lei) [1822001]
- [block] scsi: bsg: refactor bsg_ioctl (Ming Lei) [1822001]
- [netdrv] sfc: fix XDP-redirect in this driver (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: support configuring vf spoofchk on EF10 VFs (Jarod Wilson) [1796582 1788753 1684003]
- [netdrv] sfc: ethtool: Refactor to remove fallthrough comments in case blocks (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: Replace zero-length array with flexible-array member (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: remove unused variable 'efx_default_channel_type' (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: elide assignment of skb (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move some ARFS code out of headers (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: only schedule asynchronous filter work if needed (Jarod Wilson) [1796582 1788753]
- [netdrv] net: sfc: Use scnprintf() for avoiding potential buffer overflow (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: detach from cb_page in efx_copy_channel() (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: complete the next packet when we receive a timestamp (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: fix timestamp reconstruction at 16-bit rollover points (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move mcdi filtering code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: create header for mcdi filtering code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: rename mcdi filtering functions/structs (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: remove duplicated include from efx.c (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc/ethtool_common: Make some function to static (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: remove set but not used variable 'nic_data' (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: remove duplicated include from ef10.c (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move RPS code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move yet more functions (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move RSS code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move a couple more functions (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move some ethtool code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move various functions (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move more rx code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move more tx code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: refactor selftest work init code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move MCDI logging device attribute (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: conditioned some functionality (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move MCDI receive queue management code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move MCDI transmit queue management code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move MCDI event queue management code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move MCDI VI alloc/free code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move more MCDI port code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move some MCDI port utility functions (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move some port link state/caps code (Jarod Wilson) [1796582 1788753]
- [netdrv] net: sfc: use skb_list_walk_safe helper for gso segments (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move common tx code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move common rx code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move event queue management code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move channel interrupt management code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move channel alloc/removal code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move channel start/stop code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move some channel-related code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move struct init and fini code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move some device reset code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move datapath management code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move mac configuration and status functions (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: move reset workqueue code (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: further preparation for code split (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: add new headers in preparation for code split (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: remove ioremap_nocache and devm_ioremap_nocache (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: Remove unnecessary dependencies on I2C (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: avoid duplicate error handling code in 'efx_ef10_sriov_set_vf_mac()' (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: Include XDP packet headroom in buffer step size (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: fix channel allocation with brute force (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: fix build without CONFIG_RFS_ACCEL (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: do ARFS expiry work occasionally even without NAPI poll (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: add statistics for ARFS (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: suppress MCDI errors from ARFS (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: change ARFS expiry mechanism (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: Only cancel the PPS workqueue if it exists (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: trace_xdp_exception on XDP failure (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: add XDP counters to ethtool stats (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: handle XDP_TX outcomes of XDP eBPF programs (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: allocate channels for XDP tx queues (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: Enable setting of xdp_prog (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: perform XDP processing on received packets (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: support encapsulation of xdp_frames in efx_tx_buffer (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: use the new __netdev_tx_sent_queue BQL optimisation (Jarod Wilson) [1796582 1788753]
- [netdrv] net/sfc: Use skb_frag_off accessors (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: phase out dma_zalloc_coherent() (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: remove redundant variable old_vlan (Jarod Wilson) [1796582 1788753]
- [netdrv] net: sfc: Convert random_ether_addr to eth_random_addr (Jarod Wilson) [1796582 1788753]
- [netdrv] sfc: batch up RX delivery (Jarod Wilson) [1796582 1788753]
- [netdrv] net: mlx4: Use scnprintf() for avoiding potential buffer overflow (Alaa Hleihel) [1789363]
- [infiniband] IB/mlx4: Fix leak in id_map_find_del (Alaa Hleihel) [1789363]
- [infiniband] IB/mlx4: Fix memory leak in add_gid error flow (Alaa Hleihel) [1789363]
- [include] mlx4: Bump up MAX_MSIX from 64 to 128 (Alaa Hleihel) [1789363]
- [infiniband] RDMA/mlx4: use true, false for bool variable (Alaa Hleihel) [1789363]
- [infiniband] RDMA/mlx4: Redo TX checksum offload in line with docs (Alaa Hleihel) [1789363]
- [netdrv] mlx4: use new txqueue timeout argument (Alaa Hleihel) [1789363]
- [netdrv] treewide: Use sizeof_field() macro (Alaa Hleihel) [1789363 1789362]
- [infiniband] IB/mlx4: Update HW GID table while adding vlan GID (Alaa Hleihel) [1789363 1789362]
- [netdrv] net/mlx4_en: ethtool: make array modes static const, makes object smaller (Alaa Hleihel) [1789363 1789361]
- [infiniband] RDMA/mlx4: Annotate boolean arguments as bool and not int (Alaa Hleihel) [1789363 1789361]
- [netdrv] mlx4: avoid large stack usage in mlx4_init_hca() (Alaa Hleihel) [1789363 1789361]
- [infiniband] RDMA/mlx4: Untag user pointers in mlx4_get_umem_mr (Alaa Hleihel) [1789363 1789361]
- [netdrv] net: Use skb accessors in network drivers (Alaa Hleihel) [1789363 1789361]

* Thu May 07 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-197.el8]
- [net] ip_vti: receive ipip packet by calling ip_tunnel_rcv (Xin Long) [1815554]
- [net] xfrm: call xfrm_output_gso when inner_protocol is set in xfrm_output (Xin Long) [1815968]
- [net] sched: Fix hw_stats_type setting in pedit loop (Ivan Vecera) [1817156]
- [net] sched: set the hw_stats_type in pedit loop (Ivan Vecera) [1817156]
- [include] flow_offload: fix allowed types check (Ivan Vecera) [1817156]
- [net] sched: act: allow user to specify type of HW stats for a filter (Ivan Vecera) [1817156]
- [net] flow_offload: pass action cookie through offload structures (Ivan Vecera) [1817156]
- [netdrv] flow_offload: introduce "disabled" HW stats type and allow it in mlxsw (Ivan Vecera) [1817156]
- [include] flow_offload: introduce "delayed" HW stats type and allow it in mlx5 (Ivan Vecera) [1817156]
- [netdrv] flow_offload: introduce "immediate" HW stats type and allow it in mlxsw (Ivan Vecera) [1817156]
- [netdrv] mlxsw: restrict supported HW stats type to "any" (Ivan Vecera) [1817156]
- [netdrv] mlxsw: spectrum_flower: Do not allow mixing HW stats types for actions (Ivan Vecera) [1817156]
- [netdrv] flow_offload: check for basic action hw stats type (Ivan Vecera) [1817156]
- [include] flow_offload: Introduce offload of HW stats type (Ivan Vecera) [1817156]
- [net] netfilter: nf_tables: use-after-free in dynamic operations (Phil Sutter) [1822577]
- [net] devlink: Add health recover notifications on devlink flows (Petr Oros) [1821169]
- [net] devlink: add devink notification when reporter update health state (Petr Oros) [1821169]
- [net] devlink: add support for reporter recovery completion (Petr Oros) [1821169]
- [net] devlink: Add new "enable_roce" generic device param (Petr Oros) [1805955]
- [netdrv] netdevsim: use __GFP_NOWARN to avoid memalloc warning (Petr Oros) [1817157]
- [tools] selftests: add netdevsim devlink health tests (Petr Oros) [1817157]
- [netdrv] netdevsim: implement couple of testing devlink health reporters (Petr Oros) [1817157]
- [net] devlink: propagate extack down to health reporter ops (Petr Oros) [1817157]
- [net] devlink: don't do reporter recovery if the state is healthy (Petr Oros) [1817157]
- [net] xsk: Fix out of boundary write in __xsk_rcv_memcpy (Jiri Benc) [1819630]
- [samples] bpf: Allow for -ENETDOWN in xdpsock (Jiri Benc) [1819630]
- [samples] bpf: Drop doubled variable declaration in xdpsock (Jiri Benc) [1819630]
- [netdrv] i40e: Relax i40e_xsk_wakeup's return value when PF is busy (Jiri Benc) [1819630]
- [netdrv] net/ixgbe: Fix concurrency issues between config flow and XSK (Jiri Benc) [1819630]
- [netdrv] net/i40e: Fix concurrency issues between config flow and XSK (Jiri Benc) [1819630]
- [net] xsk: Add rcu_read_lock around the XSK wakeup (Jiri Benc) [1819630]
- [net] fix installing orphaned programs (Jiri Benc) [1819630]
- [tools] libbpf: Don't use kernel-side u32 type in xsk.c (Jiri Benc) [1819630]
- [tools] libbpf: Fix compatibility for kernels without need_wakeup (Jiri Benc) [1819630]
- [net] xsk: Fix crash in poll when device does not support ndo_xsk_wakeup (Jiri Benc) [1819630]
- [kernel] bpf/xskmap: Return ERR_PTR for failure case instead of NULL. (Jiri Benc) [1819630]
- [net] xdp: convert put_page() to put_user_page*() (Jiri Benc) [1819630]
- [net] xdp: mm: introduce page_size() (Jiri Benc) [1819630]
- [net] xsk: relax UMEM headroom alignment (Jiri Benc) [1819630]
- [samples] bpf: fix xdpsock l2fwd tx for unaligned mode (Jiri Benc) [1819630]
- [netdrv] ixgbe: fix xdp handle calculations (Jiri Benc) [1819630]
- [netdrv] ixgbe: fix xdp handle calculations (Jiri Benc) [1819630]
- [netdrv] i40e: fix xdp handle calculations (Jiri Benc) [1819630]
- [netdrv] i40e: fix xdp handle calculations (Jiri Benc) [1819630]
- [net] xsk: use state member for socket synchronization (Jiri Benc) [1819630]
- [documentation] doc/af_xdp: include unaligned chunk case (Jiri Benc) [1819630]
- [samples] bpf: use hugepages in xdpsock app (Jiri Benc) [1819630]
- [samples] bpf: add buffer recycling for unaligned chunks to xdpsock (Jiri Benc) [1819630]
- [samples] bpf: add unaligned chunks mode support to xdpsock (Jiri Benc) [1819630]
- [tools] libbpf: add flags to umem config (Jiri Benc) [1819630]
- [netdrv] mlx5e: Allow XSK frames smaller than a page (Jiri Benc) [1819630]
- [netdrv] mlx5e: modify driver for handling offsets (Jiri Benc) [1819630]
- [netdrv] ixgbe: modify driver for handling offsets (Jiri Benc) [1819630]
- [netdrv] i40e: modify driver for handling offsets (Jiri Benc) [1819630]
- [net] xsk: add support to allow unaligned chunk placement (Jiri Benc) [1819630]
- [net] xdp: xdp_umem: replace kmap on vmap for umem map (Jiri Benc) [1819630]
- [net] Don't call XDP_SETUP_PROG when nothing is changed (Jiri Benc) [1819630]
- [kernel] bpf: Use PTR_ERR_OR_ZERO in xsk_map_inc() (Jiri Benc) [1819630]
- [kernel] xsk: support BPF_EXIST and BPF_NOEXIST flags in XSKMAP (Jiri Benc) [1819630]
- [net] xsk: remove AF_XDP socket from map when the socket is released (Jiri Benc) [1819630]
- [netdrv] mlx5e: Add AF_XDP need_wakeup support (Jiri Benc) [1819630]
- [netdrv] net/mlx5e: Move the SW XSK code from NAPI poll to a separate function (Jiri Benc) [1819630]
- [samples] bpf: add use of need_wakeup flag in xdpsock (Jiri Benc) [1819630]
- [tools] libbpf: add support for need_wakeup flag in AF_XDP part (Jiri Benc) [1819630]
- [netdrv] ixgbe: need_wakeup flag might not be set for Tx (Jiri Benc) [1819630]
- [netdrv] ixgbe: add support for AF_XDP need_wakeup feature (Jiri Benc) [1819630]
- [netdrv] i40e: add support for AF_XDP need_wakeup feature (Jiri Benc) [1819630]
- [net] xsk: add support for need_wakeup flag in AF_XDP rings (Jiri Benc) [1819630]
- [net] xsk: replace ndo_xsk_async_xmit with ndo_xsk_wakeup (Jiri Benc) [1819630]
- [net] xdp: xdp_umem: fix umem pages mapping for 32bits systems (Jiri Benc) [1819630]
- [net] ethtool: add infrastructure for centralized checking of coalescing parameters (Ivan Vecera) [1818096]
- [tools] selftests: netfilter: add simple masq/redirect test cases (Hangbin Liu) [1826220]
- [tools] selftests: netfilter: fix config fragment CONFIG_NF_TABLES_INET (Hangbin Liu) [1826220]
- [tools] selftests: add script to stress-test nft packet path vs. control plane (Hangbin Liu) [1826220]
- [net] devlink: disallow reload operation during device cleanup (Petr Oros) [1805958]
- [tools] selftests: test creating netdevsim inside network namespace (Petr Oros) [1805958]
- [net] devlink: export devlink net setter (Petr Oros) [1805958]
- [net] devlink: don't ignore errors during dumpit (Petr Oros) [1805958]
- [netdrv] netdevsim: fix spelling mistake "forbidded" -> "forbid" (Petr Oros) [1805958]
- [netdrv] netdevsim: implement devlink dev_info op (Petr Oros) [1805958]
- [netdrv] netdevsim: add couple of debugfs bools to debug devlink reload (Petr Oros) [1805958]
- [netdrv] netdevsim: create devlink and netdev instances in namespace (Petr Oros) [1805958]
- [include] net: skbuff: disambiguate argument and member for skb_list_walk_safe helper (Josef Oskera) [1818105]
- [include] net: introduce skb_list_walk_safe for skb segment walking (Josef Oskera) [1818105]
- [netdrv] netdevsim: drop code duplicated by a merge (Petr Oros) [1805951]
- [tools] selftests: devlink: undo changes at the end of resource_test (Petr Oros) [1805951]
- [tools] selftests: netdevsim: add tests for devlink reload with resources (Petr Oros) [1805951]
- [net] devlink: allow to change namespaces during reload (Petr Oros) [1805951]
- [net] devlink: Add method for time-stamp on reporter's dump (Petr Oros) [1805951]
- [netdrv] netdevsim: take devlink net instead of init_net (Petr Oros) [1805951]
- [netdrv] netdevsim: register port netdevices into net of device (Petr Oros) [1805951]
- [netdrv] netdevsim: implement proper devlink reload (Petr Oros) [1805951]
- [netdrv] netdevsim: add all ports in nsim_dev_create() and del them in destroy() (Petr Oros) [1805951]
- [net] devlink: export devlink net getter (Petr Oros) [1805951]
- [net] fib_notifier: propagate extack down to the notifier block callback (Petr Oros) [1805951]
- [net] fib_notifier: propagate possible error during fib notifier registration (Petr Oros) [1805951]
- [net] fib_notifier: make FIB notifier per-netns (Petr Oros) [1805951]
- [netdrv] netdevsim: change fib accounting and limitations to be per-device (Petr Oros) [1805951]
- [netdrv] netdevsim: Set offsets to various protocol layers (Petr Oros) [1805951]
- [net] devlink: Fix error handling in param and info_get dumpit cb (Petr Oros) [1805951]
- [net] lwtunnel: check erspan options before allocating tun_info (Xin Long) [1730151]
- [net] lwtunnel: be STRICT to validate the new LWTUNNEL_IP(6)_OPTS (Xin Long) [1730151]
- [net] lwtunnel: add support for multiple geneve opts (Xin Long) [1730151]
- [net] lwtunnel: change to use nla_put_u8 for LWTUNNEL_IP_OPT_ERSPAN_VER (Xin Long) [1730151]
- [net] lwtunnel: ignore any TUNNEL_OPTIONS_PRESENT flags set by users (Xin Long) [1730151]
- [net] lwtunnel: get nlsize for erspan options properly (Xin Long) [1730151]
- [net] lwtunnel: change to use nla_parse_nested on new options (Xin Long) [1730151]
- [net] lwtunnel: add options setting and dumping for erspan (Xin Long) [1730151]
- [net] lwtunnel: add options setting and dumping for vxlan (Xin Long) [1730151]
- [net] lwtunnel: add options setting and dumping for geneve (Xin Long) [1730151]
- [net] lwtunnel: add options process for cmp_encap (Xin Long) [1730151]
- [net] lwtunnel: add options process for arp request (Xin Long) [1730151]
- [net] ip_tunnel: Add dst_cache support in lwtunnel_state of ip tunnel (Xin Long) [1730151]
- [include] tcp: Define IPPROTO_MPTCP (Florian Westphal) [1812198]
- [net] skb: add helpers to allocate ext independently from sk_buff (Florian Westphal) [1812198]
- [net] tcp: Check for filled TCP option space before SACK (Florian Westphal) [1812198]
- [net] tcp: Export TCP functions and ops struct (Florian Westphal) [1812198]
- [net] tcp: coalesce/collapse must respect MPTCP extensions (Florian Westphal) [1812198]
- [net] mptcp: Add MPTCP to skb extensions (Florian Westphal) [1812198]
- [net] tcp, ulp: Add clone operation to tcp_ulp_ops (Florian Westphal) [1812198]
- [include] tcp: Add MPTCP option number (Florian Westphal) [1812198]
- [net] Make sock protocol value checks more specific (Florian Westphal) [1812198]
- [net] ipv6: provide and use ipv6 specific version for {recv, send}msg (Florian Westphal) [1812198]
- [net] inet: factor out inet_send_prepare() (Florian Westphal) [1812198]
- [net] tipc: fix incorrect increasing of link window (Xin Long) [1822129]
- [net] tipc: Add a missing case of TIPC_DIRECT_MSG type (Xin Long) [1822129]
- [net] tipc: add NULL pointer check to prevent kernel oops (Xin Long) [1822129]
- [net] tipc: simplify trivial boolean return (Xin Long) [1822129]
- [net] tipc: add missing attribute validation for MTU property (Xin Long) [1822129]
- [net] tipc: fix successful connect() but timed out (Xin Long) [1822129]
- [net] tipc: make three functions static (Xin Long) [1822129]
- [net] tipc: fix wrong connect() return code (Xin Long) [1822129]
- [net] tipc: make legacy address flag readable over netlink (Xin Long) [1822129]
- [net] tipc: don't send gap blocks in ACK messages (Xin Long) [1822129]
- [net] tipc: fix use-after-free in tipc_disc_rcv() (Xin Long) [1822129]
- [net] tipc: introduce variable window congestion control (Xin Long) [1822129]
- [net] tipc: eliminate more unnecessary nacks and retransmissions (Xin Long) [1822129]
- [net] tipc: eliminate gap indicator from ACK messages (Xin Long) [1822129]
- [net] tipc: fix duplicate SYN messages under link congestion (Xin Long) [1822129]
- [net] tipc: support in-order name publication events (Xin Long) [1822129]
- [net] tipc: add back tipc prefix to log messages (Xin Long) [1822129]
- [net] tipc: fix update of the uninitialized variable err (Xin Long) [1822129]
- [net] tipc: add support for AEAD key setting via netlink (Xin Long) [1822129]
- [net] tipc: introduce TIPC encryption & authentication (Xin Long) [1822129]
- [include] tipc: add new AEAD key structure for user API (Xin Long) [1822129]
- [net] tipc: enable creating a "preliminary" node (Xin Long) [1822129]
- [net] tipc: add reference counter to bearer (Xin Long) [1822129]
- [net] tipc: eliminate checking netns if node established (Xin Long) [1822129]
- [net] tipc: eliminate the dummy packet in link synching (Xin Long) [1822129]
- [net] tipc: improve message bundling algorithm (Xin Long) [1822129]
- [net] tipc: add smart nagle feature (Xin Long) [1822129]
- [net] tipc: improve throughput between nodes in netns (Xin Long) [1822129]
- [net] tipc: add loopback device tracking (Xin Long) [1822129]
- [netdrv] vxlan: check return value of gro_cells_init() (Sabrina Dubroca) [1821295]
- [netdrv] geneve: move debug check after netdev unregister (Sabrina Dubroca) [1821295]
- [net] ip6_tunnel: enhance tunnel locate with link check (Sabrina Dubroca) [1821295]
- [netdrv] vxlan: implement get_link_ksettings ethtool method (Sabrina Dubroca) [1821295]
- [netdrv] vxlan: check tun_info options_len properly (Sabrina Dubroca) [1821295]
- [include] iptunnel: make TUNNEL_FLAGS available in uapi (Sabrina Dubroca) [1821295]
- [net] introduce dev_net notifier register/unregister variants (Ivan Vecera) [1818102]
- [net] push code from net notifier reg/unreg into helpers (Ivan Vecera) [1818102]
- [net] call call_netdevice_unregister_net_notifiers from unregister (Ivan Vecera) [1818102]
- [net] introduce per-netns netdevice notifiers (Ivan Vecera) [1818102]
- [net] push loops and nb calls into helper functions (Ivan Vecera) [1818102]
- [include] net: ipv6: do not consider routes via gateways for anycast address check (Hangbin Liu) [1816506]
- [net] ipv6/addrconf: call ipv6_mc_up() for non-Ethernet interface (Hangbin Liu) [1816506]
- [net] ipv6: need update peer route when modify metric (Hangbin Liu) [1816506]
- [net] ipv6: use configured metric when add peer route (Hangbin Liu) [1816506]
- [net] ipv6: restrict IPV6_ADDRFORM operation (Hangbin Liu) [1816506]
- [net] ipv6: Fix nlmsg_flags when splitting a multipath route (Hangbin Liu) [1816506]
- [net] ipv6: Fix route replacement with dev-only route (Hangbin Liu) [1816506]
- [net] ipv6/addrconf: fix potential NULL deref in inet6_set_link_af() (Hangbin Liu) [1816506]
- [net] net-ipv6-ndisc: add support for RFC7710 RA Captive Portal Identifier (Hangbin Liu) [1816506]
- [net] ipv6: Don't use dst gateway directly in ip6_confirm_neigh() (Hangbin Liu) [1816506]
- [net] ipv6: Fix the link time qualifier of 'ping_v6_proc_exit_net()' (Hangbin Liu) [1816506]
- [net] ipv6: propagate ipv6_add_dev's error returns out of ipv6_find_idev (Hangbin Liu) [1816506]
- [net] ipv6: allow any source address for sendmsg pktinfo with ip_nonlocal_bind (Hangbin Liu) [1816506]
- [net] multicast: remove useless parameter for group add (Hangbin Liu) [1816506]
- [documentation] networking: devlink-trap: Fix reference to other document (Petr Oros) [1805882]
- [netdrv] netdevsim: Fix use-after-free during device dismantle (Petr Oros) [1805882]
- [netdrv] netdevsim: Fix build error without CONFIG_INET (Petr Oros) [1805882]
- [net] devlink: move reload fail indication to devlink core and expose to user (Petr Oros) [1805882]
- [net] devlink: split reload op into two (Petr Oros) [1805882]
- [netdrv] mlx4: Split restart_one into two functions (Petr Oros) [1805882]
- [include] devlink: add unknown 'fw_load_policy' value (Petr Oros) [1805882]
- [net] devlink: add 'reset_dev_on_drv_probe' param (Petr Oros) [1805882]
- [include] devlink: extend 'fw_load_policy' values (Petr Oros) [1805882]
- [include] devlink: Add new info version tags for ASIC and FW (Petr Oros) [1805882]
- [net] devlink: Use switch-case instead of if-else (Petr Oros) [1805882]
- [net] devlink: Make port index data type as unsigned int (Petr Oros) [1805882]
- [net] devlink: send notifications for deleted snapshots on region destroy (Petr Oros) [1805882]
- [net] devlink: remove pointless data_len arg from region snapshot create (Petr Oros) [1805882]
- [documentation] Add description of netdevsim traps (Petr Oros) [1805882]
- [netdrv] netdevsim: Add devlink-trap support (Petr Oros) [1805882]
- [tools] selftests: netdevsim: add devlink regions tests (Petr Oros) [1805882]
- [tools] selftests: netdevsim: add devlink params tests (Petr Oros) [1805882]
- [netdrv] netdevsim: implement support for devlink region and snapshots (Petr Oros) [1805882]
- [netdrv] netdevsim: register couple of devlink params (Petr Oros) [1805882]

* Wed May 06 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-196.el8]
- [arm64] kvm: arm64: limit PMU version to PMUv3 for ARMv8.1 (Gavin Shan) [1814009]
- [arm64] cpufeature: Extract capped perfmon fields (Gavin Shan) [1814009]
- [virt] kvm: arm64: Use the correct timer structure to access the physical counter (Gavin Shan) [1814009]
- [arm64] Ask the compiler to __always_inline functions used by KVM at HYP (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Define our own swab32() to avoid a uapi static inline (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Ask the compiler to __always_inline functions used at HYP (Gavin Shan) [1814009]
- [arm64] kvm: arm/arm64: Fold VHE entry/exit work into kvm_vcpu_run_vhe() (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Fix up includes for trace.h (Gavin Shan) [1814009]
- [virt] kvm: arm64: Treat emulated TVAL TimerValue as a signed 32-bit integer (Gavin Shan) [1814009]
- [virt] kvm: arm64: pmu: Only handle supported event counters (Gavin Shan) [1814009]
- [virt] kvm: arm64: pmu: Fix chained SW_INCR counters (Gavin Shan) [1814009]
- [virt] kvm: arm64: pmu: Don't mark a counter as chained if the odd one is disabled (Gavin Shan) [1814009]
- [virt] kvm: arm64: pmu: Don't increment SW_INCR if PMCR.E is unset (Gavin Shan) [1814009]
- [virt] kvm: arm: Make inject_abt32() inject an external abort instead (Gavin Shan) [1814009]
- [virt] kvm: arm: Fix DFSR setting for non-LPAE aarch32 guests (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Fix young bit from mmu notifier (Gavin Shan) [1814009]
- [arm64] kvm: Add UAPI notes for swapped registers (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Cleanup MMIO handling (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Write arch.mdcr_el2 changes since last vcpu_load on VHE (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic: Drop the kvm_vgic_register_mmio_region() (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic-its: Properly check the unmapped coll in DISCARD handler (Gavin Shan) [1814009]
- [arm64] kvm: arm/arm64: Correct AArch32 SPSR on exception entry (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Correct CPSR on exception entry (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Correct PSTATE on exception entry (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Re-check VMA on detecting a poisoned page (Gavin Shan) [1814009]
- [virt] kvm: arm: Remove duplicate include (Gavin Shan) [1814009]
- [virt] kvm: arm: Call hyp_cpu_pm_exit at the right place (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic: Handle GICR_PENDBASER.PTZ filed as RAZ (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic-its: Fix restoration of unmapped collections (Gavin Shan) [1814009]
- [virt] kvm: arm64: Only sign-extend MMIO up to register width (Gavin Shan) [1814009]
- [arm64] kvm: stop treating register x18 as caller save (Gavin Shan) [1814009]
- [arm64] Workaround for Cortex-A55 erratum 1530923 (Gavin Shan) [1814009]
- [arm64] Rename WORKAROUND_1319367 to SPECULATIVE_AT_NVHE (Gavin Shan) [1814009]
- [arm64] Enable and document ARM errata 1319367 and 1319537 (Gavin Shan) [1814009]
- [arm64] Rename WORKAROUND_1165522 to SPECULATIVE_AT_VHE (Gavin Shan) [1814009]
- [arm64] Introduce ID_ISAR6 CPU register (Gavin Shan) [1814009]
- [arm64] nofpsmid: Handle TIF_FOREIGN_FPSTATE flag cleanly (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Properly handle faulting of device mappings (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Ensure 'params' is initialised when looking up sys register (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Remove excessive permission check in kvm_arch_prepare_memory_region (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Don't log IMP DEF sysreg traps (Gavin Shan) [1814009]
- [arm64] kvm: Invoke compute_layout() before alternatives are applied (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Sanely ratelimit sysreg messages (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic: Use wrapper function to lock/unlock all vcpus in kvm_vgic_create() (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic: Fix potential double free dist->spis in __kvm_vgic_destroy() (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Get rid of unused arg in cpu_init_hyp_mode() (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Opportunistically turn off WFI trapping when using direct LPI injection (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Let the timer expire in hardirq context on RT (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: vgic: Fix some comments typo (Gavin Shan) [1814009]
- [kvm] arm/arm64: vgic: Remove the declaration of kvm_send_userspace_msi() (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Don't set HCR_EL2.TVM when S2FWB is supported (Gavin Shan) [1814009]
- [arm64] kvm: arm/arm64: Show halt poll counters in debugfs (Gavin Shan) [1814009]
- [arm64] kvm: Prevent speculative S1 PTW when restoring vcpu context (Gavin Shan) [1814009]
- [arm64] kvm: Disable EL1 PTW when invalidating S2 TLBs (Gavin Shan) [1814009]
- [arm64] Add ARM64_WORKAROUND_1319367 for all A57 and A72 versions (Gavin Shan) [1814009]
- [arm64] kvm: Reorder system register restoration and stage-2 activation (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Select TASK_DELAY_ACCT+TASKSTATS rather than SCHEDSTATS (Gavin Shan) [1814009]
- [arm64] Retrieve stolen time as paravirtualized guest (Gavin Shan) [1814009]
- [arm64] arm/arm64: Make use of the SMCCC 1.1 wrapper (Gavin Shan) [1814009]
- [kernel] arm/arm64: Provide a wrapper for SMCCC 1.1 calls (Gavin Shan) [1814009]
- [virt] kvm: arm64: Provide VCPU attributes for stolen time (Gavin Shan) [1814009]
- [virt] kvm: arm64: Support stolen time reporting via shared structure (Gavin Shan) [1814009]
- [virt] kvm: arm64: Implement PV_TIME_FEATURES call (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Factor out hypercall handling from PSCI code (Gavin Shan) [1814009]
- [documentation] kvm: arm64: Document PV-time interface (Gavin Shan) [1814009]
- [arm64] kvm: arm/arm64: Allow user injection of external data aborts (Gavin Shan) [1814009]
- [virt] kvm: arm/arm64: Allow reporting non-ISV data aborts to userspace (Gavin Shan) [1814009]
- [arm64] errata: use arm_smccc_1_1_get_conduit() (Gavin Shan) [1814009]
- [kernel] arm/arm64: smccc/psci: add arm_smccc_1_1_get_conduit() (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Fix ptrauth ID register masking logic (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Add capability to advertise ptrauth for guest (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Add userspace flag to enable pointer authentication (Gavin Shan) [1814009]
- [arm64] kvm: arm/arm64: Context-switch ptrauth registers (Gavin Shan) [1814009]
- [arm64] kvm: arm64: Add a vcpu flag to control ptrauth for guest (Gavin Shan) [1814009]
- [tools] selftests: kvm: s390: fix format strings for access reg test (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: make syncregs more reliable on s390 (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: drop vcpu_setup from s390x (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Add support for vcpu_args_set to aarch64 and s390x (Vitaly Kuznetsov) [1813987]
- [iommu] amd: Fix IOMMU AVIC not properly update the is_run bit in IRTE (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: Fix kernel crash with PR KVM (Vitaly Kuznetsov) [1813987]
- [x86] cpu: Print "VMX disabled" error message iff KVM is enabled (Vitaly Kuznetsov) [1813987]
- [tools] redhat: update kvm/x86 headers in tools (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: fix crash cleanup when KVM wasn't used (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Filter out the broadcast dest for IPI fastpath (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: don't clear mtf_pending when nested events are blocked (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Remove unnecessary exception trampoline in vmx_vmenter (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Split svm_vcpu_run inline assembly to separate file (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Move SEV code to separate file (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Move AVIC code to separate file (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Move Nested SVM Implementation to nested.c (Vitaly Kuznetsov) [1813987]
- [x86] kvm svm: Move SVM related files to own sub-directory (Vitaly Kuznetsov) [1813987]
- [x86] kvm: fix a missing-prototypes "vmread_error" (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix BUILD_BUG() in __cpuid_entry_get_reg() w/ CONFIG_UBSAN=y (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Add a trampoline to fix VMREAD error handling (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Annotate svm_x86_ops as __initdata (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Annotate vmx_x86_ops as __initdata (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop __exit from kvm_x86_ops' hardware_unsetup() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Copy kvm_x86_ops by value to eliminate layer of indirection (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Set kvm_x86_ops only after ->hardware_setup() completes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Configure runtime hooks using vmx_x86_ops (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Move hardware_setup() definition below vmx_x86_ops (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move init-only kvm_x86_ops to separate struct (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Pass kvm_init()'s opaque param to additional arch funcs (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Fix cosmetic copy-paste error in vm_mem_region_move() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Fix out of range accesses to memslots (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Micro-optimize IPI fastpath delay (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Delay read msr data iff writes ICR MSR (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Narrow down the IPI fastpath to single target IPI (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Gracefully handle faults on VMXON (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Fold loaded_vmcs_init() into alloc_loaded_vmcs() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Always VMCLEAR in-use VMCSes during crash with kexec support (Vitaly Kuznetsov) [1813987]
- [tools] kvm_stat: add command line switch '-c' to log in csv format (Vitaly Kuznetsov) [1813987]
- [tools] kvm_stat: add command line switch '-s' to set update interval (Vitaly Kuznetsov) [1813987]
- [tools] kvm_stat: switch to argparse (Vitaly Kuznetsov) [1813987]
- [tools] kvm_stat: rework command line sequence and message texts (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: don't allow memory operands for inline asm that modifies SP (Vitaly Kuznetsov) [1813987]
- [x86] kvm: lapic: Mark hrtimer for period or oneshot mode to expire in hard interrupt context (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Issue WBINVD after deactivating an SEV guest (Vitaly Kuznetsov) [1813987]
- [documentation] kvm: svm: document KVM_MEM_ENCRYPT_OP, let userspace detect if SEV is available (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: remove bogus user-triggerable WARN_ON (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Rework timespec functions and usage (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Code style cleanup in kvm_arch_dev_ioctl() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add blurb to CPUID tracepoint when using max basic leaf values (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add requested index to the CPUID tracepoint (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: check for EFER.SVME=1 before entering guest (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: remove side effects from nested_vmx_exit_reflected (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: access regs array in vmenter.S in its natural order (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: enlightened VMPTRLD with an incorrect GPA (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: test enlightened vmenter with wrong eVMCS version (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: define and use EVMCS_VERSION (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: properly handle errors in nested_vmx_handle_enlightened_vmptrld() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: stop abusing need_vmcs12_to_shadow_sync for eVMCS mapping (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: Uses TEST_FAIL in tests/utilities (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: Introduce the TEST_FAIL macro (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Introduce steal-time test (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: virt_map should take npages, not size (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Use consistent message for test skipping (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Enable printf format warnings for TEST_ASSERT (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Share common API documentation (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: svm: Add vmcall test to gitignore (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: Remove an obsolete comment (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: correct meaningless kvm_apicv_activated() check (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Consolidate nested MTF checks to helper function (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Micro-optimize vmexit time when not exposing PMU (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Introduce GA Log tracepoint for AVIC (Vitaly Kuznetsov) [1813987]
- [documentation] kvm: documentation: Update fast page fault for indirect sp (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: avoid loss of pending IRQ/NMI before entering L2 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: implement check_nested_events for interrupts (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: ignore L1 interrupt window while running L2 with V_INTR_MASKING=1 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: do not change host intercepts while nested VM is running (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: rename set_cr3 callback and related flags to load_mmu_pgd (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: unify callbacks to load paging root (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor kvm_cpuid() param that controls out-of-range logic (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor out-of-range logic to contain the madness (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix CPUID range checks for Hypervisor and Centaur classes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add helpers to perform CPUID-based guest vendor check (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Trace the original requested CPUID function in kvm_cpuid() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: cpuid: add support for supervisor states (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move nSVM CPUID 0x8000000A handling into common x86 code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: Advertise and enable NRIPS for L1 iff nrips is enabled (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nsvm: Expose SVM features to L1 iff nested is enabled (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move VMX's host_efer to common x86 code (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Drop largepages_enabled and its accessor/mutator (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Don't propagate MMU lpage support to memslot.disallow_lpage (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Configure max page level during hardware setup (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Merge kvm_{enable, disable}_tdp() into a common function (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Refactor logging of NPT enabled/disabled (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Directly query Intel PT mode when refreshing PMUs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Check for Intel PT MSR virtualization using KVM cpu caps (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Directly use VMX capabilities helper to detect RDTSCP support (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use KVM cpu caps to detect MSR_TSC_AUX virt support (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Do kvm_cpuid_array capacity checks in terminal functions (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use kvm_cpu_caps to detect Intel PT support (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Set emulated/transmuted feature bits via kvm_cpu_caps (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Override host CPUID results with kvm_cpu_caps (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Do host CPUID at load time to mask KVM cpu caps (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Remove stateful CPUID handling (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Squash CPUID 0x2.0 insanity for modern CPUs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Remove the unnecessary loop on CPUID 0x7 sub-leafs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fold CPUID 0x7 masking back into __do_cpuid_func() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use KVM cpu caps to track UMIP emulation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use KVM cpu caps to mark CR4.LA57 as not-reserved (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add a helper to check kernel support when setting cpu cap (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move XSAVES CPUID adjust to VMX's KVM cpu cap update (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Convert feature updates from CPUID to KVM cpu caps (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Convert feature updates from CPUID to KVM cpu caps (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce kvm_cpu_caps to replace runtime CPUID masking (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor handling of XSAVES CPUID adjustment (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: handle GBPAGE CPUID adjustment for EPT with generic code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle Intel PT CPUID adjustment in VMX code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle RDTSCP CPUID adjustment in VMX code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle PKU CPUID adjustment in VMX code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle UMIP emulation CPUID adjustment in VMX code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle INVPCID CPUID adjustment in VMX code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle MPX CPUID adjustment in VMX code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor cpuid_mask() to auto-retrieve the register (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce cpuid_entry_{change, set, clear}() mutators (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce cpuid_entry_{get, has}() accessors (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Replace bare "unsigned" with "unsigned int" in cpuid helpers (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use u32 for holding CPUID register value in helpers (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop explicit @func param from ->set_supported_cpuid() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Clear output regs for CPUID 0x14 if PT isn't exposed to guest (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Make kvm_mpx_supported() an inline function (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use supported_xcr0 to detect MPX support (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Calculate the supported xcr0 mask at load time (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Add helpers to query Intel PT mode (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use common loop iterator when handling CPUID 0xD.N (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop redundant array size check (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Encapsulate CPUID entries and metadata in struct (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor CPUID 0x4 and 0x8000001d handling (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Hoist loop counter and terminator to top of __do_cpuid_func() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Consolidate CPUID array max num entries checking (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop redundant boot cpu checks on SSBD feature bits (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop the explicit @index from do_cpuid_7_mask() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Clean up CPUID 0x7 sub-leaf loop (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor CPUID 0xD.N sub-leaf entry creation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Warn on zero-size save state for valid CPUID 0xD.N sub-leaf (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Check for CPUID 0xD.N support before validating array size (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move CPUID 0xD.1 handling out of the index>0 loop (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Check userspace CPUID array size after validating sub-leaf (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Clean up error handling in kvm_dev_ioctl_get_cpuid() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Simplify handling of Centaur CPUID leafs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor loop around do_cpuid_func() to separate helper (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Return -E2BIG when KVM_GET_SUPPORTED_CPUID hits max entries (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Shrink the usercopy region of the emulation context (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move kvm_emulate.h into KVM's private directory (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Dynamically allocate per-vCPU emulation context (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move emulation-only helpers to emulate.c (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Explicitly pass an exception struct to check_intercept (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor I/O emulation helpers to provide vcpu-only variant (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Drop gfn_to_pfn_atomic() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix warning due to implicit truncation on 32-bit KVM (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Drop unnecessary check on ept caps for execute-only (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Rename kvm_mmu->get_cr3() to ->get_guest_pgd() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Rename EPTP validity helper and associated variables (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Rename nested_ept_get_cr3() to nested_ept_get_eptp() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Allow L1 to use 5-level page walks for nested EPT (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Drop kvm_mmu_extended_role.cr4_la57 hack (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Don't drop level/direct from MMU role calculation (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Support dirty log initial-all-set test (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Properly handle userspace interrupt window request (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: trigger kvmclock sync request just once on VM creation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: lapic: Recalculate apic map in batch (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Fix some obsolete comments (Vitaly Kuznetsov) [1813987]
- [virt] kvm: x86: enable dirty log gradually in small chunks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Reuse the current root if possible for fast switch (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Ignore guest CR3 on fast root switch for direct MMU (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Inhibit APIC virtualization for X2APIC guest (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Remove unnecessary asm/kvm_host.h includes (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Fix unknown ucall command asserts (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Consolidate VM allocation and free for VMX and SVM (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Directly return __vmalloc() result in ->vm_alloc() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Gracefully handle __vmalloc() failure during VM allocation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Adjust counter sample period after a wrmsr (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Consolidate open coded variants of memslot TLB flushes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Use range-based TLB flush for dirty log memslot flush (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Move kvm_arch_flush_remote_tlbs_memslot() to mmu.c (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Add test for KVM_SET_USER_MEMORY_REGION (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Dynamically size memslot array based on number of used slots (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Terminate memslot walks via used_slots (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Ensure validity of memslot with respect to kvm_get_dirty_log() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Provide common implementation for generic dirty log functions (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Clean up local variable usage in __kvm_set_memory_region() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Simplify kvm_free_memslot() and all its descendents (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Move memslot deletion to helper function (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Free arrays for old memslot when moving memslot's base gfn (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Drop "const" attribute from old memslot in commit_memory_region() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Move setting of memslot into helper routine (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Refactor error handling for setting memory region (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Explicitly free allocated-but-unused dirty bitmap (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Drop kvm_arch_create_memslot() (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: Move memslot memory allocation into prepare_memory_region() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Allocate memslot resources during prepare_memory_region() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Don't free new memslot if allocation of said memslot fails (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Reinstall old memslots if arch preparation fails (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Allocate new rmap and large page tracking when moving memslot (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move gpa_val and gpa_available into the emulator context (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add EMULTYPE_PF when emulation is triggered by a page fault (Vitaly Kuznetsov) [1813987]
- [x86] kvm: apic: remove unused function apic_lvt_vector() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Add 'else' to split mutually exclusive case (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: eliminate some unreachable code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix print format and coding style (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: rewrite the comment in vmx_get_mt_mask (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Convert some printf's to pr_info's (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Rework debug message printing (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Time guest demand paging (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Support multiple vCPUs in demand paging test (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Pass args to vCPU in global vCPU args struct (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Add memory size parameter to the demand paging test (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Add configurable demand paging delay (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Add demand paging content to the demand paging test (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Create a demand paging test (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Introduce num-pages conversion utilities (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Introduce vm_guest_mode_params (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Rename vm_guest_mode_params (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: aarch64: Remove unnecessary ifdefs (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: Remove unnecessary defines (Vitaly Kuznetsov) [1813987]
- [tools] redhat: selftests: kvm: add SPDX-License-Identifier (Vitaly Kuznetsov) [1813987]
- [x86] redhat: kvm: x86: add SPDX-License-Identifier (Vitaly Kuznetsov) [1813987]
- [x86] x86 kvm page table walks: switch to explicit __get_user() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: avoid NULL pointer dereference with incorrect EVMCS GPAs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Initializing all kvm_lapic_irq fields in ioapic_write_indirect (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Condition ENCLS-exiting enabling on CPU support for SGX1 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: fix Kconfig menu text for -Werror (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: remove stale comment from struct x86_emulate_ctxt (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Fix the svm vmexit code for WRMSR (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix dereference null cpufreq policy (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: limit the number of "kvm: disabled by bios" messages (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: avoid useless copy of cpufreq policy (Vitaly Kuznetsov) [1813987]
- [x86] kvm: allow disabling -Werror (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: allow compiling as non-module with W=1 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Pre-allocate 1 cpumask variable per cpu for both pv tlb and pv ipis (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Introduce pv check helpers (Vitaly Kuznetsov) [1813987]
- [kernel] kvm: let declaration of kvm_get_running_vcpus match implementation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: allocate AVIC data structures based on kvm_amd module parameter (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Emulate MTF when performing instruction emulation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: fix error handling in svm_hardware_setup (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Fix potential memory leak in svm_cpu_init() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: apic: avoid calculating pending eoi from an uninitialized val (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: clear PIN_BASED_POSTED_INTR from nested pinbased_ctls only when apicv is globally disabled (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: handle nested posted interrupts when apicv is disabled for L1 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: svm: Fix NULL pointer dereference when AVIC not enabled (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Hold KVM's srcu lock when syncing vmcs12->shadow (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: don't notify userspace IOAPIC on edge-triggered interrupt EOI (Vitaly Kuznetsov) [1813987]
- [x86] kvm/emulate: fix a -Werror=cast-function-type (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: fix incorrect comparison in trace event (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Fix some obsolete comments and grammar error (Vitaly Kuznetsov) [1813987]
- [kernel] kvm: x86: fix missing prototypes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: enable -Werror (Vitaly Kuznetsov) [1813987]
- [documentation] docs: virt: guest-halt-polling.txt convert to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: review-checklist.txt: rename to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert timekeeping.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert s390-diag.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert ppc-pv.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert nested-vmx.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert mmu.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert locking.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert hypercalls.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: arm/psci.txt: convert to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert arm/hyp-abi.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: Convert api.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/xive.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/xics.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/vm.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/vfio.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/vcpu.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/s390_flic.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/mpic.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: convert devices/arm-vgit.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: devices/arm-vgit-v3.txt to ReST (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: devices/arm-vgic-its.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: virt: Convert msr.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: virt: convert halt-polling.txt to ReST format (Vitaly Kuznetsov) [1813987]
- [documentation] docs: kvm: add arm/pvtime.rst to index.rst (Vitaly Kuznetsov) [1813987]
- [documentation] docs: virtual: add it to the documentation body (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: fix WARN_ON check of an unsigned less than zero (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: Remove unused x86_register enum (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Fix struct guest_walker arrays for 5-level paging (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Use correct root level for nested EPT shadow page tables (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Fix some comment typos and coding style (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Avoid retpoline on ->page_fault() with TDP (Vitaly Kuznetsov) [1813987]
- [x86] kvm: apic: reuse smp_wmb() in kvm_make_request() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: remove duplicated KVM_REQ_EVENT request (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: svm: Add vmcall test (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: AMD Nested test infrastructure (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: Replace get_{gdt, idt}_base() by get_{gdt, idt}() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Deliver exception payload on KVM_GET_VCPU_EVENTS (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Handle pending #DB when injecting INIT VM-exit (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Mask off reserved bit from #DB exception payload (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Disable preemption in kvm_get_running_vcpu() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: delete meaningless vmx_decache_cr0_guest_bits() declaration (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Mark CR4.UMIP as reserved based on associated CPUID bit (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix perfctr WRMSR for running counters (Vitaly Kuznetsov) [1813987]
- [x86] kvm: mmu: Separate generating and setting mmio ptes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: mmu: Replace unsigned with unsigned int for PTE access (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Remove stale comment from nested_vmx_load_cr3() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: do not setup pv tlb flush when not paravirtualized (Vitaly Kuznetsov) [1813987]
- [x86] Add "nopv" parameter to disable PV extensions (Vitaly Kuznetsov) [1813987]
- [virt] kvm: fix overflow of zero page refcount with ksm running (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Take a u64 when checking for a valid dr7 value (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: use raw clock values consistently (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: reorganize pvclock_gtod_data members (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: delete meaningless nested_vmx_run() declaration (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: allow AVIC without split irqchip (Vitaly Kuznetsov) [1813987]
- [x86] kvm: ioapic: Lazy update IOAPIC EOI (Vitaly Kuznetsov) [1813987]
- [x86] kvm: ioapic: Refactor kvm_ioapic_update_eoi() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: i8254: Deactivate APICv when using in-kernel PIT re-injection mode (Vitaly Kuznetsov) [1813987]
- [x86] svm: Temporarily deactivate AVIC during ExtINT handling (Vitaly Kuznetsov) [1813987]
- [x86] svm: Deactivate AVIC when launching guest with nested SVM support (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: hyperv: Use APICv update request interface (Vitaly Kuznetsov) [1813987]
- [x86] svm: Add support for dynamic APICv (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce x86 ops hook for pre-update APICv (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce APICv x86 ops for checking APIC inhibit reasons (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: avic: Add support for dynamic setup/teardown of virtual APIC backing page (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: svm: Add support to (de)activate posted interrupts (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add APICv (de)activate request trace points (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add support for dynamic APICv activation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: remove get_enable_apicv from kvm_x86_ops (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce APICv inhibit reason bits (Vitaly Kuznetsov) [1813987]
- [x86] kvm: lapic: Introduce APICv update helper function (Vitaly Kuznetsov) [1813987]
- [iommu] amd: Re-factor guest virtual APIC (de-)activation code (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: Add fpu and one reg set/get library functions (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Clean up host's steal time structure (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Make sure KVM_VCPU_FLUSH_TLB flag is not missed (Vitaly Kuznetsov) [1813987]
- [virt] x86/kvm: Cache gfn to pfn translation (Vitaly Kuznetsov) [1813987]
- [virt] x86/kvm: Introduce kvm_(un)map_gfn() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Be careful not to clear KVM_VCPU_FLUSH_TLB bit (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use a typedef for fastop functions (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add 'else' to unify fastop and execute call path (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: inline memslot_valid_for_gpte (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Use huge pages for DAX-backed files (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Remove lpage_is_disallowed() check from set_spte() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Fold max_mapping_level() into kvm_mmu_hugepage_adjust() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Zap any compound page when collapsing sptes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Remove obsolete gfn restoration in FNAME(fetch) (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Rely on host page tables to find HugeTLB mappings (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Drop level optimization from fast_page_fault() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Walk host page tables to find THP mappings (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Refactor THP adjust to prep for changing query (Vitaly Kuznetsov) [1813987]
- [x86] mm: Introduce lookup_address_in_mm() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Play nice with read-only memslots when querying host page size (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Use vcpu-specific gva->hva translation when querying host page size (Vitaly Kuznetsov) [1813987]
- [mm] thp: kvm: Explicitly check for THP when populating secondary MMU (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Enforce max_level on HugeTLB mappings (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Return immediately if __kvm_gfn_to_hva_cache_init() fails (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Clean up __kvm_gfn_to_hva_cache_init() and its callers (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Check for a bad hva before dropping into the ghc slow path (Vitaly Kuznetsov) [1813987]
- [x86] kvm/x86: export kvm_vector_hashing_enabled() is unnecessary (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: remove duplicated segment cache clear (Vitaly Kuznetsov) [1813987]
- [x86] Adding 'else' to reduce checking (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Check GUEST_DR7 on vmentry of nested guests (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Move running VCPU from ARM to common code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop x86_set_memory_region() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Don't take srcu lock in init_rmode_identity_map() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Add build-time error check on kvm_run size (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Remove kvm_read_guest_atomic() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Perform non-canonical checks in 32-bit KVM (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: WARN on failure to set IA32_PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Remove unused ctxt param from emulator's FPU accessors (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: revert "kvm: x86: Fix fpu state crash in kvm guest" (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Ensure guest's FPU state is loaded when accessing for emulation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Handle TIF_NEED_FPU_LOAD in kvm_{load, put}_guest_fpu() (Vitaly Kuznetsov) [1813987]
- [x86] revert "kvm: x86: Add a WARN on TIF_NEED_FPU_LOAD in kvm_load_guest_fpu()" (Vitaly Kuznetsov) [1813987]
- [x86] kvm: apic: short-circuit kvm_apic_accept_pic_intr() when pic intr is accepted (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: avoid clearing pending exception event twice (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect pmu_intel.c from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect DR-based index computations from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect exit_reason from being used in Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor prefix decoding to prevent Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect MSR-based index computations from Spectre-v1/L1TF attacks in x86.c (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect MSR-based index computations in pmu.h from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect MSR-based index computations in fixed_msr_to_seg_unit() from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect kvm_lapic_reg_write() from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect ioapic_write_indirect() from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect ioapic_read_indirect() from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor picdev_write() to prevent Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect kvm_hv_msr_[get|set]_crash_data() from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Protect x86_decode_insn from Spectre-v1/L1TF attacks (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Move vcpu->run page allocation out of kvm_vcpu_init() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Move putting of vcpu->pid to kvm_vcpu_destroy() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Drop kvm_arch_vcpu_init() and kvm_arch_vcpu_uninit() (Vitaly Kuznetsov) [1813987]
- [arm64] kvm: arm64: Free sve_state via arm specific hook (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: Move all vcpu init code into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: arm: Move all vcpu init code into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move all vcpu init code into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Drop kvm_arch_vcpu_setup() (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: booke: Setup vcpu during kvmppc_core_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [s390] kvm: s390: Manually invoke vcpu setup during kvm_arch_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move guts of kvm_arch_vcpu_setup() into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Move initialization of preempt notifier to kvm_vcpu_init() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Unexport kvm_vcpu_cache and kvm_vcpu_{un}init() (Vitaly Kuznetsov) [1813987]
- [s390] kvm: Move vcpu alloc and init invocation to common code (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Introduce kvm_vcpu_destroy() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Invoke kvm_vcpu_uninit() immediately prior to freeing vcpu (Vitaly Kuznetsov) [1813987]
- [s390] kvm: s390: Invoke kvm_vcpu_init() before allocating sie_page (Vitaly Kuznetsov) [1813987]
- [s390] kvm: s390: Move guts of kvm_arch_vcpu_init() into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Add kvm_arch_vcpu_precreate() to handle pre-allocation issues (Vitaly Kuznetsov) [1813987]
- [kernel] kvm: Remove kvm_arch_vcpu_free() declaration (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop kvm_arch_vcpu_free() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: arm: Drop kvm_arch_vcpu_free() (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: Drop kvm_arch_vcpu_free() (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: Move kvm_vcpu_init() invocation to common code (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: e500mc: Move reset of oldpir below call to kvm_vcpu_init() (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: book3s pr: Allocate book3s and shadow vcpu after common init (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: Allocate vcpu struct in common PPC code (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: e500mc: Add build-time assert that vcpu is at offset 0 (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: book3s pr: Free shared page if mmu initialization fails (Vitaly Kuznetsov) [1813987]
- [powerpc] kvm: ppc: book3s hv: Uninit vCPU if vcore creation fails (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Remove spurious clearing of async #PF MSR (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Remove spurious kvm_mmu_unload() from vcpu destruction path (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move kvm_vcpu_init() invocation to common code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move allocation of pio_data page down a few lines (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move FPU allocation to common x86 code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Allocate vcpu struct in common x86 code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Use direct vcpu pointer during vCPU create/free (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Use direct vcpu pointer during vCPU create/free (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Allocate VPID after initializing VCPU (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Free wbinvd_dirty_mask if vCPU creation fails (Vitaly Kuznetsov) [1813987]
- [virt] kvm: async_pf: drop kvm_arch_async_page_present wrappers (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: fix overlap between SPTE_MMIO_MASK and generation (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Refactor handling of VM debugfs files (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Apply max PA check for MMIO sptes to 32-bit KVM (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: vmread should not set rflags to specify success in case of #PF (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Micro-optimize nEPT's bad memptype/XWR checks (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Reorder the reserved bit check in prefetch_invalid_gpte() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: delete meaningless nested_vmx_prepare_msr_bitmap() declaration (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Refactor and rename bit() to feature_bit() macro (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Expand build-time assertion on reverse CPUID usage (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add CPUID_7_1_EAX to the reverse CPUID table (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move bit() helper to cpuid.h (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add dedicated emulator helpers for querying CPUID features (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add macro to ensure reserved cr4 bits checks stay in sync (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop special XSAVE handling from guest_cpuid_has() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Ensure all logical CPUs have consistent reserved cr4 bits (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Don't let userspace set host-reserved cr4 bits (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Add helper to consolidate up PT/RTIT WRMSR fault logic (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Add non-canonical check on writes to RTIT address MSRs (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Fix some writing mistakes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: hyperv: Fix some typos in vcpu unimpl info (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Fix some grammar mistakes (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Fix some comment typos and missing parentheses (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Fix some out-dated function names in comment (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Fix some wrong function names in comment (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: check kvm_pit outside kvm_vm_ioctl_reinject() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: lapic: micro-optimize fixed mode ipi delivery (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: FIXED+PHYSICAL mode single target IPI fastpath (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Allow KVM_INTEL when building for Centaur and/or Zhaoxin CPUs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Check for full VMX support when verifying CPU compatibility (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Use VMX feature flag to query BIOS enabling (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Drop initialization of IA32_FEAT_CTL MSR (Vitaly Kuznetsov) [1813987]
- [x86] cpufeatures: Add flag to track whether MSR IA32_FEAT_CTL is configured (Vitaly Kuznetsov) [1813987]
- [x86] cpu: Set synthetic VMX cpufeatures during init_ia32_feat_ctl() (Vitaly Kuznetsov) [1813987]
- [x86] cpufeatures: Add EPT_AD feature bit (Vitaly Kuznetsov) [1813987]
- [x86] cpu: Detect VMX features on Intel, Centaur and Zhaoxin CPUs (Vitaly Kuznetsov) [1813987]
- [x86] vmx: Introduce VMX_FEATURES_* (Vitaly Kuznetsov) [1813987]
- [x86] cpu: Clear VMX feature flag if VMX is not fully enabled (Vitaly Kuznetsov) [1813987]
- [x86] centaur: Use common IA32_FEAT_CTL MSR initialization (Vitaly Kuznetsov) [1813987]
- [x86] mce: WARN once if IA32_FEAT_CTL MSR is left unlocked (Vitaly Kuznetsov) [1813987]
- [x86] intel: Initialize IA32_FEAT_CTL MSR at boot (Vitaly Kuznetsov) [1813987]
- [tools] x86: Sync msr-index.h from kernel sources (Vitaly Kuznetsov) [1813987]
- [tools] selftests, kvm: Replace manual MSR defs with common msr-index.h (Vitaly Kuznetsov) [1813987]
- [x86] msr-index: Clean up bit defines for IA32_FEATURE_CONTROL MSR (Vitaly Kuznetsov) [1813987]
- [tools] tools arch x86: Grab a copy of the file containing the MSR numbers (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: WARN if root_hpa is invalid when handling a page fault (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: WARN on an invalid root_hpa (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Move root_hpa validity checks to top of page fault handler (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Move calls to thp_adjust() down a level (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Move transparent_hugepage_adjust() above __direct_map() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Consolidate tdp_page_fault() and nonpaging_page_fault() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Rename lpage_disallowed to account_disallowed_nx_lpage (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Persist gfn_lpage_is_disallowed() to max_level (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Incorporate guest's page level into max level for shadow MMU (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Refactor handling of forced 4k pages in page faults (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Refactor the per-slot level calculation in mapping_level() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Refactor handling of cache consistency with TDP (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Move nonpaging_page_fault() below try_async_pf() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Fold nonpaging_map() into nonpaging_page_fault() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/mmu: Move definition of make_mmu_pages_available() up (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use gpa_t for cr2/gpa to fix TDP support on 32-bit KVM (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add a WARN on TIF_NEED_FPU_LOAD in kvm_load_guest_fpu() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix potential put_fpu() w/o load_fpu() on MPX platform (Vitaly Kuznetsov) [1813987]
- [kernel] kvm: Remove duplicated declaration of kvm_vcpu_kick (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Aesthetic cleanup of handle_vmread and handle_vmwrite (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: VMWRITE checks unsupported field before read-only field (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: VMWRITE checks VMCS-link pointer before VMCS field (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Fix the spelling of CPU_BASED_USE_TSC_OFFSETTING (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Rename NMI_PENDING to NMI_WINDOW (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Rename INTERRUPT_PENDING to INTERRUPT_WINDOW (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix some comment typos (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Convert the last users of "shorthand = 0" to use macros (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix callers of kvm_apic_match_dest() to use correct macros (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Drop KVM_APIC_SHORT_MASK and KVM_APIC_DEST_MASK (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Use APIC_DEST_* macros properly in kvm_lapic_irq.dest_mode (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move irrelevant declarations out of ioapic.h (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix kvm_bitmap_or_dest_vcpus() to use irq shorthand (Vitaly Kuznetsov) [1813987]
- [x86] kvm: explicitly set rmap_head->val to 0 in pte_list_desc_remove_entry() (Vitaly Kuznetsov) [1813987]
- [virt] kvm: get rid of var page in kvm_set_pfn_dirty() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: remove unreachable statement in vmx_get_msr_feature() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: use CPUID to locate host page table reserved bits (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Host feature SSBD doesn't imply guest feature AMD_SSBD (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Host feature SSBD doesn't imply guest feature SPEC_CTRL_SSBD (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Stop wasting a page for guest_msrs (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: fix out-of-bounds write in KVM_GET_EMULATED_CPUID (CVE-2019-19332) (Vitaly Kuznetsov) [1813987]
- [documentation] documentation: kvm: Fix mention to number of ioctls classes (Vitaly Kuznetsov) [1813987]
- [x86] kvm x86: Move kvm cpuid support out of svm (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Relax guest IA32_FEATURE_CONTROL constraints (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Grab KVM's srcu lock when setting nested state (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Open code shared_msr_update() in its only caller (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Fix jump label out_free_* in kvm_init() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: create mmu/ subdirectory (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Remove unnecessary TLB flushes on L1<->L2 switches when L1 use apic-access-page (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Do not mark vmcs02->apic_access_page as dirty when unpinning (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Assume TLB entries of L1 and L2 are tagged differently if L0 use EPT (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Unexport kvm_vcpu_reload_apic_access_page() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: add CR4_LA57 bit to nested CR4_FIXED1 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Use semi-colon instead of comma for exit-handlers initialization (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Add support for capturing highest observable L2 TSC (Vitaly Kuznetsov) [1813987]
- [x86] tss: Fix and move VMX BUILD_BUG_ON() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Rename function find_msr() to vmx_find_msr_index() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Rename NR_AUTOLOAD_MSRS to NR_LOADSTORE_MSRS (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nested: Introduce read_and_check_msr_entry() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Expose load IA32_PERF_GLOBAL_CTRL VM-{Entry, Exit} control (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Load GUEST_IA32_PERF_GLOBAL_CTRL MSR on VM-Entry (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: mark functions in the header as "static inline" (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Use kvm_set_msr to load IA32_PERF_GLOBAL_CTRL on VM-Exit (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Check HOST_IA32_PERF_GLOBAL_CTRL on VM-Entry (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Check GUEST_IA32_PERF_GLOBAL_CTRL on VM-Entry (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Add helper to check reserved bits in IA32_PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: Simplify loop in kvm_create_max_vcpus test (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: optimization: Requst TLB flush in fast_cr3_switch() instead of do it directly (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/vpmu: Add lazy mechanism to release perf_event per vPMC (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/vpmu: Reuse perf_event to avoid unnecessary pmc_reprogram_counter (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/vpmu: Introduce a new kvm_pmu_ops->msr_idx_to_pmc callback (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/vpmu: Rename pmu_ops callbacks from msr_idx to rdpmc_ecx (Vitaly Kuznetsov) [1813987]
- [kernel] perf/core: Provide a kernel-internal interface to pause perf_event (Vitaly Kuznetsov) [1813987]
- [kernel] perf/core: Provide a kernel-internal interface to recalibrate event period (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Update vmcs01 TPR_THRESHOLD if L2 changed L1 TPR (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Refactor update_cr8_intercept() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Remove check if APICv enabled in SVM update_cr8_intercept() handler (Vitaly Kuznetsov) [1813987]
- [x86] kvm: apic: add helper func to remove duplicate code in kvm_pv_send_ipi (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: avoid unused setup_syscalls_segments call when SYSCALL check failed (Vitaly Kuznetsov) [1813987]
- [virt] kvm: mmio: get rid of odd out_err label in kvm_coalesced_mmio_init (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Consume pending LAPIC INIT event when exit on INIT_SIGNAL (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Prevent set vCPU into INIT/SIPI_RECEIVED state when INIT are latched (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Evaluate latched_init in KVM_SET_VCPU_EVENTS when vCPU not in SMM (Vitaly Kuznetsov) [1813987]
- [x86] kvm: retpolines: x86: eliminate retpoline from svm.c exit handlers (Vitaly Kuznetsov) [1813987]
- [x86] kvm: retpolines: x86: eliminate retpoline from vmx.c exit handlers (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: optimize more exit handlers in vmx.c (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Add a comment describing the /dev/kvm no_compat handling (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Forbid /dev/kvm being opened by a compat task when CONFIG_KVM_COMPAT=n (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Reset the three MSR list number variables to 0 in kvm_init_msr_list() (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: fix build with glibc >= 2.30 (Vitaly Kuznetsov) [1813987]
- [virt] kvm: mmu: Do not treat ZONE_DEVICE pages as being reserved (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Introduce pi_is_pir_empty() helper (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Do not change PID.NDST when loading a blocked vCPU (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Consider PID.PIR to determine if vCPU has pending interrupts (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Fix comment to specify PID.ON instead of PIR.ON (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fix initialization of MSR lists (Vitaly Kuznetsov) [1813987]
- [virt] kvm: fix placement of refcount initialization (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Fix NULL-ptr deref after kvm_create_vm fails (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: get rid of odd out jump label in pdptrs_changed (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: switch KVMCLOCK base to monotonic raw clock (Vitaly Kuznetsov) [1813987]
- [virt] kvm: call kvm_arch_destroy_vm if vm creation fails (Vitaly Kuznetsov) [1813987]
- [x86] kvm/pmu: Replace rcu_swap_protected() with rcu_replace_pointer() (Vitaly Kuznetsov) [1813987]
- [kernel] rcu: Upgrade rcu_swap_protected() to rcu_replace_pointer() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: Fix -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Allocate memslots and buses before calling kvm_arch_init_vm (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Don't leak L1 MMIO regions to L2 (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Fix potential wrong physical id in avic_handle_ldr_update (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Add separate helper for putting borrowed reference to kvm (Vitaly Kuznetsov) [1813987]
- [tools] kvm: tests: Add test to verify MSR_IA32_XSS (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Update svm_xsaves_supported (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move IA32_XSS to kvm_{get, set}_msr_common (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Move IA32_XSS-swapping on VM-entry/VM-exit to common x86 code (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Use wrmsr for switching between guest and host IA32_XSS on Intel (Vitaly Kuznetsov) [1813987]
- [x86] kvm: svm: Use wrmsr for switching between guest and host IA32_XSS on AMD (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Remove unneeded kvm_vcpu variable, guest_xcr0_loaded (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Fix conditions for guest IA32_XSS support (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Introduce vcpu->arch.xsaves_enabled (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Rename {vmx, nested_vmx}_vcpu_setup() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Initialize vmx->guest_msrs[] right after allocation (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Remove vmx->hv_deadline_tsc initialization from vmx_vcpu_setup() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Write VPID to vmcs when creating vcpu (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86/vpmu: Declare kvm_pmu->reprogram_pmi field using DECLARE_BITMAP (Vitaly Kuznetsov) [1813987]
- [x86] kvm: remove redundant code in kvm_arch_vm_ioctl (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Modify kvm_x86_ops.get_enable_apicv() to use struct kvm parameter (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fold decache_cr3() into cache_reg() (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add helpers to test/mark reg availability and dirtiness (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Fold 'enum kvm_ex_reg' definitions into 'enum kvm_reg' (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Add WARNs to detect out-of-bounds register indices (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Optimize vmx_set_rflags() for unrestricted guest (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Consolidate to_vmx() usage in RFLAGS accessors (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Skip GUEST_CR3 VMREAD+VMWRITE if the VMCS is up-to-date (Vitaly Kuznetsov) [1813987]
- [x86] kvm: nvmx: Always write vmcs02.GUEST_CR3 during nested VM-Enter (Vitaly Kuznetsov) [1813987]
- [x86] kvm: clear kvmclock MSR on reset (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: fix bugon.cocci warnings (Vitaly Kuznetsov) [1813987]
- [x86] kvm: vmx: Remove specialized handling of unexpected exit-reasons (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: fix sync_regs_test with newer gccs (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Don't shrink/grow vCPU halt_poll_ns if host side polling is disabled (Vitaly Kuznetsov) [1813987]
- [tools] selftests: kvm: synchronize .gitignore to Makefile (Vitaly Kuznetsov) [1813987]
- [x86] kvm: x86: Expose RDPID in KVM_GET_SUPPORTED_CPUID (Vitaly Kuznetsov) [1813987]
- [virt] kvm: Allow kvm_device_ops to be const (Vitaly Kuznetsov) [1813987]
- [kernel] kvm: Implement kvm_put_guest() (Vitaly Kuznetsov) [1813987]
- [x86] xen: kvm: Gather the definition of emulate prefixes (Vitaly Kuznetsov) [1813987]
- [tools] kvm: selftests: do not blindly clobber registers in guest asm (Vitaly Kuznetsov) [1813987]

* Tue May 05 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-195.el8]
- [fs] cifs: handle prefix paths in reconnect (Leif Sahlberg) [1814203]
- [fs] cifs: use compounding for open and first query-dir for readdir() (Leif Sahlberg) [1814203]
- [fs] cifs: create a helper function to parse the query-directory response buffer (Leif Sahlberg) [1814203]
- [fs] cifs: prepare SMB2_query_directory to be used with compounding (Leif Sahlberg) [1814203]
- [fs] xfs: reflink should force the log out if mounted with wsync (Bill O'Donnell) [1825373]
- [fs] xfs: factor out a new xfs_log_force_inode helper (Bill O'Donnell) [1825373]
- [fs] xfs: don't ever return a stale pointer from __xfs_dir3_free_read (Bill O'Donnell) [1825373]
- [fs] xfs: fix xfs_rmap_has_other_keys usage of ECANCELED (Bill O'Donnell) [1825373]
- [fs] xfs: clear kernel only flags in XFS_IOC_ATTRMULTI_BY_HANDLE (Bill O'Donnell) [1825373]
- [fs] xfs: use bitops interface for buf log item AIL flag check (Bill O'Donnell) [1825373]
- [fs] xfs: Sanity check flags of Q_XQUOTARM call (Bill O'Donnell) [1825373]
- [fs] iomap: iomap that extends beyond EOF should be marked dirty (Bill O'Donnell) [1825373]
- [s390] s390/kasan: Fix crash when attaching PCI device (Philipp Rudo) [1827334]
- [s390] s390/qeth: fix initialization on old HW (Philipp Rudo) [1780667]
- [s390] s390/qeth: vnicc Fix init to default (Philipp Rudo) [1780667]
- [s390] s390/qeth: Fix vnicc_is_in_use if rx_bcast not set (Philipp Rudo) [1780667]
- [s390] s390/qeth: fix false reporting of VNIC CHAR config failure (Philipp Rudo) [1780667]
- [s390] s390/qeth: lock the card while changing its hsuid (Philipp Rudo) [1780667]
- [s390] s390/qeth: fix qdio teardown after early init error (Philipp Rudo) [1780667]
- [s390] s390/qeth: don't return -ENOTSUPP to userspace (Philipp Rudo) [1780667]
- [s390] s390/qeth: fix promiscuous mode after reset (Philipp Rudo) [1780667]
- [s390] s390/qeth: handle error due to unsupported transport mode (Philipp Rudo) [1780667]
- [s390] s390/qeth: return proper errno on IO error (Philipp Rudo) [1780667]
- [s390] s390/qeth: don't check drvdata in sysfs code (Philipp Rudo) [1780667]
- [s390] s390/qeth: replace qeth_l3_get_addr_buffer() (Philipp Rudo) [1780667]
- [s390] s390/qeth: remove VLAN tracking for L3 devices (Philipp Rudo) [1780667]
- [net] net: 8021q: vlan_core: allow use list of vlans for real device (Philipp Rudo) [1780667]
- [s390] s390/qeth: consolidate L3 mcast registration code (Philipp Rudo) [1780667]
- [s390] s390/qeth: remove gratuitious RX modeset (Philipp Rudo) [1780667]
- [s390] s390/qeth: fine-tune L3 mcast locking (Philipp Rudo) [1780667]
- [s390] s390/qeth: clean up error path in qeth_core_probe_device() (Philipp Rudo) [1780667]
- [s390] s390/qeth: don't cache MAC addresses for multicast IPs (Philipp Rudo) [1780667]
- [s390] s390/qeth: use helpers for IP address hashing (Philipp Rudo) [1780667]
- [s390] s390/qeth: don't set card state in qeth_qdio_clear_card() (Philipp Rudo) [1780667]
- [s390] s390/qeth: consolidate some duplicated HW cmd code (Philipp Rudo) [1780667]
- [s390] s390/qeth: keep IRQ disabled until NAPI is really done (Philipp Rudo) [1780667]
- [s390] s390/qeth: use QDIO_BUFNR() (Philipp Rudo) [1780667]
- [s390] s390/qdio: move SSQD Sniffer mask definition (Philipp Rudo) [1780667]
- [s390] s390/qdio: don't attempt IRQ avoidance on Output SBALs (Philipp Rudo) [1780667]
- [s390] s390/qdio: simplify thinint device registration (Philipp Rudo) [1780667]
- [s390] s390/qdio: add statistics helper macro (Philipp Rudo) [1780667]
- [s390] s390/qdio: remove a forward declaration (Philipp Rudo) [1780667]
- [s390] s390/qdio: reduce log level for EQBS partial (Philipp Rudo) [1780667]
- [s390] s390/qdio: use QDIO_BUFNR() (Philipp Rudo) [1780667]
- [s390] s390/qeth: Fix initialization of vnicc cmd masks during set online (Philipp Rudo) [1780667]
- [s390] s390/qeth: Fix error handling during VNICC initialization (Philipp Rudo) [1780667]
- [s390] s390/qdio: clarify size of the QIB parm area (Philipp Rudo) [1780667]
- [s390] s390/qeth: get vnicc sub-cmd type from reply data (Philipp Rudo) [1780667]
- [s390] s390/qeth: merge qeth_reply struct into qeth_cmd_buffer (Philipp Rudo) [1780667]
- [s390] s390/qeth: keep cmd alive after IO completion (Philipp Rudo) [1780667]
- [s390] s390/qeth: use correct length field in SNMP cmd callback (Philipp Rudo) [1780667]
- [s390] s390/qeth: propagate length of processed cmd IO data to callback (Philipp Rudo) [1780667]
- [s390] s390/qeth: use node_descriptor struct (Philipp Rudo) [1780667]
- [s390] s390/cio: move struct node_descriptor to cio.h (Philipp Rudo) [1780667]
- [s390] scsi: zfcp: log FC Endpoint Security errors (Philipp Rudo) [1723820]
- [s390] scsi: zfcp: enhance handling of FC Endpoint Security errors (Philipp Rudo) [1723820]
- [lib] lib/zlib: add zlib_deflate_dfltcc_enabled() function (Philipp Rudo) [1659435]
- [lib] s390/boot: add dfltcc= kernel command line parameter (Philipp Rudo) [1659435]
- [lib] lib/zlib: add s390 hardware support for kernel zlib_inflate (Philipp Rudo) [1659435]
- [s390] s390/boot: rename HEAP_SIZE due to name collision (Philipp Rudo) [1659435]
- [lib] lib/zlib: add s390 hardware support for kernel zlib_deflate (Philipp Rudo) [1659435]
- [base] mm/memory_hotplug: allow to specify a default online_type (David Hildenbrand) [1038941]
- [base] mm/memory_hotplug: convert memhp_auto_online to store an online_type (David Hildenbrand) [1038941]
- [mm] mm/memory_hotplug: unexport memhp_auto_online (David Hildenbrand) [1038941]
- [hv] hv_balloon: don't check for memhp_auto_online manually (David Hildenbrand) [1038941]
- [powerpc] powernv/memtrace: always online added memory blocks (David Hildenbrand) [1038941]
- [base] drivers/base/memory: store mapping between MMOP_* and string in an array (David Hildenbrand) [1038941]
- [base] drivers/base/memory: map MMOP_OFFLINE to 0 (David Hildenbrand) [1038941]
- [base] drivers/base/memory: rename MMOP_ONLINE_KEEP to MMOP_ONLINE (David Hildenbrand) [1038941]
- [netdrv] cxgb4: fix adapter crash due to wrong MC size (Vishal Kulkarni) [1813128]
- [scsi] scsi: ibmvfc: Don't send implicit logouts prior to NPIV login (Steve Best) [1828725]
- [fs] cifs: ignore cached share root handle closing errors (Leif Sahlberg) [1827485]
- [fs] cifs: Optimize readdir on reparse points (Leif Sahlberg) [1827485]
- [fs] cifs: Adjust indentation in smb2_open_file (Leif Sahlberg) [1827485]
- [fs] CIFS: Close cached root handle only if it has a lease (Leif Sahlberg) [1827485]
- [fs] SMB3: Fix crash in SMB2_open_init due to uninitialized field in compounding path (Leif Sahlberg) [1827485]
- [fs] smb3: fix refcount underflow warning on unmount when no directory leases (Leif Sahlberg) [1827485]
- [fs] fs: cifs: Delete usage of timespec64_trunc (Leif Sahlberg) [1827485]
- [fs] smb3: improve check for when we send the security descriptor context on create (Leif Sahlberg) [1827485]
- [fs] smb3: fix mode passed in on create for modetosid mount option (Leif Sahlberg) [1827485]
- [fs] cifs: fix possible uninitialized access and race on iface_list (Leif Sahlberg) [1827485]
- [fs] cifs: Fix lookup of SMB connections on multichannel (Leif Sahlberg) [1827485]
- [fs] smb3: query attributes on file close (Leif Sahlberg) [1827485]
- [fs] smb3: remove unused flag passed into close functions (Leif Sahlberg) [1827485]
- [fs] cifs: remove redundant assignment to pointer pneg_ctxt (Leif Sahlberg) [1827485]
- [fs] fs: cifs: Fix atime update check vs mtime (Leif Sahlberg) [1827485]
- [fs] CIFS: fix a white space issue in cifs_get_inode_info() (Leif Sahlberg) [1827485]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1827485]
- [fs] cifs: Always update signing key of first channel (Leif Sahlberg) [1827485]
- [fs] cifs: Fix retrieval of DFS referrals in cifs_mount() (Leif Sahlberg) [1827485]
- [fs] cifs: Fix potential softlockups while refreshing DFS cache (Leif Sahlberg) [1827485]
- [fs] cifs: Fix lookup of root ses in DFS referral cache (Leif Sahlberg) [1827485]
- [fs] cifs: Fix use-after-free bug in cifs_reconnect() (Leif Sahlberg) [1827485]
- [fs] cifs: dump channel info in DebugData (Leif Sahlberg) [1827485]
- [fs] smb3: dump in_send and num_waiters stats counters by default (Leif Sahlberg) [1827485]
- [fs] cifs: try harder to open new channels (Leif Sahlberg) [1827485]
- [fs] CIFS: Properly process SMB3 lease breaks (Leif Sahlberg) [1827485]
- [fs] cifs: move cifsFileInfo_put logic into a work-queue (Leif Sahlberg) [1827485]
- [fs] cifs: try opening channels after mounting (Leif Sahlberg) [1827485]
- [fs] CIFS: refactor cifs_get_inode_info() (Leif Sahlberg) [1827485]
- [fs] cifs: switch servers depending on binding state (Leif Sahlberg) [1827485]
- [fs] cifs: add server param (Leif Sahlberg) [1827485]
- [fs] cifs: add multichannel mount options and data structs (Leif Sahlberg) [1827485]
- [fs] cifs: sort interface list by speed (Leif Sahlberg) [1827485]
- [fs] CIFS: Fix SMB2 oplock break processing (Leif Sahlberg) [1827485]
- [fs] cifs: smbd: Return -EAGAIN when transport is reconnecting (Leif Sahlberg) [1827485]
- [fs] cifs: smbd: Only queue work for error recovery on memory registration (Leif Sahlberg) [1827485]
- [fs] smb3: add debug messages for closing unmatched open (Leif Sahlberg) [1827485]
- [fs] CIFS: Respect O_SYNC and O_DIRECT flags during reconnect (Leif Sahlberg) [1827485]
- [fs] smb3: remove confusing dmesg when mounting with encryption ("seal") (Leif Sahlberg) [1827485]
- [fs] cifs: close the shared root handle on tree disconnect (Leif Sahlberg) [1827485]
- [fs] CIFS: Return directly after a failed build_path_from_dentry() in cifs_do_create() (Leif Sahlberg) [1827485]
- [fs] CIFS: Use common error handling code in smb2_ioctl_query_info() (Leif Sahlberg) [1827485]
- [fs] CIFS: Use memdup_user() rather than duplicating its implementation (Leif Sahlberg) [1827485]
- [fs] cifs: smbd: Return -ECONNABORTED when trasnport is not in connected state (Leif Sahlberg) [1827485]
- [fs] cifs: smbd: Add messages on RDMA session destroy and reconnection (Leif Sahlberg) [1827485]
- [fs] cifs: smbd: Return -EINVAL when the number of iovs exceeds SMBDIRECT_MAX_SGE (Leif Sahlberg) [1827485]
- [fs] cifs: smbd: Invalidate and deregister memory registration on re-send for direct I/O (Leif Sahlberg) [1827485]
- [fs] cifs: Don't display RDMA transport on reconnect (Leif Sahlberg) [1827485]
- [fs] CIFS: remove set but not used variables 'cinode' and 'netfid' (Leif Sahlberg) [1827485]
- [fs] cifs: add support for flock (Leif Sahlberg) [1827485]
- [fs] cifs: remove unused variable 'sid_user' (Leif Sahlberg) [1827485]
- [fs] cifs: rename a variable in SendReceive() (Leif Sahlberg) [1827485]
- [fs] SMB3: Fix persistent handles reconnect (Leif Sahlberg) [1827485]
- [fs] fix memory leak in large read decrypt offload (Leif Sahlberg) [1827485]
- [fs] cifs: Fix missed free operations (Leif Sahlberg) [1827485]
- [fs] cifs: clarify comment about timestamp granularity for old servers (Leif Sahlberg) [1827485]
- [fs] cifs: Handle -EINPROGRESS only when noblockcnt is set (Leif Sahlberg) [1827485]
- [fs] smb3: remove noisy debug message and minor cleanup (Leif Sahlberg) [1827485]
- [fs] fs: cifs: mute -Wunused-const-variable message (Leif Sahlberg) [1827485]
- [fs] smb3: cleanup some recent endian errors spotted by updated sparse (Leif Sahlberg) [1827485]
- [fs] CIFS: Fix oplock handling for SMB 2.1+ protocols (Leif Sahlberg) [1827485]
- [fs] smb3: missing ACL related flags (Leif Sahlberg) [1827485]
- [fs] smb3: pass mode bits into create calls (Leif Sahlberg) [1827485]
- [fs] smb3: Add missing reparse tags (Leif Sahlberg) [1827485]
- [fs] CIFS: fix max ea value size (Leif Sahlberg) [1827485]
- [fs] fs/cifs/sess.c: Remove set but not used variable 'capabilities' (Leif Sahlberg) [1827485]
- [fs] fs/cifs/smb2pdu.c: Make SMB2_notify_init static (Leif Sahlberg) [1827485]
- [fs] smb3: fix leak in "open on server" perf counter (Leif Sahlberg) [1827485]
- [fs] smb3: allow decryption keys to be dumped by admin for debugging (Leif Sahlberg) [1827485]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1827485]
- [fs] cifs: modefromsid: write mode ACE first (Leif Sahlberg) [1827485]
- [fs] cifs: cifsroot: add more err checking (Leif Sahlberg) [1827485]
- [fs] smb3: add missing worker function for SMB3 change notify (Leif Sahlberg) [1827485]
- [fs] cifs: Add support for root file systems (Leif Sahlberg) [1827485]
- [fs] cifs: modefromsid: make room for 4 ACE (Leif Sahlberg) [1827485]
- [fs] smb3: fix potential null dereference in decrypt offload (Leif Sahlberg) [1827485]
- [fs] smb3: allow disabling requesting leases (Leif Sahlberg) [1827485]
- [fs] smb3: improve handling of share deleted (and share recreated) (Leif Sahlberg) [1827485]
- [fs] smb3: display max smb3 requests in flight at any one time (Leif Sahlberg) [1827485]
- [fs] smb3: only offload decryption of read responses if multiple requests (Leif Sahlberg) [1827485]
- [fs] cifs: add a helper to find an existing readable handle to a file (Leif Sahlberg) [1827485]
- [fs] smb3: enable offload of decryption of large reads via mount option (Leif Sahlberg) [1827485]
- [fs] smb3: allow parallelizing decryption of reads (Leif Sahlberg) [1827485]
- [fs] smb3: allow skipping signature verification for perf sensitive configurations (Leif Sahlberg) [1827485]
- [fs] smb3: add dynamic tracepoints for flush and close (Leif Sahlberg) [1827485]
- [fs] smb3: log warning if CSC policy conflicts with cache mount option (Leif Sahlberg) [1827485]
- [fs] smb3: add mount option to allow RW caching of share accessed by only 1 client (Leif Sahlberg) [1827485]
- [fs] smb3: add some more descriptive messages about share when mounting cache=ro (Leif Sahlberg) [1827485]
- [fs] smb3: add mount option to allow forced caching of read only share (Leif Sahlberg) [1827485]
- [fs] cifs: fix dereference on ses before it is null checked (Leif Sahlberg) [1827485]
- [fs] cifs: use existing handle for compound_op(OP_SET_INFO) when possible (Leif Sahlberg) [1827485]
- [fs] cifs: create a helper to find a writeable handle by path name (Leif Sahlberg) [1827485]
- [fs] cifs: remove set but not used variables (Leif Sahlberg) [1827485]
- [fs] smb3: Incorrect size for netname negotiate context (Leif Sahlberg) [1827485]
- [fs] cifs: remove unused variable (Leif Sahlberg) [1827485]
- [fs] cifs: remove redundant assignment to variable rc (Leif Sahlberg) [1827485]
- [fs] smb3: add missing flag definitions (Leif Sahlberg) [1827485]
- [fs] cifs: add passthrough for smb2 setinfo (Leif Sahlberg) [1827485]
- [fs] cifs: prepare SMB2_Flush to be usable in compounds (Leif Sahlberg) [1827485]
- [fs] cifs: allow chmod to set mode bits using special sid (Leif Sahlberg) [1827485]
- [fs] cifs: get mode bits from special sid on stat (Leif Sahlberg) [1827485]
- [fs] fs: cifs: cifsssmb: remove redundant assignment to variable ret (Leif Sahlberg) [1827485]
- [fs] cifs: fix a comment for the timeouts when sending echos (Leif Sahlberg) [1827485]
- [fs] fs: cifs: switch to RC4 library interface (Leif Sahlberg) [1827485]
- [fs] smb3: smbdirect no longer experimental (Leif Sahlberg) [1827485]
- [fs] cifs: copy_file_range needs to strip setuid bits and update timestamps (Leif Sahlberg) [1827485]
- [tools] perf vendor events s390: Add new deflate counters for IBM z15 (Philipp Rudo) [1827333]
- [s390] s390/cpum_cf: Add new extended counters for IBM z15 (Philipp Rudo) [1827333]
- [s390] s390/zcrypt: use kvmalloc instead of kmalloc for 256k alloc (Philipp Rudo) [1827310]
- [s390] s390/pkey/zcrypt: Support EP11 AES secure keys (Philipp Rudo) [1723826]
- [s390] s390/zcrypt: extend EP11 card and queue sysfs attributes (Philipp Rudo) [1723826]
- [s390] s390/zcrypt: add new low level ep11 functions support file (Philipp Rudo) [1723826]
- [s390] s390/zcrypt: ep11 structs rework, export zcrypt_send_ep11_cprb (Philipp Rudo) [1723826]
- [s390] s390/zcrypt: enable card/domain autoselect on ep11 cprbs (Philipp Rudo) [1723826]
- [crypto] crypto/testmgr: enable selftests for paes-s390 ciphers (Philipp Rudo) [1780668]
- [s390] s390/pkey: Add support for key blob with clear key value (Philipp Rudo) [1780668]
- [s390] s390/crypto: enable clear key values for paes ciphers (Philipp Rudo) [1780668]
- [s390] s390/crypto: Rework on paes implementation (Philipp Rudo) [1780668]
- [s390] scsi: zfcp: trace FC Endpoint Security of FCP devices and connections (Philipp Rudo) [1723822]
- [s390] scsi: zfcp: log FC Endpoint Security of connections (Philipp Rudo) [1723822]
- [s390] scsi: zfcp: report FC Endpoint Security in sysfs (Philipp Rudo) [1723822]
- [s390] scsi: zfcp: auto variables for dereferenced structs in open port handler (Philipp Rudo) [1723822]
- [block] blk-iocost: Fix error on iocost_ioc_vrate_adj (Waiman Long) [1828563]
- [s390] s390/ipl: add support to control memory clearing for FCP and CCW re-IPL (Philipp Rudo) [1812985]
- [s390] s390: support KPROBES_ON_FTRACE (Philipp Rudo) [1810526]
- [s390] s390/ftrace: generate traced function stack frame (Philipp Rudo) [1810526]
- [s390] s390/ftrace: save traced function caller (Philipp Rudo) [1810526]
- [misc] mei: me: fix irq number stored in hw struct (Tony Camuso) [1822645]
- [misc] mei: me: add cedar fork device ids (Tony Camuso) [1822645]
- [misc] mei: fix CNL itouch device number to match the spec (Tony Camuso) [1822645]
- [misc] misc: Replace zero-length array with flexible-array member (Tony Camuso) [1822645]
- [misc] mei: remove unused includes from pci-{me, txe}.c (Tony Camuso) [1822645]
- [misc] mei: limit number of bytes in mei header (Tony Camuso) [1822645]
- [misc] mei: bus: replace zero-length array with flexible-array member (Tony Camuso) [1822645]
- [misc] mei: me: add jasper point DID (Tony Camuso) [1822645]
- [misc] mei: hdcp: bind only with i915 on the same PCH (Tony Camuso) [1822645]
- [misc] mei: bus: use simple sprintf for sysfs (Tony Camuso) [1822645]
- [misc] mei: bus: add more client attributes to sysfs (Tony Camuso) [1822645]
- [misc] mei: add trc detection register to sysfs (Tony Camuso) [1822645]
- [misc] mei: abstract fw status register read (Tony Camuso) [1822645]
- [misc] mei: me: store irq number in the hw struct (Tony Camuso) [1822645]
- [misc] mei: me: mei_me_dev_init() use struct device instead of struct pci_dev (Tony Camuso) [1822645]
- [misc] mei: me: add comet point V device id (Tony Camuso) [1822645]
- [misc] mei: bus: prefix device names on bus with the bus name (Tony Camuso) [1822645]
- [misc] mei: me: fix me_intr_clear function name in KDoc (Tony Camuso) [1822645]
- [misc] mei: buf: drop 'running hook' debug messages (Tony Camuso) [1822645]
- [misc] mei: avoid FW version request on Ibex Peak and earlier (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Fill transcoder index in port info (Tony Camuso) [1822645]
- [misc] drm/i915: mei_hdcp: I915 sends ddi index as per ME FW (Tony Camuso) [1822645]
- [drm] drm/i915: Attach content type property (Tony Camuso) [1822645]
- [drm] drm: Add Content protection type property (Tony Camuso) [1822645]
- [misc] mei: me: add Tiger Lake point LP device ID (Tony Camuso) [1822645]
- [misc] mei: Use dev_get_drvdata where possible (Tony Camuso) [1822645]
- [misc] mei: me: add mule creek canyon (EHL) device ids (Tony Camuso) [1822645]
- [misc] mei: no need to check return value of debugfs_create functions (Tony Camuso) [1822645]
- [documentation] mei: docs: add hdcp documentation (Tony Camuso) [1822645]
- [documentation] mei: docs: add a short description for nfc behind mei (Tony Camuso) [1822645]
- [documentation] mei: docs: update mei client bus documentation (Tony Camuso) [1822645]
- [documentation] mei: docs: move iamt docs to a iamt.rst file (Tony Camuso) [1822645]
- [documentation] mei: docs: move documentation under driver-api (Tony Camuso) [1822645]
- [misc] mei: Convert to use DEFINE_SHOW_ATTRIBUTE macro (Tony Camuso) [1822645]
- [drm] drm: generic fn converting be24 to cpu and vice versa (Tony Camuso) [1822645]
- [misc] mei: expose device state in sysfs (Tony Camuso) [1822645]
- [misc] mei: hdcp: use own Kconfig file (Tony Camuso) [1822645]
- [misc] mei: adjust the copyright notice in the files (Tony Camuso) [1822645]
- [misc] mei/hdcp: Fix SPDX identifiers (Tony Camuso) [1822645]
- [misc] mei: convert to SPDX license tags (Tony Camuso) [1822645]
- [misc] mei: add missing SPDX tag to mei Kconfig (Tony Camuso) [1822645]
- [misc] mei: bus: move hw module get/put to probe/release (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Component framework for I915 Interface (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Closing wired HDCP2.2 Tx Session (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Enabling the HDCP authentication (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Verify M_prime (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Repeater topology verification and ack (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Prepare Session Key (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Verify L_prime (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Initiate Locality check (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Store the HDCP Pairing info (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Verify H_prime (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Verify Receiver Cert and prepare km (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Initiate Wired HDCP2.2 Tx Session (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Define ME FW interface for HDCP2.2 (Tony Camuso) [1822645]
- [misc] misc/mei/hdcp: Client driver for HDCP application (Tony Camuso) [1822645]
- [misc] mei: bus: whitelist hdcp client (Tony Camuso) [1822645]
- [misc] mei: hbm: clean the feature flags on link reset (Tony Camuso) [1822645]
- [misc] mei: bus: export to_mei_cl_device for mei client devices drivers (Tony Camuso) [1822645]
- [misc] mei: free read cb on ctrl_wr list flush (Tony Camuso) [1822645]
- [misc] mei: me: add ice lake point device id (Tony Camuso) [1822645]
- [misc] mei: squash single_recv_buf into one bit in client properties (Tony Camuso) [1822645]
- [misc] mei: me: add denverton innovation engine device IDs (Tony Camuso) [1822645]
- [misc] mei: me: mark LBG devices as having dma support (Tony Camuso) [1822645]
- [misc] mei: dma: silent the reject message (Tony Camuso) [1822645]
- [misc] mei: me: mark CNP devices as having dma support (Tony Camuso) [1822645]
- [misc] mei: bump hbm version to 2.1 (Tony Camuso) [1822645]
- [misc] mei: dma ring: implement transmit flow (Tony Camuso) [1822645]
- [misc] mei: dma ring: implement rx circular buffer logic (Tony Camuso) [1822645]
- [misc] mei: hw: add dma ring control block (Tony Camuso) [1822645]
- [misc] mei: hbm: setup dma ring (Tony Camuso) [1822645]
- [misc] mei: dma ring buffers allocation (Tony Camuso) [1822645]
- [misc] mei: expedite ioctl return on the notify set operation error (Tony Camuso) [1822645]
- [misc] mei: flush queues by the host client only (Tony Camuso) [1822645]
- [misc] mei: hbm: drop BUG() from the hbm handler (Tony Camuso) [1822645]
- [misc] mei: replace POLL* with EPOLL* for write queues (Tony Camuso) [1822645]
- [misc] misc: remove redundant include moduleparam.h (Tony Camuso) [1822645]
- [misc] mei: bus: need to unlink client before freeing (Tony Camuso) [1822645]
- [misc] mei: bus: fix hw module get/put balance (Tony Camuso) [1822645]
- [misc] mei: fix use-after-free in mei_cl_write (Tony Camuso) [1822645]
- [misc] mei: ignore not found client in the enumeration (Tony Camuso) [1822645]
- [misc] mei: restrict dma ring support to hbm version 2.1 (Tony Camuso) [1822645]
- [misc] mei: hbm: introduce dma bit in the message header (Tony Camuso) [1822645]
- [misc] mei: add support for variable length mei headers (Tony Camuso) [1822645]
- [misc] mei: add mei_msg_hdr_init wrapper (Tony Camuso) [1822645]
- [misc] mei: move hbuf_depth from the mei device to the hw modules (Tony Camuso) [1822645]
- [misc] mei: cleanup slots to data conversions (Tony Camuso) [1822645]
- [misc] mei: bus: suppress sign-compare warnings (Tony Camuso) [1822645]
- [misc] mei: fix ssize_t to int assignment in read and write ops (Tony Camuso) [1822645]
- [misc] mei: use correct type for counter variable in for loops (Tony Camuso) [1822645]
- [misc] mei: check for error returned from mei_hbuf_empty_slots() (Tony Camuso) [1822645]
- [misc] mei: don't update offset in write (Tony Camuso) [1822645]
- [misc] mei: bus: type promotion bug in mei_fwver() (Tony Camuso) [1822645]
- [misc] mei: bus: type promotion bug in mei_nfc_if_version() (Tony Camuso) [1822645]
- [misc] mei: expose fw version to sysfs (Tony Camuso) [1822645]
- [misc] mei: add optional timeout to internal bus recv (Tony Camuso) [1822645]
- [misc] mei: remove unused MEI_IAMTHIF_STALL_TIMER define (Tony Camuso) [1822645]
- [s390] s390/pci: Fix unexpected write combine on resource (Philipp Rudo) [1827311]
- [powerpc] pwerpc/vas: Include linux/types.h in uapi/asm/vas-api.h (Gustavo Duarte) [1725806]
- [documentation] Documentation/powerpc: VAS API (Gustavo Duarte) [1725806]
- [crypto] crypto/nx: Remove 'pid' in vas_tx_win_attr struct (Gustavo Duarte) [1725806]
- [crypto] crypto/nx: Enable and setup GZIP compresstion type (Gustavo Duarte) [1725806]
- [crypto] crypto/nx: Make enable code generic to add new GZIP compression type (Gustavo Duarte) [1725806]
- [crypto] crypto/nx: Rename nx-842-powernv file name to nx-common-powernv (Gustavo Duarte) [1725806]
- [crypto] crypto/nx: Initialize coproc entry with kzalloc (Gustavo Duarte) [1725806]
- [crypto] crypto: nx - Add of_node_put() before return in 842 (Gustavo Duarte) [1725806]
- [crypto] crypto/NX: Set receive window credits to max number of CRBs in RxFIFO (Gustavo Duarte) [1725806]
- [powerpc] crypto/nx: Initialize 842 high and normal RxFIFO control registers (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Add VAS user space API (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Define VAS_TX_WIN_OPEN ioctl API (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Initialize window attributes for GZIP coprocessor type (Gustavo Duarte) [1725806]
- [powerpc] powerpc: Use mm_context vas_windows counter to issue CP_ABORT (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Free send window in VAS instance after credits returned (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Display process stuck message (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Do not use default credits for receive window (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Print CRB and FIFO values (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Return credits after handling fault (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Update CSB and notify process for fault CRBs (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Setup thread IRQ handler per VAS instance (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Take reference to PID and mm for user space windows (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Register NX with fault window ID and IRQ port value (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Setup fault window per VAS instance (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Alloc and setup IRQ and trigger port (Gustavo Duarte) [1725806]
- [powerpc] powerpc/vas: Define nx_fault_stamp in coprocessor_request_block (Gustavo Duarte) [1725806]
- [powerpc] powerpc/xive: Define xive_native_alloc_irq_on_chip() (Gustavo Duarte) [1725806]
- [powerpc] powerpc/powernv: remove the unused vas_win_paste_addr and vas_win_id functions (Gustavo Duarte) [1725806]
- [tools] intel-speed-select: Fix speed-select-base-freq-properties output on CLX-N (Prarit Bhargava) [1828306]
- [tools] tools/power/x86/intel-speed-select: Fix CLX-N package information output (Prarit Bhargava) [1828306]
- [kernel] sched/isolation: Allow "isolcpus=" to skip unknown sub-parameters (Peter Xu) [1799014]
- [arm64] arm64: tlb: skip tlbi broadcast, fix speculative tlb lookups (Andrea Arcangeli) [1820817]
- [x86] pci: hv: Introduce hv_msi_entry (Mohammed Gamal) [1816740]
- [pci] hv: Move retarget related structures into tlfs header (Mohammed Gamal) [1816740]
- [pci] hv: Move hypercall related definitions into tlfs header (Mohammed Gamal) [1816740]
- [pci] hv: Reorganize the code in preparation of hibernation (Mohammed Gamal) [1816740]
- [pci] hv: Add a Hyper-V PCI interface driver for software backchannel interface (Mohammed Gamal) [1816740]
- [pci] hv: Add a paravirtual backchannel in software (Mohammed Gamal) [1816740]

* Thu Apr 30 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-194.el8]
- [include] i2c: fix a doc warning (David Arcari) [1826759]
- [i2c] i2c: acpi: put device when verifying client fails (David Arcari) [1826759]
- [i2c] i2c: i2c-core-of: convert to use i2c_new_client_device() (David Arcari) [1826759]
- [i2c] i2c: i2c-core-base: convert to use i2c_new_client_device() (David Arcari) [1826759]
- [i2c] i2c: i2c-core-acpi: convert to use i2c_new_client_device() (David Arcari) [1826759]
- [i2c] i2c: fix bus recovery stop mode timing (David Arcari) [1826759]
- [i2c] i2c: core: Use DEVICE_ATTR_*() helper macros (David Arcari) [1826759]
- [include] i2c: remove unneeded 'extern' from function declatations (David Arcari) [1826759]
- [include] i2c: add helper to check if a client has a driver attached (David Arcari) [1826759]
- [include] i2c: fix header file kernel-doc warning (David Arcari) [1826759]
- [misc] eeprom: at24: use devm_i2c_new_dummy_device() (David Arcari) [1826759]
- [i2c] i2c: remove i2c_new_dummy() API (David Arcari) [1826759]
- [media] media: dvb-frontends: cxd2820r_core: convert to i2c_new_dummy_device (David Arcari) [1826759]
- [media] media: dvb-frontends: mn88473: convert to i2c_new_dummy_device (David Arcari) [1826759]
- [media] media: dvb-frontends: mn88472: convert to i2c_new_dummy_device (David Arcari) [1826759]
- [hwmon] hwmon: (w83791d) convert to use devm_i2c_new_dummy_device (David Arcari) [1826759]
- [hwmon] hwmon: (w83793d) convert to use devm_i2c_new_dummy_device (David Arcari) [1826759]
- [hwmon] hwmon: (w83781d) convert to i2c_new_dummy_device (David Arcari) [1826759]
- [media] media: ir-kbd-i2c: convert to i2c_new_dummy_device() (David Arcari) [1826759]
- [misc] misc: eeprom: max6875: convert to i2c_new_dummy_device (David Arcari) [1826759]
- [hwmon] hwmon: (w83792d) convert to use devm_i2c_new_dummy_device (David Arcari) [1826759]
- [hwmon] hwmon: (asb100) convert to i2c_new_dummy_device (David Arcari) [1826759]
- [i2c] i2c: replace i2c_new_probed_device with an ERR_PTR variant (David Arcari) [1826759]
- [i2c] i2c: smbus: Don't filter out duplicate alerts (David Arcari) [1826759]
- [i2c] i2c: of: Populate fwnode in of_i2c_get_board_info() (David Arcari) [1826759]
- [i2c] i2c: remove helpers for ref-counting clients (David Arcari) [1826759]
- [i2c] i2c: core: fix use after free in of_i2c_notify (David Arcari) [1826759]
- [i2c] i2c: acpi: Force bus speed to 400KHz if a Silead touchscreen is present (David Arcari) [1826759]
- [i2c] i2c: add support for filters optional properties (David Arcari) [1826759]
- [i2c] i2c: slave-eeprom: Add read only mode (David Arcari) [1826759]
- [i2c] i2c: slave-eeprom: Add comment about address handling (David Arcari) [1826759]
- [i2c] i2c-eeprom_slave: Add support for more eeprom models (David Arcari) [1826759]
- [i2c] i2c: make i2c_unregister_device() ERR_PTR safe (David Arcari) [1826759]
- [media] i2c: replace i2c_new_secondary_device with an ERR_PTR variant (David Arcari) [1826759]
- [i2c] i2c: Drop unneeded check for of_node (David Arcari) [1826759]
- [i2c] i2c: core: Tidy up handling of init_irq (David Arcari) [1826759]
- [i2c] i2c: core: Move ACPI gpio IRQ handling into i2c_acpi_get_irq (David Arcari) [1826759]
- [i2c] i2c: core: Move ACPI IRQ handling to probe time (David Arcari) [1826759]
- [i2c] i2c: acpi: Factor out getting the IRQ from ACPI (David Arcari) [1826759]
- [i2c] i2c: acpi: Use available IRQ helper functions (David Arcari) [1826759]
- [i2c] i2c: core: Allow whole core to use i2c_dev_irq_from_resources (David Arcari) [1826759]
- [i2c] i2c: core: add sysfs header (David Arcari) [1826759]
- [i2c] i2c: add newly exported functions to the header, too (David Arcari) [1826759]
- [i2c] i2c: mux: add sysfs header (David Arcari) [1826759]
- [include] i2c: headers: reformat header comment and update copyright (David Arcari) [1826759]
- [include] i2c: headers: update docs about I2C_CLIENT_* (David Arcari) [1826759]
- [i2c] i2c: core: always have a named variable in arguments (David Arcari) [1826759]
- [include] i2c: headers: always have a named variable in arguments (David Arcari) [1826759]
- [include] i2c: headers: don't use 'dev' as adapter variable (David Arcari) [1826759]
- [i2c] i2c: mux: Use struct_size() in devm_kzalloc() (David Arcari) [1826759]
- [i2c] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (David Arcari) [1826759]
- [i2c] i2c: acpi: export i2c_acpi_find_adapter_by_handle (David Arcari) [1826759]
- [media] tua6100: Avoid build warnings (David Arcari) [1826759]
- [i2c] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (David Arcari) [1826759]
- [i2c] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (David Arcari) [1826759]
- [i2c] i2c: acpi: permit bus speed to be discovered after enumeration (David Arcari) [1826759]
- [i2c] i2c: dev: fix potential memory leak in i2cdev_ioctl_rdwr (David Arcari) [1826759]
- [include] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 1 (David Arcari) [1826759]
- [i2c] treewide: Add SPDX license identifier - Makefile/Kconfig (David Arcari) [1826759]
- [i2c] i2c: core: add device-managed version of i2c_new_dummy (David Arcari) [1826759]
- [i2c] i2c: core: improve return value handling of i2c_new_device and i2c_new_dummy (David Arcari) [1826759]
- [i2c] i2c: core: apply 'is_suspended' check for SMBus, too (David Arcari) [1826759]
- [i2c] i2c: core: ratelimit 'transfer when suspended' errors (David Arcari) [1826759]
- [i2c] i2c: Prevent runtime suspend of adapter when Host Notify is required (David Arcari) [1826759]
- [i2c] gcc-9: don't warn about uninitialized variable (David Arcari) [1826759]
- [i2c] i2c: mux: populate the new *_atomic callbacks (David Arcari) [1826759]
- [i2c] i2c: core: introduce callbacks for atomic transfers (David Arcari) [1826759]
- [i2c] i2c: core: use I2C locking behaviour also for SMBUS (David Arcari) [1826759]
- [i2c] i2c: core: remove use of in_atomic() (David Arcari) [1826759]
- [include] i2c: apply coding style for struct i2c_adapter (David Arcari) [1826759]
- [i2c] i2c: add extra check to safe DMA buffer helper (David Arcari) [1826759]
- [i2c] i2c: Allow recovery of the initial IRQ by an I2C client device (David Arcari) [1826759]
- [i2c] i2c: expand minor range when registering chrdev region (David Arcari) [1826759]
- [i2c] i2c: core-smbus: don't trace smbus_reply data on errors (David Arcari) [1826759]
- [i2c] i2c: of: Try to find an I2C adapter matching the parent (David Arcari) [1826759]
- [include] i2c: acpi: Move I2C bits from acpi.h to i2c.h (David Arcari) [1826759]
- [i2c] i2c: dev: prevent adapter retries and timeout being set as minus value (David Arcari) [1826759]
- [i2c] i2c: add suspended flag and accessors for i2c adapters (David Arcari) [1826759]
- [i2c] treewide: surround Kconfig file paths with double quotes (David Arcari) [1826759]
- [i2c] i2c: acpi: Introduce i2c_acpi_get_i2c_resource() helper (David Arcari) [1826759]
- [i2c] i2c: acpi: Use ACPI_FAILURE instead of !ACPI_SUCCESS (David Arcari) [1826759]
- [i2c] i2c: acpi: Return error pointers from i2c_acpi_new_device() (David Arcari) [1826759]
- [i2c] i2c: Clear client->irq in i2c_device_remove (David Arcari) [1826759]
- [i2c] i2c: Remove unnecessary call to irq_find_mapping (David Arcari) [1826759]
- [i2c] i2c: Fix kerneldoc for renamed i2c dma put function (David Arcari) [1826759]
- [i2c] i2c: core: remove level of indentation in i2c_transfer (David Arcari) [1826759]
- [i2c] i2c: core: remove outdated DEBUG output (David Arcari) [1826759]
- [i2c] i2c: refactor function to release a DMA safe buffer (David Arcari) [1826759]
- [i2c] i2c: don't use any __deprecated handling anymore (David Arcari) [1826759]
- [i2c] i2c: remove deprecated attach_adapter callback (David Arcari) [1826759]
- [i2c] i2c: core: Parse SDA hold time from firmware (David Arcari) [1826759]
- [i2c] i2c: quirks: add zero length checks (David Arcari) [1826759]
- [i2c] i2c: recovery: make pin init look like STOP (David Arcari) [1826759]
- [i2c] i2c: recovery: rename variable for easier understanding (David Arcari) [1826759]
- [i2c] i2c: recovery: add get_bus_free callback (David Arcari) [1826759]
- [i2c] i2c: recovery: refactor recovery function (David Arcari) [1826759]
- [i2c] i2c: recovery: require either get_sda or set_sda (David Arcari) [1826759]
- [i2c] i2c: remove i2c_lock_adapter and use i2c_lock_bus directly (David Arcari) [1826759]
- [media] media: tda1004x: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (David Arcari) [1826759]
- [media] media: tda18271: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (David Arcari) [1826759]
- [media] media: af9013: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (David Arcari) [1826759]
- [media] media: drxk_hard: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (David Arcari) [1826759]
- [media] media: rtl2830: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (David Arcari) [1826759]
- [i2c] i2c: mux: pca9541: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (David Arcari) [1826759]
- [i2c] i2c: mux: make use of __i2c_smbus_xfer (David Arcari) [1826759]
- [kvm] KVM: PPC: Book3S HV: Fix H_CEDE return code for nested guests (David Gibson) [1778556]
- [block] block/diskstats: more accurate approximation of io_ticks for slow disks (Ming Lei) [1811745]
- [scsi] scsi: storvsc: Correctly set number of hardware queues for IDE disk (Cathy Avery) [1816702]
- [netdrv] bonding/alb: make sure arp header is pulled before accessing it (Jarod Wilson) [1819408]
- [netdrv] bonding/alb: properly access headers in bond_alb_xmit() (Jarod Wilson) [1819408]
- [netdrv] bonding: rename AD_STATE_* to LACP_STATE_* (Jarod Wilson) [1819408]
- [netdrv] bonding: fix active-backup transition after link failure (Jarod Wilson) [1819408]
- [netdrv] bonding: move 802.3ad port state flags to uapi (Jarod Wilson) [1819408]
- [netdrv] bonding: fix bond_neigh_init() (Jarod Wilson) [1819408]
- [netdrv] bonding: fix state transition issue in link monitoring (Jarod Wilson) [1819408]
- [netdrv] bonding: fix potential NULL deref in bond_update_slave_arr (Jarod Wilson) [1819408]
- [netdrv] team: Always enable vlan tx offload (Hangbin Liu) [1827017]
- [net] netlink: Use netlink header as base to calculate bad attribute offset (Andrea Claudi) [1825252]
- [net] netlink: cap max groups which will be considered in netlink_bind() (Andrea Claudi) [1825252]
- [net] tcp: repair: fix TCP_QUEUE_SEQ implementation (Paolo Abeni) [1823771]
- [net] tcp: fix "old stuff" D-SACK causing SACK to be treated as D-SACK (Paolo Abeni) [1823771]
- [net] tcp: refine rule to allow EPOLLOUT generation under mem pressure (Paolo Abeni) [1823771]
- [net] tcp: refine tcp_write_queue_empty() implementation (Paolo Abeni) [1823771]
- [include] fib: add missing attribute validation for tun_id (Marcelo Leitner) [1823468]
- [include] net/flow_dissector: remove unexist field description (Marcelo Leitner) [1823468]
- [net] vlan: vlan_changelink() should propagate errors (Marcelo Leitner) [1823468]
- [net] af_packet: set defaule value for tmo (Marcelo Leitner) [1823468]
- [net] packet: fix data-race in fanout_flow_is_huge() (Marcelo Leitner) [1823468]
- [net] llc: fix sk_buff refcounting in llc_conn_state_process() (Marcelo Leitner) [1823468]
- [net] llc: fix another potential sk_buff leak in llc_ui_sendmsg() (Marcelo Leitner) [1823468]
- [net] llc: fix sk_buff leak in llc_conn_service() (Marcelo Leitner) [1823468]
- [net] llc: fix sk_buff leak in llc_sap_state_process() (Marcelo Leitner) [1823468]
- [net] openvswitch: Fix conntrack cache with timeout (Patrlck Talbert) [1765587]
- [net] openvswitch: Fix log message in ovs conntrack (Patrlck Talbert) [1765587]
- [net] openvswitch: use after free in __ovs_ct_free_action() (Patrlck Talbert) [1765587]
- [net] openvswitch: Add timeout support to ct action (Patrlck Talbert) [1765587]
- [net] netfilter: Export nf_ct_{set, destroy}_timeout() (Patrlck Talbert) [1765587]
- [net] netfilter: cttimeout: ctnl_timeout_find_get() returns incorrect pointer to type (Patrlck Talbert) [1765587]
- [net] netfilter: remove ifdef around cttimeout in struct nf_conntrack_l4proto (Patrlck Talbert) [1765587]
- [net] netfilter: cttimeout: decouple timeout policy from nfnetlink_cttimeout object (Patrlck Talbert) [1765587]
- [net] netfilter: cttimeout: move ctnl_untimeout to nf_conntrack (Patrlck Talbert) [1765587]
- [netdrv] ipvlan: do not use cond_resched_rcu() in ipvlan_process_multicast() (Davide Caratti) [1822906]
- [netdrv] ipvlan: add cond_resched_rcu() while processing muticast backlog (Davide Caratti) [1822906]
- [netdrv] ipvlan: don't deref eth hdr before checking it's set (Davide Caratti) [1822906]
- [netdrv] ipvlan: do not add hardware address of master to its unicast filter list (Davide Caratti) [1822906]
- [include] net/dst: do not confirm neighbor for vxlan and geneve pmtu update (Hangbin Liu) [1755686]
- [net] sit: do not confirm neighbor when do pmtu update (Hangbin Liu) [1755686]
- [net] vti: do not confirm neighbor when do pmtu update (Hangbin Liu) [1755686]
- [net] tunnel: do not confirm neighbor when do pmtu update (Hangbin Liu) [1755686]
- [include] net/dst: add new function skb_dst_update_pmtu_no_confirm (Hangbin Liu) [1755686]
- [netdrv] gtp: do not confirm neighbor when do pmtu update (Hangbin Liu) [1755686]
- [net] ip6_gre: do not confirm neighbor when do pmtu update (Hangbin Liu) [1755686]
- [net] add bool confirm_neigh parameter for dst_ops.update_pmtu (Hangbin Liu) [1755686]
- [net] neigh: support smaller retrans_time settting (Hangbin Liu) [1767282]
- [include] net: core: add helper tcp_v6_gso_csum_prep (Josef Oskera) [1818097]
- [net] ip_tunnel: fix interface lookup with no key (Guillaume Nault) [1822247]
- [net] ipv4: fix a RCU-list lock in inet_dump_fib() (Guillaume Nault) [1822247]
- [net] gre: fix uninit-value in __iptunnel_pull_header (Guillaume Nault) [1822247]
- [net] netfilter: conntrack: allow insertion of clashing entries (Florian Westphal) [1821404]
- [net] netfilter: conntrack: split resolve_clash function (Florian Westphal) [1821404]
- [net] netfilter: conntrack: place confirm-bit setting in a helper (Florian Westphal) [1821404]
- [net] netfilter: never get/set skb->tstamp (Florian Westphal) [1821404]
- [net] netfilter: conntrack: remove two args from resolve_clash (Florian Westphal) [1821404]
- [net] netfilter: conntrack: tell compiler to not inline nf_ct_resolve_clash (Florian Westphal) [1821404]
- [netdrv] macsec: restrict to ethernet devices (Sabrina Dubroca) [1820524]
- [netdrv] macsec: add missing attribute validation for port (Sabrina Dubroca) [1820524]
- [net] netns: restore ops before calling ops_exit_list (Ivan Vecera) [1822568]
- [net] netns: add pre_exit method to struct pernet_operations (Ivan Vecera) [1822568]
- [include] net: dst: Force 4-byte alignment of dst_metrics (Guillaume Nault) [1822148]
- [include] net: annotate lockless accesses to sk->sk_napi_id (Guillaume Nault) [1822148]
- [net] Fix typo of SKB_SGO_CB_OFFSET (Guillaume Nault) [1822148]
- [net] use indirect call wrappers for skb_copy_datagram_iter() (Guillaume Nault) [1822148]
- [net] datagram: Make __skb_datagram_iter static (Guillaume Nault) [1822148]
- [net] Fix Tx hash bound checking (Guillaume Nault) [1822148]
- [net] openvswitch: add missing attribute validation for hash (Eelco Chaudron) [1819202]
- [net] openvswitch: Distribute switch variables for initialization (Eelco Chaudron) [1819202]
- [net] openvswitch: support asymmetric conntrack (Eelco Chaudron) [1819202]
- [net] openvswitch: remove another BUG_ON() (Eelco Chaudron) [1819202]
- [net] openvswitch: drop unneeded BUG_ON() in ovs_flow_cmd_build_info() (Eelco Chaudron) [1819202]
- [net] openvswitch: don't call pad_packet if not necessary (Eelco Chaudron) [1819202]
- [net] openvswitch: add hash info to upcall (Eelco Chaudron) [1819202]
- [net] openvswitch: select vport upcall portid directly (Eelco Chaudron) [1819202]
- [net] openvswitch: simplify the ovs_dp_cmd_new (Eelco Chaudron) [1819202]
- [net] openvswitch: fix possible memleak on destroy flow-table (Eelco Chaudron) [1819202]
- [net] openvswitch: add likely in flow_lookup (Eelco Chaudron) [1819202]
- [net] openvswitch: simplify the flow_hash (Eelco Chaudron) [1819202]
- [net] openvswitch: optimize flow-mask looking up (Eelco Chaudron) [1819202]
- [net] openvswitch: optimize flow mask cache hash collision (Eelco Chaudron) [1819202]
- [net] openvswitch: shrink the mask array if necessary (Eelco Chaudron) [1819202]
- [net] openvswitch: convert mask list in mask array (Eelco Chaudron) [1819202]
- [net] openvswitch: add flow-mask cache for performance (Eelco Chaudron) [1819202]
- [net] openvswitch: Allow attaching helper in later commit (Eelco Chaudron) [1819202]
- [net] openvswitch: change type of UPCALL_PID attribute to NLA_UNSPEC (Eelco Chaudron) [1819202]
- [net] openvswitch: Make metadata_dst tunnel work in IP_TUNNEL_INFO_BRIDGE mode (Eelco Chaudron) [1819202]
- [netdrv] mlxsw: spectrum_router: Remove unlikely user-triggerable warning (Ivan Vecera) [1821358]
- [net] ipv6: Error when route does not have any valid nexthops (Ivan Vecera) [1821358]
- [tools] selftests: mlxsw: Add a test for FIB offload indication (Ivan Vecera) [1821358]
- [net] ipv6: Stop sending in-kernel notifications for each nexthop (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Create IPv6 multipath routes in one go (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Add / delete multiple IPv6 nexthops (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Pass array of routes to route handling functions (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Adjust IPv6 replace logic to new notifications (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Pass multiple routes to work item (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Prepare function to return errors (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Remove processing of IPv6 append notifications (Ivan Vecera) [1821358]
- [net] ipv6: Add IPv6 multipath notification for route delete (Ivan Vecera) [1821358]
- [net] ipv6: Add IPv6 multipath notifications for add / replace (Ivan Vecera) [1821358]
- [netdrv] netdevsim: Ignore IPv6 multipath notifications (Ivan Vecera) [1821358]
- [netdrv] mlxsw: spectrum_router: Ignore IPv6 multipath notifications (Ivan Vecera) [1821358]
- [net] ipv6: Extend notifier info for multipath routes (Ivan Vecera) [1821358]
- [net] ipv6: export function to send route updates (Ivan Vecera) [1821358]
- [net] sctp: fix possibly using a bad saddr with a given dst (Xin Long) [1821578]
- [net] sctp: fix refcount bug in sctp_wfree (Xin Long) [1821578]
- [net] sctp: move the format error check out of __sctp_sf_do_9_1_abort (Xin Long) [1821578]
- [net] Remove switchdev_ops (Ivan Vecera) [1821402]
- [net] switchdev: Replace port attr set SDO with a notification (Ivan Vecera) [1821402]
- [net] switchdev: Complete removal of switchdev_port_attr_get() (Ivan Vecera) [1821402]
- [net] Get rid of switchdev_port_attr_get() (Ivan Vecera) [1821402]
- [net] Remove SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS_SUPPORT (Ivan Vecera) [1821402]
- [net] fib_notifier: move fib_notifier_ops from struct net into per-net struct (Ivan Vecera) [1821186]
- [net] Properly unlink GRO packets on overflow. (Ivan Vecera) [1805302]
- [net] Add and use skb_list_del_init(). (Ivan Vecera) [1805302]
- [net] Add and use skb_mark_not_on_list(). (Ivan Vecera) [1805302]
- [net] Init backlog NAPI's gro_hash. (Ivan Vecera) [1805302]
- [net] gro: properly remove skb from list (Ivan Vecera) [1805302]
- [net] core: trivial netif_receive_skb_list() entry point (Ivan Vecera) [1805302]
- [net] Convert GRO SKB handling to list_head. (Ivan Vecera) [1805302]
- [net] ipv6: don't auto-add link-local address to lag ports (Jarod Wilson) [1733953]
- [tools] selftests: forwarding: vxlan_bridge_1d: use more proper tos value (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: vxlan_bridge_1d: fix tos value (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: use proto icmp for {gretap, ip6gretap}_mac testing (Hangbin Liu) [1816587]
- [tools] fcnal-test: Fix vrf argument in local tcp tests (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: router: Add test case for destination IP link-local (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: router: Add test case for source IP equals destination IP (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: router: Add test case for multicast destination MAC mismatch (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: router: Add test case for source IP in class E (Hangbin Liu) [1816587]
- [tools] selftests/net: make so_txtime more robust to timer variance (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: Add speed and auto-negotiation test (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: lib.sh: Add wait for dev with timeout (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: Add ethtool_lib.sh (Hangbin Liu) [1816587]
- [tools] selftests: net: avoid ptl lock contention in tcp_mmap (Hangbin Liu) [1816587]
- [tools] selftest: net: add alternative names test (Hangbin Liu) [1816587]
- [tools] selftest: net: add some traceroute tests (Hangbin Liu) [1816587]
- [tools] selftests: net: Fix printf format warnings on arm (Hangbin Liu) [1816587]
- [tools] selftests: net: Use size_t and ssize_t for counting file size (Hangbin Liu) [1816587]
- [tools] selftests: Make l2tp.sh executable (Hangbin Liu) [1816587]
- [tools] selftests/net: add nettest to .gitignore (Hangbin Liu) [1816587]
- [tools] selftests: Add test cases for `ip nexthop flush proto XX` (Hangbin Liu) [1816587]
- [tools] selftest: A few cleanups for fib_nexthops.sh (Hangbin Liu) [1816587]
- [tools] selftests: Fix get_ifidx and callers in nettest.c (Hangbin Liu) [1816587]
- [tools] selftests: Fix detection of nettest command in fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add l2tp tests (Hangbin Liu) [1816587]
- [tools] selftests: nettest: fix spelling mistake: "potocol" -> "protocol" (Hangbin Liu) [1816587]
- [tools] selftests: Add use case section to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv6 netfilter tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv4 netfilter tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv6 runtime tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv4 runtime tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv6 address bind tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv4 address bind tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv6 udp tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv4 udp tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv6 tcp tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv4 tcp tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv6 ping tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Add ipv4 ping tests to fcnal-test (Hangbin Liu) [1816587]
- [tools] selftests: Setup for functional tests for fib and socket lookups (Hangbin Liu) [1816587]
- [tools] selftests: Add nettest (Hangbin Liu) [1816587]
- [tools] selftests/net: add missing gitignores (ipv6_flowlabel) (Hangbin Liu) [1816587]
- [tools] selftests: txring_overwrite: fix incorrect test of mmap() return value (Hangbin Liu) [1816587]
- [tools] selftests/net: skip psock_tpacket test if KALLSYMS was not enabled (Hangbin Liu) [1816587]
- [tools] selftests: rtnetlink: skip ipsec offload tests if netdevsim isn't present (Hangbin Liu) [1816587]
- [tools] selftests: Add test cases for nexthop objects (Hangbin Liu) [1816587]
- [tools] selftests/net: ipv6 flowlabel (Hangbin Liu) [1816587]
- [tools] selftests/net: SO_TXTIME with ETF and FQ (Hangbin Liu) [1816587]
- [tools] selftests: fib-onlink: Make quiet by default (Hangbin Liu) [1816587]
- [tools] selftests/net: correct the return value for run_afpackettests (Hangbin Liu) [1816587]
- [tools] selftests/net: correct the return value for run_netsocktests (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: Add reverse path forwarding (RPF) test cases (Hangbin Liu) [1816587]
- [tools] selftest/net: Remove duplicate header (Hangbin Liu) [1816587]
- [tools] selftests: fib_tests: sleep after changing carrier. again. (Hangbin Liu) [1816587]
- [tools] selftests: net: use LDLIBS instead of LDFLAGS (Hangbin Liu) [1816587]
- [tools] selftests/net: add txring_overwrite (Hangbin Liu) [1816587]
- [tools] fib_tests: Add tests for invalid metric on route (Hangbin Liu) [1816587]
- [tools] selftests: forwarding: test for bridge sticky flag (Hangbin Liu) [1816587]
- [tools] selftests: net: Test headroom handling of ip6_gre devices (Hangbin Liu) [1816587]
- [net] Don't disable interrupts in __netdev_alloc_skb() (Andrea Claudi) [1811207]
- [net] Don't disable interrupts in napi_alloc_frag() (Andrea Claudi) [1811207]
- [net] ipv4: ensure rcu_read_lock() in cipso_v4_error() (Matteo Croce) [1720708]
- [net] ipv4: add sanity checks in ipv4_link_failure() (Matteo Croce) [1720708]
- [net] ipv4: ensure rcu_read_lock() in ipv4_link_failure() (Matteo Croce) [1720708]
- [net] ipv4: recompile ip options in ipv4_link_failure (Matteo Croce) [1720708]
- [net] avoid use IPCB in cipso_v4_error (Matteo Croce) [1720708]
- [net] Add __icmp_send helper. (Matteo Croce) [1720708]
- [net] ipv4: defensive cipso option parsing (Matteo Croce) [1720708]
- [net] netfilter: nf_queue: enqueue skbs with NULL dst (Matteo Croce) [1786116]

* Tue Apr 28 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.15.el8]
- [powerpc] powerpc/pseries/ddw: Extend upper limit for huge DMA window for persistent memory (Steve Best) [1817596]
- [cpuidle] cpuidle: haltpoll: allow force loading on hosts without the REALTIME hint (David Arcari) [1825353]
- [cpuidle] cpuidle: dt: Support hierarchical CPU idle states (David Arcari) [1825353]
- [of] of: base: Add of_get_cpu_state_node() to get idle states for a CPU node (David Arcari) [1825353]
- [cpuidle] cpuidle: Allow idle states to be disabled by default (David Arcari) [1825353]
- [cpuidle] cpuidle: Drop unnecessary type cast in cpuidle_poll_time() (David Arcari) [1825353]
- [cpuidle] cpuidle: Fix cpuidle_driver_state_disabled() (David Arcari) [1825353]
- [cpuidle] cpuidle: use first valid target residency as poll time (David Arcari) [1825353]
- [cpuidle] cpuidle: Drop disabled field from struct cpuidle_state (David Arcari) [1825353]
- [cpuidle] cpuidle: Pass exit latency limit to cpuidle_use_deepest_state() (David Arcari) [1825353]
- [include] cpuidle: Allow idle injection to apply exit latency limit (David Arcari) [1825353]
- [thermal] cpuidle: play_idle: Increase the resolution to usec (David Arcari) [1825353]
- [cpuidle] cpuidle: Use nanoseconds as the unit of time (David Arcari) [1825353]
- [cpuidle] cpuidle: menu: Allow tick to be stopped if PM QoS is used (David Arcari) [1825353]
- [cpuidle] cpuidle: Consolidate disabled state checks (David Arcari) [1825353]
- [cpuidle] cpuidle: Do not unset the driver if it is there already (David Arcari) [1825353]
- [cpuidle] cpuidle: haltpoll: Take 'idle=' override into account (David Arcari) [1825353]
- [cpuidle] cpuidle-haltpoll: Enable kvm guest polling when dedicated physical CPUs are available (David Arcari) [1825353]
- [fs] gfs2: fix gfs2_find_jhead that returns uninitialized jhead with seq 0 (Abhijith Das) [1655566]
- [fs] gfs2: Another gfs2_find_jhead fix (Abhijith Das) [1655566]
- [fs] gfs2: read journal in large chunks (Abhijith Das) [1655566]
- [fs] gfs2: add a helper function to get_log_header that can be used elsewhere (Abhijith Das) [1655566]
- [fs] gfs2: changes to gfs2_log_XXX_bio (Abhijith Das) [1655566]
- [fs] gfs2: add more timing info to journal recovery process (Abhijith Das) [1655566]
- [mm] mm: hugetlb controller for cgroup v2 (Joel Savitz) [1810728]
- [arm64] crypto: arm64/aes-ce - implement 5 way interleave for ECB, CBC and CTR (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-ce - add 5 way interleave routines (Mark Salter) [1826982]
- [arm64] crypto: arm64/sha2-ce - correct digest for empty data in finup (Mark Salter) [1826982]
- [arm64] crypto: arm64/sha1-ce - correct digest for empty data in finup (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-neonbs - don't access already-freed walk.iv (Mark Salter) [1826982]
- [arm64] crypto: arm64/cbcmac - handle empty messages in same way as template (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-blk - update IV after partial final CTR block (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-neonbs - fix returning final keystream block (Mark Salter) [1826982]
- [arm64] crypto: arm64/crct10dif-ce - cleanup and optimizations (Mark Salter) [1826982]
- [arm64] crypto: arm64/crct10dif - register PMULL variants as separate algos (Mark Salter) [1826982]
- [arm64] crypto: arm64/crct10dif - remove dead code (Mark Salter) [1826982]
- [arm64] crypto: arm64/crct10dif - revert to C code for short inputs (Mark Salter) [1826982]
- [arm64] crypto: arm64/ghash-neon - bump priority to 150 (Mark Salter) [1826982]
- [arm64] crypto: arm64/ghash - register PMULL variants as separate algos (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-ccm - don't use an atomic walk needlessly (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-ccm - fix bugs in non-NEON fallback routine (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-blk - ensure XTS mask is always loaded (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes - fix handling sub-block CTS-CBC inputs (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-blk - improve XTS mask handling (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-blk - add support for CTS-CBC mode (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-blk - revert NEON yield for skciphers (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-blk - remove pointless (u8 *) casts (Mark Salter) [1826982]
- [arm64] crypto: arm64/crct10dif - implement non-Crypto Extensions alternative (Mark Salter) [1826982]
- [arm64] crypto: arm64/crct10dif - preparatory refactor for 8x8 PMULL version (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-modes - get rid of literal load of addend vector (Mark Salter) [1826982]
- [arm64] crypto: arm64/sm4-ce - check for the right CPU feature bit (Mark Salter) [1826982]
- [arm64] crypto: arm64/gcm-aes-ce - fix no-NEON fallback code (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-gcm-ce - fix scatterwalk API violation (Mark Salter) [1826982]
- [arm64] crypto: arm64/ghash-ce - implement 4-way aggregation (Mark Salter) [1826982]
- [arm64] crypto: arm64/ghash-ce - replace NEON yield check with block limit (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-ce-gcm - don't reload key schedule if avoidable (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-ce-gcm - implement 2-way aggregation (Mark Salter) [1826982]
- [arm64] crypto: arm64/aes-ce-gcm - operate on two input blocks at a time (Mark Salter) [1826982]
- [mm] mm, slub: prevent kmalloc_node crashes and memory leaks (Rafael Aquini) [1819839]
- [mm] mm: slub: be more careful about the double cmpxchg of freelist (Rafael Aquini) [1819839]
- [mm] mm: slub: add missing TID bump in kmem_cache_alloc_bulk() (Rafael Aquini) [1819839]
- [mm] mm/slub.c: avoid slub allocation while holding list_lock (Rafael Aquini) [1819839]
- [mm] mm/slub.c: clean up validate_slab() (Rafael Aquini) [1819839]
- [mm] mm: slub: print the offset of fault addresses (Rafael Aquini) [1819839]
- [mm] hugetlbfs: don't retry when pool page allocations start to fail (Rafael Aquini) [1727288]
- [mm] mm, compaction: raise compaction priority after it withdrawns (Rafael Aquini) [1727288]
- [mm] mm, reclaim: cleanup should_continue_reclaim() (Rafael Aquini) [1727288]
- [mm] mm, reclaim: make should_continue_reclaim perform dryrun detection (Rafael Aquini) [1727288]

* Sat Apr 25 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.14.el8]
- [tools] bpf: selftests: remove test_bpftool_build.sh from TEST_PROGS (Yauheni Kaliuta) [1813365]
- [tools] libbpf: Support .text sub-calls relocations (Yauheni Kaliuta) [1813365]
- [tools] libbpf: Sanitize global functions (Yauheni Kaliuta) [1813365]
- [kernel] workqueue: Add RCU annotation for pwq list walk (Yauheni Kaliuta) [1813365]
- [kernel] perf/core: Add SRCU annotation for pmus list walk (Yauheni Kaliuta) [1813365]
- [net] kcm: disable preemption in kcm_parse_func_strparser() (Yauheni Kaliuta) [1813365]
- [net] kcm: use BPF_PROG_RUN (Yauheni Kaliuta) [1813365]
- [kernel] bpf: clarify description for CONFIG_BPF_EVENTS (Yauheni Kaliuta) [1813365]
- [lib] test_bpf: Fix a new clang warning about xor-ing two numbers (Yauheni Kaliuta) [1813365]
- [include] bpf: add include guard to tnum.h (Yauheni Kaliuta) [1813365]
- [tools] libbpf: handle symbol versioning properly for libbpf.a (Yauheni Kaliuta) [1813365]
- [net] bpf, devmap: Pass lockdep expression to RCU lists (Yauheni Kaliuta) [1813365]
- [tools] libbpf: Fix Makefile' libbpf symbol mismatch diagnostic (Yauheni Kaliuta) [1813365]
- [net] xdp: Fix cleanup on map free for devmap_hash map type (Yauheni Kaliuta) [1813365]
- [tools] tools, bpf: Fix build for 'make -s tools/bpf O=<dir>' (Yauheni Kaliuta) [1813365]
- [tools] libbpf: Fix passing uninitialized bytes to setsockopt (Yauheni Kaliuta) [1813365]
- [tools] selftests: bpf: Skip write only files in debugfs (Yauheni Kaliuta) [1813365]
- [net] xdp: Handle device unregister for devmap_hash map type (Yauheni Kaliuta) [1813365]
- [net] ipv4: Add lockdep condition to fix for_each_entry() (Yauheni Kaliuta) [1813365]
- [kernel] rcu/sync: Remove custom check for RCU readers (Yauheni Kaliuta) [1813365]
- [kernel] rcu: Add support for consolidated-RCU reader checking (Yauheni Kaliuta) [1813365]
- [kernel] rcu: Remove redundant debug_locks check in rcu_read_lock_sched_held() (Yauheni Kaliuta) [1813365]
- [net] xdp: Prevent overflow in devmap_hash cost calculation for 32-bit builds (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: Add a workaround for asm_inline (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: Fix build for task_fd_query_user.c (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: Don't leak server_fd in test_sockopt_inherit (Yauheni Kaliuta) [1813365]
- [tools] tools: bpf: Use !building_out_of_srctree to determine srctree (Yauheni Kaliuta) [1813365]
- [net] bpf: Clean up indentation issue in BTF kflag processing (Yauheni Kaliuta) [1813365]
- [tools] libbpf: Teach btf_dumper to emit stand-alone anonymous enum definitions (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: adjust strobemeta loop to satisfy latest clang (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: delete unused variables in test_sysctl (Yauheni Kaliuta) [1813365]
- [tools] libbpf: fix false uninitialized variable warning (Yauheni Kaliuta) [1813365]
- [tools] libbpf: Remove getsockopt() check for XDP_OPTIONS (Yauheni Kaliuta) [1813365]
- [net] xdp: Fix race in dev_map_hash_update_elem() when replacing element (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: convert test_tcp_rtt (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: convert test_sockopt_inherit (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: convert test_sockopt_multi (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: convert test_sockopt_sk (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: convert test_sockopt (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: add test__join_cgroup helper (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: precision tracking tests (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: fix endianness issues in test_sysctl (Yauheni Kaliuta) [1813365]
- [arm64] arm64: bpf: optimize modulo operation (Yauheni Kaliuta) [1813365]
- [s390] bpf: s390: add JIT support for bpf line info (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: add missing \n to CHECK_FAIL (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: fix verbose mode garbage (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: Fix a typo in test_offload.py (Yauheni Kaliuta) [1813365]
- [net] bpf: fix error check in bpf_tcp_gen_syncookie (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: do not link twice against libbpf.a in Makefile (Yauheni Kaliuta) [1813365]
- [tools] tools: bpf: account for generated feature/ and libbpf/ directories (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: improve and check builds for different make invocations (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: ignore make built-in rules for getting kernel version (Yauheni Kaliuta) [1813365]
- [s390] bpf: s390: add JIT support for multi-function programs (Yauheni Kaliuta) [1746980 1813365]
- [tools] selftests/bpf: remove wrong nhoff in flow dissector test (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: remove unused ret (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: remove asserts from subtests (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: remove global fail/success counts (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: test__skip (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: add precision tracking test (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: verifier precise tests (Yauheni Kaliuta) [1813365]
- [tools] tools/bpf: sync bpf.h (Yauheni Kaliuta) [1813365]
- [net] bpf: introduce verifier internal test flag (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add "bpftool map freeze" subcommand (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: show frozen status for maps (Yauheni Kaliuta) [1813365]
- [uapi] bpf: clarify when bpf_trace_printk discards lines (Yauheni Kaliuta) [1813365]
- [samples] samples: bpf: syscall_nrs: use mmap2 if defined (Yauheni Kaliuta) [1813365]
- [tools] libbpf: use LFS (_FILE_OFFSET_BITS) instead of direct mmap2 syscall (Yauheni Kaliuta) [1813365]
- [net] bpf: add new BPF_BTF_GET_NEXT_ID syscall command (Yauheni Kaliuta) [1813365]
- [net] bpf: add BTF ids in procfs for file descriptors to BTF objects (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: add sockopt clone/inheritance test (Yauheni Kaliuta) [1813365]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1813365]
- [net] bpf: support cloning sk storage on accept() (Yauheni Kaliuta) [1813365]
- [net] bpf: export bpf_map_inc_not_zero (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add documentation for net attach/detach (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add bash-completion for net attach/detach (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add net detach command to detach XDP on interface (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add net attach command to attach XDP on interface (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: compile with $(EXTRA_WARNINGS) (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add feature check for zlib (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: fix reading from /proc/config.gz (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: xdp_fwd explain bpf_fib_lookup return codes (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: make xdp_fwd more practically usable via devmap lookup (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: xdp_fwd rename devmap name to be xdp_tx_ports (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: drop extra trailing tab (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: test__printf -> printf (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: test_progs: switch to open_memstream (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: add loop test 5 (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: add loop test 4 (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: extend sockopt_sk selftest with TCP_CONGESTION use case (Yauheni Kaliuta) [1813365]
- [net] bpf: always allocate at least 16 bytes for setsockopt hook (Yauheni Kaliuta) [1813365]
- [tools] tools: bpftool: add support for reporting the effective cgroup progs (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: add test for bpf_tcp_gen_syncookie (Yauheni Kaliuta) [1813365]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1813365]
- [net] bpf: add bpf_tcp_gen_syncookie helper (Yauheni Kaliuta) [1813365]
- [net] tcp: add skb-less helpers to retrieve SYN cookie (Yauheni Kaliuta) [1813365]
- [net] tcp: tcp_syn_flood_action read port from socket (Yauheni Kaliuta) [1813365]
- [net] tcp: rate limit synflood warnings further (Yauheni Kaliuta) [1813365]
- [tools] tools: Add definitions for devmap_hash map type (Yauheni Kaliuta) [1813365]
- [tools] tools/libbpf_probes: Add new devmap_hash type (Yauheni Kaliuta) [1813365]
- [tools] tools/include/uapi: Add devmap_hash BPF map type (Yauheni Kaliuta) [1813365]
- [net] xdp: Add devmap_hash map type for looking up devices by hashed index (Yauheni Kaliuta) [1813365]
- [net] xdp: Refactor devmap allocation code for reuse (Yauheni Kaliuta) [1813365]
- [include] include/bpf.h: Remove map_insert_ctx() stubs (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: convert send_signal.c to use subtests (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: convert bpf_verif_scale.c to sub-tests API (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: support BPF_FLOW_DISSECTOR_F_STOP_AT_ENCAP (Yauheni Kaliuta) [1813365]
- [tools] bpf/flow_dissector: support ipv6 flow_label and BPF_FLOW_DISSECTOR_F_STOP_AT_FLOW_LABEL (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: support BPF_FLOW_DISSECTOR_F_PARSE_1ST_FRAG (Yauheni Kaliuta) [1813365]
- [tools] tools/bpf: sync bpf_flow_keys flags (Yauheni Kaliuta) [1813365]
- [net] bpf/flow_dissector: support flags in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1813365]
- [documentation] bpf/flow_dissector: document flags (Yauheni Kaliuta) [1813365]
- [net] bpf/flow_dissector: pass input flags to BPF flow dissector program (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: Add selftests for bpf_perf_event_output (Yauheni Kaliuta) [1813365]
- [net] bpf: Allow bpf_skb_event_output for a few prog types (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: remove perf buffer helpers (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: switch trace_output sample to perf_buffer API (Yauheni Kaliuta) [1813365]
- [samples] samples/bpf: convert xdp_sample_pkts_user to perf_buffer API (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: switch test_tcpnotify to perf_buffer API (Yauheni Kaliuta) [1813365]
- [tools] selftests/bpf: convert test_get_stack_raw_tp to perf_buffer API (Yauheni Kaliuta) [1813365]
- [block] block, bfq: fix use-after-free in bfq_idle_slice_timer_body (Ming Lei) [1823596]
- [block] block, bfq: fix overwrite of bfq_group pointer in bfq_find_set_group() (Ming Lei) [1823596]
- [block] block, bfq: clarify the goal of bfq_split_bfqq() (Ming Lei) [1823596]
- [block] block, bfq: get a ref to a group when adding it to a service tree (Ming Lei) [1823596]
- [block] block, bfq: remove ifdefs from around gets/puts of bfq groups (Ming Lei) [1823596]
- [block] block, bfq: extend incomplete name of field on_st (Ming Lei) [1823596]
- [block] block, bfq: get extra ref to prevent a queue from being freed during a group move (Ming Lei) [1823596]
- [block] block, bfq: do not insert oom queue into position tree (Ming Lei) [1823596]
- [block] block, bfq: do not plug I/O for bfq_queues with no proc refs (Ming Lei) [1823596]
- [block] block, bfq: improve arithmetic division in bfq_delta() (Ming Lei) [1823596]
- [block] block/bfq: remove unused bfq_class_rt which never used (Ming Lei) [1823596]
- [block] block: Prevent hung_check firing during long sync IO (Ming Lei) [1813383]
- [block] brd: check and limit max_part par (Ming Lei) [1790403]

* Fri Apr 24 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.13.el8]
- [char] random: silence a lockdep splat with printk() (Brian Masney) [1798900]
- [net] SUNRPC: fix krb5p mount to provide large enough buffer in rq_rcvsize (Steve Dickson) [1825388]
- [include] percpu-refcount: Use normal instead of RCU-sched" (Waiman Long) [1803822]
- [kernel] locking/spinlock/debug: Fix various data races (Waiman Long) [1803822]
- [kernel] locktorture: Forgive apparent unfairness if CPU hotplug (Waiman Long) [1803822]
- [kernel] locktorture: Use private random-number generators (Waiman Long) [1803822]
- [tools] locktorture: Allow CPU-hotplug to be disabled via --bootargs (Waiman Long) [1803822]
- [kernel] locking: locktorture: Do not include rwlock.h directly (Waiman Long) [1803822]
- [kernel] locktorture: Replace strncmp() with str_has_prefix() (Waiman Long) [1803822]
- [kernel] locking/rtmutex: rcu: Add WRITE_ONCE() to rt_mutex ->owner (Waiman Long) [1803822]
- [arm64] arm64/spinlock: fix a -Wunused-function warning (Waiman Long) [1803822]
- [arm64] locking/osq: Use optimized spinning loop for arm64 (Waiman Long) [1803822]
- [kernel] locking/qspinlock: Fix inaccessible URL of MCS lock paper (Waiman Long) [1803822]
- [include] string.h: Add str_has_prefix() helper function (Waiman Long) [1803822]
- [kernel] futex: Remove {get,drop}_futex_key_refs() (Waiman Long) [1803822]
- [kernel] futex: Remove pointless mmgrap() + mmdrop() (Waiman Long) [1803822]
- [kernel] futex: Unbreak futex hashing (Waiman Long) [1803822]
- [fs] futex: Fix inode life-time issue (Waiman Long) [1803822]
- [kernel] futex: Fix kernel-doc notation warning (Waiman Long) [1803822]
- [kernel] futex: Prevent exit livelock (Waiman Long) [1803822]
- [kernel] futex: Provide distinct return value when owner is exiting (Waiman Long) [1803822]
- [include] futex: Add mutex around futex exit (Waiman Long) [1803822]
- [kernel] futex: Provide state handling for exec() as well (Waiman Long) [1803822]
- [kernel] futex: Sanitize exit state handling (Waiman Long) [1803822]
- [kernel] futex: Mark the begin of futex exit explicitly (Waiman Long) [1803822]
- [kernel] futex: Set task::futex_state to DEAD right after handling futex exit (Waiman Long) [1803822]
- [kernel] futex: Split futex_mm_release() for exit/exec (Waiman Long) [1803822]
- [kernel] exit/exec: Seperate mm_release() (Waiman Long) [1803822]
- [kernel] futex: Replace PF_EXITPIDONE with a state (Waiman Long) [1803822]
- [kernel] futex: Move futex exit handling into futex code (Waiman Long) [1803822]
- [kernel] futex: Prevent robust futex exit race (Waiman Long) [1803822]
- [kernel] futex: Drop leftover wake_q_add() comment (Waiman Long) [1803822]
- [kernel] fork: Provide a function for copying init_mm (Waiman Long) [1803822]
- [kernel] y2038: futex: Move compat implementation into futex.c (Waiman Long) [1803822]
- [fs] nfsd: Fix races between nfsd4_cb_release() and nfsd4_shutdown_callback() ("J. Bruce Fields") [1797484]
- [fs] nfsd: minor 4.1 callback cleanup ("J. Bruce Fields") [1797484]
- [video] vgacon: Fix a UAF in vgacon_invert_region (Vladis Dronov) [1818732] {CVE-2020-8647 CVE-2020-8649}
- [powerpc] powerpc/xive: Use XIVE_BAD_IRQ instead of zero to catch non configured IPIs (David Gibson) [1773891]
- [clocksource] hyper-v: Make sched clock return nanoseconds correctly (Mohammed Gamal) [1816731]
- [clocksource] hyper-v: Set TSC clocksource as default w/ InvariantTSC (Mohammed Gamal) [1816731]
- [clocksource] hyper-v: Untangle stimers and timesync from clocksources (Mohammed Gamal) [1816731]
- [clocksource] hyper-v: Reserve PAGE_SIZE space for tsc page (Mohammed Gamal) [1816731]
- [clocksource] x86/hyperv: Initialize clockevents earlier in CPU onlining (Mohammed Gamal) [1816731]
- [x86] hyperv: Allow guests to enable InvariantTSC (Mohammed Gamal) [1816731]
- [hv] hv: vmbus: Suspend/resume the synic for hibernation (Mohammed Gamal) [1816731]
- [hv] hv: vmbus: Break out synic enable and disable operations (Mohammed Gamal) [1816731]
- [x86] hyperv: Set pv_info.name to "Hyper-V" (Mohammed Gamal) [1816731]
- [x86] hyperv: Hide pv_ops access for CONFIG_PARAVIRT=n (Mohammed Gamal) [1816731]
- [clocksource] hyperv: Enable TSC page clocksource on 32bit (Mohammed Gamal) [1816731]
- [clocksource] hyperv: Add Hyper-V specific sched clock function (Mohammed Gamal) [1816731]
- [clocksource] hyperv: Allocate Hyper-V TSC page statically (Mohammed Gamal) [1816731]
- [clocksource] Continue making Hyper-V clocksource ISA agnostic (Mohammed Gamal) [1816731]
- [clocksource] Make Hyper-V clocksource ISA agnostic (Mohammed Gamal) [1816731]
- [tools] hv: Reopen the devices if read() or write() returns errors (Mohammed Gamal) [1824182]
- [tools] hv: add vmbus testing tool (Mohammed Gamal) [1824182]
- [tools] hv: move to tools buildsystem (Mohammed Gamal) [1824182]
- [tools] hv: kvp: eliminate 'may be used uninitialized' warning (Mohammed Gamal) [1824182]
- [tools] hv: fix typos in toolchain (Mohammed Gamal) [1824182]
- [tools] hv: fix KVP and VSS daemons exit code (Mohammed Gamal) [1824182]
- [tools] hv: fixed Python pep8/flake8 warnings for lsvmbus (Mohammed Gamal) [1824182]
- [tools] hv: kvp: Fix a warning of buffer overflow with gcc 8.0.1 (Mohammed Gamal) [1824182]
- [tools] hv: fcopy: set 'error' in case an unknown operation was requested (Mohammed Gamal) [1824182]
- [tools] hv: Fix a bug in the key delete code (Mohammed Gamal) [1824182]
- [tools] hv: vss: fix loop device detection (Mohammed Gamal) [1824182]
- [hv] hv: vmbus: Introduce latency testing (Mohammed Gamal) [1824182]
- [tools] hv: update lsvmbus to be compatible with python3 (Mohammed Gamal) [1824182]

* Thu Apr 23 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.12.el8]
- [hwtracing] coresight: etm4x: Add kernel configuration for CONTEXTID (Michael Petlan) [1818835]
- [samples] samples/bpf: fix build by setting HAVE_ATTR_TEST to zero (Michael Petlan) [1818835]
- [tools] perf metricgroup: Fix printing event names of metric group with multiple events (Michael Petlan) [1818835]
- [tools] perf script: Fix invalid LBR/binary mismatch error (Michael Petlan) [1818835]
- [tools] perf c2c: Fix return type for histogram sorting comparision functions (Michael Petlan) [1818835]
- [tools] perf session: Fix decompression of PERF_RECORD_COMPRESSED records (Michael Petlan) [1818835]
- [tools] perf tools: Fix time sorting (Michael Petlan) [1818835]
- [tools] perf tools: Remove unused trace_find_next_event() (Michael Petlan) [1818835]
- [tools] perf scripting engines: Iterate on tep event arrays directly (Michael Petlan) [1818835]
- [tools] perf tools: Make usage of test_attr__* optional for perf-sys.h (Michael Petlan) [1818835]
- [tools] perf kmem: Fix memory leak in compact_gfp_flags() (Michael Petlan) [1818835]
- [tools] perf c2c: Fix memory leak in build_cl_output() (Michael Petlan) [1818835]
- [tools] perf tools: Fix mode setting in copyfile_mode_ns() (Michael Petlan) [1818835]
- [tools] perf annotate: Fix multiple memory and file descriptor leaks (Michael Petlan) [1818835]
- [tools] perf tools: Fix resource leak of closedir() on the error paths (Michael Petlan) [1818835]
- [tools] perf evlist: Fix fix for freed id arrays (Michael Petlan) [1818835]
- [tools] perf annotate: Don't return -1 for error when doing BPF disassembly (Michael Petlan) [1818835]
- [tools] perf annotate: Return appropriate error code for allocation failures (Michael Petlan) [1818835]
- [tools] perf annotate: Fix arch specific ->init() failure errors (Michael Petlan) [1818835]
- [tools] perf annotate: Propagate the symbol__annotate() error return (Michael Petlan) [1818835]
- [tools] perf annotate: Fix the signedness of failure returns (Michael Petlan) [1818835]
- [tools] perf annotate: Propagate perf_env__arch() error (Michael Petlan) [1818835]
- [tools] perf evsel: Fall back to global 'perf_env' in perf_evsel__env() (Michael Petlan) [1818835]
- [tools] perf tools: Propagate get_cpuid() error (Michael Petlan) [1818835]
- [tools] perf jevents: Fix period for Intel fixed counters (Michael Petlan) [1818835]
- [tools] perf script brstackinsn: Fix recovery from LBR/binary mismatch (Michael Petlan) [1818835]
- [tools] perf docs: Correct and clarify jitdump spec (Michael Petlan) [1818835]
- [tools] perf inject jit: Fix JIT_CODE_MOVE filename (Michael Petlan) [1818835]
- [tools] perf map: Fix overlapped map handling (Michael Petlan) [1818835]
- [tools] perf vendor events s390: Use s390 machine name instead of type 8561 (Michael Petlan) [1818835]
- [tools] perf llvm: Don't access out-of-scope array (Michael Petlan) [1818835]
- [tools] perf docs: Allow man page date to be specified (Michael Petlan) [1818835]
- [tools] perf tests: Avoid raising SEGV using an obvious NULL dereference (Michael Petlan) [1818835]
- [tools] libsubcmd: Make _FORTIFY_SOURCE defines dependent on the feature (Michael Petlan) [1818835]
- [tools] perf unwind: Fix libunwind build failure on i386 systems (Michael Petlan) [1818835]
- [tools] perf parser: Remove needless include directives (Michael Petlan) [1818835]
- [tools] perf build: Add detection of java-11-openjdk-devel package (Michael Petlan) [1818835]
- [tools] perf jvmti: Include JVMTI support for s390 (Michael Petlan) [1818835]
- [tools] perf evlist: Fix access of freed id arrays (Michael Petlan) [1818835]
- [tools] perf stat: Fix free memory access / memory leaks in metrics (Michael Petlan) [1818835]
- [tools] perf tools: Replace needless mmap.h with what is needed, event.h (Michael Petlan) [1818835]
- [tools] perf evsel: Move config terms to a separate header (Michael Petlan) [1818835]
- [tools] perf evlist: Remove unused perf_evlist__fprintf() method (Michael Petlan) [1818835]
- [tools] perf evsel: Introduce evsel_fprintf.h (Michael Petlan) [1818835]
- [tools] perf evsel: Remove need for symbol_conf in evsel_fprintf.c (Michael Petlan) [1818835]
- [tools] perf copyfile: Move copyfile routines to separate files (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__poll() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__add_pollfd() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__alloc_pollfd() function (Michael Petlan) [1818835]
- [tools] libperf: Add libperf_init() call to the tests (Michael Petlan) [1818835]
- [tools] libperf: Merge libperf_set_print() into libperf_init() (Michael Petlan) [1818835]
- [tools] libperf: Add libperf dependency for tests targets (Michael Petlan) [1818835]
- [tools] libperf: Use sys/types.h to get ssize_t, not unistd.h (Michael Petlan) [1818835]
- [tools] perf tools: No need to include internal/lib.h from util/util.h (Michael Petlan) [1818835]
- [tools] libperf: Move 'page_size' global variable to libperf (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__id_add_fd() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__id_add() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__read_format() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__first()/last() functions (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__alloc_id/perf_evsel__free_id functions (Michael Petlan) [1818835]
- [tools] libperf: Move 'heads' from 'struct evlist' to 'struct perf_evlist' (Michael Petlan) [1818835]
- [tools] libperf: Move 'ids' from 'struct evsel' to 'struct perf_evsel' (Michael Petlan) [1818835]
- [tools] libperf: Move 'id' from 'struct evsel' to 'struct perf_evsel' (Michael Petlan) [1818835]
- [tools] libperf: Move 'sample_id' from 'struct evsel' to 'struct perf_evsel' (Michael Petlan) [1818835]
- [tools] libperf: Add missing 'struct xyarray' forward declaration (Michael Petlan) [1818835]
- [tools] libperf: Move 'pollfd' from 'struct evlist' to 'struct perf_evlist' (Michael Petlan) [1818835]
- [tools] libperf: Move 'mmap_len' from 'struct evlist' to 'struct perf_evlist' (Michael Petlan) [1818835]
- [tools] libperf: Move 'nr_mmaps' from 'struct evlist' to 'struct perf_evlist' (Michael Petlan) [1818835]
- [tools] libperf: Move 'system_wide' from 'struct evsel' to 'struct perf_evsel' (Michael Petlan) [1818835]
- [tools] libperf: Add 'flush' to 'struct perf_mmap' (Michael Petlan) [1818835]
- [tools] libperf: Add 'event_copy' to 'struct perf_mmap' (Michael Petlan) [1818835]
- [tools] libperf: Add 'overwrite' to 'struct perf_mmap' (Michael Petlan) [1818835]
- [tools] libperf: Add prev/start/end to struct perf_mmap (Michael Petlan) [1818835]
- [tools] libperf: Add 'refcnt' to struct perf_mmap (Michael Petlan) [1818835]
- [tools] libperf: Add 'cpu' to struct perf_mmap (Michael Petlan) [1818835]
- [tools] libperf: Add 'fd' to struct perf_mmap (Michael Petlan) [1818835]
- [tools] libperf: Add 'mask' to struct perf_mmap (Michael Petlan) [1818835]
- [tools] libperf: Add perf_mmap struct (Michael Petlan) [1818835]
- [tools] perf evlist: Adopt backwards ring buffer state enum (Michael Petlan) [1818835]
- [tools] libperf: Link libapi.a in libperf.so (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_evlist__purge() to evlist__purge() (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_evlist__exit() to evlist__exit() (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_evlist__alloc_mmap() to evlist__alloc_mmap() (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_evlist__munmap() to evlist__munmap() (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_evlist__mmap() to evlist__mmap() (Michael Petlan) [1818835]
- [tools] perf tools: Rename 'struct perf_mmap' to 'struct mmap' (Michael Petlan) [1818835]
- [tools] tools: Add missing stdio.h include to asm/bug.h header (Michael Petlan) [1818835]
- [tools] libtraceevent: Man pages for tep plugins APIs (Michael Petlan) [1818835]
- [tools] libtraceevent: Move traceevent plugins in its own subdirectory (Michael Petlan) [1818835]
- [tools] libtraceevent: Add tep_get_event() in event-parse.h (Michael Petlan) [1818835]
- [tools] libtraceevent: Man pages fix, changes in event printing APIs (Michael Petlan) [1818835]
- [tools] libtraceevent: Man pages fix, rename tep_ref_get() to tep_get_ref() (Michael Petlan) [1818835]
- [tools] libtraceevent: Man pages for libtraceevent event print related API (Michael Petlan) [1818835]
- [tools] libtraceevent: Round up in tep_print_event() time precision (Michael Petlan) [1818835]
- [tools] perf record: Move restricted maps check to after a possible fallback to not collect kernel samples (Michael Petlan) [1818835]
- [tools] perf record: Fix priv level with branch sampling for paranoid=2 (Michael Petlan) [1818835]
- [tools] perf probe: Fix to clear tev->nargs in clear_probe_trace_event() (Michael Petlan) [1818835]
- [tools] perf probe: Skip same probe address for a given line (Michael Petlan) [1818835]
- [tools] perf tests: Fix static build test (Michael Petlan) [1818835]
- [tools] perf kvm stat: Set 'trace_cycles' as default event for 'perf kvm record' in powerpc (Michael Petlan) [1818835]
- [tools] perf kvm: Add arch neutral function to choose event for perf kvm record (Michael Petlan) [1818835]
- [tools] perf kvm: Move kvm-stat header file from conditional inclusion to common include section (Michael Petlan) [1818835]
- [tools] perf test: Fix spelling mistake "allos" -> "allocate" (Michael Petlan) [1818835]
- [tools] perf stat: Fix a segmentation fault when using repeat forever (Michael Petlan) [1818835]
- [tools] perf stat: Reset previous counts on repeat with interval (Michael Petlan) [1818835]
- [tools] tools lib traceevent: Convert remaining pusers to p (Michael Petlan) [1818835]
- [tools] perf tools: Move event synthesizing routines to separate .c file (Michael Petlan) [1818835]
- [tools] perf memswap: Adopt 'struct u64_swap' from evsel.h (Michael Petlan) [1818835]
- [tools] perf tools: Move event synthesizing routines to separate header (Michael Petlan) [1818835]
- [tools] perf auxtrace: Add missing 'struct perf_sample' forward declaration (Michael Petlan) [1818835]
- [tools] perf sched: Add missing event.h include directive (Michael Petlan) [1818835]
- [tools] perf annotate: Add missing machine.h include directive (Michael Petlan) [1818835]
- [tools] perf hist: Add missing 'struct branch_stack' forward declaration (Michael Petlan) [1818835]
- [tools] perf python: Remove debug.h (Michael Petlan) [1818835]
- [tools] perf callchain: Remove needless event.h include (Michael Petlan) [1818835]
- [tools] perf stat: Move perf_stat_synthesize_config() to event.h (Michael Petlan) [1818835]
- [tools] perf event: Move perf_event__synthesize* to event.h (Michael Petlan) [1818835]
- [tools] perf env: Remove needless cpumap.h header (Michael Petlan) [1818835]
- [tools] perf symbols: Add missing dso.h header (Michael Petlan) [1818835]
- [tools] perf probe: Add missing build-id.h header (Michael Petlan) [1818835]
- [tools] perf tools: Remove util.h from where it is not needed (Michael Petlan) [1818835]
- [tools] perf tools: Remove debug.h from places where it is not needed (Michael Petlan) [1818835]
- [tools] perf debug: No need to include ui/util.h (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless builtin.h include directives (Michael Petlan) [1818835]
- [tools] perf tools: Add PMU event JSON files for ARM Cortex-A76 and, Neoverse N1 (Michael Petlan) [1818835]
- [tools] libperf: Adopt perf_cpu_map__max() function (Michael Petlan) [1818835]
- [tools] libperf: Add missing event.h file to install rule (Michael Petlan) [1818835]
- [tools] perf tests: Add libperf automated test for 'make -C tools/perf build-test' (Michael Petlan) [1818835]
- [tools] perf python: Add missing python/perf.so dependency for libperf (Michael Petlan) [1818835]
- [tools] perf build: Ignore intentional differences for the x86 insn decoder (Michael Petlan) [1818835]
- [tools] perf intel-pt: Use shared x86 insn decoder (Michael Petlan) [1818835]
- [tools] objtool: Move x86 insn decoder to a common location (Michael Petlan) [1818835]
- [tools] perf intel-pt: Remove inat.c from build dependency list (Michael Petlan) [1818835]
- [tools] perf: Update .gitignore file (Michael Petlan) [1818835]
- [tools] perf metricgroup: Support multiple events for metricgroup (Michael Petlan) [1818835]
- [tools] perf metricgroup: Scale the metric result (Michael Petlan) [1818835]
- [tools] perf pmu: Change convert_scale from static to global (Michael Petlan) [1818835]
- [tools] perf symbols: Move mem_info and branch_info out of symbol.h (Michael Petlan) [1818835]
- [tools] perf auxtrace: Uninline functions that touch perf_session (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless evlist.h include directives (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless evlist.h include directives (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless thread_map.h include directives (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless thread.h include directives (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless map.h include directives (Michael Petlan) [1818835]
- [tools] perf probe: No need for symbol.h, symbol_conf is enough (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless sort.h include directives (Michael Petlan) [1818835]
- [tools] perf tools: Move 'struct events_stats' and prototypes to separate header (Michael Petlan) [1818835]
- [tools] perf hist: Remove needless ui/progress.h from hist.h (Michael Petlan) [1818835]
- [tools] perf dsos: Move the dsos struct and its methods to separate source files (Michael Petlan) [1818835]
- [tools] perf symbols: Move symsrc prototypes to a separate header (Michael Petlan) [1818835]
- [tools] perf symbols: Add missing linux/refcount.h to symbol.h (Michael Petlan) [1818835]
- [tools] perf symbol: Move C++ demangle defines to the only file using it (Michael Petlan) [1818835]
- [tools] perf dso: Adopt DSO related macros from symbol.h (Michael Petlan) [1818835]
- [tools] libtraceevent: Change users plugin directory (Michael Petlan) [1818835]
- [tools] libtraceevent: Remove tep_register_trace_clock() (Michael Petlan) [1818835]
- [tools] libtraceevent, perf tools: Changes in tep_print_event_* APIs (Michael Petlan) [1818835]
- [tools] perf event: Remove needless include directives from event.h (Michael Petlan) [1818835]
- [tools] perf env: Remove env.h from other headers where just a fwd decl is needed (Michael Petlan) [1818835]
- [tools] perf debug: Remove needless include directives from debug.h (Michael Petlan) [1818835]
- [tools] perf tools: Remove debug.h from header files not needing it (Michael Petlan) [1818835]
- [tools] perf tools: Remove perf.h from source files not needing it (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless perf.h include directive from headers (Michael Petlan) [1818835]
- [tools] perf time-utils: Adopt rdclock() from perf.h (Michael Petlan) [1818835]
- [tools] perf tools: Move everything related to sys_perf_event_open() to perf-sys.h (Michael Petlan) [1818835]
- [tools] perf header: Move CPUINFO_PROC to the only file where it is used (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless libtraceevent include directives (Michael Petlan) [1818835]
- [tools] libperf: Warn when exceeding MAX_NR_CPUS in cpumap (Michael Petlan) [1818835]
- [tools] perf c2c: Display proper cpu count in nodes column (Michael Petlan) [1818835]
- [tools] tools lib traceevent: Remove unneeded qsort and uses memmove instead (Michael Petlan) [1818835]
- [tools] tools lib traceevent: Do not free tep->cmdlines in add_new_comm() on failure (Michael Petlan) [1818835]
- [tools] perf evlist: Use unshare(CLONE_FS) in sb threads to let setns(CLONE_NEWNS) work (Michael Petlan) [1818835]
- [tools] libperf: Move 'enum perf_user_event_type' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Rename the PERF_RECORD_ structs to have a "perf" prefix (Michael Petlan) [1818835]
- [tools] libperf: Add 'union perf_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_COMPRESSED 'struct compressed_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_HEADER_FEATURE 'struct feature_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_TIME_CONV 'struct time_conv_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_STAT_ROUND 'struct stat_round_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_STAT 'struct stat_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_STAT_CONFIG 'struct stat_config_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_THREAD_MAP 'struct thread_map_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_SWITCH 'struct context_switch_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_ITRACE_START 'struct itrace_start_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_AUX 'struct aux_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_AUXTRACE_ERROR 'struct auxtrace_error_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_AUXTRACE 'struct auxtrace_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_AUXTRACE_INFO 'struct auxtrace_info_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_ID_INDEX 'struct id_index_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_HEADER_BUILD_ID 'struct build_id_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_HEADER_TRACING_DATA 'struct tracing_data_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_HEADER_EVENT_TYPE 'struct event_type_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_EVENT_UPDATE 'struct event_update_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_CPU_MAP 'struct cpu_map_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_HEADER_ATTR 'struct attr_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] perf top: Fix event group with more than two events (Michael Petlan) [1818835]
- [tools] perf top: Decay all events in the evlist (Michael Petlan) [1818835]
- [tools] perf clang: Delete needless util-cxx.h header (Michael Petlan) [1818835]
- [tools] perf evlist: Remove needless util.h from evlist.h (Michael Petlan) [1818835]
- [tools] perf tools: Remove needless util.h include from builtin.h (Michael Petlan) [1818835]
- [tools] perf tools: Warn that perf_event_paranoid can restrict kernel symbols (Michael Petlan) [1818835]
- [tools] perf symbols: Use CAP_SYSLOG with kptr_restrict checks (Michael Petlan) [1818835]
- [tools] perf evsel: Kernel profiling is disallowed only when perf_event_paranoid > 1 (Michael Petlan) [1818835]
- [tools] perf tools: Use CAP_SYS_ADMIN with perf_event_paranoid checks (Michael Petlan) [1818835]
- [tools] perf event: Check ref_reloc_sym before using it (Michael Petlan) [1818835]
- [tools] perf arch powerpc: Sync powerpc syscall.tbl (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_missing_features::bpf_event to ::bpf (Michael Petlan) [1818835]
- [tools] perf tool: Rename perf_tool::bpf_event to bpf (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_event::bpf_event to perf_event::bpf (Michael Petlan) [1818835]
- [tools] perf tools: Rename perf_event::ksymbol_event to perf_event::ksymbol (Michael Petlan) [1818835]
- [tools] libperf: Rename the PERF_RECORD_ structs to have a "perf" suffix (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_SAMPLE 'struct sample_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_BPF_EVENT 'struct bpf_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_KSYMBOL 'struct ksymbol_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_THROTTLE 'struct throttle_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_READ 'struct read_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_LOST_SAMPLES 'struct lost_samples_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_LOST 'struct lost_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_FORK 'struct fork_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_NAMESPACES 'struct namespaces_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_COMM 'struct comm_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_MMAP2 'struct mmap2_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] libperf: Add PERF_RECORD_MMAP 'struct mmap_event' to perf/event.h (Michael Petlan) [1818835]
- [tools] perf script: Fix memory leaks in list_scripts() (Michael Petlan) [1818835]
- [tools] perf report: Fix --ns time sort key output (Michael Petlan) [1818835]
- [tools] perf report: Use timestamp__scnprintf_nsec() for time sort key (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Reduce perf_event_output() boilerplate (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Introduce helper to get the scratch space (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Postpone tmp map lookup to after pid_filter (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Rename augmented_filename to augmented_arg (Michael Petlan) [1818835]
- [tools] perf trace beauty ioctl: Fix off-by-one error in cmd->string table (Michael Petlan) [1818835]
- [tools] perf tests: Fixes hang in zstd compression test by changing the source of random data (Michael Petlan) [1818835]
- [tools] perf sort: Remove needless headers from sort.h, provide fwd struct decls (Michael Petlan) [1818835]
- [tools] perf srcline: Add missing srcline.h header to files needing its defs (Michael Petlan) [1818835]
- [tools] perf cacheline: Move cacheline related routines to separate files (Michael Petlan) [1818835]
- [tools] perf record: Move record_opts and other record decls out of perf.h (Michael Petlan) [1818835]
- [tools] perf stat: Remove needless headers from stat.h (Michael Petlan) [1818835]
- [tools] perf cpumap: No need to include perf.h, ditch it (Michael Petlan) [1818835]
- [tools] libperf: Fix alignment trap with xyarray contents in 'perf stat' (Michael Petlan) [1818835]
- [tools] libperf: Add perf_thread_map__nr/perf_thread_map__pid functions (Michael Petlan) [1818835]
- [tools] perf cpumap: Remove needless includes from cpumap.h (Michael Petlan) [1818835]
- [tools] perf evsel: Switch to libperf's cpumap.h (Michael Petlan) [1818835]
- [tools] perf x86 kvm-stat: Add missing string.h header (Michael Petlan) [1818835]
- [tools] perf evsel: util/evsel.h needs stdio.h as it uses FILE (Michael Petlan) [1818835]
- [tools] perf evsel: Remove needless stddef.h from util/evsel.h (Michael Petlan) [1818835]
- [tools] perf evsel: Remove needless counts.h header from util/evsel.h (Michael Petlan) [1818835]
- [tools] perf evsel: Add missing perf/evsel.h header in util/evsel.h (Michael Petlan) [1818835]
- [tools] perf scripting python: Add missing counts.h header (Michael Petlan) [1818835]
- [tools] perf stat: Add missing counts.h (Michael Petlan) [1818835]
- [tools] perf tests: Add missing counts.h (Michael Petlan) [1818835]
- [tools] perf script: Add missing counts.h (Michael Petlan) [1818835]
- [tools] perf evlist: Add missing xyarray.h header (Michael Petlan) [1818835]
- [tools] perf bpf: Add missing xyarray.h header (Michael Petlan) [1818835]
- [tools] perf counts: Add missing headers needed for types used (Michael Petlan) [1818835]
- [tools] perf evsel: Move xyarray.h from evsel.c to evsel.h to reduce include dep tree (Michael Petlan) [1818835]
- [tools] perf metricgroup: Remove needless includes from metricgroup.h (Michael Petlan) [1818835]
- [tools] perf kvm s390: Add missing string.h header (Michael Petlan) [1818835]
- [tools] perf arm64: Add missing debug.h header (Michael Petlan) [1818835]
- [tools] libperf: Move perf's cpu_map__idx() to perf_cpu_map__idx() (Michael Petlan) [1818835]
- [tools] libperf: Move perf's cpu_map__empty() to perf_cpu_map__empty() (Michael Petlan) [1818835]
- [tools] perf tools: Use perf_cpu_map__nr instead of cpu_map__nr (Michael Petlan) [1818835]
- [tools] tools headers: Add missing perf_event.h include (Michael Petlan) [1818835]
- [tools] libperf: Fix arch include paths (Michael Petlan) [1818835]
- [tools] tools headers: Fixup bitsperlong per arch includes (Michael Petlan) [1818835]
- [tools] perf top: Show info message while collecting samples (Michael Petlan) [1818835]
- [tools] perf ui browser: Allow specifying message to show when no samples are available to display (Michael Petlan) [1818835]
- [tools] perf ui: Introduce non-interactive ui__info_window() function (Michael Petlan) [1818835]
- [tools] perf ui: Make 'exit_msg' optional in ui__question_window() (Michael Petlan) [1818835]
- [tools] perf cs-etm: Support sample flags 'insn' and 'insnlen' (Michael Petlan) [1818835]
- [tools] perf report: Prefer DWARF callstacks to LBR ones when captured both (Michael Petlan) [1818835]
- [tools] perf report: Dump LBR callstack data by -D jointly with thread stack (Michael Petlan) [1818835]
- [tools] perf record: Enable LBR callstack capture jointly with thread stack (Michael Petlan) [1818835]
- [tools] tools lib traceevent: Fix "robust" test of do_generate_dynamic_list_file (Michael Petlan) [1818835]
- [tools] perf evsel: Add comment for 'idx' member in 'struct perf_sample_id (Michael Petlan) [1818835]
- [tools] tools headers: Synchronize linux/bits.h with the kernel sources (Michael Petlan) [1818835]
- [tools] tools headers: Grab copy of linux/const.h, needed by linux/bits.h (Michael Petlan) [1818835]
- [tools] perf tools: tools/include should come before tools/uapi/include (Michael Petlan) [1818835]
- [tools] tools headers: Add limits.h to access __WORDSIZE (Michael Petlan) [1818835]
- [tools] perf unwind: Remove unnecessary test (Michael Petlan) [1818835]
- [tools] perf unwind: Fix libunwind when tid != pid (Michael Petlan) [1818835]
- [tools] perf map: Use zalloc for map_groups (Michael Petlan) [1818835]
- [tools] perf report: Add --switch-on/--switch-off events (Michael Petlan) [1818835]
- [tools] perf top: Add --switch-on/--switch-off events (Michael Petlan) [1818835]
- [tools] perf trace: Add --switch-on/--switch-off events (Michael Petlan) [1818835]
- [tools] perf evswitch: Add hint when not finding specified on/off events (Michael Petlan) [1818835]
- [tools] perf evswitch: Move enoent error message printing to separate function (Michael Petlan) [1818835]
- [tools] perf evswitch: Introduce init() method to set the on/off evsels from the command line (Michael Petlan) [1818835]
- [tools] perf evswitch: Introduce OPTS_EVSWITCH() for cmd line processing (Michael Petlan) [1818835]
- [tools] perf evswitch: Add the names of on/off events (Michael Petlan) [1818835]
- [tools] perf evswitch: Move switch logic to use in other tools (Michael Petlan) [1818835]
- [tools] perf evswitch: Move struct to a separate header to use in other tools (Michael Petlan) [1818835]
- [tools] perf script: Allow specifying event to switch off processing of other events (Michael Petlan) [1818835]
- [tools] perf script: Allow showing the --switch-on event (Michael Petlan) [1818835]
- [tools] perf script: Allow specifying event to switch on processing of other events (Michael Petlan) [1818835]
- [tools] perf vendor events intel: Add Tremontx event file v1.02 (Michael Petlan) [1818835]
- [tools] perf ui: No need to set ui_browser to 1 twice (Michael Petlan) [1818835]
- [tools] perf record: Support aarch64 random socket_id assignment (Michael Petlan) [1818835]
- [tools] perf.data documentation: Clarify HEADER_SAMPLE_TOPOLOGY format (Michael Petlan) [1818835]
- [tools] perf evsel: Provide meaningful warning when trying to use 'aux_output' on older kernels (Michael Petlan) [1818835]
- [tools] perf intel-pt: Add brief documentation for PEBS via Intel PT (Michael Petlan) [1818835]
- [tools] perf tools: Add aux-output config term (Michael Petlan) [1818835]
- [tools] perf intel-pt: Process options for PEBS event synthesis (Michael Petlan) [1818835]
- [tools] perf tools: Add itrace option 'o' to synthesize aux-output events (Michael Petlan) [1818835]
- [tools] perf tools: Add aux_output attribute flag (Michael Petlan) [1818835]
- [tools] perf record: Add an option to take an AUX snapshot on exit (Michael Petlan) [1818835]
- [tools] perf ftrace: Improve error message about capability to use ftrace (Michael Petlan) [1818835]
- [tools] perf ftrace: Use CAP_SYS_ADMIN instead of euid==0 (Michael Petlan) [1818835]
- [tools] perf tools: Add CAP_SYSLOG define for older systems (Michael Petlan) [1818835]
- [tools] perf tools: Add NO_LIBCAP=1 to the minimal build test (Michael Petlan) [1818835]
- [tools] perf tools: Add helpers to use capabilities if present (Michael Petlan) [1818835]
- [tools] tools build: Add capability-related feature detection (Michael Petlan) [1818835]
- [tools] perf top: Collapse and resort all evsels in a group (Michael Petlan) [1818835]
- [tools] perf hist: Remove dummy entries when finding real ones (Michael Petlan) [1818835]
- [tools] perf trace: Fix segmentation fault when access syscall info on arm64 (Michael Petlan) [1818835]
- [tools] perf hists: Do not link a pair if already linked (Michael Petlan) [1818835]
- [tools] perf top: Set display thread COMM to help with debugging (Michael Petlan) [1818835]
- [tools] perf vendor events intel: Add Icelake V1.00 event file (Michael Petlan) [1818835]
- [tools] perf tools: Fix paths in include statements (Michael Petlan) [1818835]
- [tools] perf test vfs_getname: Disable ~/.perfconfig to get default output (Michael Petlan) [1818835]
- [tools] perf config: Document the PERF_CONFIG environment variable (Michael Petlan) [1818835]
- [tools] perf config: Honour $PERF_CONFIG env var to specify alternate .perfconfig (Michael Petlan) [1818835]
- [tools] perf session: Avoid infinite loop when seeing invalid header.size (Michael Petlan) [1818835]
- [tools] libperf: Initial documentation (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__enable/disable test (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__enable/disable test (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel tests (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist test (Michael Petlan) [1818835]
- [tools] libperf: Add perf_thread_map test (Michael Petlan) [1818835]
- [tools] libperf: Add perf_cpu_map test (Michael Petlan) [1818835]
- [tools] libperf: Add tests support (Michael Petlan) [1818835]
- [tools] libperf: Add install targets (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__attr() function (Michael Petlan) [1818835]
- [tools] libperf: Adopt perf_evlist__enable()/disable() functions from perf (Michael Petlan) [1818835]
- [tools] libperf: Adopt simplified perf_evlist__open()/close() functions from tools/perf (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__cpus()/threads() functions (Michael Petlan) [1818835]
- [tools] libperf: Add perf_cpu_map__for_each_cpu() macro (Michael Petlan) [1818835]
- [tools] libperf: Adopt perf_evsel__enable()/disable()/apply_filter() functions (Michael Petlan) [1818835]
- [tools] libperf: Adopt perf_evsel__read() function from tools/perf (Michael Petlan) [1818835]
- [tools] libperf: Adopt simplified perf_evsel__close() function from tools/perf (Michael Petlan) [1818835]
- [tools] libperf: Adopt simplified perf_evsel__open() function from tools/perf (Michael Petlan) [1818835]
- [tools] libperf: Adopt perf_evsel__alloc_fd() function from tools/perf (Michael Petlan) [1818835]
- [tools] libperf: Adopt the readn()/writen() functions from tools/perf (Michael Petlan) [1818835]
- [tools] libperf: Move nr_members from perf's evsel to libperf's perf_evsel (Michael Petlan) [1818835]
- [tools] libperf: Move fd array from perf's evsel to lobperf's perf_evsel class (Michael Petlan) [1818835]
- [tools] libperf: Adopt xyarray class from perf (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__set_maps() function (Michael Petlan) [1818835]
- [tools] libperf: Add threads to struct perf_evlist (Michael Petlan) [1818835]
- [tools] libperf: Add cpus to struct perf_evlist (Michael Petlan) [1818835]
- [tools] libperf: Add has_user_cpus to struct perf_evlist (Michael Petlan) [1818835]
- [tools] libperf: Add threads to struct perf_evsel (Michael Petlan) [1818835]
- [tools] libperf: Add own_cpus to struct perf_evsel (Michael Petlan) [1818835]
- [tools] libperf: Add cpus to struct perf_evsel (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__delete() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__delete() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__for_each_evsel() iterator (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__new() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__new() function (Michael Petlan) [1818835]
- [tools] libperf: Move zalloc.o into libperf (Michael Petlan) [1818835]
- [tools] libperf: Add perf_cpu_map__new()/perf_cpu_map__read() functions (Michael Petlan) [1818835]
- [tools] libperf: Move perf_event_attr field from perf's evsel to libperf's perf_evsel (Michael Petlan) [1818835]
- [tools] libperf: Add nr_entries to struct perf_evlist (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__remove() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__add() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist__init() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evsel__init function (Michael Petlan) [1818835]
- [tools] libperf: Include perf_evlist in evlist object (Michael Petlan) [1818835]
- [tools] libperf: Include perf_evsel in evsel object (Michael Petlan) [1818835]
- [tools] libperf: Add perf_evlist and perf_evsel structs (Michael Petlan) [1818835]
- [tools] libperf: Add perf_thread_map__get()/perf_thread_map__put() (Michael Petlan) [1818835]
- [tools] libperf: Add perf_thread_map__new_dummy() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_thread_map struct (Michael Petlan) [1818835]
- [tools] libperf: Add perf_cpu_map__get()/perf_cpu_map__put() (Michael Petlan) [1818835]
- [tools] libperf: Add perf_cpu_map__dummy_new() function (Michael Petlan) [1818835]
- [tools] libperf: Add perf_cpu_map struct (Michael Petlan) [1818835]
- [tools] libperf: Add debug output support (Michael Petlan) [1818835]
- [tools] libperf: Add perf/core.h header (Michael Petlan) [1818835]
- [tools] libperf: Add libperf to the python.so build (Michael Petlan) [1818835]
- [tools] libperf: Add build version support (Michael Petlan) [1818835]
- [tools] libperf: Make libperf.a part of the perf build (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__disable() to evlist__disable() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__enable() to evlist__enable() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__close() to evlist__close() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__open() to evlist__open() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__cpus() to evsel__cpus() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__apply_filter() to evsel__apply_filter() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__disable() to evsel__disable() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__enable() to evsel__enable() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__open() to evsel__open() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__remove() to evlist__remove() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__add() to evlist__add() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__new() to evsel__new() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__delete() to evsel__delete() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__delete() to evlist__delete() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__new() to evlist__new() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename perf_evlist__init() to evlist__init() (Michael Petlan) [1818835]
- [tools] perf evsel: Rename perf_evsel__init() to evsel__init() (Michael Petlan) [1818835]
- [tools] perf evlist: Rename struct perf_evlist to struct evlist (Michael Petlan) [1818835]
- [tools] perf evsel: Rename struct perf_evsel to struct evsel (Michael Petlan) [1818835]
- [tools] perf tools: Rename struct thread_map to struct perf_thread_map (Michael Petlan) [1818835]
- [tools] perf cpu_map: Rename struct cpu_map to struct perf_cpu_map (Michael Petlan) [1818835]
- [tools] perf stat: Move loaded out of struct perf_counts_values (Michael Petlan) [1818835]
- [tools] perf trace: Add "sendfile64" alias to the "sendfile" syscall (Michael Petlan) [1818835]
- [tools] perf trace: Reuse BPF augmenters from syscalls with similar args signature (Michael Petlan) [1818835]
- [tools] perf trace: Preallocate the syscall table (Michael Petlan) [1818835]
- [tools] perf trace: Mark syscall ids that are not allocated to avoid unnecessary error messages (Michael Petlan) [1818835]
- [tools] perf trace: Forward error codes when trying to read syscall info (Michael Petlan) [1818835]
- [tools] perf trace beauty: Add BPF augmenter for the 'rename' syscall (Michael Petlan) [1818835]
- [tools] perf trace beauty: Beautify bind's sockaddr arg (Michael Petlan) [1818835]
- [tools] perf trace beauty: Beautify 'sendto's sockaddr arg (Michael Petlan) [1818835]
- [tools] perf trace beauty: Do not try to use the fd->pathname beautifier for bind/connect fd arg (Michael Petlan) [1818835]
- [tools] perf trace beauty: Disable fd->pathname when close() not enabled (Michael Petlan) [1818835]
- [tools] perf trace beauty: Make connect's addrlen be printed as an int, not hex (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Augment sockaddr arg in 'connect' (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Rename augmented_args_filename to augmented_args_payload (Michael Petlan) [1818835]
- [tools] perf trace: Look for default name for entries in the syscalls prog array (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Support copying two string syscall args (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Switch to using BPF_MAP_TYPE_PROG_ARRAY (Michael Petlan) [1818835]
- [tools] perf augmented_raw_syscalls: Add handler for "openat" (Michael Petlan) [1818835]
- [tools] perf trace: Handle raw_syscalls:sys_enter just like the BPF_OUTPUT augmented event (Michael Petlan) [1818835]
- [tools] perf trace: Put the per-syscall entry/exit prog_array BPF map infrastructure in place (Michael Petlan) [1818835]
- [tools] perf trace: Allow specifying the bpf prog to augment specific syscalls (Michael Petlan) [1818835]
- [tools] perf trace: Add BPF handler for unaugmented syscalls (Michael Petlan) [1818835]
- [tools] perf trace: Order -e syscalls table (Michael Petlan) [1818835]
- [tools] perf trace: Look up maps just on the __augmented_syscalls__ BPF object (Michael Petlan) [1818835]
- [tools] perf trace: Add pointer to BPF object containing __augmented_syscalls__ (Michael Petlan) [1818835]
- [tools] perf evsel: Store backpointer to attached bpf_object (Michael Petlan) [1818835]
- [tools] perf bpf: Do not attach a BPF prog to a tracepoint if its name starts with ! (Michael Petlan) [1818835]
- [tools] perf include bpf: Add bpf_tail_call() prototype (Michael Petlan) [1818835]
- [tools] perf: cs-etm: Optimize option setup for CPU-wide sessions (Michael Petlan) [1818835]
- [tools] perf cs-etm: Remove duplicate GENMASK() define, use linux/bits.h instead (Michael Petlan) [1818835]
- [tools] perf cs-etm: Add support for CPU-wide trace scenarios (Michael Petlan) [1818835]
- [tools] perf cs-etm: Add notion of time to decoding code (Michael Petlan) [1818835]
- [tools] perf cs-etm: Linking PE contextID with perf thread mechanic (Michael Petlan) [1818835]
- [tools] perf cs-etm: Add support for multiple traceID queues (Michael Petlan) [1818835]
- [tools] perf cs-etm: Use traceID aware memory callback API (Michael Petlan) [1818835]
- [tools] perf cs-etm: Move tid/pid to traceid_queue (Michael Petlan) [1818835]
- [tools] perf cs-etm: Move thread to traceid_queue (Michael Petlan) [1818835]
- [tools] perf cs-etm: Get rid of unused cpu in struct cs_etm_queue (Michael Petlan) [1818835]
- [tools] perf cs-etm: Introduce the concept of trace ID queues (Michael Petlan) [1818835]
- [tools] perf cs-etm: Fix indentation in function cs_etm__process_decoder_queue() (Michael Petlan) [1818835]
- [tools] perf cs-etm: Move packet queue out of decoder structure (Michael Petlan) [1818835]
- [tools] perf cs-etm: Refactor error path in cs_etm_decoder__new() (Michael Petlan) [1818835]
- [tools] perf cs-etm: Add handling of switch-CPU-wide events (Michael Petlan) [1818835]
- [tools] perf cs-etm: Add handling of itrace start events (Michael Petlan) [1818835]
- [tools] perf cs-etm: Configure SWITCH_EVENTS in CPU-wide mode (Michael Petlan) [1818835]
- [tools] perf cs-etm: Configure timestamp generation in CPU-wide mode (Michael Petlan) [1818835]
- [tools] perf cs-etm: Configure contextID tracing in CPU-wide mode (Michael Petlan) [1818835]
- [kernel] perf/core: Fix missing static inline on perf_cgroup_switch() (Michael Petlan) [1818835]
- [kernel] perf/core: Consistently fail fork on allocation failures (Michael Petlan) [1818835]
- [kernel] perf/core: Disallow uncore-cgroup events (Michael Petlan) [1818835]
- [include] perf/headers: Fix spelling s/EACCESS/EACCES/, s/privilidge/privilege/ (Michael Petlan) [1818835]
- [x86] perf/x86/uncore: Fix event group support (Michael Petlan) [1818835]
- [kernel] perf/core: Start rejecting the syscall with attr.__reserved_2 set (Michael Petlan) [1818835]
- [kernel] perf/aux: Fix tracking of auxiliary trace buffer allocation (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Fix base for single entry topa (Michael Petlan) [1818835]
- [x86] perf/x86/cstate: Add Tiger Lake CPU support (Michael Petlan) [1818835]
- [x86] perf/x86/msr: Add Tiger Lake CPU support (Michael Petlan) [1818835]
- [x86] perf/x86/intel: Add Tiger Lake CPU support (Michael Petlan) [1818835]
- [x86] perf/x86/cstate: Update C-state counters for Ice Lake (Michael Petlan) [1818835]
- [x86] perf/x86/msr: Add new CPU model numbers for Ice Lake (Michael Petlan) [1818835]
- [kernel] perf/core: Fix corner case in perf_rotate_context() (Michael Petlan) [1818835]
- [kernel] perf/core: Rework memory accounting in perf_mmap() (Michael Petlan) [1818835]
- [kernel] perf/core: Fix several typos in comments (Michael Petlan) [1818835]
- [x86] perf/x86: Make more stuff static (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Get rid of reverse lookup table for ToPA (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Free up space in a ToPA descriptor (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Split ToPA metadata and page layout (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Use pointer arithmetics instead in ToPA entry calculation (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Use helpers to obtain ToPA entry size (Michael Petlan) [1818835]
- [x86] perf/x86/intel/pt: Clean up ToPA allocation path (Michael Petlan) [1818835]

* Wed Apr 22 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.11.el8]
- [scsi] scsi: bnx2fc: Update the driver version to 2.12.13 (Nilesh Javali) [1792115]
- [scsi] scsi: bnx2fc: fix boolreturn.cocci warnings (Nilesh Javali) [1792115]
- [scsi] scsi: bnx2fc: Fix SCSI command completion after cleanup is posted (Nilesh Javali) [1792115]
- [scsi] scsi: bnx2fc: Process the RQE with CQE in interrupt context (Nilesh Javali) [1792115]
- [scsi] scsi: bnx2fc: timeout calculation invalid for bnx2fc_eh_abort() (Nilesh Javali) [1792115]
- [powerpc] powerpc/smp: Use nid as fallback for package_id (Steve Best) [1764530]
- [kernel] audit: Add __rcu annotation to RCU pointer (Richard Guy Briggs) [1822776]
- [infiniband] i40iw: Report correct firmware version (Stefan Assmann) [1726909]
- [x86] x86/mce/amd: Add PPIN support for AMD MCE (Wei Huang) [1790521]
- [kernel] locking/percpu-rwsem: Fix a task_struct refcount (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem: Add might_sleep() for writer locking (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem: Fold __percpu_up_read() (Waiman Long) [1810257]
- [kernel] locking/rwsem: Remove RWSEM_OWNER_UNKNOWN (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem: Remove the embedded rwsem (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem: Extract __percpu_down_read_trylock() (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem: Move __this_cpu_inc() into the slowpath (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem: Convert to bool (Waiman Long) [1810257]
- [kernel] locking/percpu-rwsem, lockdep: Make percpu-rwsem use its own lockdep_map (Waiman Long) [1810257]
- [kernel] locking/lockdep: Remove unused @nested argument from lock_release() (Waiman Long) [1810257]
- [kernel] sched/core: Convert get_task_struct() to return the task (Waiman Long) [1810257]
- [kernel] locking/lockdep, cpu/hotplug: Annotate AP thread (Waiman Long) [1810257]
- [tty] tty/ldsem: Decrement wait_readers on timeouted down_read() (Waiman Long) [1810257]
- [tty] tty/ldsem: Convert to regular lockdep annotations (Waiman Long) [1810257]
- [tty] tty/ldsem: Wake up readers after timed out down_write() (Waiman Long) [1810257]
- [tty] atomic/tty: Fix up atomic abuse in ldsem (Waiman Long) [1810257]
- [kernel] cpu/hotplug: Remove skip_onerr field from cpuhp_step structure (Waiman Long) [1810257]
- [watchdog] watchdog: hpwdt: drop warning after calling watchdog_init_timeout (Joseph Szczypek) [1790669]
- [mm] powerpc/pkeys: Fix handling of pkey state across fork() (Steve Best) [1823744]
- [irqchip] irqchip/gic-v3: Workaround Cavium erratum 38539 when reading GICD_TYPER2 (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Avoid 64bit division for the sake of 32bit ARM (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Rename VPENDBASER/VPROPBASER accessors (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Remove superfluous WARN_ON (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Drop 'tmp' in inherit_vpe_l1_table_from_rd() (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Ensure L2 vPE table is allocated at RD level (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Set vpe_l1_base for all redistributors (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Fix programming of GICR_VPROPBASER_4_1_SIZE (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Reference to its_invall_cmd descriptor when building INVALL (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Only provision redistributors that are enabled in ACPI (Mark Salter) [1818174]
- [arm64] arm64: acpi: fix DAIF manipulation with pNMI (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Allow direct invalidation of VLPIs (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Suppress per-VLPI doorbell (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Add VPE INVALL callback (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Add VPE eviction callback (Mark Salter) [1818174]
- [include] irqchip/gic-v4.1: Add VPE residency callback (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Add mask/unmask doorbell callbacks (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Plumb skeletal VPE irqchip (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Implement the v4.1 flavour of VMOVP (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Don't use the VPE proxy if RVPEID is set (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: Implement the v4.1 flavour of VMAPP (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4.1: VPE table (aka GICR_VPROPBASER) allocation (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Add GICv4.1 VPEID size discovery (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Detect GICv4.1 supporting RVPEID (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix get_vlpi_map() breakage with doorbells (Mark Salter) [1818174]
- [arm64] arm64: Kconfig: Remove CONFIG_ prefix from ARM64_PSEUDO_NMI section (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Make vlpi_lock a spinlock (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Lock VLPI map array before translating it (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Synchronise INT/CLEAR commands targetting a VLPI using VSYNC (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Synchronise INV command targetting a VLPI using VSYNC (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Add its_vlpi_map helpers (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Kill its->device_ids and use TYPER copy instead (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Kill its->ite_size and use TYPER copy instead (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Make is_v4 use a TYPER copy (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Allow LPI invalidation via the DirectLPI interface (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Factor out wait_for_syncr primitive (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Free collection mapping on device teardown (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix u64 to __le64 warnings (Mark Salter) [1818174]
- [irqchip] irqchip: Remove redundant semicolon after while (Mark Salter) [1818174]
- [virt] KVM: vgic-v4: Track the number of VLPIs per vcpu (Mark Salter) [1818174]
- [virt] KVM: arm64: vgic-v4: Move the GICv4 residency flow to be driven by vcpu_load/put (Mark Salter) [1818174]
- [arm64] arm64: add local_daif_inherit() (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Use the exact ITSList for VMOVP (Mark Salter) [1818174]
- [arm64] arm64: Relax ICC_PMR_EL1 accesses when ICC_CTLR_EL1.PMHE is clear (Mark Salter) [1818174]
- [arm64] arm64: Fix incorrect irqflag restore for priority masking for compat (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Fix GIC_LINE_NR accessor (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix LPI release for Multi-MSI devices (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Remove the redundant set_bit for lpi_map (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Add quirks for HIP06/07 invalid GICD_TYPER erratum 161010803 (Mark Salter) [1818174]
- [irqchip] irqchip/gic: Skip DT quirks when evaluating IIDR-based quirks (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Warn about inconsistent implementations of extended ranges (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Add EPPI range support (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Dynamically allocate PPI partition descriptors (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Dynamically allocate PPI NMI refcounts (Mark Salter) [1818174]
- [irqchip] irqchip/gic: Prepare for more than 16 PPIs (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Add ESPI range support (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Add INTID range and convertion primitives (Mark Salter) [1818174]
- [irqchip] irqchip/gic: Rework gic_configure_irq to take the full ICFGR base (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v2m: Register the frame's PA instead of its VA in fwnode (Mark Salter) [1818174]
- [irqchip] irqchip/gic: Register the distributor's PA instead of its VA in fwnode (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Register the ITS' PA instead of its VA in fwnode (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Register the distributor's PA instead of its VA in fwnode (Mark Salter) [1818174]
- [arm64] arm64: kprobes: Recover pstate.D in single-step exception handler (Mark Salter) [1818174]
- [arm64] arm64: Lower priority mask for GIC_PRIO_IRQON (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Free unused vpt_page when alloc vpe table fail (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Mark expected switch fall-through (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix misuse of GENMASK macro (Mark Salter) [1818174]
- [arm64] arm64: fix kernel stack overflow in kdump capture kernel (Mark Salter) [1818174]
- [arm64] arm64: irqflags: Introduce explicit debugging for IRQ priorities (Mark Salter) [1818174]
- [arm64] arm64: Enable the support of pseudo-NMIs (Mark Salter) [1818174]
- [arm64] arm64: Fix incorrect irqflag restore for priority masking (Mark Salter) [1818174]
- [arm64] arm64: Fix interrupt tracing in the presence of NMIs (Mark Salter) [1818174]
- [arm64] arm64: irqflags: Add condition flags to inline asm clobber list (Mark Salter) [1818174]
- [arm64] arm64: irqflags: Pass flags as readonly operand to restore instruction (Mark Salter) [1818174]
- [arm64] arm64: Do not enable IRQs for ct_user_exit (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix command queue pointer comparison bug (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Make free_lpi_range a little cheaper (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Drop redundant initialization in mk_lpi_range (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Move allocation outside mutex (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix typo in a comment in its_msi_prepare() (Mark Salter) [1818174]
- [include] irqchip/gic-v3-its: fix some definitions of inner cacheability attributes (Mark Salter) [1818174]
- [arm64] arm64: fix wrong check of on_sdei_stack in nmi context (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Fix comparison logic in lpi_range_cmp (Mark Salter) [1818174]
- [arm64] arm64: remove obsolete selection of MULTI_IRQ_HANDLER (Mark Salter) [1818174]
- [irqchip] irqchip/gicv3-its: Use NUMA aware memory allocation for ITS tables (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Avoid parsing _indirect_ twice for Device table (Mark Salter) [1818174]
- [arm64] arm64: irqflags: Fix clang build warnings (Mark Salter) [1818174]
- [arm64] arm64: KVM/mm: Move SEA handling behind a single 'claim' interface (Mark Salter) [1818174]
- [arm64] arm64: Skip irqflags tracing for NMI in IRQs disabled context (Mark Salter) [1818174]
- [arm64] arm64: Skip preemption when exiting an NMI (Mark Salter) [1818174]
- [arm64] arm64: Handle serror in NMI context (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Allow interrupts to be set as pseudo-NMI (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Handle pseudo-NMIs (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Detect if GIC can support pseudo-NMIs (Mark Salter) [1818174]
- [arm64] arm64: gic-v3: Implement arch support for priority masking (Mark Salter) [1818174]
- [irqchip] arm64: Switch to PMR masking when starting CPUs (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Factor group0 detection into functions (Mark Salter) [1818174]
- [arm64] arm64: alternative: Apply alternatives early in boot process (Mark Salter) [1818174]
- [arm64] arm64: alternative: Allow alternative status checking per cpufeature (Mark Salter) [1818174]
- [arm64] arm64: sysreg: Make mrs_s and msr_s macros work with Clang and LTO (Mark Salter) [1818174]
- [arm64] arm64: daifflags: Include PMR in daifflags restore operations (Mark Salter) [1818174]
- [arm64] arm64: irqflags: Use ICC_PMR_EL1 for interrupt masking (Mark Salter) [1818174]
- [firmware] efi: Let architectures decide the flags that should be saved/restored (Mark Salter) [1818174]
- [kvm] arm64: kvm: Unmask PMR before entering guest (Mark Salter) [1818174]
- [mm] arm64: Unmask PMR before going idle (Mark Salter) [1818174]
- [arm64] arm64: Make PMR part of task context (Mark Salter) [1818174]
- [arm64] arm64: ptrace: Provide definitions for PMR values (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Switch to PMR masking before calling IRQ handler (Mark Salter) [1818174]
- [arm64] arm64: cpufeature: Add cpufeature for IRQ priority masking (Mark Salter) [1818174]
- [arm64] arm64: cpufeature: Set SYSREG_GIC_CPUIF as a boot system feature (Mark Salter) [1818174]
- [arm64] arm64: Remove unused daif related functions/macros (Mark Salter) [1818174]
- [arm64] arm64: Fix HCR.TGE status for NMI contexts (Mark Salter) [1818174]
- [kernel] irqdesc: Add domain handler for NMIs (Mark Salter) [1818174]
- [kernel] genirq: Update irq stats from NMI handlers (Mark Salter) [1818174]
- [kernel] genirq: Provide NMI handlers (Mark Salter) [1818174]
- [kernel] genirq: Provide NMI management for percpu_devid interrupts (Mark Salter) [1818174]
- [kernel] genirq: Provide basic NMI management for interrupt lines (Mark Salter) [1818174]
- [include] irqchip/gic-v3-its: Fix ITT_entry_size accessor (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Gracefully fail on LPI exhaustion (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Plug allocation race for devices sharing a DevID (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v4: Fix occasional VLPI drop (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-mbi: Fix uninitialized mbi_lock (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Add quirk for msm8996 broken registers (Mark Salter) [1818174]
- [irqchip] irqchip/gic: Add support to device tree based quirks (Mark Salter) [1818174]
- [arm64] arm64: capabilities: Batch cpu_enable callbacks (Mark Salter) [1818174]
- [arm64] arm64: capabilities: Use linear array for detection and verification (Mark Salter) [1818174]
- [arm64] arm64: capabilities: Optimize this_cpu_has_cap (Mark Salter) [1818174]
- [arm64] arm64: capabilities: Speed up capability lookup (Mark Salter) [1818174]
- [irqchip] irqchip: Convert to using pOFn instead of device_node.name (Mark Salter) [1818174]
- [mm] arm64: Use daifflag_restore after bp_hardening (Mark Salter) [1818174]
- [arm64] arm64: daifflags: Use irqflags functions for daifflags (Mark Salter) [1818174]
- [include] irqchip/gic: Unify GIC priority definitions (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Remove acknowledge loop (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3: Allow interrupt to be configured as wake-up sources (Mark Salter) [1818174]
- [irqchip] irqchip/gic-v3-its: Make its_lock a raw_spin_lock_t (Mark Salter) [1818174]
- [irqchip] genirq/irqchip: Remove MULTI_IRQ_HANDLER as it's now obselete (Mark Salter) [1818174]
- [arm64] arm64: Use the new GENERIC_IRQ_MULTI_HANDLER (Mark Salter) [1818174]
- [irqchip] irqchip: Port the ARM IRQ drivers to GENERIC_IRQ_MULTI_HANDLER (Mark Salter) [1818174]
- [arm64] arm64: sdei: Mark sdei stack helper functions as static (Mark Salter) [1818174]
- [arm64] arm64: Add stack information to on_accessible_stack (Mark Salter) [1818174]
- [x86] Reserve at most 64M of SWIOTLB memory for crashkernel (Kairui Song) [1812754]
- [md] md/raid1: introduce wait_for_serialization (Nigel Croxon) [1788370]
- [md] md/raid1: use bucket based mechanism for IO serialization (Nigel Croxon) [1788370]
- [md] md: introduce a new struct for IO serialization (Nigel Croxon) [1788370]
- [md] md: don't destroy serial_info_pool if serialize_policy is true (Nigel Croxon) [1788370]
- [md] raid1: serialize the overlap write (Nigel Croxon) [1788370]
- [md] md: reorgnize mddev_create/destroy_serial_pool (Nigel Croxon) [1788370]
- [md] md: add serialize_policy sysfs node for raid1 (Nigel Croxon) [1788370]
- [md] md: prepare for enable raid1 io serialization (Nigel Croxon) [1788370]
- [md] md: fix a typo s/creat/create (Nigel Croxon) [1788370]
- [md] md: rename wb stuffs (Nigel Croxon) [1788370]
- [md] raid5: remove worker_cnt_per_group argument from alloc_thread_groups (Nigel Croxon) [1788370]
- [lib] md/raid6: fix algorithm choice under larger PAGE_SIZE (Nigel Croxon) [1788370]
- [lib] raid6/test: fix a compilation warning (Nigel Croxon) [1788370]
- [md] md-bitmap: small cleanups (Nigel Croxon) [1788370]

* Sat Apr 18 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.10.el8]
- [firmware] efi: cper: print AER info of PCIe fatal error (Vladis Dronov) [1822595]
- [init] redhat: Replace hardware.redhat.com link in Unsupported message (Prarit Bhargava) [1810301]
- [pci] PCI: Mark AMD Navi14 GPU rev 0xc5 ATS as broken (Myron Stowe) [1820933]
- [pci] PCI: Fix typos (Myron Stowe) [1820933]
- [pci] PCI: Remove useless comments and tidy others (Myron Stowe) [1820933]
- [pci] PCI: Remove unnecessary includes (Myron Stowe) [1820933]
- [tools] tools: PCI: Fix fd leakage (Myron Stowe) [1820933]
- [pci] PCI: Export pci_parse_request_of_pci_ranges() (Myron Stowe) [1820933]
- [include] resource: Add a resource_list_first_type helper (Myron Stowe) [1820933]
- [pci] PCI/ATS: Restore EXPORT_SYMBOL_GPL() for pci_{enable, disable}_ats() (Myron Stowe) [1820933]
- [include] PCI/ATS: Add PASID stubs (Myron Stowe) [1820933]
- [pci] PCI: Unify ACS quirk desired vs provided checking (Myron Stowe) [1820933]
- [pci] PCI: Make ACS quirk implementations more uniform (Myron Stowe) [1820933]
- [pci] PCI: Apply Cavium ACS quirk to ThunderX2 and ThunderX3 (Myron Stowe) [1820933]
- [pci] PCI/IOV: Serialize sysfs sriov_numvfs reads vs writes (Myron Stowe) [1820933]
- [pci] PCI: Add DMA alias quirk for Intel VCA NTB (Myron Stowe) [1820933]
- [pci] PCI: Fix Intel ACS quirk UPDCR register address (Myron Stowe) [1820933]
- [pci] PCI/ATS: Make pci_restore_pri_state(), pci_restore_pasid_state() private (Myron Stowe) [1820933]
- [pci] PCI/ATS: Remove unnecessary EXPORT_SYMBOL_GPL() (Myron Stowe) [1820933]
- [include] PCI/ATS: Remove unused PRI and PASID stubs (Myron Stowe) [1820933]
- [pci] PCI/ATS: Consolidate ATS declarations in linux/pci-ats.h (Myron Stowe) [1820933]
- [pci] PCI/ATS: Cache PRI PRG Response PASID Required bit (Myron Stowe) [1820933]
- [pci] PCI/ATS: Use PF PASID for VFs (Myron Stowe) [1820933]
- [pci] PCI/ATS: Cache PASID Capability offset (Myron Stowe) [1820933]
- [pci] PCI/ATS: Cache PRI Capability offset (Myron Stowe) [1820933]
- [pci] PCI/ATS: Disable PF/VF ATS service independently (Myron Stowe) [1820933]
- [pci] PCI/ATS: Handle sharing of PF PASID Capability with all VFs (Myron Stowe) [1820933]
- [pci] PCI/ATS: Handle sharing of PF PRI Capability with all VFs (Myron Stowe) [1820933]
- [pci] PCI/ATS: Move pci_prg_resp_pasid_required() to CONFIG_PCI_PRI (Myron Stowe) [1820933]
- [iommu] iommu/vt-d: Select PCI_PRI for INTEL_IOMMU_SVM (Myron Stowe) [1820933]
- [pci] PCI/switchtec: Read all 64 bits of part_event_bitmap (Myron Stowe) [1820933]
- [pci] PCI: Do not use bus number zero from EA capability (Myron Stowe) [1820933]
- [pci] PCI: Avoid double hpmemsize MMIO window assignment (Myron Stowe) [1820933]
- [pci] PCI: Add "pci=hpmmiosize" and "pci=hpmmioprefsize" parameters (Myron Stowe) [1820933]
- [pci] PCI: Add PCI_STD_NUM_BARS for the number of standard BARs (Myron Stowe) [1820933]
- [pci] PCI: Fix missing bridge dma_ranges resource list cleanup (Myron Stowe) [1820933]
- [pci] PCI: Protect pci_reassign_bridge_resources() against concurrent addition/removal (Myron Stowe) [1820933]
- [pci] PCI/MSI: Fix incorrect MSI-X masking on resume (Myron Stowe) [1820933]
- [pci] PCI/MSI: Move power state check out of pci_msi_supported() (Myron Stowe) [1820933]
- [pci] PCI/MSI: Remove unused pci_irq_get_node() (Myron Stowe) [1820933]
- [uapi] PCI: Add #defines for Enter Compliance, Transmit Margin (Myron Stowe) [1820933]
- [pci] PCI: Allow building PCIe things without PCIEPORTBUS (Myron Stowe) [1820933]
- [pci] PCI: Remove PCIe Kconfig dependencies on PCI (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Remove dependency on PCIEPORTBUS (Myron Stowe) [1820933]
- [pci] PCI/PTM: Remove dependency on PCIEPORTBUS (Myron Stowe) [1820933]
- [pci] PCI/PTM: Remove spurious "d" from granularity message (Myron Stowe) [1820933]
- [pci] PCI: sysfs: Remove unused attribute groups (Myron Stowe) [1820933]
- [x86] x86/PCI: Avoid AMD FCH XHCI USB PME# from D0 defect (Myron Stowe) [1820933]
- [pci] PCI: Remove unused includes and superfluous struct declaration (Myron Stowe) [1820933]
- [x86] x86/PCI: Replace deprecated EXTRA_CFLAGS with ccflags-y (Myron Stowe) [1820933]
- [pci] x86/PCI: Correct SPDX comment style (Myron Stowe) [1820933]
- [x86] x86/PCI: Add NumaChip SPDX GPL-2.0 to replace COPYING boilerplate (Myron Stowe) [1820933]
- [pci] ACPI / hotplug / PCI: Allocate resources directly under the non-hotplug bridge (Myron Stowe) [1820933]
- [pci] PCI: pciehp: Prevent deadlock on disconnect (Myron Stowe) [1820933]
- [pci] PCI: pciehp: Do not disable interrupt twice on suspend (Myron Stowe) [1820933]
- [pci] PCI: pciehp: Refactor infinite loop in pcie_poll_cmd() (Myron Stowe) [1820933]
- [pci] PCI: pciehp: Fix indefinite wait on sysfs requests (Myron Stowe) [1820933]
- [pci] PCI: pciehp: Avoid returning prematurely from sysfs requests (Myron Stowe) [1820933]
- [pci] PCI: Warn if no host bridge NUMA node info (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Remove PCIEASPM_DEBUG Kconfig option and related code (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Add sysfs attributes for controlling ASPM link states (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Add pcie_aspm_get_link() (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Allow re-enabling Clock PM (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Add L1 PM substate support to pci_disable_link_state() (Myron Stowe) [1820933]
- [pci] PCI/ASPM: Remove pcie_aspm_enabled() unnecessary locking (Myron Stowe) [1820933]
- [pci] PCI/DPC: Add "pcie_ports=dpc-native" to allow DPC without AER control (Myron Stowe) [1820933]
- [pci] PCI/AER: Fix kernel-doc warnings (Myron Stowe) [1820933]
- [pci] PCI/AER: Use for_each_set_bit() to simplify code (Myron Stowe) [1820933]
- [pci] PCI/AER: Add PoisonTLPBlocked to Uncorrectable error counters (Myron Stowe) [1820933]
- [pci] PCI/AER: Save AER Capability for suspend/resume (Myron Stowe) [1820933]
- [pci] PCI: Add ACS quirk for iProc PAXB (Myron Stowe) [1820933]
- [cpufreq] cpufreq: intel_pstate: Simplify intel_pstate_cpu_init() (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: powernv: Fix frame-size-overflow in powernv_cpufreq_work_fn (Prarit Bhargava) [1823339]
- [cpufreq] x86/devicetable: Move x86 specific macro out of generic code (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Use scnprintf() for avoiding potential buffer overflow (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: intel_pstate: Consolidate policy verification (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: powernv: Fix unsafe notifiers (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: powernv: Fix use-after-free (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: dt: Allow platform specific intermediate callbacks (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: add function to get the hardware max frequency (Prarit Bhargava) [1823339]
- [kernel] sched/vtime: Prevent unstable evaluation of WARN(vtime->state) (Prarit Bhargava) [1823339]
- [cpufreq] docs: cpufreq: fix a broken reference (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: annotate data races in pm_qos_*_value() (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Fix policy initialization for internal governor drivers (Prarit Bhargava) [1823339]
- [documentation] Documentation: power: fix pm_qos_interface.rst format warning (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Make CPU latency QoS depend on CONFIG_CPU_IDLE (Prarit Bhargava) [1823339]
- [documentation] Documentation: PM: QoS: Update to reflect previous code changes (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Update file information comments (Prarit Bhargava) [1823339]
- [x86] x86: platform: iosf_mbi: Call cpu_latency_qos_*() instead of pm_qos_*() (Prarit Bhargava) [1823339]
- [cpuidle] cpuidle: Call cpu_latency_qos_limit() instead of pm_qos_request() (Prarit Bhargava) [1823339]
- [x86] x86: baytrail/cherrytrail: Rework and move P-Unit PMIC bus semaphore code (Prarit Bhargava) [1823339]
- [sound] sound: Call cpu_latency_qos_*() instead of pm_qos_*() (Prarit Bhargava) [1823339]
- [media] drivers: media: Call cpu_latency_qos_*() instead of pm_qos_*() (Prarit Bhargava) [1823339]
- [wireless] drivers: net: Call cpu_latency_qos_*() instead of pm_qos_*() (Prarit Bhargava) [1823339]
- [drm] drm/i915: Implement a better i945gm vblank irq vs. C-states workaround (Prarit Bhargava) [1823339]
- [drm] drm: i915: Call cpu_latency_qos_*() instead of pm_qos_*() (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Drop PM_QOS_CPU_DMA_LATENCY and rename related functions (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Adjust pm_qos_request() signature and reorder pm_qos.h (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Simplify definitions of CPU latency QoS trace events (Prarit Bhargava) [1823339]
- [tty] PM: QoS: Rename things related to the CPU latency QoS (Prarit Bhargava) [1823339]
- [cpuidle] PM: QoS: Drop PM_QOS_CPU_DMA_LATENCY notifier chain (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Redefine struct pm_qos_request and drop struct pm_qos_object (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Clean up misc device file operations (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Drop iterations over global QoS classes (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Clean up pm_qos_read_value() and pm_qos_get/set_value() (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Clean up pm_qos_update_target() and pm_qos_update_flags() (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Drop the PM_QOS_SUM QoS type (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Drop pm_qos_update_request_timeout() (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Drop debugfs interface (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: ti-cpufreq: Add support for OPP_PLUS (Prarit Bhargava) [1823339]
- [x86] x86/intel_pstate: Handle runtime turbo disablement/enablement in frequency invariance (Prarit Bhargava) [1823339]
- [x86] x86, sched: Add support for frequency invariance on ATOM (Prarit Bhargava) [1823339]
- [x86] x86, sched: Add support for frequency invariance on ATOM_GOLDMONT* (Prarit Bhargava) [1823339]
- [x86] x86, sched: Add support for frequency invariance on XEON_PHI_KNL/KNM (Prarit Bhargava) [1823339]
- [x86] x86, sched: Add support for frequency invariance on SKYLAKE_X (Prarit Bhargava) [1823339]
- [x86] x86, sched: Add support for frequency invariance (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Avoid creating excessively large stack frames (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: loongson2_cpufreq: adjust cpufreq uses of LOONGSON_CHIPCFG (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: brcmstb-avs: fix imbalance of cpufreq policy refcount (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: intel_pstate: fix spelling mistake: "Whethet" -> "Whether" (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: s3c: fix unbalances of cpufreq policy refcount (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: tegra186: convert to devm_platform_ioremap_resource (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: kirkwood: convert to devm_platform_ioremap_resource (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: CPPC: put ACPI table after using it (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq : CPPC: Break out if HiSilicon CPPC workaround is matched (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: scmi: Match scmi device by both name and protocol id (Prarit Bhargava) [1823339]
- [base] PM / QoS: Restore DEV_PM_QOS_MIN/MAX_FREQUENCY (Prarit Bhargava) [1823339]
- [base] PM: QoS: Drop frequency QoS types from device PM QoS (Prarit Bhargava) [1823339]
- [include] PM / QoS: Reorder pm_qos/freq_qos/dev_pm_qos structs (Prarit Bhargava) [1823339]
- [include] PM / QoS: Redefine FREQ_QOS_MAX_DEFAULT_VALUE to S32_MAX (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Fix Kconfig indentation (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Use vtime aware kcpustat accessors for user time (Prarit Bhargava) [1823339]
- [kernel] sched/vtime: Bring up complete kcpustat accessor (Prarit Bhargava) [1823339]
- [documentation] PM: Wrap documentation to fit in 80 columns (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Invalidate frequency QoS requests after removal (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Register drivers only after CPU devices have been registered (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Add NULL checks to show() and store() methods of cpufreq (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: intel_pstate: Fix invalid EPB setting (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Initialize cpufreq-dt driver earlier (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: intel_pstate: Fix plain int as pointer warning from sparse (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: powernv: fix stack bloat and hard limit on number of CPUs (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Clarify the comment in cpufreq_set_policy() (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Use vtime aware kcpustat accessor to fetch CPUTIME_SYSTEM (Prarit Bhargava) [1823339]
- [kernel] sched/kcpustat: Introduce vtime-aware kcpustat accessor for CPUTIME_SYSTEM (Prarit Bhargava) [1823339]
- [include] sched/vtime: Introduce vtime_accounting_enabled_cpu() (Prarit Bhargava) [1823339]
- [kernel] sched/vtime: Rename vtime_accounting_cpu_enabled() to vtime_accounting_enabled_this_cpu() (Prarit Bhargava) [1823339]
- [include] context_tracking: Introduce context_tracking_enabled_cpu() (Prarit Bhargava) [1823339]
- [include] context_tracking: Rename context_tracking_is_cpu_enabled() to context_tracking_enabled_this_cpu() (Prarit Bhargava) [1823339]
- [kernel] sched/vtime: Record CPU under seqcount for kcpustat needs (Prarit Bhargava) [1823339]
- [acpi] ACPI: processor: Add QoS requests for all CPUs (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: scpi: remove stale/outdated comment about the driver (Prarit Bhargava) [1823339]
- [thermal] thermal/drivers/cpufreq_cooling: Fix return of cpufreq_set_cur_state (Prarit Bhargava) [1823339]
- [acpi] cpufreq: Use per-policy frequency QoS (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Introduce frequency QoS (Prarit Bhargava) [1823339]
- [acpi] ACPI: processor: Avoid NULL pointer dereferences at init time (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: ti-cpufreq: Add support for AM3517 (Prarit Bhargava) [1823339]
- [cpufreq] ARM: dts: omap36xx: using OPP1G needs to control the abb_ldo (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: ti-cpufreq: add support for omap34xx and omap36xx (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Remove CPUFREQ_ADJUST and CPUFREQ_NOTIFY policy notifier events (Prarit Bhargava) [1823339]
- [base] arch_topology: Use CPUFREQ_CREATE_POLICY instead of CPUFREQ_NOTIFY (Prarit Bhargava) [1823339]
- [acpi] ACPI: cpufreq: Switch to QoS requests instead of cpufreq notifier (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: Get rid of unused flags (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: intel_pstate: Implement QoS supported freq constraints (Prarit Bhargava) [1823339]
- [thermal] thermal: cpu_cooling: Switch to QoS requests for freq limits (Prarit Bhargava) [1823339]
- [cpufreq] cpufreq: Add policy create/remove notifiers back (Prarit Bhargava) [1823339]
- [documentation] docs: power: convert docs to ReST and rename to *.rst (Prarit Bhargava) [1823339]
- [kernel] PM: QoS: no need to check return value of debugfs_create functions (Prarit Bhargava) [1823339]
- [kernel] PM / QoS: Change to use DEFINE_SHOW_ATTRIBUTE macro (Prarit Bhargava) [1823339]
- [nvme] nvme-fc: Revert "add module to ops template to allow module references" (Gopal Tiwari) [1823270]
- [nvme] nvme: fix deadlock caused by ANA update wrong locking (Gopal Tiwari) [1823270]
- [nvme] nvme-pci: Hold cq_poll_lock while completing CQEs (Gopal Tiwari) [1823270]
- [uapi] nvme: change nvme_passthru_cmd64 to explicitly mark rsvd (Gopal Tiwari) [1823270]
- [tools] tools/power/x86/intel-speed-select: Fix a typo in error message (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Update version (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Avoid duplicate Package strings for json (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Add display for enabled cpus count (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Print friendly warning for bad command line (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Fix avx options for turbo-freq feature (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Improve CLX commands (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Show error for invalid CPUs in the options (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Improve core-power result and error display (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Kernel interface error handling (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Improve error display for turbo-freq feature (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Improve error display for base-freq feature (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Improve output of perf-profile commands (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Enhance help for core-power assoc (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Display error for invalid priority type (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Check feature status first (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Improve error display for perf-profile feature (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Add an API for error/information print (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Enhance --info option (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Enhance help (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Helpful warning for missing kernel interface (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Store topology information (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Max CPU count calculation when CPU0 is offline (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Special handling for CPU 0 online/offline (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Use more verbiage for clos information (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Enhance core-power info command (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Make target CPU optional for core-power info (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Warn for invalid package id (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Fix last cpu number (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Fix mailbox usage for CLOS_PM_QOS_CONFIG (Prarit Bhargava) [1778956]
- [platform] platform/x86: ISST: Fix wrong unregister type (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Avoid duplicate names for json parsing (Prarit Bhargava) [1778956]
- [tools] tools/power/x86/intel-speed-select: Fix display for turbo-freq auto mode (Prarit Bhargava) [1778956]
- [platform] platform/x86: ISST: Allow additional core-power mailbox commands (Prarit Bhargava) [1778956]
- [misc] mei: me: add comet point (lake) H device ids (Ken Cox) [1815355]
- [misc] mei: me: add comet point (lake) LP device ids (Ken Cox) [1815355]
- [misc] mei: define dma ring buffer sizes for PCH12 HW and newer (Ken Cox) [1815355]
- [misc] mei: hbm: define dma ring setup protocol (Ken Cox) [1815355]
- [acpi] apei/ghes: Do not delay GHES polling (Robert Richter) [1793544]
- [edac] EDAC/ghes: Do not warn when incrementing refcount on 0 (Robert Richter) [1793544]
- [edac] EDAC/ghes: Fix locking and memory barrier issues (Robert Richter) [1793544]
- [edac] EDAC/ghes: Fix Use after free in ghes_edac remove path (Robert Richter) [1793544]
- [edac] EDAC, ghes: Use CPER module handles to locate DIMMs (Robert Richter) [1793544]
- [kernel] sched/fair: Fix statistics for find_idlest_group() (Phil Auld) [1794398]
- [kernel] sched/core: Annotate curr pointer in rq with __rcu (Phil Auld) [1794398]
- [kernel] sched/psi: Fix OOB write when writing 0 bytes to PSI files (Phil Auld) [1794398]
- [kernel] sched/psi: Correct overly pessimistic size calculation (Phil Auld) [1794398]
- [kernel] sched/fair: Prevent unlimited runtime on throttled group (Phil Auld) [1794398]
- [kernel] sched/nohz: Optimize get_nohz_timer_target() (Phil Auld) [1794398]
- [kernel] sched/topology: Assert non-NUMA topology masks don't (partially) overlap (Phil Auld) [1794398]
- [kernel] sched/psi: create /proc/pressure and /proc/pressure/{io|memory|cpu} only when psi enabled (Phil Auld) [1794398]
- [kernel] sched/fair: Remove redundant call to cpufreq_update_util() (Phil Auld) [1794398]
- [kernel] sched/debug: Add new tracepoints to track PELT at rq level (Phil Auld) [1794398]
- [kernel] sched/fair: calculate delta runnable load only when it's needed (Phil Auld) [1794398]
- [kernel] sched/fair: Fix sgc->{min, max}_capacity calculation for SD_OVERLAP (Phil Auld) [1794398]
- [kernel] sched/debug: Reset watchdog on all CPUs while processing sysrq-t (Phil Auld) [1794398]
- [kernel] sched/fair: Make sched-idle CPU selection consistent throughout (Phil Auld) [1794398]
- [kernel] sched/core: Remove unused variable from set_user_nice() (Phil Auld) [1794398]
- [kernel] sched/fair: Optimize select_idle_cpu (Phil Auld) [1794398]
- [kernel] schied/fair: Skip calculating @contrib without load (Phil Auld) [1794398]
- [kernel] sched: Spare resched IPI when prio changes on a single fair task (Phil Auld) [1794398]
- [kernel] sched: Use fair:prio_changed() instead of ad-hoc implementation (Phil Auld) [1794398]
- [kernel] sched/wait: fix ___wait_var_event(exclusive) (Phil Auld) [1794398]
- [kernel] psi: Fix a division error in psi poll() (Phil Auld) [1794398]
- [kernel] sched/psi: Fix sampling error and rare div0 crashes with cgroups and high uptime (Phil Auld) [1794398]
- [kernel] sched/cpufreq: Move the cfs_rq_util_change() call to cpufreq_update_util() (Phil Auld) [1794398]
- [kernel] sched/pelt: Fix update of blocked PELT ordering (Phil Auld) [1794398]
- [kernel] sched/core: Avoid spurious lock dependencies (Phil Auld) [1794398]
- [kernel] Add wake_up_interruptible_sync_poll_locked() (Phil Auld) [1794398]
- [kernel] Remove the nr_exclusive argument from __wake_up_sync_key() (Phil Auld) [1794398]
- [x86] x86/mce: Do not log spurious corrected mce errors (Prarit Bhargava) [1819761]
- [x86] x86/MCE: Add an MCE-record filtering function (Prarit Bhargava) [1819761]

* Thu Apr 16 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.9.el8]
- [mm] mm/page_alloc: increase default min_free_kbytes bound (Joel Savitz) [1808039]
- [crypto] crypto: remove CRYPTO_TFM_RES_BAD_KEY_LEN (Neil Horman) [1782179]
- [crypto] crypto: qat - switch to skcipher API (Neil Horman) [1782179]
- [scsi] scsi: lpfc: Change default SCSI LUN QD to 64 (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Update lpfc version to 12.8.0.0 (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Remove prototype FIPS/DSS options from SLI-3 (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Make debugfs ktime stats generic for NVME and SCSI (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix erroneous cpu limit of 128 on I/O statistics (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix crash in target side cable pulls hitting WAIT_FOR_UNREG (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix update of wq consumer index in lpfc_sli4_wq_release (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix crash after handling a pci error (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix scsi host template for SLI3 vports (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix lpfc overwrite of sg_cnt field in nvmefc_tgt_fcp_req (Dick Kennedy) [1822334]
- [scsi] scsi: lpfc: Fix lockdep error - register non-static key (Dick Kennedy) [1822334]
- [fs] utimes: Clamp the timestamps in notify_change() (Eric Sandeen) [1795991]
- [fs] smb3: Fix regression in time handling (Eric Sandeen) [1795991]
- [fs] isofs: Initialize filesystem timestamp ranges (Eric Sandeen) [1795991]
- [fs] fs: ceph: Initialize filesystem timestamp ranges (Eric Sandeen) [1795991]
- [fs] fs: fat: Initialize filesystem timestamp ranges (Eric Sandeen) [1795991]
- [fs] fat: propagate 64-bit inode timestamps (Eric Sandeen) [1795991]
- [fs] fs: cifs: Initialize filesystem timestamp ranges (Eric Sandeen) [1795991]
- [fs] fs: nfs: Initialize filesystem timestamp ranges (Eric Sandeen) [1795991]
- [fs] ext4: Initialize timestamps limits (Eric Sandeen) [1795991]
- [fs] fs: Fill in max and min timestamps in superblock (Eric Sandeen) [1795991]
- [fs] utimes: Clamp the timestamps before update (Eric Sandeen) [1795991]
- [fs] timestamp_truncate: Replace users of timespec64_trunc (Eric Sandeen) [1795991]
- [fs] vfs: Add timestamp_truncate() api (Eric Sandeen) [1795991]
- [fs] vfs: Add file timestamp range support (Eric Sandeen) [1795991]
- [fs] cramfs: Deprecate cramfs in RHEL (Abhijith Das) [1794513]
- [thermal] thermal: intel: intel_pch_thermal: Add Comet Lake (CML) platform support (David Arcari) [1773794]
- [thermal] thermal: intel: Fix unmatched pci_release_region (David Arcari) [1773794]
- [thermal] thermal: intel: Use dev_get_drvdata (David Arcari) [1773794]
- [thermal] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (David Arcari) [1773794]
- [thermal] drivers: thermal: Move various drivers for intel platforms into a subdir (David Arcari) [1773794]
- [x86] x86/cpufeatures: Enable a new AVX512 CPU feature (David Arcari) [1783143]
- [x86] cpu/cpuid-deps: Add a tab to cpuid dependent features (David Arcari) [1783143]
- [crypto] crypto: rng - Override drivers/char/random in FIPS mode (Herbert Xu) [1785660]
- [char] random: Add hook to override device reads and getrandom(2) (Herbert Xu) [1785660]
- [block] nbd: add a flush_workqueue in nbd_start_device (Ming Lei) [1798919]
- [scsi] scsi: sd_sbc: Fix sd_zbc_report_zones() (Ming Lei) [1798919]
- [block] block: Fix partition support for host aware zoned block devices (Ming Lei) [1798919]
- [scsi] block: allow partitions on host aware zone devices (Ming Lei) [1798919]
- [block] null_blk: Fix zone write handling (Ming Lei) [1798919]
- [fs] fs: move guard_bio_eod() after bio_set_op_attrs (Ming Lei) [1798919]
- [block] null_blk: Fix REQ_OP_ZONE_CLOSE handling (Ming Lei) [1798919]
- [block] block: add bio_truncate to fix guard_bio_eod (Ming Lei) [1798919]
- [block] compat_ioctl: block: handle Persistent Reservations (Ming Lei) [1798919]
- [block] compat_ioctl: block: handle add zone open, close and finish ioctl (Ming Lei) [1798919]
- [block] compat_ioctl: block: handle BLKGETZONESZ/BLKGETNRZONES (Ming Lei) [1798919]
- [block] compat_ioctl: block: handle BLKREPORTZONE/BLKRESETZONE (Ming Lei) [1798919]
- [block] block: fix memleak when __blk_rq_map_user_iov() is failed (Ming Lei) [1798919]
- [s390] s390/dasd: fix typo in copyright statement (Ming Lei) [1798919]
- [s390] s390/dasd: fix memleak in path handling error case (Ming Lei) [1798919]
- [s390] s390/dasd/cio: Interpret ccw_device_get_mdc return value correctly (Ming Lei) [1798919]
- [block] block: Fix a lockdep complaint triggered by request queue flushing (Ming Lei) [1798919]
- [block] block: Fix the type of 'sts' in bsg_queue_rq() (Ming Lei) [1798919]
- [block] block: end bio with BLK_STS_AGAIN in case of non-mq devs and REQ_NOWAIT (Ming Lei) [1798919]
- [block] nbd: fix shutdown and recv work deadlock v2 (Ming Lei) [1798919]
- [block] blk-iocost: fix incorrect vtime comparison in iocg_is_idle() (Ming Lei) [1798919]
- [block] iocost: check active_list of all the ancestors in iocg_activate() (Ming Lei) [1798919]
- [block] iocost: over-budget forced IOs should schedule async delay (Ming Lei) [1798919]
- [block] blk-cgroup: remove blkcg_drain_queue (Ming Lei) [1798919]
- [block] block: fix NULL pointer dereference in account statistics with IDE (Ming Lei) [1798919]
- [block] null_blk: remove unused variable warning on !CONFIG_BLK_DEV_ZONED (Ming Lei) [1798919]
- [block] brd: warn on un-aligned buffer (Ming Lei) [1798919]
- [block] brd: remove max_hw_sectors queue limit (Ming Lei) [1798919]
- [block] block: set the zone size in blk_revalidate_disk_zones atomically (Ming Lei) [1798919]
- [block] block: don't handle bio based drivers in blk_revalidate_disk_zones (Ming Lei) [1798919]
- [block] block: allocate the zone bitmaps lazily (Ming Lei) [1798919]
- [block] block: replace seq_zones_bitmap with conv_zones_bitmap (Ming Lei) [1798919]
- [block] block: simplify blkdev_nr_zones (Ming Lei) [1798919]
- [block] block: remove the empty line at the end of blk-zoned.c (Ming Lei) [1798919]
- [block] null_blk: cleanup null_gendisk_register (Ming Lei) [1798919]
- [block] null_blk: fix zone size paramter check (Ming Lei) [1798919]
- [fs] block: don't send uevent for empty disk when not invalidating (Ming Lei) [1798919]
- [block] ataflop: Remove unneeded semicolon (Ming Lei) [1798919]
- [block] drbd: Remove unneeded semicolon (Ming Lei) [1798919]
- [scsi] sr_vendor: support Beurer GL50 evo CD-on-a-chip devices (Ming Lei) [1798919]
- [cdrom] cdrom: respect device capabilities during opening action (Ming Lei) [1798919]
- [fs] block: move clearing bd_invalidated into check_disk_size_change (Ming Lei) [1798919]
- [block] block: remove (__)blkdev_reread_part as an exported API (Ming Lei) [1798919]
- [block] block: fix bdev_disk_changed for non-partitioned devices (Ming Lei) [1798919]
- [block] block: move rescan_partitions to fs/block_dev.c (Ming Lei) [1798919]
- [block] block: merge invalidate_partitions into rescan_partitions (Ming Lei) [1798919]
- [block] block: refactor rescan_partitions (Ming Lei) [1798919]
- [scsi] scsi: sd_zbc: Remove set but not used variable 'buflen' (Ming Lei) [1798919]
- [md] block: rework zone reporting (Ming Lei) [1798919]
- [scsi] scsi: sd_zbc: Cleanup sd_zbc_alloc_report_buffer() (Ming Lei) [1798919]
- [block] null_blk: Add zone_nr_conv to features (Ming Lei) [1798919]
- [block] null_blk: clean up report zones (Ming Lei) [1798919]
- [block] null_blk: clean up the block device operations (Ming Lei) [1798919]
- [block] block: Remove partition support for zoned block devices (Ming Lei) [1798919]
- [md] block: Simplify report zones execution (Ming Lei) [1798919]
- [block] block: cleanup the !zoned case in blk_revalidate_disk_zones (Ming Lei) [1798919]
- [scsi] block: Enhance blk_revalidate_disk_zones() (Ming Lei) [1798919]
- [block] nbd: prevent memory leak (Ming Lei) [1798919]
- [scsi] scsi: sd_zbc: add zone open, close, and finish support (Ming Lei) [1798919]
- [block] null_blk: add zone open, close, and finish support (Ming Lei) [1798919]
- [md] dm: add zone open, close and finish support (Ming Lei) [1798919]
- [block] loop: fix no-unmap write-zeroes request behavior (Ming Lei) [1798919]
- [block] null_blk: return fixed zoned reads > write pointer (Ming Lei) [1798919]
- [block] null_blk: Enable modifying 'submit_queues' after an instance has been configured (Ming Lei) [1798919]
- [block] null_blk: Improve nullb_device_##NAME##_store() readability (Ming Lei) [1798919]
- [block] block,bfq: Skip tracing hooks if possible (Ming Lei) [1798919]
- [block] block: Don't disable interrupts in trigger_softirq() (Ming Lei) [1798919]
- [lib] sbitmap: Delete sbitmap_any_bit_clear() (Ming Lei) [1798919]
- [block] blk-mq: Delete blk_mq_has_free_tags() and blk_mq_can_queue() (Ming Lei) [1798919]
- [block] block: add zone open, close and finish ioctl support (Ming Lei) [1798919]
- [uapi] uapi: fix ioctl documentation (Ming Lei) [1798919]
- [uapi] uapi: linux/blkzoned.h: fix BLKGETZONESZ and BLKGETNRZONES definitions (Ming Lei) [1798919]
- [block] block: add zone open, close and finish operations (Ming Lei) [1798919]
- [block] block: Simplify REQ_OP_ZONE_RESET_ALL handling (Ming Lei) [1798919]
- [block] block: Remove REQ_OP_ZONE_RESET plugging (Ming Lei) [1798919]
- [fs] bdev: Refresh bdev size for disks without partitioning (Ming Lei) [1798919]
- [fs] bdev: Factor out bdev revalidation into a common helper (Ming Lei) [1798919]
- [block] blk-mq: Make blk_mq_run_hw_queue() return void (Ming Lei) [1798919]
- [fs] fcntl: fix typo in RWH_WRITE_LIFE_NOT_SET r/w hint name (Ming Lei) [1798919]
- [block] blk-mq: remove needless goto from blk_mq_get_driver_tag (Ming Lei) [1798919]
- [block] block: Reduce the amount of memory used for tag sets (Ming Lei) [1798919]
- [block] block: Reduce the amount of memory required per request queue (Ming Lei) [1798919]
- [block] block: Remove the synchronize_rcu() call from __blk_mq_update_nr_hw_queues() (Ming Lei) [1798919]
- [block] block: account statistics for passthrough requests (Ming Lei) [1798919]
- [block] blk-stat: Optimise blk_stat_add() (Ming Lei) [1798919]
- [block] blk-mq: Embed counters into struct mq_inflight (Ming Lei) [1798919]
- [block] blk-mq: Reuse callback in blk_mq_in_flight*() (Ming Lei) [1798919]
- [block] blk-mq: Inline status checkers (Ming Lei) [1798919]
- [block] block: Document all members of blk_mq_tag_set and bkl_mq_queue_map (Ming Lei) [1798919]
- [block] block: Reduce sysfs_lock locking inside blk_cleanup_queue() (Ming Lei) [1798919]
- [block] block: Remove "dying" checks from sysfs callbacks (Ming Lei) [1798919]
- [block] block: Remove request_queue.nr_queues (Ming Lei) [1798919]
- [trace] block: Fix writeback throttling W=1 compiler warnings (Ming Lei) [1798919]
- [block] block: Fix three kernel-doc warnings (Ming Lei) [1798919]
- [fs] writeback: fix use-after-free in finish_writeback_work() (Ming Lei) [1798919]
- [scsi] scsi: sd_zbc: Fix sd_zbc_complete() (Ming Lei) [1798919]
- [block] nbd:fix memory leak in nbd_get_socket() (Ming Lei) [1798919]
- [block] nbd: verify socket is supported during setup (Ming Lei) [1798919]
- [block] nbd: handle racing with error'ed out commands (Ming Lei) [1798919]
- [block] nbd: protect cmd->status with cmd->lock (Ming Lei) [1798919]
- [block] nbd: fix possible sysfs duplicate warning (Ming Lei) [1798919]
- [block] nbd: fix possible page fault for nbd disk (Ming Lei) [1798919]
- [block] nbd: rename the runtime flags as NBD_RT_ prefixed (Ming Lei) [1798919]
- [block] nbd: fix max number of supported devs (Ming Lei) [1798919]
- [block] nbd: fix zero cmd timeout handling v2 (Ming Lei) [1798919]
- [block] nbd: add missing config put (Ming Lei) [1798919]
- [block] nbd: add function to convert blk req op to nbd cmd (Ming Lei) [1798919]
- [block] nbd: add set cmd timeout helper (Ming Lei) [1798919]
- [block] loop: change queue block size to match when using DIO (Ming Lei) [1798919]
- [block] rsxx: add missed destroy_workqueue calls in remove (Ming Lei) [1798919]
- [fs] cgroup, writeback: don't switch wbs immediately on dead wbs if the memcg is dead (Ming Lei) [1798919]
- [block] block: drbd: remove a stray unlock in __drbd_send_protocol() (Ming Lei) [1798919]
- [block] blkcg: make blkcg_print_stat() print stats only for online blkgs (Ming Lei) [1798919]
- [block] iocost: don't nest spin_lock_irq in ioc_weight_write() (Ming Lei) [1798919]
- [block] blk-rq-qos: fix first node deletion of rq_qos_del() (Ming Lei) [1798919]
- [block] blkcg: Fix multiple bugs in blkcg_activate_policy() (Ming Lei) [1798919]
- [block] block: Fix elv_support_iosched() (Ming Lei) [1798919]
- [block] null_blk: Fix zoned command return code (Ming Lei) [1798919]
- [block] blk-wbt: fix performance regression in wbt scale_up/scale_down (Ming Lei) [1798919]
- [ata] Revert "libata, freezer: avoid block device removal while system is frozen" (Ming Lei) [1798919]
- [mm] bdi: Do not use freezable workqueue (Ming Lei) [1798919]
- [uapi] block: pg: add header include guard (Ming Lei) [1798919]
- [block] block: fix null pointer dereference in blk_mq_rq_timed_out() (Ming Lei) [1798919]
- [block] rq-qos: get rid of redundant wbt_update_limits() (Ming Lei) [1798919]
- [block] iocost: bump up default latency targets for hard disks (Ming Lei) [1798919]
- [block] iocost: improve nr_lagging handling (Ming Lei) [1798919]
- [block] iocost: better trace vrate changes (Ming Lei) [1798919]
- [block] block: drop device references in bsg_queue_rq() (Ming Lei) [1798919]
- [block] pktcdvd: remove warning on attempting to register non-passthrough dev (Ming Lei) [1798919]
- [ata] ata: libahci_platform: Add of_node_put() before loop exit (Ming Lei) [1798919]
- [block] block, bfq: push up injection only after setting service time (Ming Lei) [1798919]
- [block] block, bfq: increase update frequency of inject limit (Ming Lei) [1798919]
- [block] block, bfq: reduce upper bound for inject limit to max_rq_in_driver+1 (Ming Lei) [1798919]
- [block] block, bfq: update inject limit only after injection occurred (Ming Lei) [1798919]
- [block] block: centralize PI remapping logic to the block layer (Ming Lei) [1798919]
- [block] block: use symbolic constants for t10_pi type (Ming Lei) [1798919]
- [block] null_blk: format pr_* logs with pr_fmt (Ming Lei) [1798919]
- [block] null_blk: match the type of parameter nr_devices (Ming Lei) [1798919]
- [block] null_blk: do not fail the module load with zero devices (Ming Lei) [1798919]
- [block] block: also check RQF_STATS in blk_mq_need_time_stamp() (Ming Lei) [1798919]
- [block] block: make rq sector size accessible for block stats (Ming Lei) [1798919]
- [block] bfq: Fix bfq linkage error (Ming Lei) [1798919]
- [scsi] scsi: core: remove dummy q->dev check (Ming Lei) [1798919]
- [block] block: bypass blk_set_runtime_active for uninitialized q->dev (Ming Lei) [1798919]
- [block] null_blk: validate the number of devices (Ming Lei) [1798919]
- [block] null_blk: fix module name at log message (Ming Lei) [1798919]
- [block] iocost_monitor: Report debt (Ming Lei) [1798919]
- [tools] iocost_monitor: Report more info with higher accuracy (Ming Lei) [1798919]
- [tools] iocost_monitor: Always use strings for json values (Ming Lei) [1798919]
- [block] blk-iocost: Don't let merges push vtime into the future (Ming Lei) [1798919]
- [block] blk-iocost: Account force-charged overage in absolute vtime (Ming Lei) [1798919]
- [block] blk-iocost: Fix incorrect operation order during iocg free (Ming Lei) [1798919]
- [block] bfq: Add per-device weight (Ming Lei) [1798919]
- [block] bfq: Extract bfq_group_set_weight from bfq_io_set_weight_legacy (Ming Lei) [1798919]
- [block] bfq: Fix the missing barrier in __bfq_entity_update_weight_prio (Ming Lei) [1798919]
- [block] block: fix elevator_get_by_features() (Ming Lei) [1798919]
- [scsi] sd: Set ELEVATOR_F_ZBD_SEQ_WRITE for ZBC disks (Ming Lei) [1798919]
- [block] block: Set ELEVATOR_F_ZBD_SEQ_WRITE for nullblk zoned disks (Ming Lei) [1798919]
- [block] block: Delay default elevator initialization (Ming Lei) [1798919]
- [block] block: Improve default elevator selection (Ming Lei) [1798919]
- [block] block: Introduce elevator features (Ming Lei) [1798919]
- [block] block: Change elevator_init_mq() to always succeed (Ming Lei) [1798919]
- [block] block: Cleanup elevator_init_mq() use (Ming Lei) [1798919]
- [block] paride/pcd: need to check if cd->disk is null in pcd_detect (Ming Lei) [1798919]
- [block] paride/pcd: need to set queue to NULL before put_disk (Ming Lei) [1798919]
- [block] blkcg: add missing NULL check in ioc_cpd_alloc() (Ming Lei) [1798919]
- [block] blkcg: fix missing free on error path of blk_iocost_init() (Ming Lei) [1798919]
- [trace] blkcg: blk-iocost: predeclare used structs (Ming Lei) [1798919]
- [block] blkcg: add tools/cgroup/iocost_coef_gen.py (Ming Lei) [1798919]
- [block] blkcg: add tools/cgroup/iocost_monitor.py (Ming Lei) [1798919]
- [block] blkcg: implement blk-iocost (Ming Lei) [1798919]
- [block] blk-mq: add optional request->alloc_time_ns (Ming Lei) [1798919]
- [block] block: extend 'struct request' via 'request_aux' (Ming Lei) [1798919]
- [block] blkcg: s/RQ_QOS_CGROUP/RQ_QOS_LATENCY/ (Ming Lei) [1798919]
- [block] block/rq_qos: implement rq_qos_ops->queue_depth_changed() (Ming Lei) [1798919]
- [block] block/rq_qos: add rq_qos_merge() (Ming Lei) [1798919]
- [block] blkcg: separate blkcg_conf_get_disk() out of blkg_conf_prep() (Ming Lei) [1798919]
- [block] blkcg: make ->cpd_init_fn() optional (Ming Lei) [1798919]
- [block] blkcg: pass @q and @blkcg into blkcg_pol_alloc_pd_fn() (Ming Lei) [1798919]
- [include] writeback: Generalize and expose wb_completion (Ming Lei) [1798919]
- [block] null_blk: fix inline misuse (Ming Lei) [1798919]
- [block] null_blk: create a helper for req completion (Ming Lei) [1798919]
- [block] null_blk: create a helper for zoned devices (Ming Lei) [1798919]
- [block] null_blk: create a helper for mem-backed ops (Ming Lei) [1798919]
- [block] null_blk: create a helper for badblocks (Ming Lei) [1798919]
- [block] null_blk: create a helper for throttling (Ming Lei) [1798919]
- [block] null_blk: move duplicate code to callers (Ming Lei) [1798919]
- [block] block: remove struct request_queue queue_head (Ming Lei) [1798919]
- [fs] writeback, cgroup: inode_switch_wbs() shouldn't give up on wb_switch_rwsem trylock fail (Ming Lei) [1798919]
- [fs] writeback, cgroup: Adjust WB_FRN_TIME_CUT_DIV to accelerate foreign inode switching (Ming Lei) [1798919]
- [block] blk-mq: Fix memory leak in blk_mq_init_allocated_queue error handling (Ming Lei) [1798919]
- [block] loop: Add LOOP_SET_DIRECT_IO to compat ioctl (Ming Lei) [1798919]
- [lib] lib: scatterlist: Fix to support no mapped sg (Ming Lei) [1798919]
- [block] null_blk: implement REQ_OP_ZONE_RESET_ALL (Ming Lei) [1798919]
- [scsi] scsi: implement REQ_OP_ZONE_RESET_ALL (Ming Lei) [1798919]
- [block] blk-zoned: implement REQ_OP_ZONE_RESET_ALL (Ming Lei) [1798919]
- [block] block: add req op to reset all zones and flag (Ming Lei) [1798919]
- [block] block: Fix a comment in blk_cleanup_queue() (Ming Lei) [1798919]
- [block] block: Fix spelling in the header above blkg_lookup() (Ming Lei) [1798919]
- [kernel] cgroup: Move cgroup_parse_float() implementation out of CONFIG_SYSFS (Ming Lei) [1798919]
- [kernel] cgroup: add cgroup_parse_float() (Ming Lei) [1798919]
- [block] nbd: replace kill_bdev() with __invalidate_device() again (Ming Lei) [1798919]
- [block] nbd: add netlink reconfigure resize support (Ming Lei) [1798919]
- [block] nbd: fix crash when the blksize is zero (Ming Lei) [1798919]
- [block] nbd: propagate genlmsg_reply return code (Ming Lei) [1798919]
- [block] block: loop: mark bvec as ITER_BVEC_FLAG_NO_REF (Ming Lei) [1798919]
- [block] loop: properly observe rotational flag of underlying device (Ming Lei) [1798919]
- [block] block: Limit zone array allocation size (Ming Lei) [1798919]
- [block] block: Fix null_blk_zoned creation failure with small number of zones (Ming Lei) [1798919]
- [scsi] sd_zbc: Fix report zones buffer allocation (Ming Lei) [1798919]
- [scsi] scsi: sd_zbc: Fix sd_zbc_report_zones() buffer allocation (Ming Lei) [1798919]
- [md] block: Kill gfp_t argument of blkdev_report_zones() (Ming Lei) [1798919]
- [md] dm zoned: Fix zone report handling (Ming Lei) [1798919]
- [block] blkcg: implement REQ_CGROUP_PUNT (Ming Lei) [1798919]
- [include] blkcg, writeback: Implement wbc_blkcg_css() (Ming Lei) [1798919]
- [fs] blkcg, writeback: Add wbc->no_cgroup_owner (Ming Lei) [1798919]
- [fs] blkcg, writeback: Rename wbc_account_io() to wbc_account_cgroup_owner() (Ming Lei) [1798919]
- [block] cgroup, blkcg: Prepare some symbols for module and !CONFIG_CGROUP usages (Ming Lei) [1798919]
- [fs] writeback: synchronize sync(2) against cgroup writeback membership switches (Ming Lei) [1798919]
- [block] blk-mq: move cancel of requeue_work to the front of blk_exit_queue (Ming Lei) [1798919]
- [block] blk-mq-debugfs: support rq_qos (Ming Lei) [1798919]
- [block] null_blk: fix type mismatch null_handle_cmd() (Ming Lei) [1798919]
- [block] null_blk: remove duplicate 0 initialization (Ming Lei) [1798919]
- [block] null_blk: remove duplicate check for report zone (Ming Lei) [1798919]
- [block] null_blk: add zoned config support information (Ming Lei) [1798919]
- [tools] tools arch x86: Sync asm/cpufeatures.h with the kernel sources (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Use bool type for vmw_sched_clock (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Enable steal time accounting (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Add steal time clock support for VMware guests (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Remove vmware_sched_clock_setup() (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Make vmware_select_hypercall() __init (Vitaly Kuznetsov) [1807448]
- [x86] cpu/vmware: Fix platform detection VMWARE_PORT macro (Vitaly Kuznetsov) [1807448]
- [x86] cpu/vmware: Use the full form of INL in VMWARE_HYPERCALL, for clang/llvm (Vitaly Kuznetsov) [1807448]
- [x86] cpu/vmware: Use the full form of INL in VMWARE_PORT (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Add a header file for hypercall definitions (Vitaly Kuznetsov) [1807448]
- [x86] vmware: Update platform detection code for VMCALL/VMMCALL hypercalls (Vitaly Kuznetsov) [1807448]
- [netdrv] hv_netvsc: Fix unwanted wakeup in netvsc_attach() (Mohammed Gamal) [1815503]
- [netdrv] hv_netvsc: make recording RSS hash depend on feature flag (Mohammed Gamal) [1815503]
- [netdrv] hv_netvsc: record hardware hash in skb (Mohammed Gamal) [1815503]
- [netdrv] hv_netvsc: flag software created hash value (Mohammed Gamal) [1815503]
- [video] hyperv: hyperv_fb: Use physical memory for fb on HyperV Gen 1 VMs (Mohammed Gamal) [1816744]
- [video] hyperv: hyperv_fb: Support deferred IO for Hyper-V frame buffer driver (Mohammed Gamal) [1816744]
- [video] hyperv: hyperv_fb: Obtain screen resolution from Hyper-V host (Mohammed Gamal) [1816744]
- [uio] uio_hv_generic: drop #ifdef DEBUG (Mohammed Gamal) [1816744]
- [hid] hv: Remove dependencies on PAGE_SIZE for ring buffer (Mohammed Gamal) [1816744]
- [x86] x86/hyperv: Create and use Hyper-V page definitions (Mohammed Gamal) [1816285]
- [x86] x86/hyper-v: Drop HV_X64_CONFIGURE_PROFILER definition (Mohammed Gamal) [1816285]
- [x86] x86: hv: Add function to allocate zeroed page for Hyper-V (Mohammed Gamal) [1816285]
- [x86] x86/hyperv: Add functions to allocate/deallocate page for Hyper-V (Mohammed Gamal) [1816285]
- [x86] x86/hyper-v: Fix indentation in hv_do_fast_hypercall16() (Mohammed Gamal) [1816285]
- [x86] x86/hyperv: Micro-optimize send_ipi_one() (Mohammed Gamal) [1816285]
- [x86] x86/hyperv: Make vapic support x2apic mode (Mohammed Gamal) [1816285]
- [x86] x86/hyper-v: Fix overflow bug in fill_gva_list() (Mohammed Gamal) [1816285]
- [x86] x86/hyper-v: Zero out the VP ASSIST PAGE on allocation (Mohammed Gamal) [1816285]
- [x86] x86/hyperv: Make hv_vcpu_is_preempted() visible (Mohammed Gamal) [1816285]
- [x86] x86/hyper-v: Implement EOI assist (Mohammed Gamal) [1816285]
- [x86] x86/hyperv: Prevent potential NULL pointer dereference (Mohammed Gamal) [1816285]
- [x86] Drivers: hv: vmbus: Break out ISA independent parts of mshyperv.h (Mohammed Gamal) [1816285]
- [x86] x86/hyperv: Remove unused include (Mohammed Gamal) [1816285]
- [net] vsock/virtio: add support for MSG_PEEK (Stefano Garzarella) [1818059]

* Tue Apr 14 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.8.el8]
- [include] leds: triggers: new function led_set_trigger_data() (Torez Smith) [1686205]
- [leds] leds: triggers: add device attribute support (Torez Smith) [1686205]
- [usb] USB: cdc-wdm: fix race between write and disconnect due to flag abuse (Torez Smith) [1686205]
- [usb] usb: host: xhci: rcar: Fix typo in compatible string matching (Torez Smith) [1686205]
- [usb] usb: host: xhci-tegra: Set DMA mask correctly (Torez Smith) [1686205]
- [usb] USB: storage: ums-realtek: Whitelist auto-delink support (Torez Smith) [1686205]
- [usb] USB: storage: ums-realtek: Update module parameter description for auto_delink_en (Torez Smith) [1686205]
- [usb] usb: host: ohci: fix a race condition between shutdown and irq (Torez Smith) [1686205]
- [usb] usb: hcd: use managed device resources (Torez Smith) [1686205]
- [usb] typec: tcpm: fix a typo in the comparison of pdo_max_voltage (Torez Smith) [1686205]
- [usb] usb-storage: Add new JMS567 revision to unusual_devs (Torez Smith) [1686205]
- [usb] usb: chipidea: udc: don't do hardware access if gadget has stopped (Torez Smith) [1686205]
- [usb] usbtmc: more sanity checking for packet size (Torez Smith) [1686205]
- [usb] usb: udc: lpc32xx: silence fall-through warning (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: fix EPROBE_DEFER support during driver probe (Torez Smith) [1686205]
- [usb] usb: host: fotg2: restart hcd after port reset (Torez Smith) [1686205]
- [usb] USB: CDC: fix sanity checks in CDC union parser (Torez Smith) [1686205]
- [usb] usb: cdc-acm: make sure a refcount is taken early enough (Torez Smith) [1686205]
- [usb] USB: serial: option: add the BroadMobi BM818 card (Torez Smith) [1686205]
- [usb] USB: serial: option: Add Motorola modem UARTs (Torez Smith) [1686205]
- [usb] USB: core: Fix races in character device registration and deregistraion (Torez Smith) [1686205]
- [usb] usb: gadget: mass_storage: Fix races between fsg_disable and fsg_set_alt (Torez Smith) [1686205]
- [usb] usb: gadget: composite: Clear "suspended" on reset/disconnect (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: Fix sysfs interface of "role" (Torez Smith) [1686205]
- [usb] usb: setup authorized_default attributes using usb_bus_notify (Torez Smith) [1686205]
- [usb] usb: iowarrior: fix deadlock on disconnect (Torez Smith) [1686205]
- [usb] Revert "USB: rio500: simplify locking" (Torez Smith) [1686205]
- [usb] usb: usbfs: fix double-free of usb memory upon submiturb error (Torez Smith) [1686205]
- [usb] usb: yurex: Fix use-after-free in yurex_delete (Torez Smith) [1686205]
- [usb] USB: serial: option: add D-Link DWM-222 device ID (Torez Smith) [1686205]
- [usb] USB: serial: option: Add support for ZTE MF871A (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Ignore unsupported/unknown alternate mode requests (Torez Smith) [1686205]
- [usb] xhci: Fix NULL pointer dereference at endpoint zero reset (Torez Smith) [1686205]
- [usb] usb: host: xhci-rcar: Fix timeout in xhci_suspend() (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: Fix uninitilized symbol error (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: remove tcpm dir if no children (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: free log buf memory when remove debug file (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Add NULL check before dereferencing config (Torez Smith) [1686205]
- [tools] tools headers UAPI: Sync usbdevice_fs.h with the kernels to get new ioctl (Torez Smith) [1686205]
- [usb] xhci: Fix crash if scatter gather is used with Immediate Data Transfer (IDT) (Torez Smith) [1686205]
- [usb] usb: usb251xb: Reallow swap-dx-lanes to apply to the upstream port (Torez Smith) [1686205]
- [usb] Revert "usb: usb251xb: Add US port lanes inversion property" (Torez Smith) [1686205]
- [documentation] Revert "usb: usb251xb: Add US lanes inversion dts-bindings" (Torez Smith) [1686205]
- [usb] usb: wusbcore: fix unbalanced get/put cluster_id (Torez Smith) [1686205]
- [usb] usb/hcd: Fix a NULL vs IS_ERR() bug in usb_hcd_setup_local_mem() (Torez Smith) [1686205]
- [usb] usb-storage: Add a limitation for blk_queue_max_hw_sectors() (Torez Smith) [1686205]
- [usb] usb: pci-quirks: Minor cleanup for AMD PLL quirk (Torez Smith) [1686205]
- [usb] usb: pci-quirks: Correct AMD PLL quirk detection (Torez Smith) [1686205]
- [usb] vfs: Convert gadgetfs to use the new mount API (Torez Smith) [1686205]
- [usb] Revert "usb: gadget: storage: Remove warning message" (Torez Smith) [1686205]
- [documentation] Revert "dt-bindings: add binding for USBSS-DRD controller." (Torez Smith) [1686205]
- [usb] Revert "usb:gadget Separated decoding functions from dwc3 driver." (Torez Smith) [1686205]
- [usb] Revert "usb:gadget Patch simplify usb_decode_set_clear_feature function." (Torez Smith) [1686205]
- [usb] Revert "usb:gadget Simplify usb_decode_get_set_descriptor function." (Torez Smith) [1686205]
- [usb] Revert "usb:cdns3 Add Cadence USB3 DRD Driver" (Torez Smith) [1686205]
- [usb] Revert "usb:cdns3 Fix for stuck packets in on-chip OUT buffer." (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: ehci: Fix example warnings (Torez Smith) [1686205]
- [usb] usb :fsl: Change string format for errata property (Torez Smith) [1686205]
- [usb] usb: host: Stops USB controller init if PLL fails to lock (Torez Smith) [1686205]
- [usb] usb: phy: Workaround for USB erratum-A005728 (Torez Smith) [1686205]
- [usb] usb: fsl: Set USB_EN bit to select ULPI phy (Torez Smith) [1686205]
- [usb] usb: Handle USB3 remote wakeup for LPM enabled devices correctly (Torez Smith) [1686205]
- [usb] drivers/usb/typec/tps6598x.c: fix 4CC cmd write (Torez Smith) [1686205]
- [usb] drivers/usb/typec/tps6598x.c: fix portinfo width (Torez Smith) [1686205]
- [usb] usb: storage: scsiglue: Do not skip VPD if try_vpd_pages is set (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: add a workaround for a race condition of workqueue (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: remove redundant assignment to ret (Torez Smith) [1686205]
- [usb] usb: dwc2: use a longer AHB idle timeout in dwc2_core_reset() (Torez Smith) [1686205]
- [usb] USB: gadget: function: fix issue Unneeded variable: "value" (Torez Smith) [1686205]
- [usb] usb: phy: phy-mxs-usb: add imx7ulp support (Torez Smith) [1686205]
- [usb] usb:cdns3 Fix for stuck packets in on-chip OUT buffer (Torez Smith) [1686205]
- [usb] usb:cdns3 Add Cadence USB3 DRD Driver (Torez Smith) [1686205]
- [usb] usb:gadget Simplify usb_decode_get_set_descriptor function (Torez Smith) [1686205]
- [usb] usb:gadget Patch simplify usb_decode_set_clear_feature function (Torez Smith) [1686205]
- [usb] usb:gadget Separated decoding functions from dwc3 driver (Torez Smith) [1686205]
- [documentation] dt-bindings: add binding for USBSS-DRD controller (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: add support for TigerLake Devices (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: add ID for isodebug v1 (Torez Smith) [1686205]
- [usb] usb: host: Fix excessive alignment restriction for local memory allocations (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use struct platform_callback pointer (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use renesas_usbhs_platform_info on of_device_id.data (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Add a common function for the .get_id (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: move device tree properties parsing (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Add struct device * declaration in usbhs_probe() (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Add has_new_pipe_configs flag (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use dev_of_node macro instead of open coded (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Remove type member from renesas_usbhs_driver_param (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use a specific flag instead of type for multi_clks (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Avoid to write platform_data's value (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: move macros from mod.c to the mod.h (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: remove notify_hotplug callback (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: revise the irq_vbus comments (Torez Smith) [1686205]
- [usb] USB: core: Fix compiler warnings in devio.c (Torez Smith) [1686205]
- [usb] USB: core: Remove usbfs_mutex (Torez Smith) [1686205]
- [usb] usb: clean up some of the computations in adu_read (Torez Smith) [1686205]
- [usb] scsi: usb: image: microtek: use sg helper to iterate over scatterlist (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use struct assignment instead of memcpy() (Torez Smith) [1686205]
- [usb] USB: core: correct a spelling mistake in the comment (Torez Smith) [1686205]
- [usb] usb: dwc3: remove unused @lock member of dwc3_ep struct (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Add Support for Intel Elkhart Lake Devices (Torez Smith) [1686205]
- [usb] usb: Replace snprintf with scnprintf in gether_get_ifname (Torez Smith) [1686205]
- [uapi] USB: fix types in uapi include (Torez Smith) [1686205]
- [usb] USB: serial: option: add support for GosunCn ME3630 RNDIS mode (Torez Smith) [1686205]
- [usb] xhci: detect USB 3.2 capable host controllers correctly (Torez Smith) [1686205]
- [usb] usb: xhci: Don't try to recover an endpoint if port is in error state (Torez Smith) [1686205]
- [usb] usb: gadget: ether: Fix race between gether_disconnect and rx_submit (Torez Smith) [1686205]
- [usb] usb: gadget: storage: Remove warning message (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Add support for disabling U1 and U2 entries (Torez Smith) [1686205]
- [usb] usb: gadget: send usb_gadget as an argument in get_config_params (Torez Smith) [1686205]
- [documentation] doc: dt: bindings: usb: dwc3: Update entries for disabling U1 and U2 (Torez Smith) [1686205]
- [usb] usb: dwc3: qcom: Use of_clk_get_parent_count() (Torez Smith) [1686205]
- [usb] usb: dwc3: Fix core validation in probe, move after clocks are enabled (Torez Smith) [1686205]
- [usb] usb: dwc3: qcom: Improve error handling (Torez Smith) [1686205]
- [usb] usb: dwc3: qcom: Start USB in 'host mode' on the SDM845 (Torez Smith) [1686205]
- [usb] usb: dwc3: qcom: Add support for booting with ACPI (Torez Smith) [1686205]
- [usb] Revert "usb: dwc2: host: Setting qtd to NULL after freeing it" (Torez Smith) [1686205]
- [usb] usb: gadget: net2272: remove redundant assignments to pointer 's' (Torez Smith) [1686205]
- [usb] usb: gadget: Zero ffs_io_data (Torez Smith) [1686205]
- [usb] USB: omap_udc: Remove unneeded variable (Torez Smith) [1686205]
- [usb] fotg210-udc: Remove unneeded variable (Torez Smith) [1686205]
- [usb] usb: gadget: at91_udc: Remove unneeded variable (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: Enhance role switch support (Torez Smith) [1686205]
- [usb] usb: gadget: u_audio: Fixed variable declaration coding style issue (Torez Smith) [1686205]
- [usb] usb: gadget: f_fs: data_len used before properly set (Torez Smith) [1686205]
- [usb] USB: dwc2: Don't turn off the usbphy in suspend if wakeup is enabled (Torez Smith) [1686205]
- [documentation] Documentation: dt-bindings: Add snps, need-phy-for-wake for dwc2 USB (Torez Smith) [1686205]
- [usb] usb: dwc2: Force 8bit UTMI width for Samsung Exynos SoCs (Torez Smith) [1686205]
- [usb] usb: dwc3: meson-g12a: Add support for IRQ based OTG switching (Torez Smith) [1686205]
- [usb] usb: dwc2: Use generic PHY width in params setup (Torez Smith) [1686205]
- [usb] usb: host: fotg2: add device tree probing (Torez Smith) [1686205]
- [usb] usb: isp1362: Spelling s/eclusive/exclusive/ (Torez Smith) [1686205]
- [usb] USB: add usbfs ioctl to retrieve the connection parameters (Torez Smith) [1686205]
- [usb] usb: host: xhci-tegra: Fix Wunused-const-variable (Torez Smith) [1686205]
- [usb] usb: chipidea: udc: workaround for endpoint conflict issue (Torez Smith) [1686205]
- dt-bindings: usb: renesas_gen3: Rename bindings documentation file (Torez Smith) [1686205]
- dt-bindings: usb: renesas_usbhs: Rename bindings documentation file (Torez Smith) [1686205]
- [documentation] docs: power: convert docs to ReST and rename to *.rst (Torez Smith) [1686205]
- [usb] docs: kbuild: convert docs to ReST and rename to *.rst (Torez Smith) [1686205]
- [usb] usb: chipidea: msm: Use devm_platform_ioremap_resource() (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: Use devm_platform_ioremap_resource() (Torez Smith) [1686205]
- [usb] usb: chipidea: Use dev_err() instead of pr_err() (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: "fsl, usbphy" phandle is not mandatory now (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: add imx7ulp support (Torez Smith) [1686205]
- [usb] usb: typec: Make sure an alt mode exist before getting its partner (Torez Smith) [1686205]
- [usb] Revert "usb: mtu3: fix up undefined reference to usb_debug_root" (Torez Smith) [1686205]
- [usb] USB: sisusbvga: Remove unneeded variable (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: fusb302: simplify getting the adapter of a client (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: add runtime pm workaround (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: enable runtime pm support (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: fix return value check in lpc32xx_udc_probe() (Torez Smith) [1686205]
- [usb] usb: gadget: dwc2: fix zlp handling (Torez Smith) [1686205]
- [usb] usb: dwc2: Set actual frame number for completed ISOC transfer for none DDMA (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: allocate descriptor with GFP_ATOMIC (Torez Smith) [1686205]
- [usb] usb: gadget: fusb300_udc: Fix memory leak of fusb300->ep (Torez Smith) [1686205]
- [usb] usb: phy: mxs: Disable external charger detect in mxs_phy_hw_init() (Torez Smith) [1686205]
- [usb] usb: dwc2: Fix DMA cache alignment issues (Torez Smith) [1686205]
- [usb] usb: dwc2: host: Fix wMaxPacketSize handling (fix webcam regression) (Torez Smith) [1686205]
- [usb] USB: move usb debugfs directory creation to the usb common core (Torez Smith) [1686205]
- [usb] usb: host: u132-hcd: remove unneeded variable frame (Torez Smith) [1686205]
- [usb] media: usb/gadget/f_uvc: set device_caps in struct video_device (Torez Smith) [1686205]
- [usb] usbip: Replace unused kvec array with single variable in vhci_send_cmd_unlink() (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: remove controlling PWEN/EXTLP support (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: remove sudmac support (Torez Smith) [1686205]
- [usb] usb: xhci: Add Clear_TT_Buffer (Torez Smith) [1686205]
- [usb] usb: Add devaddr in struct usb_device (Torez Smith) [1686205]
- [usb] USB: Fix chipmunk-like voice when using Logitech C270 for recording audio (Torez Smith) [1686205]
- [usb] USB: usb-storage: Add new ID to ums-realtek (Torez Smith) [1686205]
- [usb] USB: use genalloc for USB HCs with local memory (Torez Smith) [1686205]
- [usb] usb: phy: mv-usb: Remove set but not used variable 'phy' (Torez Smith) [1686205]
- [usb] usb: ftdi-elan: fix possible condition with no effect (if == else) (Torez Smith) [1686205]
- [usb] USB: ohci-spear: Remove set but not used variable 'ohci' (Torez Smith) [1686205]
- [usb] USB: atm: ueagle-atm.c: remove redundant license text (Torez Smith) [1686205]
- [usb] USB: atm: ueagle-atm.c: fix SPDX tag to be BSD2 (Torez Smith) [1686205]
- [usb] usb: ohci-s3c2410: Remove set but not used variable 'hcd' (Torez Smith) [1686205]
- [usb] usb: cdc-wdm: remove redundant assignment to rv (Torez Smith) [1686205]
- [usb] usb: host: ohci-st: Remove set but not used variable 'ohci' (Torez Smith) [1686205]
- [usb] usb: host: ehci-st: Remove set but not used variable 'ehci' (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: fix memory leak in do_flash (Torez Smith) [1686205]
- [include] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Torez Smith) [1686205]
- [tools] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Torez Smith) [1686205]
- [usb] usbip: usbip_host: fix stub_dev lock context imbalance regression (Torez Smith) [1686205]
- [tools] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 61 (Torez Smith) [1686205]
- [usb] usb: avoid redundant allocation and free of memory (Torez Smith) [1686205]
- [usb] signal/usb: Replace kill_pid_info_as_cred with kill_pid_usb_asyncio (Torez Smith) [1686205]
- [usb] xhci: Use zu for printing size_t type (Torez Smith) [1686205]
- [usb] xhci: Convert xhci_handshake() to use readl_poll_timeout_atomic() (Torez Smith) [1686205]
- [usb] xhci: Fix immediate data transfer if buffer is already DMA mapped (Torez Smith) [1686205]
- [usb] usb: xhci: avoid null pointer deref when bos field is NULL (Torez Smith) [1686205]
- [usb] usb: xhci: Fix a potential null pointer dereference in xhci_debugfs_create_endpoint() (Torez Smith) [1686205]
- [usb] xhci: update bounce buffer with correct sg num (Torez Smith) [1686205]
- [tools] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Torez Smith) [1686205]
- [usb] USB: serial: option: add Telit 0x1260 and 0x1261 compositions (Torez Smith) [1686205]
- [usb] USB: serial: pl2303: add Allied Telesis VT-Kit3 (Torez Smith) [1686205]
- [usb] USB: serial: option: add support for Simcom SIM7500/SIM7600 RNDIS mode (Torez Smith) [1686205]
- [tools] treewide: Add SPDX license identifier - Makefile/Kconfig (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: Add support for r7s9210 (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Add support for RZ/A2 (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: support byte addressable CFIFO (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: add support for CNEN bit (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: move flags to param (Torez Smith) [1686205]
- [usb] usb: core: hub: Disable hub-initiated U1/U2 (Torez Smith) [1686205]
- [usb] usb: core: hub: Enable/disable U1/U2 in configured state (Torez Smith) [1686205]
- [usb] USB: rio500: simplify locking (Torez Smith) [1686205]
- [usb] USB: rio500: fix memory leak in close after disconnect (Torez Smith) [1686205]
- [usb] USB: rio500: refuse more than one device at a time (Torez Smith) [1686205]
- [usb] usbip: usbip_host: fix BUG: sleeping function called from invalid context (Torez Smith) [1686205]
- [usb] USB: sisusbvga: fix oops in error path of sisusb_probe (Torez Smith) [1686205]
- [usb] USB: Add LPM quirk for Surface Dock GigE adapter (Torez Smith) [1686205]
- [usb] usb: mtu3: fix up undefined reference to usb_debug_root (Torez Smith) [1686205]
- [usb] USB: Fix slab-out-of-bounds write in usb_get_bos_descriptor (Torez Smith) [1686205]
- [usb] usb: remove redundant 'default n' from Kconfig-s (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use specific struct instead of USBHS_TYPE_* enums (Torez Smith) [1686205]
- [usb] USB: OHCI: remove space before open square bracket '[' (Torez Smith) [1686205]
- [usb] usb: exynos: add workaround for the USB device bindings conflict (Torez Smith) [1686205]
- [usb] usbip: usbip_host: cleanup do_rebind() return path (Torez Smith) [1686205]
- [usb] USB: serial: f81232: clear overrun flag (Torez Smith) [1686205]
- [usb] USB: serial: f81232: fix interrupt worker not stop (Torez Smith) [1686205]
- [usb] usb: dwc3: Rename DWC3_DCTL_LPM_ERRATA (Torez Smith) [1686205]
- [usb] usb: dwc3: Fix default lpm_nyet_threshold value (Torez Smith) [1686205]
- [usb] usb: dwc3: debug: Print GET_STATUS(device) tracepoint (Torez Smith) [1686205]
- [usb] usb: dwc3: Do core validation early on probe (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Set lpm_capable (Torez Smith) [1686205]
- [usb] usb: gadget: atmel: tie wake lock to running clock (Torez Smith) [1686205]
- [usb] usb: gadget: atmel: support USB suspend (Torez Smith) [1686205]
- [usb] usb: gadget: atmel_usba_udc: simplify setting of interrupt-enabled mask (Torez Smith) [1686205]
- [usb] dwc2: gadget: Fix completed transfer size calculation in DDMA (Torez Smith) [1686205]
- [usb] usb: dwc2: Set lpm mode parameters depend on HW configuration (Torez Smith) [1686205]
- [usb] usb: dwc2: Fix channel disable flow (Torez Smith) [1686205]
- [usb] usb: dwc2: Set actual frame number for completed ISOC transfer (Torez Smith) [1686205]
- [usb] usb: gadget: do not use __constant_cpu_to_le16 (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Increase descriptors count for ISOC's (Torez Smith) [1686205]
- [usb] usb: dwc3: move synchronize_irq() out of the spinlock protected block (Torez Smith) [1686205]
- [usb] usb: dwc3: Free resource immediately after use (Torez Smith) [1686205]
- [usb] usb: dwc3: of-simple: Convert to bulk clk API (Torez Smith) [1686205]
- [usb] usb: dwc2: Delayed status support (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: rework interrupt handling (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: add support for stotg04 phy (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: properly setup phy interrupts (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: simplify vbus handling (Torez Smith) [1686205]
- [usb] usb: gadget: udc: lpc32xx: simplify probe (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Move gadget phy init into core phy init (Torez Smith) [1686205]
- [usb] usb: dwc2: Move phy init into core (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Replace phyif with phy_utmi_width (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Remove duplicated phy init (Torez Smith) [1686205]
- [usb] usb: dwc2: Move UTMI_PHY_DATA defines closer (Torez Smith) [1686205]
- [usb] usb: dwc2: optionally assert phy reset when waking up (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: dwc2: Document quirk to reset PHY upon wakeup (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: dwc2: document the vbus-supply property (Torez Smith) [1686205]
- [usb] USB: UDC: net22{80, 72}: remove mistaken test of req->zero (Torez Smith) [1686205]
- [usb] USB: UDC: net2280: Remove redundant "if" condition (Torez Smith) [1686205]
- [usb] usb: gadget: fsl: fix link error against usb-gadget module (Torez Smith) [1686205]
- [usb] usb: gadget: f_ncm: Add OS descriptor support (Torez Smith) [1686205]
- [usb] usb: gadget: f_ncm: Fix NTP-32 support (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Reject LPM token during Control transfers (Torez Smith) [1686205]
- [usb] USB: Export usb_wakeup_enabled_descendants() (Torez Smith) [1686205]
- [usb] usb: dwc2: bus suspend/resume for hosts with DWC2_POWER_DOWN_PARAM_NONE (Torez Smith) [1686205]
- [usb] usb: dwc3: Add Amlogic G12A DWC3 glue (Torez Smith) [1686205]
- [usb] usb: dwc2: Add Amlogic G12A DWC2 Params (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: dwc3: Add Amlogic G12A DWC3 Glue Bindings (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: dwc2: Add Amlogic G12A DWC2 Compatible (Torez Smith) [1686205]
- [usb] usb: gadget: f_fs: don't free buffer prematurely (Torez Smith) [1686205]
- [usb] USB: serial: io_edgeport: fix up switch fall-through comments (Torez Smith) [1686205]
- [usb] usb: usb251xb: Add US port lanes inversion property (Torez Smith) [1686205]
- [usb] usb: usb251xb: Create a ports field collector method (Torez Smith) [1686205]
- [documentation] usb: usb251xb: Add US lanes inversion dts-bindings (Torez Smith) [1686205]
- [usb] usb: isp1760-hcd: Fix fall-through annotations (Torez Smith) [1686205]
- [usb] usb: musb: dsps: Use dev_get_drvdata() (Torez Smith) [1686205]
- [usb] usb: musb: jz4740: obtain USB PHY from devicetree (Torez Smith) [1686205]
- [usb] usb: musb: jz4740: Let the platform probe the PHY (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: Add usb-phy property to the jz4740-musb node (Torez Smith) [1686205]
- [soc] soc: sunxi: Fix missing dependency on REGMAP_MMIO (Torez Smith) [1686205]
- [usb] usb: musb: omap2430: Add support for idling phy when musb is idle (Torez Smith) [1686205]
- [usb] usb: musb: Silence error about blacklisting hubs if !CONFIG_USB (Torez Smith) [1686205]
- [usb] usbip: vhci_hcd: Mark expected switch fall-through (Torez Smith) [1686205]
- [usb] UAS: fix alignment of scatter/gather segments (Torez Smith) [1686205]
- [include] USB: serial: drop unused iflag macro (Torez Smith) [1686205]
- [usb] USB: serial: drop unnecessary goto (Torez Smith) [1686205]
- [usb] USB: serial: clean up throttle handling (Torez Smith) [1686205]
- [usb] USB: serial: fix unthrottle races (Torez Smith) [1686205]
- [usb] USB: cdc-acm: clean up throttle handling (Torez Smith) [1686205]
- [usb] USB: cdc-acm: fix unthrottle races (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: fix missing unlock on error in ccg_cmd_write_flash_row() (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: Add support for r8a77470 (Torez Smith) [1686205]
- [documentation] dt-bindings: usb-xhci: Add r8a774c0 support (Torez Smith) [1686205]
- [usb] usb: xhci: add endpoint context tracing when an endpoint is added (Torez Smith) [1686205]
- [usb] xhci: Add tracing for input control context (Torez Smith) [1686205]
- [usb] xhci: add port and bus number to port dynamic debugging (Torez Smith) [1686205]
- [usb] usb: xhci: add Immediate Data Transfer support (Torez Smith) [1686205]
- [usb] usb: usb251xb: Add an empty hub' i2c-bus segment checker (Torez Smith) [1686205]
- [usb] USB: serial: spcp8x5: simplify init_termios (Torez Smith) [1686205]
- [usb] USB: serial: oti6858: simplify init_termios (Torez Smith) [1686205]
- [usb] USB: serial: iuu_phoenix: simplify init_termios (Torez Smith) [1686205]
- [usb] USB: serial: iuu_phoenix: drop bogus initial cflag (Torez Smith) [1686205]
- [usb] USB: serial: cypress_m8: clean up initial-termios handling (Torez Smith) [1686205]
- [usb] USB: serial: cypress_m8: drop unused termios (Torez Smith) [1686205]
- [usb] USB: serial: cypress_m8: drop unused driver data flag (Torez Smith) [1686205]
- [usb] USB: serial: fix initial-termios handling (Torez Smith) [1686205]
- [usb] USB: yurex: Fix protection fault after device removal (Torez Smith) [1686205]
- [usb] usb: usbip: fix isoc packet num validation in get_pipe (Torez Smith) [1686205]
- [usb] usb/hcd: Send a uevent signaling that the host controller had died (Torez Smith) [1686205]
- [usb] usb: typec: Add driver for NVIDIA Alt Modes (Torez Smith) [1686205]
- [usb] usb: typec: displayport: Export probe and remove functions (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: Support for DisplayPort alt mode (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: Preliminary support for alternate modes (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: add firmware flashing support (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: ccg: add get_fw_info function (Torez Smith) [1686205]
- [usb] usb: usb251xb: Lock i2c-bus segment the hub resides (Torez Smith) [1686205]
- [usb] usb: dwc3: Allow building USB_DWC3_QCOM without EXTCON (Torez Smith) [1686205]
- [usb] usbip: stub_rx: tidy the indenting in is_clear_halt_cmd() (Torez Smith) [1686205]
- [usb] USB: serial: digi_acceleport: clean up set_termios (Torez Smith) [1686205]
- [usb] USB: serial: digi_acceleport: clean up modem-control handling (Torez Smith) [1686205]
- [usb] USB: core: Fix bug caused by duplicate interface PM usage counter (Torez Smith) [1686205]
- [usb] usb: mtu3: get optional clock by devm_clk_get_optional() (Torez Smith) [1686205]
- [usb] usb: chipidea: msm: get optional clock by devm_clk_get_optional() (Torez Smith) [1686205]
- [usb] usb: dwc2: get optional clock by devm_clk_get_optional() (Torez Smith) [1686205]
- [usb] usb: misc: usb3503: get optional clock by devm_clk_get_optional() (Torez Smith) [1686205]
- [usb] usb: host: xhci-plat: get optional clock by devm_clk_get_optional() (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: get optional clock by devm_clk_get_optional() (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Revert "Resolve fixed power role contract setup" (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Implement start_toggling for all port-types (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Notify the tcpc to start connection-detection for SRPs (Torez Smith) [1686205]
- [usb] usb: host: use usb_endpoint_maxp instead of usb_maxpacket (Torez Smith) [1686205]
- [usb] USB: dummy-hcd: Fix failure to give back unlinked URBs (Torez Smith) [1686205]
- [usb] USB: core: Don't unbind interfaces following device reset failure (Torez Smith) [1686205]
- [usb] usb-storage: Set virt_boundary_mask to avoid SG overflows (Torez Smith) [1686205]
- [usb] USB: core: Fix unterminated string returned by usb_string() (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: Convert the generic EHCI binding to YAML (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: Convert the generic OHCI binding to YAML (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: Convert USB HCD generic binding to YAML (Torez Smith) [1686205]
- [usb] USB: hub: Remove returned value 'status' since never used (Torez Smith) [1686205]
- [usb] usb: host: xhci-tegra: Add Tegra186 XUSB support (Torez Smith) [1686205]
- [usb] usb: host: xhci-tegra: Selectively program IPFS (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: xhci-tegra: Add Tegra186 support (Torez Smith) [1686205]
- [usb] usb: ohci-da8xx: drop the vbus GPIO (Torez Smith) [1686205]
- [usb] usb: ohci-da8xx: disable the regulator if the overcurrent irq fired (Torez Smith) [1686205]
- [usb] usb: ohci-da8xx: let the regulator framework keep track of use count (Torez Smith) [1686205]
- [usb] USB: serial: pl2303: fix tranceiver suspend mode (Torez Smith) [1686205]
- [usb] USB: serial: pl2303: fix non-supported xon/xoff (Torez Smith) [1686205]
- [usb] USB: serial: option: add Olicard 600 (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: add new device id (Torez Smith) [1686205]
- [usb] usb: u132-hcd: fix resource leak (Torez Smith) [1686205]
- [usb] usb: cdc-acm: fix race during wakeup blocking TX traffic (Torez Smith) [1686205]
- [usb] usb: mtu3: fix EXTCON dependency (Torez Smith) [1686205]
- [usb] usb: usb251xb: fix to avoid potential NULL pointer dereference (Torez Smith) [1686205]
- [usb] usb: core: Try generic PHY_MODE_USB_HOST if usb_phy_roothub_set_mode fails (Torez Smith) [1686205]
- [usb] usb: introduce usb_ep_type_string() function (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Make fusb302_irq_work static (Torez Smith) [1686205]
- [usb] usb: u132-hcd: fix potential NULL pointer dereference (Torez Smith) [1686205]
- [usb] usb: typec: wcove: Provide fwnode for the port (Torez Smith) [1686205]
- [usb] usb: core: Add PM runtime calls to usb_hcd_platform_shutdown (Torez Smith) [1686205]
- [usb] usb: sierra: fix a missing check of device_create_file (Torez Smith) [1686205]
- [usb] usb: mtu3: add a function to switch mailbox state to string (Torez Smith) [1686205]
- [usb] usb: mtu3: add tracepoints to help debug (Torez Smith) [1686205]
- [usb] usb: mtu3: move vbus and mode debugfs interfaces into mtu3_debugfs.c (Torez Smith) [1686205]
- [usb] usb: mtu3: add debugfs interface files (Torez Smith) [1686205]
- [usb] usb: mtu3: supports new QMU format (Torez Smith) [1686205]
- [usb] usb: mtu3: rebuild qmu_gpd struct to prepare to support new QMU format (Torez Smith) [1686205]
- [usb] usb: mtu3: fix transfer error of USB3 Gen2 isoc (Torez Smith) [1686205]
- [usb] usb: mtu3: rebuild the code of getting vbus regulator (Torez Smith) [1686205]
- [usb] usb: mtu3: remove unnecessary local variable @req (Torez Smith) [1686205]
- [usb] usb: mtu3: print useful information also for device and host modes (Torez Smith) [1686205]
- [usb] usb: mtu3: check return value of devm_extcon_register_notifier() (Torez Smith) [1686205]
- [usb] xhci: Don't let USB3 ports stuck in polling state prevent suspend (Torez Smith) [1686205]
- [usb] usb: xhci: dbc: Don't free all memory with spinlock held (Torez Smith) [1686205]
- [usb] xhci: Fix port resume done detection for SS ports with LPM enabled (Torez Smith) [1686205]
- [usb] USB: serial: mos7720: fix mos_parport refcount imbalance on error path (Torez Smith) [1686205]
- [usb] USB: gadget: f_hid: fix deadlock in f_hidg_write() (Torez Smith) [1686205]
- [usb] usb: gadget: net2272: Fix net2272_dequeue() (Torez Smith) [1686205]
- [usb] usb: gadget: net2280: Fix net2280_dequeue() (Torez Smith) [1686205]
- [usb] usb: gadget: net2280: Fix overrun of OUT messages (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: add support for Comet Lake PCH ID (Torez Smith) [1686205]
- [usb] usb: usb251xb: Remove unnecessary comparison of unsigned integer with >= 0 (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Add __printf attribute to fusb302_log function (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Improve suspend/resume handling (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: 2 small misc. fixes (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Fix fusb302_handle_togdone_src Ra handling (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Check vconn is off when we start toggling (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Fold fusb302_set_cc_pull into tcpm_set_cc (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Refactor / simplify tcpm_set_cc() (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Make fusb302_set_cc_polarity also set pull ups / downs (Torez Smith) [1686205]
- [usb] usb: typec: pi3usb30532: Keep orientation when setting mux to safe mode (Torez Smith) [1686205]
- [usb] usb: typec: altmodes/displayport: Fall back to multi-func pins (Torez Smith) [1686205]
- [usb] usbip: Remove unnecessary null check (Torez Smith) [1686205]
- [include] USB: usb.h: tweak struct urb to remove wasted space (Torez Smith) [1686205]
- [usb] usb: common: Consider only available nodes for dr_mode (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Try PD-2.0 if sink does not respond to 3.0 source-caps (Torez Smith) [1686205]
- [usb] usb: host: xhci-rcar: Add XHCI_TRUST_TX_LENGTH quirk (Torez Smith) [1686205]
- [usb] usb: typec: Fix unchecked return value (Torez Smith) [1686205]
- [usb] USB: serial: option: set driver_info for SIM5218 and compatibles (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: add additional NovaTech products (Torez Smith) [1686205]
- [usb] USB: serial: option: add support for Quectel EM12 (Torez Smith) [1686205]
- [usb] wusb: Remove unnecessary static function ckhdid_printf (Torez Smith) [1686205]
- [usb] usb: core: make default autosuspend delay configurable (Torez Smith) [1686205]
- [usb] usb: core: Fix typo in description of "authorized_default" (Torez Smith) [1686205]
- [usb] usb: chipidea: Refactor USB PHY selection and keep a single PHY (Torez Smith) [1686205]
- [usb] usb: chipidea: Grab the (legacy) USB PHY by phandle first (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: set power polarity (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: ci-hdrc-usb2: add property power-active-high (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: remove unused header files (Torez Smith) [1686205]
- [usb] usb: chipidea: tegra: Fix missed ci_hdrc_remove_device() (Torez Smith) [1686205]
- [usb] usb: core: add option of only authorizing internal devices (Torez Smith) [1686205]
- [usb] usb: typec: tps6598x: handle block writes separately with plain-I2C adapters (Torez Smith) [1686205]
- [usb] usb: xhci: Fix for Enabling USB ROLE SWITCH QUIRK on INTEL_SUNRISEPOINT_LP_XHCI (Torez Smith) [1686205]
- [usb] usb: xhci: fix build warning - missing prototype (Torez Smith) [1686205]
- [usb] usb: xhci: dbc: Fixing typo error (Torez Smith) [1686205]
- [usb] usb: xhci: remove unused member 'parent' in xhci_regset struct (Torez Smith) [1686205]
- [usb] xhci: tegra: Prevent error pointer dereference (Torez Smith) [1686205]
- [usb] USB: serial: option: add Telit ME910 ECM composition (Torez Smith) [1686205]
- [usb] usb: core: Replace hardcoded check with inline function from usb.h (Torez Smith) [1686205]
- [usb] usb: core: skip interfaces disabled in devicetree (Torez Smith) [1686205]
- [usb] usb: typec: mux: remove redundant check on variable match (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: fix GPIO in autosuspend (Torez Smith) [1686205]
- [usb] usb: dwc3: drd: Defer probe if extcon device is not found (Torez Smith) [1686205]
- [usb] cdc-wdm: pass return value of recover_from_urb_loss (Torez Smith) [1686205]
- [usb] usb: host: oxu210hp-hcd: remove set but not used variables 'uframes, transfer_buffer_length' (Torez Smith) [1686205]
- [usb] USB: renesas_usbhs: fix spelling mistake "doens't" -> "doesn't" (Torez Smith) [1686205]
- [usb] usb: wusbcore: wa-xfer: use struct_size() helper (Torez Smith) [1686205]
- [usb] usb: core: config: Use struct_size() in kzalloc() (Torez Smith) [1686205]
- [usb] usb: dwc2: use struct_size() in kzalloc() (Torez Smith) [1686205]
- [usb] usb: typec: mux: Fix unsigned comparison with less than zero (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: add ID for Hjelmslund Electronics USB485 (Torez Smith) [1686205]
- [usb] usb: typec: mux: Find the muxes by also matching against the device node (Torez Smith) [1686205]
- [usb] usb: typec: Find the ports by also matching against the device node (Torez Smith) [1686205]
- [usb] usb: roles: Find the muxes by also matching against the device node (Torez Smith) [1686205]
- [usb] usb: typec: Rationalize the API for the muxes (Torez Smith) [1686205]
- [usb] usb: typec: tps6598x: Check mode of operation (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Remove unused functions (Torez Smith) [1686205]
- [usb] USB: musb: mark expected switch fall-through (Torez Smith) [1686205]
- [usb] usb: phy: twl6030-usb: fix possible use-after-free on remove (Torez Smith) [1686205]
- [usb] usb: misc: usbtest: add super-speed isoc support (Torez Smith) [1686205]
- [usb] usb: dwc3: Reset num_trbs after skipping (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: don't enable interrupt when disabling endpoint (Torez Smith) [1686205]
- [usb] scsi: uas: Use scsi_et_resid() where appropriate (Torez Smith) [1686205]
- [usb] usb: host: oxu210hp-hcd: fix indentation issue (Torez Smith) [1686205]
- [usb] usb: ohci-da8xx: add vbus and overcurrent gpios (Torez Smith) [1686205]
- [usb] usb: ohci-da8xx: add a helper pointer to &pdev->dev (Torez Smith) [1686205]
- [usb] usb: ohci-da8xx: add a new line after local variables (Torez Smith) [1686205]
- [usb] usb: musb: Kconfig: Drop dependency on CONFIG_USB for jz4740 (Torez Smith) [1686205]
- [usb] usb: musb: Kconfig: Drop dependency on MACH_JZ4740 for jz4740 (Torez Smith) [1686205]
- [usb] usb: musb: jz4740: Add support for devicetree (Torez Smith) [1686205]
- [documentation] Documentation: dt: Add binding info for jz4740-musb driver (Torez Smith) [1686205]
- [usb] USB: musb: fix indentation issue on a return statement (Torez Smith) [1686205]
- [usb] fotg210-udc: pass struct device to DMA API functions (Torez Smith) [1686205]
- [usb] fotg210-udc: remove a bogus dma_sync_single_for_device call (Torez Smith) [1686205]
- [usb] usb: gadget: Change Andrzej Pietrasiewicz's e-mail address (Torez Smith) [1686205]
- [usb] usb: f_fs: Avoid crash due to out-of-scope stack ptr access (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: Remove debug.h file (Torez Smith) [1686205]
- [usb] usb: typec: Prepare alt mode enter/exit reporting for UCSI alt mode support (Torez Smith) [1686205]
- [usb] usb: typec: displayport: Move the Configuration VDO helpers to the header (Torez Smith) [1686205]
- [usb] USB: Fix configuration selection issues introduced in v4.20.0 (Torez Smith) [1686205]
- [usb] usb: handle warm-reset port requests on hub resume (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: add ID for Ingenico 3070 (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: add minimum baud rate for CP2105 SCI (Torez Smith) [1686205]
- [usb] usb: dwc3: haps: Workaround matching VID PID (Torez Smith) [1686205]
- [usb] usb: gadget: f_fs: preserve wMaxPacketSize across usb_ep_autoconfig() call (Torez Smith) [1686205]
- [usb] usb: gadget: move non-super speed code out of usb_ep_autoconfig_ss() (Torez Smith) [1686205]
- [usb] usb: gadget: function: sync f_uac1 ac header baInterfaceNr (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Add scatter-gather mode (Torez Smith) [1686205]
- [usb] usb: gadget: fix various indentation issues (Torez Smith) [1686205]
- [usb] usb: dwc2: Fix EP TxFIFO number setting (Torez Smith) [1686205]
- [usb] udc: net2280: Fix net2280_disable (Torez Smith) [1686205]
- [usb] USB: gadget: Improve kerneldoc for usb_ep_dequeue() (Torez Smith) [1686205]
- [usb] usb: dwc3: debug: purge usage of strcat (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: add GPIO support for CP2104 (Torez Smith) [1686205]
- [usb] usb: dwc3: trace: pass trace buffer size to decoding functions (Torez Smith) [1686205]
- [usb] usb: core: Move variable initialization to appropriate place (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: remove DWC3_EP_END_TRANSFER_PENDING (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: early giveback if End Transfer already completed (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: don't use resource_index as a flag (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: clear DWC3_EP_TRANSFER_STARTED on cmd complete (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Correct the PPS out_volt calculation (Torez Smith) [1686205]
- [usb] usb: gadget: musb: fix short isoc packets with inventra dma (Torez Smith) [1686205]
- [usb] usbip: Fix vep_free_request() null pointer checks on input args (Torez Smith) [1686205]
- [usb] usb: ehci-orion: add S2RAM support (Torez Smith) [1686205]
- [usb] usb: ehci-orion: avoid double PHY initialization (Torez Smith) [1686205]
- [usb] usb: host: xhci: mvebu: add reset on resume quirk (Torez Smith) [1686205]
- [usb] usb: core: comply to PHY framework (Torez Smith) [1686205]
- [usb] usb: phy: am335x: fix race condition in _probe (Torez Smith) [1686205]
- [usb] usb: dwc3: exynos: Fix error handling of clk_prepare_enable (Torez Smith) [1686205]
- [usb] usb: phy: fix link errors (Torez Smith) [1686205]
- [usb] usb: gadget: udc: net2272: Fix bitwise and boolean operations (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Handle 0 xfer length for OUT EP (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: remove req->started flag (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: prevent dwc3_request from being queued twice (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: add dwc3_request status tracking (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: add support for r8a774c0 (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: add uvcg_warn macro (Torez Smith) [1686205]
- [usb] usb: gadget: u_serial: process RX in workqueue instead of tasklet (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: Add r8a774c0 support (Torez Smith) [1686205]
- [documentation] usb: gadget: udc: renesas_usb3: Add bindings for r8a774c0 (Torez Smith) [1686205]
- [usb] usb: gadget: aspeed: fix typo (Torez Smith) [1686205]
- [usb] usb: dwc3: keystone: Add support for ti, am654-dwc3 (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: keystone-usb: Add ti, am654-dwc3 support (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Fix OTG events when gadget driver isn't loaded (Torez Smith) [1686205]
- [usb] usb: dwc3: qcom: Add support for MSM8998 (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: Add support for msm8998 (Torez Smith) [1686205]
- [usb] usb: gadget: Remove dead branch code (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: support all gpios on CP2102N QFN28 package (Torez Smith) [1686205]
- [usb] usb: ftdi-elan: Fix if == else warnings in ftdi_elan_respond_engine (Torez Smith) [1686205]
- [usb] usb: typec: tpcm: improve error handling of tcpm_register_port (Torez Smith) [1686205]
- [usb] usb: misc: usb3503: Add system sleep support in non-I2C mode (Torez Smith) [1686205]
- [usb] usbip: Fix vhci_urb_enqueue() URB null transfer buffer error path (Torez Smith) [1686205]
- [usb] usb: sisusb: remove useless macros and compact the code (Torez Smith) [1686205]
- [usb] usb: sisusb: let files build only when needed (Torez Smith) [1686205]
- [usb] usb: sisusb_con, cleanup configs (Torez Smith) [1686205]
- [usb] usb: sisusb_con, convert addr macros to functions (Torez Smith) [1686205]
- [usb] usb: ftdi-elan: remove a unnecessary variable 'empty_packets' (Torez Smith) [1686205]
- [usb] usb: assign ACPI companions for embedded USB devices (Torez Smith) [1686205]
- [usb] usb: split code locating ACPI companion into port and device (Torez Smith) [1686205]
- [usb] USB: host: whci: rename Kbuild file (Torez Smith) [1686205]
- [usb] USB: remove README file (Torez Smith) [1686205]
- [usb] USB: add missing SPDX lines to Kconfig and Makefiles (Torez Smith) [1686205]
- [usb] USB: storage: karma: add whitespace after declarations (Torez Smith) [1686205]
- [usb] USB: serial: keyspan_usa: add proper SPDX lines for .h files (Torez Smith) [1686205]
- [usb] USB: EHCI: ehci-mv: add MODULE_DEVICE_TABLE (Torez Smith) [1686205]
- [usb] USB: Consolidate LPM checks to avoid enabling LPM twice (Torez Smith) [1686205]
- [usb] USB: Add new USB LPM helpers (Torez Smith) [1686205]
- [usb] drivers: usb :fsl: Remove USB Errata checking code (Torez Smith) [1686205]
- [usb] usb: kconfig: remove dependency FSL_SOC for ehci fsl driver (Torez Smith) [1686205]
- [usb] usb: ehci: fsl: Update register accessing for arm/arm64 platforms (Torez Smith) [1686205]
- [usb] usb: usb251xb: add usb data lane port swap feature (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: usb251xb: add documentation for data lane swapping (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: replace udelay() with usleep_range() (Torez Smith) [1686205]
- [usb] USB: host: ohci-at91: add sam9x60-sfr definition for ohci (Torez Smith) [1686205]
- [usb] xhci: Use struct_size() in kzalloc() (Torez Smith) [1686205]
- [usb] usb: hub: add retry routine after intr URB submit error (Torez Smith) [1686205]
- [usb] USB: leds: fix regression in usbport led trigger (Torez Smith) [1686205]
- [usb] usb: chipidea: fix static checker warning for NULL pointer (Torez Smith) [1686205]
- [usb] USB: usbip: delete README file (Torez Smith) [1686205]
- [usb] USB: serial: pl2303: add new PID to support PL2303TB (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Fix Remote Wakeup interrupt bit clearing (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: fix GPIO not working in autosuspend (Torez Smith) [1686205]
- [usb] usb: gadget: Potential NULL dereference on allocation error (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Fix the uninitialized link_state when udc starts (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Clear req->needs_extra_trb flag on cleanup (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: synchronize_irq dwc irq in suspend (Torez Smith) [1686205]
- [usb] USB: core: urb: Use struct_size() in kmalloc() (Torez Smith) [1686205]
- [usb] cross-tree: phase out dma_zalloc_coherent() (Torez Smith) [1686205]
- [usb] usb: gadget: udc: reduce indentation (Torez Smith) [1686205]
- [usb] usb: devio: update max count of DPs per interval for ISOC (Torez Smith) [1686205]
- [usb] usb: host: u132-hcd: fix a couple of indentation issues (Torez Smith) [1686205]
- [usb] usb: core: Simplify return value of usb_get_configuration() (Torez Smith) [1686205]
- [usb] USB: Add USB_QUIRK_DELAY_CTRL_MSG quirk for Corsair K70 RGB (Torez Smith) [1686205]
- [usb] usbcore: Select only first configuration for non-UAC3 compliant devices (Torez Smith) [1686205]
- [usb] USB: storage: add quirk for SMI SM3350 (Torez Smith) [1686205]
- [usb] USB: storage: don't insert sane sense for SPC3+ when bad sense specified (Torez Smith) [1686205]
- [usb] usb: cdc-acm: send ZLP for Telit 3G Intel based modems (Torez Smith) [1686205]
- [usb] USB: serial: simple: add Motorola Tetra TPG2200 device id (Torez Smith) [1686205]
- [usb] USB: serial: option: add Fibocom NL678 series (Torez Smith) [1686205]
- [usb] cdc-acm: fix abnormal DATA RX issue for Mediatek Preloader (Torez Smith) [1686205]
- [usb] usb: r8a66597: Fix a possible concurrency use-after-free bug in r8a66597_endpoint_disable() (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Extend the matching rules on PPS APDO selection (Torez Smith) [1686205]
- [documentation] usb: typec: Improve Alt Mode documentation (Torez Smith) [1686205]
- [usb] usb: musb: dsps: fix runtime pm for peripheral mode (Torez Smith) [1686205]
- [usb] usb: musb: dsps: fix otg state machine (Torez Smith) [1686205]
- [usb] USB: serial: pl2303: add ids for Hewlett-Packard HP POS pole displays (Torez Smith) [1686205]
- [usb] PCI: Move Synopsys HAPS platform device IDs (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: add support for RZ/G2E (Torez Smith) [1686205]
- [usb] usb: ehci-omap: Fix deferred probe for phy handling (Torez Smith) [1686205]
- [usb] usb: roles: Add a description for the class to Kconfig (Torez Smith) [1686205]
- [usb] xhci: Don't prevent USB2 bus suspend in state check intended for USB3 only (Torez Smith) [1686205]
- [usb] USB: serial: option: add Telit LN940 series (Torez Smith) [1686205]
- [usb] USB: serial: option: add Fibocom NL668 series (Torez Smith) [1686205]
- [usb] USB: serial: option: add Simcom SIM7500/SIM7600 (MBIM mode) (Torez Smith) [1686205]
- [usb] USB: serial: option: add GosunCn ZTE WeLink ME3630 (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: mark PM functions as __maybe_unused (Torez Smith) [1686205]
- [usb] usb: core: Remove unnecessary memset() (Torez Smith) [1686205]
- [usb] usb: host: isp1362-hcd: convert to DEFINE_SHOW_ATTRIBUTE (Torez Smith) [1686205]
- [usb] usb: dwc2: Fix disable all EP's on disconnect (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: allow to configure oc polarity on i.MX25 (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: Warn if oc polarity isn't specified (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: support configuring for active low oc signal (Torez Smith) [1686205]
- [documentation] doc: usb: ci-hdrc-usb2: Add pinctrl properties for HSIC pin groups (Torez Smith) [1686205]
- [usb] usb: chipidea: host: override ehci->hub_control (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: add HSIC support (Torez Smith) [1686205]
- [usb] usb: chipidea: add flag for imx hsic implementation (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Disable CSP for stream OUT ep (Torez Smith) [1686205]
- [usb] USB: serial: mos7840: remove set but not used variables 'number, serial' (Torez Smith) [1686205]
- [usb] USB: serial: option: add HP lt4132 (Torez Smith) [1686205]
- [usb] usb: dwc2: disable power_down on Amlogic devices (Torez Smith) [1686205]
- [usb] xhci: move usb2 get port status link resume handling to its own function (Torez Smith) [1686205]
- [usb] xhci: refactor U0 link state handling in get_port_status (Torez Smith) [1686205]
- [usb] xhci: cleanup code that sets portstatus and portchange bits (Torez Smith) [1686205]
- [usb] xhci: move usb2 speficic bits to own function in get_port_status call (Torez Smith) [1686205]
- [usb] xhci: move usb3 speficic bits to own function in get_port_status call (Torez Smith) [1686205]
- [usb] xhci: remove unused hcd_index() (Torez Smith) [1686205]
- [usb] xhci: move bus_state structure under the xhci_hub structure (Torez Smith) [1686205]
- [usb] xhci: remove the unused sw_lpm_support (Torez Smith) [1686205]
- [usb] Revert "usb: dwc3: pci: Use devm functions to get the phy GPIOs" (Torez Smith) [1686205]
- [usb] USB: gadget: udc: s3c2410_udc: convert to DEFINE_SHOW_ATTRIBUTE (Torez Smith) [1686205]
- [usb] usb: mtu3: fix dbginfo in qmu_tx_zlp_error_handler (Torez Smith) [1686205]
- [usb] usb: dwc3: trace: add missing break statement to make compiler happy (Torez Smith) [1686205]
- [usb] xhci: Prevent U1/U2 link pm states if exit latency is too long (Torez Smith) [1686205]
- [usb] xhci: workaround CSS timeout on AMD SNPS 3.0 xHC (Torez Smith) [1686205]
- [tty] USB: serial: console: fix reported terminal settings (Torez Smith) [1686205]
- [usb] usb: appledisplay: Remove unnecessary spinlock (Torez Smith) [1686205]
- [usb] usb: appledisplay: Set urb transfer_flags to URB_NO_TRANSFER_DMA_MAP (Torez Smith) [1686205]
- [usb] usb: quirk: add no-LPM quirk on SanDisk Ultra Flair device (Torez Smith) [1686205]
- [usb] USB: Fix invalid-free bug in port_over_current_notify() (Torez Smith) [1686205]
- [usb] usb: appledisplay: Add 27" Apple Cinema Display (Torez Smith) [1686205]
- [platform] staging: typec: fusb302: Rename fcs, extcon-name to linux, extcon-name (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Report isoc transfer frame number (Torez Smith) [1686205]
- [include] usb: gadget: Introduce frame_number to usb_request (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Use SIMPLE_DEV_PM_OPS macro (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Remove dummy runtime PM callbacks (Torez Smith) [1686205]
- [usb] usb: dwc2: host: use hrtimer for NAK retries (Torez Smith) [1686205]
- [usb] usb: hub: delay hub autosuspend if USB3 port is still link training (Torez Smith) [1686205]
- [usb] usb: mtu3: clear SOFTCONN when clear USB3_EN if work as HS mode (Torez Smith) [1686205]
- [usb] usb: mtu3: enable SETUPENDISR interrupt (Torez Smith) [1686205]
- [usb] usb: mtu3: fix the issue about SetFeature(U1/U2_Enable) (Torez Smith) [1686205]
- [usb] usb: mtu3: enable hardware remote wakeup from L1 automatically (Torez Smith) [1686205]
- [usb] usb: mtu3: remove QMU checksum (Torez Smith) [1686205]
- [usb] usb/mtu3: power down device ip at setup (Torez Smith) [1686205]
- [usb] usb: dwc2: Disable power down feature on Samsung SoCs (Torez Smith) [1686205]
- [usb] usb: dwc3: Correct the logic for checking TRB full in __dwc3_prepare_one_trb() (Torez Smith) [1686205]
- [usb] usb: dwc3: don't issue no-op trb for stream capable endpoints (Torez Smith) [1686205]
- [usb] usb: dwc3: update stream id in depcmd (Torez Smith) [1686205]
- [usb] USB: serial: mos7840: add a product ID for the new product (Torez Smith) [1686205]
- [usb] USB: serial: mos7840: clean up register handling (Torez Smith) [1686205]
- [usb] usb: gadget: u_ether: fix unsafe list iteration (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: check if dep->frame_number is still valid (Torez Smith) [1686205]
- [usb] USB: omap_udc: fix rejection of out transfers when DMA is used (Torez Smith) [1686205]
- [usb] USB: omap_udc: fix USB gadget functionality on Palm Tungsten E (Torez Smith) [1686205]
- [usb] USB: omap_udc: fix omap_udc_start() on 15xx machines (Torez Smith) [1686205]
- [usb] USB: omap_udc: fix crashes on probe error and module removal (Torez Smith) [1686205]
- [usb] USB: omap_udc: use devm_request_irq() (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: remove unnecessary dev_info() (Torez Smith) [1686205]
- [usb] usb: dwc3: trace: log ep commands in hex (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: return errors from __dwc3_gadget_start_isoc() (Torez Smith) [1686205]
- [usb] usb: core: quirks: add RESET_RESUME quirk for Cherry G230 Stream series (Torez Smith) [1686205]
- [usb] USB: usb-storage: Add new IDs to ums-realtek (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: remove wait_end_transfer (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: move requests to cancelled_list (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: introduce cancelled_list (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: extract dwc3_gadget_ep_skip_trbs() (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: use num_trbs when skipping TRBs on ->dequeue() (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: track number of TRBs per request (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: combine unaligned and zero flags (Torez Smith) [1686205]
- [usb] usb: dwc3: Add workaround for isoc start transfer failure (Torez Smith) [1686205]
- [documentation] usb: dwc3: Add disabling of start_transfer failure quirk (Torez Smith) [1686205]
- [usb] usb: dwc3: Track DWC_usb31 VERSIONTYPE (Torez Smith) [1686205]
- [usb] usb: gadget: f_fs: Allow scatter-gather buffers (Torez Smith) [1686205]
- [usb] usb: gadget: f_fs: Add support for CCID descriptors (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: constify vb2_ops structure (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Accept LPM token when TxFIFO is not empty (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Fix WkupAlert interrupt handler (Torez Smith) [1686205]
- [usb] usb: dwc3: Set default mode for DWC_usb3 v3.30a and higher (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: add a safety connection way for forced_b_device (Torez Smith) [1686205]
- [usb] usb: dwc3: drd: Add support for DR detection through extcon (Torez Smith) [1686205]
- [usb] usb: dwc3: drd: Switch to device property for 'extcon' handling (Torez Smith) [1686205]
- [usb] usb: dwc3: don't log probe deferrals; but do log other error codes (Torez Smith) [1686205]
- [usb] usb: gadget: aspeed-vhub: constify usb_gadget_ops structure (Torez Smith) [1686205]
- [usb] usb: dwc3: Support option to disable USB2 LPM (Torez Smith) [1686205]
- [documentation] usb: dwc3: Add a property to disable USB2 LPM (Torez Smith) [1686205]
- [usb] usb: dwc3: Set GUSB2PHYCFG.ENBLSLPM (Torez Smith) [1686205]
- [usb] usb: dwc3: debugfs: Print/set link state for peripheral mode (Torez Smith) [1686205]
- [usb] usb: dwc3: debugfs: Properly print/set link state for HS (Torez Smith) [1686205]
- [usb] usb: dwc3: debugfs: Dump internal LSP and ep registers (Torez Smith) [1686205]
- [usb] usb: dwc3: debugfs: Print eps Tx/RxFIFO in bytes (Torez Smith) [1686205]
- [usb] usb: dwc3: debugfs: Properly name Tx/RxFIFO (Torez Smith) [1686205]
- [usb] Revert "usb: dwc3: gadget: skip Set/Clear Halt when invalid" (Torez Smith) [1686205]
- [usb] drivers: usb: early: clean up indentation, remove extraneous tabs (Torez Smith) [1686205]
- [usb] USB: ene_usb6250: add missing indentation (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: use rounding when calculating baud rate divisors (Torez Smith) [1686205]
- [usb] USB: serial: f81534: fix reading old/new IC config (Torez Smith) [1686205]
- [usb] usb: cdc-acm: add entry for Hiro (Conexant) modem (Torez Smith) [1686205]
- [usb] usb: xhci: Prevent bus suspend if a port connect change or polling state is detected (Torez Smith) [1686205]
- [usb] usb: core: Fix hub port connection events lost (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: fix ISOC TRB type on unaligned transfers (Torez Smith) [1686205]
- [usb] Revert "usb: gadget: ffs: Fix BUG when userland exits with submitted AIO transfers" (Torez Smith) [1686205]
- [usb] usb: dwc2: pci: Fix an error code in probe (Torez Smith) [1686205]
- [usb] usb: dwc3: Fix NULL pointer exception in dwc3_pci_remove() (Torez Smith) [1686205]
- [usb] USB: serial: mos7840: remove set but not used variables 'st, data1, iflag' (Torez Smith) [1686205]
- [usb] USB: serial: quatech2: remove set but not used variable 'port_priv' (Torez Smith) [1686205]
- [include] USB: remove the unused struct hcd_timeout definition (Torez Smith) [1686205]
- [usb] usb: typec: ucsi: add support for Cypress CCGx (Torez Smith) [1686205]
- [usb] usb: xhci: fix timeout for transition from RExit to U0 (Torez Smith) [1686205]
- [usb] usb: xhci: fix uninitialized completion when USB3 port got wrong status (Torez Smith) [1686205]
- [usb] xhci: Add check for invalid byte size error when UAS devices are connected (Torez Smith) [1686205]
- [usb] xhci: handle port status events for removed USB3 hcd (Torez Smith) [1686205]
- [usb] xhci: Fix leaking USB3 shared_hcd at xhci removal (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: xhci-tegra: Add power-domain details (Torez Smith) [1686205]
- [usb] USB: misc: appledisplay: add 20" Apple Cinema Display (Torez Smith) [1686205]
- [usb] USB: quirks: Add no-lpm quirk for Raydium touchscreens (Torez Smith) [1686205]
- [usb] usb: quirks: Add delay-init quirk for Corsair K70 LUX RGB (Torez Smith) [1686205]
- [usb] USB: Wait for extra delay time after USB_PORT_FEAT_RESET for quirky hub (Torez Smith) [1686205]
- [usb] USB: gadget: udc: fix spelling mistake "intrerrupt" -> "interrupt" (Torez Smith) [1686205]
- [usb] usb: host: remove unnecessary condition check (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: charge current handling for sink during hard reset (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Do not disconnect link for self powered devices (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Properly check last unaligned/zero chain TRB (Torez Smith) [1686205]
- [usb] usb: dwc3: core: Clean up ULPI device (Torez Smith) [1686205]
- [usb] usb: phy: ab8500: silence some uninitialized variable warnings (Torez Smith) [1686205]
- [usb] usb: xhci: tegra: Add genpd support (Torez Smith) [1686205]
- [usb] usb: xhci: tegra: Power-off power-domains on removal (Torez Smith) [1686205]
- [usb] usbip:vudc: BUG kmalloc-2048 (Not tainted): Poison overwritten (Torez Smith) [1686205]
- [tools] usbip: tools: fix atoi() on non-null terminated string (Torez Smith) [1686205]
- [usb] USB: misc: appledisplay: fix backlight update_status return code (Torez Smith) [1686205]
- [usb] USB: fix the usbfs flag sanitization for control transfers (Torez Smith) [1686205]
- [documentation] usb: host: add DT bindings for faraday fotg2 (Torez Smith) [1686205]
- [usb] usb: host: ohci-at91: fix request of irq for optional gpio (Torez Smith) [1686205]
- [usb] usb: xhci: pci: Enable Intel USB role mux on Apollo Lake platforms (Torez Smith) [1686205]
- [usb] usb: roles: intel_xhci: Fix Unbalanced pm_runtime_enable (Torez Smith) [1686205]
- [usb] cdc-acm: correct counting of UART states in serial state notification (Torez Smith) [1686205]
- [usb] cdc-acm: do not reset notification buffer index upon urb unlinking (Torez Smith) [1686205]
- [usb] cdc-acm: fix race between reset and control messaging (Torez Smith) [1686205]
- [usb] usb: usbip: Fix BUG: KASAN: slab-out-of-bounds in vhci_hub_control() (Torez Smith) [1686205]
- [usb] usb/early: remove set but not used variable 'remain_length' (Torez Smith) [1686205]
- [usb] usb: typec: Fix copy/paste on typec_set_vconn_role() kerneldoc (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Report back negotiated PPS voltage and current (Torez Smith) [1686205]
- [usb] USB: core: remove set but not used variable 'udev' (Torez Smith) [1686205]
- [usb] usb: core: fix memory leak on port_dev_path allocation (Torez Smith) [1686205]
- [usb] USB: net2280: Remove ->disconnect() callback from net2280_pullup() (Torez Smith) [1686205]
- [usb] usb: dwc2: disable power_down on rockchip devices (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: add support for r8a77990 (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usb3: add bindings for r8a77990 (Torez Smith) [1686205]
- [usb] USB: serial: cypress_m8: remove set but not used variable 'iflag' (Torez Smith) [1686205]
- [usb] USB: serial: cypress_m8: fix interrupt-out transfer length (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: add support for FT232R CBUS gpios (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: fix gpio name collisions (Torez Smith) [1686205]
- [netdrv] net: usbnet: make driver_info const (Torez Smith) [1686205]
- [usb] usb: typec: remove set but not used variables 'snk_ma, min_mv' (Torez Smith) [1686205]
- [usb] usb: export firmware port location in sysfs (Torez Smith) [1686205]
- [usb] usb: hub: try old enumeration scheme first for high speed devices (Torez Smith) [1686205]
- [documentation] dt-bindings: usb-xhci: Document r8a7744 support (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: Add support for r8a7744 (Torez Smith) [1686205]
- [usb] usb: typec: tcpm: Fix APDO PPS order checking to be based on voltage (Torez Smith) [1686205]
- [tools] usbip: fix vhci_hcd controller counting (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: Fix b-device mode for "workaround" (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Add handler for WkupAlert interrupt (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: enable WKUP_ALERT interrupt (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Program GREFCLK register (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: Add parameters for GREFCLK register (Torez Smith) [1686205]
- [usb] usb: dwc2: Add definitions for new registers (Torez Smith) [1686205]
- [usb] usb: dwc2: Update target (u)frame calculation (Torez Smith) [1686205]
- [usb] usb: dwc2: Add dwc2_gadget_dec_frame_num_by_one() function (Torez Smith) [1686205]
- [usb] usb: dwc2: Add core parameter for service interval support (Torez Smith) [1686205]
- [usb] usb: dwc2: Update registers definitions to support service interval (Torez Smith) [1686205]
- [usb] usb: gadget: f_uac2: disable IN/OUT ep if unused (Torez Smith) [1686205]
- [usb] USB: gadget core: Issue ->disconnect() callback from usb_gadget_disconnect() (Torez Smith) [1686205]
- [usb] usb: dwc3: Fix spelling of 'optimizations' (Torez Smith) [1686205]
- [usb] usb: gadget: atmel: remove pointless retrieval of DT name property (Torez Smith) [1686205]
- [usb] usb: gadget: fsl_udc_core: fixup struct_udc_setup documentation (Torez Smith) [1686205]
- [usb] usb: gadget: fsl_udc_core: check allocation return value and cleanup on failure (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Check ENBLSLPM before sending ep command (Torez Smith) [1686205]
- [usb] usb: dwc2: fix unbalanced use of external vbus-supply (Torez Smith) [1686205]
- [usb] usb: dwc2: fix call to vbus supply exit routine, call it unlocked (Torez Smith) [1686205]
- [usb] usb: dwc2: fix a race with external vbus supply (Torez Smith) [1686205]
- [usb] usb: dwc2: get optional vbus-supply regulator once (Torez Smith) [1686205]
- [usb] usb: dwc3: add EXTCON dependency for qcom (Torez Smith) [1686205]
- [usb] usb: gadget: udc: atmel: handle at91sam9rl PMC (Torez Smith) [1686205]
- [usb] usb: gadget: udc: fotg210-udc: Fix a sleep-in-atomic-context bug in fotg210_get_status() (Torez Smith) [1686205]
- [usb] usb: dwc2: Disable all EP's on disconnect (Torez Smith) [1686205]
- [documentation] usb: dwc3: exynos: Add support for Exynos5433 variant with all clocks (Torez Smith) [1686205]
- [usb] usb: dwc3: exynos: Rework clock handling and prepare for new variants (Torez Smith) [1686205]
- [usb] usb: dwc3: exynos: Remove dead code (Torez Smith) [1686205]
- [usb] usb: gadget: udc: Remove unnecessary parentheses (Torez Smith) [1686205]
- [usb] usb: dwc2: remove set but unused variable (Torez Smith) [1686205]
- [usb] usb: gadget: fix spelling mistakeis "queing" -> "queuing" (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: resume USB3 roothub first (Torez Smith) [1686205]
- [usb] xhci: Add missing CAS workaround for Intel Sunrise Point xHCI (Torez Smith) [1686205]
- [usb] usb: cdc_acm: Do not leak URB buffers (Torez Smith) [1686205]
- [usb] usb: usbtmc: uninitialized symbol 'actual' in usbtmc_ioctl_abort_bulk_in_tag (Torez Smith) [1686205]
- [usb] usb: usbtmc: uninitialized symbol 'actual' in usbtmc_ioctl_clear (Torez Smith) [1686205]
- [usb] usb: usbtmc: uninitialized symbol 'actual' in usbtmc_read (Torez Smith) [1686205]
- [usb] usb: usbtmc: Fix memory leak in usbtmc_ioctl_request (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: add support for R-Car E3 (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: add bindings for r8a77990 (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: rcar3: Use OTG mode for R-Car D3 (Torez Smith) [1686205]
- [usb] Revert "usb: renesas_usbhs: set the mode by using extcon state for non-otg channel" (Torez Smith) [1686205]
- [usb] Revert "usb: renesas_usbhs: add extcon notifier to set mode for non-otg channel" (Torez Smith) [1686205]
- [usb] usb: core: added uevent for over-current (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Resolve fixed power role contract setup (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Correct spelling mistake for toggling state (Torez Smith) [1686205]
- [usb] xhci: Avoid USB autosuspend when resuming USB2 ports (Torez Smith) [1686205]
- [usb] usb: xhci: tegra: Firmware header is little endian (Torez Smith) [1686205]
- [usb] xhci: Use soft retry to recover faster from transaction errors (Torez Smith) [1686205]
- [usb] usb: host: xhci-plat: add platform TPL support (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: supports SSP without external USB3 gen2 hub (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: supports bandwidth scheduling with multi-TT (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: improve bandwidth scheduling (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: fix ISOC error when interval is zero (Torez Smith) [1686205]
- [usb] usb: xhci-mtk: use maximum ESIT payload of endpiont context (Torez Smith) [1686205]
- [usb] usb: host: Replace empty define with do while (Torez Smith) [1686205]
- [usb] USB: serial: ftdi_sio: implement GPIO support for FT-X devices (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Use u to print unsigned int values (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Simplify attributes macros (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Fix operation on big endian platforms (Torez Smith) [1686205]
- [uapi] usb: video: Fix endianness mismatches in descriptor structures (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Remove uvc_set_trace_param() function (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Replace plain printk() with dev_*() (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Only halt video streaming endpoint in bulk mode (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Factor out video USB request queueing (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Sort frame intervals upon writing (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Prevent format changes after linking header (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Add bFrameIndex attributes (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Add bFormatIndex attributes (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Add interface number attributes (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Allocate groups dynamically (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Drop leaked references to config items (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: dwc2: add description for px30 (Torez Smith) [1686205]
- [usb] USB: serial: simple: add Motorola Tetra MTP6550 id (Torez Smith) [1686205]
- [usb] USB: serial: cypress_m8: fix spelling mistake "retreiving" -> "retrieving" (Torez Smith) [1686205]
- [usb] USB: STORAGE: ISD200 Fixed coding style issue "space required in for loop" (Torez Smith) [1686205]
- [usb] usb: typec: Group all TCPCI/TCPM code together (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: reorganizing the probe function a little (Torez Smith) [1686205]
- [usb] usb: typec: class: Don't use port parent for getting mux handles (Torez Smith) [1686205]
- [usb] usb: typec: mux: Take care of driver module reference counting (Torez Smith) [1686205]
- [usb] usb: core: safely deal with the dynamic quirk lists (Torez Smith) [1686205]
- [usb] usb: roles: Take care of driver module reference counting (Torez Smith) [1686205]
- [usb] usb: phy: mxs: fix spelling mistake "stardard" -> "standard" (Torez Smith) [1686205]
- [usb] usb: host: fotg2: Fix potential NULL dereference (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Add multiple clocks management (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: add clock-names property (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Add reset_control (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: ohci: Add clocks description for R-Car Gen3 (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: ehci: Add clocks description for R-Car Gen3 (Torez Smith) [1686205]
- [usb] usbcore: Select UAC3 configuration for audio if present (Torez Smith) [1686205]
- [documentation] usb: gadget: udc: renesas_usb3: Add r8a774a1 support (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: renesas_usbhs: Add r8a774a1 support (Torez Smith) [1686205]
- [documentation] dt-bindings: usb-xhci: Add r8a774a1 support (Torez Smith) [1686205]
- [documentation] dt-bindings: ehci-mv: add bindings (Torez Smith) [1686205]
- [usb] USB: EHCI: ehci-mv: add DT support (Torez Smith) [1686205]
- [usb] USB: EHCI: ehci-mv: use phy-pxa-usb (Torez Smith) [1686205]
- [usb] USB: EHCI: ehci-mv: remove private_init (Torez Smith) [1686205]
- [usb] USB: EHCI: make ehci-mv a separate driver (Torez Smith) [1686205]
- [usb] usb: usbtmc: Remove sysfs group TermChar and auto_abort (Torez Smith) [1686205]
- [usb] usb: usbtmc: Fix split quoted string in debug message (Torez Smith) [1686205]
- [usb] usb: usbtmc: Remove redundant macro USBTMC_SIZE_IOBUFFER (Torez Smith) [1686205]
- [usb] usb: usbtmc: Remove redundant code (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl USBTMC_IOCTL_API_VERSION (Torez Smith) [1686205]
- [usb] usb: usbtmc: Replace USBTMC_TIMEOUT macros for control messages (Torez Smith) [1686205]
- [usb] usb: usbtmc: Fix ioctl USBTMC_IOCTL_ABORT_BULK_OUT (Torez Smith) [1686205]
- [usb] usb: usbtmc: Fix ioctl USBTMC_IOCTL_ABORT_BULK_IN (Torez Smith) [1686205]
- [usb] usb: usbtmc: Fix ioctl USBTMC_IOCTL_CLEAR (Torez Smith) [1686205]
- [usb] usb: usbtmc: Optimize usbtmc_read (Torez Smith) [1686205]
- [usb] usb: usbtmc: Optimize usbtmc_write (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl USBTMC_IOCTL_AUTO_ABORT (Torez Smith) [1686205]
- [usb] usb: usbtmc: add ioctl USBTMC_IOCTL_MSG_IN_ATTR (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl USBTMC488_IOCTL_WAIT_SRQ (Torez Smith) [1686205]
- [usb] usb: usbtmc: Fix suspend/resume (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl USBTMC_IOCTL_CLEANUP_IO (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl USBTMC_IOCTL_CANCEL_IO (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl for vendor specific read (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl USBTMC_IOCTL_WRITE_RESULT (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl for vendor specific write (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl for generic requests on control (Torez Smith) [1686205]
- [usb] usb: typec: fusb302: Populate tcpc fwnode for TCPM property handling (Torez Smith) [1686205]
- [documentation] dt-bindings: usb: fusb302: Use usb-connector bindings for configuration (Torez Smith) [1686205]
- [documentation] dt-bindings: connector: Add support for USB-PD PPS APDOs to bindings (Torez Smith) [1686205]
- [usb] USB: handle NULL config in usb_find_alt_setting() (Torez Smith) [1686205]
- [usb] USB: fix error handling in usb_driver_claim_interface() (Torez Smith) [1686205]
- [usb] USB: remove LPM management from usb_driver_claim_interface() (Torez Smith) [1686205]
- [usb] USB: usbdevfs: restore warning for nonsensical flags (Torez Smith) [1686205]
- [usb] USB: usbdevfs: sanitize flags more (Torez Smith) [1686205]
- [usb] Revert "usb: cdc-wdm: Fix a sleep-in-atomic-context bug in service_outstanding_interrupt()" (Torez Smith) [1686205]
- [usb] usb: musb: dsps: do not disable CPPI41 irq in driver teardown (Torez Smith) [1686205]
- [usb] usb: chipidea: Fix otg event handler (Torez Smith) [1686205]
- [usb] usb: chipidea: Prevent unbalanced IRQ disable (Torez Smith) [1686205]
- [documentation] doc: usb: ci-hdrc-usb2: Add pinctrl properties definition (Torez Smith) [1686205]
- [usb] usb: chipidea: Add dynamic pinctrl selection (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: make MODULE_LICENCE and SPDX-identifier match (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: enable OTG overcurrent in case USB subsystem is already started (Torez Smith) [1686205]
- [usb] usb: chipidea: imx: do not use preprocessor conditionals for PM (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Add section header comments (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Don't wrap groups unnecessarily (Torez Smith) [1686205]
- [usb] mos7720: bury dead TIOCM... in ->ioctl() (Torez Smith) [1686205]
- [usb] USB: serial: option: add two-endpoints device-id flag (Torez Smith) [1686205]
- [usb] USB: serial: option: improve Quectel EP06 detection (Torez Smith) [1686205]
- [usb] Revert "cdc-acm: implement put_char() and flush_chars()" (Torez Smith) [1686205]
- [usb] usb: Change usb_of_get_companion_dev() place to usb/common (Torez Smith) [1686205]
- [usb] usb: xhci: fix interrupt transfer error happened on MTK platforms (Torez Smith) [1686205]
- [usb] usb: core: phy: clean up return value check about devm_of_phy_get_by_index() (Torez Smith) [1686205]
- [usb] usb: mtu3: disable vbus rise/fall interrupts of ltssm (Torez Smith) [1686205]
- [usb] USB: wusbcore: Switch to bitmap_zalloc() (Torez Smith) [1686205]
- [usb] usb: misc: fix obsolete function (Torez Smith) [1686205]
- [usb] usb: iowarrior: replace kmalloc with kmalloc_array (Torez Smith) [1686205]
- [usb] USB: OHCI: Remove USB bus reset delay from OHCI handover code (Torez Smith) [1686205]
- [usb] usb: host: fotg2: add silicon clock handling (Torez Smith) [1686205]
- [usb] USB: typec: fsusb302: remove unused variables snk_pdo and toggling_mode_name (Torez Smith) [1686205]
- [usb] usb storage: remove inherited SCSI dependency for USB_STORAGE_ENE_UB6250 (Torez Smith) [1686205]
- [usb] usb storage: group dependent USB storage Kconfig entries together (Torez Smith) [1686205]
- [usb] USB: Removing NULL check for pool since dma_pool_destroy is safe (Torez Smith) [1686205]
- [usb] usb: cdc-wdm: Fix a sleep-in-atomic-context bug in service_outstanding_interrupt() (Torez Smith) [1686205]
- [usb] usb: misc: uss720: Fix two sleep-in-atomic-context bugs (Torez Smith) [1686205]
- [usb] usb: host: u132-hcd: Fix a sleep-in-atomic-context bug in u132_get_frame() (Torez Smith) [1686205]
- [usb] usb: Avoid use-after-free by flushing endpoints early in usb_set_interface() (Torez Smith) [1686205]
- [usb] usb/typec: fix kernel-doc notation warning for typec_match_altmode (Torez Smith) [1686205]
- [usb] usb: Don't die twice if PCI xhci host is not responding in resume (Torez Smith) [1686205]
- [usb] usb: mtu3: fix error of xhci port id when enable U3 dual role (Torez Smith) [1686205]
- [usb] usb: uas: add support for more quirk flags (Torez Smith) [1686205]
- [usb] USB: Add quirk to support DJI CineSSD (Torez Smith) [1686205]
- [usb] usb: typec: fix kernel-doc parameter warning (Torez Smith) [1686205]
- [usb] usb/dwc3/gadget: fix kernel-doc parameter warning (Torez Smith) [1686205]
- [usb] USB: yurex: Check for truncation in yurex_read() (Torez Smith) [1686205]
- [usb] USB: yurex: Fix buffer over-read in yurex_write() (Torez Smith) [1686205]
- [usb] usb: host: xhci-plat: Iterate over parent nodes for finding quirks (Torez Smith) [1686205]
- [usb] xhci: Fix use after free for URB cancellation on a reallocated endpoint (Torez Smith) [1686205]
- [usb] USB: add quirk for WORLDE Controller KS49 or Prodipe MIDI 49C USB controller (Torez Smith) [1686205]
- [usb] usb: dwc2: Fix call location of dwc2_check_core_endianness (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Fix return value check in dwc3_byt_enable_ulpi_refclock() (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: fix maxpacket size of ep0 (Torez Smith) [1686205]
- [usb] usb: gadget: fotg210-udc: Fix memory leak of fotg210->ep (Torez Smith) [1686205]
- [usb] USB: net2280: Fix erroneous synchronization change (Torez Smith) [1686205]
- [usb] usb: dwc3: of-simple: avoid unused function warnings (Torez Smith) [1686205]
- [usb] USB: serial: ti_usb_3410_5052: fix array underflow in completion handler (Torez Smith) [1686205]
- [usb] USB: serial: io_ti: fix array underflow in completion handler (Torez Smith) [1686205]
- [usb] USB: serial: pl2303: add a new device id for ATEN (Torez Smith) [1686205]
- [usb] usb: renesas_usbhs: Kconfig: convert to SPDX identifiers (Torez Smith) [1686205]
- [usb] usb: dwc3: gadget: Check MaxPacketSize from descriptor (Torez Smith) [1686205]
- [usb] usb: dwc2: Turn on uframe_sched on "stm32f4x9_fsotg" platforms (Torez Smith) [1686205]
- [usb] usb: dwc2: Turn on uframe_sched on "amlogic" platforms (Torez Smith) [1686205]
- [usb] usb: dwc2: Turn on uframe_sched on "his" platforms (Torez Smith) [1686205]
- [usb] usb: dwc2: Turn on uframe_sched on "bcm" platforms (Torez Smith) [1686205]
- [usb] usb: dwc2: gadget: ISOC's starting flow improvement (Torez Smith) [1686205]
- [usb] usb: dwc2: Make dwc2_readl/writel functions endianness-agnostic (Torez Smith) [1686205]
- [usb] usb: dwc3: core: Enable AutoRetry feature in the controller (Torez Smith) [1686205]
- [usb] usb: dwc3: Set default mode for dwc_usb31 (Torez Smith) [1686205]
- [usb] usb: gadget: udc: renesas_usb3: Add register of usb role switch (Torez Smith) [1686205]
- [usb] usb: dwc2: replace ioread32/iowrite32_rep with dwc2_readl/writel_rep (Torez Smith) [1686205]
- [usb] usb: dwc2: Modify dwc2_readl/writel functions prototype (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Intel Merrifield can be host (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Supply device properties via driver data (Torez Smith) [1686205]
- [documentation] arm64: dts: dwc3: description of incr burst type (Torez Smith) [1686205]
- [usb] usb: dwc3: Enable undefined length INCR burst type (Torez Smith) [1686205]
- [usb] usb: dwc3: add global soc bus configuration reg0 (Torez Smith) [1686205]
- [usb] usb: dwc3: Describe 'wakeup_work' field of struct dwc3_pci (Torez Smith) [1686205]
- [usb] USB: option: add support for DW5821e (Torez Smith) [1686205]
- [usb] usb: dwc3: change stream event enable bit back to 13 (Torez Smith) [1686205]
- [usb] usb: dwc3: of-simple: reset host controller at suspend/resume (Torez Smith) [1686205]
- [usb] usb: gadget: storage: Remove reference counting (Torez Smith) [1686205]
- [usb] usb: gadget: storage: Add error handling for no memory (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Use devm functions to get the phy GPIOs (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Enable ULPI Refclk on platforms where the firmware does not (Torez Smith) [1686205]
- [usb] usb: dwc3: pci: Add GPIO lookup table on platforms without ACPI GPIO resources (Torez Smith) [1686205]
- [usb] USB: gadget: Document that certain ep operations can be called in interrupt context (Torez Smith) [1686205]
- [usb] usb: gadget: configfs: avoid spaces for indentation (Torez Smith) [1686205]
- [usb] usb: dwc3: Add a glue driver for Synopsys HAPS platform (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Expose configuration name through video node (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: configfs: Move function to avoid forward declaration (Torez Smith) [1686205]
- [usb] usb: dwc2: Move dwc2_readl/writel functions after hsotg structure (Torez Smith) [1686205]
- [usb] usb: gadget: tcm: fix spelling mistake: "Manufactor" -> "Manufacturer" (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Move trace parameter to function module (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Minimize #include in headers (Torez Smith) [1686205]
- [usb] usb: gadget: uvc: Move userspace API definition to public header (Torez Smith) [1686205]
- [usb] usb: host: exynos: Remove support for Exynos5440 (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add support for 32 bit compat applications (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl for termination character (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl for EOM bit (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctl for trigger (Torez Smith) [1686205]
- [usb] usb: usbtmc: Add ioctls to set/get usb timeout (Torez Smith) [1686205]
- [usb] usb: usbtmc: use consistent timeout error (Torez Smith) [1686205]
- [usb] usb: usbtmc: Support Read Status Byte with SRQ per file (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: implement GPIO support for CP2102N (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: improve line-speed handling for CP2104 and CP2105 (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: generalise CP2102N line-speed handling (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: improve baudrate support for CP2102N (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: honour device-type maximum line speed (Torez Smith) [1686205]
- [usb] USB: serial: cp210x: make line-speed quantisation data driven (Torez Smith) [1686205]
- [usb] USB: serial: iuu_phoenix: drop redundant input-speed re-encoding (Torez Smith) [1686205]
- [usb] USB: serial: iuu_phoenix: drop unused driver-data baud rate (Torez Smith) [1686205]
- [usb] USB: serial: mos7720: remove redundant variables iflag, mask and serial (Torez Smith) [1686205]
- [documentation] dt-bindings: usb-xhci: Add r8a77990 support (Torez Smith) [1686205]
- [usb] usb: host: ehci-sched: remove redundant pointer dev (Torez Smith) [1686205]
- [usb] usb: host: u132-hcd: remove redundant variable num_ports (Torez Smith) [1686205]
- [usb] USB: host: whci: remove redundant variable t (Torez Smith) [1686205]
- [usb] usb: xhci: dbc: remove redundant pointer dbc (Torez Smith) [1686205]
- [usb] usb: isp1760: remove redundant variable 'selector' (Torez Smith) [1686205]
- [usb] usb-misc: sisusbvga: remove redundant variable modey (Torez Smith) [1686205]
- [usb] usb: misc: uss720: remove redundant pointer usbdev (Torez Smith) [1686205]
- [usb] usb: usbip: remove redundant pointer ep (Torez Smith) [1686205]
- [usb] USB: serial: kl5kusb105: remove KLSI device id (Torez Smith) [1686205]
- [usb] usb: host: xhci-rcar: Add a condition check about PLL active (Torez Smith) [1686205]
- [usb] usb: host: xhci-rcar: Simplify getting the firmware name for R-Car Gen3 (Torez Smith) [1686205]
- [usb] usb: host: xhci-plat: add firmware_name for R-Car Gen3 (Torez Smith) [1686205]
- [usb] usb: typec: avoid format-overflow warning (Torez Smith) [1686205]
- [usb] usb: typec: unlock dp->lock on error exit path, and also zero ret if successful (Torez Smith) [1686205]
- [usb] usb: typec: fix dereference before null check on adev (Torez Smith) [1686205]
- [usb] usb: usbtest: use irqsave() in USB's complete callback (Torez Smith) [1686205]
- [usb] USB: serial: kobil_sct: add missing version error handling (Torez Smith) [1686205]
- [usb] USB: serial: kobil_sct: fix modem-status error handling (Torez Smith) [1686205]
- [usb] usb: simplify usbport trigger (Torez Smith) [1686205]
- [include] device connection: Add fwnode member to struct device_connection (Torez Smith) [1686205]

* Sun Apr 12 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.7.el8]
- [security] KEYS: reaching the keys quotas correctly (Vladis Dronov) [1820405]
- [security] KEYS: allow reaching the keys quotas exactly (Vladis Dronov) [1820405]
- [infiniband] RDMA/core: Ensure security pkey modify is not lost (Kamal Heib) [1786604]
- [infiniband] IB/hfi1: Ensure pq is not left on waitlist (Kamal Heib) [1786604 1739282]
- [infiniband] RDMA/mad: Do not crash if the rdma device does not have a umad interface (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Fix missing error check on dev_set_name() (Kamal Heib) [1786604]
- [infiniband] RDMA/nl: Do not permit empty devices names during RDMA_NLDEV_CMD_NEWLINK/SET (Kamal Heib) [1786604]
- [infiniband] RDMA/iwcm: Fix iwcm work deallocation (Kamal Heib) [1786604]
- [infiniband] RDMA/siw: Fix failure handling during device creation (Kamal Heib) [1786604]
- [infiniband] RDMA/nldev: Fix crash when set a QP to a new counter but QPN is missing (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Fix protection fault in ib_mr_pool_destroy (Kamal Heib) [1786604]
- [infiniband] IB/hfi1, qib: Ensure RCU is locked when accessing list (Kamal Heib) [1786604 1739282]
- [infiniband] RDMA/core: Fix pkey and port assignment in get_new_pps (Kamal Heib) [1786604]
- [infiniband] RMDA/cm: Fix missing ib_cm_destroy_id() in ib_cm_insert_listen() (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Fix use of logical OR in get_new_pps (Kamal Heib) [1786604]
- [infiniband] Revert "RDMA/cma: Simplify rdma_resolve_addr() error flow" (Kamal Heib) [1786604]
- [net] xprtrdma: Fix DMA scatter-gather list mapping imbalance (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Fix protection fault in get_pkey_idx_qp_list (Kamal Heib) [1786604]
- [infiniband] RDMA/rxe: Fix soft lockup problem due to using tasklets in softirq (Kamal Heib) [1786604]
- [infiniband] IB/umad: Fix kernel crash while unloading ib_umad (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Add missing list deletion on freeing event queue (Kamal Heib) [1786604]
- [infiniband] RDMA/siw: Remove unwanted WARN_ON in siw_cm_llp_data_ready() (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Fix invalid memory access in spec_filter_size (Kamal Heib) [1786604]
- [infiniband] IB/rdmavt: Reset all QPs when the device is shut down (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Close window for pq and request coliding (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Acquire lock to release TID entries when user file is closed (Kamal Heib) [1786604 1739282]
- [infiniband] IB/umem: use get_user_pages_fast() to pin DMA pages (Kamal Heib) [1786604]
- [infiniband] RDMA/efa: Mask access flags with the correct optional range (Kamal Heib) [1786604]
- [infiniband] RDMA/cma: Fix unbalanced cm_id reference count during address resolve (Kamal Heib) [1786604]
- [infiniband] RDMA/umem: Fix ib_umem_find_best_pgsz() (Kamal Heib) [1786604]
- [infiniband] IB/hfi1: Fix logical condition in msix_request_irq (Kamal Heib) [1786604 1739282]
- [infiniband] RDMA/cm: Remove CM message structs (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Use IBA functions for complex structure members (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Use IBA functions for simple structure members (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Use IBA functions for swapping get/set acessors (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Use IBA functions for simple get/set acessors (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Add SET/GET implementations to hide IBA wire format (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Add accessors for CM_REQ transport_type (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Ensure that rdma_user_mmap_entry_remove() is a fence (Kamal Heib) [1786604]
- [rdma] RDMA/uverbs: Add new relaxed ordering memory region access flag (Kamal Heib) [1786604]
- [infiniband] RDMA/efa: Allow passing of optional access flags for MR registration (Kamal Heib) [1786604]
- [rdma] RDMA/core: Add optional access flags range (Kamal Heib) [1786604]
- [rdma] RDMA/uverbs: Verify MR access flags (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Remove ucontext_lock from the uverbs_destry_ufile_hw() path (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Add UVERBS_METHOD_ASYNC_EVENT_ALLOC (Kamal Heib) [1786604]
- [infiniband] IB/srp: Never use immediate data if it is disabled by a user (Kamal Heib) [1786604]
- [infiniband] RDMA/rxe: Compute the maximum sges and inline size based on the WQE size (Kamal Heib) [1786604]
- [infiniband] Introduce maximum WQE size to check limits (Kamal Heib) [1786604]
- [infiniband] RDMA/efa: Remove unused ucontext parameter from efa_qp_user_mmap_entries_remove (Kamal Heib) [1786604]
- [infiniband] RDMA/efa: Remove {} brackets from single statement if (Kamal Heib) [1786604]
- [infiniband] RDMA/efa: Device definitions documentation updates (Kamal Heib) [1786604]
- [net] xprtrdma: DMA map rr_rdma_buf as each rpcrdma_rep is created (Kamal Heib) [1786604]
- [net] xprtrdma: Destroy reps from previous connection instance (Kamal Heib) [1786604]
- [net] xprtrdma: Destroy rpcrdma_rep when Receive is flushed (Kamal Heib) [1786604]
- [net] xprtrdma: Allocate and map transport header buffers at connect time (Kamal Heib) [1786604]
- [net] xprtrdma: Refactor frwr_is_supported (Kamal Heib) [1786604]
- [net] xprtrdma: Eliminate per-transport "max pages" (Kamal Heib) [1786604]
- [net] xprtrdma: Refactor initialization of ep->rep_max_requests (Kamal Heib) [1786604]
- [net] xprtrdma: Make sendctx queue lifetime the same as connection lifetime (Kamal Heib) [1786604]
- [net] xprtrdma: Eliminate ri_max_send_sges (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Use READ_ONCE for ib_ufile.async_file (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Make ib_uverbs_async_event_file into a uobject (Kamal Heib) [1786604]
- [rdma] RDMA/core: Remove the ufile arg from rdma_alloc_begin_uobject (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Simplify type usage for ib_uverbs_async_handler() (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Do not erase the type of ib_wq.uobject (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Do not erase the type of ib_srq.uobject (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Do not erase the type of ib_qp.uobject (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Do not erase the type of ib_cq.uobject (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Make ib_ucq_object use ib_uevent_object (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Do not allow alloc_commit to fail (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Simplify destruction of FD uobjects (Kamal Heib) [1786604]
- [infiniband] RDMA/mlx5: Use RCU and direct refcounts to keep memory alive (Kamal Heib) [1786604]
- [infiniband] RDMA/uverbs: Remove needs_kfree_rcu from uverbs_obj_type_class (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Remove err in iw_query_port (Kamal Heib) [1786604]
- [infiniband] IB/hfi1: Add RcvShortLengthErrCnt to hfi1stats (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Add software counter for ctxt0 seq drop (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Return void in packet receiving functions (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Decouple IRQ name from type (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Create API for auto activate (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: IB/hfi1: Add an API to handle special case drop (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Move common receive IRQ code to function (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Add fast and slow handlers for receive context (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Move chip specific functions to chip.c (Kamal Heib) [1786604 1739282]
- [infiniband] RDMA/core: Fix locking in ib_uverbs_event_read (Kamal Heib) [1786604]
- [infiniband] IB/core: Fix build failure without hugepages (Kamal Heib) [1786604]
- [infiniband] IB/core: Rename event_handler_lock to qp_open_list_lock (Kamal Heib) [1786604]
- [infiniband] IB/core: Cut down single member ib_cache structure (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Add trace points to follow MR allocation (Kamal Heib) [1786604]
- [infiniband] RDMA/core: Trace points for diagnosing completion queue issues (Kamal Heib) [1786604]
- [infiniband] RDMA/cma: Add trace points in RDMA Connection Manager (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Delete unused CM ARP functions (Kamal Heib) [1786604]
- [infiniband] RDMA/cm: Delete unused CM LAP functions (Kamal Heib) [1786604]
- [infiniband] RDMA/rxe: Fix error type of mmap_offset (Kamal Heib) [1786604]
- [infiniband] IB/iser: use true,false for bool variable (Kamal Heib) [1786604]
- [infiniband] IB/hfi1: use true,false for bool variable (Kamal Heib) [1786604 1739282]
- [infiniband] RDMA/siw: use true,false for bool variable (Kamal Heib) [1786604]
- [infiniband] IB/core: Fix ODP with IB_ACCESS_HUGETLB handling (Kamal Heib) [1786604]
- [infiniband] IB/core: Fix ODP get user pages flow (Kamal Heib) [1786604]
- [infiniband] IB/rdmavt: Correct comments in rdmavt_qp.h header (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: List all receive contexts from debugfs (Kamal Heib) [1786604 1739282]
- [infiniband] IB/hfi1: Add accessor API routines to access context members (Kamal Heib) [1786604 1739282]
- [infiniband] RDMA/cm: Use RCU synchronization mechanism to protect cm_id_private xa_load() (Kamal Heib) [1786604]
- [infiniband] RDMA/srpt: Remove unnecessary assertion in srpt_queue_response (Kamal Heib) [1786604]
- [infiniband] RDMA/netlink: Do not always generate an ACK for some netlink operations (Kamal Heib) [1786604]
- [infiniband] RDMA/siw: Simplify QP representation (Kamal Heib) [1786604]
- [infiniband] RDMA/qedr: Add kernel capability flags for dpm enabled mode (Kamal Heib) [1786604]
- [platform] platform/x86: intel_pmc_core: Add Intel Tiger Lake support (Alexander Beregalov) [1783390]
- [platform] platform/x86: intel_pmc_core: Create platform dependent bitmap structs (Alexander Beregalov) [1783390]
- [platform] platform/x86: intel_pmc_core: Clean up: Remove comma after the termination line (Alexander Beregalov) [1783390]
- [pinctrl] pinctrl: tigerlake: Tiger Lake uses _HID enumeration (David Arcari) [1773772]
- [pinctrl] pinctrl: sunrisepoint: Add Coffee Lake-S ACPI ID (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Pass irqchip when adding gpiochip (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Add GPIO <-> pin mapping ranges via callback (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Replace WARN with dev_info_once when setting direct-irq pin to output (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Do not clear IRQ flags on direct-irq enabled pins (David Arcari) [1773772]
- [pinctrl] pinctrl: sunrisepoint: Add missing Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Reuse struct intel_pinctrl in the driver (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Use local variable to keep device pointer (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Keep pointer to struct device instead of its container (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Share struct intel_pinctrl for wider use (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Use GPIO direction definitions (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Use GPIO direction definitions (David Arcari) [1773772]
- [include] gpio: Add definition for GPIO direction (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Move IRQ valid mask initialization to a dedicated callback (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Group GPIO IRQ chip initialization (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Allocate IRQ chip dynamic (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Pass irqchip when adding gpiochip (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Add GPIO <-> pin mapping ranges via callback (David Arcari) [1773772]
- [gpio] gpiolib: Introduce ->add_pin_ranges() callback (David Arcari) [1773772]
- [gpio] gpiolib: Initialize the hardware with a callback (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Update North Community pin list (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Really serialize all register accesses (David Arcari) [1773772]
- [pinctrl] pinctrl: lewisburg: Update pin list according to v1.1v6 (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Missed type change to unsigned int (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Add Intel Tiger Lake pin controller support (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Use helper to restore register values on ->resume() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Drop level from warning to debug in intel_restore_hostown() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Introduce intel_restore_intmask() helper (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Introduce intel_restore_hostown() helper (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Introduce intel_restore_padcfg() helper (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Avoid potential glitches if pin is in GPIO mode (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Allocate IRQ chip dynamic (David Arcari) [1773772]
- [pinctrl] gpio: Initialize the irqchip valid_mask with a callback (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: mark intel_pin_to_gpio __maybe_unused (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: remap the pin number to gpio offset for irq enabled pin (David Arcari) [1773772]
- [pinctrl] pinctrl: denverton: Update pin names according to v1.08 (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Remove dev_err() usage after platform_get_irq() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Use NSEC_PER_USEC for debounce calculus (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Re-use data structures from pinctrl-intel.h (part 2) (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Remove default Interrupt Status offset (David Arcari) [1773772]
- [pinctrl] pinctrl: lewisburg: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: denverton: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: sunrisepoint: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: icelake: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: cannonlake: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: broxton: Provide Interrupt Status register offset (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Simplify offset validation in intel_get_padcfg() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Drop double check for data in intel_pinctrl_probe_by_uid() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Use devm_platform_ioremap_resource() (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Use devm_platform_ioremap_resource() (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Use GENMASK() consistently (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Re-use data structures from pinctrl-intel.h (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Use defined macro instead of magic in byt_get_gpio_mux() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Clear interrupt status in mask/unmask callback (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Use GENMASK() consistently (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Increase readability of intel_gpio_update_pad_mode() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Retain HOSTSW_OWN for requested gpio pin (David Arcari) [1773772]
- [pinctrl] pinctrl: pinctrl-intel: move gpio suspend/resume to noirq phase (David Arcari) [1773772]
- [pinctrl] pinctrl: cedarfork: Update pin names according to v1.13c (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Fix potential NULL pointer dereference (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Code formatting fixes (David Arcari) [1773772]
- [pinctrl] pinctrl: icelake: Code formatting fixes (David Arcari) [1773772]
- [pinctrl] pinctrl: cannonlake: Code formatting fixes (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Code formatting fixes (David Arcari) [1773772]
- [pinctrl] pinctrl: broxton: Code formatting fixes (David Arcari) [1773772]
- [pinctrl] pinctrl: lewisburg: Replace acpi.h with mod_devicetable.h (David Arcari) [1773772]
- [pinctrl] pinctrl: denverton: Replace acpi.h with mod_devicetable.h (David Arcari) [1773772]
- [pinctrl] pinctrl: cedarfork: Replace acpi.h with mod_devicetable.h (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Unexport intel_pinctrl_probe() (David Arcari) [1773772]
- [pinctrl] pinctrl: sunrisepoint: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: icelake: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: cannonlake: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: lewisburg: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: denverton: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: cedarfork: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: simplify getting .driver_data (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: simplify getting .driver_data (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Sort register offsets by value (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Get rid of unneeded ->probe() stub (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Update pin list for B0 stepping (David Arcari) [1773772]
- [pinctrl] pinctrl: broxton: Convert unsigned to unsigned int (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Convert unsigned to unsigned int (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Convert unsigned to unsigned int (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Sort headers alphabetically (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Remove unneeded MODULE_DEVICE_TABLE() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Move linux/pm.h to the local header (David Arcari) [1773772]
- [pinctrl] pinctrl: Include <linux/gpio/driver.h> nothing else (David Arcari) [1773772]
- [pinctrl] pinctrl: lewisburg: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: sunrisepoint: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: icelake: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: denverton: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: cedarfork: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: cannonlake: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: broxton: Define PM ops via INTEL_PINCTRL_PM_OPS() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Introduce common macro for PM operations (David Arcari) [1773772]
- [pinctrl] pinctrl: sunrisepoint: Convert to use intel_pinctrl_probe_by_hid() (David Arcari) [1773772]
- [pinctrl] pinctrl: cannonlake: Convert to use intel_pinctrl_probe_by_hid() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Introduce intel_pinctrl_probe_by_hid() internal API (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: Convert to use device_get_match_data() (David Arcari) [1773772]
- [pinctrl] pinctrl: geminilake: Convert to use intel_pinctrl_probe_by_uid() (David Arcari) [1773772]
- [pinctrl] pinctrl: broxton: Convert to use intel_pinctrl_probe_by_uid() (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Introduce intel_pinctrl_probe_by_uid() internal API (David Arcari) [1773772]
- [pinctrl] pinctrl: intel: Fix a spelling typo in kernel documentation (David Arcari) [1773772]
- [pinctrl] pinctrl: baytrail: actually print the apparently misconfigured pin (David Arcari) [1773772]
- [mm] mm, page_alloc: move_freepages should not examine struct page of reserved memory (Rafael Aquini) [1588584]
- [mm] mm, page_alloc: initialize num_movable in move_freepages() (Rafael Aquini) [1588584]
- [tools] selftests: vm: drop dependencies on page flags from mlock2 tests (Rafael Aquini) [1658886]
- [powercap] powercap/intel_rapl: add support for TigerLake Mobile (David Arcari) [1783136]
- [kernel] locking/lockdep: Avoid recursion in lockdep_count_{for, back}ward_deps() (Waiman Long) [1780993]
- [kernel] locking/lockdep: Reuse freed chain_hlocks entries (Waiman Long) [1780993]
- [kernel] locking/lockdep: Track number of zapped lock chains (Waiman Long) [1780993]
- [kernel] locking/lockdep: Throw away all lock chains with zapped class (Waiman Long) [1780993]
- [kernel] locking/lockdep: Track number of zapped classes (Waiman Long) [1780993]
- [kernel] locking/lockdep: Display irq_context names in /proc/lockdep_chains (Waiman Long) [1780993]
- [kernel] locking/lockdep: Decrement IRQ context counters when removing lock chain (Waiman Long) [1780993]
- [kernel] locking/lockdep: Fix lockdep_stats indentation problem (Waiman Long) [1780993]
- [kernel] locking/lockdep: Fix buffer overrun problem in stack_trace (Waiman Long) [1780993]
- [lib] lib/string: Make memzero_explicit() inline instead of external (Florian Westphal) [1820623]
- [crypto] crypto: sha256 - Remove sha256/224_init code duplication (Florian Westphal) [1820623]
- [crypto] crypto: sha256 - Merge crypto/sha256.h into crypto/sha.h (Florian Westphal) [1820623]
- [crypto] crypto: chelsio - Rename arrays to avoid conflict with crypto/sha256.h (Florian Westphal) [1820623]
- [x86] crypto: x86 - Rename functions to avoid conflict with crypto/sha256.h (Florian Westphal) [1820623]
- [arm64] crypto: arm64 - Rename functions to avoid conflict with crypto/sha256.h (Florian Westphal) [1820623]
- [crypto] crypto: sha256_generic - Switch to the generic lib/crypto/sha256.c lib code (Florian Westphal) [1820623]
- [lib] crypto: sha256 - Add sha224 support to sha256 library code (Florian Westphal) [1820623]
- [lib] crypto: sha256 - Make lib/crypto/sha256.c suitable for generic use (Florian Westphal) [1820623]
- [lib] crypto: sha256 - Use get/put_unaligned_be32 to get input, memzero_explicit (Florian Westphal) [1820623]
- [s390] crypto: sha256 - Move lib/sha256.c to lib/crypto (Florian Westphal) [1820623]
- [crypto] crypto: sha256_generic - Fix some coding style issues (Florian Westphal) [1820623]
- [lib] crypto: sha256 - Fix some coding style issues (Florian Westphal) [1820623]
- [thunderbolt] thunderbolt: Fix error code in tb_port_is_width_supported() (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Prevent crash if non-active NVMem file is read (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: fix memory leak of object sw (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Fix xhci check in usb4_switch_setup() (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add support for USB 3.x tunnels (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add support for Time Management Unit (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Make tb_switch_find_cap() available to other files (Jarod Wilson) [1482838]
- [netdrv] thunderbolt: Update Kconfig entries to USB4 (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add initial support for USB4 (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Populate PG field in hot plug acknowledgment packet (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Call tb_eeprom_get_drom_offset() from tb_eeprom_read_n() (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Make tb_find_port() available to other files (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Power cycle the router if NVM authentication fails (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Do not start firmware unless asked by the user (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add bandwidth management for Display Port tunnels (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add Display Port adapter pairing and resource management (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add Display Port CM handshake for Titan Ridge devices (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add downstream PCIe port mappings for Alpine and Titan Ridge (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Expand controller name in tb_switch_is_xy() (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add default linking between lane adapters if not provided by DROM (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add support for lane bonding (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Refactor add_switch() into two functions (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add helper macro to iterate over switch ports (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Make tb_sw_write() take const parameter (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Convert DP adapter register names to follow the USB4 spec (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Convert PCIe adapter register names to follow the USB4 spec (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Convert basic adapter register names to follow the USB4 spec (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Log error if adding switch fails (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Log switch route string on config read/write timeout (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Introduce tb_switch_is_icm() (Jarod Wilson) [1482838]
- [thunderbolt] thunderbolt: Add 'generation' attribute for devices (Jarod Wilson) [1482838]

* Thu Apr 09 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.6.el8]
- [scsi] scsi: lpfc: Copyright updates for 12.6.0.4 patches (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Update lpfc version to 12.6.0.4 (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Clean up hba max_lun_queue_depth checks (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Remove handler for obsolete ELS - Read Port Status (RPS) (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix coverity errors in fmdi attribute handling (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix compiler warning on frame size (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix registration of ELS type support in fdmi (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix broken Credit Recovery after driver load (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix lpfc_io_buf resource leak in lpfc_get_scsi_buf_s4 error path (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix RQ buffer leakage when no IOCBs available (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Make lpfc_defer_acc_rsp static (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Update lpfc version to 12.6.0.3 (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix improper flag check for IO type (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix MDS Latency Diagnostics Err-drop rates (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix unmap of dpp bars affecting next driver load (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix disablement of FC-AL on lpe35000 models (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix ras_log via debugfs (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix Fabric hostname registration if system hostname changes (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix missing check for CSF in Write Object Mbox Rsp (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix: Rework setting of fdmi symbolic node name registration (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix incomplete NVME discovery when target (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: fix spelling mistakes of asynchronous (Dick Kennedy) [1793674]
- [scsi] scsi: lpfc: Fix memory leak on lpfc_bsg_write_ebuf_set func (Dick Kennedy) [1793674]
- [tools] tools/power turbostat: Support Tiger Lake (David Arcari) [1783441]
- [md] dm integrity: fix logic bug in integrity tag testing (Mike Snitzer) [1820280]
- [md] Revert "dm: always call blk_queue_split() in dm_process_bio()" (Mike Snitzer) [1820705]
- [md] dm integrity: fix ppc64le warning (Mike Snitzer) [1820280]
- [md] dm writecache: add cond_resched to avoid CPU hangs (Mike Snitzer) [1820280]
- [md] dm integrity: improve discard in journal mode (Mike Snitzer) [1820280]
- [md] dm integrity: add optional discard support (Mike Snitzer) [1820280]
- [md] dm integrity: allow resize of the integrity device (Mike Snitzer) [1820280]
- [md] dm integrity: factor out get_provided_data_sectors() (Mike Snitzer) [1820280]
- [md] dm integrity: don't replay journal data past the end of the device (Mike Snitzer) [1820280]
- [md] dm integrity: remove sector type casts (Mike Snitzer) [1820280]
- [md] dm integrity: fix a crash with unusually large tag size (Mike Snitzer) [1820280]
- [md] dm verity fec: fix memory leak in verity_fec_dtr (Mike Snitzer) [1820280]
- [md] dm writecache: optimize superblock write (Mike Snitzer) [1820280]
- [md] dm writecache: implement gradual cleanup (Mike Snitzer) [1820280]
- [md] dm writecache: implement the "cleaner" policy (Mike Snitzer) [1820280]
- [md] dm writecache: do direct write if the cache is full (Mike Snitzer) [1820280]
- [md] dm integrity: print device name in integrity_metadata() error message (Mike Snitzer) [1820280]
- [md] dm crypt: use crypt_integrity_aead() helper (Mike Snitzer) [1820280]
- [lib] lib/test_bitmap: add tests for bitmap_parselist_user() (Vladis Dronov) [1819152]
- [lib] lib/test_bitmap: add testcases for bitmap_parselist() (Vladis Dronov) [1819152]
- [lib] lib/test_bitmap: switch test_bitmap_parselist to ktime_get() (Vladis Dronov) [1819152]
- [lib] lib: rework bitmap_parselist (Vladis Dronov) [1819152]
- [lib] lib: make bitmap_parselist_user() a wrapper on bitmap_parselist() (Vladis Dronov) [1819152]
- [platform] platform/x86: mlx-platform: Add support for next generation systems (Ivan Vecera) [1820312]
- [platform] platform/mellanox: mlxreg-hotplug: Add support for new capability register (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add support for new capability register (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add support for new system type (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Set system mux configuration based on system type (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add more definitions for system attributes (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Style changes (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add missed attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Fix documentation inconsistency for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Cosmetic changes (Ivan Vecera) [1820312]
- [platform] platform/mellanox: Fix Kconfig indentation (Ivan Vecera) [1820312]
- [leds] leds: mlxreg: Fix possible buffer overflow (Ivan Vecera) [1820312]
- [platform] platform/mellanox: mlxreg-hotplug: Remove dev_err() usage after platform_get_irq() (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Fix error handling in mlxplat_init() (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add more reset cause attributes (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Modify DMI matching order (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add regmap structure for the next generation systems (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Change API for i2c-mlxcpld driver activation (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Move regmap initialization before all drivers activation (Ivan Vecera) [1820312]
- [documentation] ABI: sysfs-driver-mlxreg-io: fix the what fields (Ivan Vecera) [1820312]
- [documentation] docs: watchdog: convert docs to ReST and rename to *.rst (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Fix parent device in i2c-mux-reg device registration (Ivan Vecera) [1820312]
- [platform] platform/mellanox: mlxreg-hotplug: Add devm_free_irq call to remove flow (Ivan Vecera) [1820312]
- [i2c] i2c: mlxcpld: Fix wrong initialization order in probe (Ivan Vecera) [1820312]
- [hwmon] hwmon: (mlxreg-fan) Use devm_thermal_of_cooling_device_register (Ivan Vecera) [1820312]
- [thermal] thermal: Introduce devm_thermal_of_cooling_device_register (Ivan Vecera) [1820312]
- [watchdog] watchdog: mlx_wdt: Use 'dev' instead of dereferencing it repeatedly (Ivan Vecera) [1820312]
- [hwmon] hwmon: (mlxreg-fan) Use HWMON_CHANNEL_INFO macro (Ivan Vecera) [1820312]
- [include] hwmon: Add convience macro to define simple static sensors (Ivan Vecera) [1820312]
- [hwmon] hwmon: (mlxreg-fan) Add support for fan capability registers (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add mlx-wdt platform driver activation (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add support for tachometer speed register (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Fix access mode for fan_dir attribute (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add UID LED for the next generation systems (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add extra CPLD for next generation systems (Ivan Vecera) [1820312]
- [documentation] Documentation/watchdog: Add documentation mlx-wdt driver (Ivan Vecera) [1820312]
- [watchdog] watchdog: mlx-wdt: introduce a watchdog driver for Mellanox systems (Ivan Vecera) [1820312]
- [include] platform_data/mlxreg: additions for Mellanox watchdog driver (Ivan Vecera) [1820312]
- [leds] leds: mlxreg: Add support for capability register (Ivan Vecera) [1820312]
- [platform] platform/mellanox: mlxreg-hotplug: Fix KASAN warning (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Correct mlxreg-io KernelVersion for 5.0 (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add support for new VMOD0007 board name (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add support for fan capability registers (Ivan Vecera) [1820312]
- [include] platform_data/mlxreg: Add capability field to core platform data (Ivan Vecera) [1820312]
- [include] platform_data/mlxreg: Document fixes for core platform data (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add support for fan direction register (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Convert to use SPDX identifier (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Allow mlxreg-io driver activation for new systems (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Fix LED configuration (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Fix tachometer registers (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Rename new systems product names (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add definitions for new registers (Ivan Vecera) [1820312]
- [i2c] i2c: mux: mlxcpld: simplify code to reach the adapter (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Properly use mlxplat_mlxcpld_msn201x_items (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Fix copy-paste error in mlxplat_init() (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Remove unused define (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Change mlxreg-io configuration for MSN274x systems (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Allow mlxreg-io driver activation for more systems (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add ASIC hotplug device configuration (Ivan Vecera) [1820312]
- [platform] platform/mellanox: mlxreg-hotplug: Add hotplug hwmon uevent notification (Ivan Vecera) [1820312]
- [platform] platform/mellanox: mlxreg-hotplug: Improve mechanism of ASIC health discovery (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add mlxreg-fan platform driver activation (Ivan Vecera) [1820312]
- [platform] platform/mellanox: Use 2-factor allocator calls (Ivan Vecera) [1820312]
- [hwmon] hwmon: (mlxreg-fan) Modify macros for tachometer fault status reading (Ivan Vecera) [1820312]
- [hwmon] hwmon: (mlxreg-fan) Fix macros for tacho fault reading (Ivan Vecera) [1820312]
- [hwmon] hwmon: (mlxreg-fan) Add support for Mellanox FAN driver (Ivan Vecera) [1820312]
- [i2c] i2c: mux: mlxcpld: make use of __i2c_smbus_xfer (Ivan Vecera) [1820312]
- [i2c] i2c: smbus: add unlocked __i2c_smbus_xfer variant (Ivan Vecera) [1820312]
- [documentation] Documentation/ABI: Add documentation mlxreg-io sysfs interfaces (Ivan Vecera) [1820312]
- [platform] platform/x86: mlx-platform: Add mlxreg-io platform driver activation (Ivan Vecera) [1820312]
- [platform] platform/mellanox: Introduce support for Mellanox register access driver (Ivan Vecera) [1820312]
- [kernel] audit: trigger accompanying records when no rules present (Richard Guy Briggs) [1819944]
- [kernel] sched/fair: Allow a per-CPU kthread waking a task to stack on the same CPU, to fix XFS performance regression (Phil Auld) [1745111]
- [hid] HID: intel-ish-hid: ipc: Add Tiger Lake PCI device ID (Tony Camuso) [1818043]
- [hid] HID: intel-ish-hid: ipc: add CMP device id (Tony Camuso) [1818043]
- [hid] HID: intel-ish-hid: Spelling s/diconnect/disconnect/ (Tony Camuso) [1818043]
- [hid] HID: intel-ish-hid: fix wrong error handling in ishtp_cl_alloc_tx_ring() (Tony Camuso) [1818043]
- [hid] HID: intel-ish-hid: ipc: check the NO_D3 flag to distinguish resume paths (Tony Camuso) [1818043]
- [hid] HID: intel-ish-hid: ipc: make ish suspend paths clear (Tony Camuso) [1818043]
- [hid] HID: intel-ish-hid: ipc: set NO_D3 flag only when needed (Tony Camuso) [1818043]
- [netdrv] net: ena: Add PCI shutdown handler to allow safe kexec (Bhupesh Sharma) [1758323]
- [net] vsock: fix potential deadlock in transport->release() (Stefano Garzarella) [1771582]
- [net] vsock/virtio: remove loopback handling (Stefano Garzarella) [1771582]
- [net] vsock: use local transport when it is loaded (Stefano Garzarella) [1771582]
- [net] vsock: add vsock_loopback transport (Stefano Garzarella) [1771582]
- [net] vsock: add local transport support in the vsock core (Stefano Garzarella) [1771582]
- [uapi] vsock: add VMADDR_CID_LOCAL definition (Stefano Garzarella) [1771582]
- [net] vsock/virtio_transport_common: remove unused virtio header includes (Stefano Garzarella) [1771582]
- [infiniband] IB/rdmavt: Free kernel completion queue when done (Gopal Tiwari) [1805036]
- [powerpc] powerpc/64s: Fix section mismatch warnings from boot code (Desnes Augusto Nunes do Rosario) [1391523]
- [powerpc] powerpc/prom: convert PROM_BUG() to standard trap (Desnes Augusto Nunes do Rosario) [1391523]
- [powerpc] powerpc/64: mark start_here_multiplatform as __ref (Desnes Augusto Nunes do Rosario) [1391523]
- [mfd] mfd: intel-lpss: Add Intel Tiger Lake PCI IDs (David Arcari) [1773767]
- [mfd] mfd: intel-lpss: Release IDA resources (David Arcari) [1773767]
- [mfd] mfd: intel-lpss: Keep device tables sorted by ID (David Arcari) [1773767]
- [i2c] i2c: i801: Add support for Intel Tiger Lake (David Arcari) [1773765]
- [edac] EDAC/mce_amd: Print !SMCA processor warning only once (Prarit Bhargava) [1796178]
- [powerpc] powerpc/pseries/dlpar: Fix a missing check in dlpar_parse_cc_property() (Steve Best) [1806630] {CVE-2019-12614}

* Tue Apr 07 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.5.el8]
- [x86] x86/gart: Rewrite early_gart_iommu_check() comment (Waiman Long) [1818532]
- [mm] mm/memblock.c: warn if zero alignment was requested (Waiman Long) [1818532]
- [powerpc] memblock: stop using implicit alignment to SMP_CACHE_BYTES (Waiman Long) [1818532]
- [mm] memblock: replace BOOTMEM_ALLOC_* with MEMBLOCK variants (Waiman Long) [1818532]
- [mm] mm: remove nobootmem (Waiman Long) [1818532]
- [mm] memblock: rename __free_pages_bootmem to memblock_free_pages (Waiman Long) [1818532]
- [mm] memblock: rename free_all_bootmem to memblock_free_all (Waiman Long) [1818532]
- [firmware] memblock: replace free_bootmem_late with memblock_free_late (Waiman Long) [1818532]
- [x86] memblock: replace free_bootmem{_node} with memblock_free (Waiman Long) [1818532]
- [mm] mm: nobootmem: remove bootmem allocation APIs (Waiman Long) [1818532]
- [mm] memblock: replace __alloc_bootmem with memblock_alloc_from (Waiman Long) [1818532]
- [mm] memblock: replace alloc_bootmem_pages with memblock_alloc (Waiman Long) [1818532]
- [mm] memblock: replace alloc_bootmem_low_pages with memblock_alloc_low (Waiman Long) [1818532]
- [mm] memblock: replace alloc_bootmem_pages_node with memblock_alloc_node (Waiman Long) [1818532]
- [mm] memblock: add align parameter to memblock_alloc_node() (Waiman Long) [1818532]
- [arm64] memblock: replace alloc_bootmem_low with memblock_alloc_low (2) (Waiman Long) [1818532]
- [usb] memblock: replace alloc_bootmem_pages_nopanic with memblock_alloc_nopanic (Waiman Long) [1818532]
- [x86] memblock: replace __alloc_bootmem_node_nopanic with memblock_alloc_try_nid_nopanic (Waiman Long) [1818532]
- [x86] memblock: replace alloc_bootmem_low with memblock_alloc_low (Waiman Long) [1818532]
- [x86] memblock: replace alloc_bootmem_align with memblock_alloc (Waiman Long) [1818532]
- [mm] memblock: remove _virt from APIs returning virtual address (Waiman Long) [1818532]
- [powerpc] memblock: rename memblock_alloc{_nid, _try_nid} to memblock_phys_alloc* (Waiman Long) [1818532]
- [mm] mm: nobootmem: remove dead code (Waiman Long) [1818532]
- [mm] mm: remove bootmem allocator implementation (Waiman Long) [1818532]
- [mm] mm: remove CONFIG_HAVE_MEMBLOCK (Waiman Long) [1818532]
- [mm] mm: remove CONFIG_NO_BOOTMEM (Waiman Long) [1818532]
- [mm] mm: disable deferred struct page for 32-bit arches (Waiman Long) [1818532]
- [mm] mm: make DEFERRED_STRUCT_PAGE_INIT explicitly depend on SPARSEMEM (Waiman Long) [1818532]
- [mm] mm/hugetlb.c: don't zero 1GiB bootmem pages (Waiman Long) [1818532]
- [mm] docs/mm: memblock: add overview documentation (Waiman Long) [1818532]
- [include] docs/mm: memblock: add kernel-doc description for memblock types (Waiman Long) [1818532]
- [mm] docs/mm: memblock: add kernel-doc comments for memblock_add (Waiman Long) [1818532]
- [mm] docs/mm: bootmem: add overview documentation (Waiman Long) [1818532]
- [include] docs/mm: bootmem: add kernel-doc description of 'struct bootmem_data' (Waiman Long) [1818532]
- [mm] docs/mm: bootmem: fix kernel-doc warnings (Waiman Long) [1818532]
- [mm] docs/mm: nobootmem: fixup kernel-doc comments (Waiman Long) [1818532]
- [mm] mm/bootmem: drop duplicated kernel-doc comments (Waiman Long) [1818532]
- [lib] lib/smp_processor_id: Don't use cpumask_equal() (Waiman Long) [1812092]
- [kernel] audit: always check the netlink payload length in audit_receive_msg() (Richard Guy Briggs) [1814448]
- [kernel] audit: fix error handling in audit_data_to_entry() (Richard Guy Briggs) [1814448]
- [fs] fat: work around race with userspace's read via blockdev while mounting (Bill O'Donnell) [1771351]
- [include] raid6/test: fix a compilation error (Bhupesh Sharma) [1817524]
- [arm64] arm64: kexec_file: add crash dump support (Bhupesh Sharma) [1817524]
- [lib] libfdt: include fdt_addresses.c (Bhupesh Sharma) [1817524]
- [scripts] scripts/dtc: Update to upstream version v1.5.1-22-gc40aeb60b47a (Bhupesh Sharma) [1817524]
- [include] libfdt: reduce the number of headers included from libfdt_env.h (Bhupesh Sharma) [1817524]
- [arm64] arm64: dts: amd: Fix SPI bus warnings (Bhupesh Sharma) [1817524]
- [arm64] arm64: dts: broadcom: Fix I2C and SPI bus warnings (Bhupesh Sharma) [1817524]
- [scripts] scripts/dtc: Update to upstream version v1.5.0-30-g702c1b6c0e73 (Bhupesh Sharma) [1817524]
- [scripts] scripts/dtc: Update to upstream version v1.5.0-23-g87963ee20693 (Bhupesh Sharma) [1817524]
- [include] linux/kernel.h: split *_MAX and *_MIN macros into <linux/limits.h> (Bhupesh Sharma) [1817524]
- [scripts] kbuild: disable dtc simple_bus_reg warnings by default (Bhupesh Sharma) [1817524]
- [scripts] scripts/dtc: Update to upstream version v1.4.7-57-gf267e674d145 (Bhupesh Sharma) [1817524]
- [scripts] scripts/dtc: Update to upstream version v1.4.7-14-gc86da84d30e4 (Bhupesh Sharma) [1817524]
- [scripts] scripts/dtc: consolidate include path options in Makefile (Bhupesh Sharma) [1817524]
- [pci] PCI: Remove unnecessary returns (Myron Stowe) [1807175]
- [pci] PCI: OF: Correct of_irq_parse_pci() documentation (Myron Stowe) [1807175]
- [pci] PCI: Fix typos and whitespace errors (Myron Stowe) [1807175]
- [documentation] PCI: Correct pci=resource_alignment parameter example (Myron Stowe) [1807175]
- [pci] PCI: Use PCI_SRIOV_NUM_BARS in loops instead of PCI_IOV_RESOURCE_END (Myron Stowe) [1807175]
- [pci] PCI: Convert pci_resource_to_user() to a weak function (Myron Stowe) [1807175]
- [pci] PCI: pciehp: Refer to "Indicators" instead of "LEDs" in comments (Myron Stowe) [1807175]
- [pci] PCI: pciehp: Remove pciehp_green_led_{on, off, blink}() (Myron Stowe) [1807175]
- [pci] PCI: pciehp: Remove pciehp_set_attention_status() (Myron Stowe) [1807175]
- [pci] PCI: pciehp: Combine adjacent indicator updates (Myron Stowe) [1807175]
- [pci] PCI: pciehp: Add pciehp_set_indicators() to set both indicators (Myron Stowe) [1807175]
- [pci] PCI: Add pci_irq_vector() and other stubs when !CONFIG_PCI (Myron Stowe) [1807175]
- [pci] PCI: Force trailing new line to resource_alignment_param in sysfs (Myron Stowe) [1807175]
- [pci] PCI: Move pci__resource_alignment_param() into their callers (Myron Stowe) [1807175]
- [pci] PCI: pci.c: convert to use BUS_ATTR_RW (Myron Stowe) [1807175]
- [pci] PCI: Clean up resource_alignment parameter to not require static buffer (Myron Stowe) [1807175]
- [pci] PCI/IOV: Remove group write permission from sriov_numvfs, sriov_drivers_autoprobe (Myron Stowe) [1807175]
- [pci] PCI/IOV: Move sysfs SR-IOV functions to iov.c (Myron Stowe) [1807175]
- [pci] PCI: sysfs: Change permissions from symbolic to octal (Myron Stowe) [1807175]
- [pci] PCI: sysfs: Revert "rescan" file renames (Myron Stowe) [1807175]
- [pci] PCI: sysfs: Change DEVICE_ATTR() to DEVICE_ATTR_WO() (Myron Stowe) [1807175]
- [pci] PCI: pci-sysfs.c: convert to use BUS_ATTR_WO (Myron Stowe) [1807175]
- [pci] PCI: sysfs: Define device attributes with DEVICE_ATTR*() (Myron Stowe) [1807175]
- [pci] PCI: Mark expected switch fall-through (Myron Stowe) [1807175]
- [pci] PCI: Use devm_add_action_or_reset() (Myron Stowe) [1807175]
- [pci] PCI: Get rid of dev->has_secondary_link flag (Myron Stowe) [1807175]
- [pci] PCI/ACPI: Remove unnecessary struct hotplug_program_ops (Myron Stowe) [1807175]
- [pci] PCI/ACPI: Move _HPP & _HPX functions to pci-acpi.c (Myron Stowe) [1807175]
- [pci] PCI/ACPI: Rename _HPX structs from hpp_* to hpx_* (Myron Stowe) [1807175]
- [pci] PCI: Make pci_set_of_node(), etc private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_enable_ptm() private (Myron Stowe) [1807175]
- [pci] PCI: Make pcie_set_ecrc_checking(), pcie_ecrc_get_policy() private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_ats_init() private (Myron Stowe) [1807175]
- [pci] PCI: Make pcie_update_link_speed() private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_bus_get(), pci_bus_put() private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_hotplug_io_size, mem_size, and bus_size private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_save_vc_state(), pci_restore_vc_state(), etc private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_get_host_bridge_device(), pci_put_host_bridge_device() private (Myron Stowe) [1807175]
- [pci] PCI: Make pci_check_pme_status(), pci_pme_wakeup_bus() private (Myron Stowe) [1807175]
- [pci] PCI: Make PCI_PM_* delay times private (Myron Stowe) [1807175]
- [pci] PCI: Unexport pci_bus_sem (Myron Stowe) [1807175]
- [pci] PCI: Unexport pci_bus_get() and pci_bus_put() (Myron Stowe) [1807175]
- [pci] PCI: Remove pci_block_cfg_access() et al (unused) (Myron Stowe) [1807175]
- [wireless] PCI: Move ASPM declarations to linux/pci.h (Myron Stowe) [1807175]
- [pci] PCI/MSI: Support allocating virtual MSI interrupts (Myron Stowe) [1807175]
- [fs] gfs2: Remove unnecessary gfs2_qa_{get,put} pairs (Robert S Peterson) [1807146]
- [fs] gfs2: Split gfs2_rsqa_delete into gfs2_rs_delete and gfs2_qa_put (Robert S Peterson) [1807146]
- [fs] gfs2: Change inode qa_data to allow multiple users (Robert S Peterson) [1807146]
- [fs] gfs2: eliminate gfs2_rsqa_alloc in favor of gfs2_qa_alloc (Robert S Peterson) [1807146]
- [fs] gfs2: Switch to list_{first,last}_entry (Robert S Peterson) [1807146]
- [fs] gfs2: Clean up inode initialization and teardown (Robert S Peterson) [1807146]
- [fs] gfs2: Minor gfs2_alloc_inode cleanup (Robert S Peterson) [1807146]
- [pinctrl] pinctrl: pinmux: fix a possible null pointer in pinmux_can_be_used_for_gpio (David Arcari) [1817454]
- [pinctrl] pinctrl/gpio: Take MUX usage into account (David Arcari) [1817454]
- [include] gpio: Fix build warnings on undefined struct pinctrl_dev (David Arcari) [1817454]
- [pinctrl] pinctrl: remove unused pin_is_valid() (David Arcari) [1817454]
- [pinctrl] pinctrl: remove unneeded initializer for list_for_each_entry() iterator (David Arcari) [1817454]
- [pinctrl] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 194 (David Arcari) [1817454]
- [pinctrl] pinctrl: core: Do not add device links for hogs (David Arcari) [1817454]
- [pinctrl] pinctrl: Enable device link creation for pin control (David Arcari) [1817454]
- [pinctrl] pinctrl: generic: add new 'drive-strength-microamp' property support (David Arcari) [1817454]
- [pinctrl] pinctrl: remove unused 'pinconf-config' debugfs interface (David Arcari) [1817454]
- [pinctrl] pinctrl: Change to use DEFINE_SHOW_ATTRIBUTE macro (David Arcari) [1817454]
- [pinctrl] pinctrl: core: make sure strcmp() doesn't get a null parameter (David Arcari) [1817454]
- [pinctrl] pinctrl: core: Remove broken remove_last group and pinmux functions (David Arcari) [1817454]
- [pinctrl] pinctrl: pinmux: Return selector to the pinctrl driver (David Arcari) [1817454]
- [pinctrl] pinctrl: core: Return selector to the pinctrl driver (David Arcari) [1817454]
- [pinctrl] pinctrl: Cut unused sysfs includes (David Arcari) [1817454]
- [mm] mm, numa: fix bad pmd by atomically check for pmd_trans_huge when marking page tables prot_numa (Rafael Aquini) [1763878]
- [mm] mm: thp: fix flags for pmd migration when split (Rafael Aquini) [1763878]
- [mm] mm: thp: relocate flush_cache_range() in migrate_misplaced_transhuge_page() (Rafael Aquini) [1763878]
- [mm] mm: thp: fix mmu_notifier in migrate_misplaced_transhuge_page() (Rafael Aquini) [1763878]
- [mm] mm: thp: fix MADV_DONTNEED vs migrate_misplaced_transhuge_page race condition (Rafael Aquini) [1763878]
- [fs] nfsd: set the server_scope during service startup (Scott Mayhew) [1817752]
- [fs] nfsd: v4 support requires CRYPTO_SHA256 (Scott Mayhew) [1817752]
- [fs] nfsd: Fix cld_net->cn_tfm initialization (Scott Mayhew) [1817752]
- [fs] nfsd: add support for upcall version 2 (Scott Mayhew) [1817752]
- [fs] nfsd: add a "GetVersion" upcall for nfsdcld (Scott Mayhew) [1817752]
- [fs] nfsd: handle legacy client tracking records sent by nfsdcld (Scott Mayhew) [1817752]
- [fs] nfsd: re-order client tracking method selection (Scott Mayhew) [1817752]
- [fs] nfsd: keep a tally of RECLAIM_COMPLETE operations when using nfsdcld (Scott Mayhew) [1817752]
- [fs] nfsd: un-deprecate nfsdcld (Scott Mayhew) [1817752]
- [fs] nfsd: make nfs4_client_reclaim use an xdr_netobj instead of a fixed char array (Scott Mayhew) [1817752]

* Sun Apr 05 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.4.el8]
- [s390] scsi: zfcp: fix to prevent port_remove with pure auto scan LUNs (only sdevs) (Philipp Rudo) [1814791]
- [s390] scsi: zfcp: fix missing zfcp_port reference put on -EBUSY from port_remove (Philipp Rudo) [1814792]
- [infiniband] RDMA/qedr: Fix null-pointer dereference when calling rdma_user_mmap_get_offset (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Make qedr_iw_load_qp() static (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Fix potential use after free (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Remove unsupported modify_port callback (Kamal Heib) [1786602]
- [infiniband] IB/ipoib: Add ndo operation for getting VFs GUID attributes (Kamal Heib) [1786602]
- [net] xprtrdma: Fix oops in Receive handler after device removal (Kamal Heib) [1786602]
- [net] xprtrdma: Fix completion wait during device removal (Kamal Heib) [1786602]
- [net] xprtrdma: Fix create_qp crash on device unload (Kamal Heib) [1786602]
- [infiniband] IB/hfi1: Adjust flow PSN with the correct resync_psn (Kamal Heib) [1786602]
- [infiniband] IB/hfi1: Don't cancel unused work item (Kamal Heib) [1786602]
- [infiniband] IB/core: Introduce rdma_user_mmap_entry_insert_range() API (Kamal Heib) [1786602]
- [infiniband] RDMA/counter: Prevent auto-binding a QP which are not tracked with res (Kamal Heib) [1786602]
- [infiniband] rxe: correctly calculate iCRC for unaligned payloads (Kamal Heib) [1786602]
- [infiniband] treewide: Use sizeof_field() macro (Kamal Heib) [1786602]
- [infiniband] RDMA/cma: add missed unregister_pernet_subsys in init failure (Kamal Heib) [1786602]
- [infiniband] RDMA/efa: Expose RDMA read related attributes (Kamal Heib) [1786602]
- [infiniband] RDMA/efa: Support remote read access in MR registration (Kamal Heib) [1786602]
- [infiniband] RDMA/efa: Store network attributes in device attributes (Kamal Heib) [1786602]
- [infiniband] IB/hfi1: remove redundant assignment to variable ret (Kamal Heib) [1786602]
- [infiniband] net: use rhashtable_lookup() instead of rhashtable_lookup_fast() (Kamal Heib) [1786602]
- [infiniband] IB/core: Add interfaces to get VF node and port GUIDs (Kamal Heib) [1786602]
- [infiniband] RDMA/cm: Use refcount_t type for refcount variable (Kamal Heib) [1786602]
- [infiniband] RDMA/cma: Use ACK timeout for RoCE packetLifeTime (Kamal Heib) [1786602]
- [infiniband] IB/umem: remove the dmasync argument to ib_umem_get (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Add iWARP doorbell recovery support (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Add doorbell overflow recovery support (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Use the common mmap API (Kamal Heib) [1786602]
- [infiniband] RDMA/qedr: Fix memory leak in user qp and mr (Kamal Heib) [1810854 1786602]
- [infiniband] RDMA/qedr: Fix synchronization methods and memory leaks in qedr (Kamal Heib) [1810854 1786602]
- [infiniband] RDMA/qedr: Fix qpids xarray api used (Kamal Heib) [1810854 1786602]
- [infiniband] RDMA/qedr: Fix srqs xarray initialization (Kamal Heib) [1810854 1786602]
- [infiniband] RDMA/qedr: Remove Unneeded variable rc (Kamal Heib) [1810854 1786602]
- [infiniband] RDMA/mlx4: Separate creation of RWQ and QP (Kamal Heib) [1786602]
- [infiniband] RDMA/hns: Package for hns_roce_rereg_user_mr function (Kamal Heib) [1786602]
- [infiniband] RDMA/hns: Fix sg offset non-zero issue (Kamal Heib) [1786602]
- [infiniband] dma-mapping: remove the DMA_ATTR_WRITE_BARRIER flag (Kamal Heib) [1786602]
- [infiniband] RDMA/efa: Clear the admin command buffer prior to its submission (Kamal Heib) [1786602]
- [infiniband] RDMA/siw: Cleanup unused mmap structures (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Report the SCSI residual to the initiator (Kamal Heib) [1786602]
- [infiniband] RDMA: Change MAD processing function to remove extra casting and parameter (Kamal Heib) [1786602]
- [infiniband] RDMA/mlx5: Rewrite MAD processing logic to be readable (Kamal Heib) [1786602]
- [infiniband] RDMA/ocrdma: Simplify process_mad function (Kamal Heib) [1786602]
- [infiniband] RDMA/ocrdma: Make ocrdma_pma_counters() return void (Kamal Heib) [1786602]
- [infiniband] RDMA/mad: Do not check MAD sizes in roce and ib drivers (Kamal Heib) [1786602]
- [infiniband] RDMA/hfi1: Delete unreachable code (Kamal Heib) [1786602]
- [infiniband] RDMA/mad: Allocate zeroed MAD buffer (Kamal Heib) [1786602]
- [infiniband] RDMA/mad: Delete never implemented functions (Kamal Heib) [1786602]
- [infiniband] RDMA/core: Fix return code when modify_port isn't supported (Kamal Heib) [1786602]
- [infiniband] RDMA/siw: Use the common mmap_xa helpers (Kamal Heib) [1786602]
- [infiniband] RDMA/efa: Use the common mmap_xa helpers (Kamal Heib) [1786602]
- [infiniband] RDMA: Connect between the mmap entry and the umap_priv structure (Kamal Heib) [1786602]
- [infiniband] RDMA/hns: Use rdma_user_mmap_io (Kamal Heib) [1786602]
- [infiniband] RDMA/core: Create mmap database and cookie helper functions (Kamal Heib) [1786602]
- [infiniband] RDMA/core: Move core content from ib_uverbs to ib_core (Kamal Heib) [1786602]
- [infiniband] RDMA/odp: Remove broken debugging call to invalidate_range (Kamal Heib) [1786602]
- [infiniband] RDMA/vmw_pvrdma: Use resource ids from physical device if available (Kamal Heib) [1786602]
- [infiniband] RDMA/core: Set DMA parameters correctly (Kamal Heib) [1786602]
- [infiniband] RDMA/siw: Increase DMA max_segment_size parameter (Kamal Heib) [1786602]
- [infiniband] RDMA/rxe: Increase DMA max_segment_size parameter (Kamal Heib) [1786602]
- [uapi] rdma: Remove nes ABI header (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Fix TPG creation (Kamal Heib) [1786602]
- [infiniband] RDMA/cm: Update copyright together with SPDX tag (Kamal Heib) [1786602]
- [infiniband] RDMA/cm: Use specific keyword to check define (Kamal Heib) [1786602]
- [infiniband] RDMA/cm: Delete unused cm_is_active_peer function (Kamal Heib) [1786602]
- [infiniband] RDMA/rxe: Remove useless rxe_init_device_param assignments (Kamal Heib) [1786602]
- [net] xprtrdma: Replace dprintk in xprt_rdma_set_port (Kamal Heib) [1786602]
- [net] xprtrdma: Replace dprintk() in rpcrdma_update_connect_private() (Kamal Heib) [1786602]
- [net] xprtrdma: Refine trace_xprtrdma_fixup (Kamal Heib) [1786602]
- [net] xprtrdma: Report the computed connect delay (Kamal Heib) [1786602]
- [net] xprtrdma: Wake tasks after connect worker fails (Kamal Heib) [1786602]
- [net] xprtrdma: Pull up sometimes (Kamal Heib) [1786602]
- [net] xprtrdma: Refactor rpcrdma_prepare_msg_sges() (Kamal Heib) [1786602]
- [net] xprtrdma: Move the rpcrdma_sendctx::sc_wr field (Kamal Heib) [1786602]
- [net] xprtrdma: Remove rpcrdma_sendctx::sc_device (Kamal Heib) [1786602]
- [net] xprtrdma: Remove rpcrdma_sendctx::sc_xprt (Kamal Heib) [1786602]
- [net] xprtrdma: Ensure ri_id is stable during MR recycling (Kamal Heib) [1786602]
- [net] xprtrdma: Manage MRs in context of a single connection (Kamal Heib) [1786602]
- [net] xprtrdma: Fix MR list handling (Kamal Heib) [1786602]
- [net] xprtrdma: Initialize rb_credits in one place (Kamal Heib) [1786602]
- [infiniband] RDMA/core: Check that process is still alive before sending it to the users (Kamal Heib) [1786602]
- [infiniband] RDMA/restrack: Remove PID namespace support (Kamal Heib) [1786602]
- [infiniband] RDMA/uverbs: Add a check for uverbs_attr_get to uverbs_copy_to_struct_or_zero (Kamal Heib) [1786602]
- [infiniband] IB/cma: Honor traffic class from lower netdevice for RoCE (Kamal Heib) [1786602]
- [infiniband] RDMA/nldev: Provide MR statistics (Kamal Heib) [1786602]
- [infiniband] RDMA/mlx5: Return ODP type per MR (Kamal Heib) [1786602]
- [infiniband] RDMA/nldev: Allow different fill function per resource (Kamal Heib) [1786602]
- [infiniband] IB/mlx5: Introduce ODP diagnostic counters (Kamal Heib) [1786602]
- [infiniband] infiniband: fix sw/rdmavt/ kernel-doc notation (Kamal Heib) [1786602]
- [infiniband] infiniband: fix core/ kernel-doc notation (Kamal Heib) [1786602]
- [infiniband] infiniband: fix ulp/iser/iser_initiator.c kernel-doc warnings (Kamal Heib) [1786602]
- [infiniband] infiniband: fix ulp/iser/iser_verbs.c kernel-doc notation (Kamal Heib) [1786602]
- [infiniband] infiniband: fix core/verbs.c kernel-doc notation (Kamal Heib) [1786602]
- [infiniband] infiniband: fix ulp/srpt/ib_srpt.h kernel-doc notation (Kamal Heib) [1786602]
- [infiniband] infiniband: fix ulp/iser/iscsi_iser.h kernel-doc warnings (Kamal Heib) [1786602]
- [infiniband] infiniband: fix core/ipwm_util.h kernel-doc warnings (Kamal Heib) [1786602]
- [infiniband] infiniband: fix ulp/iser/iscsi_iser.kernel-doc notation (Kamal Heib) [1786602]
- [infiniband] RDMA/rw: Support threshold for registration vs scattering to local pages (Kamal Heib) [1786602]
- [uapi] RDMA/uapi: Fix and re-organize the usage of rdma_driver_id (Kamal Heib) [1786602]
- [net] svcrdma: Improve DMA mapping trace points (Kamal Heib) [1786602]
- [infiniband] RDMA/iser: Use iser_err instead of pr_err for logging (Kamal Heib) [1786602]
- [infiniband] RDMA/srp: Calculate max_it_iu_size if remote max_it_iu length available (Kamal Heib) [1786602]
- [infiniband] RDMA/srp: Add parse function for maximum initiator to target IU size (Kamal Heib) [1786602]
- [infiniband] IB/cm: Use container_of() instead of typecast (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Make the code for handling port identities more systematic (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Rework the code that waits until an RDMA port is no longer in use (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Rework the approach for closing an RDMA channel (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Improve a debug message (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Fix handling of iWARP logins (Kamal Heib) [1786602]
- [infiniband] RDMA/srpt: Fix handling of SR-IOV and iWARP ports (Kamal Heib) [1786602]
- [infiniband] RDMA/srp: Make route resolving error messages more informative (Kamal Heib) [1786602]
- [infiniband] RDMA/srp: Honor the max_send_sge device attribute (Kamal Heib) [1786602]
- [infiniband] RDMA/srp: Remove two casts (Kamal Heib) [1786602]
- [infiniband] RDMA/siw: Make node GUIDs valid EUI-64 identifiers (Kamal Heib) [1786602]
- [infiniband] RDMA/iw_cxgb3: Remove the iw_cxgb3 module from kernel (Kamal Heib) [1786602]
- [infiniband] RDMA/rxe: Verify modify_device mask (Kamal Heib) [1786602]
- [infiniband] RDMA/core: Fix return code when modify_device isn't supported (Kamal Heib) [1786602]
- [infiniband] RDMA/siw: Fix port number endianness in a debug message (Kamal Heib) [1786602]
- [infiniband] RDMA/siw: Simplify several debug messages (Kamal Heib) [1786602]
- [infiniband] IB/iser: remove redundant macro definitions (Kamal Heib) [1786602]
- [infiniband] IB/iser: bound protection_sg size by data_sg size (Kamal Heib) [1786602]
- [infiniband] IB/iser: add unlikely checks in the fast path (Kamal Heib) [1786602]
- [infiniband] RDMA/counter: Prevent QP counter manual binding in auto mode (Kamal Heib) [1786602]
- [kvm] KVM: SVM: Override default MMIO mask if memory encryption is enabled (Wei Huang) [1789537]
- [netdrv] mlx5e: Reorder mirrer action parsing to check for encap first (Ivan Vecera) [1818074]
- [tools] selftests: mlxsw: Adjust test to recent changes (Ivan Vecera) [1818074]
- [netdrv] vxlan: fix unexpected failure of vxlan_changelink() (Ivan Vecera) [1818074]
- [netdrv] bonding: fix lockdep warning in bond_get_stats() (Ivan Vecera) [1818074]
- [netdrv] bonding: fix using uninitialized mode_lock (Ivan Vecera) [1818074]
- [net] export netdev_next_lower_dev_rcu() (Ivan Vecera) [1818074]
- [netdrv] bonding: add missing netdev_update_lockdep_key() (Ivan Vecera) [1818074]
- [net] avoid updating qdisc_xmit_lock_key in netdev_update_lockdep_key() (Ivan Vecera) [1818074]
- [include] net: fix kernel-doc warning in <linux/netdevice.h> (Ivan Vecera) [1818074]
- [net] batman-adv: Drop lockdep.h include for soft-interface.c (Ivan Vecera) [1818074]
- [net] remove unnecessary variables and callback (Ivan Vecera) [1818074]
- [netdrv] macsec: Fix multiple coding style issues (Ivan Vecera) [1818074]
- [netdrv] vxlan: add adjacent link to limit depth level (Ivan Vecera) [1818074]
- [net] core: add ignore flag to netdev_adjacent structure (Ivan Vecera) [1818074]
- [netdrv] team: fix nested locking lockdep warning (Ivan Vecera) [1818074]
- [netdrv] bonding: use dynamic lockdep key instead of subclass (Ivan Vecera) [1818074]
- [netdrv] bonding: fix unexpected IFF_BONDING bit unset (Ivan Vecera) [1818074]
- [net] core: add generic lockdep keys (Ivan Vecera) [1818074]
- [net] core: limit nested device depth (Ivan Vecera) [1818074]
- [net] udp: rehash on disconnect (Davide Caratti) [1817671]
- [net] revert "udp: do rmem bulk free even if the rx sk queue is empty" (Davide Caratti) [1817671]
- [net] udp: fix data-race in udp_set_dev_scratch() (Davide Caratti) [1817671]
- [net] page_pool: refill page when alloc.count of pool is zero (Petr Oros) [1811201]
- [net] page_pool: help compiler remove code in case CONFIG_NUMA=n (Petr Oros) [1811201]
- [net] page_pool: handle page recycle for NUMA_NO_NODE condition (Petr Oros) [1811201]
- [netdrv] mlx5e: Rx, Update page pool numa node when changed (Petr Oros) [1811201]
- [net] page_pool: Don't recycle non-reusable pages (Petr Oros) [1811201]
- [net] page_pool: Add API to update numa node (Petr Oros) [1811201]
- [include] page_pool: extend tracepoint to also include the page PFN (Petr Oros) [1811201]
- [net] page_pool: add destroy attempts counter and rename tracepoint (Petr Oros) [1811201]
- [net] page_pool: remove unnecessary variable init (Petr Oros) [1811201]
- [net] page_pool: fix logic in __page_pool_get_cached (Petr Oros) [1811201]
- [netdrv] team: add missing attribute validation for array index (Hangbin Liu) [1816499]
- [netdrv] team: add missing attribute validation for port ifindex (Hangbin Liu) [1816499]
- [netdrv] team: Add vlan tx offload to hw_enc_features (Hangbin Liu) [1816499]
- [netdrv] team: set slave to promisc if team is already in promisc mode (Hangbin Liu) [1816499]
- [netdrv] team: Free BPF filter when unregistering netdev (Hangbin Liu) [1816499]
- [netdrv] net: Remove switchdev.h inclusion from team/bond/vlan (Hangbin Liu) [1816499]
- [netdrv] team: use operstate consistently for linkup (Hangbin Liu) [1816499]
- [netdrv] team: avoid complex list operations in team_nl_cmd_options_set() (Hangbin Liu) [1816499]
- [netdev] pass the stuck queue to the timeout handler (Ivan Vecera) [1811203]
- [net] flow_dissector: extract more ICMP information (Ivan Vecera) [1795213]
- [net] flow_dissector: skip the ICMP dissector for non ICMP packets (Ivan Vecera) [1795213]
- [net] flow_dissector: add meaningful comments (Ivan Vecera) [1795213]
- [net] vti[6]: fix packet tx through bpf_redirect() in XinY cases (Sabrina Dubroca) [1795145]
- [net] xfrm interface: fix packet tx through bpf_redirect() (Sabrina Dubroca) [1795145]
- [net] vti[6]: fix packet tx through bpf_redirect() (Sabrina Dubroca) [1795145]
- [documentation] Clarify trap's description (Petr Oros) [1809496]
- [net] devlink: Wait longer before warning about unset port type (Petr Oros) [1809496]
- [documentation] Add a section for devlink-trap testing (Petr Oros) [1809496]
- [tools] selftests: devlink_trap: Add test cases for devlink-trap (Petr Oros) [1809496]
- [tools] selftests: forwarding: devlink_lib: Add devlink-trap helpers (Petr Oros) [1809496]
- [tools] selftests: forwarding: devlink_lib: Allow tests to define devlink device (Petr Oros) [1809496]
- [documentation] Add devlink-trap documentation (Petr Oros) [1809496]
- [net] devlink: Add generic packet traps and groups (Petr Oros) [1809496]
- [net] devlink: Add packet trap infrastructure (Petr Oros) [1809496]
- [net] devlink: add warning in case driver does not set port type (Petr Oros) [1809496]
- [net] devlink: remove unused devlink_port_get_phys_port_name() function (Petr Oros) [1809496]
- [net] tcp: add sanity tests in tcp_add_backlog() (Guillaume Nault) [1790843]
- [net] tcp: implement coalescing on backlog queue (Guillaume Nault) [1790843]
- [include] tcp: make tcp_space() aware of socket backlog (Guillaume Nault) [1790843]
- [net] tcp: take care of compressed acks in tcp_add_reno_sack() (Guillaume Nault) [1790843]
- [include] tcp: hint compiler about sack flows (Guillaume Nault) [1790843]
- [net] tcp: drop dst in tcp_add_backlog() (Guillaume Nault) [1790843]
- [net] drop_monitor: Do not cancel uninitialized work item (Petr Oros) [1810114]
- [net] drop_monitor: Use kstrdup (Petr Oros) [1810114]
- [net] drop_monitor: Better sanitize notified packets (Petr Oros) [1810114]
- [net] drop_monitor: Make timestamps y2038 safe (Petr Oros) [1810114]
- [net] drop_monitor: Allow user to start monitoring hardware drops (Petr Oros) [1810114]
- [net] drop_monitor: Add support for summary alert mode for hardware drops (Petr Oros) [1810114]
- [net] drop_monitor: Add support for packet alert mode for hardware drops (Petr Oros) [1810114]
- [net] drop_monitor: Consider all monitoring states before performing configuration (Petr Oros) [1810114]
- [net] drop_monitor: Add basic infrastructure for hardware drops (Petr Oros) [1810114]
- [net] drop_monitor: Initialize hardware per-CPU data (Petr Oros) [1810114]
- [net] drop_monitor: Move per-CPU data init/fini to separate functions (Petr Oros) [1810114]
- [maintainers] drop_monitor: Add missing uAPI file to MAINTAINERS file (Petr Oros) [1810114]
- [net] drop_monitor: Expose tail drop counter (Petr Oros) [1810114]
- [net] drop_monitor: Make drop queue length configurable (Petr Oros) [1810114]
- [net] drop_monitor: Add a command to query current configuration (Petr Oros) [1810114]
- [net] drop_monitor: Allow truncation of dropped packets (Petr Oros) [1810114]
- [net] drop_monitor: Add packet alert mode (Petr Oros) [1810114]
- [net] drop_monitor: Add alert mode operations (Petr Oros) [1810114]
- [net] drop_monitor: Require CAP_NET_ADMIN for drop monitor configuration (Petr Oros) [1810114]
- [net] drop_monitor: Reset per-CPU data before starting to trace (Petr Oros) [1810114]
- [net] drop_monitor: Initialize timer and work item upon tracing enable (Petr Oros) [1810114]
- [net] drop_monitor: Split tracing enable / disable to different functions (Petr Oros) [1810114]
- [net] drop_monitor: Use pre_doit / post_doit hooks (Petr Oros) [1810114]
- [net] drop_monitor: Add extack support (Petr Oros) [1810114]
- [net] drop_monitor: Avoid multiple blank lines (Petr Oros) [1810114]
- [net] drop_monitor: Document scope of spinlock (Petr Oros) [1810114]
- [net] drop_monitor: Rename and document scope of mutex (Petr Oros) [1810114]
- [net] drop_monitor: Use correct error code (Petr Oros) [1810114]
- [net] revert "net: dev: introduce support for sch BYPASS for lockless qdisc" (Paolo Abeni) [1805983]
- [net] neighbour: remove neigh_cleanup() method (Ivan Vecera) [1795285]
- [include] trace: events: neigh_update: print new state in string format (Ivan Vecera) [1795285]
- [net] neigh: hook tracepoints in neigh update code (Ivan Vecera) [1795285]
- [net] trace: events: add a few neigh tracepoints (Ivan Vecera) [1795285]
- [net] netfilter: nf_tables: add __nft_chain_type_get() (Florian Westphal) [1806888]
- [net] devlink: Hang reporter's dump method on a dumpit cb (Andrea Claudi) [1804798]
- [net] core: Do not clear VF index for node/port GUIDs query (Petr Oros) [1805312]
- [net] core: Populate VF index in struct ifla_vf_guid (Petr Oros) [1805312]
- [net] core: Add support for getting VF GUIDs (Petr Oros) [1805312]
- [tools] ptp: Extend the test program to check the external time stamp flags (Petr Oros) [1795192]
- [netdrv] mlx5: Reject requests to enable time stamping on both edges (Petr Oros) [1795192]
- [netdrv] igb: Reject requests that fail to enable time stamping on both edges (Petr Oros) [1795192]
- [netdrv] dp83640: Reject requests to enable time stamping on both edges (Petr Oros) [1795192]
- [netdrv] mv88e6xxx: Reject requests to enable time stamping on both edges (Petr Oros) [1795192]
- [netdrv] ptp: Introduce strict checking of external time stamp options (Petr Oros) [1795192]
- [netdrv] renesas: reject unsupported external timestamp flags (Petr Oros) [1795192]
- [netdrv] mlx5: reject unsupported external timestamp flags (Petr Oros) [1795192]
- [netdrv] igb: reject unsupported external timestamp flags (Petr Oros) [1795192]
- [netdrv] dp83640: reject unsupported external timestamp flags (Petr Oros) [1795192]
- [netdrv] mv88e6xxx: reject unsupported external timestamp flags (Petr Oros) [1795192]
- [netdrv] net: reject PTP periodic output requests with unsupported flags (Petr Oros) [1795192]
- [ptp] Validate requests to enable time stamping of external signals (Petr Oros) [1795192]
- [tools] ptp: Fix example program to match kernel (Petr Oros) [1795192]
- [include] uaccess: add noop untagged_addr definition (Josef Oskera) [1805320]
- [include] debugfs: Add debugfs_create_xul() for hexadecimal unsigned long (Josef Oskera) [1795286]
- [documentation] debugfs: Document debugfs helper for unsigned long values (Josef Oskera) [1795286]
- [net] vsock/virtio: add WARN_ON check on virtio_transport_get_ops() (Stefano Garzarella) [1692797]
- [net] vsock/virtio: fix null-pointer dereference in virtio_transport_recv_listen() (Stefano Garzarella) [1692797]
- [net] vsock: avoid to assign transport if its initialization fails (Stefano Garzarella) [1692797]
- [misc] vsock/vmci: make vmci_vsock_cb_host_called static (Stefano Garzarella) [1692797]
- [net] vsock: fix bind() behaviour taking care of CID (Stefano Garzarella) [1692797]
- [net] vsock: prevent transport modules unloading (Stefano Garzarella) [1692797]
- [misc] vsock/vmci: register vmci_transport only when VMCI guest/host are active (Stefano Garzarella) [1692797]
- [net] vsock: add multi-transports support (Stefano Garzarella) [1692797]
- [net] hv_sock: set VMADDR_CID_HOST in the hvs_remote_addr_init() (Stefano Garzarella) [1692797]
- [net] vsock: move vsock_insert_unbound() in the vsock_create() (Stefano Garzarella) [1692797]
- [net] vsock: add vsock_create_connected() called by transports (Stefano Garzarella) [1692797]
- [net] vsock: handle buffer_size sockopts in the core (Stefano Garzarella) [1692797]
- [net] vsock: add 'struct vsock_sock *' param to vsock_core_get_transport() (Stefano Garzarella) [1692797]
- [net] vsock/virtio: add transport parameter to the virtio_transport_reset_no_sock() (Stefano Garzarella) [1692797]
- [net] vsock: add 'transport' member in the struct vsock_sock (Stefano Garzarella) [1692797]
- [kernel] vsock: remove linux/vm_sockets.h file (Stefano Garzarella) [1692797]
- [net] vsock: remove vm_sockets_get_local_cid() (Stefano Garzarella) [1692797]
- [net] vsock/vmci: remove unused VSOCK_DEFAULT_CONNECT_TIMEOUT (Stefano Garzarella) [1692797]
- [x86] kvm: x86: clear stale x86_emulate_ctxt->intercept value (Jon Maloy) [1806817] {CVE-2020-2732}
- [x86] kvm: vmx: check descriptor table exits on instruction emulation (Jon Maloy) [1806817] {CVE-2020-2732}
- [x86] kvm: nvmx: Check IO instruction VM-exit conditions (Jon Maloy) [1806817] {CVE-2020-2732}
- [x86] kvm: nvmx: Refactor IO bitmap checks into helper function (Jon Maloy) [1806817] {CVE-2020-2732}
- [x86] kvm: nvmx: Don't emulate instructions in guest mode (Jon Maloy) [1806817] {CVE-2020-2732}

* Wed Apr 01 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.3.el8]
- [fs] gfs2: Fix oversight in gfs2_ail1_flush (Robert S Peterson) [1724769]
- [kernel] sched/uclamp: Extend sched_setattr() to support utilization clamping (Phil Auld) [1810399]
- [kernel] sched/core: Further clarify sched_class::set_next_task() (Phil Auld) [1810399]
- [kernel] sched/fair: Use mul_u32_u32() (Phil Auld) [1810399]
- [kernel] sched/core: Simplify sched_class::pick_next_task() (Phil Auld) [1810399]
- [kernel] sched/core: Optimize pick_next_task() (Phil Auld) [1810399]
- [kernel] sched/core: Make pick_next_task_idle() more consistent (Phil Auld) [1810399]
- [kernel] sched/fair: Better document newidle_balance() (Phil Auld) [1810399]
- [kernel] sched: Fix pick_next_task() vs 'change' pattern race (Phil Auld) [1810399]
- [cpufreq] cpufreq: Initialize the governors in core_initcall (Phil Auld) [1810399]
- [kernel] sched/vtime: Fix guest/system mis-accounting on task switch (Phil Auld) [1810399]
- [kernel] sched/fair/util_est: Implement faster ramp-up EWMA on utilization increases (Phil Auld) [1810399]
- [kernel] sched/topology: Allow sched_asym_cpucapacity to be disabled (Phil Auld) [1810399]
- [kernel] sched/topology: Don't try to build empty sched domains (Phil Auld) [1810399]
- [kernel] sched/topology: Don't set SD_BALANCE_WAKE on cpuset domain relax (Phil Auld) [1810399]
- [kernel] membarrier: Fix RCU locking bug caused by faulty merge (Phil Auld) [1810399]
- [kernel] sched/core: Fix preempt_schedule() interrupt return comment (Phil Auld) [1810399]
- [kernel] sched/membarrier: Return -ENOMEM to userspace on memory allocation failure (Phil Auld) [1810399]
- [kernel] sched/membarrier: Skip IPIs when mm->mm_users == 1 (Phil Auld) [1810399]
- [tools] selftests, sched/membarrier: Add multi-threaded test (Phil Auld) [1810399]
- [kernel] sched/membarrier: Fix p->mm->membarrier_state racy load (Phil Auld) [1810399]
- [include] sched/membarrier: Call sync_core only before usermode for same mm (Phil Auld) [1810399]
- [kernel] sched/membarrier: Remove redundant check (Phil Auld) [1810399]
- [kernel] sched/membarrier: Fix private expedited registration check (Phil Auld) [1810399]
- [kernel] tasks, sched/core: RCUify the assignment of rq->curr (Phil Auld) [1810399]
- [kernel] tasks, sched/core: With a grace period after finish_task_switch(), remove unnecessary code (Phil Auld) [1810399]
- [kernel] tasks, sched/core: Ensure tasks are available for a grace period after leaving the runqueue (Phil Auld) [1810399]
- [kernel] tasks: Add a count of task RCU users (Phil Auld) [1810399]
- [include] sched/core: Convert task_struct.usage to refcount_t (Phil Auld) [1810399]
- [include] sched/core: Convert vcpu_is_preempted() from macro to an inline function (Phil Auld) [1810399]
- [kernel] sched/fair: Remove unused cfs_rq_clock_task() function (Phil Auld) [1810399]
- [scripts] Kbuild: Handle PREEMPT_RT for version string and magic (Phil Auld) [1810399]
- [kernel] sched/fair: Use rq_lock/unlock in online_fair_sched_group (Phil Auld) [1810399]
- [kernel] sched: Rework pick_next_task() slow-path (Phil Auld) [1810399]
- [kernel] sched: Allow put_prev_task() to drop rq->lock (Phil Auld) [1810399]
- [kernel] sched/fair: Expose newidle_balance() (Phil Auld) [1810399]
- [kernel] sched: Add task_struct pointer to sched_class::set_curr_task (Phil Auld) [1810399]
- [kernel] sched: Rework CPU hotplug task selection (Phil Auld) [1810399]
- [kernel] rcu/tree: Fix SCHED_FIFO params (Phil Auld) [1810399]
- [kernel] sched: Clean up active_mm reference counting (Phil Auld) [1810399]
- [kernel] sched/{rt, deadline}: Fix set_next_task vs pick_next_task (Phil Auld) [1810399]
- [kernel] sched: Fix kerneldoc comment for ia64_set_curr_task (Phil Auld) [1810399]
- [kernel] stop_machine: Fix stop_cpus_in_progress ordering (Phil Auld) [1810399]
- [kernel] sched/psi: Reduce psimon FIFO priority (Phil Auld) [1810399]
- [kernel] sched/psi: Do not require setsched permission from the trigger creator (Phil Auld) [1810399]
- [x86] x86/kvm: Use CONFIG_PREEMPTION (Phil Auld) [1810399]
- [x86] x86/dumpstack: Indicate PREEMPT_RT in dumps (Phil Auld) [1810399]
- [x86] x86: Use CONFIG_PREEMPTION (Phil Auld) [1810399]
- [kernel] kprobes: Use CONFIG_PREEMPTION (Phil Auld) [1810399]
- [kernel] tracing: Use CONFIG_PREEMPTION (Phil Auld) [1810399]
- [include] locking/spinlocks: Use CONFIG_PREEMPTION (Phil Auld) [1810399]
- [kernel] rcu: Use CONFIG_PREEMPTION (Phil Auld) [1810399]
- [kernel] sched/preempt: Use CONFIG_PREEMPTION where appropriate (Phil Auld) [1810399]
- [kernel] sched/core: Prevent race condition between cpuset and __sched_setscheduler() (Phil Auld) [1810399]
- [kernel] rcu/tree: Call setschedule() gp ktread to SCHED_FIFO outside of atomic region (Phil Auld) [1810399]
- [kernel] cgroup/cpuset: Change cpuset_rwsem and hotplug lock order (Phil Auld) [1810399]
- [kernel] cgroup/cpuset: Convert cpuset_mutex to percpu_rwsem (Phil Auld) [1810399]
- [kernel] sched/deadline: Fix bandwidth accounting at all levels after offline migration (Phil Auld) [1810399]
- [kernel] cpusets: Rebuild root domain deadline accounting information (Phil Auld) [1810399]
- [kernel] sched/core: Streamle calls to task_rq_unlock() (Phil Auld) [1810399]
- [kernel] sched/topology: Add partition_sched_domains_locked() (Phil Auld) [1810399]
- [kernel] sched/stats: Fix unlikely() use of sched_info_on() (Phil Auld) [1810399]
- [kernel] sched/fair: Change task_numa_work() storage to static (Phil Auld) [1810399]
- [kernel] sched/fair: Move task_numa_work() init to init_numa_balancing() (Phil Auld) [1810399]
- [kernel] sched/fair: Move init_numa_balancing() below task_numa_work() (Phil Auld) [1810399]
- [kernel] sched/rt, Kconfig: Unbreak def/oldconfig with CONFIG_PREEMPT=y (Phil Auld) [1810399]
- [kernel] sched/rt, Kconfig: Introduce CONFIG_PREEMPT_RT (Phil Auld) [1810399]
- [kernel] kconfig: include kernel/Kconfig.preempt from init/Kconfig (Phil Auld) [1810399]
- [kernel] sched/core: Fix preempt warning in ttwu (Phil Auld) [1810399]
- [kernel] sched/core: Optimize try_to_wake_up() for local wakeups (Phil Auld) [1810399]
- [kernel] sched/core: Introduce set_next_task() helper for better code readability (Phil Auld) [1810399]
- [kernel] sched/fair: Don't increase sd->balance_interval on newidle balance (Phil Auld) [1810399]
- [kernel] sched/fair: Clean up load_balance() condition (Phil Auld) [1810399]
- [mm] mm: fix possible PMD dirty bit lost in set_pmd_migration_entry() (Rafael Aquini) [1809698]
- [mm] mm, thp: fix defrag setting if newline is not used (Rafael Aquini) [1809698]
- [mm] mm/migrate.c: also overwrite error when it is bigger than zero (Rafael Aquini) [1809698]
- [mm] mm/mempolicy.c: fix out of bounds write in mpol_parse_str() (Rafael Aquini) [1809698]
- [mm] mm: memcg/slab: call flush_memcg_workqueue() only if memcg workqueue is valid (Rafael Aquini) [1809698]
- [mm] mm/page-writeback.c: avoid potential division by zero in wb_min_max_ratio() (Rafael Aquini) [1809698]
- [mm] mm/gup: fix memory leak in __gup_benchmark_ioctl (Rafael Aquini) [1809698]
- [mm] mm: move_pages: return valid node id in status if the page is already on the target node (Rafael Aquini) [1809698]
- [mm] mm/zsmalloc.c: fix the migrated zspage statistics (Rafael Aquini) [1809698]
- [mm] mm: memcg/slab: wait for !root kmem_cache refcnt killing on root kmem_cache destruction (Rafael Aquini) [1809698]
- [mm] mm/mempolicy.c: check range first in queue_pages_test_walk (Rafael Aquini) [1809698]
- [mm] mm/memory.c: fix a huge pud insertion race during faulting (Rafael Aquini) [1809698]
- [mm] mm: move the backup x_devmap() functions to asm-generic/pgtable.h (Rafael Aquini) [1809698]
- [mm] mm/rmap.c: don't reuse anon_vma if we just want a copy (Rafael Aquini) [1809698]
- [mm] mm/ksm.c: don't WARN if page is still mapped in remove_stable_node() (Rafael Aquini) [1809698]
- [mm] mm/page_io.c: do not free shared swap slots (Rafael Aquini) [1809698]
- [mm] mm: thp: handle page cache THP correctly in PageTransCompoundMap (Rafael Aquini) [1809698]
- [mm] mm/slub: fix a deadlock in show_slab_objects() (Rafael Aquini) [1809698]
- [mm] mm/vmpressure.c: fix a signedness bug in vmpressure_register_event() (Rafael Aquini) [1809698]
- [trace] include/trace/events/writeback.h: fix -Wstringop-truncation warnings (Rafael Aquini) [1809698]
- [mm] mm/compaction.c: clear total_{migrate, free}_scanned before scanning a new zone (Rafael Aquini) [1809698]
- [mm] mm/hmm: fix hmm_range_fault()'s handling of swapped out pages (Rafael Aquini) [1809698]
- [mm] mm/migrate.c: initialize pud_entry in migrate_vma() (Rafael Aquini) [1809698]
- [kernel] ptrace: restore smp_rmb() in __ptrace_may_access() (Rafael Aquini) [1809698]
- [documentation] mm: fix Documentation/vm/hmm.rst Sphinx warnings (Rafael Aquini) [1809698]
- [fs] writeback: fix inode cgroup switching comment (Rafael Aquini) [1809698]
- [include] mm/page_poison: update comment after code moved (Rafael Aquini) [1809698]
- [mm] mm/filemap: pass inclusive 'end_byte' parameter to filemap_range_has_page (Rafael Aquini) [1809698]
- [mm] ARM: 8826/1: mm: initialize pfn limits with find_limits() (Rafael Aquini) [1809698]
- [fs] mm, proc: report PR_SET_THP_DISABLE in proc (Rafael Aquini) [1809698]
- [mm] mm/khugepaged: fix crashes due to misaccounted holes (Rafael Aquini) [1809698]
- [include] writeback: don't decrement wb->refcnt if !wb->bdi (Rafael Aquini) [1809698]
- [mm] mm/filemap.c: Use existing variable (Rafael Aquini) [1809698]
- [fs] removed extra extern file_fdatawait_range (Rafael Aquini) [1809698]
- [s390] Revert "s390/dasd: Disable Thin Provisioning to prevent data loss" (Philipp Rudo) [1816984]
- [s390] s390/dasd: fix data corruption for thin provisioned devices (Philipp Rudo) [1816984]
- [block] virtio-blk: improve virtqueue error to BLK_STS (Philipp Rudo) [1816983]
- [block] virtio-blk: fix hw_queue stopped on arbitrary error (Philipp Rudo) [1816983]
- [s390] s390/pkey: fix missing length of protected key on return (Philipp Rudo) [1816981]
- [s390] s390/mm: fix panic in gup_fast on large pud (Philipp Rudo) [1816980]

* Tue Mar 31 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.2.el8]
- [mmc] mmc: core: Use a minimum 1600ms timeout when enabling CACHE ctrl (Yannick Cote) [1811430]
- [mmc] mmc: core: Allow BKOPS and CACHE ctrl even if no HPI support (Yannick Cote) [1811430]
- [net] net/smc: keep vlan_id for SMC-R in smc_listen_work() (Philipp Rudo) [1796890]
- [scripts] redhat: fix modpost.c prerequisites (Frantisek Hrbata) [1818499]
- [tools] tools/power/x86/intel-speed-select: Update version (Prarit Bhargava) [1817068]
- [tools] tools/power/x86/intel-speed-select: Change the order for clos disable (Prarit Bhargava) [1817068]
- [tools] tools/power/x86/intel-speed-select: Fix result display for turbo-freq auto mode (Prarit Bhargava) [1817068]
- [tools] tools/power/x86/intel-speed-select: Add support for core-power discovery (Prarit Bhargava) [1817068]
- [netdrv] can, slip: Protect tty->disc_data in write_wakeup and close with RCU (Steve Best) [1816036]
- [kernel] exit: panic before exit_mm() on global init exit (Oleg Nesterov) [1808944]
- [fs] nfsd: restore NFSv3 ACL support ("J. Bruce Fields") [1815683]
- [fs] nfsd4: Fix kernel crash when reading proc file reply_cache_stats ("J. Bruce Fields") [1815683]
- [fs] nfsd: fix cleanup of nfsd_reply_cache_init on failure ("J. Bruce Fields") [1815683]
- [fs] nfsd: note inadequate stats locking ("J. Bruce Fields") [1815683]
- [fs] nfsd4: drc containerization ("J. Bruce Fields") [1815683]
- [fs] nfsd: don't call nfsd_reply_cache_shutdown twice ("J. Bruce Fields") [1815683]
- [fs] nfsd: knfsd must use the container user namespace ("J. Bruce Fields") [1815683]
- [net] SUNRPC: rsi_parse() should use the current user namespace ("J. Bruce Fields") [1815683]
- [net] SUNRPC: Fix the server AUTH_UNIX userspace mappings ("J. Bruce Fields") [1815683]
- [fs] lockd: Pass the user cred from knfsd when starting the lockd server ("J. Bruce Fields") [1815683]
- [net] SUNRPC: Temporary sockets should inherit the cred from their parent ("J. Bruce Fields") [1815683]
- [fs] SUNRPC: Cache the process user cred in the RPC server listener ("J. Bruce Fields") [1815683]
- [fs] nfsd: Allow containers to set supported nfs versions ("J. Bruce Fields") [1815683]
- [fs] nfsd: Add custom rpcbind callbacks for knfsd ("J. Bruce Fields") [1815683]
- [fs] SUNRPC: Allow further customisation of RPC program registration ("J. Bruce Fields") [1815683]
- [net] SUNRPC: Clean up generic dispatcher code ("J. Bruce Fields") [1815683]
- [fs] SUNRPC: Add a callback to initialise server requests ("J. Bruce Fields") [1815683]
- [fs] SUNRPC/nfs: Fix return value for nfs4_callback_compound() ("J. Bruce Fields") [1815683]
- [kernel] sched: Avoid scale real weight down to zero (Phil Auld) [1808562]
- [nvme] nvme/pci: move cqe check after device shutdown (David Milburn) [1779247 1750267]
- [mm] mm, slb: guarantee natural alignment for kmalloc(power-of-two) (Brian Foster) [1814964]
- [tools] tools/power turbostat: Support Ice Lake server (Steve Best) [1776467]
- [pinctrl] pinctrl: intel: Allow to request locked pads (Prarit Bhargava) [1783115]
- [s390] s390/qeth: fix potential deadlock on workqueue flush (Philipp Rudo) [1814783]
- [s390] s390/qeth: streamline control code for promisc mode (Philipp Rudo) [1814783]
- [s390] scsi: zfcp: fix request object use-after-free in send path causing wrong traces (Philipp Rudo) [1814790]
- [s390] s390/pci: Fix possible deadlock in recover_store() (Philipp Rudo) [1814788]
- [s390] s390/pci: Recover handle in clp_set_pci_fn() (Philipp Rudo) [1814788]
- [s390] scsi: zfcp: fix rport unblock if deleted SCSI devices on Scsi_Host (Philipp Rudo) [1814794]
- [s390] scsi: zfcp: fix scsi_eh host reset with port_forced ERP for non-NPIV FCP devices (Philipp Rudo) [1814793]
- [s390] s390/cio: fix virtio-ccw DMA without PV (Philipp Rudo) [1814787]
- [s390] s390/kaslr: store KASLR offset for early dumps (Philipp Rudo) [1814781]
- [mm] s390/mm: fix dynamic pagetable upgrade for hugetlbfs (Philipp Rudo) [1814779]
- [char] tpm: ibmvtpm: retry on H_CLOSED in tpm_ibmvtpm_send() (Steve Best) [1808048]
- [s390] s390/qeth: fix dangling IO buffers after halt/clear (Philipp Rudo) [1814782]
- [virtio] virtio_ring: fix unmap of indirect descriptors (Philipp Rudo) [1797289]
- [virtio] virtio_ring: fix return code on DMA mapping fails (Philipp Rudo) [1797289]
- [misc] dma-mapping: zero memory returned from dma_alloc_* (Philipp Rudo) [1788928]
- [platform] platform/mellanox: fix the mlx-bootctl sysfs (Alaa Hleihel) [1655714]
- [platform] platform/mellanox: Add bootctl driver for Mellanox BlueField Soc (Alaa Hleihel) [1655714]
- [char] tpm: ibmvtpm: Wait for buffer to be set before proceeding (Steve Best) [1815548]
- [scsi] iscsi: Avoid potential deadlock in iscsi_if_rx func (Oleksandr Natalenko) [1815874]
- [x86] x86/vector: Remove warning on managed interrupt migration (Peter Xu) [1812331]
- [scsi] scsi: lpfc: fix spelling mistake "Notication" -> "Notification" (Dick Kennedy) [1796565]
- [scsi] scsi: lpfc: add RDF registration and Link Integrity FPIN logging (Dick Kennedy) [1796565]
- [uapi] scsi: fc: Update Descriptor definition and add RDF and Link Integrity FPINs (Dick Kennedy) [1796565]

* Sun Mar 29 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-193.1.el8]
- [kvm] KVM: PPC: Book3S HV: Use __gfn_to_pfn_memslot in HPT page fault handler (Sam Bobroff) [1815491]
- [net] tcp: also NULL skb->dev when copy was needed (Florian Westphal) [1775961]
- [net] tcp: ensure skb->dev is NULL before leaving TCP stack (Florian Westphal) [1775961]

* Thu Mar 26 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-192.2.el8]
- [mm] mm/memcontrol: use vmstat names for printing statistics (Waiman Long) [1793534]
- [base] mm/vmstat: add helpers to get vmstat item names for each enum type (Waiman Long) [1793534]
- [mm] mm/vmstat.c: assert that vmstat_text is in sync with stat_items_size (Waiman Long) [1793534]
- [mm] mm: memcontrol: dump memory.stat during cgroup OOM (Waiman Long) [1793534]
- [mm] mm/memcontrol.c: lost css_put in memcg_expand_shrinker_maps() (Waiman Long) [1793534]
- [mm] mm: memcg/slab: fix percpu slab vmstats flushing (Waiman Long) [1793534]
- [include] include/linux/memcontrol.h: fix comments based on per-node memcg (Waiman Long) [1793534]
- [mm] mm: memcg: switch to css_tryget() in get_mem_cgroup_from_mm() (Waiman Long) [1793534]
- [mm] mm: memcontrol: fix network errors from failing __GFP_ATOMIC charges (Waiman Long) [1793534]
- [mm] mm: slab: make page_cgroup_ino() to recognize non-compound slab pages properly (Waiman Long) [1793534]
- [mm] mm: memcontrol: fix NULL-ptr deref in percpu stats flush (Waiman Long) [1793534]
- [mm] mm/memcontrol: update lruvec counters in mem_cgroup_move_account (Waiman Long) [1793534]
- [mm] mm: memcg: get number of pages on the LRU list in memcgroup base on lru_zone_size (Waiman Long) [1793534]
- [mm] mm: memcontrol: fix percpu vmstats and vmevents flush (Waiman Long) [1793534]
- [mm] mm, memcg: partially revert "mm/memcontrol.c: keep local VM counters in sync with the hierarchical ones" (Waiman Long) [1793534]
- [mm] mm: memcontrol: flush percpu slab vmstats on kmem offlining (Waiman Long) [1793534]
- [mm] mm: memcontrol: flush percpu vmevents before releasing memcg (Waiman Long) [1793534]
- [mm] mm: memcontrol: flush percpu vmstats before releasing memcg (Waiman Long) [1793534]
- [mm] mm/memcontrol.c: keep local VM counters in sync with the hierarchical ones (Waiman Long) [1793534]
- [mm] mm/memcontrol: fix wrong statistics in memory.stat (Waiman Long) [1793534]
- [mm] mm: memcontrol: don't batch updates of local VM stats and events (Waiman Long) [1793534]
- [mm] mm: memcontrol: fix NUMA round-robin reclaim at intermediate level (Waiman Long) [1793534]
- [mm] mm: memcontrol: fix recursive statistics correctness & scalabilty (Waiman Long) [1793534]
- [mm] mm: memcontrol: move stat/event counting functions out-of-line (Waiman Long) [1793534]
- [mm] mm: memcontrol: make cgroup stats and events query API explicitly local (Waiman Long) [1793534]
- [mm] mm, memcg: rename ambiguously named memory.stat counters and functions (Waiman Long) [1793534]
- [mm] mm: memcontrol: quarantine the mem_cgroup_nr_lru_pages() API (Waiman Long) [1793534]
- [mm] mm: memcontrol: push down mem_cgroup_nr_lru_pages() (Waiman Long) [1793534]
- [mm] mm: memcontrol: push down mem_cgroup_node_nr_lru_pages() (Waiman Long) [1793534]
- [mm] mm: memcontrol: replace node summing with memcg_page_state() (Waiman Long) [1793534]
- [mm] mm: memcontrol: replace zone summing with lruvec_page_state() (Waiman Long) [1793534]
- [include] mm: memcontrol: track LRU counts in the vmstats array (Waiman Long) [1793534]
- [mm] mm: writeback: use exact memcg dirty counts (Waiman Long) [1793534]
- [mm] mm: memcontrol: expose THP events on a per-memcg basis (Waiman Long) [1793534]
- [mm] memcg: killed threads should not invoke memcg OOM killer (Waiman Long) [1793534]
- [mm] mm, memcg: extract memcg maxable seq_file logic to seq_show_memcg_tunable (Waiman Long) [1793534]
- [mm] mm, memcg: create mem_cgroup_from_seq (Waiman Long) [1793534]
- [mm] mm/oom_kill.c: fix uninitialized oc->constraint (Waiman Long) [1793534]
- [mm] mm, oom: add oom victim's memcg to the oom context information (Waiman Long) [1793534]
- [mm] mm, oom: reorganize the oom report in dump_header (Waiman Long) [1793534]
- [include] mm: Clarify the implication of adding new node stat items (Waiman Long) [1793534]
- [mm] memcg: Revert "Add preemption point in accumulate_memcg_tree()" (Waiman Long) [1793534]
- [base] driver core: add dev_groups to all drivers (Don Dutile) [1814347]
- [tools] selftests/livepatch: Remove unused local variable in set_ftrace_enabled() (Yannick Cote) [1807115]
- [tools] selftests/livepatch: Replace set_dynamic_debug() with setup_config() in README (Yannick Cote) [1807115]
- [tools] selftests: livepatch: Fix it to do root uid check and skip (Yannick Cote) [1807115]
- [tools] selftests/livepatch: Test interaction with ftrace_enabled (Yannick Cote) [1807115]
- [tools] selftests/livepatch: Make dynamic debug setup and restore generic (Yannick Cote) [1807115]
- [kernel] ftrace: Introduce PERMANENT ftrace_ops flag (Yannick Cote) [1807115]
- [samples] livepatch: Handle allocation failure in the sample of shadow variable API (Yannick Cote) [1807115]
- [lib] livepatch/samples/selftest: Use klp_shadow_alloc() API correctly (Yannick Cote) [1807115]
- [lib] livepatch/selftest: Clean up shadow variable names and type (Yannick Cote) [1807115]
- [samples] livepatch/sample: Use the right type for the leaking data pointer (Yannick Cote) [1807115]
- [kernel] kprobes: Allow kprobes coexist with livepatch (Yannick Cote) [1727330 1807115]
- [x86] ftrace/x86: Remove mcount() declaration (Yannick Cote) [1807115]
- [tools] selftests: livepatch: add missing fragments to config (Yannick Cote) [1807115]
- [lib] livepatch: Selftests of the API for tracking system state changes (Yannick Cote) [1807115]
- [documentation] livepatch: Documentation of the new API for tracking system state changes (Yannick Cote) [1807115]
- [kernel] livepatch: Allow to distinguish different version of system state changes (Yannick Cote) [1807115]
- [kernel] livepatch: Basic API to track system state changes (Yannick Cote) [1807115]
- [kernel] livepatch: Keep replaced patches until post_patch callback is called (Yannick Cote) [1807115]
- [tools] selftests/livepatch: Disable the timeout (Yannick Cote) [1807115]
- [kernel] livepatch: Nullify obj->mod in klp_module_coming()'s error path (Yannick Cote) [1807115]
- [powerpc] livepatch: Remove klp_check_compiler_support() (Yannick Cote) [1807115]
- [x86] ftrace/x86: Remove mcount support (Yannick Cote) [1807115]
- [x86] ftrace/x86_32: Remove support for non DYNAMIC_FTRACE (Yannick Cote) [1807115]
- [documentation] docs/livepatch: Unify style of livepatch documentation in the ReST format (Yannick Cote) [1807115]
- [documentation] docs: livepatch: convert docs to ReST and rename to *.rst (Yannick Cote) [1807115]
- [kernel] livepatch: Remove duplicate warning about missing reliable stacktrace support (Yannick Cote) [1807115]
- [kernel] livepatch: Use static buffer for debugging messages under rq lock (Yannick Cote) [1807115]
- [include] livepatch: Remove stale kobj_added entries from kernel-doc descriptions (Yannick Cote) [1807115]
- [kernel] livepatch: Remove duplicated code for early initialization (Yannick Cote) [1807115]
- [kernel] livepatch: Remove custom kobject state handling (Yannick Cote) [1807115]
- [kernel] livepatch: Convert error about unsupported reliable stacktrace into a warning (Yannick Cote) [1807115]
- [kernel] kprobes: Replace p with other pointer types (Yannick Cote) [1727330 1807115]

* Wed Mar 25 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-192.1.el8]
- [drm] drm/bochs: downgrade pci_request_region failure from error to warning (Dave Airlie) [1804735]
- [drm] drm/bochs: deinit bugfix (Dave Airlie) [1804735]
- [fs] gfs2: fix O_EXCL|O_CREAT handling on cold dcache (Andrew Price) [1811787]
- [net] esp: remove the skb from the chain when it's enqueued in cryptd_wq (Xin Long) [1807909]
- [powerpc] powerpc/nvdimm: set target_node properly (Diego Domingos) [1815038]

* Wed Mar 25 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-191.2.el8]
- [kernel] posix-cpu-timers: Fix two trivial comments (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Annotate lockless access to timer->base (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Fix permission check regression (Prarit Bhargava) [1810244]
- [include] posix-cpu-timers: Always clear head pointer on dequeue (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Add a missing bracket and hide `migration_base' on !SMP (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Make expiry_active check actually work correctly (Prarit Bhargava) [1810244]
- [include] posix-timers: Unbreak CONFIG_POSIX_TIMERS=n build (Prarit Bhargava) [1810244]
- [kernel] tick: Mark sched_timer to expire in hard interrupt context (Prarit Bhargava) [1810244]
- [include] posix-cpu-timers: Utilize timerqueue for storage (Prarit Bhargava) [1810244]
- [include] posix-cpu-timers: Move state tracking to struct posix_cputimers (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Deduplicate rlimit handling (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Remove pointless comparisons (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Get rid of 64bit divisions (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Consolidate timer expiry further (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Get rid of zero checks (Prarit Bhargava) [1810244]
- [kernel] rlimit: Rewrite non-sensical RLIMIT_CPU comment (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Respect INFINITY for hard RTTIME limit (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Switch thread group sampling to array (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Restructure expiry array (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Remove cputime_expires (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Make expiry checks array based (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Provide array based sample functions (Prarit Bhargava) [1810244]
- [include] posix-cpu-timers: Remove the odd field rename defines (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Switch check_*_timers() to array cache (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Simplify set_process_cpu_timer() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Simplify timer queueing (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Provide array based access to expiry cache (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Move expiry cache into struct posix_cputimers (Prarit Bhargava) [1810244]
- [include] sched: Move struct task_cputime to types.h (Prarit Bhargava) [1810244]
- [include] posix-cpu-timers: Create a container struct (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Move prof/virt_ticks into caller (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Sample task times once in expiry check (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Get rid of pointer indirection (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Simplify sample functions (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Remove pointless return value check (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Use clock ID in posix_cpu_timer_rearm() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Use clock ID in posix_cpu_timer_get() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Use clock ID in posix_cpu_timer_set() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Consolidate thread group sample code (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Rename thread_group_cputimer() and make it static (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Sample directly in timer check (Prarit Bhargava) [1810244]
- [kernel] itimers: Use quick sample function (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Provide quick sample function for itimer (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Use common permission check in posix_cpu_timer_create() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Use common permission check in posix_cpu_clock_get() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Provide task validation functions (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Remove tsk argument from run_posix_cpu_timers() (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Sanitize bogus WARNONS (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Don't take expiry_lock when timer is currently migrated (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Protect lockless access to timer->base (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Fixup stale comment (Prarit Bhargava) [1810244]
- [include] alarmtimers: Avoid rtc.h include (Prarit Bhargava) [1810244]
- [include] posix-timers: Cleanup forward declarations and includes (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Improve comments on handling priority inversion against softirq kthread (Prarit Bhargava) [1810244]
- [kernel] posix-timers: Use a callback for cancel synchronization on PREEMPT_RT (Prarit Bhargava) [1810244]
- [kernel] posix-timers: Move rcu_head out of it union (Prarit Bhargava) [1810244]
- [kernel] posix-timers: Rework cancel retry loops (Prarit Bhargava) [1810244]
- [kernel] posix-timers: Cleanup the flag/flags confusion (Prarit Bhargava) [1810244]
- [kernel] itimers: Prepare for PREEMPT_RT (Prarit Bhargava) [1810244]
- [fs] timerfd: Prepare for PREEMPT_RT (Prarit Bhargava) [1810244]
- [kernel] alarmtimer: Prepare for PREEMPT_RT (Prarit Bhargava) [1810244]
- [kernel] sched/deadline: Ensure inactive_timer runs in hardirq context (Prarit Bhargava) [1810244]
- [kernel] timers: Prepare support for PREEMPT_RT (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Prepare support for PREEMPT_RT (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Determine hard/soft expiry mode for hrtimer sleepers on RT (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Move unmarked hrtimers to soft interrupt expiry on RT (Prarit Bhargava) [1810244]
- [kernel] tick: Mark tick related hrtimers to expiry in hard interrupt context (Prarit Bhargava) [1810244]
- [kvm] KVM: LAPIC: Mark hrtimer to expire in hard interrupt context (Prarit Bhargava) [1810244]
- [kernel] watchdog: Mark watchdog_hrtimer to expire in hard interrupt context (Prarit Bhargava) [1810244]
- [kernel] perf/core: Mark hrtimers to expire in hard interrupt context (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Make enqueue mode check work on RT (Prarit Bhargava) [1810244]
- [kernel] sched: Mark hrtimers to expire in hard interrupt context (Prarit Bhargava) [1810244]
- [staging] hrtimer/treewide: Use hrtimer_sleeper_start_expires() (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Provide hrtimer_sleeper_start_expires() (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Consolidate hrtimer_init() + hrtimer_init_sleeper() calls (Prarit Bhargava) [1810244]
- [kernel] hrtimer: Remove task argument from hrtimer_init_sleeper() (Prarit Bhargava) [1810244]
- [kernel] futex: Consolidate duplicated timer setup code (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Remove private interval storage (Prarit Bhargava) [1810244]
- [kernel] posix-cpu-timers: Unbreak timer rearming (Prarit Bhargava) [1810244]
- [mm] mm, slub: naive detection of double-free or freelist corruption (Rafael Aquini) [1810288]
- [fs] nfs: add minor version to nfs_server_key for fscache (Dave Wysochanski) [1777097]
- [edac] EDAC, mellanox: Add ECC support for BlueField DDR4 (Alaa Hleihel) [1725108]
- [platform] platform/mellanox: fix potential deadlock in the tmfifo driver (Alaa Hleihel) [1655736]
- [platform] platform/mellanox: Add TmFifo driver for Mellanox BlueField Soc (Alaa Hleihel) [1655736]
- [mm] powerpc/pmem: Fix kernel crash due to wrong range value usage in flush_dcache_range (Steve Best) [1814279]
- [mm] powerpc: Chunk calls to flush_dcache_range in arch_*_memory (Steve Best) [1814279]
- [fs] cifs: fix NULL dereference in match_prepath (Leif Sahlberg) [1760879]
- [fs] cifs: fail i/o on soft mounts if sessionsetup errors out (Leif Sahlberg) [1798031]
- [sound] ALSA: usb-audio: set the interface format after resume on Dell WD19 (Perry Yuan) [1807965]
- [fs] cifs: make sure we do not overflow the max EA buffer size (Leif Sahlberg) [1752437]

* Sun Mar 22 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-191.1.el8]
- [netdrv] net/mlx5e: Don't clear the whole vf config when switching modes (mohamad meib) [1814350]
- [fs] fuse: fix stack use after return (Miklos Szeredi) [1814666]

* Sat Mar 21 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-190.3.el8]
- [target] scsi: Revert "target: iscsi: Wait for all commands to finish before freeing a session" (Maurizio Lombardi) [1784442]
- [infiniband] scsi: Revert "RDMA/isert: Fix a recently introduced regression related to logout" (Maurizio Lombardi) [1784442]
- [target] scsi: Revert "target/core: Inline transport_lun_remove_cmd()" (Maurizio Lombardi) [1784442]
- [target] scsi: libfc: remove unnecessary assertion on ep variable (Maurizio Lombardi) [1784442]
- [infiniband] scsi: RDMA/isert: Fix a recently introduced regression related to logout (Maurizio Lombardi) [1784442]
- [target] scsi: target/iblock: Fix protection error with blocks greater than 512B (Maurizio Lombardi) [1784442]
- [target] scsi: target: core: Fix a pr_debug() argument (Maurizio Lombardi) [1784442]
- [target] scsi: target: iscsi: Wait for all commands to finish before freeing a session (Maurizio Lombardi) [1784442]
- [target] scsi: target: core: Release SPC-2 reservations when closing a session (Maurizio Lombardi) [1784442]
- [target] scsi: target: core: Document target_cmd_size_check() (Maurizio Lombardi) [1784442]
- [target] scsi: target: tcmu: Prevent memory reclaim recursion (Maurizio Lombardi) [1784442]
- [scsi] scsi: cxgb4i: remove set but not used variable 'ppmax' (Maurizio Lombardi) [1784442]
- [target] scsi: target: remove unused extension parameters (Maurizio Lombardi) [1784442]
- [target] scsi: target: fix SendTargets=All string compares (Maurizio Lombardi) [1784442]
- [target] scsi: target: Remove tpg_list and se_portal_group.se_tpg_node (Maurizio Lombardi) [1784442]
- [target] scsi: target: cxgbit: Fix cxgbit_fw4_ack() (Maurizio Lombardi) [1784442]
- [infiniband] IB/hfi1: TID RDMA WRITE should not return IB_WC_RNR_RETRY_EXC_ERR (Kamal Heib) [1786601]
- [infiniband] IB/hfi1: Calculate flow weight based on QP MTU for TID RDMA (Kamal Heib) [1786601]
- [infiniband] IB/hfi1: Ensure r_tid_ack is valid before building TID RDMA ACK packet (Kamal Heib) [1786601]
- [infiniband] IB/hfi1: Ensure full Gen3 speed in a Gen4 system (Kamal Heib) [1786601]
- [infiniband] IB/core: Avoid deadlock during netlink message handling (Kamal Heib) [1786601]
- [infiniband] RDMA/efa: Fix incorrect error print (Kamal Heib) [1786601]
- [infiniband] IB/iser: Support up to 16MB data transfer in a single command (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Add missing cast for 32 bit (Kamal Heib) [1786601]
- [documentation] Documentation/infiniband: update name of some functions (Kamal Heib) [1786601]
- [infiniband] RDMA/iwpm: Delete unnecessary checks before the macro call "dev_kfree_skb" (Kamal Heib) [1786601]
- [infiniband] RDMA/efa: Use existing FIELD_SIZEOF macro (Kamal Heib) [1786601]
- [infiniband] RDMA/efa: Remove umem check on dereg MR flow (Kamal Heib) [1786601]
- [net] xprtrdma: Send Queue size grows after a reconnect (Kamal Heib) [1786601]
- [net] xprtrdma: Clear xprt->reestablish_timeout on close (Kamal Heib) [1786601]
- [net] xprtrdma: Recycle MRs after disconnect (Kamal Heib) [1786601]
- [net] xprtrdma: Optimize rpcrdma_post_recvs() (Kamal Heib) [1786601]
- [net] xprtrdma: Inline XDR chunk encoder functions (Kamal Heib) [1786601]
- [infiniband] RDMA/core: Make invalidate_range a device operation (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Use kvcalloc for the dma_list and page_list (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Check for overflow when computing the umem_odp end (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Provide ib_umem_odp_release() to undo the allocs (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Split creating a umem_odp from ib_umem_get (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Make the three ways to create a umem_odp clear (Kamal Heib) [1786601]
- [infiniband] RMDA/odp: Consolidate umem_odp initialization (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Make it clearer when a umem is an implicit ODP umem (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Iterate over the whole rbtree directly (Kamal Heib) [1786601]
- [infiniband] RDMA/odp: Use the common interval tree library instead of generic (Kamal Heib) [1786601]
- [net] xprtrdma: Clean up xprt_rdma_set_connect_timeout() (Kamal Heib) [1786601]
- [net] xprtrdma: Use an llist to manage free rpcrdma_reps (Kamal Heib) [1786601]
- [net] xprtrdma: Remove rpcrdma_buffer::rb_mrlock (Kamal Heib) [1786601]
- [net] xprtrdma: Cache free MRs in each rpcrdma_req (Kamal Heib) [1786601]
- [net] xprtrdma: Ensure creating an MR does not trigger FS writeback (Kamal Heib) [1786601]
- [net] xprtrdma: Move rpcrdma_mr_get out of frwr_map (Kamal Heib) [1786601]
- [net] xprtrdma: Combine rpcrdma_mr_put and rpcrdma_mr_unmap_and_put (Kamal Heib) [1786601]
- [net] xprtrdma: Simplify rpcrdma_mr_pop (Kamal Heib) [1786601]
- [net] xprtrdma: Rename rpcrdma_buffer::rb_all (Kamal Heib) [1786601]
- [net] xprtrdma: Rename CQE field in Receive trace points (Kamal Heib) [1786601]
- [infiniband] RDMA: Delete DEBUG code (Kamal Heib) [1786601]
- [include] xprtrdma: Boost client's max slot table size to match Linux server (Kamal Heib) [1786601]
- [net] xprtrdma: Boost maximum transport header size (Kamal Heib) [1786601]
- [net] xprtrdma: Fix calculation of ri_max_segs again (Kamal Heib) [1786601]
- [net] xprtrdma: Update obsolete comment (Kamal Heib) [1786601]
- [net] xprtrdma: Refresh the documenting comment in frwr_ops.c (Kamal Heib) [1786601]
- [net] svcrdma: Use llist for managing cache of recv_ctxts (Kamal Heib) [1786601]
- [net] svcrdma: Remove svc_rdma_wq (Kamal Heib) [1786601]
- [infiniband] RDMA/efa: Rate limit admin queue error prints (Kamal Heib) [1786601]
- [rdma] RDMA/core: Introduce ratelimited ibdev printk functions (Kamal Heib) [1786601]
- [net] rdma: Enable ib_alloc_cq to spread work over a device's comp_vectors (Kamal Heib) [1786601]
- [infiniband] RDMA/core: fix spelling mistake "Nelink" -> "Netlink" (Kamal Heib) [1786601]
- [infiniband] net: Use skb_frag_off accessors (Kamal Heib) [1786601]
- [infiniband] RDMA/efa: Expose device statistics (Kamal Heib) [1786601]
- [infiniband] RDMA/core: Support netlink commands in non init_net net namespaces (Kamal Heib) [1786601]
- [rdma] RDMA: Make most headers compile stand alone (Kamal Heib) [1786601]
- [infiniband] RDMA/core: Annotate destroy of mutex to ensure that it is released as unlocked (Kamal Heib) [1786601]
- [infiniband] net: Use skb accessors in network drivers (Kamal Heib) [1786601]
- [documentation] docs: infiniband: add it to the driver-api bookset (Kamal Heib) [1786601]
- [infiniband] IB/hfi1: use the new FOLL_LONGTERM flag to get_user_pages_fast() (Kamal Heib) [1786601]
- [documentation] Documentation/infiniband: update from locked to pinned_vm (Kamal Heib) [1786601]
- [infiniband] opa_vnic: fix check on record->event, incorrect operator used (Kamal Heib) [1786601]
- [infiniband] opa_vnic: Convert vport_idr to XArray (Kamal Heib) [1786601]
- [infiniband] IB/hfi1: Ensure ucast_dlid access doesnt exceed bounds (Kamal Heib) [1786601]
- [infiniband] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Kamal Heib) [1786601]
- [infiniband] treewide: Add SPDX license identifier - Kbuild (Kamal Heib) [1786601]
- [infiniband] mm/gup: add make_dirty arg to put_user_pages_dirty_lock() (Kamal Heib) [1786601]
- [netdrv] ibmvnic: Do not process device remove during device reset (Steve Best) [1813223]
- [bluetooth] Revert "Bluetooth: btusb: driver to enable the usb-wakeup feature" (Gopal Tiwari) [1811534]
- [tty] serial: 8250_pci: Make PCI class test non fatal (Prarit Bhargava) [1812742]
- [powercap] powercap/intel_rapl: add support for ICX-D (Steve Best) [1485067]
- [char] drivers: ipmi: fix off-by-one bounds check that leads to a out-of-bounds write (Tony Camuso) [1812922]
- [char] ipmi:ssif: Handle a possible NULL pointer reference (Tony Camuso) [1812922]
- [char] drivers: ipmi: Modify max length of IPMB packet (Tony Camuso) [1812922]
- [char] drivers: ipmi: Support raw i2c packet in IPMB (Tony Camuso) [1812922]
- [char] ipmi: fix ipmb_poll()'s return type (Tony Camuso) [1812922]
- [char] char: Fix Kconfig indentation, continued (Tony Camuso) [1812922]
- [char] char: Fix Kconfig indentation (Tony Camuso) [1812922]
- [char] ipmi: kill off 'timespec' usage again (Tony Camuso) [1812922]
- [char] drivers: ipmi: Support for both IPMB Req and Resp (Tony Camuso) [1812922]
- [char] ipmi: Fix memory leak in __ipmi_bmc_register (Tony Camuso) [1812922]
- [char] ipmi: bt-bmc: use devm_platform_ioremap_resource() to simplify code (Tony Camuso) [1812922]
- [char] ipmi: use *ph to print small buffer (Tony Camuso) [1812922]
- [char] ipmi: Don't leave holes in the I2C address list in the ssif driver (Tony Camuso) [1812922]
- [char] ipmi: fix return value of ipmi_set_my_LUN (Tony Camuso) [1812922]
- [char] ipmi: Convert pr_xxx() to dev_xxx() in the BT code (Tony Camuso) [1812922]
- [char] ipmi:dmi: Ignore IPMI SMBIOS entries with a zero base address (Tony Camuso) [1812922]
- [char] ipmi_si: fix potential integer overflow on large shift (Tony Camuso) [1812922]
- [char] ipmi_si_pci: fix NULL device in ipmi_si error message (Tony Camuso) [1812922]
- [char] ipmi: Convert printk(KERN_<level> to pr_<level>( (Tony Camuso) [1812922]
- [char] pci:ipmi: Move IPMI PCI class id defines to pci_ids.h (Tony Camuso) [1812922]
- [char] ipmi:powernv: Convert ipmi_smi_t to struct ipmi_smi (Tony Camuso) [1812922]
- [fs] NFSv4 fix acl retrieval over krb5i/krb5p mounts (Steve Dickson) [1787627]

* Fri Mar 20 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-190.2.el8]
- [fs] gfs2: Additional information when gfs2_ail1_flush withdraws (Robert S Peterson) [1752976]
- [fs] gfs2: Fix lru_count going negative (Robert S Peterson) [1752976]
- [fs] gfs2: allow journal replay to hold sd_log_flush_lock (Robert S Peterson) [1752976]
- [fs] gfs2: don't allow releasepage to free bd still used for revokes (Robert S Peterson) [1752976]
- [fs] gfs2: clean up iopen glock mess in gfs2_create_inode (Robert S Peterson) [1752976]
- [fs] gfs2: flesh out delayed withdraw for gfs2_log_flush (Robert S Peterson) [1752976]
- [fs] gfs2: Fix incorrect variable name (Robert S Peterson) [1752976]
- [fs] gfs2: Do proper error checking for go_sync family of glops functions (Robert S Peterson) [1752976]
- [fs] gfs2: Don't demote a glock until its revokes are written (Robert S Peterson) [1752976]
- [fs] gfs2: drain the ail2 list after io errors (Robert S Peterson) [1752976]
- [fs] gfs2: Withdraw in gfs2_ail1_flush if write_cache_pages fails (Robert S Peterson) [1752976]
- [fs] gfs2: Do log_flush in gfs2_ail_empty_gl even if ail list is empty (Robert S Peterson) [1752976]
- [fs] gfs2: Check for log write errors before telling dlm to unlock (Robert S Peterson) [1752976]
- [fs] gfs2: Prepare to withdraw as soon as an IO error occurs in log write (Robert S Peterson) [1752976]
- [fs] gfs2: Issue revokes more intelligently (Robert S Peterson) [1752976]
- [fs] gfs2: Add verbose option to check_journal_clean (Robert S Peterson) [1752976]
- [fs] gfs2: fix infinite loop when checking ail item count before go_inval (Robert S Peterson) [1752976]
- [fs] gfs2: Force withdraw to replay journals and wait for it to finish (Robert S Peterson) [1752976]
- [fs] gfs2: Allow some glocks to be used during withdraw (Robert S Peterson) [1752976]
- [fs] gfs2: move check_journal_clean to util.c for future use (Robert S Peterson) [1752976]
- [fs] gfs2: Ignore dlm recovery requests if gfs2 is withdrawn (Robert S Peterson) [1752976]
- [fs] gfs2: Only complain the first time an io error occurs in quota or log (Robert S Peterson) [1752976]
- [fs] gfs2: log error reform (Robert S Peterson) [1752976]
- [fs] gfs2: Rework how rgrp buffer_heads are managed (Robert S Peterson) [1752976]
- [fs] gfs2: clear ail1 list when gfs2 withdraws (Robert S Peterson) [1752976]
- [fs] gfs2: Introduce concept of a pending withdraw (Robert S Peterson) [1752976]
- [fs] gfs2: Return bool from gfs2_assert functions (Robert S Peterson) [1752976]
- [fs] gfs2: Turn gfs2_consist into void functions (Robert S Peterson) [1752976]
- [fs] gfs2: Remove usused cluster_wide arguments of gfs2_consist functions (Robert S Peterson) [1752976]
- [fs] gfs2: Report errors before withdraw (Robert S Peterson) [1752976]
- [fs] gfs2: Split gfs2_lm_withdraw into two functions (Robert S Peterson) [1752976]
- [fs] gfs2: Fix possible fs name overflows (Robert S Peterson) [1752976]
- [fs] gfs2: Remove active journal side effect from gfs2_write_log_header (Robert S Peterson) [1752976]
- [fs] gfs2: Don't loop forever in gfs2_freeze if withdrawn (Robert S Peterson) [1752976]
- [fs] gfs2: fix infinite loop in gfs2_ail1_flush on io error (Robert S Peterson) [1752976]
- [fs] gfs2: Introduce function gfs2_withdrawn (Robert S Peterson) [1752976]
- [fs] gfs2: fix glock reference problem in gfs2_trans_add_unrevoke (Robert S Peterson) [1752976]
- [fs] gfs2: make gfs2_log_shutdown static (Robert S Peterson) [1752976]
- [fs] gfs2: replace more printk with calls to fs_info and friends (Robert S Peterson) [1752976]
- [fs] gfs2: dump fsid when dumping glock problems (Robert S Peterson) [1752976]
- [fs] gfs2: simplify gfs2_freeze by removing case (Robert S Peterson) [1752976]
- [fs] gfs2: Rename SDF_SHUTDOWN to SDF_WITHDRAWN (Robert S Peterson) [1752976]
- [fs] gfs2: Warn when a journal replay overwrites a rgrp with buffers (Robert S Peterson) [1752976]
- [fs] gfs2: log which portion of the journal is replayed (Robert S Peterson) [1752976]
- [fs] gfs2: kthread and remount improvements (Robert S Peterson) [1752976]
- [fs] gfs2: Fix occasional glock use-after-free (Robert S Peterson) [1752976]
- [fs] gfs2: Rename sd_log_le_{revoke,ordered} (Robert S Peterson) [1724769]
- [watchdog] watchdog: make nowayout sysfs file writable (David Arcari) [1802742]
- [watchdog] watchdog: prevent deferral of watchdogd wakeup on RT (David Arcari) [1802742]
- [watchdog] watchdog: Fix the race between the release of watchdog_core_data and cdev (David Arcari) [1802742]
- [watchdog] watchdog: convert remaining drivers to use SPDX license identifier (David Arcari) [1802742]
- [watchdog] watchdog: make the device time out at open_deadline when open_timeout is used (David Arcari) [1802742]
- [watchdog] watchdog: introduce CONFIG_WATCHDOG_OPEN_TIMEOUT (David Arcari) [1802742]
- [watchdog] watchdog: introduce watchdog.open_timeout commandline parameter (David Arcari) [1802742]
- [watchdog] watchdog: let core print error message when registering device fails (David Arcari) [1802742]
- [watchdog] watchdog: make watchdog_deferred_registration_add() void (David Arcari) [1802742]
- [watchdog] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (David Arcari) [1802742]
- [watchdog] watchdog: add error messages when initializing timeout fails (David Arcari) [1802742]
- [watchdog] watchdog: refactor watchdog_init_timeout (David Arcari) [1802742]
- [watchdog] watchdog: core: fix null pointer dereference when releasing cdev (David Arcari) [1802742]
- [x86] x86/ioapic: Prevent inconsistent state when moving an interrupt (Prarit Bhargava) [1810236]
- [x86] x86/fpu: Don't cache access to fpu_fpregs_owner_ctx (Prarit Bhargava) [1810236]
- [lib] lib/ubsan: don't serialize UBSAN report (Prarit Bhargava) [1810243]
- [lib] ubsan, x86: Annotate and allow __ubsan_handle_shift_out_of_bounds() in uaccess regions (Prarit Bhargava) [1810243]
- [kernel] workqueue: Fix pwq ref leak in rescuer_thread() (Prarit Bhargava) [1810243]
- [kernel] workqueue: Fix missing kfree(rescuer) in destroy_workqueue() (Prarit Bhargava) [1810243]
- [kernel] workqueue: Fix spurious sanity check failures in destroy_workqueue() (Prarit Bhargava) [1810243]
- [include] hrtimer: Add kernel doc annotation for HRTIMER_MODE_HARD (Prarit Bhargava) [1810243]
- [kernel] genirq: Force interrupt threading on RT (Prarit Bhargava) [1810243]
- [include] hrtimer: Introduce HARD expiry mode (Prarit Bhargava) [1810243]
- [kernel] workqueue: Remove GPF argument from alloc_workqueue_attrs() (Prarit Bhargava) [1810243]
- [kernel] workqueue: Make alloc/apply/free_workqueue_attrs() static (Prarit Bhargava) [1810243]
- [tools] objtool: Add UACCESS validation (Prarit Bhargava) [1810243]
- [tools] objtool: Handle function aliases (Prarit Bhargava) [1810243]
- [lib] ubsan: build ubsan.c more conservatively (Prarit Bhargava) [1810243]
- [lib] x86/uaccess, ubsan: Fix UBSAN vs. SMAP (Prarit Bhargava) [1810243]
- [tools] objtool: Rewrite alt->skip_orig (Prarit Bhargava) [1810243]
- [fs] dlm: Don't swamp the CPU with callbacks queued during recovery (Robert S Peterson) [1752976]
- [nvme] nvmet: update AEN list and array at one place (Gopal Tiwari) [1781927]
- [nvme] nvmet: Fix controller use after free (Gopal Tiwari) [1781927]
- [nvme] nvmet: Fix error print message at nvmet_install_queue function (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: remove nvmeq->tags (Gopal Tiwari) [1781927]
- [nvme] nvmet: fix dsm failure when payload does not match sgl descriptor (Gopal Tiwari) [1781927]
- [nvme] nvme: hwmon: switch to use <linux/units.h> helpers (Gopal Tiwari) [1781927]
- [nvme] nvmet: fix per feat data len for get_feature (Gopal Tiwari) [1781927]
- [nvme] nvme/pci: Fix read queue count (Gopal Tiwari) [1781927]
- [nvme] nvme/pci Limit write queue sizes to possible cpus (Gopal Tiwari) [1781927]
- [nvme] nvme/pci: Fix write and poll queue types (Gopal Tiwari) [1781927]
- [nvme] nvme/pci: Remove last_cq_head (Gopal Tiwari) [1781927]
- [nvme] nvme: Namepace identification descriptor list is optional (Gopal Tiwari) [1781927]
- [nvme] Revert "nvme: Add quirk for Kingston NVME SSD running FW E8FK11.T" (Gopal Tiwari) [1781927]
- [nvme] nvme: else following return is not needed (Gopal Tiwari) [1781927]
- [nvme] nvme: add error message on mismatching controller ids (Gopal Tiwari) [1781927]
- [nvme] nvme_fc: add module to ops template to allow module references (Gopal Tiwari) [1781927]
- [nvme] nvmet-loop: Avoid preallocating big SGL for data (Gopal Tiwari) [1781927]
- [nvme] nvme-fc: Avoid preallocating big SGL for data (Gopal Tiwari) [1781927]
- [nvme] nvme-rdma: Avoid preallocating big SGL for data (Gopal Tiwari) [1781927]
- [nvme] nvme: hwmon: add quirk to avoid changing temperature threshold (Gopal Tiwari) [1781927]
- [nvme] nvme: hwmon: provide temperature min and max values for each sensor (Gopal Tiwari) [1781927]
- [nvme] nvme: Discard workaround for non-conformant devices (Gopal Tiwari) [1781927]
- [nvme] nvme: Add hardware monitoring support (Gopal Tiwari) [1781927]
- [nvme] nvme-multipath: fix crash in nvme_mpath_clear_ctrl_paths (Gopal Tiwari) [1781927]
- [nvme] nvme-rdma: fix a segmentation fault during module unload (Gopal Tiwari) [1781927]
- [nvme] nvmet: clean up command parsing a bit (Gopal Tiwari) [1781927]
- [nvme] nvmet: fill discovery controller sn, fr and mn correctly (Gopal Tiwari) [1781927]
- [nvme] nvmet: Open code nvmet_req_execute() (Gopal Tiwari) [1781927]
- [nvme] nvmet: Remove the data_len field from the nvmet_req struct (Gopal Tiwari) [1781927]
- [nvme] nvmet: add plugging for read/write when ns is bdev (Gopal Tiwari) [1781927]
- [nvme] nvmet: stop using bio_set_op_attrs (Gopal Tiwari) [1781927]
- [nvme] nvmet: Introduce nvmet_dsm_len() helper (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Spelling s/resdicovered/rediscovered/ (Gopal Tiwari) [1781927]
- [nvme] nvmet-tcp: Don't check data_len in nvmet_tcp_map_data() (Gopal Tiwari) [1781927]
- [nvme] nvme: Introduce nvme_lba_to_sect() (Gopal Tiwari) [1781927]
- [nvme] nvmet-tcp: Don't set the request's data_len (Gopal Tiwari) [1781927]
- [nvme] nvmet: Cleanup discovery execute handlers (Gopal Tiwari) [1781927]
- [nvme] nvmet-rdma: add unlikely check at nvmet_rdma_map_sgl_keyed (Gopal Tiwari) [1781927]
- [nvme] nvme: Cleanup and rename nvme_block_nr() (Gopal Tiwari) [1781927]
- [nvme] nvme: introduce "Command Aborted By host" status code (Gopal Tiwari) [1781927]
- [nvme] nvmet: Introduce common execute function for get_log_page and identify (Gopal Tiwari) [1781927]
- [nvme] nvme: move common call to nvme_cleanup_cmd to core layer (Gopal Tiwari) [1781927]
- [nvme] nvmet: add unlikely check at nvmet_req_alloc_sgl (Gopal Tiwari) [1781927]
- [nvme] nvme-fc: ensure association_id is cleared regardless of a Disconnect LS (Gopal Tiwari) [1781927]
- [nvme] nvme-fc: clarify error messages (Gopal Tiwari) [1781927]
- [nvme] nvme: introduce nvme_is_aen_req function (Gopal Tiwari) [1781927]
- [nvme] nvme-fc and nvmet-fc: sync with FC-NVME-2 header changes (Gopal Tiwari) [1781927]
- [nvme] nvmet: use bio_io_error instead of duplicating it (Gopal Tiwari) [1781927]
- [nvme] nvme-fc: Set new cmd set indicator in nvme-fc cmnd iu (Gopal Tiwari) [1781927]
- [nvme] nvme-multipath: remove unused groups_only mode in ana log (Gopal Tiwari) [1781927]
- [nvme] nvme-multipath: fix possible io hang after ctrl reconnect (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: fix possible leakage during error flow (Gopal Tiwari) [1781927]
- [nvme] nvmet-loop: fix possible leakage during error flow (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: Initialize sk->sk_ll_usec only with NET_RX_BUSY_POLL (Gopal Tiwari) [1781927]
- [nvme] nvme: Wait for reset state when required (Gopal Tiwari) [1781927]
- [nvme] nvme: Prevent resets during paused controller state (Gopal Tiwari) [1781927]
- [nvme] nvme: Restart request timers in resetting state (Gopal Tiwari) [1781927]
- [nvme] nvme: Remove ADMIN_ONLY state (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Free tagset if no IO queues (Gopal Tiwari) [1781927]
- [nvme] nvme: fix possible deadlock when nvme_update_formats fails (Gopal Tiwari) [1781927]
- [include] nvme-fc: Sync nvme-fc header to FC-NVME-2 (Gopal Tiwari) [1781927]
- [nvme] nvme: retain split access workaround for capability reads (Gopal Tiwari) [1781927]
- [nvme] nvme: Move ctrl sqsize to generic space (Gopal Tiwari) [1781927]
- [nvme] nvme: Add ctrl attributes for queue_count and sqsize (Gopal Tiwari) [1781927]
- [nvme] nvme: allow 64-bit results in passthru commands (Gopal Tiwari) [1781927]
- [nvme] nvme-rdma: Fix max_hw_sectors calculation (Gopal Tiwari) [1781927]
- [nvme] Added QUIRKs for ADATA XPG SX8200 Pro 512GB (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: fix wrong stop condition in io_work (Gopal Tiwari) [1781927]
- [nvme] nvme: fix an error code in nvme_init_subsystem() (Gopal Tiwari) [1781927]
- [nvme] nvmet-tcp: remove superflous check on request sgl (Gopal Tiwari) [1781927]
- [nvme] nvme: Add quirk for Kingston NVME SSD running FW E8FK11.T (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Fix a race in controller removal (Gopal Tiwari) [1781927]
- [nvme] nvmet: change ppl to lpp (Gopal Tiwari) [1781927]
- [nvme] nvme: add uevent variables for controller devices (Gopal Tiwari) [1781927]
- [nvme] nvme: Remove redundant assignment of cq vector (Gopal Tiwari) [1781927]
- [nvme] nvme: enable aen regardless of the presence of I/O queues (Gopal Tiwari) [1781927]
- [nvme] nvme: send discovery log page change events to userspace (Gopal Tiwari) [1781927]
- [nvme] nvme: Assign subsys instance from first ctrl (Gopal Tiwari) [1781927]
- [nvme] nvmet: fix a wrong error status returned in error log page (Gopal Tiwari) [1781927]
- [nvme] nvme: tcp: remove redundant assignment to variable ret (Gopal Tiwari) [1781927]
- [nvme] nvme-fabrics: allow discovery subsystems accept a kato (Gopal Tiwari) [1781927]
- [nvme] nvmet: Use PTR_ERR_OR_ZERO() in nvmet_init_discovery() (Gopal Tiwari) [1781927]
- [nvme] nvme: Treat discovery subsystems as unique subsystems (Gopal Tiwari) [1781927]
- [nvme] nvme-fc: Fail transport errors with NVME_SC_HOST_PATH (Gopal Tiwari) [1781927]
- [nvme] nvme: make nvme_report_ns_ids propagate error back (Gopal Tiwari) [1781927]
- [nvme] nvme: pass status to nvme_error_status (Gopal Tiwari) [1781927]
- [nvme] nvme: fix ns removal hang when failing to revalidate due to a transient error (Gopal Tiwari) [1781927]
- [nvme] nvme: make nvme_identify_ns propagate errors back (Gopal Tiwari) [1781927]
- [nvme] nvme: fail cancelled commands with NVME_SC_HOST_PATH_ERROR (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: fail command with NVME_SC_HOST_PATH_ERROR send failed (Gopal Tiwari) [1781927]
- [nvme] nvme: include admin_q sync with nvme_sync_queues (Gopal Tiwari) [1781927]
- [nvme] nvme-fc: Use rq_dma_dir macro (Gopal Tiwari) [1781927]
- [nvme] nvme-rdma: Use rq_dma_dir macro (Gopal Tiwari) [1781927]
- [nvme] nvme-rdma: Add TOS for rdma transport (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Support shared tags across queues for Apple 2018 controllers (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Add support for Apple 2018+ models (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Add support for variable IO SQ element size (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: Add TOS for tcp transport (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: Use struct nvme_ctrl directly (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: Pass the queue to SQ_SIZE/CQ_SIZE macros (Gopal Tiwari) [1781927]
- [nvme] nvmet-tcp: Add TOS for tcp transport (Gopal Tiwari) [1781927]
- [nvme] nvme: trace bio completion (Gopal Tiwari) [1781927]
- [nvme] nvmet-tcp: fix possible NULL deref (Gopal Tiwari) [1781927]
- [nvme] nvme: tcp: selects CRYPTO_CRC32C for nvme-tcp (Gopal Tiwari) [1781927]
- [nvme] nvme-fabrics: Add type of service (TOS) configuration (Gopal Tiwari) [1781927]
- [nvme] nvmet: trace: parse Get LBA Status command in detail (Gopal Tiwari) [1781927]
- [nvme] nvmet: fix data units read and written counters in SMART log (Gopal Tiwari) [1781927]
- [nvme] nvmet-tcp: fix possible memory leak (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: support simple polling (Gopal Tiwari) [1781927]
- [nvme] nvme: trace: parse Get LBA Status command in detail (Gopal Tiwari) [1781927]
- [include] nvme: add Get LBA Status command opcode (Gopal Tiwari) [1781927]
- [nvme] nvme: move sqsize setting to the core (Gopal Tiwari) [1781927]
- [nvme] nvme: don't pass cap to nvme_disable_ctrl (Gopal Tiwari) [1781927]
- [nvme] nvme-pci: set ctrl sqsize to the device q_depth (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: cleanup nvme_tcp_recv_pdu (Gopal Tiwari) [1781927]
- [nvme] nvme: have nvme_init_identify set ctrl->cap (Gopal Tiwari) [1781927]
- [nvme] nvme-tcp: Use protocol specific operations while reading socket (Gopal Tiwari) [1781927]
- [nvme] nvme: Fix cntlid validation when not using NVMEoF (Gopal Tiwari) [1781927]
- [infiniband] PCI/P2PDMA: Introduce pci_p2pdma_unmap_sg() (Gopal Tiwari) [1781927]
- [nvme] PCI/P2PDMA: Add attrs argument to pci_p2pdma_map_sg() (Gopal Tiwari) [1781927]
- [lightnvm] lightnvm: remove nvm_submit_io_sync_fn (Gopal Tiwari) [1781927]
- [powerpc] xive: Discard ESB load value when interrupt is invalid (David Gibson) [1744408]
- [documentation] kvm: ppc: book3s hv: xive: Allow userspace to set the # of VPs (David Gibson) [1744408]
- [powerpc] kvm: ppc: book3s hv: xive: Make VP block size configurable (David Gibson) [1744408]
- [powerpc] kvm: ppc: book3s hv: xive: Set kvm->arch.xive when VPs are allocated (David Gibson) [1744408]
- [powerpc] kvm: ppc: book3s hv: xive: Compute the VP id in a common helper (David Gibson) [1744408]
- [powerpc] xive: Implement get_irqchip_state method for XIVE to fix shutdown race (David Gibson) [1744408]
- [powerpc] kvm: ppc: book3s hv: xive: Free escalation interrupts before disabling the VP (David Gibson) [1744408]
- [powerpc] kvm: ppc: book3s hv: xive: Ensure VP isn't already in use (David Gibson) [1744408]
- [powerpc] kvm: ppc: book3s hv: Fix regression on big endian hosts (David Gibson) [1725763]
- [powerpc] 64s: Fix misleading SPR and timebase information (David Gibson) [1725763]
- [powerpc] powernv: Add ultravisor message log interface (David Gibson) [1725763]
- [powerpc] powernv/opal-msglog: Refactor memcons code (David Gibson) [1725763]
- [powerpc] kvm: Use UV_RETURN ucall to return to ultravisor (David Gibson) [1725763]
- [powerpc] powernv: Access LDBAR only if ultravisor disabled (David Gibson) [1725763]
- [powerpc] powernv/idle: Fix restore of SPRN_LDBAR for POWER9 stop state (David Gibson) [1725763]
- [powerpc] powernv/idle: Restore AMR/UAMOR/AMOR/IAMR after idle (David Gibson) [1725763]
- [powerpc] 64s: Reimplement book3s idle code in C (David Gibson) [1725763]
- [powerpc] revert "powerpc/powernv/idle: Restore IAMR after idle" (David Gibson) [1725763]
- [powerpc] revert "powerpc/powernv/idle: Restore AMR/UAMOR/AMOR after idle" (David Gibson) [1725763]
- [powerpc] mm: Write to PTCR only if ultravisor disabled (David Gibson) [1725763]
- [powerpc] mm: Use UV_WRITE_PATE ucall to register a PATE (David Gibson) [1725763]
- [powerpc] powernv: Introduce FW_FEATURE_ULTRAVISOR (David Gibson) [1725763]
- [powerpc] kernel: Add ucall_norets() ultravisor call handler (David Gibson) [1725763]
- [documentation] documentation/powerpc: Ultravisor API (David Gibson) [1725763]
- [documentation] documentation/powerpc: Add ELF note documentation (David Gibson) [1725763]
- [powerpc] Add PowerPC Capabilities ELF note (David Gibson) [1725763]
- [netdrv] mlx5e: allow TSO on VXLAN over VLAN topologies (Davide Caratti) [1780643]
- [net] bluetooth: Add debug setting for changing minimum encryption key size (Gopal Tiwari) [1764976]
- [net] bluetooth: hidp: Let hidp_send_message return number of queued bytes (Gopal Tiwari) [1764976]
- [net] bluetooth: 6lowpan: search for destination address in all peers (Gopal Tiwari) [1764976]
- [net] bluetooth: 6lowpan: always check destination address (Gopal Tiwari) [1764976]
- [net] bluetooth: 6lowpan: check neighbour table for SLAAC (Gopal Tiwari) [1764976]
- [net] bluetooth: Add SMP workaround Microsoft Surface Precision Mouse bug (Gopal Tiwari) [1764976]
- [net] bluetooth: Use controller sets when available (Gopal Tiwari) [1764976]
- [net] bluetooth: l2cap: Check bearer type on __l2cap_global_chan_by_addr (Gopal Tiwari) [1764976]
- [net] bluetooth: validate BLE connection interval updates (Gopal Tiwari) [1764976]
- [net] bluetooth: Add support for LE ping feature (Gopal Tiwari) [1764976]
- [net] bluetooth: Check state in l2cap_disconnect_rsp (Gopal Tiwari) [1764976]
- [net] bluetooth: hidp: NUL terminate a string in the compat ioctl (Gopal Tiwari) [1764976]
- [net] bluetooth: Ignore CC events not matching the last HCI command (Gopal Tiwari) [1764976]
- [net] bluetooth: Align minimum encryption key size for LE and BR/EDR connections (Gopal Tiwari) [1764976]
- [net] bluetooth: hci_core: Don't stop BT if the BD address missing in dts (Gopal Tiwari) [1764976]
- [net] bluetooth: Use struct_size() helper (Gopal Tiwari) [1764976]
- [net] bluetooth: Fix incorrect pointer arithmatic in ext_adv_report_evt (Gopal Tiwari) [1764976]
- [net] bluetooth: hidp: fix buffer overflow (Gopal Tiwari) [1764976]
- [net] bluetooth: Add return check for L2CAP security level set (Gopal Tiwari) [1764976]
- [net] bluetooth: Fix not initializing L2CAP tx_credits (Gopal Tiwari) [1764976]
- [net] bluetooth: Check address length before reading address field (Gopal Tiwari) [1764976]
- [net] bluetooth: Add quirk for reading BD_ADDR from fwnode property (Gopal Tiwari) [1764976]
- [net] bluetooth: mgmt: Use struct_size() helper (Gopal Tiwari) [1764976]
- [net] bluetooth: a2mp: Use struct_size() helper (Gopal Tiwari) [1764976]
- [net] bluetooth: hci_event: Use struct_size() helper (Gopal Tiwari) [1764976]
- [net] bluetooth: Fix decrementing reference count twice in releasing socket (Gopal Tiwari) [1764976]
- [net] bluetooth: make hw_err static, reduces object code size (Gopal Tiwari) [1764976]
- [net] bluetooth: Allow driver specific cmd timeout handling (Gopal Tiwari) [1764976]
- [net] bluetooth: Mark expected switch fall-throughs (Gopal Tiwari) [1764976]
- [net] bluetooth: Check L2CAP option sizes returned from l2cap_get_conf_opt (Gopal Tiwari) [1764976]
- [net] Bluetooth: Fix locking in bt_accept_enqueue() for BH context (Gopal Tiwari) [1764976]
- [net] bluetooth: 6lowpan: Fix debugfs_simple_attr.cocci warnings (Gopal Tiwari) [1764976]
- [net] bluetooth: Fix unnecessary error message for HCI request completion (Gopal Tiwari) [1764976]
- [net] bluetooth: clean an indentation issue, remove extraneous space (Gopal Tiwari) [1764976]
- [net] bluetooth: Change to use DEFINE_SHOW_ATTRIBUTE macro (Gopal Tiwari) [1764976]
- [net] bluetooth: Remove redundant check on status (Gopal Tiwari) [1764976]
- [net] bluetooth: Errata Service Release 8, Erratum 3253 (Gopal Tiwari) [1764976]
- [net] bluetooth: Use separate L2CAP LE credit based connection result values (Gopal Tiwari) [1764976]
- [net] rfcomm: get rid of mentioning TIOC[SG]SERIAL (Gopal Tiwari) [1764976]
- [net] bluetooth: Fix debugfs NULL pointer dereference (Gopal Tiwari) [1764976]
- [net] bluetooth: l2cap: Detect if remote is not able to use the whole MPS (Gopal Tiwari) [1764976]
- [net] bluetooth: l2cap: Derive rx credits from MTU and MPS (Gopal Tiwari) [1764976]
- [net] bluetooth: l2cap: Derive MPS from connection MTU (Gopal Tiwari) [1764976]
- [net] bluetooth: Add definitions and track LE resolve list modification (Gopal Tiwari) [1764976]
- [net] bluetooth: Remove unnecessary smp_mb__{before, after}_atomic (Gopal Tiwari) [1764976]
- [net] bluetooth: smp: fix crash in unpairing (Gopal Tiwari) [1764976]
- [net] bluetooth: smp: Fix trying to use non-existent local OOB data (Gopal Tiwari) [1764976]
- [net] bluetooth: Use correct tfm to generate OOB data (Gopal Tiwari) [1764976]
- [net] hidp: fix compat_ioctl (Gopal Tiwari) [1764976]
- [net] hidp: constify hidp_connection_add() (Gopal Tiwari) [1764976]
- [net] cmtp: fix compat_ioctl (Gopal Tiwari) [1764976]
- [net] bnep: fix compat_ioctl (Gopal Tiwari) [1764976]
- [net] bluetooth: Add definitions for LE set address resolution (Gopal Tiwari) [1764976]
- [net] bluetooth: remove redundant variables 'adv_set' and 'cp' (Gopal Tiwari) [1764976]
- [net] bluetooth: hidp: Fix handling of strncpy for hid->name information (Gopal Tiwari) [1764976]
- [net] bluetooth: Add new quirk for non-persistent setup settings (Gopal Tiwari) [1764976]
- [net] bluetooth: Handle ADv set terminated event (Gopal Tiwari) [1764976]
- [net] bluetooth: Implement secondary advertising on different PHYs (Gopal Tiwari) [1764976]
- [net] bluetooth: Implement Set ADV set random address (Gopal Tiwari) [1764976]
- [net] bluetooth: Implement disable and removal of adv instance (Gopal Tiwari) [1764976]
- [net] bluetooth: Use ext adv for directed adv (Gopal Tiwari) [1764976]
- [net] bluetooth: Implement PHY changed event (Gopal Tiwari) [1764976]
- [net] bluetooth: Handle extended ADV PDU types (Gopal Tiwari) [1764976]
- [net] bluetooth: Use Set ext adv/scan rsp data if controller supports (Gopal Tiwari) [1764976]
- [net] bluetooth: Impmlement extended adv enable (Gopal Tiwari) [1764976]
- [net] bluetooth: Define PHY flags in hdev and set 1M as default (Gopal Tiwari) [1764976]
- [net] bluetooth: Read no of adv sets during init (Gopal Tiwari) [1764976]
- [net] bluetooth: Implement Get PHY Configuration mgmt command (Gopal Tiwari) [1764976]
- [net] bluetooth: Use selected PHYs in extended connect (Gopal Tiwari) [1764976]
- [net] bluetooth: Set Scan PHYs based on selected PHYs by user (Gopal Tiwari) [1764976]
- [net] bluetooth: Implement Set PHY Confguration command (Gopal Tiwari) [1764976]
- [net] bluetooth: Add defines for BREDR pkt_type (Gopal Tiwari) [1764976]
- [net] bluetooth: Use lock_sock_nested in bt_accept_enqueue (Gopal Tiwari) [1764976]
- [net] bluetooth: avoid killing an already killed socket (Gopal Tiwari) [1764976]
- [net] bluetooth: Use extended LE Connection if supported (Gopal Tiwari) [1764976]
- [net] bluetooth: Introduce helpers for le conn status and complete (Gopal Tiwari) [1764976]
- [net] bluetooth: Process extended ADV report event (Gopal Tiwari) [1764976]
- [net] bluetooth: Use extended scanning if controller supports (Gopal Tiwari) [1764976]
- [net] bluetooth: Introduce helpers for LE set scan start and complete (Gopal Tiwari) [1764976]
- [net] bluetooth: Store Resolv list size (Gopal Tiwari) [1764976]
- [net] bluetooth: Add HCI command for clear Resolv list (Gopal Tiwari) [1764976]
- [leds] triggers: let struct (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Skip 1 error print in device_want_to_sleep() (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Reset download type to default (Gopal Tiwari) [1764976]
- [bluetooth] btqca: release_firmware after qca_inject_cmd_complete_event (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Send VS pre shutdown command (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Use correct byte format for opcode of injected command (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Add a short delay before downloading the NVM (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Fix error return code in btusb_mtk_setup_firmware() (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Use kfree_skb() instead of kfree() (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Add protocol support for MediaTek MT7663U USB devices (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Add protocol support for MediaTek MT7668U USB devices (Gopal Tiwari) [1764976]
- [bluetooth] Add new 13d3:3491 QCA_ROME device (Gopal Tiwari) [1764976]
- [bluetooth] Add new 13d3:3501 QCA_ROME device (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcsp: Fix memory leak in rx_skb (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: Add support for RTL8723DU (Gopal Tiwari) [1764976]
- [bluetooth] btmtkuart: add an implementation for clock osc property (Gopal Tiwari) [1764976]
- [bluetooth] btmtkuart: add an implementation for boot-gpios property (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add entry for BCM4359C0 UART bluetooth (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Load customized NVM based on the device property (Gopal Tiwari) [1764976]
- [bluetooth] hci_mrvl: Add serdev support (Gopal Tiwari) [1764976]
- [bluetooth] hci_mrvl: Wait for final ack before switching baudrate (Gopal Tiwari) [1764976]
- [bluetooth] hci_ldisc: Add function to wait for characters to be sent (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: wcn3990: Drop baudrate change vendor event (Gopal Tiwari) [1764976]
- [bluetooth] btqca: inject command complete event during fw download (Gopal Tiwari) [1764976]
- [bluetooth] Cleanup formatting and coding style (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: HCI reset on close for Realtek BT chip (Gopal Tiwari) [1764976]
- [bluetooth] hci_ll: Refactor download_firmware (Gopal Tiwari) [1764976]
- [bluetooth] hci_ll: set operational frequency earlier (Gopal Tiwari) [1764976]
- [bluetooth] btsdio: Do not bind to non-removable BCM4356 (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Rename STATE_<flags> to QCA_<flags> (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add default address for BCM2076B1 (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Added support for WCN3998 (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Fix crash with non-serdev devices (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Give enough time to ROME controller to bootup (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Fix empty regulator supplies for Intel Macs (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add entry for BCM2076B1 UART Bluetooth (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add default address for BCM43341B (Gopal Tiwari) [1764976]
- [bluetooth] btmrvl: add support for SD8987 chipset (Gopal Tiwari) [1764976]
- [bluetooth] btmtksdio: Drop newline with bt_dev logging macros (Gopal Tiwari) [1764976]
- [bluetooth] btmtksdio: Fix hdev->stat.byte_rx accumulation (Gopal Tiwari) [1764976]
- [bluetooth] btmtksdio: Add runtime PM support to SDIO based Bluetooth (Gopal Tiwari) [1764976]
- [bluetooth] btmtksdio: Add a bit definition for CHLPCR (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: Fixed incorrect type in assignment (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: fix spelling mistake "sliped" -> "slipped" (Gopal Tiwari) [1764976]
- [bluetooth] btmtksdio: fix uninitialized symbol errors in btmtksdio_rx_packet (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: Use module_sdio_driver helper (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: add support for MediaTek MT7663S and MT7668S SDIO devices (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Fix misspelling of 'baudrate' (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add helper function to get the chip family (Gopal Tiwari) [1764976]
- [bluetooth] btusb: request wake pin with NOAUTOEN (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: add support for MediaTek MT7663U and MT7668U UART devices (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Reduce delay after sending baudrate request for WCN3990 (Gopal Tiwari) [1764976]
- [bluetooth] btusb: add QCA6174A compatible properties (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Use msleep() instead of open coding it (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add delay after power-off pulse (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Move boot delay to qca_send_power_pulse() (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Pass boolean 'on/off' to qca_send_power_pulse() (Gopal Tiwari) [1764976]
- [bluetooth] btqcomsmd: use HCI_QUIRK_USE_BDADDR_PROPERTY (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Set HCI_QUIRK_USE_BDADDR_PROPERTY for wcn3990 (Gopal Tiwari) [1764976]
- [bluetooth] hci_ldisc: Postpone HCI_UART_PROTO_READY bit set in hci_uart_set_proto() (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: update the common setup between MT7622 and other devices (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: pass a pointer to mtk_hci_wmt_sync (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: fix up an error path to restore bdev->tx_state (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: trivial typo fix (Gopal Tiwari) [1764976]
- [bluetooth] hci_ldisc: Initialize hci_dev before open() (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Disable IBS state machine and flush Tx buffer (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Deassert RTS while baudrate change command (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: use wait_until_sent() for power pulses (Gopal Tiwari) [1764976]
- [bluetooth] remove redundant zero check on count (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Add shutdown routine for BTUSB_INTEL_NEW devices (Gopal Tiwari) [1764976]
- [bluetooth] btusb: btusb_intel_cmd_timeout: use sleeping functions (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: Restore old logic to assume firmware is already loaded (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Use the cmd_timeout method to reset the Intel BT chip (Gopal Tiwari) [1764976]
- [bluetooth] btmrvl: add support for sd8977 chipset (Gopal Tiwari) [1764976]
- [bluetooth] btmrvl: Drop unused GPIO includes (Gopal Tiwari) [1764976]
- [bluetooth] btmrvl: lower log level of informational message (Gopal Tiwari) [1764976]
- [bluetooth] hci_uart: Check if socket buffer is ERR_PTR in h4_recv_buf() (Gopal Tiwari) [1764976]
- [bluetooth] btmrvl: improve printk messages (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add helper to set device address (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add entry for BCM4329B1 UART bluetooth (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Handle specific unknown packets after firmware loading (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: Turn off RTL8723BS on suspend, reprobe on resume (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: Add suspend / resume ops (Gopal Tiwari) [1764976]
- [bluetooth] hci_intel: clean an indentation issue, remove extraneous spaces (Gopal Tiwari) [1764976]
- [bluetooth] hci_serdev: Remove setting of HCI_QUIRK_RESET_ON_CLOSE (Gopal Tiwari) [1764976]
- [bluetooth] Remove unnecessary smp_mb__after_atomic() barriers (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Add BCM20702A1 variant (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Wait for device to come out of reset after power on (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Add support for regulator supplies (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Add compatible string for BCM4330 (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add default address for BCM43430A0 (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Add support for LPO clock (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Use "txco" and "extclk" to get clock reference (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Simplify clk_get error handling (Gopal Tiwari) [1764976]
- [bluetooth] hci_bcm: Handle deferred probing for the clock supply (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add support for controller debug logs (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Add support for 0cf3:535b QCA_ROME device (Gopal Tiwari) [1764976]
- [bluetooth] btsdio: Do not bind to non-removable BCM43430 (Gopal Tiwari) [1764976]
- [bluetooth] ath3k: add more information to error message (Gopal Tiwari) [1764976]
- [bluetooth] bt3c_cs: Fix obsolete function (Gopal Tiwari) [1764976]
- [bluetooth] btrsi: fix bt tx timeout issue (Gopal Tiwari) [1764976]
- [bluetooth] btbcm: Add entry for BCM4335C0 UART bluetooth (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: Add support for RTL8822C with USB interface (Gopal Tiwari) [1764976]
- [bluetooth] hci_serdev: Fixed error space required before open paranethesis (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add poweroff support during hci down for wcn3990 (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Add quirk for BTUSB_INTEL_NEW (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: Make array extension_sig static, shrinks object size (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Remove serdev_device_open/close function calls (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Remove hdev dereference in qca_close() (Gopal Tiwari) [1764976]
- [bluetooth] hci_serdev: clear HCI_UART_PROTO_READY to avoid closing proto races (Gopal Tiwari) [1764976]
- [bluetooth] hci_serdev: Add protocol check in hci_uart_dequeue() (Gopal Tiwari) [1764976]
- [bluetooth] hci_ldisc: Free rw_semaphore on close (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: Fix memory leak (Gopal Tiwari) [1764976]
- [bluetooth] Make BT_HCIUART_RTL configuration option depend on ACPI (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: pass correct size to h4_recv_buf() (Gopal Tiwari) [1764976]
- [bluetooth] Introduce BT_HCIUART_RTL configuration option (Gopal Tiwari) [1764976]
- [bluetooth] mediatek: Add protocol support for MediaTek serial devices (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Introduce HCI_EV_VENDOR and use it (Gopal Tiwari) [1764976]
- [bluetooth] h5: Fix missing dependency on BT_HCIUART_SERDEV (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add support for Qualcomm Bluetooth chip wcn3990 (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Enable 3.2 Mbps operating speed (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Add wrapper functions for setting UART speed (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Add wcn3990 firmware download support (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Redefine qca_uart_setup() to generic function (Gopal Tiwari) [1764976]
- [bluetooth] btqca: Rename ROME specific functions to generic functions (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: Add support for enable and device-wake GPIOs (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: Add support for the RTL8723BS (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: Add vendor setup, open, and close callbacks (Gopal Tiwari) [1764976]
- [bluetooth] hci_h5: Add support for serdev enumerated devices (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: add support for retrieving the UART settings (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: Use rtl_dev_err and rtl_dev_info (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: Add support for a config filename postfix (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: add support for the RTL8723BS and RTL8723DS chips (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: add MODULE_FIRMWARE declarations (Gopal Tiwari) [1764976]
- [bluetooth] btrtl: split the device initialization into smaller parts (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Release RF resource on BT shutdown (Gopal Tiwari) [1764976]
- [bluetooth] hci_qca: Replace GFP_ATOMIC with GFP_KERNEL (Gopal Tiwari) [1764976]
- [bluetooth] hci_intel: Replace GFP_ATOMIC with GFP_KERNEL in inject_cmd_complete() (Gopal Tiwari) [1764976]
- [bluetooth] btusb: Replace GFP_ATOMIC with GFP_KERNEL in inject_cmd_complete() (Gopal Tiwari) [1764976]
- [bluetooth] bfusb: Replace GFP_ATOMIC with GFP_KERNEL in bfusb_send_frame() (Gopal Tiwari) [1764976]
- [bluetooth] bluecard_cs: Replace GFP_ATOMIC with GFP_KERNEL in bluecard_hci_set_baud_rate() (Gopal Tiwari) [1764976]
- [bluetooth] bpa10x: Replace GFP_ATOMIC with GFP_KERNEL in bpa10x_send_frame() (Gopal Tiwari) [1764976]
- [bluetooth] btmrvl_sdio: Replace GFP_ATOMIC with GFP_KERNEL in btmrvl_sdio_card_to_host() (Gopal Tiwari) [1764976]
- [bluetooth] btusb: use irqsave() in URB's complete callback (Gopal Tiwari) [1764976]
- [bluetooth] Add a new Realtek 8723DE ID 0bda:b009 (Gopal Tiwari) [1764976]

* Thu Mar 19 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-190.1.el8]
- Revert "[redhat] switch secureboot kernel image signing to release keys" (Frantisek Hrbata)
- [powerpc] powerpc/pseries: Avoid NULL pointer dereference when drmem is unavailable (David Hildenbrand) [1812874]
- [x86] kvm/svm: PKU not currently supported (Wei Huang) [1789159]
- [x86] Remove the unsupported check for Cooper Lake (David Arcari) [1813921]

* Wed Mar 18 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-189.1.el8]
- [netdrv] net/mlx5e: Show/set Rx network flow classification rules on ul rep (Alaa Hleihel) [1795156 1794280]
- [netdrv] net/mlx5e: Init ethtool steering for representors (Alaa Hleihel) [1795156 1794280]
- [netdrv] net/mlx5e: Show/set Rx flow indir table and RSS hash key on ul rep (Alaa Hleihel) [1795156 1794280]
- [netdrv] net/mlx5e: Introduce root ft concept for representors netdevs (Alaa Hleihel) [1795156 1794280]
- [netdrv] net/mlx5: E-Switch, Use vport metadata matching only when mandatory (Alaa Hleihel) [1795156]
- [nvme] nvme: log additional message for controller status (David Milburn) [1752952]

* Tue Mar 17 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-188.3.el8]
- [powerpc] powerpc: fix hardware PMU exception bug on PowerVM compatibility mode systems (Desnes Augusto Nunes do Rosario) [1755221]
- [mm] powerpc/book3s64/radix: Remove WARN_ON in destroy_context() (Steve Best) [1812821]
- [kernel] rcutorture: Upper case solves the case of the vanishing NULL pointer (Waiman Long) [1810247]
- [tools] torture: Suppress propagating trace_printk() warning (Waiman Long) [1810247]
- [kernel] rcutorture: Dump trace buffer for callback pipe drain failures (Waiman Long) [1810247]
- [tools] torture: Add --trust-make to suppress "make clean" (Waiman Long) [1810247]
- [tools] torture: Make --cpus override idleness calculations (Waiman Long) [1810247]
- [tools] torture: Run kernel build in source directory (Waiman Long) [1810247]
- [tools] torture: Add function graph-tracing cheat sheet (Waiman Long) [1810247]
- [tools] torture: Capture qemu output (Waiman Long) [1810247]
- [tools] rcutorture: Tweak kvm options (Waiman Long) [1810247]
- [kernel] rcutorture: Add trivial RCU implementation (Waiman Long) [1810247]
- [kernel] rcutorture: Halt forward-progress checks at end of run (Waiman Long) [1810247]
- [kernel] rcutorture: Give the scheduler a chance on PREEMPT && NO_HZ_FULL kernels (Waiman Long) [1810247]
- [tools] rcutorture: Exempt TREE01 from forward-progress testing (Waiman Long) [1810247]
- [kernel] rcutorture: Exempt tasks RCU from timely draining of grace periods (Waiman Long) [1810247]
- [tools] rcutorture: Provide rudimentary Makefile (Waiman Long) [1810247]
- [tools] torture: Make kvm-find-errors.sh and kvm-recheck.sh provide exit status (Waiman Long) [1810247]
- [kernel] torture: Allow inter-stutter interval to be specified (Waiman Long) [1810247]
- [kernel] rcutorture: Fix stutter_wait() return value and freelist checks (Waiman Long) [1810247]
- [kernel] rcutorture: Add cond_resched() to forward-progress free-up loop (Waiman Long) [1810247]
- [tools] rcutorture: Add cpu0 to the set of CPUs to add jitter (Waiman Long) [1810247]
- [tools] rcutorture: Select from only online CPUs (Waiman Long) [1810247]
- [kernel] rcu/sync: Simplify the state machine (Waiman Long) [1810247]
- [kernel] locking/percpu-rwsem: Add DEFINE_PERCPU_RWSEM(), use it to initialize cgroup_threadgroup_rwsem (Waiman Long) [1810247]
- [kernel] rcu/sync: Kill rcu_sync_type/gp_type (Waiman Long) [1810247]
- [kernel] rcu: Make __call_srcu static (Waiman Long) [1810247]
- [kernel] rcu: Upgrade sync_exp_work_done() to smp_mb() (Waiman Long) [1810247]
- [documentation] doc: Remove ".vnet" from paulmck email addresses (Waiman Long) [1810247]
- [kernel] rcu: Set a maximum limit for back-to-back callback invocation (Waiman Long) [1810247]
- [kernel] rcu: Correctly unlock root node in rcu_check_gp_start_stall() (Waiman Long) [1810247]
- [kernel] rcu: Dump specified number of blocked tasks (Waiman Long) [1810247]
- [kernel] rcu: Remove unused rdp local from synchronize_rcu_expedited() (Waiman Long) [1810247]
- [kernel] rcu: Rename rcu_data's ->deferred_qs to ->exp_deferred_qs (Waiman Long) [1810247]
- [kernel] rcu: Add checks for dynticks counters in rcu_is_cpu_rrupt_from_idle() (Waiman Long) [1810247]
- [kernel] rcu: Avoid self-IPI in sync_sched_exp_online_cleanup() (Waiman Long) [1810247]
- [kernel] rcu: Avoid self-IPI in sync_rcu_exp_select_node_cpus() (Waiman Long) [1810247]
- [kernel] rcu: Inline invoke_rcu_callbacks() into its sole remaining caller (Waiman Long) [1810247]
- [kernel] rcu: Use irq_work to get scheduler's attention in clean context (Waiman Long) [1810247]
- [kernel] rcu: Allow rcu_read_unlock_special() to raise_softirq() if in_irq() (Waiman Long) [1810247]
- [kernel] rcu: Only do rcu_read_unlock_special() wakeups if expedited (Waiman Long) [1810247]
- [kernel] rcu: Check for wakeup-safe conditions in rcu_read_unlock_special() (Waiman Long) [1810247]
- [kernel] rcu: Enable elimination of Tree-RCU softirq processing (Waiman Long) [1810247]
- [kernel] rcuperf: Fix cleanup path for invalid perf_type strings (Waiman Long) [1810247]
- [kernel] rcutorture: Fix cleanup path for invalid torture_type strings (Waiman Long) [1810247]
- [kernel] rcutorture: Fix expected forward progress duration in OOM notifier (Waiman Long) [1810247]
- [kernel] rcutorture: Remove ->ext_irq_conflict field (Waiman Long) [1810247]
- [kernel] rcutorture: Make rcutorture_extend_mask() comment match the code (Waiman Long) [1810247]
- [tools] tools/.../rcutorture: Convert to SPDX license identifier (Waiman Long) [1810247]
- [kernel] torture: Don't try to offline the last CPU (Waiman Long) [1810247]
- [kernel] rcu: Fix nohz status in stall warning (Waiman Long) [1810247]
- [kernel] rcu: Move forward-progress checkers into tree_stall.h (Waiman Long) [1810247]
- [kernel] rcu: Move irq-disabled stall-warning checking to tree_stall.h (Waiman Long) [1810247]
- [kernel] rcu: Organize functions in tree_stall.h (Waiman Long) [1810247]
- [kernel] rcu: Move FAST_NO_HZ stall-warning code to tree_stall.h (Waiman Long) [1810247]
- [kernel] rcu: Inline RCU stall-warning info helper functions (Waiman Long) [1810247]
- [kernel] rcu: Move rcu_print_task_exp_stall() to tree_exp.h (Waiman Long) [1810247]
- [kernel] rcu: Inline RCU task stall-warning helper functions (Waiman Long) [1810247]
- [kernel] rcu: Move RCU CPU stall-warning code out of tree.c (Waiman Long) [1810247]
- [kernel] rcu: Move RCU CPU stall-warning code out of tree_plugin.h (Waiman Long) [1810247]
- [kernel] rcu: Move RCU CPU stall-warning code out of update.c (Waiman Long) [1810247]
- [kernel] srcu: Remove cleanup_srcu_struct_quiesced() (Waiman Long) [1810247]
- [kernel] srcu: Check for in-flight callbacks in _cleanup_srcu_struct() (Waiman Long) [1810247]
- [kernel] rcu: Correct READ_ONCE()/WRITE_ONCE() for ->rcu_read_unlock_special (Waiman Long) [1810247]
- [kernel] rcu: Fix typo in tree_exp.h comment (Waiman Long) [1810247]
- [kernel] rcu: Eliminate redundant NULL-pointer check (Waiman Long) [1810247]
- [kernel] rcu: Fix force_qs_rnp() header comment (Waiman Long) [1810247]
- [kernel] rcu: Update jiffies_to_sched_qs and adjust_jiffies_till_sched_qs() comments (Waiman Long) [1810247]
- [kernel] rcu: Do a single rhp->func read in rcu_head_after_call_rcu() (Waiman Long) [1810247]
- [kernel] rcu: Default jiffies_to_sched_qs to jiffies_till_sched_qs (Waiman Long) [1810247]
- [kernel] rcu: Fix self-wakeups for grace-period kthread (Waiman Long) [1810247]
- [kernel] rcu: Report error for bad rcu_nocbs= parameter values (Waiman Long) [1810247]
- [kernel] rcu: Allow rcu_nocbs= to specify all CPUs (Waiman Long) [1810247]
- [kernel] rcu: Move common code out of if-else block (Waiman Long) [1810247]
- [kernel] rcu: Set rcutree.kthread_prio sysfs access to read-only (Waiman Long) [1810247]
- [kernel] rcu: Make exit_rcu() handle non-preempted RCU readers (Waiman Long) [1810247]
- [kernel] rcu: rcu_qs -- Use raise_softirq_irqoff to not save irqs twice (Waiman Long) [1810247]
- [kernel] rcu: Avoid unnecessary softirq when system is idle (Waiman Long) [1810247]
- [kernel] rcu: Unconditionally expedite during suspend/hibernate (Waiman Long) [1810247]
- [kernel] rcu/tree: Convert to SPDX license identifier (Waiman Long) [1810247]
- [kernel] srcu: Remove srcu_queue_delayed_work_on() (Waiman Long) [1810247]
- [kernel] sched/fair: Define sched_idle_cpu() only for SMP configurations (Phil Auld) [1419746]
- [kernel] sched/fair: Load balance aggressively for SCHED_IDLE CPUs (Phil Auld) [1419746]
- [kernel] sched/fair : Improve update_sd_pick_busiest for spare capacity case (Phil Auld) [1419746]
- [kernel] sched/fair: Fix find_idlest_group() to handle CPU affinity (Phil Auld) [1419746]
- [kernel] sched/cfs: fix spurious active migration (Phil Auld) [1419746]
- [kernel] sched/fair: Add comments for group_type and balancing at SD_NUMA level (Phil Auld) [1419746]
- [kernel] sched/fair: Fix rework of find_idlest_group() (Phil Auld) [1419746]
- [kernel] sched/fair: Rework find_idlest_group() (Phil Auld) [1419746]
- [kernel] sched/fair: Optimize find_idlest_group() (Phil Auld) [1419746]
- [kernel] sched/fair: Use load instead of runnable load in wakeup path (Phil Auld) [1419746]
- [kernel] sched/fair: Use utilization to select misfit task (Phil Auld) [1419746]
- [kernel] sched/fair: Spread out tasks evenly when not overloaded (Phil Auld) [1419746]
- [kernel] sched/fair: Use load instead of runnable load in load_balance() (Phil Auld) [1419746]
- [kernel] sched/fair: Use rq->nr_running when balancing load (Phil Auld) [1419746]
- [kernel] sched/fair: Rework load_balance() (Phil Auld) [1419746]
- [kernel] sched/fair: Remove meaningless imbalance calculation (Phil Auld) [1419746]
- [kernel] sched/fair: Rename sg_lb_stats::sum_nr_running to sum_h_nr_running (Phil Auld) [1419746]
- [kernel] sched/fair: Clean up asym packing (Phil Auld) [1419746]
- [kernel] sched/fair: Fall back to sched-idle CPU if idle CPU isn't found (Phil Auld) [1419746]
- [kernel] sched/fair: Start tracking SCHED_IDLE tasks count in cfs_rq (Phil Auld) [1419746]
- [kernel] sched/core: Allow sched_setattr() to use the current policy (Phil Auld) [1419746]
- [kernel] sched/fair: Introduce fits_capacity() (Phil Auld) [1419746]
- [kernel] sched/core: Provide a pointer to the valid CPU mask (Phil Auld) [1419746]
- [x86] x86/percpu: Optimize raw_cpu_xchg() (Phil Auld) [1419746]
- [kernel] x86/percpu, sched/fair: Avoid local_clock() (Phil Auld) [1419746]
- [x86] x86/percpu, x86/irq: Relax {set,get}_irq_regs() (Phil Auld) [1419746]
- [x86] x86/percpu: Relax smp_processor_id() (Phil Auld) [1419746]
- [x86] x86/percpu: Differentiate this_cpu_{}() and __this_cpu_{}() (Phil Auld) [1419746]
- [kernel] sched/fair: Fix unnecessary increase of balance interval (Phil Auld) [1419746]
- [kernel] sched/fair: Trigger asym_packing during idle load balance (Phil Auld) [1419746]
- [kernel] sched/fair: Fix rounding bug for asym packing (Phil Auld) [1419746]
- [kernel] sched/fair: Fix warning on non-SMP build (Phil Auld) [1419746]
- [kernel] sched/core: Create task_has_idle_policy() helper (Phil Auld) [1419746]
- [firmware] efi: fix a mistype in comments mentioning efivar_entry_iter_begin() (Vladis Dronov) [1804417]
- [firmware] efi: add a sanity check to efivar_store_raw() (Vladis Dronov) [1804417]
- [firmware] efi: fix a race and a buffer overflow while reading efivars via sysfs (Vladis Dronov) [1804417]
- [scsi] scsi: ibmvfc: Fix NULL return compiler warning (Steve Best) [1810653]
- [scsi] scsi: ibmvfc: Avoid loss of all paths during SVC node reboot (Steve Best) [1810653]
- [fs] xfs: fix some memory leaks in log recovery (Bill O'Donnell) [1765693]
- [fs] xfs: Fix deadlock between AGI and AGF when target_ip exists in xfs_rename() (Bill O'Donnell) [1765693]
- [fs] xfs: fix inode fork extent count overflow (Bill O'Donnell) [1765693]
- [fs] xfs: change the seconds fields in xfs_bulkstat to signed (Bill O'Donnell) [1765693]
- [fs] xfs: assure zeroed memory buffers for certain kmem allocations (Bill O'Donnell) [1765693]
- [fs] xfs: removed unused error variable from xchk_refcountbt_rec (Bill O'Donnell) [1765693]
- [fs] xfs: remove unused flags arg from xfs_get_aghdr_buf() (Bill O'Donnell) [1765693]
- [fs] xfs: Fix tail rounding in xfs_alloc_file_space() (Bill O'Donnell) [1765693]
- [fs] xfs: remove unlikely() from WARN_ON() condition (Bill O'Donnell) [1765693]
- [fs] xfs: avoid unused to_mp() function warning (Bill O'Donnell) [1765693]
- [fs] xfs: log proper length of superblock (Bill O'Donnell) [1765693]
- [fs] xfs: revert 1baa2800e62d ("xfs: remove the unused XFS_ALLOC_USERDATA flag") (Bill O'Donnell) [1765693]
- [fs] xfs: removed unneeded variable (Bill O'Donnell) [1765693]
- [fs] xfs: push the grant head when the log head moves forward (Bill O'Donnell) [1765693]
- [fs] xfs: push iclog state cleaning into xlog_state_clean_log (Bill O'Donnell) [1765693]
- [fs] xfs: factor iclog state processing out of xlog_state_do_callback() (Bill O'Donnell) [1765693]
- [fs] xfs: factor callbacks out of xlog_state_do_callback() (Bill O'Donnell) [1765693]
- [fs] xfs: factor debug code out of xlog_state_do_callback() (Bill O'Donnell) [1765693]
- [fs] xfs: prevent CIL push holdoff in log recovery (Bill O'Donnell) [1765693]
- [fs] xfs: fix missed wakeup on l_flush_wait (Bill O'Donnell) [1765693]
- [fs] xfs: push the AIL in xlog_grant_head_wake (Bill O'Donnell) [1765693]
- [fs] xfs: Use WARN_ON_ONCE for bailout mount-operation (Bill O'Donnell) [1765693]
- [fs] xfs: define a flags field for the AG geometry ioctl structure (Bill O'Donnell) [1765693]
- [fs] xfs: add a xfs_valid_startblock helper (Bill O'Donnell) [1765693]
- [fs] xfs: remove the unused XFS_ALLOC_USERDATA flag (Bill O'Donnell) [1765693]
- [fs] xfs: cleanup xfs_fsb_to_db (Bill O'Donnell) [1765693]
- [fs] xfs: fix the dax supported check in xfs_ioctl_setattr_dax_invalidate (Bill O'Donnell) [1765693]
- [fs] xfs: Fix stale data exposure when readahead races with hole punch (Bill O'Donnell) [1765693]
- [mm] fs: Export generic_fadvise() (Bill O'Donnell) [1765693]
- [fs] xfs: reverse search directory freespace indexes (Bill O'Donnell) [1765693]
- [fs] xfs: speed up directory bestfree block scanning (Bill O'Donnell) [1765693]
- [fs] xfs: factor free block index lookup from xfs_dir2_node_addname_int() (Bill O'Donnell) [1765693]
- [fs] xfs: factor data block addition from xfs_dir2_node_addname_int() (Bill O'Donnell) [1765693]
- [fs] xfs: move xfs_dir2_addname() (Bill O'Donnell) [1765693]
- [fs] xfs: remove all *_ITER_CONTINUE values (Bill O'Donnell) [1765693]
- [fs] xfs: remove all *_ITER_ABORT values (Bill O'Donnell) [1765693]
- [fs] xfs: log proper length of btree block in scrub/repair (Bill O'Donnell) [1765693]
- [fs] xfs: reinitialize rm_flags when unpacking an offset into an rmap irec (Bill O'Donnell) [1765693]
- [fs] xfs: remove unnecessary int returns from deferred bmap functions (Bill O'Donnell) [1765693]
- [fs] xfs: remove unnecessary int returns from deferred refcount functions (Bill O'Donnell) [1765693]
- [fs] xfs: remove unnecessary int returns from deferred rmap functions (Bill O'Donnell) [1765693]
- [fs] xfs: remove unnecessary parameter from xfs_iext_inc_seq (Bill O'Donnell) [1765693]
- [fs] xfs: fix sign handling problem in xfs_bmbt_diff_two_keys (Bill O'Donnell) [1765693]
- [fs] xfs: don't return _QUERY_ABORT from xfs_rmap_has_other_keys (Bill O'Donnell) [1765693]
- [fs] xfs: fix maxicount division by zero error (Bill O'Donnell) [1765693]
- [fs] xfs: bmap scrub should only scrub records once (Bill O'Donnell) [1765693]
- [fs] xfs: remove excess function parameter description in 'xfs_btree_sblock_v5hdr_verify' (Bill O'Donnell) [1765693]
- [fs] fs: xfs: Remove KM_NOSLEEP and KM_SLEEP (Bill O'Donnell) [1765693]
- [fs] fs/xfs: Fix return code of xfs_break_leased_layouts() (Bill O'Donnell) [1765693]
- [fs] xfs: compat_ioctl: use compat_ptr() (Bill O'Donnell) [1765693]
- [fs] xfs: fall back to native ioctls for unhandled compat ones (Bill O'Donnell) [1765693]
- [fs] xfs: remove more ondisk directory corruption asserts (Bill O'Donnell) [1765693]
- [fs] fs: xfs: xfs_log: Don't use KM_MAYFAIL at xfs_log_reserve() (Bill O'Donnell) [1765693]
- [fs] xfs: Fix possible null-pointer dereferences in xchk_da_btree_block_check_sibling() (Bill O'Donnell) [1765693]
- [fs] xfs: fix stack contents leakage in the v1 inumber ioctls (Bill O'Donnell) [1765693]
- [fs] xfs: sync up xfs_trans_inode with userspace (Bill O'Donnell) [1765693]
- [fs] xfs: move xfs_trans_inode.c to libxfs/ (Bill O'Donnell) [1765693]
- [fs] xfs: chain bios the right way around in xfs_rw_bdev (Bill O'Donnell) [1765693]
- [fs] xfs: bump INUMBERS cursor correctly in xfs_inumbers_walk (Bill O'Donnell) [1765693]
- [fs] xfs: don't update lastino for FSBULKSTAT_SINGLE (Bill O'Donnell) [1765693]
- [fs] xfs: online scrub needn't bother zeroing its temporary buffer (Bill O'Donnell) [1765693]
- [fs] xfs: only allocate memory for scrubbing attributes when we need it (Bill O'Donnell) [1765693]
- [fs] xfs: refactor attr scrub memory allocation function (Bill O'Donnell) [1765693]
- [fs] xfs: refactor extended attribute buffer pointer functions (Bill O'Donnell) [1765693]
- [fs] xfs: attribute scrub should use seen_enough to pass error values (Bill O'Donnell) [1765693]
- [fs] xfs: allow single bulkstat of special inodes (Bill O'Donnell) [1765693]
- [fs] xfs: specify AG in bulk req (Bill O'Donnell) [1765693]
- [fs] xfs: wire up the v5 inumbers ioctl (Bill O'Donnell) [1765693]
- [fs] xfs: wire up new v5 bulkstat ioctls (Bill O'Donnell) [1765693]
- [fs] xfs: introduce v5 inode group structure (Bill O'Donnell) [1765693]
- [fs] xfs: introduce new v5 bulkstat structure (Bill O'Donnell) [1765693]
- [fs] xfs: rename bulkstat functions (Bill O'Donnell) [1765693]
- [fs] xfs: remove various bulk request typedef usage (Bill O'Donnell) [1765693]
- [fs] fs: xfs: xfs_log: Change return type from int to void (Bill O'Donnell) [1765693]
- [fs] xfs: poll waiting for quotacheck (Bill O'Donnell) [1765693]
- [fs] xfs: multithreaded iwalk implementation (Bill O'Donnell) [1765693]
- [fs] xfs: refactor INUMBERS to use iwalk functions (Bill O'Donnell) [1765693]
- [fs] xfs: refactor iwalk code to handle walking inobt records (Bill O'Donnell) [1765693]
- [fs] xfs: refactor xfs_iwalk_grab_ichunk (Bill O'Donnell) [1765693]
- [fs] xfs: clean up long conditionals in xfs_iwalk_ichunk_ra (Bill O'Donnell) [1765693]
- [fs] xfs: change xfs_iwalk_grab_ichunk to use startino, not lastino (Bill O'Donnell) [1765693]
- [fs] xfs: move bulkstat ichunk helpers to iwalk code (Bill O'Donnell) [1765693]
- [fs] xfs: calculate inode walk prefetch more carefully (Bill O'Donnell) [1765693]
- [fs] xfs: convert bulkstat to new iwalk infrastructure (Bill O'Donnell) [1765693]
- [fs] xfs: bulkstat should copy lastip whenever userspace supplies one (Bill O'Donnell) [1765693]
- [fs] xfs: convert quotacheck to use the new iwalk functions (Bill O'Donnell) [1765693]
- [fs] xfs: create simplified inode walk function (Bill O'Donnell) [1765693]
- [fs] xfs: create iterator error codes (Bill O'Donnell) [1765693]
- [fs] xfs: remove XFS_TRANS_NOFS (Bill O'Donnell) [1765693]
- [fs] xfs: simplify xfs_ioend_can_merge (Bill O'Donnell) [1765693]
- [fs] xfs: allow merging ioends over append boundaries (Bill O'Donnell) [1765693]
- [fs] xfs: fix a comment typo in xfs_submit_ioend (Bill O'Donnell) [1765693]
- [fs] xfs: remove the unused xfs_count_page_state declaration (Bill O'Donnell) [1765693]
- [fs] xfs: fix iclog allocation size (Bill O'Donnell) [1765693]
- [fs] xfs: remove unused header files (Bill O'Donnell) [1765693]
- [fs] xfs: account for log space when formatting new AGs (Bill O'Donnell) [1765693]
- [fs] xfs: refactor free space btree record initialization (Bill O'Donnell) [1765693]
- [fs] xfs: always update params on small allocation (Bill O'Donnell) [1765693]
- [fs] xfs: skip small alloc cntbt logic on NULL cursor (Bill O'Donnell) [1765693]
- [fs] xfs: move small allocation helper (Bill O'Donnell) [1765693]
- [fs] xfs: clean up small allocation helper (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_trans_bmap.c into xfs_bmap_item.c (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_trans_rmap.c into xfs_rmap_item.c (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_trans_refcount.c into xfs_refcount_item.c (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_trans_extfree.c into xfs_extfree_item.c (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_bud_init into xfs_trans_get_bud (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_rud_init into xfs_trans_get_rud (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_cud_init into xfs_trans_get_cud (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_efd_init into xfs_trans_get_efd (Bill O'Donnell) [1765693]
- [fs] xfs: remove a pointless comment duplicated above all xfs_item_ops instances (Bill O'Donnell) [1765693]
- [fs] xfs: use a list_head for iclog callbacks (Bill O'Donnell) [1765693]
- [fs] xfs: remove the xfs_log_item_t typedef (Bill O'Donnell) [1765693]
- [fs] xfs: don't cast inode_log_items to get the log_item (Bill O'Donnell) [1765693]
- [fs] xfs: add a flag to release log items on commit (Bill O'Donnell) [1765693]
- [fs] xfs: split iop_unlock (Bill O'Donnell) [1765693]
- [fs] xfs: don't use xfs_trans_free_items in the commit path (Bill O'Donnell) [1765693]
- [fs] xfs: remove the dummy iop_push implementation for inode creation items (Bill O'Donnell) [1765693]
- [fs] xfs: don't require log items to implement optional methods (Bill O'Donnell) [1765693]
- [fs] xfs: stop using XFS_LI_ABORTED as a parameter flag (Bill O'Donnell) [1765693]
- [fs] xfs: fix a trivial comment typo in xfs_trans_committed_bulk (Bill O'Donnell) [1765693]
- [fs] xfs: add struct xfs_mount pointer to struct xfs_buf (Bill O'Donnell) [1765693]
- [fs] xfs: remove the b_io_length field in struct xfs_buf (Bill O'Donnell) [1765693]
- [fs] xfs: properly type the b_log_item field in struct xfs_buf (Bill O'Donnell) [1765693]
- [fs] xfs: remove unused buffer cache APIs (Bill O'Donnell) [1765693]
- [fs] xfs: stop using bp naming for log recovery buffers (Bill O'Donnell) [1765693]
- [fs] xfs: use bios directly to read and write the log recovery buffers (Bill O'Donnell) [1765693]
- [fs] xfs: return an offset instead of a pointer from xlog_align (Bill O'Donnell) [1765693]
- [fs] xfs: move the log ioend workqueue to struct xlog (Bill O'Donnell) [1765693]
- [fs] xfs: use bios directly to write log buffers (Bill O'Donnell) [1765693]
- [fs] xfs: make use of the l_targ field in struct xlog (Bill O'Donnell) [1765693]
- [fs] xfs: remove the syncing argument from xlog_verify_iclog (Bill O'Donnell) [1765693]
- [fs] xfs: update both stat counters together in xlog_sync (Bill O'Donnell) [1765693]
- [fs] xfs: factor out iclog size calculation from xlog_sync (Bill O'Donnell) [1765693]
- [fs] xfs: factor out splitting of an iclog from xlog_sync (Bill O'Donnell) [1765693]
- [fs] xfs: factor out log buffer writing from xlog_sync (Bill O'Donnell) [1765693]
- [fs] xfs: don't use REQ_PREFLUSH for split log writes (Bill O'Donnell) [1765693]
- [fs] xfs: remove XLOG_STATE_IOABORT (Bill O'Donnell) [1765693]
- [fs] xfs: reformat xlog_get_lowest_lsn (Bill O'Donnell) [1765693]
- [fs] xfs: cleanup xlog_get_iclog_buffer_size (Bill O'Donnell) [1765693]
- [fs] xfs: remove the l_iclog_size_log field from struct xlog (Bill O'Donnell) [1765693]
- [fs] xfs: renumber XBF_WRITE_FAIL (Bill O'Donnell) [1765693]
- [fs] xfs: remove the never used _XBF_COMPOUND flag (Bill O'Donnell) [1765693]
- [fs] xfs: remove the no-op spinlock_destroy stub (Bill O'Donnell) [1765693]
- [fs] xfs: move xfs_ino_geometry to xfs_shared.h (Bill O'Donnell) [1765693]
- [fs] xfs: remove unused flag arguments (Bill O'Donnell) [1765693]
- [fs] xfs: remove the debug-only q_transp field from struct xfs_dquot (Bill O'Donnell) [1765693]
- [fs] xfs: merge xfs_buf_zero and xfs_buf_iomove (Bill O'Donnell) [1765693]
- [fs] xfs: remove unused flags arg from getsb interfaces (Bill O'Donnell) [1765693]
- [fs] xfs: include WARN, REPAIR build options in XFS_BUILD_OPTIONS (Bill O'Donnell) [1765693]
- [fs] xfs: finish converting to inodes_per_cluster (Bill O'Donnell) [1765693]
- [fs] xfs: fix inode_cluster_size rounding mayhem (Bill O'Donnell) [1765693]
- [fs] xfs: refactor inode geometry setup routines (Bill O'Donnell) [1765693]
- [fs] xfs: separate inode geometry (Bill O'Donnell) [1765693]
- [fs] xfs: use file_modified() helper (Bill O'Donnell) [1765693]
- [fs] vfs: introduce file_modified() helper (Bill O'Donnell) [1765693]

* Sun Mar 15 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-188.2.el8]
- [md] dm: bump version of core and various targets (Mike Snitzer) [1810746]
- [md] dm: fix congested_fn for request-based device (Mike Snitzer) [1810746]
- [md] dm integrity: use dm_bio_record and dm_bio_restore (Mike Snitzer) [1810746]
- [md] dm bio record: save_restore bi_end_io and bi_integrity (Mike Snitzer) [1810746]
- [md] dm writecache: verify watermark during resume (Mike Snitzer) [1810746]
- [md] dm: report suspended device during destroy (Mike Snitzer) [1810746]
- [md] dm thin metadata: fix lockdep complaint (Mike Snitzer) [1810746]
- [md] dm cache: fix a crash due to incorrect work item cancelling (Mike Snitzer) [1810746]
- [md] dm integrity: fix invalid table returned due to argument count mismatch (Mike Snitzer) [1810746]
- [md] dm integrity: fix a deadlock due to offloading to an incorrect workqueue (Mike Snitzer) [1810746]
- [md] dm integrity: fix recalculation when moving from journal mode to bitmap mode (Mike Snitzer) [1810746]
- [md] dm writecache: improve performance of large linear writes on SSDs (Mike Snitzer) [1810746]
- [md] dm mpath: Add timeout mechanism for queue_if_no_path (Mike Snitzer) [1810746]
- [md] dm thin: change data device's flush_bio to be member of struct pool (Mike Snitzer) [1810746]
- [md] dm thin: don't allow changing data device during thin-pool reload (Mike Snitzer) [1810746]
- [md] dm thin: fix use-after-free in metadata_pre_commit_callback (Mike Snitzer) [1810746]
- [md] dm thin metadata: use pool locking at end of dm_pool_metadata_close (Mike Snitzer) [1810746]
- [md] dm writecache: fix incorrect flush sequence when doing SSD mode commit (Mike Snitzer) [1810746]
- [md] dm crypt: fix benbi IV constructor crash if used in authenticated mode (Mike Snitzer) [1810746]
- [md] dm crypt: Implement Elephant diffuser for Bitlocker compatibility (Mike Snitzer) [1810746]
- [md] dm space map common: fix to ensure new block isn't already in use (Mike Snitzer) [1810746]
- [md] dm verity: don't prefetch hash blocks for already-verified data (Mike Snitzer) [1810746]
- [md] dm crypt: fix GFP flags passed to skcipher_request_alloc() (Mike Snitzer) [1810746]
- [md] dm thin metadata: Fix trivial math error in on-disk format documentation (Mike Snitzer) [1810746]
- [md] dm thin metadata: use true_false for bool variable (Mike Snitzer) [1810746]
- [md] dm snapshot: use true_false for bool variable (Mike Snitzer) [1810746]
- [md] dm bio prison v2: use true_false for bool variable (Mike Snitzer) [1810746]
- [md] dm mpath: use true_false for bool variable (Mike Snitzer) [1810746]
- [md] dm zoned: support zone sizes smaller than 128MiB (Mike Snitzer) [1810746]
- [md] dm raid: table line rebuild status fixes (Mike Snitzer) [1810746]
- [documentation] docs: dm-integrity: remove reference to ARC4 (Mike Snitzer) [1810746]
- [md] dm thin: Flush data device before committing metadata (Mike Snitzer) [1810746]
- [md] dm thin metadata: Add support for a pre-commit callback (Mike Snitzer) [1810746]
- [md] dm btree: increase rebalance threshold in __rebalance2() (Mike Snitzer) [1810746]
- [md] dm mpath: remove harmful bio-based optimization (Mike Snitzer) [1810746]
- [md] dm integrity: fix excessive alignment of metadata runs (Mike Snitzer) [1810746]
- [md] dm cache: replace spin_lock_irqsave with spin_lock_irq (Mike Snitzer) [1810746]
- [md] dm bio prison: replace spin_lock_irqsave with spin_lock_irq (Mike Snitzer) [1810746]
- [md] dm thin: replace spin_lock_irqsave with spin_lock_irq (Mike Snitzer) [1810746]
- [md] dm raid: streamline rs_get_progress() and its raid_status() caller side (Mike Snitzer) [1810746]
- [md] dm raid: simplify rs_setup_recovery call chain (Mike Snitzer) [1810746]
- [md] dm raid: to ensure resynchronization, perform raid set grow in preresume (Mike Snitzer) [1810746]
- [md] dm raid: change rs_set_dev_and_array_sectors API and callers (Mike Snitzer) [1810746]
- [md] dm: introduce DM_GET_TARGET_VERSION (Mike Snitzer) [1810746]
- [md] dm bufio: introduce a global cache replacement (Mike Snitzer) [1810746]
- [md] dm bufio: remove old-style buffer cleanup (Mike Snitzer) [1810746]
- [md] dm bufio: introduce a global queue (Mike Snitzer) [1810746]
- [md] dm bufio: refactor adjust_total_allocated (Mike Snitzer) [1810746]
- [md] dm bufio: call adjust_total_allocated from __link_buffer and __unlink_buffer (Mike Snitzer) [1810746]
- [md] dm crypt: omit parsing of the encapsulated cipher (Mike Snitzer) [1810746]
- [md] dm crypt: switch to ESSIV crypto API template (Mike Snitzer) [1810746]
- [crypto] crypto: essiv - create wrapper template for ESSIV generation (Mike Snitzer) [1810746]
- [security] crypto: drop mask=CRYPTO_ALG_ASYNC from shash tfm allocations (Mike Snitzer) [1810746]
- [crypto] crypto: drop mask=CRYPTO_ALG_ASYNC from cipher tfm allocations (Mike Snitzer) [1810746]
- [md] dm verity: add root hash pkcs#7 signature verification (Mike Snitzer) [1810746]
- [md] dm crypt: reuse eboiv skcipher for IV generation (Mike Snitzer) [1810746]
- [md] dm integrity: fix a crash due to BUG_ON in __journal_read_write() (Mike Snitzer) [1810746]
- [md] dm kcopyd: Increase default sub-job size to 512KB (Mike Snitzer) [1810746]
- [documentation] docs: device-mapper: move it to the admin-guide (Mike Snitzer) [1810746]
- [documentation] docs: convert docs to ReST and rename to *.rst (Mike Snitzer) [1810746]
- [md] dm crypt: implement eboiv - encrypted byte-offset initialization vector (Mike Snitzer) [1810746]
- [md] dm integrity: use kzalloc() instead of kmalloc() + memset() (Mike Snitzer) [1810746]
- [md] dm integrity: always set version on superblock update (Mike Snitzer) [1810746]
- [md] dm integrity: whitespace, coding style and dead code cleanup (Mike Snitzer) [1810746]
- [md] dm integrity: implement synchronous mode for reboot handling (Mike Snitzer) [1810746]
- [md] dm integrity: handle machine reboot in bitmap mode (Mike Snitzer) [1810746]
- [md] dm integrity: add a bitmap mode (Mike Snitzer) [1810746]
- [md] dm integrity: introduce a function add_new_range_and_wait() (Mike Snitzer) [1810746]
- [md] dm integrity: allow large ranges to be described (Mike Snitzer) [1810746]
- [md] dm ingerity: pass size to dm_integrity_alloc_page_list() (Mike Snitzer) [1810746]
- [md] dm integrity: introduce rw_journal_sectors() (Mike Snitzer) [1810746]
- [md] dm crypt and integrity: shash - remove shash_desc::flags (Mike Snitzer) [1810746]
- [md] dm: fix potential for q->make_request_fn NULL pointer (Mike Snitzer) [1794340]
- [netdrv] net/mlx5e: Don't clear the whole vf config when switching modes (mohamad meib) [1811428]
- [scsi] scsi: be2iscsi: be_main: Mark expected switch fall-through (Maurizio Lombardi) [1796740]
- [scsi] scsi: be2iscsi: be_iscsi: Mark expected switch fall-through (Maurizio Lombardi) [1796740]
- [scsi] scsi: be2iscsi: switch to generic DMA API (Maurizio Lombardi) [1796740]
- [scsi] scsi: be2iscsi: fix spelling mistake "Retreiving" -> "Retrieving" (Maurizio Lombardi) [1796740]
- [scsi] scsi: be2iscsi: remove unused variable dmsg (Maurizio Lombardi) [1796740]
- [scsi] scsi: be2iscsi: Update copyright (Maurizio Lombardi) [1796740]
- [security] selinux: fix sidtab string cache locking (Ondrej Mosnacek) [1807001 1806991]
- [security] selinux: do not allocate ancillary buffer on first load (Ondrej Mosnacek) [1807001]
- [security] selinux: remove redundant selinux_nlmsg_perm (Ondrej Mosnacek) [1807001]
- [security] selinux: fix wrong buffer types in policydb.c (Ondrej Mosnacek) [1807001]
- [security] selinux: treat atomic flags more carefully (Ondrej Mosnacek) [1807001]
- [security] selinux: make default_noexec read-only after init (Ondrej Mosnacek) [1807001]
- [security] selinux: move ibpkeys code under CONFIG_SECURITY_INFINIBAND (Ondrej Mosnacek) [1807001]
- [security] Documentation, selinux: fix references to old selinuxfs mount point (Ondrej Mosnacek) [1807001]
- [security] selinuxfs: use scnprintf to get real length for inode (Ondrej Mosnacek) [1807001]
- [security] selinux: remove set but not used variable 'sidtab' (Ondrej Mosnacek) [1807001]
- [security] selinux: ensure the policy has been loaded before reading the sidtab stats (Ondrej Mosnacek) [1807001]
- [security] selinux: ensure we cleanup the internal AVC counters on error in avc_update() (Ondrej Mosnacek) [1807001]
- [security] selinux: randomize layout of key structures (Ondrej Mosnacek) [1807001]
- [security] selinux: clean up selinux_enabled/disabled/enforcing_boot (Ondrej Mosnacek) [1807001]
- [security] selinux: remove unnecessary selinux cred request (Ondrej Mosnacek) [1807001]
- [security] selinux: ensure we cleanup the internal AVC counters on error in avc_insert() (Ondrej Mosnacek) [1807001]
- [security] security: only build lsm_audit if CONFIG_SECURITY=y (Ondrej Mosnacek) [1807001]
- [security] selinux: clean up selinux_inode_permission MAY_NOT_BLOCK tests (Ondrej Mosnacek) [1807001]
- [security] selinux: fall back to ref-walk if audit is required (Ondrej Mosnacek) [1807001]
- [security] selinux: revert "stop passing MAY_NOT_BLOCK to the AVC upon follow_link" (Ondrej Mosnacek) [1807001]
- [security] selinux: cache the SID -> context string translation (Ondrej Mosnacek) [1807001 1806991]
- [security] selinux: sidtab reverse lookup hash table (Ondrej Mosnacek) [1807001]
- [security] selinux: default_range glblub implementation (Ondrej Mosnacek) [1807001]
- [security] selinux: allow labeling before policy is loaded (Ondrej Mosnacek) [1807001 1777525]
- [security] selinux: remove load size limit (Ondrej Mosnacek) [1807001]
- [security] selinux: fix residual uses of current_security() for the SELinux blob (Ondrej Mosnacek) [1807001]
- [kernel] rcu: Make kfree_rcu() ignore NULL pointers (Ondrej Mosnacek) [1807001]
- [security] SELinux: Abstract use of ipc security blobs (Ondrej Mosnacek) [1807001]
- [security] SELinux: Abstract use of inode security blob (Ondrej Mosnacek) [1807001]
- [security] SELinux: Abstract use of file security blob (Ondrej Mosnacek) [1807001]
- [security] SELinux: Abstract use of cred security blob (Ondrej Mosnacek) [1807001]
- [security] selinux: kill selinux_sb_get_mnt_opts() (Ondrej Mosnacek) [1807001]
- [security] selinux; don't open-code a loop in sb_finish_set_opts() (Ondrej Mosnacek) [1807001]
- [security] selinux: expand superblock_doinit() calls (Ondrej Mosnacek) [1807001]
- [netdrv] hv_netvsc: Fix unwanted rx_table reset (Mohammed Gamal) [1805950]
- [netdrv] hv_netvsc: Fix tx_table init in rndis_set_subchannel() (Mohammed Gamal) [1805950]
- [netdrv] hv_netvsc: Fix send_table offset in case of a host bug (Mohammed Gamal) [1805950]
- [netdrv] hv_netvsc: Fix offset usage in netvsc_send_table() (Mohammed Gamal) [1805950]

* Sat Mar 14 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-188.1.el8]
- [block] blk-mq: Keep set->nr_hw_queues and set->map.nr_queues in sync (Ming Lei) [1810523]
- [block] block: clear REQ_HIPRI if polling is not supported (Ming Lei) [1809506]

* Thu Mar 12 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-187.2.el8]
- [perf] arm_spe: Enable ACPI/Platform automatic module loading (Jeremy Linton) [1501652]
- [perf] perf: arm_spe: Don't error on high-order pages for aux buf (Jeremy Linton) [1501652]
- [perf] arm_spe: handle devm_kasprintf() failure (Jeremy Linton) [1501652]
- [perf] arm_spe: Enable automatic DT loading (Jeremy Linton) [1501652]
- [block] blk-iolatency: fix STS_AGAIN handling (Ming Lei) [1764737]
- [block] blk-iolatency: only account submitted bios (Ming Lei) [1764737]
- [block] blk-iolatency: clear use_delay when io.latency is set to zero (Ming Lei) [1764737]
- [block] blk-iolatency: #include "blk.h" (Ming Lei) [1764737]
- [block] Blk-iolatency: warn on negative inflight IO counter (Ming Lei) [1764737]
- [block] blk-iolatency: fix IO hang due to negative inflight counter (Ming Lei) [1764737]
- [block] block: fix blk-iolatency accounting underflow (Ming Lei) [1764737]
- [fs] xfs: stabilize insert range start boundary to avoid COW writeback race (Brian Foster) [1728979]
- [x86] uprobes/x86: Fix detection of 32-bit user mode (Oleg Nesterov) [1804961]
- [ipc] Revert "ipc, sem: remove uneeded sem_undo_list lock usage in exit_sem()" ("Herton R. Krzesinski") [1807627]
- [powerpc] powerpc/tm: Fix clearing MSRin current when reclaiming on signal delivery (Gustavo Duarte) [1751116]
- [powerpc] powerpc/tm: Set MSRjust prior to recheckpoint (Gustavo Duarte) [1751116]
- [arm64] arm64: smp: Increase secondary CPU boot timeout value (Gavin Shan) [1807684]
- [fs] ext4: work around deleting a file with i_nlink == 0 safely (Carlos Maiolino) [1801049]
- [char] ipmi: fix sleep-in-atomic in free_user at cleanup SRCU user->release_barrier (Waiman Long) [1810638]
- [char] ipmi: Revert "fix sleep-in-atomic in free_user at cleanup SRCU user->release_barrier" (Waiman Long) [1810638]

* Tue Mar 10 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-187.1.el8]
- [kernel] blktrace: Protect q->blk_trace with RCU (Ming Lei) [1798329]
- [drm] drm/i915: Force DPCD backlight mode for some Dell CML 2020 panels (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/i915: Force DPCD backlight mode on X1 Extreme 2nd Gen 4K AMOLED panel (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/dp: Introduce EDID-based quirks (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/i915: Auto detect DPCD backlight support by default (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/i915: Fix DPCD register order in intel_dp_aux_enable_backlight() (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/i915: Assume 100 brightness when not in DPCD control mode (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/i915: Fix eDP DPCD aux max backlight calculations (Lyude Paul) [1782671 1773796 1748892]
- [drm] drm/i915: Check backlight type while doing eDP backlight initializaiton (Lyude Paul) [1782671 1773796 1748892]
- [tools] selftests: nft_concat_range: Add test for reported add/flush/add issue (Stefano Brivio) [1807892]
- [net] nft_set_pipapo: Actually fetch key data in nft_pipapo_remove() (Stefano Brivio) [1807892]
- [net] sched: don't take rtnl lock during flow_action setup (Marcelo Leitner) [1804385]
- [include] net: sched: refactor ct action helpers to require tcf_lock (Marcelo Leitner) [1804385]
- [include] net: sched: refactor police action helpers to require tcf_lock (Marcelo Leitner) [1804385]
- [net] sched: lock action when translating it to flow_action infra (Marcelo Leitner) [1804385]
- [powerpc] powerpc/smp: Fix NMI IPI xmon timeout (Diego Domingos) [1747320]
- [powerpc] powerpc/smp: Fix NMI IPI timeout (Diego Domingos) [1747320]
- [powerpc] powerpc: NMI IPI make NMI IPIs fully sychronous (Diego Domingos) [1747320]
- [arm64] arm64: select CPUMASK_OFFSTACK if NUMA (Andrea Arcangeli) [1712856]
- [arm64] arm64: tlb: skip tlbi broadcast (Andrea Arcangeli) [1712856]

* Mon Mar 09 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-186.2.el8]
- [fs] fs/proc/proc_sysctl.c: Fix a NULL pointer dereference (Vladis Dronov) [1795521] {CVE-2019-20054}
- [fs] fs/proc/proc_sysctl.c: fix NULL pointer dereference in put_links (Vladis Dronov) [1795521] {CVE-2019-20054}
- [ptp] ptp: correctly disable flags on old ioctls (Petr Oros) [1795188]
- [uapi] PTP: add support for one-shot output (Petr Oros) [1795188]
- [ptp] PTP: introduce new versions of IOCTLs (Petr Oros) [1795188]
- [virtio] virtio_ring: fix stalls for packed rings (Eugenio Perez) [1601355]
- [virtio] virtio_ring: Fix potential mem leak in virtqueue_add_indirect_packed (Eugenio Perez) [1601355]
- [uapi] virtio: drop internal struct from UAPI (Eugenio Perez) [1601355]
- [virtio] virtio_ring: advertize packed ring layout (Eugenio Perez) [1601355]
- [virtio] virtio_ring: leverage event idx in packed ring (Eugenio Perez) [1601355]
- [virtio] virtio_ring: introduce packed ring support (Eugenio Perez) [1601355]
- [virtio] virtio_ring: cache whether we will use DMA API (Eugenio Perez) [1601355]
- [virtio] virtio_ring: extract split ring handling from ring creation (Eugenio Perez) [1601355]
- [virtio] virtio_ring: allocate desc state for split ring separately (Eugenio Perez) [1601355]
- [virtio] virtio_ring: introduce helper for indirect feature (Eugenio Perez) [1601355]
- [virtio] virtio_ring: introduce debug helpers (Eugenio Perez) [1601355]
- [virtio] virtio_ring: put split ring fields in a sub struct (Eugenio Perez) [1601355]
- [virtio] virtio_ring: put split ring functions together (Eugenio Perez) [1601355]
- [virtio] virtio_ring: add _split suffix for split ring functions (Eugenio Perez) [1601355]
- [uapi] virtio: add packed ring types and macros (Eugenio Perez) [1601355]
- [x86] x86/mtrr: Skip cache flushes on CPUs with cache self-snooping (Prarit Bhargava) [1724541]
- [x86] x86/cpu/intel: Clear cache self-snoop capability in CPUs with known errata (Prarit Bhargava) [1724541]
- [documentation] Documentation PCI: Fix pciebus-howto.rst filename typo (Myron Stowe) [1793091]
- [tools] tools: PCI: Fix installation when `make tools/pci_install` (Myron Stowe) [1793091]
- [tools] tools: PCI: Fix broken pcitest compilation (Myron Stowe) [1793091]
- [tools] tools pci: Do not delete pcitest.sh in 'make clean' (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Clear BAR before freeing its space (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Skip odd BAR when skipping 64bit BAR (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Allocate enough space for fixed size BAR (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Set endpoint controller pointer to NULL (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Add support to specify alignment for buffers allocated to BARs (Myron Stowe) [1793091]
- [pci] PCI: pci-epf-test: Use pci_epc_get_features() to get EPC features (Myron Stowe) [1793091]
- [pci] PCI: pci-epf-test: Do not allocate next BARs memory if current BAR is 64Bit (Myron Stowe) [1793091]
- [pci] PCI: pci-epf-test: Remove setting epf_bar flags in function driver (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Fix pci_epf_alloc_space() to set correct MEM TYPE flags (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Add helper to get first unreserved BAR (Myron Stowe) [1793091]
- [pci] PCI: endpoint: Add new pci_epc_ops to get EPC features (Myron Stowe) [1793091]
- [pci] PCI: endpoint: functions: Use memcpy_fromio()/memcpy_toio() (Myron Stowe) [1793091]
- [pci] PCI: Skip resource distribution when no hotplug bridges (Myron Stowe) [1793091]
- [pci] PCI: Simplify pci_bus_distribute_available_resources() (Myron Stowe) [1793091]
- [pci] PCI: Reset both NVIDIA GPU and HDA in ThinkPad P50 workaround (Myron Stowe) [1793091]
- [pci] PCI: Enable NVIDIA HDA controllers (Myron Stowe) [1793091]
- [pci] PCI: Use seq_puts() instead of seq_printf() in show_device() (Myron Stowe) [1793091]
- [pci] PCI: Add NVIDIA GPU multi-function power dependencies (Myron Stowe) [1793091]
- [pci] PCI: Generalize multi-function power dependency device links (Myron Stowe) [1793091]
- [pci] PCI: sysfs: Ignore lockdep for remove attribute (Myron Stowe) [1793091]
- [pci] PCI: Decode PCIe 32 GT/s link speed (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert endpoint/pci-test-howto.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert endpoint/pci-test-function.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert endpoint/pci-endpoint-cfs.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert endpoint/pci-endpoint.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert pcieaer-howto.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert pci-error-recovery.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert acpi-info.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert MSI-HOWTO.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert pci-iov-howto.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert PCIEBUS-HOWTO.txt to reST (Myron Stowe) [1793091]
- [documentation] docs: pci: fix broken links due to conversion from pci.txt to pci.rst (Myron Stowe) [1793091]
- [documentation] Documentation: PCI: convert pci.txt to reST (Myron Stowe) [1793091]
- [documentation] Documentation: add Linux PCI to Sphinx TOC tree (Myron Stowe) [1793091]
- [pci] PCI: Reset Lenovo ThinkPad P50 nvgpu at boot if necessary (Myron Stowe) [1793091]
- [pci] PCI: Add a stub for pci_ats_disabled() (Myron Stowe) [1793091]
- [pci] PCI: Provide pci_match_id() with CONFIG_PCI=n (Myron Stowe) [1793091]
- [misc] ocxl: Add PCI hotplug dependency to Kconfig (Steve Best) [1788902]
- [pci] pci/hotplug/pnv-php: Wrap warnings in macro (Steve Best) [1788902]
- [pci] pci/hotplug/pnv-php: Relax check when disabling slot (Steve Best) [1788902]
- [pci] pci/hotplug/pnv-php: Register opencapi slots (Steve Best) [1788902]
- [pci] pci/hotplug/pnv-php: Improve error msg on power state change failure (Steve Best) [1788902]
- [pci] pci/hotplug/pnv-php: Remove erroneous warning (Steve Best) [1788902]
- [powerpc] powerpc/powernv/ioda: Find opencapi slot for a device node (Steve Best) [1788902]
- [powerpc] powerpc/powernv/ioda: Release opencapi device (Steve Best) [1788902]
- [powerpc] powerpc/powernv/ioda: set up PE on opencapi device when enabling (Steve Best) [1788902]
- [powerpc] powerpc/powernv/ioda: Protect PE list (Steve Best) [1788902]
- [powerpc] powerpc/powernv/ioda: Fix ref count for devices with their own PE (Steve Best) [1788902]
- [of] of: overlay: add_changeset_property() memory leak (Steve Best) [1798483]
- [of] of: unittest: initialize args before calling of_*parse_*() (Steve Best) [1798483]
- [of] of: unittest: find overlaysentry by name instead of index (Steve Best) [1798483]
- [of] of: unittest: allow base devicetree to have symbol metadata (Steve Best) [1798483]
- [of] of: overlay: set node fields from properties when add new overlay node (Steve Best) [1798483]
- [of] of: unittest: remove unused of_unittest_apply_overlay() argument (Steve Best) [1798483]
- [of] of: overlay: check prevents multiple fragments touching same property (Steve Best) [1798483]
- [of] of: overlay: check prevents multiple fragments add or delete same node (Steve Best) [1798483]
- [of] of: overlay: test case of two fragments adding same node (Steve Best) [1798483]
- [of] of: overlay: make all pr_debug() and pr_err() messages unique (Steve Best) [1798483]
- [of] of: overlay: validate overlay properties (Steve Best) [1798483]
- [of] of: overlay: reorder fields in struct fragment (Steve Best) [1798483]
- [of] of: overlay: do not duplicate properties from overlay for new nodes (Steve Best) [1798483]
- [of] of: overlay: use prop add changeset entry for property in new nodes (Steve Best) [1798483]
- [of] of: Convert to using pOFn instead of device_node.name (Steve Best) [1798483]
- [powerpc] powerpc/pseries: add of_node_put() in dlpar_detach_node() (Steve Best) [1798483]
- [of] of: overlay: add missing of_node_get() in __of_attach_node_sysfs (Steve Best) [1798483]
- [of] of: overlay: add missing of_node_put() after add new node to changeset (Steve Best) [1798483]
- [of] of: overlay: add tests to validate kfrees from overlay removal (Steve Best) [1798483]

* Sat Mar 07 2020 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-186.1.el8]
- [kernel] open the RHEL 8.3 development (Frantisek Hrbata)
- [netdrv] Revert "r8169: don't use MSI before RTL8168d" (Josef Oskera) [1792839]
- [drm] drm/nouveau/kms/gv100-: Re-set LUT after clearing for modesets (Ben Skeggs) [1789026]
- [drm] drm/nouveau/disp/gv100-: not all channel types support reporting error codes (Ben Skeggs) [1789481]
- [drm] drm/nouveau/disp/nv50-: prevent oops when no channel method map provided (Ben Skeggs) [1789481]
- [fs] cifs: don't leak -EAGAIN for stat() during reconnect (Dave Wysochanski) [1769599]
- [block] blk-mq: insert passthrough request into hctx->dispatch directly (Ming Lei) [1788728]
- [scsi] scsi: megaraid_sas: fixup MSIx interrupt setup during resume (Tomas Henzl) [1805353]

* Fri Feb 28 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-185.el8]
- [fs] NFS: Add deferred cache invalidation for close-to-open consistency violations (Benjamin Coddington) [1803162]
- [block] nbd: fix stack corruption in nbd_check_sock_type() (Ming Lei) [1803664]
- [mm] mm/vmscan.c: don't round up scan size for online memory cgroup (Aristeu Rozanski) [1775691]
- [tools] selftests/bpf: fix clearing buffered output between tests/subtests (Yauheni Kaliuta) [1786006]
- [tools] libbpf: avoid usage of __builtin_preserve_field_info (Yauheni Kaliuta) [1786006]
- [tools] selftests/bpf: samples/bpf: fix Split off legacy stuff from bpf_helpers.h (Yauheni Kaliuta) [1786006]
- [tools] libbpf: fix Make DECLARE_LIBBPF_OPTS macro strictly a variable declaration (Yauheni Kaliuta) [1786006]
- [tools] selftests: fix too long argument (Yauheni Kaliuta) [1786006]
- [tools] libbpf: Add BPF-side definitions of supported field relocation kinds (Yauheni Kaliuta) [1786006]
- [tools] selftests/bpf: add sub-tests support for test_progs (Yauheni Kaliuta) [1786006]
- [tools] selftests/bpf: abstract away test log output (Yauheni Kaliuta) [1786006]
- [tools] selftest/bpf: centralize libbpf logging management for test_progs (Yauheni Kaliuta) [1786006]
- [tools] selftests/bpf: prevent headers to be compiled as C code (Yauheni Kaliuta) [1786006]
- [tools] selftests/bpf: add test selectors by number and name to test_progs (Yauheni Kaliuta) [1786006]
- [tools] selftests/bpf: revamp test_progs to allow more control (Yauheni Kaliuta) [1786006]
- [net] core: Don't skip generic XDP program execution for cloned SKBs (Jiri Benc) [1802507]
- [tools] selftests/bpf: De-flake test_tcpbpf (Jiri Benc) [1802507]
- [net] bpf, sockmap: Check update requirements after locking (Jiri Benc) [1802507]
- [net] bpf, sockhash: Synchronize_rcu before free'ing map (Jiri Benc) [1802507]
- [net] bpf, sockmap: Don't sleep while holding RCU lock on tear-down (Jiri Benc) [1802507]
- [net] net: bpf: Don't leak time wait and request sockets (Jiri Benc) [1802507]
- [net] bpf/sockmap: Read psock ingress_msg before sk_receive_queue (Jiri Benc) [1802507]
- [net] bpf: Clear skb->tstamp in bpf_redirect when necessary (Jiri Benc) [1802507]
- [net] xdp: obtain the mem_id mutex before trying to remove an entry (Jiri Benc) [1802507]
- [net] page_pool: do not release pool until inflight == 0 (Jiri Benc) [1802507]
- [net] xsk: Fix registration of Rx-only sockets (Jiri Benc) [1802507]
- [net] xsk: avoid store-tearing when assigning umem (Jiri Benc) [1802507]
- [net] xsk: avoid store-tearing when assigning queues (Jiri Benc) [1802507]
- [tools] bpftool: Don't crash on missing xlated program instructions (Jiri Benc) [1802507]
- [tools] bpftool: Fix printing incorrect pointer in btf_dump_ptr (Jiri Benc) [1802507]
- [tools] bpftool: Don't crash on missing jited insns or ksyms (Jiri Benc) [1802507]
- [tools] bpftool: Match several programs with same tag (Jiri Benc) [1802507]
- [tools] libbpf: Fix realloc usage in bpf_core_find_cands (Jiri Benc) [1802507]
- [tools] libbpf: Add missing newline in opts validation macro (Jiri Benc) [1802507]
- [tools] libbpf: Don't attach perf_buffer to offline/missing CPUs (Jiri Benc) [1802507]
- [tools] libbpf: Extract and generalize CPU mask parsing logic (Jiri Benc) [1802507]
- [tools] libbpf: Fix printf compilation warnings on ppc64le arch (Jiri Benc) [1802507]
- [tools] libbpf: Fix sym->st_value print on 32-bit arches (Jiri Benc) [1802507]
- [tools] libbpf: Make btf__resolve_size logic always check size error condition (Jiri Benc) [1802507]
- [tools] libbpf: Fix another potential overflow issue in bpf_prog_linfo (Jiri Benc) [1802507]
- [tools] libbpf: Fix potential overflow issue (Jiri Benc) [1802507]
- [tools] libbpf: Fix memory leak/double free issue (Jiri Benc) [1802507]
- [tools] libbpf: Fix off-by-one error in ELF sanity check (Jiri Benc) [1802507]
- [tools] selftests/bpf: Fix test_attach_probe (Jiri Benc) [1802507]
- [kernel] bpf: Fix bpf_event_output re-entry issue (Jiri Benc) [1802507]
- [net] bpf: Fix incorrect verifier simulation of ARSH under ALU32 (Jiri Benc) [1802507]
- [net] bpf: Fix passing modified ctx to ld/abs/ind instruction (Jiri Benc) [1802507]
- [net] bpf: cgroup: prevent out-of-order release of cgroup bpf (Jiri Benc) [1802507]
- [net] bpf: Fix precision tracking for unbounded scalars (Jiri Benc) [1802507]
- [net] bpf: Fix cgroup local storage prog tracking (Jiri Benc) [1802507]
- [net] bpf/stackmap: Fix deadlock with rq_lock in bpf_get_stack() (Jiri Benc) [1802507]
- [net] bpf, offload: Unlock on error in bpf_offload_dev_create() (Jiri Benc) [1802507]
- [powerpc] powerpc/bpf: Fix tail call implementation (Jiri Benc) [1802507]
- [net] bpf: Fix use after free in bpf_get_prog_name (Jiri Benc) [1802507]
- [net] bpf: Fix use after free in subprog's jited symbol removal (Jiri Benc) [1802507]
- [uapi] bpf: fix BTF limits (Jiri Benc) [1802507]
- [net] bpf: fix BTF verification of enums (Jiri Benc) [1802507]
- [netdrv] ice: Don't tell the OS that link is going down (Jonathan Toppins) [1792670]
- [powerpc] powerpc/powernv: implement opal_put_chars_atomic (Steve Best) [1806254]
- [tty] powerpc/powernv: move opal console flushing to udbg (Steve Best) [1806254]
- [powerpc] powerpc/powernv: Remove OPALv1 support from opal console driver (Steve Best) [1806254]
- [powerpc] powerpc/powernv: Implement and use opal_flush_console (Steve Best) [1806254]
- [powerpc] powerpc/powernv: opal-kmsg use flush fallback from console code (Steve Best) [1806254]
- [powerpc] powerpc/powernv: opal-kmsg standardise OPAL_BUSY handling (Steve Best) [1806254]
- [powerpc] powerpc/powernv: Fix OPAL console driver OPAL_BUSY loops (Steve Best) [1806254]
- [powerpc] powerpc/powernv: opal_put_chars partial write fix (Steve Best) [1806254]
- [x86] Mark Comet Lake-S as supported (David Arcari) [1805754]

* Tue Feb 25 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-184.el8]
- rebuild, due infrastructure issues last kernel build wasn't signed properly [1807216]

* Sun Feb 23 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-183.el8]
- [nvme] nvme-multipath: Fix memory leak with ana_log_buf (David Milburn) [1804822]
- [powerpc] pci/of: Fix OF flags parsing for 64bit BARs (David Gibson) [1804038]

* Fri Feb 21 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-182.el8]
- [pci] PCI: pciehp: Add DMI table for in-band presence disabled (Myron Stowe) [1749528]
- [pci] PCI: pciehp: Wait for PDS if in-band presence is disabled (Myron Stowe) [1749528]
- [pci] PCI: pciehp: Add support for disabling in-band presence (Myron Stowe) [1749528]
- [netdrv] net/mlx5: DR, Handle reformat capability over sw-steering tables (Alaa Hleihel) [1794997]
- [netdrv] net/mlx5: DR, Fix matching on vport gvmi (Alaa Hleihel) [1794997]
- [netdrv] net/mlx5: DR, use non preemptible call to get the current cpu number (Alaa Hleihel) [1794997]
- [netdrv] net/mlx5: DR, Enable counter on non-fwd-dest objects (Alaa Hleihel) [1794997]
- [iommu] iommu/vt-d: Simplify check in identity_mapping() (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Remove deferred_attach_domain() (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Do deferred attachment in iommu_need_mapping() (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Move deferred device attachment into helper function (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Add attach_deferred() helper (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Refactor find_domain() helper (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Allow devices with RMRRs to use identity domain (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Call __dmar_remove_one_dev_info with valid pointer (Jerry Snitselaar) [1797124 1784649]
- [iommu] iommu/vt-d: Fix lock inversion between iommu->lock and device_domain_lock (Jerry Snitselaar) [1797124 1784649]
- [ata] ata: ahci: Add shutdown to freeze hardware resources of ahci (David Milburn) [1784955]
- [include] redhat: kabi: convert incorrect use of RH_KABI_EXTEND (Jiri Benc) [1715803]
- [include] redhat: kabi: macros for intentional kABI breakage (Jiri Benc) [1715803]
- [uapi] redhat: kabi: bpf: remove misleading comment (Jiri Benc) [1715803]
- [include] redhat: kabi: introduce RH_KABI_HIDE_INCLUDE and RH_KABI_FAKE_INCLUDE (Jiri Benc) [1715803]
- [kernel] kernel/module.c: wakeup processes in module_wq on module unload (Prarit Bhargava) [1804209]
- [x86] kvm: x86: do not reset microcode version on INIT or RESET (Paolo Bonzini) [1801853]
- [x86] kvm: x86: list MSR_IA32_UCODE_REV as an emulated MSR (Paolo Bonzini) [1801853]
- [nvme] nvme: prevent warning triggered by nvme_stop_keep_alive (David Milburn) [1799890]
- [nvme] nvme: nvme_keep_alive_end_io fixup setting comp_seen flag (David Milburn) [1799890]

* Thu Feb 20 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-181.el8]
- [iommu] iommu: don't change default domain if already set by quirk (Jerry Snitselaar) [1786292]
- [net] netfilter: ipset: Copy the right MAC address in hash:ip, mac IPv6 sets (Stefano Brivio) [1759422]
- [net] ipv6/addrconf: only check invalid header values when NETLINK_F_STRICT_CHK is set (Guillaume Nault) [1802817]
- [net] tcp: clear tp->segs_{in|out} in tcp_disconnect() (Guillaume Nault) [1802682]
- [net] tcp: clear tp->data_segs{in|out} in tcp_disconnect() (Guillaume Nault) [1802682]
- [net] tcp: clear tp->delivered in tcp_disconnect() (Guillaume Nault) [1802682]
- [net] tcp: clear tp->total_retrans in tcp_disconnect() (Guillaume Nault) [1802682]
- [net] tcp: do not leave dangling pointers in tp->highest_sack (Guillaume Nault) [1802682]
- [net] tcp: Fix highest_sack and highest_sack_seq (Guillaume Nault) [1802682]
- [net] tcp: do not send empty skb from tcp_write_xmit() (Guillaume Nault) [1802682]
- [net] tcp: md5: fix potential overestimation of TCP option space (Guillaume Nault) [1802682]
- [net] tcp: fix data-race in tcp_recvmsg() (Guillaume Nault) [1802682]
- [net] bridge: ebtables: don't crash when using dnat target in output chains (Andrea Claudi) [1798923]
- [net] ip6_tunnel: fix namespaces move (Andrea Claudi) [1798649]
- [net] ip_tunnel: fix namespaces move (Andrea Claudi) [1798649]
- [net] ipv4: Detect rollover in specific fib table dump (Guillaume Nault) [1801587]
- [net] inet: protect against too small mtu values. (Guillaume Nault) [1801587]
- [net] icmp: fix data-race in cmp_global_allow() (Guillaume Nault) [1801587]
- [net] inetpeer: fix data-race in inet_putpeer / inet_putpeer (Guillaume Nault) [1801587]
- [net] ipv4: Fix table id reference in fib_sync_down_addr (Guillaume Nault) [1801587]
- [net] dccp: do not leak jiffies on the wire (Guillaume Nault) [1801587]
- [net] inet: stop leaking jiffies on the wire (Guillaume Nault) [1801587]
- [tools] selftests: fib_tests: add more tests for metric update (Guillaume Nault) [1801587]
- [net] ipv4: fix route update on metric change. (Guillaume Nault) [1801587]
- [net] iptunnel: Set tun_flags in the iptunnel_metadata_reply from src (Guillaume Nault) [1801587]
- [net] flow_dissector: Fix to use new variables for port ranges in bpf hook (Ivan Vecera) [1789862]
- [net] net_sched: fix a resource leak in tcindex_set_parms() (Ivan Vecera) [1789862]
- [tools] tc-testing: fix eBPF tests failure on linux fresh clones (Ivan Vecera) [1789862]
- [net] net_sched: fix an OOB access in cls_tcindex (Ivan Vecera) [1789862]
- [net] cls_rsvp: fix rsvp_policy (Ivan Vecera) [1789862]
- [net] net_sched: ematch: reject invalid TCF_EM_SIMPLE (Ivan Vecera) [1789862]
- [net] net_sched: walk through all child classes in tc_bind_tclass() (Ivan Vecera) [1789862]
- [net] net_sched: fix ops->bind_class() implementations (Ivan Vecera) [1789862]
- [net] net_sched: fix datalen for ematch (Ivan Vecera) [1789862]
- [net] net_sched: use validated TCA_KIND attribute in tc_new_tfilter() (Ivan Vecera) [1789862]
- [net] sch_prio: When ungrafting, replace with FIFO (Ivan Vecera) [1789862]
- [net] pkt_sched: fq: do not accept silly TCA_FQ_QUANTUM (Ivan Vecera) [1789862]
- [net] sched: add delete_empty() to filters and use it in cls_flower (Ivan Vecera) [1789862]
- [net] sched: act_mirred: Pull mac prior redir to non mac_header_xmit device (Ivan Vecera) [1789862]
- [net] sched: cls_u32: fix refcount leak in the error path of u32_change() (Ivan Vecera) [1789862]
- [net] net_sched: sch_fq: properly set sk->sk_pacing_status (Ivan Vecera) [1789862]
- [net] net_sched: validate TCA_KIND attribute in tc_chain_tmplt_add() (Ivan Vecera) [1789862]
- [net] mqprio: Fix out-of-bounds access in mqprio_dump (Ivan Vecera) [1789862]
- [net] sched: allow indirect blocks to bind to clsact in TC (Ivan Vecera) [1789862]
- [net] core: rename indirect block ingress cb function (Ivan Vecera) [1789862]
- [net] Fixed updating of ethertype in skb_mpls_push() (Ivan Vecera) [1789862]
- [net] cls_flower: Fix the behavior using port ranges with hw-offload (Ivan Vecera) [1789862]
- [net] sched: fix dump qlen for sch_mq/sch_mqprio with NOLOCK subqueues (Ivan Vecera) [1789862]
- [net] Fixed updating of ethertype in function skb_mpls_pop (Ivan Vecera) [1789862]
- [net] sched: fix `tc -s class show` no bstats on class with nolock subqueues (Ivan Vecera) [1789862]
- [net] sched: act_pedit: fix WARN() in the traffic path (Ivan Vecera) [1789862]
- [net] sched: actions: remove unused 'order' (Ivan Vecera) [1789862]
- [net] sched: annotate lockless accesses to qdisc->empty (Ivan Vecera) [1789862]
- [net] annotate lockless accesses to sk->sk_max_ack_backlog (Ivan Vecera) [1789862]
- [net] inet: minor optimization for backlog setting in listen(2) (Ivan Vecera) [1789862]
- [net] annotate lockless accesses to sk->sk_ack_backlog (Ivan Vecera) [1789862]
- [net] use helpers to change sk_ack_backlog (Ivan Vecera) [1789862]
- [net] sched: prevent duplicate flower rules from tcf_proto destroy race (Ivan Vecera) [1789862]
- [net] flow_dissector: switch to siphash (Ivan Vecera) [1789862]
- [netdrv] macvlan: use skb_reset_mac_header() in macvlan_queue_xmit() (Davide Caratti) [1801128]
- [netdrv] macvlan: do not assume mac_header is set in macvlan_broadcast() (Davide Caratti) [1801128]
- [net] psample: fix skb_over_panic (Sabrina Dubroca) [1800589]
- [net] openvswitch: don't unlock mutex when changing the user_features fails (Davide Caratti) [1799363]
- [net] rtnetlink: validate IFLA_MTU attribute in rtnl_create_link() (Guillaume Nault) [1798715]
- [net] rtnetlink: fix a typo fbd -> fdb (Guillaume Nault) [1798715]
- [net] bpf: Sockmap, skmsg helper overestimates push, pull, and pop bounds (Sabrina Dubroca) [1798179]
- [net] bpf: Sockmap/tls, msg_push_data may leave end mark in place (Sabrina Dubroca) [1798179]
- [net] bpf: Sockmap/tls, push write_space updates through ulp updates (Sabrina Dubroca) [1798179]
- [net] sk_msg: Don't check if sock is locked when tearing down psock (Sabrina Dubroca) [1798179]
- [net] bpf: Sockmap/tls, fix pop data with SK_DROP return code (Sabrina Dubroca) [1798179]
- [net] bpf: Sockmap/tls, skmsg can have wrapped skmsg that needs extra chaining (Sabrina Dubroca) [1798179]
- [net] bpf: Sockmap/tls, tls_sw can create a plaintext buf > encrypt buf (Sabrina Dubroca) [1798179]
- [include] bpf: Sockmap/tls, during free we may call tcp_bpf_unhash() in loop (Sabrina Dubroca) [1798179]
- [net] bpf: Sockmap, ensure sock lock held during tear down (Sabrina Dubroca) [1798179]
- [net] tls: fix async operation (Sabrina Dubroca) [1798179]
- [net] tls: Fix return values to avoid ENOTSUPP (Sabrina Dubroca) [1798179]
- [net] skmsg: fix TLS 1.3 crash with full sk_msg (Sabrina Dubroca) [1798179]
- [net] tls: free the record on encryption error (Sabrina Dubroca) [1798179]
- [net] tls: take into account that bpf_exec_tx_verdict() may free the record (Sabrina Dubroca) [1798179]
- [net] bpf: skmsg, fix potential psock NULL pointer dereference (Sabrina Dubroca) [1798179]
- [net] tls: enable sk_msg redirect to tls socket egress (Sabrina Dubroca) [1798179]
- [netdrv] macsec: fix refcnt leak in module exit routine (Sabrina Dubroca) [1799029]
- [netdrv] ppp: Adjust indentation into ppp_async_input (Guillaume Nault) [1798104]
- [net] l2tp: Allow duplicate session creation with UDP (Guillaume Nault) [1798104]
- [net] Fix bugs introduced by netlink strict checking backport (Petr Oros) [1782172]
- [tools] selftests: forwarding: fix race between packet receive and tc check (Hangbin Liu) [1797941]
- [tools] selftests: forwarding: tc_common: Add hitting check (Hangbin Liu) [1797941]
- [tools] selftests: net: push jq workaround into separate helper (Hangbin Liu) [1797941]
- [tools] selftests: loopback.sh: skip this test if the driver does not support (Hangbin Liu) [1797941]
- [tools] selftests: pmtu: fix init mtu value in description (Hangbin Liu) [1797941]
- [tools] selftests: forwarding: Delete IPv6 address at the end (Hangbin Liu) [1797941]
- [tools] selftests: pmtu: use -oneline for ip route list cache (Hangbin Liu) [1797941]
- [tools] selftests: net: tcp_mmap should create detached threads (Hangbin Liu) [1797941]
- [tools] selftests: net: reuseport_dualstack: fix uninitalized parameter (Hangbin Liu) [1797941]
- [net] tipc: fix link overflow issue at socket shutdown (Xin Long) [1798070]
- [net] tipc: fix retrans failure due to wrong destination (Xin Long) [1798070]
- [net] tipc: fix potential hanging after b/rcast changing (Xin Long) [1798070]
- [net] tipc: fix ordering of tipc module init and exit routine (Xin Long) [1798070]
- [net] tipc: fix wrong timeout input for tipc_wait_for_cond() (Xin Long) [1798070]
- [net] tipc: fix wrong socket reference counter after tipc_sk_timeout() returns (Xin Long) [1798070]
- [net] tipc: fix potential memory leak in __tipc_sendmsg() (Xin Long) [1798070]
- [net] tipc: fix link name length check (Xin Long) [1798070]
- [net] tipc: update replicast capability for broadcast send link (Xin Long) [1798070]
- [net] tipc: update cluster capabilities if node deleted (Xin Long) [1798070]
- [net] tipc: update mon's self addr when node addr generated (Xin Long) [1798070]
- [net] tipc: reduce sensitive to retransmit failures (Xin Long) [1798070]
- [net] sctp: free cmd->obj.chunk for the unprocessed SCTP_CMD_REPLY (Xin Long) [1798061]
- [net] sctp: fully initialize v4 addr in some functions (Xin Long) [1798061]
- [net] sctp: cache netns in sctp_ep_common (Xin Long) [1798061]
- [net] sctp: Fix memory leak in sctp_sf_do_5_2_4_dupcook (Xin Long) [1798061]
- [net] xfrm: support output_mark for offload ESP packets (Xin Long) [1798059]
- [net] xfrm: release device reference for invalid state (Xin Long) [1798059]
- [net] netfilter: fix a use-after-free in mtype_destroy() (Davide Caratti) [1796361]
- [net] netfilter: ipset: avoid null deref when IPSET_ATTR_LINENO is present (Davide Caratti) [1796361]
- [net] netfilter: conntrack: Request module if l3proto is unknown (Phil Sutter) [1752765]
- [include] tcp: Protect accesses to .ts_recent_stamp with {READ,WRITE}_ONCE() (Guillaume Nault) [1780828]
- [include] tcp: tighten acceptance of ACKs not matching a child socket (Guillaume Nault) [1780828]
- [include] tcp: fix rejected syncookies due to stale timestamps (Guillaume Nault) [1780828]
- [net] SUNRPC: Make "no retrans timeout" soft tasks behave like softconn for timeouts (Steve Dickson) [1801454]
- [kernel] genirq, sched/isolation: Isolate from handling managed interrupts (Peter Xu) [1783026]

* Wed Feb 19 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-180.el8]
- [nvme] nvme: fix the parameter order for nvme_get_log in nvme_get_fw_slot_info (David Milburn) [1798630]
- [mm] arm64: debug: Remove unused return value from do_debug_exception() (Bhupesh Sharma) [1802511]
- [mm] arm64: debug: Don't propagate UNKNOWN FAR into si_code for debug signals (Bhupesh Sharma) [1802511]
- [mm] arm64/mm: Reorganize arguments for is_el1_permission_fault() (Bhupesh Sharma) [1802511]
- [mm] arm64/mm: Define esr_to_debug_fault_info() (Bhupesh Sharma) [1802511]
- [infiniband] IB/mlx5: Do reverse sequence during device removal (Alaa Hleihel) [1801497]
- [netdrv] bnxt_en: Fix RDMA driver failure with SRIOV after firmware reset (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Refactor logic to re-enable SRIOV after firmware reset detected (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix logic that disables Bus Master during firmware reset (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix TC queue mapping (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix NTUPLE firmware command failures (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix ipv6 RFS filter matching logic (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Do not treat DSN (Digital Serial Number) read failure as fatal (Jonathan Toppins) [1801868]
- [netdrv] bnxt: Detach page from page pool before sending up the stack (Jonathan Toppins) [1801868]
- [netdrv] bnxt: apply computed clamp value for coalece parameter (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix MSIX request logic for RDMA driver (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Free context memory in the open path if firmware has been reset (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Return error if FW returns more data than dump length (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix bp->fw_health allocation and free logic (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Add missing devlink health reporters for VFs (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix the logic that creates the health reporters (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Do driver unregister cleanup in bnxt_init_one() failure path (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Send FUNC_RESOURCE_QCAPS command in bnxt_resume() (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Combine 2 functions calling the same HWRM_DRV_RGTR fw command (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Abort waiting for firmware response if there is no heartbeat (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Return proper error code for non-existent NVM variable (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Add a warning message for driver initiated reset (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Improve RX buffer error handling (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Extend ETHTOOL_RESET to hot reset driver (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Increase firmware response timeout for coredump commands (Jonathan Toppins) [1801868]
- [netdrv] bnxt_en: Fix suspend/resume path on 57500 chips (Jonathan Toppins) [1801111]
- [netdrv] bnxt_en: Disable/enable Bus master during suspend/resume (Jonathan Toppins) [1801111]
- [fs] cifs: fix soft mounts hanging in the reconnect code (Leif Sahlberg) [1795423]
- [kernel] audit: CONFIG_CHANGE don't log internal bookkeeping as an event (Richard Guy Briggs) [1798512]
- [security] selinux: reorder hooks to make runtime disable less broken (Ondrej Mosnacek) [1778990]
- [scsi] scsi: qla2xxx: Fix unbound NVME response length (Himanshu Madhani) [1796480]
- [isdn] misdn: enforce CAP_NET_RAW for raw sockets (Andrea Claudi) [1779475] {CVE-2019-17055}

* Fri Feb 14 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-179.el8]
- [fs] Revert: f5bcc37b81fc ("namei: allow restricted O_CREAT of FIFOs and regular files") (Eric Sandeen) [1801468]
- [fs] Revert: 433cbb6cf0ae ("quota: honor quota type in Q_XGETQSTATcalls") (Eric Sandeen) [1800435]
- [infiniband] RDMA/siw: Fix setting active_mtu attribute (Kamal Heib) [1797199]
- [infiniband] RDMA/hfi1: Fix memory leak in _dev_comp_vect_mappings_create (Kamal Heib) [1733690]
- [scsi] scsi: lpfc: Fix release of hwq to clear the eq relationship (Dick Kennedy) [1798661]
- [x86] kvm/hyper-v: don't allow to turn on unsupported VMX controls for nested guests (Vitaly Kuznetsov) [1786288]
- [x86] kvm/hyper-v: move VMX controls sanitization out of nested_enable_evmcs() (Vitaly Kuznetsov) [1786288]
- [x86] kvm/hyper-v: remove stale evmcs_already_enabled check from nested_enable_evmcs() (Vitaly Kuznetsov) [1786288]
- [x86] kvm: svm: relax conditions for allowing MSR_IA32_SPEC_CTRL accesses (Paolo Bonzini) [1796417]
- [x86] kvm: x86: avoid incorrect writes to host MSR_IA32_SPEC_CTRL (Paolo Bonzini) [1796417]
- [tools] selftests: netfilter: Introduce tests for sets with range concatenation (Stefano Brivio) [1593711]
- [net] nf_tables: Add set type for arbitrary concatenation of ranges (Stefano Brivio) [1593711]
- [lib] bitmap: Introduce bitmap_cut(): cut bits and shift remaining (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: Support for sets with multiple ranged fields (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: add NFTA_SET_ELEM_KEY_END attribute (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: add nft_setelem_parse_key() (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: validate NFT_DATA_VALUE after nft_data_init() (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: validate NFT_SET_ELEM_INTERVAL_END (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: remove unused parameter ctx (Stefano Brivio) [1593711]
- [net] netfilter: nf_tables: remove unused variable (Stefano Brivio) [1593711]
- [ptp] ptp: free ptp device pin descriptors properly (Vladis Dronov) [1787568]
- [ptp] ptp: fix the race between the release of ptp_clock and cdev (Vladis Dronov) [1787568]
- [ptp] ptp: Fix pass zero to ERR_PTR() in ptp_clock_register (Vladis Dronov) [1787568]

* Wed Feb 12 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-178.el8]
- [fs] NFSv4: pnfs_roc() must use cred_fscmp() to compare creds (Benjamin Coddington) [1800893]
- [drm] drm/nouveau/kms/gv100-: avoid sending a core update until the first modeset (Ben Skeggs) [1801091]
- [drm] drm/nouveau/kms/gv100-: move window ownership setup into modesetting path (Ben Skeggs) [1801091]
- [drm] drm/nouveau/disp/gv100-: halt NV_PDISP_FE_RM_INTR_STAT_CTRL_DISP_ERROR storms (Ben Skeggs) [1801091]
- [drm] drm/nouveau: Add HD-audio component notifier support (Ben Skeggs) [1792191]
- [netdrv] net/mlx5: Fix deadlock in fs_core (Alaa Hleihel) [1786630]
- [drm] drm/amd/dm/mst: Ignore payload update failures (Lyude Paul) [1773800 1773795]
- [kernel] sched/rt: Optimize checking group RT scheduler constraints (Phil Auld) [1797106]
- [fs] cifs: Fix mount options set in automount (Dave Wysochanski) [1790922]

* Mon Feb 10 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-177.el8]
- [kernel] timers/nohz: Update NOHZ load in remote tick (Scott Wood) [1791434]
- [kernel] sched/core: Don't skip remote tick for idle CPUs (Scott Wood) [1791434]
- [drm] drm/amdgpu/vi: silence an uninitialized variable warning (Lyude Paul) [1792565]
- [drm] drm: panel-lvds: Potential Oops in probe error handling (Lyude Paul) [1792565]
- [drm] drm/i915: Fix pid leak with banned clients (Lyude Paul) [1792565]
- [drm] drm/amdgpu: allow direct upload save restore list for raven2 (Lyude Paul) [1792565]
- [drm] drm/amd/display: Reorder detect_edp_sink_caps before link settings read (Lyude Paul) [1792565]
- [drm] drm/i915: Add missing include file <linux/math64.h> (Lyude Paul) [1792565]
- [drm] drm/amdgpu: enable gfxoff for raven1 refresh (Lyude Paul) [1792565]
- [drm] drm/amdgpu/discovery: reserve discovery data at the top of VRAM (Lyude Paul) [1792565]
- [drm] drm/amdgpu: cleanup creating BOs at fixed location (v2) (Lyude Paul) [1792565]
- [drm] drm/tegra: Fix ordering of cleanup code (Lyude Paul) [1792565]
- [drm] drm/i915/gen9: Clear residual context state on context switch (Lyude Paul) [1792565]
- [drm] drm/i915: Add Wa_1407352427:icl,ehl (Lyude Paul) [1792565]
- [drm] drm/dp_mst: correct the shifting in DP_REMOTE_I2C_READ (Lyude Paul) [1792565]
- [drm] drm/fb-helper: Round up bits_per_pixel if possible (Lyude Paul) [1792565]
- [drm] drm/i915: Add Wa_1408615072 and Wa_1407596294 to icl, ehl (Lyude Paul) [1792565]
- [drm] drm/amdgpu/smu: add metrics table lock for vega20 (v2) (Lyude Paul) [1792565]
- [drm] drm/amdgpu/smu: add metrics table lock for navi (v2) (Lyude Paul) [1792565]
- [drm] drm/amdgpu/smu: add metrics table lock (Lyude Paul) [1792565]
- [drm] drm/nouveau/kms/nv50-: fix panel scaling (Lyude Paul) [1792565 1741114]
- [drm] drm/nouveau: Fix drm-core using atomic code-paths on pre-nv50 hardware (Lyude Paul) [1792565]
- [drm] drm/nouveau: Move the declaration of struct nouveau_conn_atom up a bit (Lyude Paul) [1792565]
- [drm] drm/amd/display: Reset steer fifo before unblanking the stream (Lyude Paul) [1792565]
- [drm] drm/amd/display: Change the delay time before enabling FEC (Lyude Paul) [1792565]
- [drm] drm/amd/display: Fixed kernel panic when booting with DP-to-HDMI dongle (Lyude Paul) [1792565]
- [drm] drm/amdgpu: add cache flush workaround to gfx8 emit_fence (Lyude Paul) [1792565]
- [drm] drm/amdgpu: add check before enabling/disabling broadcast mode (Lyude Paul) [1792565]
- [drm] drm: limit to INT_MAX in create_blob ioctl (Lyude Paul) [1792565]
- [drm] drm/amdgpu: Call find_vma under mmap_sem (Lyude Paul) [1792565]
- [drm] drm/amdgpu: fix uninitialized variable pasid_mapping_needed (Lyude Paul) [1792565]
- [drm] drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2 (Lyude Paul) [1792565]
- [drm] drm/amdgpu: Avoid accidental thread reactivation (Lyude Paul) [1792565]
- [drm] drm/amdgpu: fix potential double drop fence reference (Lyude Paul) [1792565]
- [drm] drm/amdgpu: disallow direct upload save restore list from gfx driver (Lyude Paul) [1792565]
- [gpu] gpu: host1x: Allocate gather copy for host1x (Lyude Paul) [1792565]
- [drm] drm/tegra: sor: Use correct SOR index on Tegra210 (Lyude Paul) [1792565]
- [drm] drm/amd/display: correctly populate dpp refclk in fpga (Lyude Paul) [1792565]
- [drm] drm: Don't free jobs in wait_event_interruptible() (Lyude Paul) [1792565]
- [drm] drm/gma500: fix memory disclosures due to uninitialized bytes (Lyude Paul) [1792565]
- [drm] drm/amdgpu: fix amdgpu trace event print string format error (Lyude Paul) [1792565]
- [drm] drm/amd/powerplay: avoid disabling ECC if RAS is enabled for VEGA20 (Lyude Paul) [1792565]
- [drm] drm/bridge: dw-hdmi: Restore audio when setting a mode (Lyude Paul) [1792565]
- [drm] drm/amd/display: Program DWB watermarks from correct state (Lyude Paul) [1792565]
- [drm] drm/amd/display: Fix dongle_caps containing stale information (Lyude Paul) [1792565]
- [drm] drm/amd/display: add new active dongle to existent w/a (Lyude Paul) [1792565]
- [drm] drm/amd/display: refactor Device ID for external chips (Lyude Paul) [1792565]
- [drm] drm/amd/display: wait for set pipe mcp command completion (Lyude Paul) [1792565]
- [drm] drm/amd/display: Properly round nominal frequency for SPD (Lyude Paul) [1792565]
- [drm] drm/drm_vblank: Change EINVAL by the correct errno (Lyude Paul) [1792565]
- [drm] drm/amdkfd: Fix MQD size calculation (Lyude Paul) [1792565]
- [drm] drm/bridge: dw-hdmi: Refuse DDC/CI transfers on the internal I2C controller (Lyude Paul) [1792565]
- [drm] drm/amd/display: set minimum abm backlight level (Lyude Paul) [1792565]
- [drm] drm/amd/display: load iram for abm 2.3 (Lyude Paul) [1792565]
- [drm] drm/amd/powerplay: A workaround to GPU RESET on APU (Lyude Paul) [1792565]
- [drm] drm/amdkfd: fix a potential NULL pointer dereference (v2) (Lyude Paul) [1792565]
- [drm] drm/amd/display: Set number of pipes to 1 if the second pipe was disabled (Lyude Paul) [1792565]
- [drm] drm/amd/display: Handle virtual signal type in disable_link() (Lyude Paul) [1792565]
- [drm] drm/ttm: return -EBUSY on pipelining with no_gpu_wait (v2) (Lyude Paul) [1792565]
- [drm] drm/amdgpu: grab the id mgr lock while accessing passid_mapping (Lyude Paul) [1792565]
- [drm] drm/amdgpu/sriov: add ring_stop before ring_create in psp v11 code (Lyude Paul) [1792565]
- [drm] drm/bridge: analogix-anx78xx: silence -EPROBE_DEFER warnings (Lyude Paul) [1792565]
- [drm] drm/amd/display: verify stream link before link test (Lyude Paul) [1792565]
- [drm] drm: Use EOPNOTSUPP, not ENOTSUPP (Lyude Paul) [1792565]
- [drm] drm/mipi-dbi: fix a loop in debugfs code (Lyude Paul) [1792565]
- [drm] drm: mst: Fix query_payload ack reply struct (Lyude Paul) [1792565]
- [drm] Revert "drm/virtio: switch virtio_gpu_wait_ioctl() to gem helper." (Lyude Paul) [1792565]
- [drm] drm/amdgpu: add invalidate semaphore limit for SRIOV and picasso in gmc9 (Lyude Paul) [1792565]
- [drm] drm/amdgpu: avoid using invalidate semaphore for picasso (Lyude Paul) [1792565]
- [drm] drm/amdgpu/gfx10: re-init clear state buffer after gpu reset (Lyude Paul) [1792565]
- [drm] drm/amdgpu/gfx10: explicitly wait for cp idle after halt/unhalt (Lyude Paul) [1792565]
- [drm] drm/amdgpu: invalidate mmhub semaphore workaround in gmc9/gmc10 (Lyude Paul) [1792565]
- [drm] drm/amdgpu: set adev->num_vmhubs for gmc6, 7, 8 (Lyude Paul) [1792565]
- [drm] drm/amdgpu: Export function to flush TLB of specific vm hub (Lyude Paul) [1792565]
- [drm] drm/amdgpu: add new member in amdgpu_device for vmhub counts per asic chip (Lyude Paul) [1792565]
- [drm] drm/amdgpu: rename AMDGPU_GFXHUB/MMHUB macro with hub number (Lyude Paul) [1792565]
- [drm] drm/amdgpu: initialize vm_inv_eng0_sem for gfxhub and mmhub (Lyude Paul) [1792565]
- [drm] drm/amd/display: add default clocks if not able to fetch them (Lyude Paul) [1792565]
- [drm] drm/amd/display: re-enable wait in pipelock, but add timeout (Lyude Paul) [1792565]
- [drm] drm/dp_mst: Correct the bug in drm_dp_update_payload_part1() (Lyude Paul) [1792565]
- [drm] drm/radeon: fix r1xx/r2xx register checker for POT textures (Lyude Paul) [1792565]
- [drm] drm/i915/fbc: Disable fbc by default on all glk+ (Lyude Paul) [1792565]
- [drm] drm/nouveau/kms/nv50-: Limit MST BPC to 8 (Lyude Paul) [1792565 1773804]
- [drm] drm/nouveau/kms/nv50-: Store the bpc we're using in nv50_head_atom (Lyude Paul) [1792565 1773804]
- [drm] drm/nouveau/kms/nv50-: Call outp_atomic_check_view() before handling PBN (Lyude Paul) [1792565 1773804]
- [drm] drm/mgag200: Flag all G200 SE A machines as broken wrt <startadd> (Lyude Paul) [1792565]
- [drm] drm/mgag200: Add workaround for HW that does not support 'startadd' (Lyude Paul) [1792565]
- [drm] drm/mgag200: Store flags from PCI driver data in device structure (Lyude Paul) [1792565]
- [drm] drm/mgag200: Extract device type from flags (Lyude Paul) [1792565]
- [dma-buf] dma-buf: Fix memory leak in sync_file_merge() (Lyude Paul) [1792565]
- [video] video/hdmi: Fix AVI bar unpack (Lyude Paul) [1792565]
- [drm] drm: damage_helper: Fix race checking plane->state->fb (Lyude Paul) [1792565]
- [drm] drm/i915: Fix detection for a CMP-V PCH (Lyude Paul) [1792565]
- [x86] Mark AMD Ryzen 7 as supported (David Arcari) [1797317]
- [x86] Mark AMD Ryzen 5 as supported (David Arcari) [1718051]
- [mm] mm/sparse.c: reset section's mem_map when fully deactivated (Pingfan Liu) [1797848]
- [drm] drm/mgag200: Don't unpin the current cursor image's buffer (Lyude Paul) [1784290]
- [drm] drm/mgag200: Set cursor scanout address to correct BO (Lyude Paul) [1784290]
- [drm] drm/mgag200: Pin displayed cursor BO to video memory (Lyude Paul) [1784290]
- [tools] Correction to manpage of cpupower (Prarit Bhargava) [1796139]
- [fs] cifs: fix soft mounts hanging in the reconnect code (Dave Wysochanski) [1795429]
- [net] ipv6_stub: use ip6_dst_lookup_flow instead of ip6_dst_lookup (Sabrina Dubroca) [1774440]
- [net] ipv6: add net argument to ip6_dst_lookup_flow (Sabrina Dubroca) [1774440]
- [netdrv] can: peak_usb: fix slab info leak (Guillaume Nault) [1787486] {CVE-2019-19534}
- [netdrv] vxlan: fix tos value before xmit (Hangbin Liu) [1786075]
- [net] netfilter: nft_tproxy: Fix port selector on Big Endian (Phil Sutter) [1781481]
- [net] devlink: Change devlink health locking mechanism (Petr Oros) [1785997]
- [net] xfrm: Fix memleak on xfrm state destroy (Xin Long) [1780470]
- [net] erspan: remove the incorrect mtu limit for erspan (Hangbin Liu) [1783871]
- [net] ieee802154: enforce CAP_NET_RAW for raw sockets (Andrea Claudi) [1779495] {CVE-2019-17053}
- [net] netfilter: masquerade: don't flush all conntracks if only one address deleted on device (Patrick Talbert) [1772334]

* Tue Feb 04 2020 Herton R. Krzesinski <herton@redhat.com> [4.18.0-176.el8]
- [mm] memcg: Add preemption point in accumulate_memcg_tree() (Waiman Long) [1795049]
- [edac] EDAC: skx_common: downgrade message importance on missing PCI device (Aristeu Rozanski) [1775511]
- [infiniband] IB/core: Do not notify GID change event of an unregistered device (Kamal Heib) [1787333]
- [infiniband] IB/core: Let IB core distribute cache update events (Kamal Heib) [1787333]
- [arm64] arm64: kexec: always reset to EL2 if present (Bhupesh Sharma) [1794805]
- [tools] perf header: Use last modification time for timestamp (Michael Petlan) [1791258]
- [netdrv] net/mlx5e: Enable all available stats for uplink reps (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Create q counters on uplink representors (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Convert rep stats to mlx5e_stats_grp-based infra (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: IPoIB, use separate stats groups (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Convert stats groups array to array of group pointers (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Declare stats groups via macro (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Profile specific stats groups (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Move uplink rep init/cleanup code into own functions (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Add discard counters per priority (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5e: Add port buffer's congestion counters (Alaa Hleihel) [1786321]
- [netdrv] net/mlx5: Expose HW capability bits for port buffer per priority congestion counters (Alaa Hleihel) [1786321]
- [netdrv] qede: Fix multicast mac configuration (Manish Chopra) [1784894]
- [thunderbolt] thunderbolt: Drop unnecessary read when writing LC command in Ice Lake (Jarod Wilson) [1784568]
- [thunderbolt] thunderbolt: Fix lockdep circular locking depedency warning (Jarod Wilson) [1784568]
- [thunderbolt] thunderbolt: Read DP IN adapter first two dwords in one go (Jarod Wilson) [1784568]

* Fri Jan 31 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-175.el8]
- [pci] PCI/PM: Move pci_dev_wait() definition earlier (Myron Stowe) [1794266]
- [pci] PCI/PM: Add missing link delays required by the PCIe spec (Myron Stowe) [1794266]
- [pci] PCI/PM: Add pcie_wait_for_link_delay() (Myron Stowe) [1794266]
- [pci] PCI/PM: Return error when changing power state from D3cold (Myron Stowe) [1794266]
- [pci] PCI/PM: Decode D3cold power state correctly (Myron Stowe) [1794266]
- [pci] PCI/PM: Fold __pci_complete_power_transition() into its caller (Myron Stowe) [1794266]
- [pci] PCI/PM: Avoid exporting __pci_complete_power_transition() (Myron Stowe) [1794266]
- [pci] PCI/PM: Fold __pci_start_power_transition() into its caller (Myron Stowe) [1794266]
- [pci] PCI/PM: Use pci_power_up() in pci_set_power_state() (Myron Stowe) [1794266]
- [pci] PCI/PM: Move power state update away from pci_power_up() (Myron Stowe) [1794266]
- [pci] PCI/PM: Remove unused pci_driver.suspend_late() hook (Myron Stowe) [1794266]
- [pci] PCI/PM: Remove unused pci_driver.resume_early() hook (Myron Stowe) [1794266]
- [xen] xen-platform: Convert to generic power management (Myron Stowe) [1794266]
- [pci] PCI/PM: Simplify pci_set_power_state() (Myron Stowe) [1794266]
- [pci] PCI/PM: Expand PM reset messages to mention D3hot (not just D3) (Myron Stowe) [1794266]
- [pci] PCI/PM: Apply D2 delay as milliseconds, not microseconds (Myron Stowe) [1794266]
- [pci] PCI/PM: Use pci_WARN() to include device information (Myron Stowe) [1794266]
- [pci] PCI/PM: Use PCI dev_printk() wrappers for consistency (Myron Stowe) [1794266]
- [pci] PCI/PM: Make power management op coding style consistent (Myron Stowe) [1794266]
- [pci] PCI/PM: Run resume fixups before disabling wakeup events (Myron Stowe) [1794266]
- [pci] PCI/PM: Clear PCIe PME Status even for legacy power management (Myron Stowe) [1794266]
- [pci] PCI/PM: Always return devices to D0 when thawing (Myron Stowe) [1794266]
- [pci] PCI: PM: Fix pci_power_up() (Myron Stowe) [1794266]
- [pci] PCI: Make pcie_downstream_port() available outside of access.c (Myron Stowe) [1794266]
- [pci] PCI: Add pci_info_ratelimited() to ratelimit PCI separately (Myron Stowe) [1794266]
- [pci] PCI: PM: Simplify bus-level hibernation callbacks (Myron Stowe) [1794266]
- [pci] PCI: Do not poll for PME if the device is in D3cold (Myron Stowe) [1794266]
- [pci] PCI: PM: Replace pci_dev_keep_suspended() with two functions (Myron Stowe) [1794266]
- [pci] PCI: PM: Avoid resuming devices in D3hot during system suspend (Myron Stowe) [1794266]
- [pci] PCI: PM: Avoid skipping bus-level PM on platforms without ACPI (Myron Stowe) [1794266]
- [pci] treewide: Switch printk users from pf and pF to ps and pS, respectively (Myron Stowe) [1794266]
- [sound] ALSA: Use the legacy HDA driver as default for Intel DSP platforms (Jaroslav Kysela) [1793227]
- [nvme] nvme: nvme_mpath_init remove multipath check (David Milburn) [1790958]
- [mm] mm/page-writeback.c: don't break integrity writeback on ->writepage() error (Christoph von Recklinghausen) [1782117]
- [arm64] arm64: Revert support for execute-only user mappings (Jeremy Linton) [1788629]
- [powerpc] powerpc/papr_scm: Don't enable direct map for a region by default (Steve Best) [1795706]

* Thu Jan 30 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-174.el8]
- [tools] selftests/eeh: Bump EEH wait time to 60s (Steve Best) [1783199]
- [tools] tools/kvm_stat: Fix kvm_exit filter name (Gavin Shan) [1780345]
- [infiniband] RDMA/bnxt_re: Report more number of completion vectors (Selvin Xavier) [1788037 1753515]
- [infiniband] RDMA/bnxt_re: Fix Send Work Entry state check while polling completions (Selvin Xavier) [1788037]
- [infiniband] RDMA/bnxt_re: Fix missing le16_to_cpu (Selvin Xavier) [1788037]
- [infiniband] RDMA/bnxt_re: Avoid freeing MR resources if dereg fails (Selvin Xavier) [1788037 1737147]
- [infiniband] RDMA/bnxt_re: Fix stat push into dma buffer on gen p5 devices (Selvin Xavier) [1788037 1771855]
- [infiniband] RDMA/bnxt_re: Fix chip number validation Broadcom's Gen P5 series (Selvin Xavier) [1788037 1783943]
- [netdrv] net/mlx5e: Clear VF config when switching modes (mohamad meib) [1787276]
- [base] drivers/base/memory.c: cache memory blocks in xarray to accelerate lookup fixup (David Hildenbrand) [1789900]
- [base] drivers/base/memory.c: cache memory blocks in xarray to accelerate lookup (David Hildenbrand) [1789900]
- [base] drivers/base/memory.c: drop the mem_sysfs_mutex (David Hildenbrand) [1789900]
- [base] driver/base/memory.c: validate memory block size early (David Hildenbrand) [1789900]
- [fs] block: Don't revalidate bdev of hidden gendisk (David Milburn) [1779342]
- [scsi] scsi: virtio_scsi: unplug LUNs when events missed (Maxim Levitsky) [1614188]
- [scsi] scsi: virtio_scsi: implement request batching (Maxim Levitsky) [1614188]
- [scsi] scsi: core: fix dh and multipathing for SCSI hosts without request batching (Maxim Levitsky) [1614188]
- [scsi] scsi: core: fix missing .cleanup_rq for SCSI hosts without request batching (Maxim Levitsky) [1614188]
- [scsi] scsi: core: add support for request batching (Maxim Levitsky) [1614188]
- [scsi] scsi: virtio_scsi: Use struct_size() helper (Maxim Levitsky) [1614188]
- [scsi] scsi: virtio_scsi: remove unused 'affinity_hint_set' (Maxim Levitsky) [1614188]
- [scsi] scsi: virtio_scsi: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Maxim Levitsky) [1614188]
- [scsi] scsi: virtio_scsi: don't send sc payload with tmfs (Maxim Levitsky) [1614188]
- [scsi] scsi: virtio_scsi: Remove per-target data because it is no longer used (Maxim Levitsky) [1614188]
- [powerpc] powerpc/pseries/lparcfg: Fix display of Maximum Memory (Steve Best) [1795622]
- [powerpc] powernv: Don't reprogram SLW image on every KVM guest entry/exit (Laurent Vivier) [1751078]
- [x86] Mark certain versions of Comet Lake as supported (David Arcari) [1794198]
- [s390] s390/dasd: Disable Thin Provisioning to prevent data loss (Philipp Rudo) [1793461]

* Fri Jan 24 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-173.el8]
- [x86] kvm: x86/mmu: Take slots_lock when using kvm_mmu_zap_all_fast() (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [x86] kvm: x86: disable shattered huge page recovery for PREEMPT_RT (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [documentation] documentation: Add ITLB_MULTIHIT documentation (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [x86] kvm: x86: mmu: Recovery of shattered NX large pages (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [virt] kvm: Add helper function for creating VM worker threads (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [x86] kvm: mmu: ITLB_MULTIHIT mitigation (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [kernel] cpu/speculation: Uninline and export CPU mitigations helpers (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [x86] cpu: Add Tremont to the cpu vulnerability whitelist (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [x86] bugs: Add ITLB_MULTIHIT bug infrastructure (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [x86] kvm: vmx, svm: always run with EFER.NXE=1 when shadow paging is active (Paolo Bonzini) [1690344] {CVE-2018-12207}
- [crypto] crypto: hmac - fix memory leak in hmac_init_tfm() (Herbert Xu) [1775858]
- [crypto] crypto: hash - fix incorrect HASH_MAX_DESCSIZE (Herbert Xu) [1775858]
- [nvme] nvme: Translate more status codes to blk_status_t (Gopal Tiwari) [1781537]
- [include] nvme: resync include/linux/nvme.h with nvmecli (Gopal Tiwari) [1781537]
- [netdrv] hv_netvsc: Fix memory leak when removing rndis device (Mohammed Gamal) [1733007]
- [fs] cifs: Fix memory allocation in __smb2_handle_cancelled_cmd() (Dave Wysochanski) [1793182]
- [tools] perf c2c: Fix report with offline cpus (Michael Petlan) [1744903]
- [kernel] locking/rwsem: Fix kernel crash when spinning on RWSEM_OWNER_UNKNOWN (Waiman Long) [1793028]
- [mm] mm/memory_hotplug: don't free usage map when removing a re-added early section (Pingfan Liu) [1787269]
- [netdrv] iavf: remove current MAC address filter on VF reset (Stefan Assmann) [1735725 1738738]
- [dma] dma-mapping: fix handling of dma-ranges for reserved memory (again) (Jerry Snitselaar) [1784691]

* Tue Jan 21 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-172.el8]
- [fs] pnfs/filelayout: enable LAYOUTGET on OPEN (Steve Dickson) [1756140]
- [fs] NFSD fixing possible null pointer derefering in copy offload (Benjamin Coddington) [1763220]
- [fs] nfsd: Ensure CLONE persists data and metadata changes to the target file (Benjamin Coddington) [1763220]
- [net] SUNRPC: Fix backchannel latency metrics (Benjamin Coddington) [1763220]
- [fs] NFSv4.x: Drop the slot if nfs4_delegreturn_prepare waits for layoutreturn (Benjamin Coddington) [1763220]
- [fs] NFSv4.x: Handle bad/dead sessions correctly in nfs41_sequence_process() (Benjamin Coddington) [1763220]
- [fs] NFS: Fix an RCU lock leak in nfs4_refresh_delegation_stateid() (Benjamin Coddington) [1763220]
- [fs] NFSv4: Don't allow a cached open with a revoked delegation (Benjamin Coddington) [1763220]
- [net] SUNRPC: Fix svcauth_gss_proxy_init() (Benjamin Coddington) [1763220]
- [net] SUNRPC: The TCP back channel mustn't disappear while requests are outstanding (Benjamin Coddington) [1763220]
- [net] xprtrdma: Close window between waking RPC senders and posting Receives (Benjamin Coddington) [1763220]
- [net] xprtrdma: Connection becomes unstable after a reconnect (Benjamin Coddington) [1763220]
- [net] xprtrdma: Add unique trace points for posting Local Invalidate WRs (Benjamin Coddington) [1763220]
- [net] sunrpc: fix crash when cache_head become valid before update (Benjamin Coddington) [1763220]
- [fs] nfsd4: fix up replay_matches_cache() (Benjamin Coddington) [1763220]
- [fs] NFSv4: Fix leak of clp->cl_acceptor string (Benjamin Coddington) [1763220]
- [fs] pNFS: Ensure we do clear the return-on-close layout stateid on fatal errors (Benjamin Coddington) [1763220]
- [fs] NFS: Fix O_DIRECT accounting of number of bytes read/written (Benjamin Coddington) [1763220]
- [net] SUNRPC: Fix another issue with MIC buffer space (Benjamin Coddington) [1763220]
- [net] SUNRPC: Fix buffer handling of GSS MIC without slack (Benjamin Coddington) [1763220]
- [fs] Revert "NFSv4/flexfiles: Abort I/O early if the layout segment was invalidated" (Benjamin Coddington) [1763220]
- [net] SUNRPC: Don't handle errors if the bind/connect succeeded (Benjamin Coddington) [1763220]
- [net] SUNRPC: Fix congestion window race with disconnect (Benjamin Coddington) [1763220]
- [net] SUNRPC: Don't try to parse incomplete RPC messages (Benjamin Coddington) [1763220]
- [net] SUNRPC: Don't receive TCP data into a request buffer that has been reset (Benjamin Coddington) [1763220]
- [net] SUNRPC: Dequeue the request from the receive queue while we're re-encoding (Benjamin Coddington) [1763220]
- [net] SUNRPC: Handle connection breakages correctly in call_status() (Benjamin Coddington) [1763220]
- [net] xprtrdma: Toggle XPRT_CONGESTED in xprtrdma's slot methods (Benjamin Coddington) [1763220]
- [fs] NFS: Ensure O_DIRECT reports an error if the bytes read/written is 0 (Benjamin Coddington) [1763220]
- [fs] NFSv4/pnfs: Fix a page lock leak in nfs_pageio_resend() (Benjamin Coddington) [1763220]
- [fs] NFS: Fix regression whereby fscache errors are appearing on 'nofsc' mounts (Benjamin Coddington) [1763220]
- [fs] NFSv4: Fix a potential sleep while atomic in nfs4_do_reclaim() (Benjamin Coddington) [1763220]
- [fs] NFSv4.1: Only reap expired delegations (Benjamin Coddington) [1763220]
- [fs] NFSv4.1: Fix open stateid recovery (Benjamin Coddington) [1763220]
- [fs] NFSv4: Fix a credential refcount leak in nfs41_check_delegation_stateid (Benjamin Coddington) [1763220]
- [fs] NFSv4: Handle the special Linux file open access mode (Benjamin Coddington) [1763220]
- [fs] nfsd: Fix overflow causing non-working mounts on 1 TB machines (Benjamin Coddington) [1763220]
- [md] md: make sure desc_nr less than MD_SB_DISKS (Nigel Croxon) [1769057]
- [md] md: raid1: check rdev before reference in raid1_sync_request func (Nigel Croxon) [1769057]
- [md] md/raid10: prevent access of uninitialized resync_pages offset (Nigel Croxon) [1769057]
- [md] md: avoid invalid memory access for array sb->dev_roles (Nigel Croxon) [1769057]
- [md] md/raid1: avoid soft lockup under high load (Nigel Croxon) [1769057]
- [md] md: no longer compare spare disk superblock events in super_load (Nigel Croxon) [1769057]
- [md] md: improve handling of bio with REQ_PREFLUSH in md_flush_request() (Nigel Croxon) [1769057]
- [md] md/bitmap: avoid race window between md_bitmap_resize and bitmap_file_clear_bit (Nigel Croxon) [1769057]
- [md] md/raid0: Fix an error message in raid0_make_request() (Nigel Croxon) [1769057]
- [md] md/raid0: fix warning message for parameter default_layout (Nigel Croxon) [1769057]
- [netdrv] net/mlx5: DR, Init lists that are used in rule's member (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, No need for atomic refcount for internal SW steering resources (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Create multiple destination action from dr_create_fte (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Add support for multiple destination table action (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Align dest FT action creation to API (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Pass table flags at creation to lower layer (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Create multi-destination table for SW-steering use (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Create FTE entry in the FW from SW-steering (Alaa Hleihel) [1775986]
- [netdrv] net/mlx5: DR, Use attributes struct for FW flow table creation (Alaa Hleihel) [1775986]
- [drm] drm/amd/display: fix struct init in update_bounding_box (Don Dutile) [1784621]
- [tools] perf/x86/pmu-events: Fix Kernel_Utilization metric (Michael Petlan) [1788434]
- [tools] perf vendor events intel: Update all the Intel JSON metrics from TMAM 3.6 (Michael Petlan) [1788434]
- [tools] perf vendor events intel: Update CascadelakeX events to v1.05 (Michael Petlan) [1788434]
- [tools] cpupower: mperf_monitor: Update cpupower to use the RDPRU instruction (Janakarajan Natarajan) [1766357]
- [tools] cpupower: mperf_monitor: Introduce per_cpu_schedule flag (Janakarajan Natarajan) [1766357]
- [tools] cpupower: Move needs_root variable into a sub-struct (Janakarajan Natarajan) [1766357]
- [mm] coredump: fix race condition between collapse_huge_page() and core dumping (Andrea Arcangeli) [1722986]
- [mm] memcg, oom: don't require __GFP_FS when invoking memcg OOM killer (Waiman Long) [1791170]
- [uapi] mm: move MAP_SYNC to asm-generic/mman-common.h (Jeff Moyer) [1791539]

* Fri Jan 17 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-171.el8]
- [linux] ptr_ring: wrap back ->producer in __ptr_ring_swap_queue() (Lu Lu) [1663784]
- [virtio] virtio-balloon: fix managed page counts when migrating pages between zones (David Hildenbrand) [1689800]
- [infiniband] IB/mlx4: Follow mirror sequence of device add during device removal (mohamad meib) [1786042]
- [netdrv] gve: Fix the queue page list allocated pages count (Patricio Noyola) [1789114]
- [netdrv] gve: fix dma sync bug where not all pages synced (David Awogbemila) [1790957]
- [netdrv] gve: Fixes DMA synchronization (David Awogbemila) [1789027]
- [net] SUNRPC: Ignore queue transmission errors on successful transmission (Benjamin Coddington) [1769367]
- [net] Revert "SUNRPC: Micro-optimise when the task is known not to be sleeping" (Benjamin Coddington) [1769367]
- [net] SUNRPC: Fix up calculation of client message length (Benjamin Coddington) [1769367]
- [net] Merge tag 'nfs-rdma-for-5.1-1' of git://git.linux-nfs.org/projects/anna/linux-nfs (Benjamin Coddington) [1769367]
- [char] tpm: Revert "tpm_tis_core: Turn on the TPM before probing IRQ's" (Jerry Snitselaar) [1789088]
- [char] tpm: Revert "tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for interrupts" (Jerry Snitselaar) [1789088]
- [tools] perf jvmti: Link against tools/lib/ctype.h to have weak strlcpy() (Michael Petlan) [1786048]
- [tools] perf jvmti: Link against tools/lib/string.o to have weak strlcpy() (Michael Petlan) [1786048]
- [kernel] kprobes: Show address of kprobes if kallsyms does (Michael Petlan) [1747099]
- [kernel] genirq/debugfs: Reset domain debugfs_file on removal of the debugfs file (Mohammed Gamal) [1782640]
- [powerpc] powerpc: Fix 32-bit KVM-PR lockup and host crash with MacOS guest (Steve Best) [1789594]

* Tue Jan 14 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-170.el8]
- [platform] x86: intel_pmc_core: Add Comet Lake (CML) platform support to intel_pmc_core driver (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Fix the SoC naming inconsistency (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core_pltdrv: Module removal warning fix (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Do not ioremap RAM (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_ipc: Remove dev_err() usage after platform_get_irq() (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Add ICL-NNPI support to PMC Core (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Attach using APCI HID "INT33A1" (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: transform Pkg C-state residency from TSC ticks into microseconds (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc: no need to check return value of debugfs_create functions (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Allow to dump debug registers on S0ix failure (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Convert to a platform_driver (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_ipc: Don't map non-used optional resources (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_ipc: Apply same width for offset definitions (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_ipc: Use BIT() macro (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_core: Mark local function static (Lenny Szubowicz) [1773793]
- [platform] x86: intel_pmc_ipc: adding error handling (Lenny Szubowicz) [1773793]
- [mm] memory_hotplug: cleanup __remove_pages() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: drop local variables in shrink_zone_span() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: don't check for "all holes" in shrink_zone_span() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: we always have a zone in find_(smallest|biggest)_section_pfn (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: poison memmap in remove_pfn_range_from_zone() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: shrink zones when offlining memory (Christoph von Recklinghausen) [1766491]
- [mm] memmap_init: update variable name in memmap_init_zone (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: don't access uninitialized memmaps in shrink_zone_span() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: fix try_offline_node() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: fix updating the node span (Christoph von Recklinghausen) [1766491]
- [mm] hugetlbfs: don't access uninitialized memmaps in pfn_range_valid_gigantic() (Christoph von Recklinghausen) [1766491]
- [mm] memory_hotplug: don't access uninitialized memmaps in shrink_pgdat_span() (Christoph von Recklinghausen) [1766491]
- [mm] page_owner: don't access uninitialized memmaps when reading /proc/pagetypeinfo (Christoph von Recklinghausen) [1766491]
- [mm] memory-failure.c: don't access uninitialized memmaps in memory_failure() (Christoph von Recklinghausen) [1766491]
- [fs] proc/page.c: don't access uninitialized memmaps in fs/proc/page.c (Christoph von Recklinghausen) [1766491]
- [base] base/memory.c: don't access uninitialized memmaps in soft_offline_page_store() (Christoph von Recklinghausen) [1766491]
- [base] base/node.c: simplify unregister_memory_block_under_nodes() (Christoph von Recklinghausen) [1766491]
- [kernel] /proc/kpagecount: return 0 for special pages that are never mapped (Christoph von Recklinghausen) [1766491]
- [netdrv] fm10k: fix fm10k_get_fault_pf to read correct address (Neil Horman) [1721716]
- [netdrv] fm10k: convert NON_Q_VECTORS(hw) into NON_Q_VECTORS (Neil Horman) [1721716]
- [netdrv] fm10k: mark unused parameters with __always_unused (Neil Horman) [1721716]
- [netdrv] fm10k: cast page_addr to u8 * when incrementing it (Neil Horman) [1721716]
- [netdrv] fm10k: explicitly return 0 on success path in function (Neil Horman) [1721716]
- [netdrv] fm10k: remove needless initialization of size local variable (Neil Horman) [1721716]
- [netdrv] fm10k: remove needless assignment of err local variable (Neil Horman) [1721716]
- [netdrv] fm10k: remove unnecessary variable initializer (Neil Horman) [1721716]
- [netdrv] fm10k: reduce scope of the ring variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of the result local variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of the local msg variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of the local i variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of the err variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of the tx_buffer variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of the q_idx local variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of local err variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce the scope of qv local variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce scope of *p local variable (Neil Horman) [1721716]
- [netdrv] fm10k: reduce scope of the err variable (Neil Horman) [1721716]
- [netdrv] fm10k: Use dev_get_drvdata (Neil Horman) [1721716]
- [crypto] crypto: qat - Silence smp_processor_id() warning (Neil Horman) [1723573]
- [crypto] crypto: qat - use struct_size() helper (Neil Horman) [1723573]
- [crypto] crypto: qat - do not offload zero length requests (Neil Horman) [1723573]
- [crypto] crypto: qat - return error for block ciphers for invalid requests (Neil Horman) [1723573]
- [crypto] crypto: qat - return proper error code in setkey (Neil Horman) [1723573]
- [crypto] crypto: qat - fix block size for aes ctr mode (Neil Horman) [1723573]
- [crypto] crypto: qat - update iv after encryption or decryption operations (Neil Horman) [1723573]
- [crypto] crypto: qat - add check for negative offset in alg precompute function (Neil Horman) [1723573]
- [crypto] crypto: qat - remove spin_lock in qat_ablkcipher_setkey (Neil Horman) [1723573]
- [crypto] treewide: Add SPDX license identifier - Makefile/Kconfig (Neil Horman) [1723573]
- [crypto] crypto: shash - remove shash_desc::flags (Neil Horman) [1723573]
- [crypto] crypto: rsa - unimplement sign/verify for raw RSA backends (Neil Horman) [1723573]
- [hv] Revert "hv: vmbus: Implement suspend/resume for VSC drivers for hibernation" (Mohammed Gamal) [1788082]
- [hv] Revert "hv: vmbus: Ignore the offers when resuming from hibernation" (Mohammed Gamal) [1788082]
- [hv] Revert "hv: vmbus: Suspend/resume the vmbus itself for hibernation" (Mohammed Gamal) [1788082]
- [hv] Revert "hv: vmbus: Clean up hv_sock channels by force upon suspend" (Mohammed Gamal) [1788082]
- [hv] Revert "hv: vmbus: Suspend after cleaning up hv_sock and sub channels" (Mohammed Gamal) [1788082]
- [hv] Revert "hv: vmbus: Resume after fixing up old primary channels" (Mohammed Gamal) [1788082]
- [hv] Revert "vmbus: Fix harmless building warnings without CONFIG_PM_SLEEP" (Mohammed Gamal) [1788082]
- [x86] kvm: vmx: Introduce handle_unexpected_vmexit and handle WAITPKG vmexit (Paul Lai) [1494707]
- [x86] kvm: vmx: Emulate MSR IA32_UMWAIT_CONTROL (Paul Lai) [1494707]
- [x86] kvm: x86: Add support for user wait instructions (Paul Lai) [1494707]
- [tools] tools arch x86: Update tools's copy of cpufeatures.h (Paul Lai) [1494707]
- [kvm] KVM: x86: expose AVX512_BF16 feature to guest (Paul Lai) [1642539]
- [x86] x86/cpufeatures: Enumerate the new AVX512 BFLOAT16 instructions (Paul Lai) [1642539]
- [block] rbd: silence bogus uninitialized warning in rbd_object_map_update_finish() (Jeff Layton) [1777961]
- [fs] ceph: increment/decrement dio counter on async requests (Jeff Layton) [1777961]
- [fs] ceph: take the inode lock before acquiring cap refs (Jeff Layton) [1777961]
- [scsi] scsi: lpfc: fix build failure with DEBUGFS disabled (Dick Kennedy) [1784863]
- [scsi] Revert "storvsc: setup 1:1 mapping between hardware queue and CPU queue" (Cathy Avery) [1787594]
- [tools] perf session: Return error code for perf_session__new() function on failure (Michael Petlan) [1754995]
- [tools] perf header: Fix false warning when there are no duplicate cache entries (Michael Petlan) [1776499]
- [firmware] efi/memreserve: Register reservations as 'reserved' in /proc/iomem (Bhupesh Sharma) [1772730]
- [firmware] efi/memreserve: deal with memreserve entries in unmapped memory (Bhupesh Sharma) [1772730]
- [powerpc] powerpc/powernv: Avoid re-registration of imc debugfs directory (Diego Domingos) [1781098]
- [powerpc] powerpc/powernv: Return for invalid IMC domain (Diego Domingos) [1781098]

* Fri Jan 10 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-169.el8]
- [tools] perf tools: Allow to link with libbpf dynamicaly (Michael Petlan) [1781570]
- [tools] perf probe: Fix spelling mistake "addrees" -> "address" (Michael Petlan) [1760227]
- [tools] perf probe: Trace a magic number if variable is not found (Michael Petlan) [1760227]
- [tools] perf probe: Support DW_AT_const_value constant value (Michael Petlan) [1760227]
- [tools] perf probe: Support multiprobe event (Michael Petlan) [1760227]
- [tools] perf probe: Generate event name with line number (Michael Petlan) [1760227]
- [tools] perf probe: Do not show non representive lines by perf-probe -L (Michael Petlan) [1760227]
- [tools] perf probe: Verify given line is a representive line (Michael Petlan) [1760227]
- [tools] perf probe: Show correct statement line number by perf probe -l (Michael Petlan) [1760227]
- [tools] perf probe: Skip overlapped location on searching variables (Michael Petlan) [1760227]
- [tools] perf probe: Fix to show calling lines of inlined functions (Michael Petlan) [1760227]
- [tools] perf probe: Filter out instances except for inlined subroutine and subprogram (Michael Petlan) [1760227]
- [tools] perf probe: Skip end-of-sequence and non statement lines (Michael Petlan) [1760227]
- [tools] perf probe: Return a better scope DIE if there is no best scope (Michael Petlan) [1760227]
- [tools] perf probe: Fix to show ranges of variables in functions without entry_pc (Michael Petlan) [1760227]
- [tools] perf probe: Fix to show inlined function callsite without entry_pc (Michael Petlan) [1760227]
- [tools] perf probe: Fix to list probe event with correct line number (Michael Petlan) [1760227]
- [tools] perf probe: Fix to probe an inline function which has no entry pc (Michael Petlan) [1760227]
- [tools] perf probe: Fix to probe a function which has no entry pc (Michael Petlan) [1760227]
- [tools] perf probe: Fix wrong address verification (Michael Petlan) [1760227]
- [tools] perf probe: Fix to show function entry line as probe-able (Michael Petlan) [1760227]
- [tools] perf probe: Walk function lines in lexical blocks (Michael Petlan) [1760227]
- [tools] perf probe: Fix to find range-only function instance (Michael Petlan) [1760227]
- [scsi] qla2xxx: Fix incorrect SFUB length used for Secure Flash Update MB Cmd (Himanshu Madhani) [1782598]
- [scsi] qla2xxx: Added support for MPI and PEP regions for ISP28XX (Himanshu Madhani) [1782598]
- [scsi] qla2xxx: Correctly retrieve and interpret active flash region (Himanshu Madhani) [1782598]
- [nvme] nvme: Add quirk for LiteON CL1 devices running FW 22301111 (Perry Yuan) [1769179]
- [nvme] nvme-pci: Save PCI state before putting drive into deepest state (Perry Yuan) [1769180]
- [infiniband] rdma/cxgb4: Fix spelling mistake "immedate" -> "immediate" (Vishal Kulkarni) [1725823]
- [infiniband] rdma/cxgb4: Fix null pointer dereference on alloc_skb failure (Vishal Kulkarni) [1725823]
- [infiniband] iw_cxgb4: Fix qpid leak (Vishal Kulkarni) [1725823]
- [netdrv] net/mlx5e: Use correct enum to determine uplink port (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Fix concurrency issues between config flow and XSK (mohamad meib) [1786113]
- [infiniband] IB/mlx5: Fix steering rule of drop and count (mohamad meib) [1786113]
- [netdrv] net/mlx5e: ethtool, Fix analysis of speed setting (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Fix translation of link mode into speed (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Fix free peer_flow when refcount is 0 (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Fix freeing flow with kfree() and not kvfree() (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Fix SFF 8472 eeprom length (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Query global pause state before setting prio2buffer (mohamad meib) [1786113]
- [netdrv] net/mlx5e: Fix TXQ indices to be sequential (mohamad meib) [1786113]
- [infiniband] RDMA/mlx5: Fix a race with mlx5_ib_update_xlt on an implicit MR (mohamad meib) [1786113]
- [netdrv] ath10k: Fix a NULL-ptr-deref bug in ath10k_usb_alloc_urb_from_pipe (Jarod Wilson) [1783853] {CVE-2019-15099}
- [netdrv] revert "[netdrv] ice: mark driver as tech-preview" (Jonathan Toppins) [1783062]
- [netdrv] ibmvnic: Fix typo in retry check (Steve Best) [1783775]
- [netdrv] ibmveth: Detect unsupported packets before sending to the hypervisor (Steve Best) [1784904]
- [netdrv] igc: add additional delay during phy hw reset (David Arcari) [1782824]
- [net] bridge: fix regression in br_mdb_fill_info() (Petr Oros) [1783888]
- [net] bpf: Emit audit messages upon successful prog load and unload (Jiri Olsa) [1781266]
- [fs] fuse: fix leak of fuse_io_priv (Miklos Szeredi) [1777009]
- [fs] virtiofs: Check contents of options string (Vivek Goyal) [1783426]
- [fs] exec: Fix mem leak in kernel_read_file (Eric Sandeen) [1683731] {CVE-2019-8980}
- [lib] sbitmap: only queue kyber's wait callback if not already active (Ming Lei) [1784544]
- [fs] CIFS: Fix NULL-pointer dereference in smb2_push_mandatory_locks (Dave Wysochanski) [1788202]
- [kernel] ftrace: Check for successful allocation of hash (Desnes Augusto Nunes do Rosario) [1719414]
- [kernel] ftrace: Check for empty hash and comment the race with registering probes (Desnes Augusto Nunes do Rosario) [1719414]
- [kernel] ftrace: Fix NULL pointer dereference in t_probe_next() (Desnes Augusto Nunes do Rosario) [1719414]
- [iommu] vt-d: Allocate reserved region for ISA with correct permission (Jerry Snitselaar) [1778041]
- [iommu] set group default domain before creating direct mappings (Jerry Snitselaar) [1778041]
- [iommu] vt-d: Fix dmar pte read access not set error (Jerry Snitselaar) [1778041]
- [iommu] vt-d: Set ISA bridge reserved region as relaxable (Jerry Snitselaar) [1778041]
- [iommu] fix KASAN use-after-free in iommu_insert_resv_region (Auger Eric) [1777014]
- [platform] platform/x86: dell-laptop: fix rfkill functionality (Jarod Wilson) [1725878]
- [mm] mm/hugetlb: defer freeing of huge pages if in non-task context (Waiman Long) [1780015]
- [mm] powerpc/book3s64/hash: Use secondary hash for bolted mapping if the primary is full (Steve Best) [1783159]
- [mm] powerpc/pseries: Don't fail hash page table insert for bolted mapping (Steve Best) [1783159]
- [powerpc] powerpc/pseries: Don't opencode HPTE_V_BOLTED (Steve Best) [1783159]
- [powerpc] powerpc/perf: Disable trace_imc pmu (Steve Best) [1785573]
- [powerpc] powerpc/spinlocks: Include correct header for static key (Phil Auld) [1767529]
- [powerpc] powerpc/shared: Use static key to detect shared processor (Phil Auld) [1767529]
- [powerpc] powerpc/vcpu: Assume dedicated processors as non-preempt (Phil Auld) [1767529]
- [arm64] arm64: compat: Workaround Neoverse-N1 #1542419 for compat user-space (Jeremy Linton) [1757828]
- [arm64] arm64: Fake the IminLine size on systems affected by Neoverse-N1 #1542419 (Jeremy Linton) [1757828]
- [arm64] arm64: errata: Hide CTR_EL0.DIC on systems affected by Neoverse-N1 #1542419 (Jeremy Linton) [1757828]
- [arm64] arm64: Handle erratum 1418040 as a superset of erratum 1188873 (Jeremy Linton) [1757828]
- [arm64] arm64: errata: Add workaround for Cortex-A76 erratum #1463225 (Jeremy Linton) [1757828]
- [arm64] arm64: Kconfig: Tidy up errata workaround help text (Jeremy Linton) [1757828]
- [arm64] arm64: Apply ARM64_ERRATUM_1188873 to Neoverse-N1 (Jeremy Linton) [1757828]
- [arm64] arm64: Add part number for Neoverse N1 (Jeremy Linton) [1757828]
- [arm64] arm64: Make ARM64_ERRATUM_1188873 depend on COMPAT (Jeremy Linton) [1757828]
- [clocksource] arm64: Restrict ARM64_ERRATUM_1188873 mitigation to AArch32 (Jeremy Linton) [1757828]
- [arm64] arm64: arch_timer: avoid unused function warning (Jeremy Linton) [1757828]
- [arm64] arm64: Add workaround for Cortex-A76 erratum 1286807 (Jeremy Linton) [1757828]

* Tue Jan 07 2020 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-168.el8]
- [kernel] audit: remove redundant condition check in kauditd_thread() (Richard Guy Briggs) [1716002]
- [kernel] audit: Report suspicious O_CREAT usage (Richard Guy Briggs) [1716002]
- [fs] namei: allow restricted O_CREAT of FIFOs and regular files (Richard Guy Briggs) [1716002]
- [kernel] audit_get_nd(): don't unlock parent too early (Richard Guy Briggs) [1716002]
- [fs] namei.c: keep track of nd->root refcount status (Richard Guy Briggs) [1716002]
- [fs] namei.c: new helper - legitimize_root() (Richard Guy Briggs) [1716002]
- [kernel] kill the last users of user_{path, lpath, path_dir}() (Richard Guy Briggs) [1716002]
- [kernel] namei.h: get the comments on LOOKUP_... in sync with reality (Richard Guy Briggs) [1716002]
- [kernel] kill LOOKUP_NO_EVAL, don't bother including namei.h from audit.h (Richard Guy Briggs) [1716002]
- [kernel] audit_inode(): switch to passing AUDIT_INODE_.. (Richard Guy Briggs) [1716002]
- [fs] filename_mountpoint(): make LOOKUP_NO_EVAL unconditional there (Richard Guy Briggs) [1716002]
- [fs] filename_lookup(): audit_inode() argument is always 0 (Richard Guy Briggs) [1716002]
- [kernel] audit: remove the BUG() calls in the audit rule comparison functions (Richard Guy Briggs) [1716002]
- [kernel] audit: enforce op for string fields (Richard Guy Briggs) [1716002]
- [kernel] audit: deliver signal_info regarless of syscall (Richard Guy Briggs) [1716002]
- [fs] fsnotify: fix unlink performance regression (Richard Guy Briggs) [1716002]
- [kernel] audit_compare_dname_path(): switch to const struct qstr * (Richard Guy Briggs) [1716002]
- [kernel] audit_update_watch(): switch to const struct qstr * (Richard Guy Briggs) [1716002]
- [fs] inotify_handle_event(): don't bother with strlen() (Richard Guy Briggs) [1716002]
- [kernel] fsnotify: switch send_to_group() and ->handle_event to const struct qstr * (Richard Guy Briggs) [1716002]
- [kernel] fsnotify(): switch to passing const struct qstr * for file_name (Richard Guy Briggs) [1716002]
- [kernel] switch fsnotify_move() to passing const struct qstr * for old_name (Richard Guy Briggs) [1716002]
- [fs] ovl_lookup_real_one(): don't bother with strlen() (Richard Guy Briggs) [1716002]
- [kernel] audit: fix a memory leak bug (Richard Guy Briggs) [1716002]
- [kernel] audit: purge unnecessary list_empty calls (Richard Guy Briggs) [1716002]
- [security] audit: link integrity evm_write_xattrs record to syscall event (Richard Guy Briggs) [1716002]
- [csky] syscall_get_arch: add "struct task_struct *" argument (Richard Guy Briggs) [1716002]
- [kernel] audit: Make audit_log_cap and audit_copy_inode static (Richard Guy Briggs) [1716002]
- [kernel] audit: connect LOGIN record to its syscall record (Richard Guy Briggs) [1716002]
- [kernel] audit: fix a memleak caused by auditing load module (Richard Guy Briggs) [1716002]
- [kernel] fanotify: check FS_ISDIR flag instead of d_is_dir() (Richard Guy Briggs) [1716002]
- [kernel] fsnotify: report FS_ISDIR flag with MOVE_SELF and DELETE_SELF events (Richard Guy Briggs) [1716002]
- [kernel] fsnotify: annotate directory entry modification events (Richard Guy Briggs) [1716002]
- [kernel] audit: mark expected switch fall-through (Richard Guy Briggs) [1716002]
- [kernel] audit: hide auditsc_get_stamp and audit_serial prototypes (Richard Guy Briggs) [1716002]
- [tty] audit: join tty records to their syscall (Richard Guy Briggs) [1716002]
- [kernel] audit: remove audit_context when CONFIG_ AUDIT and not AUDITSYSCALL (Richard Guy Briggs) [1716002]
- [kernel] audit: remove unused actx param from audit_rule_match (Richard Guy Briggs) [1716002]
- [kernel] audit: ignore fcaps on umount (Richard Guy Briggs) [1716002]
- [kernel] audit: clean up AUDITSYSCALL prototypes and stubs (Richard Guy Briggs) [1716002]
- [kernel] audit: more filter PATH records keyed on filesystem magic (Richard Guy Briggs) [1716002]
- [kernel] audit: add support for fcaps v3 (Richard Guy Briggs) [1716002]
- [kernel] audit: move loginuid and sessionid from CONFIG_AUDITSYSCALL to CONFIG_AUDIT (Richard Guy Briggs) [1716002]
- [kernel] audit: add syscall information to CONFIG_CHANGE records (Richard Guy Briggs) [1716002]
- [kernel] audit: hand taken context to audit_kill_trees for syscall logging (Richard Guy Briggs) [1716002]
- [kernel] audit: give a clue what CONFIG_CHANGE op was involved (Richard Guy Briggs) [1716002]
- [kernel] audit: remove duplicated include from audit.c (Richard Guy Briggs) [1716002]
- [kernel] audit: shorten PATH cap values when zero (Richard Guy Briggs) [1716002]
- [kernel] audit: use current whenever possible (Richard Guy Briggs) [1716002]
- [kernel] audit: minimize our use of audit_log_format() (Richard Guy Briggs) [1716002]
- [kernel] audit: remove WATCH and TREE config options (Richard Guy Briggs) [1716002]
- [kernel] audit: use session_info helper (Richard Guy Briggs) [1716002]
- [kernel] audit: localize audit_log_session_info prototype (Richard Guy Briggs) [1716002]
- [kernel] audit: Use 'mark' name for fsnotify_mark variables (Richard Guy Briggs) [1716002]
- [kernel] audit: Replace chunk attached to mark instead of replacing mark (Richard Guy Briggs) [1716002]
- [kernel] audit: Simplify locking around untag_chunk() (Richard Guy Briggs) [1716002]
- [kernel] audit: Drop all unused chunk nodes during deletion (Richard Guy Briggs) [1716002]
- [kernel] audit: Guarantee forward progress of chunk untagging (Richard Guy Briggs) [1716002]
- [kernel] audit: Allocate fsnotify mark independently of chunk (Richard Guy Briggs) [1716002]
- [kernel] audit: Provide helper for dropping mark's chunk reference (Richard Guy Briggs) [1716002]
- [kernel] audit: Remove pointless check in insert_hash() (Richard Guy Briggs) [1716002]
- [kernel] audit: Factor out chunk replacement code (Richard Guy Briggs) [1716002]
- [kernel] audit: Make hash table insertion safe against concurrent lookups (Richard Guy Briggs) [1716002]
- [kernel] audit: Embed key into chunk (Richard Guy Briggs) [1716002]
- [kernel] audit: Fix possible tagging failures (Richard Guy Briggs) [1716002]
- [kernel] audit: Fix possible spurious -ENOSPC error (Richard Guy Briggs) [1716002]
- [kernel] audit_tree: Remove mark->lock locking (Richard Guy Briggs) [1716002]
- [kernel] audit: print empty EXECVE args (Richard Guy Briggs) [1716002]
- [security] evm: fix return value check in evm_write_xattrs() (Richard Guy Briggs) [1716002]
- [kernel] audit: fix use-after-free in audit_add_watch (Richard Guy Briggs) [1716002]
- [kernel] audit: use ktime_get_coarse_real_ts64() for timestamps (Richard Guy Briggs) [1716002]
- [kernel] audit: use ktime_get_coarse_ts64() for time access (Richard Guy Briggs) [1716002]
- [kernel] audit: simplify audit_enabled check in audit_watch_log_rule_change() (Richard Guy Briggs) [1716002]
- [kernel] audit: check audit_enabled in audit_tree_log_remove_rule() (Richard Guy Briggs) [1716002]
- [kernel] cred: conditionally declare groups-related functions (Richard Guy Briggs) [1716002]
- [kernel] audit: eliminate audit_enabled magic number comparison (Richard Guy Briggs) [1716002]
- [kernel] audit: Fix extended comparison of GID/EGID (Richard Guy Briggs) [1716002]
- [kernel] audit: tie ANOM_ABEND records to syscall (Richard Guy Briggs) [1716002]
- [kernel] audit: tie SECCOMP records to syscall (Richard Guy Briggs) [1716002]
- [kernel] audit: allow other filter list types for AUDIT_EXE (Richard Guy Briggs) [1716002]
- [documentation] admin guide/pm: Admin guide for intel-speed-select (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Display TRL buckets for just base config level (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Ignore missing config level (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Increment version (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Use core count for base-freq mask (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Support platform with limited Intel(R) Speed Select (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Use Frequency weight for CLOS (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Make CLOS frequency in MHz (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Use mailbox for CLOS_PM_QOS_CONFIG (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Auto mode for CLX (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Correct CLX-N frequency units (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Change display of "avx" to "avx2" (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Extend command set for perf-profile (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Implement base-freq commands on CascadeLake-N (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Implement 'perf-profile info' on CascadeLake-N (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Implement CascadeLake-N help and command functions structures (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Add check for CascadeLake-N models (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Make process_command generic (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Add int argument to command functions (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Refuse to disable core-power when getting used (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Turbo-freq feature auto mode (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Base-freq feature auto mode (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Remove warning for unused result (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix perf-profile command output (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Extend core-power command set (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix some debug prints (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Format get-assoc information (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Allow online/offline based on tdp (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix high priority core mask over count (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Display core count for bucket (Prarit Bhargava) [1766228]
- [platform] x86: isst: Allow additional TRL MSRs (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix memory leak (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Output success/failed for command output (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Output human readable CPU list (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Change turbo ratio output to maximum turbo frequency (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Switch output to MHz (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Simplify output for turbo-freq and base-freq (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix cpu-count output (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix help option typo (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix package typo (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Fix a read overflow in isst_set_tdp_level_msr() (Prarit Bhargava) [1766228]
- [platform] x86: isst: Use dev_get_drvdata (Prarit Bhargava) [1766228]
- [tools] power/x86/intel-speed-select: Add .gitignore file (Prarit Bhargava) [1766228]
- [tools] tools/power/x86: A tool to validate Intel Speed Select commands (Prarit Bhargava) [1766228]
- [platform] x86: isst: Restore state on resume (Prarit Bhargava) [1766228]
- [platform] x86: isst: Add Intel Speed Select PUNIT MSR interface (Prarit Bhargava) [1766228]
- [platform] x86: isst: Add Intel Speed Select mailbox interface via MSRs (Prarit Bhargava) [1766228]
- [platform] x86: isst: Add Intel Speed Select mailbox interface via PCI (Prarit Bhargava) [1766228]
- [platform] x86: isst: Add Intel Speed Select mmio interface (Prarit Bhargava) [1766228]
- [platform] x86: isst: Add IOCTL to Translate Linux logical CPU to PUNIT CPU number (Prarit Bhargava) [1766228]
- [platform] x86: isst: Store per CPU information (Prarit Bhargava) [1766228]
- [platform] x86: isst: Add common API to register and handle ioctls (Prarit Bhargava) [1766228]
- [documentation] platform/x86: isst: Update ioctl-number.txt for Intel Speed Select interface (Prarit Bhargava) [1766228]

* Sat Dec 14 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-167.el8]
- [tools] libbpf: Refactor relocation handling (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix call relocation offset calculation bug (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix bpf_object name determination for bpf_object__open_file() (Yauheni Kaliuta) [1772081]
- [tools] libbpf: return previous print callback from libbpf_set_print (Yauheni Kaliuta) [1772081]
- [tools] libbpf: fix bpf_object__name() to actually return object name (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Make CO-RE reloc test impartial to test_progs flavor (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Add BPF_CORE_READ and BPF_CORE_READ_STR_INTO macro tests (Yauheni Kaliuta) [1772081]
- [tools] bpftool: Allow to read btf as raw data (Yauheni Kaliuta) [1772081]
- [tools] bpftool: implement "bpftool btf show|list" (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add bpf_btf_get_next_id() to cycle through BTF objects (Jiri Olsa) [1772081]
- [tools] libbpf: refactor bpf_*_get_next_id() functions (Yauheni Kaliuta) [1772081]
- [tools] bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1772081]
- [tools] libbpf: attempt to load kernel BTF from sysfs first (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add getter for program size (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add bpf_get_link_xdp_info() function to get more XDP information (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Use pr_warn() when printing netlink errors (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Propagate EPERM to caller on program load (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Unpin auto-pinned maps if loading fails (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add auto-pinning of maps when loading BPF objects (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Teach bpf_object__open to guess program types (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add bpf_program__get_{type, expected_attach_type) APIs (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Move directory creation into _pin() functions (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Store map pin path and status in struct bpf_map (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix error handling in bpf_map__reuse_fd() (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Make DECLARE_LIBBPF_OPTS macro strictly a variable declaration (Yauheni Kaliuta) [1772081]
- [tools] bpftool: Fix bpftool build by switching to bpf_object__open_file() (Yauheni Kaliuta) [1772081]
- [tools] bpf: Rename pr_warning to pr_warn to align with kernel logging (Yauheni Kaliuta) [1772081]
- [tools] libbpf: provide more helpful message on uninitialized global var (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Add field existence CO-RE relocs tests (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add support for field existance CO-RE relocation (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Update BTF reloc support to latest Clang format (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add BPF_CORE_READ/BPF_CORE_READ_INTO helpers (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Refactor bpf_object__open APIs to use common opts (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Move bpf_{helpers, helper_defs, endian, tracing}.h into libbpf (Jiri Olsa) [1772081]
- [tools] uapi/bpf: fix helper docs (Yauheni Kaliuta) [1772081]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1772081]
- [uapi] bpf: fix 'struct pt_reg' typo in documentation (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix BTF-defined map's __type macro handling of arrays (Yauheni Kaliuta) [1772081]
- [scripts] bpf: Print an error when known types list needs updating (Yauheni Kaliuta) [1772081]
- [scripts] bpf: Emit an #error directive known types list needs updating (Yauheni Kaliuta) [1772081]
- [scripts] bpf: Fix xdp_md forward declaration typo (Yauheni Kaliuta) [1772081]
- [scripts] bpf: teach bpf_helpers_doc.py to dump BPF helper definitions (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Split off tracing-only helpers into bpf_tracing.h (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: samples/bpf: Split off legacy stuff from bpf_helpers.h (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Undo GCC-specific bpf_helpers.h changes (Yauheni Kaliuta) [1772081]
- [tools] libbpf: auto-generate list of BPF helper definitions (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add bpf-gcc support (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: bpf_tcp_gen_syncookie->bpf_helpers (Yauheni Kaliuta) [1772081]
- [tools] libbpf: relicense bpf_helpers.h and bpf_endian.h (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: introduce bpf_cpu_to_be64 and bpf_be64_to_cpu (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Adjust CO-RE reloc tests for new bpf_core_read() macro (Yauheni Kaliuta) [1772081]
- [tools] bpf: fix core_reloc.c compilation error (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add bpf_object__open_{file, mem} w/ extensible opts (Yauheni Kaliuta) [1772081]
- [tools] libbpf: make libbpf.map source of truth for libbpf version (Yauheni Kaliuta) [1772081]
- [tools] libbpf: stop enforcing kern_version, populate it for users (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs misc tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs ints tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs ptr-as-array tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs modifiers/typedef tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs enum/ptr/func_proto tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs array tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs nesting tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs struct flavors tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs testing setup (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add BPF_CORE_READ relocatable read macro (Yauheni Kaliuta) [1772081]
- [tools] libbpf: implement BPF CO-RE offset relocation algorithm (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add .BTF.ext offset relocation section loading (Yauheni Kaliuta) [1772081]
- [tools] libbpf: convert libbpf code to use new btf helpers (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add helpers for working with BTF types (Yauheni Kaliuta) [1772081]
- [gpu] drm/i915: Add new CNL PCH ID seen on a CML platform (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: add warning for GRBM 1-cycle delay issue in gfx9 (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: register gpu instance before fan boost feature enablment (Lyude Paul) [1771779]
- [gpu] drm/amd/swsmu: fix smu workload bit map error (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: dont schedule jobs while in reset (Lyude Paul) [1771779]
- [gpu] drm/i915/userptr: Try to acquire the page lock around set_page_dirty() (Lyude Paul) [1771779]
- [gpu] drm/i915/pmu: "Frequency" is reported as accumulated cycles (Lyude Paul) [1771779]
- [gpu] drm/i915: Don't oops in dumb_create ioctl if we have no crtcs (Lyude Paul) [1771779]
- [gpu] drm/amd/powerplay: issue no PPSMC_MSG_GetCurrPkgPwr on unsupported ASICs (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: disable gfxoff on original raven (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: disable gfxoff when using register read interface (Lyude Paul) [1771779]
- [gpu] revert "drm/i915/ehl: Update MOCS table for EHL" (Lyude Paul) [1771779]
- [gpu] drm/i915: update rawclk also on resume (Lyude Paul) [1771779]
- [gpu] dc.c:use kzalloc without test (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Passive DP->HDMI dongle detection fix (Lyude Paul) [1771779]
- [gpu] drm/amd/display: add 50us buffer as WA for pstate switch in active (Lyude Paul) [1771779]
- [gpu] drm/amd/display: do not synchronize "drr" displays (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: If amdgpu_ib_schedule fails return back the error (Lyude Paul) [1771779]
- [gpu] drm/sched: Set error to s_fence if HW job submission failed (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/sdma5: do not execute 0-sized IBs (v2) (Lyude Paul) [1771779]
- [gpu] drm/radeon: fix si_enable_smc_cac() failed issue (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix error handling in amdgpu_bo_list_create (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix potential VM faults (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Fix SDMA hang when performing VKexample test (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/powerplay/vega10: allow undervolting in p7 (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/gfx10: update gfx golden settings (Lyude Paul) [1771779]
- [gpu] drm/i915: Fix PCH reference clock for FDI on HSW/BDW (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix memory leak (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: user pages array memory leak fix (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/uvd7: fix allocation size in enc ring test (v2) (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/uvd6: fix allocation size in enc ring test (v2) (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/vcn: fix allocation size in enc ring test (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/vce: fix allocation size in enc ring test (Lyude Paul) [1771779]
- [gpu] drm/i915: Favor last VBT child device with conflicting AUX ch/DDC pin (Lyude Paul) [1771779]
- [gpu] drm/i915/userptr: Never allow userptr into the mappable GGTT (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for pipe sync (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not set to 1 (Lyude Paul) [1771779]
- [gpu] drm/ttm: Restore ttm prefaulting (Lyude Paul) [1771779]
- [gpu] drm/edid: Add 6 bpc quirk for SDC panel in Lenovo G50 (Lyude Paul) [1771779]
- [gpu] drm/amd/display: memory leak (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix multiple memory leaks in acp_hw_init (Lyude Paul) [1771779]
- [gpu] drm: Clear the fence pointer when writeback job signaled (Lyude Paul) [1771779]
- [gpu] drm: Free the writeback_job when it with an empty fb (Lyude Paul) [1771779]
- [gpu] drm/i915: Mark contents as dirty on a write fault (Lyude Paul) [1771779]
- [gpu] drm/i915: Whitelist COMMON_SLICE_CHICKEN2 (Lyude Paul) [1771779]
- [gpu] drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled (Lyude Paul) [1771779]
- [gpu] drm/i915: Perform GGTT restore much earlier during resume (Lyude Paul) [1771779]
- [gpu] drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Check for valid number of registers to read (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Fix KFD-related kernel oops on Hawaii (Lyude Paul) [1771779]
- [gpu] drm/i915: to make vgpu ppgtt notificaiton as atomic operation (Lyude Paul) [1771779]
- [gpu] drm/i915/gvt: update vgpu workload head pointer correctly (Lyude Paul) [1771779]
- [gpu] drm/amd/powerplay: change metrics update period from 1ms to 100ms (Lyude Paul) [1771779]
- [gpu] drm/nouveau/kms/nv50-: Don't create MSTMs for eDP connectors (Lyude Paul) [1771779]
- [gpu] drm/atomic: Take the atomic toys away from X (Lyude Paul) [1771779]
- [gpu] drm/atomic: Reject FLIP_ASYNC unconditionally (Lyude Paul) [1771779]
- [gpu] drm/i915/dp: Fix dsc bpp calculations, v5 (Lyude Paul) [1771779]
- [dma-buf] sw_sync: Synchronize signal vs syncpt free (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/si: fix ASIC tests (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix trigger not generated for freesync (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix MPO HUBP underflow with Scatter Gather (Lyude Paul) [1771779]
- [gpu] drm/amd/powerpaly: fix navi series custom peak level value error (Lyude Paul) [1771779]
- [gpu] drm/amd/display: support spdif (Lyude Paul) [1771779]
- [gpu] drm/nouveau/volt: Fix for some cards having 0 maximum voltage (Lyude Paul) [1771779]
- [gpu] drm/nouveau/kms/tu102-: disable input lut when input is already FP16 (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/sdma5: fix number of sdma5 trap irq types for navi1x (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Register VUPDATE_NO_LOCK interrupts for DCN2 (Lyude Paul) [1771779]
- [gpu] drm/amd/display: reprogram VM config when system resume (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Fix frames_to_insert math (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix issue where 252-255 values are clipped (Lyude Paul) [1771779]
- [gpu] drm: radeon: Fix a possible null-pointer dereference in radeon_connector_set_property() (Lyude Paul) [1771779]
- [gpu] revert "drm/radeon: Fix EEH during kexec" (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Use proper enum conversion functions (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Fix hard hang for S/G display BOs (Lyude Paul) [1771779]
- [gpu] drm/panel: check failure cases in the probe func (Lyude Paul) [1771779]
- [gpu] drm/bridge: sii902x: fix missing reference to mclk clock (Lyude Paul) [1771779]
- [gpu] drm/tinydrm/kconfig: Select BACKLIGHT_CLASS_DEVICE (Lyude Paul) [1771779]
- [video] ssd1307fb: Start page range at page_offset (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Copy GSL groups when committing a new context (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Clear FEC_READY shadow register if DPCD write fails (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix not calling ppsmu to trigger PME (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Power-gate all DSCs at driver init time (Lyude Paul) [1771779]
- [gpu] drm/amd/display: add monitor patch to add T7 delay (Lyude Paul) [1771779]
- [gpu] drm/panel: simple: fix AUO g185han01 horizontal blanking (Lyude Paul) [1771779]
- [gpu] drm/vkms: Avoid assigning 0 for possible_crtc (Lyude Paul) [1771779]
- [gpu] drm/bridge: tc358767: Increase AUX transfer length limit (Lyude Paul) [1771779]
- [gpu] drm/vkms: Fix crc worker races (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/display: fix 64 bit divide (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Add missing HBM support and raise Vega20's uclk (Lyude Paul) [1771779]
- [gpu] drm/amd/display: dce11.x /dce12 update formula input (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Restore backlight brightness after system resume (Lyude Paul) [1771779]
- [gpu] drm: fix module name in edid_firmware log message (Lyude Paul) [1771779]
- [gpu] drm/amd/powerplay/smu7: enforce minimal VBITimeout (v2) (Lyude Paul) [1771779]
- [gpu] drm/amd/display: readd -msse2 to prevent Clang from emitting libcalls to undefined SW FP routines (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Don't replace the dc_state for fast updates (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Skip determining update type for async updates (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Allow cursor async updates for framebuffer swaps (Lyude Paul) [1771779]
- [include] sk_buff: fix skb_ext_put() and skb_ext_reset() calls (Ivan Vecera) [1779923]
- [net] openvswitch: fix flow command message size (Paolo Abeni) [1776765]
- [net] netfilter: nf_tables: add SECMARK support (Phil Sutter) [1715851]
- [net] netfilter: nf_tables: add requirements for connsecmark support (Phil Sutter) [1715851]
- [wireless] mwifiex: pcie: Fix memory leak in mwifiex_pcie_init_evt_ring (Jarod Wilson) [1781534] {CVE-2019-19057}
- [tools] selftests/powerpc: Disable basic EEH selftest (Steve Best) [1782232]
- [x86] kvm: x86: Remove a spurious export of a static function (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: vmx: use MSR_IA32_TSX_CTRL to hard-disable TSX on guest that lack it (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: vmx: implement MSR_IA32_TSX_CTRL disable RTM functionality (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: x86: implement MSR_IA32_TSX_CTRL effect on CPUID (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: x86: do not modify masked bits of shared MSRs (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: x86: fix presentation of TSX feature in ARCH_CAPABILITIES (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm/x86: Export MDS_NO=0 to guests when TSX is enabled (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [fs] cifs: Close open handle after interrupted close (Leif Sahlberg) [1771691]
- [fs] cifs: Do not miss cancelled OPEN responses (Leif Sahlberg) [1771691]
- [fs] cifs: Fix NULL pointer dereference in mid callback (Leif Sahlberg) [1771691]
- [fs] cifs: add a debug macro that prints \\server\share for errors (Leif Sahlberg) [1772630]
- [fs] cifs: add new debugging macro cifs_server_dbg (Leif Sahlberg) [1772630]

* Sat Dec 14 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-166.el8]
- [netdrv] wireless: fix nl80211 vendor commands (Jarod Wilson) [1776606]
- [net] nl80211: fix VENDOR_CMD_RAW_DATA (Jarod Wilson) [1776606]
- [netdrv] rt2x00: initialize last_reset (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: don't consider IV len in A-MSDU (Jarod Wilson) [1776606]
- [net] mac80211: fix station inactive_time shortly after boot (Jarod Wilson) [1776606]
- [net] mac80211: fix ieee80211_txq_setup_flows() failure path (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw api: support new API for scan config cmd (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: fix buffer unmap with non-linear skbs (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x2e: disable pcie_aspm by default (Jarod Wilson) [1776606]
- [net] nl80211: fix validation of mesh path nexthop (Jarod Wilson) [1776606]
- [net] nl80211: Disallow setting of HT for channel 14 (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl_pci: Fix problem of too small skb->len (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: 0x2720 is qu and 0x30DC is not (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: add workaround for power gating in integrated 22000 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: handle iwl_mvm_tvqm_enable_txq() error return (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix all 9460 entries for qnj (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix PCI ID 0x2720 configs that should be soc (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: Fix potential overflow on P2P code (Jarod Wilson) [1775223 1776606] {CVE-2019-17666}
- [netdrv] iwlwifi: pcie: fix merge damage on making QnJ exclusive (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix latency issue for QCA988x (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: change qu with jf devices to use qu configuration (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: exclude GEO SAR support for 3168 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix memory leaks in iwl_pcie_ctxt_info_gen3_init (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix memory leak in alloc_sgtable (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix rb_allocator workqueue allocation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix indexing in command dump for new HW (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix race in sync rx queue notification (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: force single phy init (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix ACPI table revision checks (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: don't access trans_cfg via cfg (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove input-polldev.h header (Jarod Wilson) [1776606]
- [net] mac80211: Don't access sk_queue_head->next directly (Jarod Wilson) [1776606]
- [net] mac80211: fix scan when operating on DFS channels in ETSI domains (Jarod Wilson) [1776606]
- [net] mac80211: accept deauth frames in IBSS mode (Jarod Wilson) [1776606]
- [net] cfg80211: fix a bunch of RCU issues in multi-bssid code (Jarod Wilson) [1776606]
- [net] nl80211: fix memory leak in nl80211_get_ftm_responder_stats (Jarod Wilson) [1776606]
- [net] cfg80211: wext: avoid copying malformed SSIDs (Jarod Wilson) [1778634 1776606] {CVE-2019-17133}
- [net] mac80211: Reject malformed SSID elements (Jarod Wilson) [1776606]
- [net] mac80211: keep BHs disabled while calling drv_tx_wake_queue() (Jarod Wilson) [1776606]
- [net] mac80211: fix txq null pointer dereference (Jarod Wilson) [1776606]
- [net] nl80211: fix null pointer dereference (Jarod Wilson) [1776606]
- [net] cfg80211: initialize on-stack chandefs (Jarod Wilson) [1776606]
- [net] cfg80211: validate SSID/MBSSID element ordering assumption (Jarod Wilson) [1776606]
- [net] nl80211: validate beacon head (Jarod Wilson) [1776606]
- [net] cfg80211: Purge frame registrations on iftype change (Jarod Wilson) [1776606]
- [net] cfg80211: Do not compare with boolean in nl80211_common_reg_change_event (Jarod Wilson) [1776606]
- [net] cfg80211: always shut down on HW rfkill (Jarod Wilson) [1776606]
- [net] cfg80211: fix boundary value in ieee80211_frequency_to_channel() (Jarod Wilson) [1776606]
- [net] cfg80211: add local BSS receive time to survey information (Jarod Wilson) [1776606]
- [net] nl80211: add NL80211_CMD_UPDATE_FT_IES to supported commands (Jarod Wilson) [1776606]
- [netdrv] wireless: Fix Kconfig indentation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw: don't send GEO_TX_POWER_LIMIT command to FW version 36 (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix mt7615 firmware path definitions (Jarod Wilson) [1776606]
- [netdrv] rtw88: configure firmware after HCI started (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: release tx skbs DMAed when stop (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: extract skbs free routine for trx rings (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix build w/o CONFIG_THERMAL (Jarod Wilson) [1776606]
- [netdrv] rtw88: report RX power for each antenna (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix wrong rx power calculation (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192de: replace _rtl92d_evm_db_to_percentage with generic version (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: replace _rtl92c_evm_db_to_percentage with generic version (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: replace _rtl92c_evm_db_to_percentage with generic version (Jarod Wilson) [1776606]
- [netdrv] rtw88: allows to receive AMSDU in AMPDU (Jarod Wilson) [1776606]
- [netdrv] rtw88: add dynamic cck pd mechanism (Jarod Wilson) [1776606]
- [netdrv] rtw88: move IQK/DPK into phy_calibration (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: add SW DPK support (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: add FW IQK support (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: Enable interrupt migration (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: update pwr_seq to v13 (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: update PHY parameter to v38 (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: rtl8192ce: rtl8192de: rtl8723ae: rtl8821ae: Remove some unused bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Remove unused SET_XXX and GET_XXX macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Remove unused GET_XXX and SET_XXX macros (Jarod Wilson) [1776606]
- [netdrv] brcmsmac: Use DIV_ROUND_CLOSEST directly to make it readable (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: make array static const and remove redundant assignment (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: don't realloc wiphy during PCIe reset (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: split brcmf_attach() and brcmf_detach() functions (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: move "cfg80211_ops" pointer to another struct (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix channel info parsing for non tlv target (Jarod Wilson) [1776606]
- [netdrv] ath10k: adjust skb length in ath10k_sdio_mbox_rx_packet (Jarod Wilson) [1776606]
- [netdrv] ath10k: free beacon buf later in vdev teardown (Jarod Wilson) [1776606]
- [net] mac80211: allow drivers to set max MTU (Jarod Wilson) [1776606]
- [net] mac80211: ibss: send deauth when expiring inactive STAs (Jarod Wilson) [1776606]
- [net] mac80211: don't check if key is NULL in ieee80211_key_link() (Jarod Wilson) [1776606]
- [net] mac80211: clear crypto tx tailroom counter upon keys enable (Jarod Wilson) [1776606]
- [net] mac80211: remove unnecessary key condition (Jarod Wilson) [1776606]
- [net] mac80211: list features in WEP/TKIP disable in better order (Jarod Wilson) [1776606]
- [net] mac80211: vht: add support VHT EXT NSS BW in parsing VHT (Jarod Wilson) [1776606]
- [netdrv] ath9k: release allocated buffer if timed out (Jarod Wilson) [1778582 1776606] {CVE-2019-19074}
- [netdrv] ath9k_htc: release allocated buffer if timed out (Jarod Wilson) [1778572 1776606] {CVE-2019-19073}
- [netdrv] ath9k: Remove unneeded variable to store return value (Jarod Wilson) [1776606]
- [netdrv] ath10k: add reorder and change PN check logic for mac80211 (Jarod Wilson) [1776606]
- [netdrv] ath10k: add mic bytes for pmf management packet (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: use *ph to print small buffer (Jarod Wilson) [1776606]
- [netdrv] hostap: use *ph to print small buffer (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: Fix file release memory leak (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix seq_file memory leak (Jarod Wilson) [1776606]
- [netdrv] hostap: remove set but not used variable 'copied' in prism2_io_debug_proc_read (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: add "reset" debugfs entry for testing reset (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: add stub version of brcmf_debugfs_get_devdir() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: remove iwl_fw_cancel_dumps function (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove periodic trigger (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix dump structs doc (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw api: add DRAM buffer allocation command (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove apply point, switch to time point API (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add iwl_tlv_array_len() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: don't log un-decrypted frames (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add support for single antenna diversity (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: handle BAR_FRAME_RELEASE (0xc2) notification (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: drop BA sessions on too many old-SN frames (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add sta_id to WOWLAN_CONFIG_CMD (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add support for suspend-resume flow for new device generation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix warning iwl-trans.h is included more than once (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: always access the trans configuration via trans (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pass the iwl_trans instead of cfg to some functions (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add a pointer to the trans_cfg directly in trans (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pass the iwl_config_trans_params when needed (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: set iwl_trans->cfg later in the probe function (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: move some cfg mangling from trans_pcie_alloc to probe (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: use the cfg we passed to iwl_trans_pcie_alloc() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: separate elements from cfg that are needed by trans_alloc (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use regions ops array instead of switch case in dump flow (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: make a single ops struct for paging collect (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: move tx fifo data into fw runtime (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use linked list for dump TLVs during dump creation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: separate cfg and dump flows to different modules (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: look for the first supported channel when add/remove phy ctxt (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: allocate bigger nvm data in case of UHB (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove unnecessary IWL_DEVICE_AX200_COMMON definition (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: align wrt log prints to the same format (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove debug flow TLV (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: verify debug TLVs at allocation phase (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use function to check if ini dbg mode is on (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove duplicate FW string definitions (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: bump FW API to 50 for 22000 series (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: api: fix FTM struct documentation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: support per-platform antenna gain (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove check for lq_sta in __iwl_mvm_rs_tx_status() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: simplify the channel switch flow for newer firmware (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: stop passing bogus gfp flags arguments to dma_alloc_coherent (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove periphery phy and aux regions handling (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use linked list to store debug TLVs (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: maintain buffer allocations from trans instead of TLVs buffer (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: add debug periphery registers to 9000 device family (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove unused regdb_ptrs allocation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: align dbg tlv functions names to a single format (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: scan: don't pass large argument by value (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove pm_runtime completely (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove the d0i3 related module parameters (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: remove some more d0i3 code from the transport (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: remove the refs / unrefs from the transport (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove the opmode's d0i3 handlers (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove runtime_pm_mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: Set w-pointer upon resume according to SN (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: use FW thermal monitoring regardless of CONFIG_THERMAL (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: name magic numbers with enum (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: scan: add support for new scan request command version (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: LTR updates (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove the code under IWLWIFI_PCIE_RTPM (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: trans: remove suspending flag (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove CMD_HIGH_PRIO (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove last leftovers of d0i3 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove iwl_mvm_update_d0i3_power_mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove d0i3_ap_sta_id (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: iwl_mvm_wowlan_config_key_params is for wowlan only (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove the d0i3 entry/exit flow (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove the tx defer for d0i3 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove all the d0i3 references (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: start to remove the code for d0i3 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add the skb length to a print (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix scan config command size (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add ldbg config cmd debug print (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: support debug recording suspend resume command (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: move debug recording stop from trans to op mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: move monitor recording functionality from header file (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove unnecessary forward declarations (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Block 26-tone RU OFDMA transmissions (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove redundant condition in iwl_mvm_set_hw_rfkill_state (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: Send DQA enable command only if TVL is on (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: bump FW API to 49 for 22000 series (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add support to read temperature from mcu (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_txwi_to_txp utility routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use devm_platform_ioremap_resource() to simplify code (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0: remove unneeded return value on set channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0: remove redundant chandef copy (Jarod Wilson) [1776606]
- [netdrv] mt76: make mt76_rx_convert static (Jarod Wilson) [1776606]
- [netdrv] mt76: remove offchannel check in tx scheduling (Jarod Wilson) [1776606]
- [netdrv] mt76: do not send BAR frame on tx aggregation flush stop (Jarod Wilson) [1776606]
- [netdrv] mt76: stop rx aggregation on station removal (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: reset q->rx_head on rx reset (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: apply calibration-free data from OTP (Jarod Wilson) [1776606]
- [netdrv] mt76: add default implementation for mt76_sw_scan/mt76_sw_scan_complete (Jarod Wilson) [1776606]
- [netdrv] mt76: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add BIP_CMAC_128 cipher support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: remove unnecessary mcu queue initialization (Jarod Wilson) [1776606]
- [netdrv] mt76: move mt76_tx_tasklet in mt76 module (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: enable survey support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: move survey_time in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02u: enable survey support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02u: enable multi-vif support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: do not copy beacon skb in mt76x02_mac_set_beacon_enable (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: introduce mt76x02_pre_tbtt_enable and mt76x02_beacon_enable macros (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add Smart Carrier Sense support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: rework locking scheme for mt7615_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: switch to SPDX tag instead of verbose boilerplate text (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: Add paragraphs to describe the config symbols fully (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: update cw_min/max related settings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add 4 WMM sets support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix watchdog rescheduling in mt7603_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix MT7615_WATCHDOG_TIME definition (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_mmio_read_copy routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add set_key_cmd and mt76_wcid to mt7615_mac_wtbl_set_key signature (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove wtbl_sec_key definition (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_mac_wtbl_set_key routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add mt7615_mac_wtbl_addr routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: move mt7615_mac_get_key_info in mac.c (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add missing register initialization (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0u: add support to TP-Link T2UHP (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: usb: remove unneeded {put,get}_unaligned (Jarod Wilson) [1776606]
- [netdrv] mt76: usb: fix endian in mt76u_copy (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix invalid fallback rates (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix invalid fallback rates (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix PS buffering of action frames (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix using VHT STBC rates (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76u: fix typo in mt76u_fill_rx_sg (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: sync with mt7603 rate control changes (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: reset rate index/counters on rate table update (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: move mt7615_mcu_set_rates to mac.c (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: enable hardware rate up/down selection (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_mcu_send_ram_firmware routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: always release sem in mt7615_load_patch (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fall back to sw encryption for unsupported ciphers (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: clean up FWDL TXQ during/after firmware upload (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add radar pattern test knob to debugfs (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add csa support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: do not perform txcalibration before cac is complited (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add hw dfs pattern detector support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_regd_notifier (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix sparse warnings: warning: restricted __le16 degrades to integer (Jarod Wilson) [1776606]
- [netdrv] mt76: round up length on mt76_wr_copy (Jarod Wilson) [1776606]
- [netdrv] ath6kl: fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe() (Jarod Wilson) [1776606]
- [netdrv] ath6kl: Fix a possible null-pointer dereference in ath6kl_htc_mbox_create() (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: set ackto to max timeout in ath_dynack_reset (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: set max timeout according to channel width (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: properly set last timeout timestamp in ath_dynack_reset (Jarod Wilson) [1776606]
- [netdrv] ath9k: dyanck: introduce ath_dynack_set_timeout routine (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: fix possible deadlock in ath_dynack_node_{de}init (Jarod Wilson) [1776606]
- [netdrv] ath9k: add loader for AR92XX (and older) pci(e) (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: get chip's default RAM info during PCIe setup (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: replace strncpy() by strscpy() (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not set IEEE80211_TX_STAT_AMPDU_NO_BACK on tx status (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: remove redundant assignment to pointer hash (Jarod Wilson) [1776606]
- [netdrv] brcm80211: Avoid possible null-pointer dereferences in wlc_phy_radio_init_2056() (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: enable MSI interrupt (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: Move a mass of jobs in hw IRQ to soft IRQ (Jarod Wilson) [1776606]
- [netdrv] rtw88: remove redundant assignment to pointer debugfs_topdir (Jarod Wilson) [1776606]
- [netdrv] rtw88: drop unused rtw_coex_coex_dm_reset() (Jarod Wilson) [1776606]
- [netdrv] rtw88: Fix an error message (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Fix incorrect returned values (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Fix incorrect returned values (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Fix incorrect returned values (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Remove some variable initializations (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl_pci: Fix memory leak when hardware init fails (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove unused variables 'RTL8712_SDIO_EFUSE_TABLE' and 'MAX_PGPKT_SIZE' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Fix value set in descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: fix non-kerneldoc comment in usb.c (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: fix infinite loop because supported is not being shifted (Jarod Wilson) [1776606]
- [netdrv] mt76: Remove dev_err() usage after platform_get_irq() (Jarod Wilson) [1776606]
- [net] mac80211: Do not send Layer 2 Update frame before authorization (Jarod Wilson) [1776606]
- [netdrv] revert "rt2800: enable TX_PIN_CFG_LNA_PE_ bits per band" (Jarod Wilson) [1776606]
- [netdrv] rt2x00: clear up IV's on key removal (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: assign directly to iwl_trans->cfg in QuZ detection (Jarod Wilson) [1776606]
- [netdrv] mwifiex: Fix three heap overflow at parsing element in cfg80211_ap_settings (Jarod Wilson) [1776244 1775484 1775475 1776606]
- [netdrv] mt76: mt76x0e: disable 5GHz band for MT7630E (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0e: don't use hw encryption for MT7630E (Jarod Wilson) [1776606]
- [net] nl80211: fill all policy .type entries (Jarod Wilson) [1776606]
- [net] cfg80211: Add support to set tx power for a station associated (Jarod Wilson) [1776606]
- [net] cfg80211: Fix Extended Key ID key install checks (Jarod Wilson) [1776606]
- [net] mac80211: AMPDU handling for rekeys with Extended Key ID (Jarod Wilson) [1776606]
- [net] mac80211: Simplify Extended Key ID API (Jarod Wilson) [1776606]
- [net] nl80211: require and validate vendor command policy (Jarod Wilson) [1776606]
- [net] mac80211: AMPDU handling for Extended Key ID (Jarod Wilson) [1776606]
- [net] mac80211: IEEE 802.11 Extended Key ID support (Jarod Wilson) [1776606]
- [net] nl80211/cfg80211: Extended Key ID support (Jarod Wilson) [1776606]
- [net] nl80211/cfg80211: Specify band specific min RSSI thresholds with sched scan (Jarod Wilson) [1776606]
- [net] cfg80211: Use const more consistently in for_each_element macros (Jarod Wilson) [1776606]
- [net] nl80211: use for_each_element() in validate_ie_attr() (Jarod Wilson) [1776606]
- [net] cfg80211: add peer measurement with FTM initiator API (Jarod Wilson) [1776606]
- [net] nl80211: use netlink policy validation function for elements (Jarod Wilson) [1776606]
- [net] nl80211: use policy range validation where applicable (Jarod Wilson) [1776606]
- [net] cfg80211: support FTM responder configuration/statistics (Jarod Wilson) [1776606]
- [net] lib80211: move TKIP handling to ARC4 library code (Jarod Wilson) [1776606]
- [net] lib80211: move WEP handling to ARC4 library code (Jarod Wilson) [1776606]
- [net] mac80211: move WEP handling to ARC4 library interface (Jarod Wilson) [1776606]
- [netdrv] rt2x00: clear IV's on start to fix AP mode regression (Jarod Wilson) [1776606]
- [netdrv] rt2800usb: Add new rt2800usb device PLANEX GW-USMicroN (Jarod Wilson) [1776606]
- [netdrv] rt2x00: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [netdrv] rt2x00usb: remove unnecessary rx flag checks (Jarod Wilson) [1776606]
- [netdrv] rt2x00usb: fix rx queue hang (Jarod Wilson) [1776606]
- [netdrv] rt2800: do not enable watchdog by default (Jarod Wilson) [1776606]
- [netdrv] rt2x00: add restart hw (Jarod Wilson) [1776606]
- [netdrv] rt2800: do not nullify initialization vector data (Jarod Wilson) [1776606]
- [netdrv] rt2800: add pre_reset_hw callback (Jarod Wilson) [1776606]
- [netdrv] rt2800: initial watchdog implementation (Jarod Wilson) [1776606]
- [netdrv] rt2800: add helpers for reading dma done index (Jarod Wilson) [1776606]
- [netdrv] rt2x00: allow to specify watchdog interval (Jarod Wilson) [1776606]
- [netdrv] rt2x00: add RT3883 support (Jarod Wilson) [1776606]
- [netdrv] rt2x00mmio: remove legacy comment (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove not used entry field (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove last_nostatus_check (Jarod Wilson) [1776606]
- [netdrv] rt2800mmio: use timer and work for handling tx statuses timeouts (Jarod Wilson) [1776606]
- [netdrv] rt2800mmio: fetch tx status changes (Jarod Wilson) [1776606]
- [netdrv] rt2800: move txstatus pending routine (Jarod Wilson) [1776606]
- [netdrv] rt2800: new flush implementation for SoC devices (Jarod Wilson) [1776606]
- [netdrv] rt2800: partially restore old mmio txstatus behaviour (Jarod Wilson) [1776606]
- [netdrv] rt2x00: code-style fix in rt2800usb.c (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not print error when queue is full (Jarod Wilson) [1776606]
- [netdrv] rt2x00: check number of EPROTO errors (Jarod Wilson) [1776606]
- [netdrv] rt2x00: use ratelimited variants dev_warn/dev_err (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not increment sequence number while re-transmitting (Jarod Wilson) [1776606]
- [netdrv] rt2800: comment and simplify AGC init for RT6352 (Jarod Wilson) [1776606]
- [netdrv] rt2800: enable TX_PIN_CFG_RFRX_EN only for MT7620 (Jarod Wilson) [1776606]
- [netdrv] rt2800: enable TX_PIN_CFG_LNA_PE_ bits per band (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove confusing AGC register (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove unneeded check (Jarod Wilson) [1776606]
- [netdrv] rt2x00: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [netdrv] rt2x00: Work around a firmware bug with shared keys (Jarod Wilson) [1776606]
- [netdrv] rt2x00: reduce tx power to nominal level on RT6352 (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt61pci: mark expected switch fall-through (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt2800lib: mark expected switch fall-throughs (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt2500pci: mark expected switch fall-through (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt2400pci: mark expected switch fall-through (Jarod Wilson) [1776606]
- [netdrv] rt2800: flush and txstatus rework for rt2800mmio (Jarod Wilson) [1776606]
- [netdrv] rt2x00: use different txstatus timeouts when flushing (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not check for txstatus timeout every time on tasklet (Jarod Wilson) [1776606]
- [netdrv] rt2800mmio: use txdone/txstatus routines from lib (Jarod Wilson) [1776606]
- [netdrv] rt2800: move usb specific txdone/txstatus routines to rt2800lib (Jarod Wilson) [1776606]
- [netdrv] rt2x00: use simple_read_from_buffer() (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove redundant functions rt2x00mac_sta_{add/remove} (Jarod Wilson) [1776606]
- [net] mac80211: Correctly set noencrypt for PAE frames (Jarod Wilson) [1776606]
- [net] mac80211: Don't memset RXCB prior to PAE intercept (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: handle switching killer Qu B0 NICs to C0 (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: improve rate probing for devices with static fallback (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: fix default max throughput rate indexes (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: reduce unnecessary rate probing attempts (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: fix per-group max throughput rate initialization (Jarod Wilson) [1776606]
- [net] nl80211: Add support for EDMG channels (Jarod Wilson) [1776606]
- [net] mac80211: fix possible NULL pointerderef in obss pd code (Jarod Wilson) [1776606]
- [net] mac80211: add assoc-at support (Jarod Wilson) [1776606]
- [uapi] cfg80211: Support assoc-at timer in sta-info (Jarod Wilson) [1776606]
- [net] cfg80211: apply same mandatory rate flags for 5GHz and 6GHz (Jarod Wilson) [1776606]
- [net] cfg80211: ibss: use 11a mandatory rates for 6GHz band operation (Jarod Wilson) [1776606]
- [net] cfg80211: use same IR permissive rules for 6GHz band (Jarod Wilson) [1776606]
- [net] cfg80211: add 6GHz in code handling array with NUM_NL80211_BANDS entries (Jarod Wilson) [1776606]
- [net] cfg80211: extend ieee80211_operating_class_to_band() for 6GHz (Jarod Wilson) [1776606]
- [net] cfg80211: util: add 6GHz channel to freq conversion and vice versa (Jarod Wilson) [1776606]
- [net] cfg80211: add 6GHz UNII band definitions (Jarod Wilson) [1776606]
- [uapi] nl80211: add 6GHz band definition to enum nl80211_band (Jarod Wilson) [1776606]
- [net] revert "cfg80211: fix processing world regdomain when non modular" (Jarod Wilson) [1776606]
- [net] mac80211: add missing length field increment when generating Radiotap header (Jarod Wilson) [1776606]
- [net] mac80211: 80Mhz was not reported properly when using tx_status_ext (Jarod Wilson) [1776606]
- [net] mac80211: fix bad guard when reporting legacy rates (Jarod Wilson) [1776606]
- [net] mac80211: fix TX legacy rate reporting when tx_status_ext is used (Jarod Wilson) [1776606]
- [net] mac80211: fix possible sta leak (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix recognition of QuZ devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: don't switch FW to qnj when ax201 is detected (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix the byte count table format for 22560 devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Allow multicast data frames only when associated (Jarod Wilson) [1776606]
- [netdrv] revert "mwifiex: fix system hang problem after resume" (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1776606]
- [netdrv] rtw88: add BT co-existence support (Jarod Wilson) [1776606]
- [netdrv] rtw88: enclose c2h cmd handle with mutex (Jarod Wilson) [1776606]
- [netdrv] rtw88: allow c2h operation in irq context (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Remove local configuration variable (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl88188ee: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Remove unused GET_XXX and SET_XXX descriptor macros (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: remove set but not used variable 'ip_sel' (Jarod Wilson) [1776606]
- [netdrv] brcmsmac: remove three set but not used variables (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: remove set but not used variable 'dtim_period' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove unneeded function _rtl_dump_channel_map() (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl_pci: Use dev_get_drvdata (Jarod Wilson) [1776606]
- [netdrv] mwifiex: pcie: Use dev_get_drvdata (Jarod Wilson) [1776606]
- [netdrv] mwifiex: make error values consistent in mwifiex_update_bss_desc_with_ie() (Jarod Wilson) [1776606]
- [netdrv] rtw88: use txpwr_lmt_cfg_pair struct, not arrays (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix compile time assert build errors (Jarod Wilson) [1776606]
- [net] mac80211: HE STA disassoc due to QOS NULL not sent (Jarod Wilson) [1776606]
- [net] mac80211: allow setting spatial reuse parameters from bss_conf (Jarod Wilson) [1776606]
- [net] nl80211: add strict start type (Jarod Wilson) [1776606]
- [net] cfg80211: add support for parsing OBBS_PD attributes (Jarod Wilson) [1776606]
- [net] mac80211: reject zero MAC address in add station (Jarod Wilson) [1776606]
- [net] cfg80211: use parallel_ops for genl (Jarod Wilson) [1776606]
- [net] mac80211: add missing null return check from call to ieee80211_get_sband (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix a use-after-free bug in iwl_mvm_tx_tso_segment (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix an out-of-bound access (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: don't unmap as page memory that was mapped as single (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix version check for GEO_TX_POWER_LIMIT support (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add 3 new IDs for the 9000 series (iwl9260_2ac_160_cfg) (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix possible out-of-bounds read when accessing lq_info (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix frame drop from the reordering buffer (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: replace RS mutex with a spin_lock (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: send LQ command always ASYNC (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix comparison of u32 variable with less than zero (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix locking in delayed GTK setting (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: move iwl_dbg_tlv_free outside of debugfs ifdef (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: move iwl_dbg_tlv_load_bin out of debug override ifdef (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a wrapper around rs_tx_status to handle locks (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a loose synchronization of the NSSN across Rx queues (Jarod Wilson) [1776606]
- [netdrv] iwlwiif: mvm: refactor iwl_mvm_notify_rx_queue (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a new RSS sync notification for NSSN sync (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: prepare the ground for more RSS notifications (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: don't send GEO_TX_POWER_LIMIT on version < 41 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: avoid races in rate init and rate perform (Jarod Wilson) [1776606]
- [net] revert "mac80211: set NETIF_F_LLTX when using intermediate tx queues" (Jarod Wilson) [1776606]
- [net] mac80211: add support for the ADDBA extension element (Jarod Wilson) [1776606]
- [net] mac80211: propagate HE operation info into bss_conf (Jarod Wilson) [1776606]
- [net] cfg80211: fix dfs channels remain DFS_AVAILABLE after ch_switch (Jarod Wilson) [1776606]
- [net] cfg80211: fix duplicated scan entries after channel switch (Jarod Wilson) [1776606]
- [net] cfg80211: refactor cfg80211_bss_update (Jarod Wilson) [1776606]
- [net] mac80211: don't WARN on short WMM parameters from AP (Jarod Wilson) [1776606]
- [net] nl80211: Include wiphy address setup in NEW_WIPHY (Jarod Wilson) [1776606]
- [net] mac80211: implement HE support for mesh (Jarod Wilson) [1776606]
- [net] mac80211: add IEEE80211_KEY_FLAG_GENERATE_MMIE to ieee80211_key_flags (Jarod Wilson) [1776606]
- [kernel] mac80211: he: add Spatial Reuse element parsing support (Jarod Wilson) [1776606]
- [net] mac80211: add struct ieee80211_tx_status support to ieee80211_add_tx_radiotap_header (Jarod Wilson) [1776606]
- [net] {nl, mac}80211: fix interface combinations on crypto controlled devices (Jarod Wilson) [1776606]
- [net] mac80211: propagate struct ieee80211_tx_status into ieee80211_tx_monitor() (Jarod Wilson) [1776606]
- [net] mac80211: add xmit rate to struct ieee80211_tx_status (Jarod Wilson) [1776606]
- [kernel] mac80211: add support for parsing ADDBA_EXT IEs (Jarod Wilson) [1776606]
- [net] cfg80211: give all multi-BSSID BSS entries the same timestamp (Jarod Wilson) [1776606]
- [net] cfg80211: don't parse MBSSID if transmitting BSS isn't created (Jarod Wilson) [1776606]
- [net] cfg80211: clean up cfg80211_inform_single_bss_frame_data() (Jarod Wilson) [1776606]
- [net] cfg80211: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [net] mac80211: add tx dequeue function for process context (Jarod Wilson) [1776606]
- [net] mac80211: run late dequeue late tx handlers without holding fq->lock (Jarod Wilson) [1776606]
- [net] lib80211: use crypto API ccm(aes) transform for CCMP processing (Jarod Wilson) [1776606]
- [net] mac80211: remove unused and unneeded remove_sta_debugfs callback (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove unused .remove_sta_debugfs callback (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dvm: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [net] mac80211: pass the vif to cancel_remain_on_channel (Jarod Wilson) [1776606]
- [netdrv] mwifiex: use eth_broadcast_addr() to assign broadcast address (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove assignment to itself (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: don't net_ratelimit() CONSOLE messages on firmware crash (Jarod Wilson) [1776606]
- [netdrv] rtw88: debug: dump tx power indexes in use (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: btcoex: fix issue possible condition with no effect (if == else) (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: remove unnecessary strlcpy() upon obtaining "ver" iovar (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: simply remove flowring if bus is down (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: avoid firmware commands when bus is down (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: clear events in brcmf_fweh_detach() will always fail (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: avoid firmware command in brcmf_netdev_open() when bus is down (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: change the order of things in brcmf_detach() (Jarod Wilson) [1776606]
- [netdrv] revert "brcmfmac: fix NULL pointer derefence during USB disconnect" (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: allow 160MHz in custom regulatory rules (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: enable DFS_OFFLOAD extended feature if supported (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: add 160MHz in chandef_to_chanspec() (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: Use DMA sync instead of remapping in RX ISR (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: Rearrange the memory usage for skb in RX ISR (Jarod Wilson) [1776606]
- [netdrv] rtw88: Fix misuse of GENMASK macro (Jarod Wilson) [1776606]
- [netdrv] rtl8xxxu: Fix wifi low signal strength issue of RTL8723BU (Jarod Wilson) [1776606]
- [net] mac80211: don't warn about CW params when not using them (Jarod Wilson) [1776606]
- [net] mac80211: fix possible memory leak in ieee80211_assign_beacon (Jarod Wilson) [1776606]
- [kernel] fix typos and some coding style in comments (Jarod Wilson) [1776606]
- [netdrv] ath10k: work around uninitialized vht_pfr variable (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: add support for qu c-step devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add new cards for 9000 and 20000 series (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: clear rfkill_safe_init_done when we start the firmware (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: don't WARN when calling iwl_get_shared_mem_conf with RF-Kill (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: don't service an interrupt that was masked (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix RF-Kill interrupt while FW load for gen2 devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix ALIVE interrupt handling for gen2 devices w/o MSI-X (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: delay GTK setting in FW in AP mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove MAC_FILTER_IN_11AX for AP mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: debug recording stop and restart command remove (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: don't stop dbg recording before entering D3 from 9000 devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix debug monitor stop and restart in ini mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: make the usage of TWT configurable (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: support FSEQ TLV even when FMAC is not compiled (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: move trans debug fields to a separate struct (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove redundant checking of ini mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: enforce apply point early on buffer allocation tlv (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: fix debug monitor stop and restart delays (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: increase the size of PCI dumps (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Drop large non sta frames (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Add log information about SAR status (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: Add support for SAR South Korea limitation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix module init error paths (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: convert to FW AC when configuring MU EDCA (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: correctly fill the ac array in the iwl_mac_ctx_cmd (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove some unnecessary NULL checks (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: d3: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: lib: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw api: support adwell HB default APs number api (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove multiple debugfs entries (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: implement dump info collection (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a debugfs entry to set a fixed size AMSDU for all TX packets (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: support debug info TLV (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use different barker for ini dump (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: add consecutive trigger firing support (Jarod Wilson) [1776606]
- [kernel] ieee80211: Add a missing extended capability flag definition (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: abort region collection in case the size is 0 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: update CSI API (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: dump headers cleanup (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: allow dump collection in case of an early error (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: iwl_mvm_tx_mpdu() must be called with BH disabled (Jarod Wilson) [1776606]
- [netdrv] ath10k: pci: remove unnecessary casts (Jarod Wilson) [1776606]
- [netdrv] ath10k: remove unnecessary 'out of memory' message (Jarod Wilson) [1776606]
- [netdrv] ath10k: destroy sdio workqueue while remove sdio module (Jarod Wilson) [1776606]
- [netdrv] ath10k: Move non-fatal warn logs to dbg level for SDIO chip (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix memory leak in qmi (Jarod Wilson) [1776606]
- [netdrv] ath10k: add new hw_ops for sdio chip (Jarod Wilson) [1776606]
- [netdrv] ath9k: correctly handle short radar pulses (Jarod Wilson) [1776606]
- [netdrv] rtw88: refine flow to get tx power index (Jarod Wilson) [1776606]
- [netdrv] rtw88: remove all RTW_MAX_POWER_INDEX macro (Jarod Wilson) [1776606]
- [netdrv] rtw88: update tx power limit table to RF v20 (Jarod Wilson) [1776606]
- [netdrv] rtw88: correct power limit selection (Jarod Wilson) [1776606]
- [netdrv] rtw88: choose the lowest as world-wide power limit (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix incorrect tx power limit at 5G (Jarod Wilson) [1776606]
- [netdrv] rtw88: remove unused variable (Jarod Wilson) [1776606]
- [netdrv] rtw88: unify prefixes for tx power setting routine (Jarod Wilson) [1776606]
- [netdrv] rtw88: do not use (void *) as argument (Jarod Wilson) [1776606]
- [netdrv] rtw88: resolve order of tx power setting routines (Jarod Wilson) [1776606]
- [netdrv] ath: fix SPDX tags (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add WMI diag fw logging support for WCN3990 (Jarod Wilson) [1776606]
- [netdrv] ath10k: add report MIC error for sdio chip (Jarod Wilson) [1776606]
- [netdrv] ath10k: add support for controlling tx power to a station (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add peer delete response event (Jarod Wilson) [1776606]
- [netdrv] ath10k: wait for vdev delete response from firmware (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix PCIE device wake up failed (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix failure to set multiple fixed rate (Jarod Wilson) [1776606]
- [netdrv] ath10k: Change the warning message string (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix fw crash by moving chip reset after napi disabled (Jarod Wilson) [1776606]
- [netdrv] ath10k: add missing error handling (Jarod Wilson) [1776606]
- [netdrv] ath10k: enabling tx stats support over pktlog (Jarod Wilson) [1776606]
- [netdrv] ath10k: acquire lock to fix lockdep's warning (Jarod Wilson) [1776606]
- [netdrv] ath10k: change firmware file name for UTF mode of SDIO/USB (Jarod Wilson) [1776606]
- [netdrv] ath10k: add support for firmware crash recovery on SDIO chip (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add wrapper function to ath10k debug (Jarod Wilson) [1776606]
- [netdrv] ath10k: add htt_h2t_aggr_cfg_msg op for high latency devices (Jarod Wilson) [1776606]
- [netdrv] ath10k: add inline wrapper for htt_h2t_aggr_cfg_msg (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix sparse warnings: warning: incorrect type in assignment (different base types) (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix sparse warnings: warning: cast from restricted __le16 (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix sparse warnings: incorrect type in assignment (different base types) (Jarod Wilson) [1776606]
- [netdrv] mt76: move nl80211_dfs_regions in mt76_dev data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove cfg80211_chan_def from mt7615_set_channel signature (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: update peer's bssid when state transition occurs (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix incorrect settings in mesh mode (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: take into account extPA when configuring tx power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: init per-channel target power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add support for per-chain signal strength reporting (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: simplify mt7615_mcu_set_sta_rec routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: improve hardware rate switching configuration (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: rework and fix tx status reporting (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove key check in mt7615_mcu_set_wtbl_key (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove unused variable in mt7615_mcu_set_bcn (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix slow performance when enable encryption (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: enable support for mesh (Jarod Wilson) [1776606]
- [netdrv] mt76: Remove set but not used variables 'pid' and 'final_mpdu' (Jarod Wilson) [1776606]
- [netdrv] mt76: move mt76_get_rate in mt76-module (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: rearrange locking in mt7615_config (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: init get_txpower mac80211 callback (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add the capability to configure tx power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: select wifi band according to eeprom (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add support for mtd eeprom parsing (Jarod Wilson) [1776606]
- [netdrv] mt76: move mt76_insert_ccmp_hdr in mt76-module (Jarod Wilson) [1776606]
- [netdrv] mt76: fix setting chan->max_power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix reading target tx power from eeprom (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: do not process rx packets if the device is not initialized (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: add debugfs knob to enable/disable edcca (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add static qualifier to mt7615_rx_poll_complete (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: rearrange cleanup operations in mt7615_unregister_device (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: stop mac80211 queues before setting the channel (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: run __mt76_mcu_send_msg in mt7615_mcu_send_firmware (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: init mcu_restart function pointer (Jarod Wilson) [1776606]
- [netdrv] mt7615: initialize mt76_mcu_ops data structure (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: use standard signature for mt7615_mcu_msg_send (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove unused structure in mcu.h (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: do not use function pointers whenever possible (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: unify __mt7615_mcu_set_dev_info and mt7615_mcu_set_dev_info (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove skb_ret from mt7615_mcu_msg_send (Jarod Wilson) [1776606]
- [netdrv] mt7615: remove dest from mt7615_mcu_msg_send signature (Jarod Wilson) [1776606]
- [netdrv] mt7615: remove query from mt7615_mcu_msg_send signature (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove unused parameter in mt7615_mcu_del_wtbl (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: unify mt7615_mcu_add_wtbl_bmc and mt7615_mcu_del_wtbl_bmc (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: use proper msg size in mt7615_mcu_add_wtbl (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: use proper msg size in mt7615_mcu_add_wtbl_bmc (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove bss_info_convert_vif_type routine (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: simplify __mt7615_mcu_set_sta_rec (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: simplify __mt7615_mcu_set_wtbl (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: Make mt7615_irq_handler static (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: Use after free in mt7615_mcu_set_bcn() (Jarod Wilson) [1776606]
- [netdrv] mt76: Fix a signedness bug in mt7615_add_interface() (Jarod Wilson) [1776606]
- [netdrv] mt76: move netif_napi_del in mt76_dma_cleanup (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: use napi polling for tx cleanup (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use napi polling for tx cleanup (Jarod Wilson) [1776606]
- [netdrv] wireless/mediatek: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: dynamically alloc mcu req in mt7603_mcu_set_eeprom (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: enable/disable pre_tbtt_tasklet in mt7603_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: move pre_tbtt_tasklet in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: move beacon_mask in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: move beacon_int in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: report firmware version using ethtool (Jarod Wilson) [1776606]
- [netdrv] mt76: fix endianness sparse warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: use sizeof instead of sizeof_field (Jarod Wilson) [1776606]
- [netdrv] mt76: add mac80211 driver for MT7615 PCIe-based chipsets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: run __mt76_mcu_send_msg in mt7603_mcu_send_firmware (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: init mcu_restart function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: initialize mt76_mcu_ops data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use standard signature for mt7603_mcu_msg_send (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: remove query from mt7603_mcu_msg_send signature (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix initialization of max rx length (Jarod Wilson) [1776606]
- [netdrv] mt76: use macro for sn and seq_ctrl conversion (Jarod Wilson) [1776606]
- [netdrv] mt76: add skb pointer to mt76_tx_info (Jarod Wilson) [1776606]
- [netdrv] mt76: move mac_work in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: only schedule txqs from the tx tasklet (Jarod Wilson) [1776606]
- [netdrv] mt76: move tx tasklet to struct mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: store wcid tx rate info in one u32 reduce locking (Jarod Wilson) [1776606]
- [netdrv] mt76: use readl/writel instead of ioread32/iowrite32 (Jarod Wilson) [1776606]
- [netdrv] mt76: fix tx power issues (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_free_device routine (Jarod Wilson) [1776606]
- [netdrv] mt76: unify set_tim (Jarod Wilson) [1776606]
- [netdrv] mt7603: core: do not use magic numbers in mt7603_reg_map (Jarod Wilson) [1776606]
- [netdrv] mt7603: remove mt7603_mcu_init routine (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: add static qualifier to mt76_dma_tx_queue_skb (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_tx_info data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_sw_queue data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: remove mt76_queue dependency from tx_complete_skb function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: remove mt76_queue dependency from tx_prepare_skb function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: remove mt76_queue dependency from tx_queue_skb function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: move mt76x02_init_{tx, rx}_queue in mt76 module (Jarod Wilson) [1776606]
- [netdrv] mt76: mmio: move mt76x02_set_irq_mask in mt76 module (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: send BAR after powersave wakeup (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix sequence number assignment (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: add missing initialization for dev->ps_lock (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use the correct hweight8() function (Jarod Wilson) [1776606]
- [netdrv] mt76: fix return value check in mt76_wmac_probe() (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: set moredata flag when queueing ps-filtered packets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: clear the service period on releasing PS filtered packets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: notify mac80211 about buffered frames in ps queue (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix up hardware queue index for PS filtered packets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: clear ps filtering mode before releasing buffered frames (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix tx status HT rate validation (Jarod Wilson) [1776606]
- [netdrv] mt76: add driver for MT7603E and MT7628/7688 (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0u: do not reset radio on resume (Jarod Wilson) [1776606]
- [netdrv] mt7601u: null check the allocation (Jarod Wilson) [1776606]
- [netdrv] mt7601u: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: usb: fix rx A-MSDU support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76u: get rid of {out,in}_max_packet (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76u: reduce rx memory footprint (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02u: fix sparse warnings: should it be static? (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0: fix RF frontend initialization for external PA (Jarod Wilson) [1776606]
- [netdrv] mt76: generalize mt76_get_txpower for 4x4:4 devices (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix tx reordering on rate control probing without a-mpdu (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix tx status reporting issues (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix edcca file permission (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: run mt76x02_edcca_init atomically in mt76_edcca_set (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x2: move mutex_lock inside mt76x2_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x2u: remove mt76x02_edcca_init in mt76x2u_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: remove enable from mt76x02_edcca_init signature (Jarod Wilson) [1776606]
- [netdrv] mt76: move tx_napi in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: remove useless return in mt76x02_resync_beacon_timer (Jarod Wilson) [1776606]
- [netdrv] mt7601u: fix possible memory leak when the device is disconnected (Jarod Wilson) [1776606]
- [netdrv] mt7601u: do not schedule rx_tasklet when the device has been disconnected (Jarod Wilson) [1776606]
- [netdrv] mwifiex: don't disable hardirqs; just softirqs (Jarod Wilson) [1776606]
- [netdrv] mwifiex: dispatch/rotate from reorder table atomically (Jarod Wilson) [1776606]
- [netdrv] mwifiex: ignore processing invalid command response (Jarod Wilson) [1776606]
- [netdrv] mwifiex: update set_mac_address logic (Jarod Wilson) [1776606]
- [netdrv] mwifiex: print PCI mmap with pK (Jarod Wilson) [1776606]
- [netdrv] mwifiex: drop 'set_consistent_dma_mask' log message (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add support for hr1 RF ID (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: change 0x02F0 fw from qu to quz (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add new cards for 22000 and change wrong structs (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add new cards for 22000 and fix struct name (Jarod Wilson) [1776606]
- [net] mac80211: notify offchannel expire on mgmt_tx (Jarod Wilson) [1776606]
- [net] nl80211: send event when CMD_FRAME duration expires (Jarod Wilson) [1776606]
- [net] mac80211: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [net] mac80211: extend __rate_control_send_low warning (Jarod Wilson) [1776606]
- [net] mac80211: fill low rate even for HAS_RATE_CONTROL (Jarod Wilson) [1776606]
- [net] mac80211: use STA info in rate_control_send_low() (Jarod Wilson) [1776606]
- [net] mac80211: call rate_control_send_low() internally (Jarod Wilson) [1776606]
- [net] cfg80211: Add a function to iterate all BSS entries (Jarod Wilson) [1776606]
- [net] mac80211: allow turning TWT responder support on and off via netlink (Jarod Wilson) [1776606]
- [net] mac80211: dynamically enable the TWT requester support on STA interfaces (Jarod Wilson) [1776606]
- [net] mac80211: add ieee80211_get_he_iftype_cap() helper (Jarod Wilson) [1776606]
- [uapi] nl80211: add support for SAE authentication offload (Jarod Wilson) [1776606]
- [net] nl80211: add WPA3 definition for SAE authentication (Jarod Wilson) [1776606]
- [net] nl80211: add NL80211_ATTR_IFINDEX to port authorized event (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: remove redundant assignment to rtstatus (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove redundant assignment to variable k (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove redundant assignment to variable badworden (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: fix error handle when usb probe failed (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: btcoex: remove unused function exhalbtc_stack_operation_notify (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: btcoex: Remove set but not used variable 'len' and 'asso_type_v2' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Remove set but not used variables 'cur_txokcnt' and 'b_last_is_cur_rdl_state' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Remove unused GET_XXX and SET_XXX descriptor macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: use le32 to access cckswing tables (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: Fix used uninitialized variables in power tracking (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: make tables to be 'static const' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: Reduce indentation and fix coding style (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix typo rtw_writ16_set (Jarod Wilson) [1776606]
- [netdrv] rtw88: rsvd page should go though management queue (Jarod Wilson) [1776606]
- [netdrv] rtw88: restore DACK results to save time (Jarod Wilson) [1776606]
- [netdrv] rtw88: power on again if it was already on (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: use more accurate ofdm fa counting (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: disable rx clock gating before counter reset (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: update channel and bandwidth BB setting (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: add rf write protection when switching channel (Jarod Wilson) [1776606]
- [netdrv] rtw88: add beacon function setting (Jarod Wilson) [1776606]
- [netdrv] rtw88: add support for random mac scan (Jarod Wilson) [1776606]
- [netdrv] rtw88: add fast xmit support (Jarod Wilson) [1776606]
- [netdrv] rtw88: more descriptions about LPS (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: check if queue mapping exceeds size of ac_to_hwq (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: use ieee80211_ac_numbers instead of 0-3 (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: use strlcpy() instead of strcpy() (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: fix typos in code comments (Jarod Wilson) [1776606]
- [netdrv] brcm80211: select WANT_DEV_COREDUMP conditionally for brcmfmac (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: use separate Kconfig file for brcmfmac (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: switch source files to using SPDX license identifier (Jarod Wilson) [1776606]
- [netdrv] brcmsmac: switch phy source files to using SPDX license identifier (Jarod Wilson) [1776606]
- [netdrv] brcmutil: switch source files to using SPDX license identifier (Jarod Wilson) [1776606]
- [netdrv] brcm80211: switch common header files to using SPDX license identifier (Jarod Wilson) [1776606]
- [net] cfg80211: Handle bss expiry during connection (Jarod Wilson) [1776606]
- [netdrv] ath10k: Check tx_stats before use it (Jarod Wilson) [1776606]
- [netdrv] ath10k: add peer id check in ath10k_peer_find_by_id (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add wmi tlv service map for mesh 11s (Jarod Wilson) [1776606]
- [netdrv] ath10k: Do not send probe response template for mesh (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add wmi tlv vdev subtype for mesh in WCN3990 (Jarod Wilson) [1776606]
- [netdrv] ath10k: change swap mail box config for UTF mode of SDIO (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix the wrong value of enums for wmi tlv stats id (Jarod Wilson) [1776606]
- [netdrv] ath10k: coredump: use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath10k: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix encoding for protected management frames (Jarod Wilson) [1776606]
- [netdrv] ath10k: rx_duration update for fw_stats debugfs entry (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix the tx stats bytes & packets parsing (Jarod Wilson) [1776606]
- [netdrv] ath10k: Modify CE4 src buffer entries to 2048 for WCN3990 (Jarod Wilson) [1776606]
- [netdrv] ath10k: Move board id and fw version logging to info level (Jarod Wilson) [1776606]
- [netdrv] ath10k: Added support to reset HTT stats in debugfs (Jarod Wilson) [1776606]
- [netdrv] ath10k: Extended the HTT stats support to retrieve Mu-MIMO related stats (Jarod Wilson) [1776606]
- [netdrv] ath: DFS JP domain W56 fixed pulse type 3 RADAR detection (Jarod Wilson) [1776606]
- [netdrv] ath9k: drop redundant code in ar9003_hw_set_channel (Jarod Wilson) [1776606]
- [netdrv] ath: drop duplicated define (Jarod Wilson) [1776606]
- [netdrv] ath9k: Remove some set but not used variables (Jarod Wilson) [1776606]
- [netdrv] ath9k: Differentiate between max combined and per chain power (Jarod Wilson) [1776606]
- [netdrv] ath9k: Check for errors when reading SREV register (Jarod Wilson) [1776606]
- [netdrv] ath9k: Don't trust TX status TID number when reporting airtime (Jarod Wilson) [1776606]
- [netdrv] ath6kl: remove redundant check of status != 0 (Jarod Wilson) [1776606]
- [netdrv] ath6kl: add some bounds checking (Jarod Wilson) [1776606]
- [netdrv] ath6kl: wmi: use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath6kl: debug: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix incorrect multicast/broadcast rate setting (Jarod Wilson) [1776606]
- [netdrv] ath10k: enable QCA6174 hw3.2 SDIO hardware (Jarod Wilson) [1776606]
- [netdrv] ath10k: add fragmentation handler for high latency devices (Jarod Wilson) [1776606]
- [netdrv] ath10k: add PN replay protection for high latency devices (Jarod Wilson) [1776606]
- [netdrv] ath10k: add handler for HTT_T2H_MSG_TYPE_SEC_IND event (Jarod Wilson) [1776606]
- [netdrv] ath10k: add struct for high latency PN replay protection (Jarod Wilson) [1776606]
- [netdrv] ath10k: sdio: add missing error check (Jarod Wilson) [1776606]
- [netdrv] ath10k: add initialization of HTC header (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix use-after-free on SDIO data frames (Jarod Wilson) [1776606]
- [netdrv] ath10k: htt: support MSDU ids with SDIO (Jarod Wilson) [1776606]
- [netdrv] ath10k: initialise struct ath10k_bus params to zero (Jarod Wilson) [1776606]
- [netdrv] ath10k: htt: don't use txdone_fifo with SDIO (Jarod Wilson) [1776606]
- [netdrv] ath10k: don't disable interrupts in ath10k_sdio_remove() (Jarod Wilson) [1776606]
- [netdrv] ath10k: sdio: workaround firmware UART pin configuration bug (Jarod Wilson) [1776606]
- [net] cfg80211: Add airtime statistics and settings (Jarod Wilson) [1776606]
- [base] depend on HAS_IOMEM for devm_platform_ioremap_resource() (Jarod Wilson) [1776606]
- [base] provide devm_platform_ioremap_resource() (Jarod Wilson) [1776606]
- [lib] crypto: arc4 - refactor arc4 core code into separate library (Jarod Wilson) [1776606]
- [crypto] export arc4 defines (Jarod Wilson) [1776606]
- [crypto] arc4 - convert to skcipher API (Jarod Wilson) [1776606]
- [kernel] bitfield: add u8 helpers (Jarod Wilson) [1776606]

* Thu Dec 12 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-165.el8]
- [md] raid5: need to set STRIPE_HANDLE for batch head (Nigel Croxon) [1774840]
- [scsi] lpfc: remove left-over BUILD_NVME defines (Ewan Milne) [1782235]
- [block] fix memleak of bio integrity data (Ming Lei) [1779898]
- [fs] xfs: attach dquots and reserve quota blocks during unwritten conversion (Carlos Maiolino) [1782094]
- [nvme] nvme-fc: fix double-free scenarios on hw queues (Ewan Milne) [1781390]
- [tools] power turbostat: Add Cometlake support (David Arcari) [1759661]
- [mm] hugetlbfs: take read_lock on i_mmap for PMD sharing (Waiman Long) [1731295]
- [documentation] powerpc/pseries: Add documentation for vcpudispatch_stats (Gustavo Duarte) [1723870]
- [powerpc] pseries: Protect against hogging the cpu while setting up the stats (Gustavo Duarte) [1723870]
- [powerpc] pseries: Provide vcpu dispatch statistics (Gustavo Duarte) [1723870]
- [powerpc] pseries: Move mm/book3s64/vphn.c under platforms/pseries/ (Gustavo Duarte) [1723870]
- [powerpc] pseries: Generalize hcall_vphn() (Gustavo Duarte) [1723870]
- [powerpc] mm: Move book3s64 specifics in subdirectory mm/book3s64 (Gustavo Duarte) [1723870]
- [powerpc] pseries: Introduce rwlock to gatekeep DTLB usage (Gustavo Duarte) [1723870]
- [powerpc] pseries: Factor out DTL buffer allocation and registration routines (Gustavo Duarte) [1723870]
- [powerpc] pseries: Do not save the previous DTL mask value (Gustavo Duarte) [1723870]
- [powerpc] pseries: Use macros for referring to the DTL enable mask (Gustavo Duarte) [1723870]
- [powerpc] mm: change #include "mmu_decl.h" to <mm/mmu_decl.h> (Gustavo Duarte) [1723870]
- [fs] devpts_pty_kill(): don't bother with d_delete() (Eric Sandeen) [1772718]
- [fs] devpts: always delete dcache dentry-s in dput() (Eric Sandeen) [1772718]
- [infiniband] rdma/siw: Fix post_recv QP state locking (Kamal Heib) [1779625]
- [infiniband] rdma/siw: Fix SQ/RQ drain logic (Kamal Heib) [1779625]
- [infiniband] rdma/siw: Relax from kmap_atomic() use in TX path (Kamal Heib) [1779625]
- [netdrv] nfp: flower: cmsg rtnl locks can timeout reify messages (Pablo Cascon) [1729154]
- [netdrv] nfp: Drop unnecessary continue in nfp_net_pf_alloc_vnics (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: handle neighbour events on internal ports (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: prevent ingress block binds on internal ports (Pablo Cascon) [1729154]
- [netdrv] nfp: add AMDA0058 boards to firmware list (Pablo Cascon) [1729154]
- [netdrv] nfp: no need to check return value of debugfs_create functions (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: encode mac indexes with pre-tunnel rule check (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: remove offloaded MACs when reprs are applied to OvS bridges (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload pre-tunnel rules (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: verify pre-tunnel rules (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: detect potential pre-tunnel rules (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: push vlan after tunnel in merge (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload MPLS set action (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload MPLS pop action (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload MPLS push action (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: ensure ip protocol is specified for L4 matches (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: fix ethernet check on match fields (Pablo Cascon) [1729154]
- [netdrv] nfp: ccm: increase message limits (Pablo Cascon) [1729154]
- [netdrv] nfp: Use spinlock_t instead of struct spinlock (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: add GRE encap action support (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: add GRE decap classification support (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: rename tunnel related functions in action offload (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: add helper functions for tunnel classification (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: refactor tunnel key layer calculation (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: extend extack messaging for flower match and actions (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: use extack messages in flower offload (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: check L4 matches on unknown IP protocols (Pablo Cascon) [1729154]
- [netdrv] nfp: print a warning when binding VFs to PF driver (Pablo Cascon) [1729154]
- [netdrv] nfp: update the old flash error message (Pablo Cascon) [1729154]
- [netdrv] nfp: prepare for more TX metadata prepend (Pablo Cascon) [1729154]
- [netdrv] nfp: add tls init code (Pablo Cascon) [1729154]
- [netdrv] nfp: parse crypto opcode TLV (Pablo Cascon) [1729154]
- [netdrv] nfp: add support for sending control messages via mailbox (Pablo Cascon) [1729154]
- [netdrv] nfp: parse the mailbox cmsg TLV (Pablo Cascon) [1729154]
- [netdrv] nfp: make bar_lock a semaphore (Pablo Cascon) [1729154]
- [netdrv] nfp: count all failed TX attempts as errors (Pablo Cascon) [1729154]
- [netdrv] nfp: ensure skb network header is set for packet redirect (Pablo Cascon) [1728773]
- [netdrv] nfp: reintroduce ndo_get_port_parent_id for representor ports (Pablo Cascon) [1728773]
- [netdrv] nfp: implement PCI driver shutdown callback (Pablo Cascon) [1728773]
- [netdrv] nfp: add SR-IOV trusted VF support (Pablo Cascon) [1728773]
- [netdrv] nfp: split out common control message handling code (Pablo Cascon) [1728773]
- [netdrv] nfp: move vNIC reset before netdev init (Pablo Cascon) [1728773]
- [netdrv] nfp: add a mutex lock for the vNIC ctrl BAR (Pablo Cascon) [1728773]
- [netdrv] nfp: opportunistically poll for reconfig result (Pablo Cascon) [1728773]
- [netdrv] nfp: remove ndo_get_port_parent_id implementation (Pablo Cascon) [1728773]
- [netdrv] nfp: pass switch ID through devlink_port_attrs_set() (Pablo Cascon) [1728773]
- [netdrv] nfp: implement ethtool get module EEPROM (Pablo Cascon) [1728773]
- [netdrv] nfp: nsp: implement read SFF module EEPROM (Pablo Cascon) [1728773]
- [netdrv] nfp: do not handle nn->port defined case in nfp_net_get_phys_port_name() (Pablo Cascon) [1728773]
- [netdrv] nfp: register devlink port before netdev (Pablo Cascon) [1728773]
- [netdrv] nfp: remove defines for unused control bits (Pablo Cascon) [1728773]
- [netdrv] replace ndo_get_devlink with ndo_get_devlink_port (Pablo Cascon) [1728773]
- [netdrv] nfp: add .ndo_get_devlink (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: add rcu locks when accessing netdev for tunnels (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: add qos offload stats request and reply (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: fix size_t compile warning (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: fix implicit fallthrough warning (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: offload merge flows (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: support stats update for merge flows (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: generate merge flow rule (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: validate merge hint flows (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: handle merge hint messages (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: get flows by host context (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: allow tunnels to output to internal port (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: support fallback packets from internal ports (Pablo Cascon) [1728773]
- [netdrv] nfp: allow fallback packets from non-reprs (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: allow offloading of matches on 'internal' ports (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: turn on recirc and merge hint support in firmware (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: reduce action list size by coalescing mangle actions (Pablo Cascon) [1728773]
- [fs] xfs: properly serialise fallocate against AIO+DIO (Eric Sandeen) [1765547]
- [fs] xfs: fix attr leaf header freemap.size underflow (Brian Foster) [1728989]
- [mm] maintain randomization of page free lists (Rafael Aquini) [1620349]
- [mm] move buddy list manipulations into helpers (Rafael Aquini) [1620349]
- [mm] shuffle initial free memory to improve memory-side-cache utilization (Rafael Aquini) [1620349]
- [powerpc] kvm: ppc: book3s hv: Flush link stack on guest exit to host kernel (Gustavo Duarte) [1777686]
- [powerpc] book3s64: Fix link stack flush on context switch (Gustavo Duarte) [1777686]
- [powerpc] 64s: support nospectre_v2 cmdline option (Gustavo Duarte) [1777686]
- [powerpc] fsl: Update Spectre v2 reporting (Gustavo Duarte) [1777686]
- [powerpc] fsl: Add nospectre_v2 command line argument (Gustavo Duarte) [1777686]
- [powerpc] fsl: Fix spectre_v2 mitigations reporting (Gustavo Duarte) [1777686]
- [powerpc] 64: Make meltdown reporting Book3S 64 specific (Gustavo Duarte) [1777686]
- [powerpc] 64: Disable the speculation barrier from the command line (Gustavo Duarte) [1777686]
- [x86] kprobes: Avoid kretprobe recursion bug (Jiri Olsa) [1779235]
- [x86] kprobes: Verify stack frame on kretprobe (Jiri Olsa) [1779235]

* Wed Dec 11 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-164.el8]
- [fs] iomap: Fix pipe page leakage during splicing (Andreas Grunbacher) [1622634]
- [fs] iomap: fix return value of iomap_dio_bio_actor on 32bit systems (Andreas Grunbacher) [1622634]
- [fs] iomap: iomap_bmap should check iomap_apply return value (Andreas Grunbacher) [1622634]
- [fs] iomap: Fix overflow in iomap_page_mkwrite (Andreas Grunbacher) [1622634]
- [fs] splice: only read in as much information as there is pipe buffer space (Andreas Grunbacher) [1622634]
- [fs] gfs2: Always mark inode dirty in fallocate (Andreas Grunbacher) [1622634]
- [fs] dax: Fix pmd vs pte conflict detection (Jeff Moyer) [1777250]
- [fs] xfs: move local to extent inode logging into bmap helper (Brian Foster) [1737677]
- [fs] xfs: remove broken error handling on failed attr sf to leaf change (Brian Foster) [1737677]
- [fs] xfs: log the inode on directory sf to block format change (Brian Foster) [1737677]
- [block] bfq: deschedule empty bfq_queues not referred by any process (Ming Lei) [1773831]
- [scsi] revert "scsi: qla2xxx: Fix memory leak when sending I/O fails" (Himanshu Madhani) [1759275]
- [infiniband] rdma/iw_cxgb4: Report correct port speed/width (Vishal Kulkarni) [1757806]
- [infiniband] rdma/iw_cxgb4: fix SRQ access from dump_qp() (Vishal Kulkarni) [1779997]
- [net] nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds (Vladis Dronov) [1778898]
- [atm] iphase: Fix Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [x86] tls: Fix possible spectre-v1 in do_get_thread_area() (Vladis Dronov) [1778898]
- [x86] ptrace: Fix possible spectre-v1 in ptrace_get_debugreg() (Vladis Dronov) [1778898]
- [net] atm: Fix potential Spectre v1 vulnerabilities (Vladis Dronov) [1778898]
- [powerpc] ptrace: Mitigate potential Spectre v1 (Vladis Dronov) [1778898]
- [char] applicom: Fix potential Spectre v1 vulnerabilities (Vladis Dronov) [1778898]
- [char] mwave: fix potential Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [misc] misc/sgi-gru: fix Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [usb] gadget: storage: Fix Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [misc] hmc6352: fix potential Spectre v1 (Vladis Dronov) [1778898]
- [s390] qeth: ensure linear access to packet headers (Philipp Rudo) [1781085]
- [s390] qeth: guard against runt packets (Philipp Rudo) [1781085]
- [s390] qeth: handle skb allocation error gracefully (Philipp Rudo) [1781085]
- [s390] qeth: drop unwanted packets earlier in RX path (Philipp Rudo) [1781085]
- [s390] qeth: support per-frame invalidation (Philipp Rudo) [1781085]
- [s390] qeth: gather more detailed RX dropped/error statistics (Philipp Rudo) [1781085]
- [s390] Mark expected switch fall-throughs (Philipp Rudo) [1781085]
- [sched] fair: Scale bandwidth quota and period without losing quota/period ratio precision (Phil Auld) [1706247]
- [sched] fair: Fix -Wunused-but-set-variable warnings (Phil Auld) [1706247]
- [sched] fair: Fix low cpu usage with high throttling by removing expiration of cpu-local slices (Phil Auld) [1706247]
- [kernel] sched/core: Remove double update_max_interval() call on CPU startup (Phil Auld) [1757535]
- [kernel] sched/core: Fix migration to invalid CPU in __set_cpus_allowed_ptr() (Phil Auld) [1757535]
- [kernel] sched/fair: Don't assign runtime for throttled cfs_rq (Phil Auld) [1757535]
- [kernel] cpufreq: schedutil: Don't skip freq update when limits change (Phil Auld) [1757535]
- [kernel] sched/deadline: Fix double accounting of rq/running bw in push & pull (Phil Auld) [1757535]
- [kernel] sched/fair: Fix imbalance due to CPU affinity (Phil Auld) [1757535]
- [kernel] sched/fair: Use RCU accessors consistently for ->numa_group (Phil Auld) [1757535]
- [kernel] sched/fair: Don't free p->numa_faults with concurrent readers (Phil Auld) [1757535]
- [kernel] sched/fair: Rename weighted_cpuload() to cpu_runnable_load() (Phil Auld) [1757535]
- [kernel] sched/topology: Remove unused 'sd' parameter from arch_scale_cpu_capacity() (Phil Auld) [1757535]
- [kernel] sched/fair: Don't push cfs_bandwith slack timers forward (Phil Auld) [1757535]
- [documentation] sched/fair: Fix "runnable_avg_yN_inv" not used warnings (Phil Auld) [1757535]
- [kernel] sched/fair: Clean up definition of NOHZ blocked load functions (Phil Auld) [1757535]
- [kernel] sched/core: Add __sched tag for io_schedule() (Phil Auld) [1757535]
- [kernel] sched/fair: Remove sgs->sum_weighted_load (Phil Auld) [1757535]
- [kernel] sched/core: Remove sd->*_idx (Phil Auld) [1757535]
- [kernel] sched/core: Remove rq->cpu_load[] (Phil Auld) [1757535]
- [kernel] sched/debug: Remove sd->*_idx range on sysctl (Phil Auld) [1757535]
- [kernel] sched/fair: Replace source_load() & target_load() with weighted_cpuload() (Phil Auld) [1757535]
- [kernel] sched/fair: Remove the rq->cpu_load[] update code (Phil Auld) [1757535]
- [kernel] sched/fair: Remove rq->load (Phil Auld) [1757535]
- [kernel] sched/core: Unify p->on_rq updates (Phil Auld) [1757535]
- [kernel] sched/core: Remove ttwu_activate() (Phil Auld) [1757535]
- [kernel] sched/cpufreq: Fix 32-bit math overflow (Phil Auld) [1757535]
- [kernel] sched/fair: Update scale invariance of PELT (Phil Auld) [1757535]
- [kernel] sched/pelt: Skip updating util_est when utilization is higher than CPU's capacity (Phil Auld) [1757535]
- [kernel] sched/fair: Move the rq_of() helper function (Phil Auld) [1757535]
- [kernel] sched/core: Use READ_ONCE()/WRITE_ONCE() in move_queued_task()/task_rq_lock() (Phil Auld) [1757535]
- [kernel] sched/numa: Remove unused numa_stats::nr_running field (Phil Auld) [1757535]
- [kernel] sched/fair: Add lsub_positive() and use it consistently (Phil Auld) [1706247 1757535]
- [kernel] sched/fair: Mask UTIL_AVG_UNCHANGED usages (Phil Auld) [1706247 1757535]
- [cpuidle] teo: Avoid using "early hits" incorrectly (Al Stone) [1725618]
- [cpuidle] teo: Fix "early hits" handling for disabled idle states (Al Stone) [1725618]
- [cpuidle] teo: Consider hits and misses metrics of disabled states (Al Stone) [1725618]
- [cpuidle] teo: Rename local variable in teo_select() (Al Stone) [1725618]
- [cpuidle] teo: Ignore disabled idle states that are too deep (Al Stone) [1725618]
- [cpuidle] teo: Get rid of redundant check in teo_update() (Al Stone) [1725618]
- [cpuidle] teo: Allow tick to be stopped if PM QoS is used (Al Stone) [1725618]
- [cpuidle] governors: unify last_state_idx (Al Stone) [1725618]
- [powerpc] powernv/cpuidle: Fix idle states all being marked invalid (Al Stone) [1725618]
- [cpuidle] menu: Avoid overflows when computing variance (Al Stone) [1725618]
- [cpuidle] dt: bail out if the idle-state DT node is not compatible (Al Stone) [1725618]
- [kernel] cpuidle: use BIT() for idle state flags and remove CPUIDLE_DRIVER_FLAGS_MASK (Al Stone) [1725618]
- [cpuidle] New timer events oriented governor for tickless systems (Al Stone) [1725618]
- [cpuidle] Add 'above' and 'below' idle state metrics (Al Stone) [1725618]
- [cpuidle] big.little: fix refcount leak (Al Stone) [1725618]
- [documentation] documentation: admin-guide: pm: Add cpuidle document (Al Stone) [1725618]
- [cpuidle] powerpc/pseries/cpuidle: Fix preempt warning (Al Stone) [1725618]
- [cpuidle] arm: cpuidle: Convert to use cpuidle_register|unregister() (Al Stone) [1725618]
- [cpuidle] arm: cpuidle: Don't register the driver when back-end init returns -ENXIO (Al Stone) [1725618]
- [cpuidle] menu: Remove get_loadavg() from the performance multiplier (Al Stone) [1725618]
- [kernel] sched: Factor out nr_iowait and nr_iowait_cpu (Al Stone) [1725618]
- [kernel] sched/core: Fix comment regarding nr_iowait_cpu() and get_iowait_load() (Al Stone) [1725618]
- [cpuidle] menu: Avoid computations when result will be discarded (Al Stone) [1725618]
- [cpuidle] menu: Drop redundant comparison (Al Stone) [1725618]
- [cpuidle] menu: Simplify checks related to the polling state (Al Stone) [1725618]
- [cpuidle] menu: Move the latency_req == 0 special case check (Al Stone) [1725618]
- [cpuidle] menu: Avoid computations for very close timers (Al Stone) [1725618]
- [cpuidle] menu: Do not update last_state_idx in menu_select() (Al Stone) [1725618]
- [cpuidle] menu: Get rid of first_idx from menu_select() (Al Stone) [1725618]
- [cpuidle] menu: Compute first_idx when latency_req is known (Al Stone) [1725618]
- [cpuidle] menu: Replace data->predicted_us with local variable (Al Stone) [1725618]
- [cpuidle] enter_state: Don't needlessly calculate diff time (Al Stone) [1725618]
- [kernel] cpuidle: Remove unnecessary wrapper cpuidle_get_last_residency() (Al Stone) [1725618]
- [cpuidle] menu: Update stale polling override comment (Al Stone) [1725618]
- [cpuidle] menu: Fix white space (Al Stone) [1725618]
- [cpuidle] powernv/cpuidle: Use parsed device tree values for cpuidle_init (Al Stone) [1725618]
- [powerpc] powernv/cpuidle: Parse dt idle properties into global structure (Al Stone) [1725618]
- [cpuidle] arm: cpuidle: silence error on driver registration failure (Al Stone) [1725618]

* Tue Dec 10 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-163.el8]
- [documentation] docs: admin-guide: Remove threads-max auto-tuning (Joe Lawrence) [1771270]
- [documentation] docs: admin-guide: Fix min value of threads-max in kernel.rst (Joe Lawrence) [1771270]
- [kernel] sysctl.c: do not override max_threads provided by userspace (Joe Lawrence) [1771270]
- [fs] ext4: fix integer overflow when calculating commit interval (Lukas Czerner) [1775166]
- [fs] ext4: fix punch hole for inline_data file systems (Lukas Czerner) [1775166]
- [fs] ext4: fix warning inside ext4_convert_unwritten_extents_endio (Lukas Czerner) [1775166]
- [fs] ext4: set error return correctly when ext4_htree_store_dirent fails (Lukas Czerner) [1775166]
- [fs] ext4: fix warning when turn on dioread_nolock and inline_data (Lukas Czerner) [1775166]
- [fs] ext4: use jbd2_inode dirty range scoping (Lukas Czerner) [1775166]
- [fs] jbd2: introduce jbd2_inode dirty range scoping (Lukas Czerner) [1775166]
- [mm] add filemap_fdatawait_range_keep_errors() (Lukas Czerner) [1775166]
- [fs] ext4: enforce the immutable flag on open files (Lukas Czerner) [1775166]
- [fs] ext4: don't allow any modifications to an immutable file (Lukas Czerner) [1775166]
- [fs] jbd2: fix typo in comment of journal_submit_inode_data_buffers (Lukas Czerner) [1775166]
- [fs] jbd2: fix some print format mistakes (Lukas Czerner) [1775166]
- [fs] ext4: do not delete unlinked inode from orphan list on failed truncate (Lukas Czerner) [1775166]
- [fs] ext4: wait for outstanding dio during truncate in nojournal mode (Lukas Czerner) [1775166]
- [fs] ext4: don't perform block validity checks on the journal inode (Lukas Czerner) [1775166]
- [fs] ext4: fix block validity checks for journal inodes using indirect blocks (Lukas Czerner) [1775166]
- [fs] ext4: fix miscellaneous sparse warnings (Lukas Czerner) [1775166]
- [fs] jbd2: fix potential double free (Lukas Czerner) [1775166]
- [fs] quota: fix condition for resetting time limit in do_set_dqblk() (Lukas Czerner) [1778119]
- [fs] quota: honor quota type in Q_XGETQSTAT[V] calls (Lukas Czerner) [1778119]
- [fs] quota: fix a problem about transfer quota (Lukas Czerner) [1778119]
- [fs] quota: add dqi_dirty_list description to comment of Dquot List Management (Lukas Czerner) [1778119]
- [fs] quota: check time limit when back out space/inode change (Lukas Czerner) [1778119]
- [fs] quota: fix wrong indentation (Lukas Czerner) [1778119]
- [fs] quota: remove trailing whitespaces (Lukas Czerner) [1778119]
- [fs] quota: code cleanup for __dquot_alloc_space() (Lukas Czerner) [1778119]
- [fs] quota: Lock s_umount in exclusive mode for Q_XQUOTA{ON, OFF} quotactls (Lukas Czerner) [1778119]
- [fs] quota: Replace XQM_MAXQUOTAS usage with MAXQUOTAS (Lukas Czerner) [1778119]
- [hv] vmbus: Fix harmless building warnings without CONFIG_PM_SLEEP (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Resume after fixing up old primary channels (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Suspend after cleaning up hv_sock and sub channels (Mohammed Gamal) [1774675]
- [kernel] hv: vmbus: Add a helper function is_sub_channel() (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Clean up hv_sock channels by force upon suspend (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Suspend/resume the vmbus itself for hibernation (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Ignore the offers when resuming from hibernation (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Implement suspend/resume for VSC drivers for hibernation (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Fix virt_to_hvpfn() for X86_PAE (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Remove the unused "tsc_page" from struct hv_context (Mohammed Gamal) [1774675]
- [hv] tools: hv: Use the correct style for SPDX License Identifier (Mohammed Gamal) [1774675]
- [hv] hv_balloon: Reorganize the probe function (Mohammed Gamal) [1774675]
- [hv] hv_balloon: Use a static page for the balloon_up send buffer (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Replace page definition with Hyper-V specific one (Mohammed Gamal) [1774675]
- [hv] hv: Add a module description line to the hv_vmbus driver (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Remove the undesired put_cpu_ptr() in hv_synic_cleanup() (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Fix race condition with new ring_buffer_info mutex (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Set ring_info field to 0 and remove memset (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Refactor chan->state if statement (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Expose monitor data only when monitor pages are used (Mohammed Gamal) [1774675]
- [netdrv] hv_netvsc: Fix error handling in netvsc_attach() (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Fix error handling in netvsc_set_features() (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Sync offloading features to VF NIC (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Allow scatter-gather feature to be tunable (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Fix a warning of suspicious RCU usage (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Fix extra rcu_read_unlock in netvsc_recv_callback() (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Set probe mode to sync (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: fix race that may miss tx queue wakeup (Mohammed Gamal) [1774687]
- [netdrv] nfp: bpf: fix latency bug when updating stack index register (Pablo Cascon) [1729156]
- [netdrv] nfp: bpf: eliminate zero extension code-gen (Pablo Cascon) [1729156]
- [netdrv] bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during suspend/resume (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during error recovery (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Improve bnxt_ulp_stop()/bnxt_ulp_start() call sequence (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: flow_offload: offload tunnel decap rules via indirect callbacks (Jonathan Toppins) [1773724]
- [netdrv] bnxt: Avoid logging an unnecessary message when a flow can't be offloaded (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Add support to collect crash dump via ethtool (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Add support to invoke OP-TEE API to reset firmware (Jonathan Toppins) [1773724]
- [netdrv] broadcom: bnxt: Fix use true/false for bool (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Avoid disabling pci device in bnxt_remove_one() for already disabled device (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Minor formatting changes in FW devlink_health_reporter (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Adjust the time to wait before polling firmware readiness (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Fix devlink NVRAM related byte order related issues (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Fix the size of devlink MSIX parameters (Jonathan Toppins) [1773724]
- [nvme] Fix parsing of ANA log page (Ewan Milne) [1769028]
- [nvme] nvme-multipath: fix ana log nsid lookup when nsid is not found (Ewan Milne) [1769028]
- [nvme] nvme-multipath: fix possible I/O hang when paths are updated (Ewan Milne) [1769028]
- [nvme] revert "nvme: update node paths after adding new path" (Ewan Milne) [1769028]
- [netdrv] mlx5: Update the list of the PCI supported devices (Mohammad Heib) [1776921]
- [netdrv] mlx5: Fix auto group size calculation (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Do not use non-EXT link modes in EXT mode (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix set vf link state error flow (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Limit STE hash table enlarge based on bytemask (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix invalid EQ vector number on CQ creation (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Skip rehash for tables with byte mask zero (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix error flow cleanup in mlx5e_tc_tun_create_header_ipv4/6 (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix matcher builders select check (Mohammad Heib) [1776921]
- [netdrv] mlx5: Read num_vfs before disabling SR-IOV (Mohammad Heib) [1776921]
- [netdrv] mlx5: Clear VF's configuration on disabling SRIOV (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix memory leak during rule creation (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix memory leak in modify action destroy (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix eswitch debug print of max fdb flow (Mohammad Heib) [1776921]
- [netdrv] mlx5: LAG, Use affinity type enumerators (Mohammad Heib) [1776921]
- [netdrv] mlx5: E-switch, Enable metadata on own vport (Mohammad Heib) [1776921]
- [netdrv] mlx5: Correct comment for legacy fields (Mohammad Heib) [1776921]
- [netdrv] mlx5: Fixed a typo in a comment in esw_del_uc_addr() (Mohammad Heib) [1776921]
- [netdrv] mlx5: Fix rtable reference leak (Mohammad Heib) [1776921]
- [netdrv] mlx5: fix a -Wstringop-truncation warning (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix a race with XSKICOSQ in XSK wakeup flow (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix wrong max num channels indication (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Add XSK zero-copy support (Mohammad Heib) [1776921]

* Tue Dec 10 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-162.el8]
- [mm] memremap: drop unused SECTION_SIZE and SECTION_MASK (Don Dutile) [1754737]
- [mm] memremap: Fix reuse of pgmap instances with internal references (Don Dutile) [1754737]
- [mm] memunmap: don't access uninitialized memmap in memunmap_pages() (Don Dutile) [1754737]
- [mm] memremap: move from kernel/ to mm/ (Don Dutile) [1754737]
- [kernel] memremap: provide an optional internal refcount in struct dev_pagemap (Don Dutile) [1754737]
- [kernel] memremap: replace the altmap_valid field with a PGMAP_ALTMAP_VALID flag (Don Dutile) [1754737]
- [mm] memremap: remove the data field in struct dev_pagemap (Don Dutile) [1754737]
- [kernel] memremap: add a migrate_to_ram method to struct dev_pagemap_ops (Don Dutile) [1754737]
- [kernel] memremap: lift the devmap_enable manipulation into devm_memremap_pages (Don Dutile) [1754737]
- [nvdimm] memremap: pass a struct dev_pagemap to ->kill and ->cleanup (Don Dutile) [1754737]
- [kernel] memremap: move dev_pagemap callbacks into a separate structure (Don Dutile) [1754737]
- [kernel] memremap: validate the pagemap type passed to devm_memremap_pages (Don Dutile) [1754737]
- [mm] remove MEMORY_DEVICE_PUBLIC support (Don Dutile) [1754737]
- [mm] migrate.c: cleanup expected_page_refs() (Don Dutile) [1754737]
- [mm] migration: factor out code to compute expected number of page references (Don Dutile) [1754737]
- [kernel] mm/devm_memremap_pages: fix final page put race (Don Dutile) [1754737]
- [kernel] mm/devm_memremap_pages: introduce devm_memunmap_pages (Don Dutile) [1754737]
- [kernel] memremap.c: remove the unused device_private_entry_fault() export (Don Dutile) [1754737]
- [base] devres: introduce devm_release_action() (Don Dutile) [1754737]
- [base] devres: Align data[] to ARCH_KMALLOC_MINALIGN (Don Dutile) [1754737]
- [base] devres: provide devm_kstrdup_const() (Don Dutile) [1754737]
- [base] devres: constify p in devm_kfree() (Don Dutile) [1754737]
- [kernel] mm: move is_kernel_rodata() to asm-generic/sections.h (Don Dutile) [1754737]
- [kernel] mm: fix vm_fault_t cast in VM_FAULT_GET_HINDEX() (Don Dutile) [1754737]
- [kernel] mm: create the new vm_fault_t type (Don Dutile) [1754737]
- [kernel] mm/hmm: convert to use vm_fault_t (Don Dutile) [1754737]
- [kernel] mm/hmm: fix memremap.h, move dev_page_fault_t callback to hmm (Don Dutile) [1754737]
- [fs] proc/vmcore.c: Convert to use vmf_error() (Don Dutile) [1754737]
- [fs] proc/vmcore.c: use new typedef vm_fault_t (Don Dutile) [1754737]
- [s390] vdso_fault return type (Don Dutile) [1754737]
- [mm] inline vm_insert_pfn_prot() into caller (Don Dutile) [1754737]
- [mm] remove vm_insert_pfn() (Don Dutile) [1754737]
- [mm] make vm_insert_pfn_prot() static (Don Dutile) [1754737]
- [x86] convert vdso to use vm_fault_t (Don Dutile) [1754737]
- [mm] introduce vmf_insert_pfn_prot() (Don Dutile) [1754737]
- [mm] convert __vm_insert_mixed() to vm_fault_t (Don Dutile) [1754737]
- [kernel] mm: remove vm_insert_mixed() (Don Dutile) [1754737]
- [fs] cramfs: convert to use vmf_insert_mixed (Don Dutile) [1754737]
- [scsi] cxlflash: Change return type for fault handler (Don Dutile) [1754737]
- [misc] ocxl: Change return type for fault handler (Don Dutile) [1754737]
- [kernel] fs/iomap.c: change return type to vm_fault_t (Don Dutile) [1754737]
- [mm] swap.c: remove duplicated include (Don Dutile) [1754737]
- [kernel] perf/aux: Fix the aux_output group inheritance fix (Michael Petlan) [1743210]
- [kernel] perf/core: Fix inheritance of aux_output groups (Michael Petlan) [1743210]
- [kernel] perf/aux: Disallow aux_output for kernel events (Michael Petlan) [1743210]
- [kernel] perf/core: Reattach a misplaced comment (Michael Petlan) [1743210]
- [kernel] perf/aux: Fix AUX output stopping (Michael Petlan) [1743210]
- [tools] perf vendor events s390: Add JSON transaction for machine type 8561 (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Fix use of TRUE with SQLite (Michael Petlan) [1743210]
- [tools] objtool: Fix build by linking against tools/lib/ctype.o sources (Michael Petlan) [1743210]
- [tools] perf list: Allow plurals for metric, metricgroup (Michael Petlan) [1743210]
- [tools] perf vendor events: Minor fixes to the README (Michael Petlan) [1743210]
- [tools] perf vendor events amd: Remove redundant '[' (Michael Petlan) [1743210]
- [tools] perf vendor events amd: Add L3 cache events for Family 17h (Michael Petlan) [1743210]
- [tools] tools include uapi: Update copy of files related to new fspick, fsmount, fsconfig, fsopen, move_mount and open_tree syscalls (Michael Petlan) [1743210]
- [tools] perf pmu-events: Fix missing "cpu_clk_unhalted.core" event (Michael Petlan) [1743210]
- [tools] perf annotate: Fix s390 gap between kernel end and module start (Michael Petlan) [1743210]
- [tools] perf record: Fix module size on s390 (Michael Petlan) [1743210]
- [tools] perf tools: Fix include paths in ui directory (Michael Petlan) [1743210]
- [tools] perf tools: Fix a typo in a variable name in the Documentation Makefile (Michael Petlan) [1743210]
- [tools] perf cpumap: Fix writing to illegal memory in handling cpumap mask (Michael Petlan) [1743210]
- [tools] perf ftrace: Fix failure to set cpumask when only one cpu is present (Michael Petlan) [1743210]
- [tools] perf db-export: Fix thread__exec_comm() (Michael Petlan) [1743210]
- [tools] perf annotate: Fix printing of unaugmented disassembled instructions from BPF (Michael Petlan) [1743210]
- [tools] perf bench numa: Fix cpu0 binding (Michael Petlan) [1743210]
- [tools] perf tools: Fix perf.data documentation units for memory size (Michael Petlan) [1743210]
- [tools] perf header: Fix use of unitialized value warning (Michael Petlan) [1743210]
- [tools] perf header: Fix divide by zero error if f_header.attr_size==0 (Michael Petlan) [1743210]
- [tools] tools perf beauty: Fix usbdevfs_ioctl table generator to handle _IOC() (Michael Petlan) [1743210]
- [tools] perf build: Do not use -Wshadow on gcc < 4.8 (Michael Petlan) [1743210]
- [tools] perf probe: Avoid calling freeing routine multiple times for same pointer (Michael Petlan) [1743210]
- [tools] perf probe: Set pev->nargs to zero after freeing pev->args entries (Michael Petlan) [1743210]
- [tools] perf session: Fix loading of compressed data split across adjacent records (Michael Petlan) [1743210]
- [tools] perf stat: Always separate stalled cycles per insn (Michael Petlan) [1743210]
- [tools] perf stat: Fix segfault for event group in repeat mode (Michael Petlan) [1743210]
- [tools] perf tools: Fix proper buffer size for feature processing (Michael Petlan) [1743210]
- [tools] perf script: Fix off by one in brstackinsn IPC computation (Michael Petlan) [1743210]
- [tools] perf script: Improve man page description of metrics (Michael Petlan) [1743210]
- [tools] perf script: Fix --max-blocks man page description (Michael Petlan) [1743210]
- [tools] perf vendor events s390: Add JSON files for machine type 8561 (Michael Petlan) [1743210]
- [tools] perf cs-etm: Return errcode in cs_etm__process_auxtrace_info() (Michael Petlan) [1743210]
- [tools] perf cs-etm: Remove errnoeous ERR_PTR() usage in cs_etm__process_auxtrace_info (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export switch events (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export switch events (Michael Petlan) [1743210]
- [tools] perf db-export: Export switch events (Michael Petlan) [1743210]
- [tools] perf db-export: Factor out db_export__threads() (Michael Petlan) [1743210]
- [tools] perf script: Add scripting operation process_switch() (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Use new 'has_calls' column (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Remove redundant semi-colons (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Add has_calls column to comms table (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Add has_calls column to comms table (Michael Petlan) [1743210]
- [tools] perf db-export: Also export thread's current comm (Michael Petlan) [1743210]
- [tools] perf db-export: Factor out db_export__comm() (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export comm details (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export comm details (Michael Petlan) [1743210]
- [tools] perf db-export: Export comm details (Michael Petlan) [1743210]
- [tools] perf db-export: Fix a white space issue in db_export__sample() (Michael Petlan) [1743210]
- [tools] perf db-export: Move export__comm_thread into db_export__sample() (Michael Petlan) [1743210]
- [tools] perf db-export: Export comm before exporting thread (Michael Petlan) [1743210]
- [tools] perf db-export: Export main_thread in db_export__sample() (Michael Petlan) [1743210]
- [tools] perf db-export: Pass main_thread to db_export__thread() (Michael Petlan) [1743210]
- [tools] perf db-export: Rename db_export__comm() to db_export__exec_comm() (Michael Petlan) [1743210]
- [tools] perf db-export: Get rid of db_export__deferred() (Michael Petlan) [1743210]
- [tools] perf trace: Auto bump rlimit(MEMLOCK) for eBPF maps sake (Michael Petlan) [1743210]
- [tools] perf test: Auto bump rlimit(MEMLOCK) for BPF test sake (Michael Petlan) [1743210]
- [tools] perf tools: Introduce rlimit__bump_memlock() helper (Michael Petlan) [1743210]
- [tools] perf-probe: Add user memory access attribute support (Michael Petlan) [1743210]
- [tools] perf intel-pt: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf intel-bts: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf script: Assume native_arch for pipe mode (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Fix DROP VIEW power_events_view (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Fix DROP VIEW power_events_view (Michael Petlan) [1743210]
- [tools] perf hists browser: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf cs-etm: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf parse-events: remove unused variable: error (Michael Petlan) [1743210]
- [tools] perf parse-events: Remove unused variable 'i' (Michael Petlan) [1743210]
- [tools] perf metricgroup: Add missing list_del_init() when flushing egroups list (Michael Petlan) [1743210]
- [tools] perf tools: Use list_del_init() more thorougly (Michael Petlan) [1743210]
- [tools] perf tools: Use zfree() where applicable (Michael Petlan) [1743210]
- [tools] tools lib: Adopt zalloc()/zfree() from tools/perf (Michael Petlan) [1743210]
- [tools] perf tools: Move get_current_dir_name() cond prototype out of util.h (Michael Petlan) [1743210]
- [tools] perf namespaces: Move the conditional setns() prototype to namespaces.h (Michael Petlan) [1743210]
- [tools] perf tools: Add missing headers, mostly stdlib.h (Michael Petlan) [1743210]
- [tools] perf evsel: perf_evsel__name(NULL) is valid, no need to check evsel (Michael Petlan) [1743210]
- [tools] perf session: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf inject: The tool->read() call may pass a NULL evsel, handle it (Michael Petlan) [1743210]
- [tools] perf map: Fix potential NULL pointer dereference found by smatch tool (Michael Petlan) [1743210]
- [tools] perf trace: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf annotate: Fix dereferencing freed memory found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf top: Fix potential NULL pointer dereference detected by the smatch tool (Michael Petlan) [1743210]
- [tools] perf stat: Fix use-after-freed pointer detected by the smatch tool (Michael Petlan) [1743210]
- [tools] perf test mmap-thread-lookup: Initialize variable to suppress memory sanitizer warning (Michael Petlan) [1743210]
- [tools] perf script: Allow specifying the files to process guest samples (Michael Petlan) [1743210]
- [tools] perf tools metric: Don't include duration_time in group (Michael Petlan) [1743210]
- [tools] perf list: avoid extra : for --raw metrics (Michael Petlan) [1743210]
- [tools] perf vendor events intel: Metric fixes for SKX/CLX (Michael Petlan) [1743210]
- [tools] perf tools: Fix typos / broken sentences (Michael Petlan) [1743210]
- [tools] perf jevents: Add support for Hisi hip08 L3C PMU aliasing (Michael Petlan) [1743210]
- [tools] perf jevents: Add support for Hisi hip08 HHA PMU aliasing (Michael Petlan) [1743210]
- [tools] perf jevents: Add support for Hisi hip08 DDRC PMU aliasing (Michael Petlan) [1743210]
- [tools] perf pmu: Support more complex PMU event aliasing (Michael Petlan) [1743210]
- [tools] perf diff: Documentation -c cycles option (Michael Petlan) [1743210]
- [tools] perf diff: Print the basic block cycles diff (Michael Petlan) [1743210]
- [tools] perf diff: Link same basic blocks among different data (Michael Petlan) [1743210]
- [tools] perf diff: Use hists to manage basic blocks per symbol (Michael Petlan) [1743210]
- [tools] perf diff: Check if all data files with branch stacks (Michael Petlan) [1743210]
- [tools] perf hists: Add block_info in hist_entry (Michael Petlan) [1743210]
- [tools] perf symbol: Create block_info structure (Michael Petlan) [1743210]
- [tools] perf jevents: Use nonlocal include statements in pmu-events.c (Michael Petlan) [1743210]
- [tools] perf annotate: Add csky support (Michael Petlan) [1743210]
- [tools] perf stat: Fix metrics with --no-merge (Michael Petlan) [1743210]
- [tools] perf stat: Fix group lookup for metric group (Michael Petlan) [1743210]
- [tools] perf stat: Don't merge events in the same PMU (Michael Petlan) [1743210]
- [tools] perf stat: Make metric event lookup more robust (Michael Petlan) [1743210]
- [tools] tools lib: Move argv_{split, free} from tools/perf/util/ (Michael Petlan) [1743210]
- [tools] perf tools: Drop strxfrchar(), use strreplace() equivalent from kernel (Michael Petlan) [1743210]
- [tools] tools lib: Adopt strreplace() from the kernel (Michael Petlan) [1743210]
- [tools] perf tools: Ditch rtrim(), use strim() from tools/lib (Michael Petlan) [1743210]
- [tools] perf tools: Remove trim() implementation, use tools/lib's strim() (Michael Petlan) [1743210]
- [tools] tools lib: Adopt strim() from the kernel (Michael Petlan) [1743210]
- [tools] perf tools: Ditch rtrim(), use skip_spaces() to get closer to the kernel (Michael Petlan) [1743210]
- [tools] perf report: Use skip_spaces() (Michael Petlan) [1743210]
- [tools] perf metricgroup: Use strsep() (Michael Petlan) [1743210]
- [tools] perf strfilter: Use skip_spaces() (Michael Petlan) [1743210]
- [tools] perf probe: Use skip_spaces() for argv handling (Michael Petlan) [1743210]
- [tools] perf time-utils: Use skip_spaces() (Michael Petlan) [1743210]
- [tools] perf header: Use skip_spaces() in __write_cpudesc() (Michael Petlan) [1743210]
- [tools] perf stat: Use recently introduced skip_spaces() (Michael Petlan) [1743210]
- [tools] tools lib: Adopt skip_spaces() from the kernel sources (Michael Petlan) [1743210]
- [tools] perf tools: Use linux/ctype.h in more places (Michael Petlan) [1743210]
- [tools] tools perf: Move from sane_ctype.h obtained from git to the Linux's original (Michael Petlan) [1743210]
- [tools] perf tools: Add missing util.h to pick up 'page_size' variable (Michael Petlan) [1743210]
- [tools] perf tools: Remove old baggage that is util/include/linux/ctype.h (Michael Petlan) [1743210]
- [tools] perf symbols: We need util.h in symbol-elf.c for zfree() (Michael Petlan) [1743210]
- [tools] perf kallsyms: Adopt hex2u64 from tools/perf/util/util.h (Michael Petlan) [1743210]
- [tools] tools x86 machine: Add missing util.h to pick up 'page_size' (Michael Petlan) [1743210]
- [tools] perf string: Move 'dots' and 'graph_dotted_line' out of sane_ctype.h (Michael Petlan) [1743210]
- [tools] perf ctype: Remove now unused 'spaces' variable (Michael Petlan) [1743210]
- [tools] perf ui stdio: No need to use 'spaces' to left align (Michael Petlan) [1743210]
- [tools] perf ctype: Remove unused 'graph_line' variable (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export Intel PT power and ptwrite events (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export Intel PT power and ptwrite events (Michael Petlan) [1743210]
- [tools] perf db-export: Export synth events (Michael Petlan) [1743210]
- [tools] perf intel-pt: Synthesize CBR events when last seen value changes (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add CBR value to decoder state (Michael Petlan) [1743210]
- [tools] perf intel-pt: Cater for CBR change in PSB+ (Michael Petlan) [1743210]
- [tools] perf intel-pt: Decoder to output CBR changes immediately (Michael Petlan) [1743210]
- [tools] perf thread-stack: Eliminate code duplicating thread_stack__pop_ks() (Michael Petlan) [1743210]
- [tools] perf thread-stack: Fix thread stack return from kernel for kernel-only case (Michael Petlan) [1743210]
- [tools] perf tools: Fix cache.h include directive (Michael Petlan) [1743210]
- [tools] tools build: Fix the zstd test in the test-all.c common case feature test (Michael Petlan) [1743210]
- [tools] perf build: Handle slang being in /usr/include and in /usr/include/slang/ (Michael Petlan) [1743210]
- [tools] tools build: Add test to check if slang.h is in /usr/include/slang/ (Michael Petlan) [1743210]
- [tools] perf tools: Don't hardcode host include path for libslang (Michael Petlan) [1743210]
- [tools] perf evsel: Make perf_evsel__name() accept a NULL argument (Michael Petlan) [1743210]
- [tools] perf trace: Fixup pointer arithmetic when consuming augmented syscall args (Michael Petlan) [1743210]
- [tools] perf pmu: Fix uncore PMU alias list for ARM64 (Michael Petlan) [1743210]
- [tools] perf tests: Add missing SPDX headers (Michael Petlan) [1743210]
- [tools] tools build feature tests: Add missing SPDX headers (Michael Petlan) [1743210]
- [tools] perf trace: Streamline validation of select syscall names list (Michael Petlan) [1743210]
- [tools] perf trace: Fix exclusion of not available syscall names from selector list (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add callchain to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add memory information to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add LBR information to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add XMM registers to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add gp registers to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Synthesize PEBS sample basic information (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out common sample preparation for re-use (Michael Petlan) [1743210]
- [tools] perf intel-pt: Prepare to synthesize PEBS samples (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add decoder support for PEBS via PT (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add Intel PT packet decoder test (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add new packets for PEBS via PT (Michael Petlan) [1743210]
- [tools] perf tests arm64: Compile tests unconditionally (Michael Petlan) [1743210]
- [tools] perf trace: Skip unknown syscalls when expanding strace like syscall groups (Michael Petlan) [1743210]
- [tools] perf report: Support s390 diag event display on x86 (Michael Petlan) [1743210]
- [tools] perf report: Fix OOM error in TUI mode on s390 (Michael Petlan) [1743210]
- [tools] perf test 6: Fix missing kvm module load for s390 (Michael Petlan) [1743210]
- [tools] perf time-utils: Add support for multiple explicit time intervals (Michael Petlan) [1743210]
- [tools] perf tests: Add a test for time-utils (Michael Petlan) [1743210]
- [tools] perf time-utils: Make perf_time__parse_for_ranges() more logical (Michael Petlan) [1743210]
- [tools] perf time-utils: Simplify perf_time__parse_for_ranges() error paths slightly (Michael Petlan) [1743210]
- [tools] perf time-utils: Fix --time documentation (Michael Petlan) [1743210]
- [tools] perf time-utils: Prevent percentage time range overlap (Michael Petlan) [1743210]
- [tools] perf time-utils: Factor out set_percent_time() (Michael Petlan) [1743210]
- [tools] perf time-utils: Treat time ranges consistently (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add support for efficient time interval filtering (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add support for lookahead (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_get_buffer() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add intel_pt_fast_forward() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add reposition parameter to intel_pt_get_data() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_reposition() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_8b_tsc() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add lookahead callback (Michael Petlan) [1743210]
- [tools] perf report: Set perf time interval in itrace_synth_ops (Michael Petlan) [1743210]
- [tools] perf script: Set perf time interval in itrace_synth_ops (Michael Petlan) [1743210]
- [tools] perf auxtrace: Add perf time interval to itrace_synth_ops (Michael Petlan) [1743210]
- [tools] perf config: Update default value for llvm.clang-bpf-cmd-template (Michael Petlan) [1743210]
- [tools] perf cs-etm: Properly set the value of 'old' and 'head' in snapshot mode (Michael Petlan) [1743210]
- [tools] perf data: Fix perf.data documentation for HEADER_CPU_TOPOLOGY (Michael Petlan) [1743210]
- [tools] perf tools: Apply new CPU topology sysfs attributes (Michael Petlan) [1743210]
- [tools] perf header: Rename "sibling cores" to "sibling sockets" (Michael Petlan) [1743210]
- [tools] perf stat: Support per-die aggregation (Michael Petlan) [1743210]
- [tools] perf header: Add die information in CPU topology (Michael Petlan) [1743210]
- [tools] perf cpumap: Retrieve die id information (Michael Petlan) [1743210]
- [tools] perf evsel: Remove superfluous nthreads system_wide setup in alloc_fd() (Michael Petlan) [1743210]
- [tools] perf record: Add support to collect callchains from kernel or user space only (Michael Petlan) [1743210]
- [tools] perf config: Bail out when a handler returns failure for a key-value pair (Michael Petlan) [1743210]
- [tools] perf trace: Exit when failing to build eBPF program (Michael Petlan) [1743210]
- [tools] perf trace: Associate more argument names with the filename beautifier (Michael Petlan) [1743210]
- [tools] perf trace: Consume the augmented_raw_syscalls payload (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Move reading filename to the loop (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Change helper to consider just the augmented_filename part (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Move the probe_read_str to a separate function (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Tell which args are filenames and how many bytes to copy (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Select find text when find bar is activated (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add IPC information to Call Tree (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add IPC information to Call Graph Graph (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add CallGraphModelParams (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add IPC information to the Branch reports (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export IPC information (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export IPC information (Michael Petlan) [1743210]
- [tools] perf db-export: Export IPC information (Michael Petlan) [1743210]
- [tools] perf db-export: Add brief documentation (Michael Petlan) [1743210]
- [tools] perf thread-stack: Accumulate IPC information (Michael Petlan) [1743210]
- [tools] perf intel-pt: Document IPC usage (Michael Petlan) [1743210]
- [tools] perf intel-pt: Accumulate cycle count from TSC/TMA/MTC packets (Michael Petlan) [1743210]
- [tools] perf intel-pt: Re-factor TIP cases in intel_pt_walk_to_ip (Michael Petlan) [1743210]
- [tools] perf intel-pt: Record when decoding PSB+ packets (Michael Petlan) [1743210]
- [tools] perf script: Add output of IPC ratio (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add support for samples to contain IPC ratio (Michael Petlan) [1743210]
- [tools] perf tools: Add IPC information to perf_sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Accumulate cycle count from CYC packets (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_update_sample_time (Michael Petlan) [1743210]
- [tools] perf record: Allow mixing --user-regs with --call-graph=dwarf (Michael Petlan) [1743210]
- [tools] perf symbols: Remove unused variable 'err' (Michael Petlan) [1743210]
- [tools] perf data: document directory format header: HEADER_DIR_FORMAT (Michael Petlan) [1743210]
- [tools] perf data: document clockid header: HEADER_CLOCKID (Michael Petlan) [1743210]
- [tools] perf data: document memory topology header: HEADER_MEM_TOPOLOGY (Michael Petlan) [1743210]
- [tools] perf data: Add description of header HEADER_BPF_PROG_INFO and HEADER_BPF_BTF (Michael Petlan) [1743210]
- [tools] perf intel-pt: Rationalize intel_pt_sync_switch()'s use of next_tid (Michael Petlan) [1743210]
- [tools] perf intel-pt: Improve sync_switch by processing PERF_RECORD_SWITCH* in events (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Add support for pyside2 (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Add support for pyside2 (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add support for pyside2 (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Use argparse module for argument parsing (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Change python2 to python (Michael Petlan) [1743210]
- [tools] perf top: Lower message level for failure on synthesizing events for pre-existing BPF programs (Michael Petlan) [1743210]
- [tools] perf machine: Return NULL instead of null-terminating /proc/version array (Michael Petlan) [1743210]
- [tools] perf version: Append 12 git SHA chars to the version string (Michael Petlan) [1743210]
- [tools] perf script: Remove superfluous BPF event titles (Michael Petlan) [1743210]
- [tools] perf script: Add --show-bpf-events to show eBPF related events (Michael Petlan) [1743210]
- [tools] perf tests: Add map_groups__merge_in test (Michael Petlan) [1743210]
- [tools] perf script: Pad DSO name for --call-trace (Michael Petlan) [1743210]
- [tools] perf dso: Add BPF DSO read and size hooks (Michael Petlan) [1743210]
- [tools] perf dso: Simplify dso_cache__read function (Michael Petlan) [1743210]
- [tools] perf dso: Separate generic code in dso_cache__read (Michael Petlan) [1743210]
- [tools] perf dso: Separate generic code in dso__data_file_size() (Michael Petlan) [1743210]
- [tools] perf tools: Remove const from thread read accessors (Michael Petlan) [1743210]
- [tools] perf top: Add --namespaces option (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for sync_file_range's 'flags' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'fsmount' arguments (Michael Petlan) [1743210]
- [tools] perf trace: Introduce syscall_arg__scnprintf_strarray_flags (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for fsmount's 'attr_flags' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'fsconfig' arguments (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for fsconfig's 'cmd' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'fspick' arguments (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for fspick's 'flags' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'move_mount' arguments (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for 'move_mount' flags argument (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Fix up comment (Michael Petlan) [1743210]
- [tools] perf tools: Preserve eBPF maps when loading kcore (Michael Petlan) [1743210]
- [tools] perf machine: Keep zero in pgoff BPF map (Michael Petlan) [1743210]
- [tools] perf intel-pt: Fix itrace defaults for perf script intel-pt documentation (Michael Petlan) [1743210]
- [tools] perf auxtrace: Fix itrace defaults for perf script (Michael Petlan) [1743210]
- [tools] perf intel-pt: Fix itrace defaults for perf script (Michael Petlan) [1743210]
- [tools] perf-with-kcore.sh: Always allow fix_buildid_cache_permissions (Michael Petlan) [1743210]
- [tools] tools build: Check if gettid() is available before providing helper (Michael Petlan) [1743210]
- [tools] tools build feature: Check if get_current_dir_name() is available (Michael Petlan) [1743210]
- [tools] perf jvmti: Address gcc string overflow warning for strncpy() (Michael Petlan) [1743210]
- [tools] perf python: Remove -fstack-protector-strong if clang doesn't have it (Michael Petlan) [1743210]
- [tools] perf annotate tui browser: Do not use member from variable within its own initialization (Michael Petlan) [1743210]
- [tools] perf thread: Allow references to thread objects after machine__exit() (Michael Petlan) [1743210]
- [fs] sysfs: Fix internal_create_group() for named group updates (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Support PEBS output to PT (Michael Petlan) [1743210]
- [kernel] perf: Allow normal events to output AUX data (Michael Petlan) [1743210]
- [x86] perf/x86/amd/ibs: Handle erratum #420 only on the affected CPU family (10h) (Michael Petlan) [1743210]
- [x86] perf/x86/amd/ibs: Fix reading of the IBS OpData register and thus precise RIP validity (Michael Petlan) [1743210]
- [kernel] perf/hw_breakpoint: Fix arch_hw_breakpoint use-before-initialization (Michael Petlan) [1743210]
- [x86] perf/x86/amd/ibs: Fix sample bias for dispatched micro-ops (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Restrict period on Nehalem (Michael Petlan) [1743210]
- [x86] perf/x86: Fix typo in comment (Michael Petlan) [1743210]
- [kernel] perf/core: Fix creating kernel counters for PMUs that override event->cpu (Michael Petlan) [1743210]
- [x86] perf/x86: Apply more accurate check on hypervisor platform (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Fix invalid Bit 13 for Icelake MSR_OFFCORE_RSP_x register (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Fix SLOTS PEBS event constraint (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Mark expected switch fall-throughs (Michael Petlan) [1743210]
- [kernel] perf_event_get(): don't bother with fget_raw() (Michael Petlan) [1743210]
- [kernel] perf/core: Fix exclusive events' grouping (Michael Petlan) [1743210]
- [x86] perf/x86/amd/uncore: Set the thread mask for F17h L3 PMCs (Michael Petlan) [1743210]
- [perf] x86/amd/uncore: Do not set 'ThreadMask' and 'SliceMask' for non-L3 PMCs (Michael Petlan) [1743210]
- [kernel] perf/core: Fix race between close() and fork() (Michael Petlan) [1743210]
- [perf] cgroups: Don't rotate events for cgroups unnecessarily (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get quirk state from new probe framework (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get attributes from new probe framework (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get MSR values from new probe framework (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get rapl_cntr_mask from new probe framework (Michael Petlan) [1743210]
- [x86] intel: Aggregate big core client naming (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Use new MSR detection interface (Michael Petlan) [1743210]
- [x86] perf/x86/cstate: Use new probe function (Michael Petlan) [1743210]
- [x86] perf/x86/msr: Use new probe function (Michael Petlan) [1743210]
- [x86] perf/x86: Add MSR probe interface (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Disable check_msr for real HW (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Use ->is_visible callback for default group (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add IMC uncore support for Snow Ridge (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Clean up client IMC (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Support MMIO type uncore blocks (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Factor out box ref/unref functions (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add uncore support for Snow Ridge server (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Handle invalid event coding for free-running counter (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Add more Icelake CPUIDs (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Add Icelake desktop CPUID (Michael Petlan) [1743210]
- [x86] perf/x86: Use update attribute groups for default attributes (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Use update attributes for skylake format (Michael Petlan) [1743210]
- [x86] perf/x86: Use update attribute groups for extra format (Michael Petlan) [1743210]
- [x86] perf/x86: Use update attribute groups for caps (Michael Petlan) [1743210]
- [x86] perf/x86: Add is_visible attribute_group callback for base events (Michael Petlan) [1743210]
- [x86] perf/x86: Use the new pmu::update_attrs attribute group (Michael Petlan) [1743210]
- [x86] perf/x86: Get rid of x86_pmu::event_attrs (Michael Petlan) [1743210]
- [x86] perf/x86/regs: Check reserved bits (Michael Petlan) [1743210]
- [fs] sysfs: Add sysfs_update_groups function (Michael Petlan) [1743210]
- [kernel] perf/core: Add attr_groups_update into struct pmu (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add new IMC PCI IDs for KabyLake, AmberLake and WhiskeyLake CPUs (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add tabs to Uncore IMC PCI IDs (Michael Petlan) [1743210]
- [kernel] perf/core: Allow non-privileged uprobe for user processes (Michael Petlan) [1743210]
- [x86] perf/x86: Add Intel Ice Lake NNPI uncore support (Michael Petlan) [1743210]
- [perf] arm_pmu: acpi: spe: Add initial MADT/SPE probing (Michael Petlan) [1743210]
- [netdrv] mwifiex: fix possible heap overflow in mwifiex_process_country_ie() (Jarod Wilson) [1776210] {CVE-2019-14895}
- [kernel] crash_core: Make S390 share the same crashkernel=auto reservation policy as X86_64 (Baoquan He) [1780432]
- [s390] kasan: avoid report in get_wchan (Philipp Rudo) [1780112 1780111]
- [s390] process: avoid potential reading of freed stack (Philipp Rudo) [1780112]
- [fs] cifs: don't use 'pre:' for MODULE_SOFTDEP (Leif Sahlberg) [1767094]
- [hwmon] Do not output deprecated warning for hwmon_device_register() (Prarit Bhargava) [1778295]
- [scsi] lpfc: size cpu map by last cpu id set (Dick Kennedy) [1778912]
- [scsi] lpfc: use hdwq assigned cpu for allocation (Dick Kennedy) [1778908]
- [scsi] be2iscsi: Include null char in SET_HOST_DATA (Maurizio Lombardi) [1776358]
- [netdrv] vmxnet3: turn off lro when rxcsum is disabled (Neil Horman) [1776056]
- [mmc] sdhci-pci: Add another Id for Intel CML (Alexander Beregalov) [1766718]
- [x86] kvm: untaint kernel for tech-preview when using nested VMX (Paolo Bonzini) [1726756]
- [powerpc] kvm: ppc: book3s hv: xive: Fix potential page leak on error path (Laurent Vivier) [1760202]
- [powerpc] kvm: ppc: book3s hv: xive: Free previous EQ page when setting up a new one (Laurent Vivier) [1760202]
- [virt] kvm: arm/arm64: vgic: Don't rely on the wrong pending table (Auger Eric) [1777059]
- [x86] kvm: x86: remove set but not used variable 'called' (Nitesh Narayan Lal) [1773677]
- [x86] kvm: x86: Zero the IOAPIC scan request dest vCPUs bitmap (Nitesh Narayan Lal) [1773677]
- [x86] kvm: x86: deliver KVM IOAPIC scan request to target vCPUs (Nitesh Narayan Lal) [1773677]
- [kernel] kvm: remember position in kvm->vcpus array (Nitesh Narayan Lal) [1773677]
- [kernel] watchdog: Reduce message verbosity (Vitaly Kuznetsov) [1774915]

* Fri Dec 06 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-161.el8]
- [fs] binfmt_elf: Do not move brk for INTERP-less ET_EXEC (Waiman Long) [1749633]
- [fs] binfmt_elf: move brk out of mmap when doing direct loader exec (Waiman Long) [1749633]
- [gpu] drm/i915/cmdparser: Fix jump whitelist clearing (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915/gen8+: Add RC6 CTX corruption WA (Dave Airlie) [1756805] {CVE-2019-0154}
- [gpu] drm/i915: Lower RM timeout to avoid DSI hard hangs (Dave Airlie) [1756805] {CVE-2019-0154}
- [gpu] drm/i915/cmdparser: Ignore Length operands during command matching (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915/cmdparser: Add support for backward jumps (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915/cmdparser: Use explicit goto for error paths (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Add gen9 BCS cmdparsing (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Allow parsing of unsized batches (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Support ro ppgtt mapped cmdparser shadow buffers (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Add support for mandatory cmdparsing (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Remove Master tables from cmdparser (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Disable Secure Batches for gen6+ (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Rename gen7 cmdparser tables (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] [drm] radeon: fix bad DMA from INTERRUPT_CNTL2 (Sam Bobroff) [1293697]
- [netdrv] mwifiex: Fix heap overflow in mmwifiex_process_tdls_action_frame() (Jarod Wilson) [1776162] {CVE-2019-14901}
- [netdrv] mlx4_en: Fix wrong limitation for number of TX rings (Mohammad Heib) [1776822]
- [netdrv] mlx4_en: fix mlx4 ethtool -N insertion (Mohammad Heib) [1776822]
- [netdrv] mlx4_core: fix wrong comment about the reason of subtract one from the max_cqes (Mohammad Heib) [1776822]
- [netdrv] ibmvnic: Serialize device queries (Steve Best) [1778037]
- [netdrv] ibmvnic: Bound waits for device queries (Steve Best) [1778037]
- [netdrv] ibmvnic: Terminate waiting device threads after loss of service (Steve Best) [1778037]
- [netdrv] ibmvnic: Fix completion structure initialization (Steve Best) [1778037]
- [netdrv] ibmvnic: Ignore H_FUNCTION return from H_EOI to tolerate XIVE mode (Steve Best) [1778037]
- [netdrv] revert "net/ibmvnic: Fix EOI when running in XIVE mode" (Steve Best) [1778037]
- [netdrv] cnic: Set fp_hsi_ver as part of CLIENT_SETUP ramrod (Manish Chopra) [1770797]
- [netdrv] bnx2x: Fix PF-VF communication over multi-cos queues (Manish Chopra) [1770797]
- [netdrv] bnx2x: Enable Multi-Cos feature (Manish Chopra) [1770797]
- [netdrv] bnx2x: Utilize FW 7.13.15.0 (Manish Chopra) [1770797]
- [fs] seq_file: fix problem when seeking mid-record (Bill O'Donnell) [1753822]
- [documentation] fs/seq_file.c: simplify seq_file iteration code and interface (Bill O'Donnell) [1753822]
- [scripts] kbuild: replace BASH-specific ${@:2} with shift and ${@} (Jiri Olsa) [1739493]
- [scripts] btf: do not use CONFIG_OUTPUT_FORMAT (Jiri Olsa) [1739493]
- [kernel] btf: fix return value check in btf_vmlinux_init() (Jiri Olsa) [1739493]
- [kernel] btf: rename /sys/kernel/btf/kernel into /sys/kernel/btf/vmlinux (Jiri Olsa) [1739493]
- [scripts] btf: expose BTF info through sysfs (Jiri Olsa) [1739493]
- [netdrv] qede: fix NULL pointer deref in __qede_remove() (Manish Chopra) [1769203]
- [gpu] cleanup: Remove .rej files (Prarit Bhargava) [1779738]
- [lib] string: Add strscpy_pad() function (Josef Oskera) [1764588]
- [char] virtio_console: allocate inbufs in add_port() only if it is needed (Pankaj Gupta) [1612795]
- [fs] xfs: add kmem_alloc_io() (Bill O'Donnell) [1583556]
- [fs] xfs: make mem_to_page available outside of xfs_buf.c (Bill O'Donnell) [1583556]
- [fs] xfs: get allocation alignment from the buftarg (Bill O'Donnell) [1583556]
- [fs] xfs: add kmem_alloc_io() (Bill O'Donnell) [1583556]
- [fs] cifs: Fix cifsInodeInfo lock_sem deadlock when reconnect occurs (Leif Sahlberg) [1765979]
- [fs] cifs: avoid using MID 0xFFFF (Leif Sahlberg) [1765979]
- [fs] cifs: Fix retry mid list corruption on reconnects (Leif Sahlberg) [1765979]
- [fs] nfsd: allow fh_want_write to be called twice ("J. Bruce Fields") [1699222]
- [net] revert "sunrpc: Fix up task signalling" (Dave Wysochanski) [1776067]
- [s390] kasan: support memcpy_real with TRACE_IRQFLAGS (Philipp Rudo) [1777468]
- [s390] kasan: add kdump support (Philipp Rudo) [1777468]
- [s390] idle: fix cpu idle time calculation (Philipp Rudo) [1777361]
- [s390] kaslr: add support for R_390_GLOB_DAT relocation type (Philipp Rudo) [1777467]
- [x86] jump_label: Make tp_vec_nr static (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Batch jump label updates (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Batch updates if arch supports it (Daniel Bristot de Oliveira) [1731860]
- [x86] alternative: Batch of patch operations (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Sort entries of the same key by the code (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Add a __jump_label_set_jump_code() helper (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Don't warn on __exit jump entries (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Add a jump_label_can_update() helper (Daniel Bristot de Oliveira) [1731860]
- [x86] alternatives: Remove the return value of text_poke_*() (Daniel Bristot de Oliveira) [1731860]
- [x86] jump-label: Remove support for custom text poker (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Use text_poke_early() during early init (Daniel Bristot de Oliveira) [1731860]
- [x86] alternatives: Add text_poke_kgdb() to not assert the lock when debugging (Daniel Bristot de Oliveira) [1731860]
- [x86] kprobes: Prohibit probing on functions before kprobe_int3_handler() (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Fix NULL dereference bug in __jump_label_mod_update() (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Annotate entries that operate on __init code earlier (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Switch to jump_entry accessors (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Implement generic support for relative references (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Abstract jump_entry member accessors (Daniel Bristot de Oliveira) [1731860]
- [x86] alternatives: Lockdep-enforce text_mutex in text_poke*() (Daniel Bristot de Oliveira) [1731860]
- [x86] revert "x86/paravirt: Set up the virt_spin_lock_key after static keys get initialized" (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Initialize static branching early (Vitaly Kuznetsov) [1777260]
- [x86] speculation: Fix redundant MDS mitigation message (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation: Fix incorrect MDS/TAA mitigation status (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation/taa: Fix printing of TAA_MSG_SMT on IBRS_ALL CPUs (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] tsx: Add config options to set tsx=on|off|auto (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [documentation] x86/speculation/taa: Add documentation for TSX Async Abort (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] tsx: Add "auto" option to the tsx= cmdline parameter (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation/taa: Add sysfs reporting for TSX Async Abort (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation/taa: Add mitigation for TSX Async Abort (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] cpu: Add a "tsx=" cmdline option with TSX disabled by default (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] cpu: Add a helper function x86_read_arch_cap_msr() (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] msr: Add the IA32_TSX_CTRL MSR (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [powerpc] xive: Prevent page fault issues in the machine crash handler (Diego Domingos) [1756116]
- [tools] Fix memcpy_mcsafe_64.S link on selftests (Desnes Augusto Nunes do Rosario) [1775570]

* Wed Dec 04 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-160.el8]
- [powerpc] perf: Fix loop exit condition in nest_imc_event_init (Steve Best) [1778609]
- [net] netfilter: nf_tables: Add missing nft_tproxy Makefile line (Phil Sutter) [1762977]

* Sat Nov 30 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-159.el8]
- [x86] kdump: Remove the backup region handling (Lianbo Jiang) [1730143]
- [x86] kdump: Always reserve the low 1M when the crashkernel option is specified (Lianbo Jiang) [1730143]
- [x86] crash: Add a forward declaration of struct kimage (Lianbo Jiang) [1730143]
- [x86] kdump: Remove the unused crash_copy_backup_region() (Lianbo Jiang) [1730143]
- [pci] p2pdma: Fix missing check for dma_virt_ops (Don Dutile) [1754734]
- [pci] p2pdma: use the dev_pagemap internal refcount (Don Dutile) [1754734]
- [pci] memremap: pass a struct dev_pagemap to ->kill and ->cleanup (Don Dutile) [1754734]
- [pci] memremap: move dev_pagemap callbacks into a separate structure (Don Dutile) [1754734]
- [pci] mm/devm_memremap_pages: fix final page put race (Don Dutile) [1754734]
- [pci] p2pdma: track pgmap references per resource, not globally (Don Dutile) [1754734]
- [pci] p2pdma: fix the gen_pool_add_virt() failure path (Don Dutile) [1754734]
- [pci] mm, hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL (Don Dutile) [1754734]
- [lib] genalloc.c: Add algorithm, align and zeroed family of DMA allocators (Don Dutile) [1754732]
- [lib] genalloc.c: include vmalloc.h (Don Dutile) [1754732]
- [lib] genalloc.c: use vzalloc_node() to allocate the bitmap (Don Dutile) [1754732]
- [md] dm table: propagate BDI_CAP_STABLE_WRITES to fix sporadic checksum errors (Mike Snitzer) [1770210]
- [fs] gfs2: fix race between gfs2_freeze_func and unmount (Abhijith Das) [1676972]
- [fs] cifs: smbd: Retry on memory registration failure (Leif Sahlberg) [1771772]
- [fs] cifs: smbd: Indicate to retry on transport sending failure (Leif Sahlberg) [1771772]
- [fs] cifs: smbd: Return EINTR when interrupted (Leif Sahlberg) [1771772]
- [fs] cifs: smbd: Don't destroy transport on RDMA disconnect (Leif Sahlberg) [1771772]
- [lib] crc-t10dif: crc_t10dif_mutex can be static (Vladis Dronov) [1769462]
- [lib] crc-t10dif: Allow current transform to be inspected in sysfs (Vladis Dronov) [1769462]
- [lib] crc-t10dif: Pick better transform if one becomes available (Vladis Dronov) [1769462]
- [crypto] api - Introduce notifier for new crypto algorithms (Vladis Dronov) [1769462]
- [netdrv] e1000e: Drop unnecessary __E1000_DOWN bit twiddling (Ken Cox) [1748256]
- [netdrv] e1000e: Use rtnl_lock to prevent race conditions between net and pci/pm (Ken Cox) [1748256]

* Fri Nov 29 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-158.el8]
- [powerpc] pseries: safely roll back failed DLPAR cpu add (Steve Best) [1772341]
- [powerpc] pseries: address checkpatch warnings in dlpar_offline_cpu (Steve Best) [1772341]
- [scsi] storvsc: setup 1:1 mapping between hardware queue and CPU queue (Cathy Avery) [1771503]
- [scsi] storvsc: Add ability to change scsi queue depth (Cathy Avery) [1771503]
- [scsi] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 320 (Cathy Avery) [1771503]
- [scsi] smartpqi: bump version (Don Brace) [1725045]
- [scsi] smartpqi: Align driver syntax with oob (Don Brace) [1725045]
- [scsi] smartpqi: remove unused manifest constants (Don Brace) [1725045]
- [scsi] smartpqi: fix problem with unique ID for physical device (Don Brace) [1725045]
- [scsi] smartpqi: correct syntax issue (Don Brace) [1725045]
- [scsi] smartpqi: change TMF timeout from 60 to 30 seconds (Don Brace) [1725045]
- [scsi] smartpqi: fix LUN reset when fw bkgnd thread is hung (Don Brace) [1725045]
- [scsi] smartpqi: add inquiry timeouts (Don Brace) [1725045]
- [scsi] smartpqi: fix call trace in device discovery (Don Brace) [1725045]
- [scsi] smartpqi: fix controller lockup observed during force reboot (Don Brace) [1725045]
- [scsi] smartpqi: clean up an indentation issue (Don Brace) [1725045]
- [scsi] smartpqi: remove set but not used variable 'ctrl_info' (Don Brace) [1725045]
- [scsi] smartpqi: clean up indentation of a statement (Don Brace) [1725045]
- [scsi] smartpqi: bump version (Don Brace) [1725045]
- [scsi] smartpqi: update copyright (Don Brace) [1725045]
- [scsi] smartpqi: add new pci ids (Don Brace) [1725045]
- [scsi] smartpqi: correct REGNEWD return status (Don Brace) [1725045]
- [scsi] smartpqi: add gigabyte controller (Don Brace) [1725045]
- [scsi] smartpqi: correct hang when deleting 32 lds (Don Brace) [1725045]
- [scsi] smartpqi: add bay identifier (Don Brace) [1725045]
- [scsi] smartpqi: add sysfs entries (Don Brace) [1725045]
- [scsi] smartpqi: add module param to hide vsep (Don Brace) [1725045]
- [scsi] smartpqi: add pci ids for fiberhome controller (Don Brace) [1725045]
- [scsi] smartpqi: add module param for exposure order (Don Brace) [1725045]
- [scsi] smartpqi: unlock on error in pqi_submit_raid_request_synchronous() (Don Brace) [1725045]
- [scsi] smartpqi: Reporting unhandled SCSI errors (Don Brace) [1725045]
- [scsi] mpt3sas: Bump mpt3sas driver version to 32.100.00.00 (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fix module parameter max_msix_vectors (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Reject NVMe Encap cmnds to unsupported HBA (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Use Component img header to get Package ver (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fail release cmnd if diag buffer is released (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add app owned flag support for diag buffer (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Reuse diag buffer allocated at load time (Tomas Henzl) [1725737]
- [scsi] mpt3sas: clear release bit when buffer reregistered (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Maintain owner of buffer through UniqueID (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Free diag buffer without any status check (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fix clear pending bit in ioctl status (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Display message before releasing diag buffer (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Register trace buffer based on NVDATA settings (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Introduce module parameter to override queue depth (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Update driver version to 31.100.00.00 (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Run SAS DEVICE STATUS CHANGE EVENT from ISR (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Reduce the performance drop (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Handle fault during HBA initialization (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add sysfs to know supported features (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Support MEMORY MOVE Tool box command (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Allow ioctls to blocked access status NVMe (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Enumerate SES of a managed PCIe switch (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Update MPI headers to 2.6.8 spec (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Gracefully handle online firmware update (Tomas Henzl) [1725737]
- [scsi] mpt3sas: memset request frame before reusing (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add support for PCIe Lane margin (Tomas Henzl) [1725737]
- [scsi] mpt3sas: support target smid for [abort|query] task (Tomas Henzl) [1725737]
- [scsi] mpt3sas: clean up a couple sizeof() uses (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fix msix load balance on and off settings (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Determine smp affinity on per HBA basis (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Use configured PCIe link speed, not max (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Remove CPU arch check to determine perf_mode (Tomas Henzl) [1725737]
- [scsi] mpt3sas: use DEVICE_ATTR_{RO, RW} (Tomas Henzl) [1725737]
- [scsi] mpt3sas: make driver options visible in sys (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Mark expected switch fall-through (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Update driver version to 29.100.00.00 (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Introduce perf_mode module parameter (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Enable interrupt coalescing on high iops (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Affinity high iops queues IRQs to local node (Tomas Henzl) [1725737]
- [scsi] mpt3sas: save and use MSI-X index for posting RD (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Use high iops queues under some circumstances (Tomas Henzl) [1725737]
- [scsi] mpt3sas: change _base_get_msix_index prototype (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add flag high_iops_queues (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add Atomic RequestDescriptor support on Aero (Tomas Henzl) [1725737]
- [scsi] mpt3sas: function pointers of request descriptor (Tomas Henzl) [1725737]
- [scsi] mpt3sas_ctl: fix double-fetch bug in _ctl_ioctl_main() (Tomas Henzl) [1725737]
- [md] revert "dm crypt: use WQ_HIGHPRI for the IO and crypt workqueues" (Mike Snitzer) [1775756]
- [md] dm thin: wakeup worker only when deferred bios exist (Mike Snitzer) [1775756]
- [md] dm raid: Remove unnecessary negation of a shift in raid10_format_to_md_layout (Mike Snitzer) [1775756]
- [md] dm writecache: handle REQ_FUA (Mike Snitzer) [1775756]
- [md] dm writecache: fix uninitialized variable warning (Mike Snitzer) [1775756]
- [md] dm stripe: use struct_size() in kmalloc() (Mike Snitzer) [1775756]
- [md] dm table: do not allow request-based DM to stack on partitions (Mike Snitzer) [1775756]
- [md] dm cache: fix bugs when a GFP_NOWAIT allocation fails (Mike Snitzer) [1775756]
- [md] dm writecache: skip writecache_wait for pmem mode (Mike Snitzer) [1775756]
- [md] dm stats: use struct_size() helper (Mike Snitzer) [1775756]
- [md] dm space map common: remove check for impossible sm_find_free() return value (Mike Snitzer) [1775756]
- [md] dm raid1: use struct_size() with kzalloc() (Mike Snitzer) [1775756]
- [md] dm writecache: optimize performance by sorting the blocks for writeback_all (Mike Snitzer) [1775756]
- [md] dm writecache: add unlikely for getting two block with same LBA (Mike Snitzer) [1775756]
- [md] dm writecache: remove unused member pointer in writeback_struct (Mike Snitzer) [1775756]
- [md] dm: make dm_table_find_target return NULL (Mike Snitzer) [1775756]
- [md] dm table: fix invalid memory accesses with too high sector number (Mike Snitzer) [1775756]
- [md] dm space map metadata: fix missing store of apply_bops() return value (Mike Snitzer) [1775756]
- [md] dm btree: fix order of block initialization in btree_split_beneath (Mike Snitzer) [1775756]
- [md] dm raid: add missing cleanup in raid_ctr() (Mike Snitzer) [1775756]
- [md] dm kcopyd: always complete failed jobs (Mike Snitzer) [1775756]
- [md] dm crypt: remove obsolete comment about plumb IV (Mike Snitzer) [1775756]
- [md] dm crypt: wipe private IV struct after key invalid flag is set (Mike Snitzer) [1775756]
- [md] dm: update stale comment in end_clone_bio() (Mike Snitzer) [1775756]
- [md] dm log writes: fix incorrect comment about the logged sequence example (Mike Snitzer) [1775756]
- [md] dm log writes: use struct_size() to calculate size of pending_block (Mike Snitzer) [1775756]
- [md] dm crypt: use struct_size() when allocating encryption context (Mike Snitzer) [1775756]
- [md] dm thin metadata: check if in fail_io mode when setting needs_check (Mike Snitzer) [1775756]
- [md] dm verity: use message limit for data block corruption message (Mike Snitzer) [1775756]
- [md] dm log writes: make sure super sector log updates are written in order (Mike Snitzer) [1775756]
- [md] dm: fix a couple brace coding style issues (Mike Snitzer) [1775756]
- [md] dm crypt: print device name in integrity error message (Mike Snitzer) [1775756]
- [documentation] dm integrity: update documentation (Mike Snitzer) [1775756]
- [md] dm integrity: don't report unused options (Mike Snitzer) [1775756]
- [md] dm integrity: don't check null pointer before kvfree and vfree (Mike Snitzer) [1775756]
- [md] dm integrity: correctly calculate the size of metadata area (Mike Snitzer) [1775756]
- [md] dm mpath: always free attached_handler_name in parse_path() (Mike Snitzer) [1775756]
- [md] dm writecache: avoid unnecessary lookups in writecache_find_entry() (Mike Snitzer) [1775756]
- [md] dm writecache: remove unused member page_offset in writeback_struct (Mike Snitzer) [1775756]
- [md] dm delay: fix a crash when invalid device is specified (Mike Snitzer) [1775756]
- [md] dm: only initialize md->dax_dev if CONFIG_DAX_DRIVER is enabled (Mike Snitzer) [1775756]
- [md] dm writecache: add unlikely for returned value of rb_next_prev (Mike Snitzer) [1775756]
- [md] dm writecache: remove needless dereferences in __writecache_writeback_pmem() (Mike Snitzer) [1775756]
- [md] dm crypt: fix endianness annotations around org_sector_of_dmreq (Mike Snitzer) [1775756]
- [md] dm integrity: fix deadlock with overlapping I_O (Mike Snitzer) [1775756]
- [md] dm: disable DISCARD if the underlying storage no longer supports it (Mike Snitzer) [1775756]
- [md] dm: revert 8f50e358153d ("dm: limit the max bio size as BIO_MAX_PAGES * PAGE_SIZE") (Mike Snitzer) [1775756]
- [md] dm integrity: make dm_integrity_init and dm_integrity_exit static (Mike Snitzer) [1775756]
- [md] dm integrity: change memcmp to strncmp in dm_integrity_ctr (Mike Snitzer) [1775756]
- [x86] platform/uv: Account for UV Hubless in is_uvX_hub Ops (Frank Ramsay) [1757510]
- [x86] platform/uv: Check EFI Boot to set reboot type (Frank Ramsay) [1757510]
- [x86] platform/uv: Decode UVsystab Info (Frank Ramsay) [1757510]
- [x86] platform/uv: Add UV Hubbed/Hubless Proc FS Files (Frank Ramsay) [1757510]
- [x86] platform/uv: Setup UV functions for Hubless UV Systems (Frank Ramsay) [1757510]
- [x86] platform/uv: Add return code to UV BIOS Init function (Frank Ramsay) [1757510]
- [x86] platform/uv: Return UV Hubless System Type (Frank Ramsay) [1757510]
- [x86] platform/uv: Save OEM_ID from ACPI MADT probe (Frank Ramsay) [1757510]
- [x86] mm: Handle physical-virtual alignment mismatch in phys_p4d_init() (Baoquan He) [1685383]
- [x86] mm/kaslr: Reduce randomization granularity for 5-level paging to 1GB (Baoquan He) [1685383]
- [x86] mm/kaslr: Use only one PUD entry for real mode trampoline (Baoquan He) [1685383]
- [documentation] documentation/stackprotector: powerpc supports stack protector (Bhupesh Sharma) [1714310]
- [makefile] kbuild: mark prepare0 as PHONY to fix external module build (Bhupesh Sharma) [1714310]
- [makefile] kbuild: fix single target build for external module (Bhupesh Sharma) [1714310]
- [arm64] enable per-task stack canaries (Bhupesh Sharma) [1714310]
- [powerpc] Fix stack protector crashes on CPU hotplug (Bhupesh Sharma) [1714310]
- [powerpc] 64: properly initialise the stackprotector canary on SMP (Bhupesh Sharma) [1714310]
- [powerpc] Fix stackprotector detection for non-glibc toolchains (Bhupesh Sharma) [1714310]
- [powerpc] 64: add stack protector support (Bhupesh Sharma) [1714310]
- [powerpc] 32: add stack protector support (Bhupesh Sharma) [1714310]
- [pci] vmd: Fix shadow offsets to reflect spec changes (Myron Stowe) [1757896]
- [pci] vmd: Fix config addressing when using bus offsets (Myron Stowe) [1757896]
- [pci] Fix typos and whitespace errors (Myron Stowe) [1757896]
- [pci] vmd: use the proper dma_* APIs instead of direct methods calls (Myron Stowe) [1757896]
- [powerpc] powernv: Disable native PCIe port management (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix eeh eeh_debugfs_break_device() with SRIOV devices (Gustavo Duarte) [1524642]
- [tools] selftests/powerpc: Add basic EEH selftest (Gustavo Duarte) [1524642]
- [powerpc] eeh: Add a eeh_dev_break debugfs interface (Gustavo Duarte) [1524642]
- [powerpc] eeh: Add debugfs interface to run an EEH check (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix debugfs_simple_attr.cocci warnings (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix build with STACKTRACE=n (Gustavo Duarte) [1524642]
- [powerpc] eeh: Set attention indicator while recovering (Gustavo Duarte) [1524642]
- [pci] pci-hotplug/pnv_php: Add attention indicator support (Gustavo Duarte) [1524642]
- [pci] pci-hotplug/pnv_php: Add support for IODA3 Power9 PHBs (Gustavo Duarte) [1524642]
- [pci] pci-hotplug/pnv_php: Add a reset_slot() callback (Gustavo Duarte) [1524642]
- [powerpc] powernv/eeh: Use generic code to handle hot resets (Gustavo Duarte) [1524642]
- [powerpc] eeh: Remove stale CAPI comment (Gustavo Duarte) [1524642]
- [powerpc] eeh: Defer printing stack trace (Gustavo Duarte) [1524642]
- [powerpc] eeh: Check slot presence state in eeh_handle_normal_event() (Gustavo Duarte) [1524642]
- [powerpc] eeh: Make permanently failed devices non-actionable (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix race when freeing PDNs (Gustavo Duarte) [1524642]
- [powerpc] eeh: Clean up EEH PEs after recovery finishes (Gustavo Duarte) [1524642]
- [netdrv] be2net: disable bh with spin_lock in be_process_mcc (Petr Oros) [1724777]
- [netdrv] be2net: Synchronize be_update_queues with dev_watchdog (Petr Oros) [1724777]
- [netdrv] be2net: Signal that the device cannot transmit during reconfiguration (Petr Oros) [1724777]
- [netdrv] be2net: fix link failure after ethtool offline test (Petr Oros) [1724777]
- [netdrv] be2net: Fix number of Rx queues used for flow hashing (Petr Oros) [1724777]
- [netdrv] benet: remove broken and unused macro (Petr Oros) [1724777]
- [netdrv] benet: use skb_vlan_tag_get_prio() (Petr Oros) [1724777]
- [netdrv] benet: use __vlan_hwaccel helpers (Petr Oros) [1724777]
- [netdrv] revert "[netdrv] be2net: Disable queue dump in be_tx_timeout handler" (Petr Oros) [1724777]
- [infiniband] rdma/i40iw: Set queue pair state when being queried (Stefan Assmann) [1721712]
- [infiniband] ib/i40iw: Use kmemdup rather than open coding (Stefan Assmann) [1721712]
- [infiniband] rdma/i40iw: Handle workqueue allocation failure (Stefan Assmann) [1721712]
- [nvdimm] libnvdimm/pfn_dev: Add page size and struct page size to pfn superblock (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn_dev: Add a build check to make sure we notice when struct page size change (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn: Fix namespace creation on misaligned addresses (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn: stop padding pmem namespaces to section alignment (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields (Baoquan He) [1724969]
- [nvdimm] revert "libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields" (Baoquan He) [1724969]
- [nvdimm] revert "libnvdimm/pfn_dev: Add page size and struct page size to pfn superblock" (Baoquan He) [1724969]
- [nvdimm] revert "libnvdimm/pfn_dev: Add a build check to make sure we notice when struct page size change" (Baoquan He) [1724969]
- [mm] sparsemem: cleanup 'section number' data types (Baoquan He) [1724969]
- [kernel] mm/devm_memremap_pages: enable sub-section remap (Baoquan He) [1724969]
- [mm] sparsemem: support sub-section hotplug (Baoquan He) [1724969]
- [mm] sparsemem: prepare for sub-section ranges (Baoquan He) [1724969]
- [kernel] mm: kill is_dev_zone() helper (Baoquan He) [1724969]
- [mm] hotplug: kill is_dev_zone() usage in __remove_pages() (Baoquan He) [1724969]
- [mm] sparsemem: convert kmalloc_section_memmap() to populate_section_memmap() (Baoquan He) [1724969]
- [mm] hotplug: prepare shrink_{zone, pgdat}_span for sub-section removal (Baoquan He) [1724969]
- [mm] sparsemem: add helpers track active portions of a section at boot (Baoquan He) [1724969]
- [mm] sparsemem: introduce a SECTION_IS_EARLY flag (Baoquan He) [1724969]
- [mm] sparsemem: introduce struct mem_section_usage (Baoquan He) [1724969]
- [base] base/memory.c: get rid of find_memory_block_hinted() (Baoquan He) [1724969]
- [mm] memory_hotplug: move and simplify walk_memory_blocks() (Baoquan He) [1724969]
- [mm] memory_hotplug: rename walk_memory_range() and pass start+size instead of pfns (Baoquan He) [1724969]
- [mm] hotplug: make remove_memory() interface usable (Baoquan He) [1724969]
- [kernel] mm: make register_mem_sect_under_node() static (Baoquan He) [1724969]
- [base] base/memory: use "unsigned long" for block ids (Baoquan He) [1724969]
- [base] mm: section numbers use the type "unsigned long" (Baoquan He) [1724969]
- [base] base/memory.c: Use DEVICE_ATTR_RO and friends (Baoquan He) [1724969]
- [mm] sparse.c: set section nid for hot-add memory (Baoquan He) [1724969]
- [mm] memory_hotplug: remove "zone" parameter from sparse_remove_one_section (Baoquan He) [1724969]
- [base] mm/memory_hotplug: make unregister_memory_block_under_nodes() never fail (Baoquan He) [1724969]
- [base] mm/memory_hotplug: remove memory block devices before arch_remove_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: drop MHP_MEMBLOCK_API (Baoquan He) [1724969]
- [base] mm/memory_hotplug: create memory block devices after arch_add_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: allow arch_remove_memory() without CONFIG_MEMORY_HOTREMOVE (Baoquan He) [1724969]
- [arm64] mm: add temporary arch_remove_memory() implementation (Baoquan He) [1724969]
- [mm] sparse.c: clean up obsolete code comment (Baoquan He) [1724969]
- [base] base/memory: pass a block_id to init_memory_block() (Baoquan He) [1724969]
- [base] base/memory.c: remove an unnecessary check on NR_MEM_SECTIONS (Baoquan He) [1724969]
- [s390] s390x/mm: implement arch_remove_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: make __remove_section() never fail (Baoquan He) [1724969]
- [base] mm/memory_hotplug: make unregister_memory_section() never fail (Baoquan He) [1724969]
- [base] base/memory.c: clean up relics in function parameters (Baoquan He) [1724969]
- [base] mm, memory_hotplug: update a comment in unregister_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: release memory resource after arch_remove_memory() (Baoquan He) [1724969]
- [kernel] mm, memory_hotplug: provide a more generic restrictions for memory hotplug (Baoquan He) [1724969]
- [kernel] linux/memory_hotplug.h: remove duplicate declaration of offline_pages() (Baoquan He) [1724969]
- [mm] x86: respect memory size limiting via mem= parameter (Baoquan He) [1724969]
- [arm64] Add memory hotplug support (Baoquan He) [1724969]
- [arm64] mm: check for upper PAGE_SHIFT bits in pfn_valid() (Baoquan He) [1724969]
- [powerpc] mm: Fix section mismatch warning (Baoquan He) [1724969]
- [base] mm/memory_hotplug: do not unlock after failing to take the device_hotplug_lock (Baoquan He) [1724969]
- [mm] memory_hotplug: drop "online" parameter from add_memory_resource() (Baoquan He) [1724969]
- [s390] s390x/mm: fail when an altmap is used for arch_add_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: simplify and fix check_hotplug_memory_range() (Baoquan He) [1724969]
- [mm] memory_hotplug: add nid parameter to arch_remove_memory (Baoquan He) [1724969]
- [mm] sparse: pass nid instead of pgdat to sparse_add_one_section() (Baoquan He) [1724969]
- [mm] sparse: drop pgdat_resize_lock in sparse_add/remove_one_section() (Baoquan He) [1724969]
- [documentation] memory-hotplug.rst: add some details about locking internals (Baoquan He) [1724969]
- [powerpc] powernv: hold device_hotplug_lock when calling memtrace_offline_pages() (Baoquan He) [1724969]
- [powerpc] powernv: hold device_hotplug_lock when calling device_online() (Baoquan He) [1724969]
- [powerpc] powernv: Allow memory that has been hot-removed to be hot-added (Baoquan He) [1724969]
- [powerpc] powernv/memtrace: Remove memtrace mmap() (Baoquan He) [1724969]
- [mm] memory_hotplug: fix online/offline_pages called w.o. mem_hotplug_lock (Baoquan He) [1724969]
- [mm] memory_hotplug: make add_memory() take the device_hotplug_lock (Baoquan He) [1724969]
- [mm] memory_hotplug: make remove_memory() take the device_hotplug_lock (Baoquan He) [1724969]
- [powerpc] memtrace: Remove memory in chunks (Baoquan He) [1724969]
- [base] mm/memory_hotplug.c: drop unnecessary checks from register_mem_sect_under_node() (Baoquan He) [1724969]
- [base] mm/memory_hotplug.c: make register_mem_sect_under_node() a callback of walk_memory_range() (Baoquan He) [1724969]
- [mm] memory_hotplug.c: call register_mem_sect_under_node() (Baoquan He) [1724969]
- [mm] memory_hotplug.c: make add_memory_resource use __try_online_node (Baoquan He) [1724969]
- [pci] Always allow probing with driver_override (Myron Stowe) [1702178]
- [pci] Return error if cannot probe VF (Myron Stowe) [1702178]
- [target] scsi: target: core: Do not overwrite CDB byte 1 (Maurizio Lombardi) [1764579]
- [target] scsi: target: tcmu: clean the nl_cmd of the udev when nl send fails (Maurizio Lombardi) [1764579]
- [target] scsi: target: tcmu: avoid use-after-free after command timeout (Maurizio Lombardi) [1764579]
- [target] scsi: tcmu: Simplify tcmu_update_uio_info() (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: fix possible condition with no effect (if == else) (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Make sure PDU processing continues if parsing a command fails (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Make iscsit_map_iovec() more robust (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Handle too large immediate data buffers correctly (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Only send R2T if needed (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Detect conn_cmd_list corruption early (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Make the XCOPY setup code easier to read by inlining two functions (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Simplify LUN initialization in XCOPY implementation (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Remove a set-but-not-used member variable from the XCOPY implementation (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Rework the SPC-2 reservation handling code (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Fix a race condition in the LUN lookup code (Maurizio Lombardi) [1764579]
- [target] scsi: target: alua: fix the tg_pt_gps_count (Maurizio Lombardi) [1764579]
- [target] scsi: target: iscsi: Free conn_ops when zalloc_cpumask_var failed (Maurizio Lombardi) [1764579]
- [target] scsi: target: iscsi: Fix np_ip_proto and np_sock_type in iscsit_setup_np (Maurizio Lombardi) [1764579]
- [target] scsi: target: fix unsigned comparision with less than zero (Maurizio Lombardi) [1764579]
- [target] scsi: target: Add device product id and revision configfs attributes (Maurizio Lombardi) [1764579]
- [kernel] genirq/affinity: Remove const qualifier from node_to_cpumask argument (Ming Lei) [1743064]
- [kernel] genirq/affinity: Spread vectors on node according to nr_cpu ratio (Ming Lei) [1743064]
- [kernel] genirq/affinity: Improve __irq_build_affinity_masks() (Ming Lei) [1743064]
- [kernel] genirq/affinity: Remove unused argument from [__]irq_build_affinity_masks() (Ming Lei) [1743064]
- [kernel] workqueue, lockdep: Fix a memory leak in wq->lock_name (Waiman Long) [1736654]
- [kernel] workqueue, lockdep: Fix an alloc_workqueue() error path (Waiman Long) [1736654]
- [kernel] locking/lockdep: Report more stack trace statistics (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reduce space occupied by stack traces (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make it clear that what lock_class::key points at is not modified (Waiman Long) [1736654]
- [kernel] lockdep: Make print_lock() address visible (Waiman Long) [1736654]
- [kernel] locking/lockdep: Clean up #ifdef checks (Waiman Long) [1736654]
- [kernel] locking/lockdep: Hide unused 'class' variable (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix lock used or unused stats error (Waiman Long) [1736654]
- [kernel] locking/lockdep: increase size of counters for lockdep statistics (Waiman Long) [1736654]
- [kernel] locking/lockdep: Move mark_lock() inside CONFIG_TRACE_IRQFLAGS && CONFIG_PROVE_LOCKING (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unnecessary DEBUG_LOCKS_WARN_ON() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix merging of hlocks with non-zero references (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix OOO unlock when hlocks need merging (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove !dir in lock irq usage check (Waiman Long) [1736654]
- [kernel] locking/lockdep: Adjust new bit cases in mark_lock (Waiman Long) [1736654]
- [kernel] locking/lockdep: Consolidate lock usage bit initialization (Waiman Long) [1736654]
- [kernel] locking/lockdep: Check redundant dependency only when CONFIG_LOCKDEP_SMALL (Waiman Long) [1736654]
- [kernel] locking/lockdep: Refactorize check_noncircular and check_redundant (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unused argument in __lock_release (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove redundant argument in check_deadlock (Waiman Long) [1736654]
- [documentation] locking/lockdep: Add explanation to lock usage rules in lockdep design doc (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update comments on dependency search (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid constant checks in __bfs by using offset reference (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change the return type of __cq_dequeue() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change type of the element field in circular_queue (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update comment (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unused argument in validate_chain() and check_deadlock() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change the range of class_idx in held_lock struct (Waiman Long) [1736654]
- [kernel] locking/lockdep: Define INITIAL_CHAIN_KEY for chain keys to start with (Waiman Long) [1736654]
- [kernel] locking/lockdep: Use lockdep_init_task for task initiation consistently (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update obsolete struct field description (Waiman Long) [1736654]
- [kernel] locking/lockdep: Print the right depth for chain key collision (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove useless conditional macro (Waiman Long) [1736654]
- [kernel] locking/lockdep: Adjust lock usage bit character checks (Waiman Long) [1736654]
- [documentation] locking/lockdep: Add description and explanation in lockdep design doc (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change all print_*() return type to void (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove the unused print_lock_trace() function (Waiman Long) [1736654]
- [kernel] locking/lockdep: Don't complain about incorrect name for no validate class (Waiman Long) [1736654]
- [kernel] lockdep: Add assertion to check if in an interrupt (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unnecessary unlikely() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Test all incompatible scenarios at once in check_irq_usage() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid bogus Clang warning (Waiman Long) [1736654]
- [kernel] locking/lockdep: Generate LOCKF_ bit composites (Waiman Long) [1736654]
- [kernel] locking/lockdep: Use expanded masks on find_usage_*() functions (Waiman Long) [1736654]
- [kernel] locking/lockdep: Map remaining magic numbers to lock usage mask names (Waiman Long) [1736654]
- [kernel] locking/lockdep: Move valid_state() inside CONFIG_TRACE_IRQFLAGS && CONFIG_PROVE_LOCKING (Waiman Long) [1736654]
- [kernel] lockdep: Simplify stack trace handling (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make lockdep_unregister_key() honor 'debug_locks' again (Waiman Long) [1736654]
- [kernel] locking/lockdep: Zap lock classes even with lock debugging disabled (Waiman Long) [1736654]
- [kernel] locking/lockdep: Only call init_rcu_head() after RCU has been initialized (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid a Clang warning (Waiman Long) [1736654]
- [kernel] locking/lockdep: Shrink struct lock_class_key (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add module_param to enable consistency checks (Waiman Long) [1736654]
- [tools] lockdep/lib/tests: Test dynamic key registration (Waiman Long) [1736654]
- [tools] lockdep/lib/tests: Fix run_tests.sh (Waiman Long) [1736654]
- [kernel] workqueue: Use dynamic lockdep keys for workqueues (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add support for dynamic keys (Waiman Long) [1736654]
- [kernel] locking/lockdep: Verify whether lock objects are small enough to be used as class keys (Waiman Long) [1736654]
- [kernel] locking/lockdep: Check data structure consistency (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reuse lock chains that have been freed (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix a comment in add_chain_cache() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Introduce lockdep_next_lockchain() and lock_chain_count() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reuse list entries that are no longer in use (Waiman Long) [1736654]
- [kernel] locking/lockdep: Free lock classes that are no longer in use (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update two outdated comments (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make it easy to detect whether or not inside a selftest (Waiman Long) [1736654]
- [kernel] locking/lockdep: Split lockdep_free_key_range() and lockdep_reset_lock() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Initialize the locks_before and locks_after lists earlier (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make zap_class() remove all matching lock order entries (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reorder struct lock_class members (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid that add_chain_cache() adds an invalid chain to the cache (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix reported required memory size (2/2) (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix reported required memory size (1/2) (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix two 32-bit compiler warnings (Waiman Long) [1736654]
- [kernel] locking/lockdep: Rename lockdep_info() to lockdep_init() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add debug_locks check in __lock_downgrade() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Provide enum lock_usage_bit mask names (Waiman Long) [1736654]
- [kernel] locking/lockdep: Simplify mark_held_locks() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add debug_locks check in __lock_downgrade() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Stop using RCU primitives to access 'all_lock_classes' (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make concurrent lockdep_reset_lock() calls safe (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove a superfluous INIT_LIST_HEAD() statement (Waiman Long) [1736654]
- [kernel] locking/lockdep: Introduce lock_class_cache_is_registered() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Inline __lockdep_init_map() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Declare local symbols static (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Test the lockdep_reset_lock() implementation (Waiman Long) [1736654]
- [tools] lib/lockdep: Add dummy print_irqtrace_events() implementation (Waiman Long) [1736654]
- [tools] lib/lockdep: Rename "trywlock" into "trywrlock" (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Run lockdep tests a second time under Valgrind (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Improve testing accuracy (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Fix shellcheck warnings (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Display compiler warning and error messages (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove ::version from lock_class structure (Waiman Long) [1736654]
- [init] kconfig: disable io_uring support (Jeff Moyer) [1758680]
- [virt] kvm: arm64: pmu: Reset sample period on overflow handling (Auger Eric) [1760872]
- [virt] kvm: arm64: pmu: Set the CHAINED attribute before creating the in-kernel event (Auger Eric) [1760872]
- [arm64] kvm: Handle PMCR_EL0.LC as RES1 on pure AArch64 systems (Auger Eric) [1760872]
- [virt] kvm: arm64: pmu: Fix cycle counter truncation (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Introduce kvm_pmu_vcpu_init() to setup PMU counter index (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Support chained PMU counters (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Remove pmc->bitmask (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Re-create event when setting counter value (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Extract duplicated code to own function (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Rename kvm_pmu_{enable/disable}_counter functions (Auger Eric) [1760872]
- [arm64] perf: Hook up new events (Auger Eric) [1760872]
- [arm64] perf: Move event definitions into perf_event.h (Auger Eric) [1760872]
- [arm64] perf: Remove duplicate generic cache events (Auger Eric) [1760872]
- [arm64] perf: Terminate PMU assignment statements with semicolons (Auger Eric) [1760872]
- [arm64] Allow CAVIUM_TX2_ERRATUM_219 to be selected (Auger Eric) [1771633]
- [arm64] Avoid Cavium TX2 erratum 219 when switching TTBR (Auger Eric) [1771633]
- [arm64] Enable workaround for Cavium TX2 erratum 219 when running SMT (Auger Eric) [1771633]
- [arm64] kvm: Trap VM ops when ARM64_WORKAROUND_CAVIUM_TX2_219_TVM is set (Auger Eric) [1771633]
- [arm64] sysreg: fix incorrect definition of SYS_PAR_EL1_F (Auger Eric) [1771633]
- [arm64] Force SSBS on context switch (Mark Salter) [1756103]
- [arm64] enable pointer authentication (Mark Salter) [1756103]
- [arm64] add ptrace regsets for ptrauth key management (Mark Salter) [1756103]
- arm64: cpufeature: Rework ptr auth hwcaps using multi_entry_cap_matches (Mark Salter) [1756103]
- [arm64] capabilities: Merge duplicate entries for Qualcomm erratum 1003 (Mark Salter) [1756103]
- [arm64] cpufeature: Reduce number of pointer auth CPU caps from 6 to 4 (Mark Salter) [1756103]
- [documentation] arm64: docs: document pointer authentication (Mark Salter) [1756103]
- [documentation] arm64: docs: Document SSBS HWCAP (Mark Salter) [1756103]
- [documentation] arm64: docs: Fix typos in ELF hwcaps (Mark Salter) [1756103]
- [arm64] ptr auth: Move per-thread keys from thread_info to thread_struct (Mark Salter) [1756103]
- [arm64] add prctl control for resetting ptrauth keys (Mark Salter) [1756103]
- [arm64] perf: strip PAC when unwinding userspace (Mark Salter) [1756103]
- [arm64] expose user PAC bit positions via ptrace (Mark Salter) [1756103]
- [arm64] add basic pointer authentication support (Mark Salter) [1756103]
- arm64/cpufeature: detect pointer authentication (Mark Salter) [1756103]
- [arm64] cpufeature: Convert hook_lock to raw_spin_lock_t in cpu_enable_ssbs() (Mark Salter) [1756103]
- [arm64] entry: Allow handling of undefined instructions from EL1 (Mark Salter) [1756103]
- [arm64] Fix silly typo in comment (Mark Salter) [1756103]
- [fs] smb3: fix signing verification of large reads (Dave Wysochanski) [1753114]
- [fs] revert "nfs4: Fix v4.0 client state corruption when mount" (Benjamin Coddington) [1767012]
- [kernel] svcrdma: Increase the default connection credit limit (Benjamin Coddington) [1771430]
- [x86] quirks: Disable HPET on Intel Coffe Lake platforms (David Arcari) [1773774]
- [sched] core: Fix CPU controller for !RT_GROUP_SCHED (Phil Auld) [1774652]
- [x86] Add comment for x86 processor OS version support (David Arcari) [1709878]
- [x86] kvm: svm: taint module and print taint message iff nested is enabled (Bandan Das) [1775410]
- [x86] cpu: Add Tiger Lake to Intel family (Steve Best) [1773790]
- [fs] Fix the locking in dcache_readdir() and friends (Miklos Szeredi) [1761746]
- [infiniband] rdma/mlx5: Return proper error value (Mohammad Heib) [1772101]
- [scsi] mpt3sas: change allocation option (Tomas Henzl) [1770264]
- [scsi] qla2xxx: Initialized mailbox to prevent driver load failure (Himanshu Madhani) [1770309]
- [mfd] intel-lpss: Add Intel Comet Lake PCH-H PCI IDs (David Arcari) [1773307]
- [powercap] intel_rapl: add support for Cometlake desktop (David Arcari) [1759664]
- [powercap] intel_rapl: add support for CometLake Mobile (David Arcari) [1746265]
- [kernel] intel_rapl: need linux/cpuhotplug.h for enum cpuhp_state (Alexander Beregalov) [1732604]
- [thermal] int340x/processor_thermal_device: Fix proc_thermal_rapl_remove() (Alexander Beregalov) [1732604]
- [thermal] int340x/processor_thermal_device: add support for MMIO RAPL (Alexander Beregalov) [1732604]
- [thermal] thermal: processor_thermal_device: Fix build warning (Alexander Beregalov) [1732604]
- [thermal] thermal: processor_thermal: Read PPCC on resume (Alexander Beregalov) [1732604]
- [thermal] thermal: processor_thermal: Downgrade error message (Alexander Beregalov) [1732604]
- [thermal] intel: int340x: processor_thermal_device: simplify to get driver data (Alexander Beregalov) [1732604]
- [thermal] int3403_thermal: favor _TMP instead of PTYP (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: fix mode setting (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: Add additional UUIDs (Alexander Beregalov) [1732604]
- [thermal] thermal: int340x_thermal: Fix sysfs race condition (Alexander Beregalov) [1732604]
- [thermal] thermal: int340x_thermal: Make PCI dependency explicit (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: Fix a NULL vs IS_ERR() check (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: int3400_thermal: simplify getting .driver_data (Alexander Beregalov) [1732604]
- [powercap] Invoke powercap_init() and rapl_init() earlier (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: Fix module autoloading issue (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: support two power limits for every RAPL domain (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: support 64 bit register (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: abstract RAPL common code (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: cleanup hardcoded MSR access (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: cleanup some functions (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: abstract register access operations (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: abstract register address (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: introduce struct rapl_if_private (Alexander Beregalov) [1732604]
- [kernel] intel_rapl: introduce intel_rapl.h (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: remove hardcoded register index (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: use reg instead of msr (Alexander Beregalov) [1732604]
- [security] ima: Differentiate auditing policy rules from "audit" actions (Richard Guy Briggs) [1479911]
- [security] ima: Do not audit if CONFIG_INTEGRITY_AUDIT is not set (Richard Guy Briggs) [1479911]
- [security] ima: Use audit_log_format() rather than audit_log_string() (Richard Guy Briggs) [1479911]
- [security] ima: Call audit_log_string() rather than logging it untrusted (Richard Guy Briggs) [1479911]
- [security] selinux: avoid atomic_t usage in sidtab (Ondrej Mosnacek) [1741182]
- [security] selinux: always return a secid from the network caches if we find one (Ondrej Mosnacek) [1741182]
- [security] selinux: policydb - rename type_val_to_struct_array (Ondrej Mosnacek) [1741182]
- [security] selinux: policydb - fix some checkpatch.pl warnings (Ondrej Mosnacek) [1741182]
- [security] selinux: shuffle around policydb.c to get rid of forward declarations (Ondrej Mosnacek) [1741182]
- [security] selinux: fix memory leak in policydb_init() (Ondrej Mosnacek) [1741182]
- [security] selinux: check sidtab limit before adding a new entry (Ondrej Mosnacek) [1741182]
- [security] selinux: format all invalid context as untrusted (Ondrej Mosnacek) [1479914 1741182]
- [security] selinux: remove some no-op BUG_ONs (Ondrej Mosnacek) [1741182]
- [security] selinux: provide __le variables explicitly (Ondrej Mosnacek) [1741182]
- [security] selinux: avoid uninitialized variable warning (Ondrej Mosnacek) [1741182]
- [security] selinux: remove useless assignments (Ondrej Mosnacek) [1741182]
- [security] selinux: fix NULL dereference in policydb_destroy() (Ondrej Mosnacek) [1741182]
- [security] selinux: convert to kvmalloc (Ondrej Mosnacek) [1741182]
- [kernel] lsm: generalize flag passing to security_capable (Ondrej Mosnacek) [1741182]
- [kernel] selinux: Remove unused selinux_is_enabled (Ondrej Mosnacek) [1741182]
- [kernel] selinux: Remove cred security blob poisoning (Ondrej Mosnacek) [1741182]
- [security] selinux: Remove SECURITY_SELINUX_BOOTPARAM_VALUE (Ondrej Mosnacek) [1741182]

* Thu Nov 28 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-157.el8]
- [tools] selftests: mlxsw: Add a test for leftover DSCP rule (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Fix local variable declarations in DSCP tests (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Add counters for GC events (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Bump firmware version to 13.2000.1886 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Prevent auto negotiation on number of lanes (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove 56G speed support (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Keep unmatched entries in a linked list (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Further reduce pool size on Spectrum-2 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Fix error path in mlxsw_sp_module_init() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: fix duplicated check on orig_egr_types (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Increase parsing depth when PTP is enabled (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Fix typo in qos_mc_aware.sh (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Do not process learned records with a dummy FID (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_dcb: Configure DSCP map as the last rule is removed (Ivan Vecera) [1737368]
- [netdrv] remove redundant memset (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Apply the PTP shaper enable/disable logic (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Set up PTP shaper when port status has changed (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Enable/disable PTP shaper on a port when getting HWTSTAMP on/off (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Add new operation for getting the port's speed (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Set the PTP shaper parameters (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add QoS PTP Shaper Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Add note about the PTP shaper (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add ptps field in QoS ETS Element Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Fix validation in mlxsw_sp1_ptp_packet_finish() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Support ethtool get_ts_info (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Support SIOCGHWTSTAMP, SIOCSHWTSTAMP ioctls (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Configure PTP traps and FIFO events (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Garbage-collect unmatched entries (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Support timestamping on Spectrum-1 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Disable BH when working with PHC (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Add PTP initialization / finalization (Ivan Vecera) [1737368]
- [netdrv] mlxsw: pci: ptp: Hook into packet transmit path (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add support for using SKB control buffer (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Hook into packet receive path (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Add support for traps specific to Spectrum-1 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Extract a helper for trap registration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Monitoring Global Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Time Precision Packet Timestamping Reading (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Monitoring Precision Time Protocol Trap Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Monitoring Time Precision Packet Port Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add support for negative temperature readout (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add the hottest thermal zone detection (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Extend thermal core with per inter-connect device thermal zones (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_flower: Implement support for ingress device matching (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Fix SRC_SYS_PORT element size (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Avoid size check for RX_ACL_SYSTEM_PORT element (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Write RX_ACL_SYSTEM_PORT acl element correctly (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Fix compilation on 32-bit ARM (Ivan Vecera) [1737368]
- [tools] selftests: ptp: Add Physical Hardware Clock test (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: PTP physical hardware clock initialization (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Add implementation for physical hardware clock operations (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Management Pulse Per Second Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Management UTC Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: pci: Query free running clock PCI BAR and offsets (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add a new interface for reading the hardware free running clock (Ivan Vecera) [1737368]
- [netdrv] mlxsw: cmd: Free running clock PCI BAR and offsets via query firmware (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Implement flash update status notifications (Ivan Vecera) [1737368]
- [netdrv] mlxfw: Introduce status_notify op and call it to notify about the status (Ivan Vecera) [1737368]
- [netdrv] mlxfw: Propagate error messages through extack (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Move firmware flash implementation to devlink (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Reduce buffer size in transactions for SFP modules temperature readout (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Extend the index size for temperature sensors readout (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Extend hwmon interface with inter-connect temperature attributes (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Management General Peripheral Information Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Extend sensor index field size of Management Temperature Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Re-order initialization sequence (Ivan Vecera) [1737368]
- [netdrv] mlxsw: i2c: Allow flexible setting of I2C transactions size (Ivan Vecera) [1737368]
- [netdrv] mlxsw: i2c: Extend initialization with querying firmware info (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Disallow prio-tagged packets when PVID is removed (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Reduce pool size on Spectrum-2 (Ivan Vecera) [1737368]
- [tools] selftests: tc_flower: Add TOS matching test (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_flower: Fix TOS matching (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Test nexthop offload indication (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Refresh nexthop neighbour when it becomes dead (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Use different seeds for ECMP and LAG hash (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Prevent force of 56G (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Avoid warning after identical rules insertion (Ivan Vecera) [1737368]
- [tools] selftests: Add loopback test (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Implement loopback ethtool feature (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Port Physical Loopback Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: split base on local_ports_in_{1x, 2x} resources (Ivan Vecera) [1737368]
- [netdrv] mlxsw: resources: Add local_ports_in_{1x, 2x} (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Bump firmware version to 13.2000.1122 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove obsolete dependency on THERMAL=m (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Prevent ipv6 gateway with v4 route via replace and append (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Adjust CPU port shared buffer egress quotas (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Allow skipping ingress port quota configuration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Split business logic from mlxsw_sp_port_sb_pms_init() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Use new CPU ingress pool for control packets (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add pools for CPU traffic (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Remove assumption about pool order (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Forbid changing multicast TCs' attributes (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Forbid changing threshold type of first egress pool (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Forbid configuration of multicast pool (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add ability to veto TC's configuration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add ability to veto pool's configuration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Use defines for pool indices (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add extack messages for invalid configurations (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Relax FIB rule validation (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Use a stable ECMP/LAG seed (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Test neighbour offload indication (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Add neighbour offload indication (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Propagate neighbour update errors (Ivan Vecera) [1737368]
- [documentation] documentation: networking: devlink-info-versions: Add fw.psid (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add support for devlink info command (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add MGIR register (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: test for bridge mcast traffic after report and leave (Ivan Vecera) [1737368]
- [netdrv] mlxsw: switch_ib: Pass valid HW id down to mlxsw_core_port_init() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove ndo_get_port_parent_id implementation (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Pass switch ID through devlink_port_attrs_set() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Rename rehash_dis trace (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Remove failed_rollback dead end (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Move rehash_dis trace call and err msg to vregion_migrate() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Remove redundant failed_rollback from migrate_start() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove ndo_get_phys_port_name implementation (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Implement ndo_get_devlink_port (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Add a new test for strict priority (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Add qos_lib.sh (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: qos_mc_aware: Configure shared buffers (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: devlink_lib: Add shared buffer helpers (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: devlink_lib: Simplify deduction of DEVLINK_DEV (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: devlink_lib: Avoid double sourcing of lib.sh (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: Test action VLAN modify (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: Add PCP match and VLAN match tests (Ivan Vecera) [1737368]
- [infiniband] rdma/mlx5: Use irq xarray locking for mkey_table (Alaa Hleihel) [1724336]
- [netdrv] mlx4_core: Dynamically set guaranteed amount of counters per VF (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Initialize on stack link modes bitmap (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: fix ethtool self test: link speed (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix handling of compressed CQEs in case of low NAPI budget (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Don't store direct pointer to action's tunnel info (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix NULL pointer dereference in extended destination (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Only skip encap flows update when encap init failed (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Determine source port properly for vlan push action (Alaa Hleihel) [1724336]
- [kernel] mlx5: Fix flow counter list auto bits struct (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Clear old rate limit when closing QP (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Remove dead code (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix memory leak in mlx5_fw_fatal_reporter_dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5: prevent memory leak in mlx5_fpga_conn_create_cq (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: TX, Fix consumer index of error cqe dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Zero-memset WQE info struct upon update (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Fix assumption of single WQEBB of NOP in cleanup flow (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Add missing synchronize_srcu() for MW cases (Alaa Hleihel) [1724307 1724336]
- [infiniband] rdma/mlx5: Order num_pending_prefetch properly with synchronize_srcu (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Do not allow rereg of a ODP MR (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix matching on tunnel addresses type (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add device ID of upcoming BlueField-2 (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Free mpi in mp_slave mode (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Use the original address for the page during free_pages (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: FWTrace, Reduce stack usage (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Remove unnecessary clear_bit()s (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix spelling mistake "offlaods" -> "offloads" (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Remove leftover declaration (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: ethtool, Fix a typo in WOL function names (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add missing include file to lib/crypto.c (Alaa Hleihel) [1724336]
- [netdrv] mlx5: remove self-assignment on esw->dev (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support MLX5_CMD_OP_QUERY_LAG as a DEVX general command (Alaa Hleihel) [1724307 1724336]
- [kernel] mlx5: Fix mlx5_ifc_query_lag_out_bits (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix formats with line continuation whitespace (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix mlx5e_tx_reporter_create return value (Alaa Hleihel) [1724336]
- [kernel] mlx5: Fix offset of tisc bits reserved field (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix -Wtype-limits compilation warnings (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support per device q counters in switchdev mode (Alaa Hleihel) [1659186 1724336]
- [infiniband] ib/mlx5: Refactor code for counters allocation (Alaa Hleihel) [1659186 1724336]
- [netdrv] mlx5: DR, Replace CRC32 implementation to use kernel lib (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Support IPv4 and IPv6 mixed matcher (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Allow insertion of duplicate rules (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: avoid 64-bit division in dr_icm_pool_mr_create() (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5e: Fix traffic duplication in ethtool steering (Alaa Hleihel) [1724336]
- [netdrv] mlx5: DR, Allow matching on vport based on vhca_id (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Fix getting incorrect prev node in ste_free (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Remove redundant vport number from action (Alaa Hleihel) [1760284 1724336]
- [kernel] mlx5: DR, Fix SW steering HW bits and definitions (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix missing assignment of variable err (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Fix rt's type in dr_action_create_reformat_action (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Fix error return code in dr_domain_init_resources() (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Fix addr's type in mlx5dr_icm_dm (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add devlink flow_steering_mode parameter (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add support to use SMFS in switchdev mode (Alaa Hleihel) [1760284 1724327 1724336]
- [netdrv] mlx5: Add API to set the namespace steering mode (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add direct rule fs_cmd implementation (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add CONFIG_MLX5_SW_STEERING for software steering support (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose APIs for direct rule managing (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add required FW steering functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering rule functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering action functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering matcher functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering table functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering domain functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add Steering entry (STE) utilities (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose an internal API to issue RDMA operations (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, ICM pool memory allocator (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add direct rule command utilities (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add the internal direct rule types definitions (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add flow steering actions to fs_cmd shim layer (Alaa Hleihel) [1760284 1724327 1724336]
- [netdrv] mlx5: Set only stag for match untagged packets (Alaa Hleihel) [1760284 1724336]
- [kernel] mlx5: Add stub for mlx5_eswitch_mode (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Avoid disabling RoCE when uninitialized (Alaa Hleihel) [1760284 1724336]
- [kernel] mlx5: Add HW bits and definitions required for SW steering (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Move device memory management to mlx5_core (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5e: Support LAG TX port affinity distribution (Alaa Hleihel) [1760285 1724336]
- [netdrv] mlx5e: Expose new function for TIS destroy loop (Alaa Hleihel) [1760285 1724336]
- [kernel] mlx5: Add lag_tx_port_affinity capability bit (Alaa Hleihel) [1760285 1724336]
- [netdrv] mlx5e: Add device out of buffer counter (Alaa Hleihel) [1760291 1724336]
- [netdrv] mlx5: Fix the order of fc_stats cleanup (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix deallocation of non-fully init encap entries (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Only access fully initialized flows in neigh update (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Refactor neigh update for concurrent execution (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Refactor neigh used value update for concurrent execution (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect neigh hash encap list with spinlock and rcu (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Refactor mlx5e_neigh_update_table->encap_lock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend neigh hash entry with rcu (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Always take reference to neigh entry (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extract code that queues neigh update work into function (Alaa Hleihel) [1663231 1724336]
- [kernel] mlx5: Add support for VNIC_ENV internal rq counter (Alaa Hleihel) [1760291 1724336]
- [netdrv] mlx5e: Use refcount_t for refcount (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Use vhca_id in generating representor port_index (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Simplify querying port representor parent id (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5: E-switch, Removed unused hwid (Alaa Hleihel) [1663231 1724327 1724336]
- [netdrv] mlx5e: Allow concurrent creation of encap entries (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect encap hash table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend encap entry with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Allow concurrent creation of mod_hdr entries (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect mod_hdr hash table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect mod header entry flows list with spinlock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend mod header entry with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Allow concurrent creation of hairpin entries (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect hairpin hash table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect hairpin entry flows list with spinlock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend hairpin entry with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5: E-switch, Tide up eswitch config sequence (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Remove redundant mc_promisc NULL check (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, remove redundant error handling (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-switch, Introduce helper function to enable/disable vports (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-switch, Initialize TSAR Qos hardware block before its user vports (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-switch, Combine metadata enable/disable functionality (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Verify support QoS element type (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Make load_one() and unload_one() symmetric (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add flow counter pool (Alaa Hleihel) [1760297 1724336]
- [netdrv] mlx5: Add flow counter bulk infrastructure (Alaa Hleihel) [1760297 1724336]
- [kernel] mlx5: Add flow counter bulk allocation hardware bits and command (Alaa Hleihel) [1760297 1724336]
- [netdrv] mlx5: Refactor and optimize flow counter bulk query (Alaa Hleihel) [1760297 1724336]
- [netdrv] mlx5e: Protect tc flow table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Rely on rcu instead of rtnl lock when getting upper dev (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Eswitch, use state_lock to synchronize vlan change (Alaa Hleihel) [1663231 1724327 1724336]
- [netdrv] mlx5e: Eswitch, change offloads num_flows type to atomic64 (Alaa Hleihel) [1663231 1724327 1724336]
- [netdrv] mlx5e: Protect unready flows with dedicated lock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect tc flows hashtable with rcu (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Change flow flags type to unsigned long (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend tc flow struct with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Simplify get_route_and_out_devs helper function (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Improve ethtool rxnfc callback structure (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Avoid warning print when not required (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Print a warning when LRO feature is dropped or not allowed (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Remove ethernet segment from dump WQE (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Add num bytes metadata to WQE info (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix delay in fw fatal report handling due to fw report (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix crdump chunks print (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Block MR WR if UMR is not possible (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix MR re-registration flow to use UMR properly (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Report and handle ODP support properly (Alaa Hleihel) [1724308 1724336]
- [infiniband] ib/mlx5: Consolidate use_umr checks into single function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix compatibility issue with ethtool flash device (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix use-after-free error while accessing ev_file pointer (Alaa Hleihel) [1724307 1724336]
- [netdrv] mlx5e: Remove redundant check in CQE recovery flow of tx reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix error flow of CQE recovery on tx reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix false negative indication on tx reporter CQE recovery (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: kTLS, Fix tisn field placement (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: kTLS, Fix tisn field name (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: kTLS, Fix progress params context WQE layout (Alaa Hleihel) [1724336]
- [kernel] mlx5: kTLS, Fix wrong TIS opmod constants (Alaa Hleihel) [1724336]
- [netdrv] mlx5: crypto, Fix wrong offset in encryption key command (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: ethtool, Avoid setting speed to 56GBASE when autoneg off (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Only support tx/rx pause setting for port owner (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Support inner header match criteria for non decap flow action (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Use flow keys dissector to parse packets for ARFS (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Check the correct variable in error handling code (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Fix implicit MR release flow (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5e: always initialize frag->last_in_page (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Release locks during notifier unregister (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix MR registration flow to use UMR properly (Alaa Hleihel) [1764207 1724336]
- [netdrv] mlx5e: kTLS, Call WARN_ONCE on netdev mismatch (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Prevent encap flow counter update async to user query (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix matching of speed to PRM link modes (Alaa Hleihel) [1724336]
- [kernel] mlx5: Fix modify_cq_in alignment (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add missing RDMA_RX capabilities (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Use reversed order when unregister devices (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix RSS Toeplitz setup to be aligned with the HW specification (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Prevent concurrent MR updates during invalidation (Alaa Hleihel) [1724308 1724336]
- [infiniband] ib/mlx5: Fix clean_mr() to work in the expected order (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Move MRs to a kernel PD when freeing them to the MR cache (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Use direct mkey destroy command upon UMR unreg failure (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix unreg_umr to ignore the mkey state (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Replace kfree with kvfree (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Replace kfree with kvfree (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Rely on filter_dev instead of dissector keys for tunnels (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Verify encapsulation is supported (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Convert single case statement switch statements into if statements (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Reduce ingress acl modify metadata stack usage (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Fix compilation error in TLS code (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: IPoIB, Add error path in mlx5_rdma_setup_rn (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix error flow in tx reporter diagnose (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix return value from timeout recover function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Rx, Fix checksum calculation for new hardware (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix port tunnel GRE entropy control (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Fix default encap mode (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Return in default case statement in tx_post_resync_params (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Register devlink ports for physical link, PCI PF, VFs (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Set RDMA DIM to be enabled by default (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Report correctly tag matching rendezvous capability (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Implement VHCA tunnel mechanism in DEVX (Alaa Hleihel) [1724307 1724336]
- [kernel] mlx5: Introduce VHCA tunnel device capability (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Add kTLS TX HW offload support (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Introduce a fenced NOP WQE posting function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Re-work TIS creation functions (Alaa Hleihel) [1760285 1724336]
- [netdrv] mlx5e: Tx, Unconstify SQ stop room (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Don't implicitly assume SKB-less wqe has one WQEBB (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Make SQ WQE fetch function type generic (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Enforce L4 inline copy when needed (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Move helper functions to a new txrx datapath header (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Accel, Add core TLS support for the Connect-X family (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add crypto library to support create/destroy encryption key (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Kconfig, Better organize compilation flags (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Accel, Expose accel wrapper for IPsec FPGA function (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Add counter_alloc_stats() and counter_update_stats() support (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support statistic q counter configuration (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Add counter set id as a parameter for mlx5_ib_query_q_counters() (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support set qp counter (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Added devlink info callback (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Added fw version query command (Alaa Hleihel) [1724336]
- [kernel] mlx5: Add rts2rts_qp_counters_set_id field in hca cap (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Use proper allocation API to get zeroed memory (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: DEVX cleanup mdev (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Add DEVX support for CQ events (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Implement DEVX dispatching event (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Enable subscription for device events over DEVX (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Register DEVX with mlx5_core to get async events (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Introduce MLX5_IB_OBJECT_DEVX_ASYNC_EVENT_FD (Alaa Hleihel) [1724307 1724336]
- [kernel] mlx5: Properly name the generic WQE control field (Alaa Hleihel) [1724336]
- [kernel] mlx5: Introduce TLS TX offload hardware bits and structures (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Refactor mlx5_esw_query_functions for modularity (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch prepare functions change handler to be modular (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Introduce and use mlx5_eswitch_get_total_vports() (Alaa Hleihel) [1724327 1724336]
- [infiniband] ib/mlx5: Fixed reporting counters on 2nd port for Dual port RoCE (Alaa Hleihel) [1724336]
- [kernel] mlx5: Expose device definitions for object events (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report EQE data upon CQ completion (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report a CQ error event only when a handler was set (Alaa Hleihel) [1724336]
- [netdrv] mlx5: mlx5_core_create_cq() enhancements (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Expose the API to register for ANY event (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Use event mask based on device capabilities (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Fix mlx5_core_destroy_cq() error flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Handle UC address change in switchdev mode (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Consider host PF for inline mode and vlan pop (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Use iterator for vlan and min-inline setups (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Reg/unreg function changed event at correct stage (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Consolidate eswitch function number of VFs (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Refactor eswitch SR-IOV interface (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Handle host PF vport mac/guid for ECPF (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Use correct flags when configuring vlan (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Reduce dependency on enabled_vfs counter and num_vfs (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Don't handle VF func change if host PF is disabled (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Limit scope of mlx5_get_next_phys_dev() to PCI PF devices (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move pci status reg access mutex to mlx5_pci_init (Alaa Hleihel) [1724336]
- [kernel] mlx5: Rename mlx5_pci_dev_type to mlx5_coredev_type (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Cleanup rep when doing unload (Alaa Hleihel) [1724336]
- [infiniband] {ib, net}/mlx5: E-Switch, Use index of rep for vport to IB port mapping (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Use vport index when init rep (Alaa Hleihel) [1724327 1724336]
- [kernel] mlx5: Added MCQI and MCQS registers' description to ifc (Alaa Hleihel) [1724336]
- [kernel] mlx5: Add hardware definitions for sub functions (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Disallow tc redirect offload cases we don't support (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Expose same physical switch_id for all representors (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Don't refresh TIRs when updating representor SQs (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: reduce stack usage in mlx5_eswitch_termtbl_create (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Set drvinfo in generic manner (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Correct phys_port_name for PF port (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Report netdevice MPLS features (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Move to HW checksumming advertising (Alaa Hleihel) [1724336]
- [netdrv] mlx5: MPFS, Allow adding the same MAC more than once (Alaa Hleihel) [1724336]
- [netdrv] mlx5: MPFS, Cleanup add MAC flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Move queue param structs to en/params.h (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Encapsulate open/close queues into a function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Consider XSK in XDP MTU limit calculation (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: XDP_TX from UMEM support (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Share the XDP SQ for XDP_TX between RQs (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Refactor struct mlx5e_xdp_info (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Allow ICO SQ to be used by multiple RQs (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Calculate linear RX frag size considering XSK (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Replace deprecated PCI_DMA_TODEVICE (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Attach/detach XDP program safely (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Enable vport metadata matching if firmware supports it (Alaa Hleihel) [1724327 1724336]
- [infiniband] rdma/mlx5: Add vport metadata matching for IB representors (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Add match on vport metadata for rule in slow path (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Pass metadata from FDB to eswitch manager (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Add query and modify esw vport context functions (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Add match on vport metadata for rule in fast path (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Specifying known origin of packets matching the flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Tag packet with vport number in VF vports and uplink ingress ACLs (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Add flow context for flow tag (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Introduce a helper API to check VF vport (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Support allocating modify header context from ingress ACL (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Get vport ACL namespace by vport index (Alaa Hleihel) [1724336]
- [kernel] mlx5: Introduce vport metadata matching bits and enum constants (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Convert mkey_table to XArray (Alaa Hleihel) [1724308 1724307 1724336]
- [infiniband] rdma/mlx5: Refactor MR descriptors allocation (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Use PA mapping for PI handover (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Improve PI handover performance (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Remove unused IB_WR_REG_SIG_MR code (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Enable decap and packet reformat on FDB (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Consider eswitch encap mode (Alaa Hleihel) [1724336]
- [netdrv] mlx5: add missing void argument to function mlx5_devlink_alloc (Alaa Hleihel) [1724336]
- [kernel] mlx5: Expose eswitch encap mode (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Declare more strictly devlink encap mode (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: use indirect calls wrapper for the rx packet handler (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: use indirect calls wrapper for skb allocation (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report devlink health on FW fatal issues (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add support for FW fatal reporter dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add fw fatal devlink_health_reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report devlink health on FW issues (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add support for FW reporter dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Create FW devlink_health_reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Issue SW reset on FW assert (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Control CR-space access by different PFs (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Handle SW reset of FW in error flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add Crdump support (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add Vendor Specific Capability access gateway (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move all devlink related functions calls to devlink.c (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add EQ enable/disable API (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Use a single IRQ for all async EQs (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Rename mlx5_irq_info to mlx5_irq (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move all IRQ logic to pci_irq.c (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Generalize IRQ interface to work with irq_table (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Separate IRQ table creation from EQ table creation (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move IRQ affinity set to IRQ allocation phase (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move IRQ rmap creation to IRQ allocation phase (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Separate IRQ data from EQ table data (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Separate IRQ request/free from EQ life cycle (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Change interrupt handler to call chain notifier (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Introduce EQ polling budget (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Support querying max VFs from device (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Return raw output for query esw functions (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Handle representors creation in handler context (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Increase wait time for fw initialization (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move firmware flash implementation to devlink (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: TX, Improve performance under GSO workload (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Use termination table for VLAN push actions (Alaa Hleihel) [1722647 1724327 1724336]
- [netdrv] mlx5e: Geneve, Add support for encap/decap flows offload (Alaa Hleihel) [1725582 1724336]
- [netdrv] mlx5e: Rearrange tc tunnel code in a modular way (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Geneve, Keep tunnel info as pointer to the original struct (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Geneve, Manage Geneve TLV options (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Enable setting multiple match criteria for flow group (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Allow matching only enc_key_id/enc_dst_port for decapsulation action (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Generalize vport type in vport representor (Alaa Hleihel) [1724336]
- [netdrv] {ib, net}/mlx5: Constify rep ops functions pointers (Alaa Hleihel) [1724327 1724336]
- [netdrv] {ib, net}/mlx5: No need to typecast from void* to mlx5_ib_dev* (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Honor eswitch functions changed event cap (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Replace host_params event with functions_changed event (Alaa Hleihel) [1724327 1724336]
- [kernel] mlx5: Introduce termination table bits (Alaa Hleihel) [1722647 1724336]
- [kernel] mlx5: Add core dump register access HW bits (Alaa Hleihel) [1724336]
- [netdrv] mlx5: potential error pointer dereference in error handling (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Support tagged tunnel over bond (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Avoid detaching non-existing netdev under switchdev mode (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix source port matching in fdb peer flow rule (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Replace reciprocal_scale in TX select queue function (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Avoid reloading already removed devices (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Update pci error handler entries and command translation (Alaa Hleihel) [1724335]
- [infiniband] mlx5: avoid 64-bit division (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Disable rxhash when CQE compress is enabled (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: restrict the real_dev of vlan device is the same as uplink device (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Allocate root ns memory using kzalloc to match kfree (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Avoid double free in fs init error unwinding path (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Avoid double free of root ns in the error flow path (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Fix error handling in mlx5_load() (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix possible modify header actions memory leak (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix no rewrite fields with the same match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Additional check for flow destination comparison (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Add missing ethtool driver info for representors (Alaa Hleihel) [1766306 1724335]
- [netdrv] mlx5e: Fix number of vports for ingress ACL configuration (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix ethtool rxfh commands when CONFIG_MLX5_EN_RXNFC is disabled (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Fix peer pf disable hca command (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Correct type to u16 for vport_num and int for vport_index (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add meaningful return codes to status_to_err function (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Imply MLXFW in mlx5_core (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Set completion EQs as shared resources (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Verify DEVX general object type correctly (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Remove MAYEXEC flag (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Device resource control for privileged DEVX user (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Add steering SW ICM device memory type (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Warn on allocated MEMIC buffers during cleanup (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Support device memory type attribute (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Add missing XRC options to QP optional params mask (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Use atomic rep state to serialize state change (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Fix the check of legal vport (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Use getter to access all vport array (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Use available mlx5_vport struct (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Reuse mlx5_esw_for_each_vf_vport macro in two files (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Remove unused mlx5_query_nic_vport_vlans (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: remove meaningless CFLAGS_tracepoint.o (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Put the common XDP code into a function (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: ethtool, Add support for EEPROM high pages query (Alaa Hleihel) [1724322 1724335]
- [netdrv] mlx5e: Return error when trying to insert existing flower filter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Replace TC VLAN pop with VLAN 0 rewrite in prio tag mode (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: ACLs for priority tag mode (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Turn on HW tunnel offload in all TIRs (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Take common TIR context settings into a function (Alaa Hleihel) [1724335]
- [kernel] mlx5: Fix broken hca cap offset (Alaa Hleihel) [1725554 1724335]
- [kernel] mlx5: Geneve, Add flow table capabilities for Geneve decap with TLV options (Alaa Hleihel) [1725554 1724335]
- [kernel] mlx5: Geneve, Add basic Geneve encap/decap flow table capabilities (Alaa Hleihel) [1725554 1724335]
- [netdrv] mlx5: Eswitch, enable RoCE loopback traffic (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add new miss flow table action (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add support in RDMA RX steering (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Pass flow steering objects to fs_cmd (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Enable general events on all interfaces (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Restrict 'DELAY_DROP_TIMEOUT' subtype to Ethernet interfaces (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Separate and generalize dma device from pci device (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Get rid of storing copy of device name (Alaa Hleihel) [1724335]
- [kernel] mlx5: e-switch: Introduce prio tag mode (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Expose TIR ICM address to user space (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Introduce new TIR creation core API (Alaa Hleihel) [1724335]
- [kernel] mlx5: Expose TIR ICM address in command outbox (Alaa Hleihel) [1724335]
- [kernel] mlx5: Expose SW ICM related device memory capabilities (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Use #define for the WQE wait timeout constant (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove unused rx_page_reuse stat (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Take HW interrupt trigger into a function (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove unused parameter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Add an underflow warning comment (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Move parameter calculation functions to en/params.c (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Report mlx5e_xdp_set errors (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove unused parameter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Inline small packets into the TX MPWQE in XDP xmit flow (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Add TX MPWQE session counter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Enhance RQ indication for XDP redirect flush (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Fix shifted flag index in RQ bitmap (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: RX, Support multiple outstanding UMR posts (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Don't create IB representors when in multiport RoCE mode (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Initialize roce port info before multiport master init (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Allow DEVX and raw creation flow on reps (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Add query e-switch vport context to devx white list (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Allow inserting a steering rule to the FDB (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Create flow table with max size supported (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Access the prio bypass inside the FDB flow table namespace (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Check for error return in flow_rule rather than err (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Remove VF representor profile (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move to single device multiport ports in switchdev mode (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move SMI caps logic (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Refactor netdev affinity code (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move default representors SQ steering to rule to modify QP (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move rep into port struct (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Use correct size for device resources (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move ports allocation to outside of INIT stage (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Free IB device on remove (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move netdev info into the port struct (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, add a new prio to be used by the RDMA side (Alaa Hleihel) [1724335]
- [kernel] mlx5: E-Switch, don't use hardcoded values for FDB prios (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Remove references to uboject->context (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Unify logic of MTU boundaries (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Obsolete param field holding a constant value (Alaa Hleihel) [1724335]
- [netdrv] mlx5: A write memory barrier is sufficient in EQ ci update (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Do not rewrite fields with the same match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Offload TC e-switch rules with ingress VLAN device (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Offload TC e-switch rules with egress VLAN device (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Allow VLAN rewrite of prio field with the same match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Deny VLAN rewrite if there is no VLAN header match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Use helpers to get headers criteria and value pointers (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Return -EOPNOTSUPP when attempting to offload an unsupported action (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Deletes unnecessary setting of esw_attr->parse_attr (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove 'parse_attr' argument in parse_tc_fdb_actions() (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Make the log friendly when decapsulation offload not supported (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Fix double mutex initialization (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Handle event of power detection in the PCIE slot (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Cleanup WQE page fault handler (Alaa Hleihel) [1724335]
- [kernel] mlx5: Expose MPEIN (Management PCIE INfo) register layout (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add rate limit print macros (Alaa Hleihel) [1724335]
- [infiniband] mlx5: Add explicit bar address field (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Replace dev_err/warn/info by mlx5_core_err/warn/info (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Use dev->priv.name instead of dev_name (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Make mlx5_core messages independent from mdev->pdev (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Break load_one into three stages (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Function setup/teardown procedures (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Move health and page alloc init to mdev_init (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Split mdev init and pci init (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Remove redundant init functions parameter (Alaa Hleihel) [1724335]
- [kernel] mlx5: Remove spinlock support from mlx5_write64 (Alaa Hleihel) [1724335]
- [kernel] mlx5: Remove unused MLX5_*_DOORBELL_LOCK macros (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Declare devx_async_cmd_event_fops static (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Compare only index part of a memory window rkey (Alaa Hleihel) [1724335]
- [infiniband] mlx5: Convert mlx5_srq_table to XArray (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Replace TC VLAN pop and push actions with VLAN modify (Alaa Hleihel) [1722646 1724335]
- [netdrv] mlx5e: Support VLAN modify action (Alaa Hleihel) [1722646 1724335]
- [netdrv] mlx5e: Add VLAN ID rewrite fields (Alaa Hleihel) [1722646 1724335]
- [netdrv] mlx5e: TX, Add geneve tunnel stateless offload support (Alaa Hleihel) [1722661 1724335]
- [netdrv] mlx5e: Take SW parser code to a separate function (Alaa Hleihel) [1722661 1724335]
- [netdrv] mlx5e: Fix port buffer function documentation format (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Simplify mlx5_sriov_is_enabled() by using pci core API (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Rename total_vfs to total_vports (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Simplify sriov enable/disable flow (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Use rdma_user_map_io for mapping BAR pages (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: ethtool, Remove unsupported SFP EEPROM high pages query (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Switch to Toeplitz RSS hash by default (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Protect against non-uplink representor for encap (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Rx, Fixup skb checksum for packets with tail padding (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: XDP, Avoid checksum complete when XDP prog is loaded (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Use fail-safe channels reopen in tx reporter recover (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Skip un-needed tx recover if interface state is down (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Update xon formula (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Update xoff formula (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, fix syndrome (0x678139) when turn on vepa (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5: E-Switch, Protect from invalid memory access in offload fdb table (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Fix access to invalid memory when toggling esw modes (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5e: Add a lock on tir list (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Fix error handling when refreshing TIRs (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Decrease default mr cache size (Alaa Hleihel) [1748518 1724333]
- [infiniband] ib/mlx5: Reset access mask when looping inside page fault handler (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Avoid panic when setting vport rate (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Avoid panic when setting vport mac, getting vport config (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: IPoIB, Fix RX checksum statistics update (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Remove redundant lag function to get pf num (Alaa Hleihel) [1724333]
- [netdrv] mlx5: ODP support for XRC transport is not enabled by default in FW (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Update tx reporter status in case channels were successfully opened (Alaa Hleihel) [1722274 1724333]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Set correct write permissions for implicit ODP MR (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Declare mlx5e_tx_reporter_recover_from_ctx as static (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Support ndo bridge_setlink and getlink (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5: E-Switch, Add support for VEPA in legacy mode (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5e: Fix mlx5e_tx_reporter_create return value (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Fix return status of TX reporter timeout recover (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Re-add support for TX timeout when TX reporter is not valid (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Fix warn print in case of TX reporter creation failure (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Disable esw manager vport correctly (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Fix the warning on vport index out of range (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Delete unused FPGA QPN variable (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Wrap the open and apply of channels in one fail-safe function (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Factor out HCA capabilities functions (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Allow transition to offloads mode for ECPF (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Load/unload VF reps according to event from host PF (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Consider ECPF vport depends on eswitch ownership (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Assign a different position for uplink rep and vport (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Centralize repersentor reg/unreg to eswitch driver (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Support load/unload reps of specific vport types (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Add state to eswitch vport representors (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Use getter and iterator to access vport/rep (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Split VF and special vports for offloads mode (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Refactor offloads flow steering init/cleanup (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Properly refer to host PF vport as other vport (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Properly refer to the esw manager vport (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Correctly set LAG mode for ECPF (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Avoid magic numbers when initializing offloads mode (Alaa Hleihel) [1724333]
- [kernel] mlx5: Relocate vport macros to the vport header file (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Normalize the name of uplink vport number (Alaa Hleihel) [1724333]
- [kernel] mlx5: Provide an alternative VF upper bound for ECPF (Alaa Hleihel) [1724333]
- [kernel] mlx5: Add host params change event (Alaa Hleihel) [1724333]
- [kernel] mlx5: Add query host params command (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Update enable HCA dependency (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Introduce Mellanox SmartNIC and modify page management logic (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Use unified register/load function for uplink and VF vports (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Use consistent vport num argument type (Alaa Hleihel) [1724333]
- [kernel] mlx5: Use void pointer as the type in address_of macro (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Align ODP capability function with netdev coding style (Alaa Hleihel) [1724333]
- [netdrv] mlx5: use RCU lock in mlx5_eq_cq_get() (Alaa Hleihel) [1724333]
- [infiniband] rdma/mlx5: Fix memory leak in case we fail to add an IB device (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Simplify WQE count power of two check (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Add tx timeout support for mlx5e tx reporter (Alaa Hleihel) [1722274 1724333]
- [netdrv] mlx5e: Add tx reporter support (Alaa Hleihel) [1722274 1724333]
- [infiniband] ib/mlx5: Advertise XRC ODP support (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Advertise SRQ ODP support for supported transports (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Add ODP SRQ support (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Let read user wqe also from SRQ buffer (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Add XRC initiator ODP support (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Clean mlx5_ib_mr_responder_pfault_handler() signature (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Remove useless check in ODP handler (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Set ODP SRQ support in firmware (Alaa Hleihel) [1724333]
- [kernel] mlx5: Add XRC transport to ODP device capabilities layout (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Implement DEVX hot unplug for async command FD (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Implement the file ops of DEVX async command FD (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Reuse fold sw stats in representors (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Present the representors SW stats when state is not opened (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Separate between ethtool and netdev software stats folding (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Add trace points for flow tables create/destroy (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Expand XPS cpumask to cover all online cpus (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Take CQ decompress fields into a separate structure (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: RX, Make sure packet header does not cross page boundary (Alaa Hleihel) [1724333]
- [infiniband] mlx5: no need to check return value of debugfs_create functions (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Add pci AtomicOps request (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Don't override existing ip_protocol (Alaa Hleihel) [1724333]
- [infiniband] rdma/mlx5: Replace kzalloc with kcalloc (Alaa Hleihel) [1724333]
- [documentation] netfilter: doc: Add nf_tables part in tproxy.txt (Phil Sutter) [1762977]
- [net] netfilter: nft_socket: fix erroneous socket assignment (Phil Sutter) [1762977]
- [net] netfilter: nft_socket: Break evaluation if no socket found (Phil Sutter) [1762977]
- [net] netfilter: nft_tproxy: Fix missing-braces warning (Phil Sutter) [1762977]
- [net] netfilter: nft_tproxy: Add missing config check (Phil Sutter) [1762977]
- [net] netfilter: nf_tables: Add native tproxy support (Phil Sutter) [1762977]
- [net] netfilter: nft_tproxy: Move nf_tproxy_assign_sock() to nf_tproxy.h (Phil Sutter) [1762977]
- [net] sched: ensure opts_len <= IP_TUNNEL_OPTS_MAX in act_tunnel_key (Ivan Vecera) [1774706]
- [net] ipmr: Fix skb headroom in ipmr_get_route(). (Guillaume Nault) [1773692]
- [net] netns: fix GFP flags in rtnl_net_notifyid() (Guillaume Nault) [1763661]
- [net] netns: fix NLM_F_ECHO mechanism for RTM_NEWNSID (Guillaume Nault) [1763661]
- [netdrv] ptp: ptp_clock: Publish scaled_ppm_to_ppb (Ivan Vecera) [1772085]
- [kernel] rh_features: move rh_features entry to sys/kernel (Hangbin Liu) [1660583]
- [net] netfilter: nf_tables: Make nft_meta expression more robust (Phil Sutter) [1725169]
- [tools] selftests/tls: add test for concurrent recv and send (Sabrina Dubroca) [1760375]
- [net] tls: add a TX lock (Sabrina Dubroca) [1760375]
- [net] tls: don't pay attention to sk_write_pending when pushing partial records (Sabrina Dubroca) [1760375]
- [net] tls: fix sk_msg trim on fallback to copy mode (Sabrina Dubroca) [1760375]
- [net] tls: align non temporal copy to cache lines (Sabrina Dubroca) [1760375]
- [net] tls: remove the record tail optimization (Sabrina Dubroca) [1760375]
- [net] tls: use RCU for the adder to the offload record list (Sabrina Dubroca) [1760375]
- [net] tls: unref frags in order (Sabrina Dubroca) [1760375]
- [net] tcp: ulp: fix possible crash in tcp_diag_get_aux_size() (Sabrina Dubroca) [1760375]
- [net] tls: dedup the record cleanup (Sabrina Dubroca) [1760375]
- [net] tls: clean up the number of #ifdefs for CONFIG_TLS_DEVICE (Sabrina Dubroca) [1760375]
- [net] tls: narrow down the critical area of device_offload_lock (Sabrina Dubroca) [1760375]
- [net] tls: don't jump to return (Sabrina Dubroca) [1760375]
- [net] tls: export protocol version, cipher, tx_conf/rx_conf to socket diag (Sabrina Dubroca) [1760375]
- [net] tcp: ulp: add functions to dump ulp-specific information (Sabrina Dubroca) [1760375]
- [net] tls: use RCU protection on icsk->icsk_ulp_data (Sabrina Dubroca) [1760375]
- [net] core/skmsg: Delete an unnecessary check before the function call "consume_skb" (Sabrina Dubroca) [1760375]
- [net] tls, fix sk_write_space NULL write when tx disabled (Sabrina Dubroca) [1760375]
- [net] tls: swap sk_write_space on close (Sabrina Dubroca) [1760375]
- [net] tls: prevent skb_orphan() from leaking TLS plain text with offload (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add a litmus test for the socket reuse through shutdown (Sabrina Dubroca) [1760375]
- [net] tls: partially revert fix transition through disconnect with close (Sabrina Dubroca) [1760375]
- [documentation] TLS: fix stat counters description (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: fix TLS tests with CONFIG_TLS=n (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add shutdown tests (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: close the socket with open record (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add a bidirectional test (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: test error codes around TLS ULP installation (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add a test for ULP but no keys (Sabrina Dubroca) [1760375]
- [net] bpf: sockmap/tls, close can race with map free (Sabrina Dubroca) [1760375]
- [net] tls: fix transition through disconnect with close (Sabrina Dubroca) [1760375]
- [net] tls: remove sock unlock/lock around strp_done() (Sabrina Dubroca) [1760375]
- [net] tls: remove close callback sock unlock/lock around TX work flush (Sabrina Dubroca) [1760375]
- [net] tls: don't call tls_sk_proto_close for hw record offload (Sabrina Dubroca) [1760375]
- [net] tls: don't arm strparser immediately in tls_set_sw_offload() (Sabrina Dubroca) [1760375]
- [net] tls: add missing prot info init (Sabrina Dubroca) [1760375]
- [netdrv] mlx5: Return -EINVAL when WARN_ON_ONCE triggers in mlx5e_tls_resync(). (Sabrina Dubroca) [1760375]
- [net] tls: don't clear TX resync flag on error (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add test for poll() with data in TLS ULP (Sabrina Dubroca) [1760375]
- [net] tls: add kernel-driven resync mechanism for TX (Sabrina Dubroca) [1760375]
- [net] tls: generalize the resync callback (Sabrina Dubroca) [1760375]
- [net] tls: add kernel-driven TLS RX resync (Sabrina Dubroca) [1760375]
- [net] tls: rename handle_device_resync() (Sabrina Dubroca) [1760375]
- [net] tls: pass record number as a byte array (Sabrina Dubroca) [1760375]
- [net] tls: simplify seq calculation in handle_device_resync() (Sabrina Dubroca) [1760375]
- [net] tls: export TLS per skb encryption (Sabrina Dubroca) [1760375]
- [include] net/tls: simplify driver context retrieval (Sabrina Dubroca) [1760375]
- [include] net/tls: split the TLS_DRIVER_STATE_SIZE and bump TX to 16 bytes (Sabrina Dubroca) [1760375]
- [net] tls: don't pass version to tls_advance_record_sn() (Sabrina Dubroca) [1760375]
- [include] net/tls: reorganize struct tls_context (Sabrina Dubroca) [1760375]
- [net] tls: use version from prot (Sabrina Dubroca) [1760375]
- [net] tls: don't re-check msg decrypted status in tls_device_decrypted() (Sabrina Dubroca) [1760375]
- [net] tls: don't look for decrypted frames on non-offloaded sockets (Sabrina Dubroca) [1760375]
- [net] tls: remove false positive warning (Sabrina Dubroca) [1760375]
- [net] tls: check return values from skb_copy_bits() and skb_store_bits() (Sabrina Dubroca) [1760375]
- [net] tls: fully initialize the msg wrapper skb (Sabrina Dubroca) [1760375]
- [net] tls: replace the sleeping lock around RX resync with a bit lock (Sabrina Dubroca) [1760375]
- [net] revert "net/tls: avoid NULL-deref on resync during device removal" (Sabrina Dubroca) [1760375]
- [net] tls: avoid NULL-deref on resync during device removal (Sabrina Dubroca) [1760375]
- [net] tls: Add support of AES128-CCM based ciphers (Sabrina Dubroca) [1760375]
- [documentation] add TLS offload documentation (Sabrina Dubroca) [1760375]
- [documentation] tls: RSTify the ktls documentation (Sabrina Dubroca) [1760375]
- [net] xdp: increase kABI version (Jiri Benc) [1749817]
- [tools] selftests: bpf: disable test_seg6_loop test (Jiri Benc) [1749817]
- [tools] selftests: bpf: fix test_tc_tunnel hanging (Jiri Benc) [1749817]
- [tools] selftests: bpf: xdping is not meant to be run standalone (Jiri Benc) [1749817]
- [tools] libbpf: Use implicit XSKMAP lookup from AF_XDP XDP program (Jiri Benc) [1749817]
- [lib] bpf, testing: Introduce 'gso_linear_no_head_frag' skb_segment test (Jiri Benc) [1749817]
- [lib] bpf, testing: Refactor test_skb_segment() for testing skb_segment() on different skbs (Jiri Benc) [1749817]
- [tools] selftests/bpf: test_progs: Don't leak server_fd in tcp_rtt (Jiri Benc) [1749817]
- [tools] selftests/bpf: test_progs: fix client/server race in tcp_rtt (Jiri Benc) [1749817]
- [net] flow_dissector: Fix potential use-after-free on BPF_PROG_DETACH (Jiri Benc) [1749817]
- [tools] selftests/bpf: fix race in test_tcp_rtt test (Jiri Benc) [1749817]
- [net] xdp: unpin xdp umem pages in error path (Jiri Benc) [1749817]
- [net] sock: make cookie generation global instead of per netns (Jiri Benc) [1749817]
- [net] bpfilter: add "WITH Linux-syscall-note" to SPDX tag of uapi headers (Jiri Benc) [1749817]
- [net] bpf: sockmap, only create entry if ulp is not already enabled (Jiri Benc) [1749817]
- [net] bpf: sockmap, synchronize_rcu before free'ing map (Jiri Benc) [1749817]
- [net] bpf: sockmap, sock_map_delete needs to use xchg (Jiri Benc) [1749817]
- [net] core: page_pool: add user refcnt and reintroduce page_pool_destroy (Jiri Benc) [1749817]
- [net] bpf: avoid unused variable warning in tcp_bpf_rtt() (Jiri Benc) [1749817]
- [net] xdp: fix potential deadlock on socket mutex (Jiri Benc) [1749817]
- [net] bpfilter: print umh messages to /dev/kmsg (Jiri Benc) [1749817]
- [net] xdp: fix possible cq entry leak (Jiri Benc) [1749817]
- [net] xdp: fix race on generic receive path (Jiri Benc) [1749817]
- [samples] bpf: fix tcp_bpf.readme detach command (Jiri Benc) [1749817]
- [samples] bpf: add sample program that periodically dumps TCP stats (Jiri Benc) [1749817]
- [tools] selftests/bpf: test BPF_SOCK_OPS_RTT_CB (Jiri Benc) [1749817]
- [tools] bpf/tools: sync bpf.h (Jiri Benc) [1749817]
- [net] bpf: add icsk_retransmits to bpf_tcp_sock (Jiri Benc) [1749817]
- [net] bpf: add dsack_dups/delivered{, _ce} to bpf_tcp_sock (Jiri Benc) [1749817]
- [net] bpf: split shared bpf_tcp_sock and bpf_sock_ops implementation (Jiri Benc) [1749817]
- [net] bpf: add BPF_CGROUP_SOCK_OPS callback that is executed on every RTT (Jiri Benc) [1749817]
- [net] init/kconfig: add CONFIG_CC_CAN_LINK (Jiri Benc) [1749817]
- [net] page_pool: add helper function for retrieving dma direction (Jiri Benc) [1749817]
- [net] xdp: fix hang while unregistering device bound to xdp socket (Jiri Benc) [1749817]
- [net] xdp: hold device for umem regardless of zero-copy mode (Jiri Benc) [1749817]
- [net] xsk: Change the default frame size to 4096 and allow controlling it (Jiri Benc) [1749817]
- [tools] libbpf: Support getsockopt XDP_OPTIONS (Jiri Benc) [1749817]
- [net] xsk: Add getsockopt XDP_OPTIONS (Jiri Benc) [1749817]
- [net] xsk: Add API to check for available entries in FQ (Jiri Benc) [1749817]
- [net] xsk: Properly terminate assignment in xskq_produce_flush_desc (Jiri Benc) [1749817]
- [net] xdp: Make __mem_id_disconnect static (Jiri Benc) [1749817]
- [net] xsk: sample kernel code is now in libbpf (Jiri Benc) [1749817]
- [net] page_pool: fix compile warning when CONFIG_PAGE_POOL is disabled (Jiri Benc) [1749817]
- [net] page_pool: make sure struct device is stable (Jiri Benc) [1749817]
- [net] page_pool: add tracepoints for page_pool with details need by XDP (Jiri Benc) [1749817]
- [net] xdp: add tracepoints for XDP mem (Jiri Benc) [1749817]
- [net] xdp: force mem allocator removal and periodic warning (Jiri Benc) [1749817]
- [net] xdp: tracking page_pool resources and safe removal (Jiri Benc) [1749817]
- [netdrv] mlx5: more strict use of page_pool API (Jiri Benc) [1749817]
- [net] page_pool: introduce page_pool_free and use in mlx5 (Jiri Benc) [1749817]
- [net] veth: use xdp_release_frame for XDP_PASS (Jiri Benc) [1749817]
- [net] xdp: page_pool related fix to cpumap (Jiri Benc) [1749817]
- [net] xdp: fix leak of IDA cyclic id if rhashtable_insert_slow fails (Jiri Benc) [1749817]
- [net] page_pool: add helper function to unmap dma addresses (Jiri Benc) [1749817]
- [net] page_pool: add helper function to retrieve dma addresses (Jiri Benc) [1749817]
- [net] page_pool: use DMA_ATTR_SKIP_CPU_SYNC for DMA mappings (Jiri Benc) [1749817]
- [net] page_pool: don't use page->private to store dma_addr_t (Jiri Benc) [1749817]
- [mm] add dma_addr_t to struct page (Jiri Benc) [1749817]
- [tools] bpf: Sync asm-generic/socket.h to tools/ (Jiri Benc) [1749817]
- [net] bpf: net: Add SO_DETACH_REUSEPORT_BPF (Jiri Benc) [1749817]
- [net] veth: Support bulk XDP_TX (Jiri Benc) [1749817]
- [net] flow_dissector: remove unused FLOW_DISSECTOR_F_STOP_AT_L3 flag (Jiri Benc) [1749817]
- [tools] selftests/bpf: fix compilation error for flow_dissector.c (Jiri Benc) [1749817]
- [net] bpf: Update BPF_CGROUP_RUN_PROG_INET_EGRESS calls (Jiri Benc) [1749817]
- [net] signal/bpfilter: Fix bpfilter_kernl to use send_sig not force_sig (Jiri Benc) [1749817]
- [net] arch: Use asm-generic/socket.h when possible (Jiri Benc) [1749817]
- [net] flow_dissector: correct comments on enum flow_dissector_key_id (Jiri Benc) [1749817]
- [net] tcp: add stat of data packet reordering events (Jiri Benc) [1749817]
- [net] tcp: add dsack blocks received stats (Jiri Benc) [1749817]
- [net] tcp: add data bytes retransmitted stats (Jiri Benc) [1749817]
- [net] tcp: add data bytes sent stats (Jiri Benc) [1749817]
- [net] tcp: add a helper to calculate size of opt_stats (Jiri Benc) [1749817]
- [net] netfilter: Support iif matches in POSTROUTING (Phil Sutter) [1775961]
- [tools] selftests: add basic netdevsim devlink flash testing (Petr Oros) [1770359]
- [netdrv] netdevsim: implement fake flash updating with notifications (Petr Oros) [1770359]
- [net] devlink: allow driver to update progress of flash update (Petr Oros) [1770359]
- [net] devlink: Add extack to shared buffer operations (Petr Oros) [1770347]
- [net] xfrm: policy: avoid warning splat when merging nodes (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix bydst hlist corruption on hash rebuild (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix infinite loop when merging src-nodes (Sabrina Dubroca) [1758100]
- [tools] selftests: xfrm: alter htresh to trigger move of policies to hash table (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix reinsertion on node merge (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: delete inexact policies from inexact list on hash rebuild (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: use hlist rcu variants on inexact insert, part 2 (Sabrina Dubroca) [1758100]
- [tools] selftests: xfrm: add block rules with adjacent/overlapping subnets (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: remove set but not used variable 'priority' (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix policy hash rebuild (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix netlink/pf_key policy lookups (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: add 2nd-level saddr trees for inexact policies (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: store inexact policies in a tree ordered by source address (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: check reinserted policies match their node (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: store inexact policies in a tree ordered by destination address (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: add inexact policy search tree infrastructure (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: consider if_id when hashing inexact policy (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: store inexact policies in an rhashtable (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: return NULL when inexact search needed (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: split list insertion into a helper (Sabrina Dubroca) [1758100]
- [net] xfrm: security: iterate all, not inexact lists (Sabrina Dubroca) [1758100]
- [tools] selftests: add xfrm policy test script (Sabrina Dubroca) [1758100]
- [net] af_packet: fix the tx skb protocol in raw sockets with ETH_P_ALL (Ivan Vecera) [1765561]
- [netdrv] mlx5e: Trust kernel regarding transport offset (Ivan Vecera) [1765561]
- [netdrv] net/mlx5e: Remove the wrong assumption about transport offset (Ivan Vecera) [1765561]
- [net] packet: Remove redundant skb->protocol set (Ivan Vecera) [1765561]
- [net] packet: Ask driver for protocol if not provided by user (Ivan Vecera) [1765561]
- [net] ethernet: Add parse_protocol header_ops support (Ivan Vecera) [1765561]
- [include] net: Introduce parse_protocol header_ops callback (Ivan Vecera) [1765561]
- [net] Don't set transport offset to invalid value (Ivan Vecera) [1765561]
- [netdrv] Fix Kconfig indentation (Josef Oskera) [1764592]
- [netdrv] be2net: make two arrays static const, makes object smaller (Josef Oskera) [1764592]
- [netdrv] be2net: eliminate enable field from be_aic_obj (Josef Oskera) [1764592]
- [netdrv] Use skb_frag_off accessors (Josef Oskera) [1764592]
- [netdrv] Use skb accessors in network drivers (Josef Oskera) [1764592]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 338 (Josef Oskera) [1764592]
- [netdrv] treewide: Add SPDX license identifier - Makefile/Kconfig (Josef Oskera) [1764592]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Josef Oskera) [1764592]
- [documentation] networking: switchdev: Update port parent ID section (Ivan Vecera) [1757840]
- [net] Get rid of SWITCHDEV_ATTR_ID_PORT_PARENT_ID (Ivan Vecera) [1757840]
- [net] dsa: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [drivers] staging: fsl-dpaa2: ethsw: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [netdrv] mscc: ocelot: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [netdrv] net/mlx5e: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [netdrv] liquidio: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [net] tipc: fix unlimited bundling of small messages (Jon Maloy) [1761969]
- [net] tipc: clean up skb list lock handling on send path (Jon Maloy) [1761969]
- [net] tipc: fix false detection of retransmit failures (Jon Maloy) [1761969]
- [net] tipc: reduce risk of wakeup queue starvation (Jon Maloy) [1761969]
- [net] tipc: fix changeover issues due to large packet (Jon Maloy) [1761969]
- [net] tipc: optimize link synching mechanism (Jon Maloy) [1761969]
- [net] tipc: Fix a typo (Jon Maloy) [1761969]
- [net] tipc: use rcu dereference functions properly (Jon Maloy) [1761969]
- [net] tipc: remove ub->ubsock checks (Jon Maloy) [1761969]
- [net] tipc: embed jiffies in macro TIPC_BC_RETR_LIM (Jon Maloy) [1761969]
- [net] tipc: add dst_cache support for udp media (Jon Maloy) [1761969]
- [net] tipc: rename function msg_get_wrapped() to msg_inner_hdr() (Jon Maloy) [1761969]
- [net] tipc: eliminate unnecessary skb expansion during retransmission (Jon Maloy) [1761969]
- [net] tipc: simplify stale link failure criteria (Jon Maloy) [1761969]
- [net] tipc: check msg->req data len in tipc_nl_compat_bearer_disable (Jon Maloy) [1761969]
- [net] tipc: remove the unnecessary msg->req check from tipc_nl_compat_bearer_set (Jon Maloy) [1761969]
- [net] tipc: fix issues with early FAILOVER_MSG from peer (Jon Maloy) [1761969]
- [net] tipc: include retrans failure detection for unicast (Jon Maloy) [1761969]
- [net] tipc: purge deferredq list for each grp member in tipc_group_delete (Jon Maloy) [1761969]
- [net] devlink: remove redundant rtnl lock assert (Marcelo Leitner) [1774694]

* Wed Nov 27 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-156.el8]
- [gpu] drm/i915/aml: Allow SPT PCH for all AML devices (Lyude Paul) [1761469 1731110]
- [gpu] drm/i915/cml: Add second PCH ID for CMP (Lyude Paul) [1731110]
- [drm] i915/cml: Add Missing PCI IDs (Lyude Paul) [1727949 1731110]
- [gpu] DRM Backport 5.2 -> 5.3 (Lyude Paul) [1731110]
- [xen] mm/pgtable: drop pgtable_t variable from pte_fn_t functions (Lyude Paul) [1731110]
- [gpu] DRM Backport 5.1 -> 5.2 (Lyude Paul) [1731110]
- [s390] bus_find_device: Unify the match callback with class_find_device (Lyude Paul) [1731110]
- [kernel] i2c: algo-bit: include main i2c header (Lyude Paul) [1731110]
- [extcon] axp288: Add a depends on ACPI to the Kconfig entry (Lyude Paul) [1731110]
- [extcon] axp288: Convert to use acpi_dev_get_first_match_dev() (Lyude Paul) [1731110]
- [acpi] gpio: merrifield: Fix build err without CONFIG_ACPI (Lyude Paul) [1731110]
- [gpio] merrifield: Convert to use acpi_dev_get_first_match_dev() (Lyude Paul) [1731110]
- [kernel] proc/sysctl: add shared variables for range check (Lyude Paul) [1731110]
- [gpu] drm/i915: Split Pineview device info into desktop and mobile (Lyude Paul) [1731110]
- [gpu] snd/hda, drm/i915: Track the display_power_status using a cookie (Lyude Paul) [1731110]
- [video] hdmi: Dropped static functions from kernel doc (Lyude Paul) [1731110]
- [video] hdmi: Add Unpack function for DRM infoframe (Lyude Paul) [1731110]
- [video] drm: Enable HDR infoframe support (Lyude Paul) [1731110]
- [kernel] drm: Add HDR source metadata property (Lyude Paul) [1731110]
- [gpu] drm: Add colorspace info to AVI Infoframe (Lyude Paul) [1731110]
- [gpu] drm: Add HDMI colorspace property (Lyude Paul) [1731110]
- [kernel] video/hdmi: Add an enum for HDMI packet types (Lyude Paul) [1731110]
- [video] hdmi: Constify infoframe passed to the pack functions (Lyude Paul) [1731110]
- [video] hdmi: Constify infoframe passed to the log functions (Lyude Paul) [1731110]
- [video] hdmi: Pass buffer size to infoframe unpack functions (Lyude Paul) [1731110]
- [video] hdmi: Constify 'buffer' to the unpack functions (Lyude Paul) [1731110]
- [video] media: hdmi.h: rename ADOBE_RGB to OPRGB and ADOBE_YCC to OPYCC (Lyude Paul) [1731110]
- [media] replace ADOBERGB by OPRGB (Lyude Paul) [1731110]
- [dma-buf] add show_fdinfo handler (Lyude Paul) [1731110]
- [dma-buf] dma-fence: Signal all callbacks from dma_fence_release() (Lyude Paul) [1731110]
- [dma-buf] udmabuf: actually unmap the scatterlist (Lyude Paul) [1731110]
- [dma-buf] Make mmap callback actually optional (Lyude Paul) [1731110]
- [dma-buf] Remove unused sync_dump() (Lyude Paul) [1731110]
- [kernel] dma-buf: explicitely note that dma-fence-chains use 64bit seqno (Lyude Paul) [1731110]
- [dma-buf] fix stack corruption in dma_fence_chain_release (Lyude Paul) [1731110]
- [dma-buf] add new dma_fence_chain container v7 (Lyude Paul) [1731110]
- [dma-buf] add some lockdep asserts to the reservation object implementation (Lyude Paul) [1731110]
- [iommu] arm-smmu-v3: Fix build error without CONFIG_PCI_ATS (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Avoid locking on invalidation path when not using ATS (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Fix ATC invalidation ordering wrt main TLBs (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Rework enabling/disabling of ATS for PCI masters (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Don't issue CMD_SYNC for zero-length invalidations (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Remove boolean bitfield for 'ats_enabled' flag (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Document ordering guarantees of command insertion (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Defer TLB invalidation until ->iotlb_sync() (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Reduce contention during command-queue insertion (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Operate directly on low-level queue where possible (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Move low-level queue fields out of arm_smmu_queue (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Drop unused 'q' argument from Q_OVF macro (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Separate s/w and h/w views of prod and cons indexes (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Pass struct iommu_iotlb_gather to ->tlb_add_page() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Pass struct iommu_iotlb_gather to ->unmap() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Remove unused ->tlb_sync() callback (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Replace ->tlb_add_flush() with ->tlb_add_page() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable-arm: Call ->tlb_flush_walk() and ->tlb_flush_leaf() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Hook up ->tlb_flush_walk() and ->tlb_flush_leaf() in drivers (Jerry Snitselaar) [1729845]
- [kernel] iommu/io-pgtable: Introduce tlb_flush_walk() and tlb_flush_leaf() (Jerry Snitselaar) [1729845]
- [iommu] Pass struct iommu_iotlb_gather to ->unmap() and ->iotlb_sync() (Jerry Snitselaar) [1729845]
- [kernel] iommu: Introduce iommu_iotlb_gather_add_page() (Jerry Snitselaar) [1729845]
- [kernel] iommu: Introduce struct iommu_iotlb_gather for batching TLB flushes (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Rename iommu_gather_ops to iommu_flush_ops (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable-arm: Remove redundant call to io_pgtable_tlb_sync() (Jerry Snitselaar) [1729845]
- [kernel] iommu: Remove empty iommu_tlb_range_add() callback from iommu_ops (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Invalidate ATC when detaching a device (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Add support for PCI ATS (Jerry Snitselaar) [1729845]
- [iommu] Introduce iotlb_sync_map callback (Jerry Snitselaar) [1742234]
- [kernel] dma-mapping: fix page attributes for dma_mmap_* (Jerry Snitselaar) [1754727]
- [kernel] dma-mapping: check pfn validity in dma_common_{mmap, get_sgtable} (Jerry Snitselaar) [1754727]
- [kernel] swiotlb: checking whether swiotlb buffer is full with io_tlb_used (Jerry Snitselaar) [1754727]
- [kernel] dma-direct: fix zone selection after an unaddressable CMA allocation (Jerry Snitselaar) [1754727]
- [kernel] dma-contiguous: page-align the size in dma_free_contiguous() (Jerry Snitselaar) [1754727]
- [kernel] dma-contiguous: do not overwrite align in dma_alloc_contiguous() (Jerry Snitselaar) [1754727]
- [kernel] dma-mapping: fix panic caused by passing empty cma command line argument (Jerry Snitselaar) [1754727]
- [iommu] dma: Handle SG length overflow better (Jerry Snitselaar) [1742234]
- [iommu] dma: Handle MSI mappings separately (Jerry Snitselaar) [1742234]
- [iommu] dma: Apply dma_{alloc, free}_contiguous functions (Jerry Snitselaar) [1742234]
- [iommu] dma: Don't depend on CONFIG_DMA_DIRECT_REMAP (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_mmap (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_get_sgtable (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_alloc, part 2 (Jerry Snitselaar) [1742234]
- [iommu] dma: Cleanup variable naming in iommu_dma_alloc (Jerry Snitselaar) [1742234]
- [iommu] dma: Split iommu_dma_free (Jerry Snitselaar) [1742234]
- [iommu] dma: Merge the CMA and alloc_pages allocation paths (Jerry Snitselaar) [1742234]
- [iommu] dma: Don't remap CMA unnecessarily (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_alloc (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_free (Jerry Snitselaar) [1742234]
- [iommu] dma: Remove __iommu_dma_free (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor the page array remapping allocator (Jerry Snitselaar) [1742234]
- [iommu] dma: Factor out remapped pages lookup (Jerry Snitselaar) [1742234]
- [iommu] dma: Squash __iommu_dma_{map, unmap}_page helpers (Jerry Snitselaar) [1742234]
- [iommu] dma: Move domain lookup into __iommu_dma_{map, unmap} (Jerry Snitselaar) [1742234]
- [iommu] dma: Move __iommu_dma_map (Jerry Snitselaar) [1742234]
- [iommu] dma: Use for_each_sg in iommu_dma_alloc (Jerry Snitselaar) [1742234]
- [clk] Make clk_bulk_get_all() return a valid "id" (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Support all Mali configurations (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Correct Mali attributes (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Fix panic after kexec -p for kdump (Jerry Snitselaar) [1742234]
- [kernel] iommu/iova: Fix compilation error with !CONFIG_IOMMU_IOVA (Jerry Snitselaar) [1742234]
- [iommu] amd: Check PM_LEVEL_SIZE() condition in locked section (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix incorrect PASID decoding from event log (Jerry Snitselaar) [1742234]
- [iommu] amd: Lock code paths traversing protection_domain->dev_list (Jerry Snitselaar) [1742234]
- [iommu] amd: Lock dev_data in attach/detach code paths (Jerry Snitselaar) [1742234]
- [iommu] amd: Check for busy devices earlier in attach_device() (Jerry Snitselaar) [1742234]
- [iommu] amd: Take domain->lock for complete attach/detach path (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove amd_iommu_devtable_lock (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove domain->updated (Jerry Snitselaar) [1742234]
- [iommu] iova: Avoid false sharing on fq_timer_on (Jerry Snitselaar) [1742234]
- [iommu] Don't use sme_active() in generic code (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix wrong analysis whether devices share the same bus (Jerry Snitselaar) [1742234]
- [iommu] amd: Wait for completion of IOTLB flush in attach_device (Jerry Snitselaar) [1742234]
- [iommu] amd: Unmap all L7 PTEs when downgrading page-sizes (Jerry Snitselaar) [1742234]
- [iommu] amd: Introduce first_pte_l7() helper (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix downgrading default page-sizes in alloc_pte() (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix pages leak in free_pagetable() (Jerry Snitselaar) [1742234]
- [documentation] documentation: Update Documentation for iommu.passthrough (Jerry Snitselaar) [1745844]
- [iommu] Disable passthrough mode when SME is active (Jerry Snitselaar) [1745844]
- [iommu] Set default domain type at runtime (Jerry Snitselaar) [1745844]
- [iommu] Print default domain type on boot (Jerry Snitselaar) [1745844]
- [x86] dma: Get rid of iommu_pass_through (Jerry Snitselaar) [1745844]
- [iommu] vt-d: Request passthrough mode from IOMMU core (Jerry Snitselaar) [1745844]
- [iommu] amd: Request passthrough mode from IOMMU core (Jerry Snitselaar) [1745844]
- [iommu] Use Functions to set default domain type in iommu_set_def_domain_type() (Jerry Snitselaar) [1745844]
- [iommu] Add helpers to set/get default domain type (Jerry Snitselaar) [1745844]
- [iommu] Remember when default domain type was set on kernel command line (Jerry Snitselaar) [1745844]
- [iommu] amd: Flush old domains in kdump kernel (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix race in increase_address_space() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove global page flush support (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix possible use-after-free of private domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Detach domain before using a private one (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Correctly check format of page table in debugfs (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Detach domain when move device out of group (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Mark expected switch fall-through (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Print pasid table entries MSB to LSB in debugfs (Jerry Snitselaar) [1742234]
- [iommu] iova: Remove stale cached32_node (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Check if domain->pgd was allocated (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't queue_iova() if there is no flush queue (Jerry Snitselaar) [1742234]
- [iommu] amd: fix a crash in iova_magazine_free_pfns (Jerry Snitselaar) [1742234]
- [iommu] Use right function to get group for device (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu-v3: Fix compilation when CONFIG_CMA=n (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable: Support non-coherent page tables (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable: Replace IO_PGTABLE_QUIRK_NO_DMA with specific flag (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm-v7s: request DMA32 memory, and improve debugging (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Add support to use system cache (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Increase maximum size of queues (Jerry Snitselaar) [1722978]
- [iommu] amd: Flush not present cache in iommu_map_page (Jerry Snitselaar) [1742234]
- [iommu] amd: Only free resources once on init error (Jerry Snitselaar) [1742234]
- [iommu] amd: Move gart fallback to amd_iommu_init (Jerry Snitselaar) [1742234]
- [iommu] amd: Make iommu_disable safer (Jerry Snitselaar) [1742234]
- [iommu] amd: Add missed 'tag' to error msg in iommu_print_event (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove redundant assignment to variable npages (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Cleanup unused variable (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Silence a variable set but not used (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove an unused variable "length" (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Cleanup after delegating DMA domain to generic iommu (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix suspicious RCU usage in probe_acpi_namespace_devices() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Allow DMA domain attaching to rmrr locked device (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't enable iommu's which have been ignored (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Set domain type for a private domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't return error when device gets right domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix a variable set but not used (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Fix typo in SVM code comment (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove static identity map code (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove duplicated code for device hotplug (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove startup parameter from device_def_domain_type() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Cleanup get_valid_domain_for_dev() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Implement is_attach_deferred iommu ops entry (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Probe DMA-capable ACPI name space devices (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Handle 32bit device with identity default domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Identify default domains replaced with private (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Delegate the dma domain to upper layer (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Delegate the identity domain to upper layer (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add device_def_domain_type() helper (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Enable DMA remapping after rmrr mapped (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Expose ISA direct mapping region via iommu_get_resv_regions (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Implement apply_resv_region iommu ops entry (Jerry Snitselaar) [1742234]
- [iommu] Add API to request DMA domain for device (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support to show scalable mode DMAR table internals (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Introduce macros useful for dumping DMAR table (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Modify the format of intel DMAR tables dump (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove unnecessary rcu_read_locks (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix bind svm with multiple devices (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Avoid constant zero in TLBI writes (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Set the right field for Page Walk Snoop (Jerry Snitselaar) [1742234]
- [iommu] Add missing new line for dma type (Jerry Snitselaar) [1742234]
- [kernel] iommu/iova: Separate atomic variables to improve performance (Jerry Snitselaar) [1742234]
- [iommu] Remove iommu_callback_data (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove amd_iommu_pd_list (Jerry Snitselaar) [1742234]
- [iommu] amd: Use pci_prg_resp_pasid_required() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix leak in intel_pasid_alloc_table on error path (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Make kernel parameter igfx_off work with vIOMMU (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Set intel_iommu_gfx_mapped correctly (Jerry Snitselaar) [1742234]
- [iommu] vt-d: cleanup: no spaces at the start of a line (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't request page request irq under dmar_global_lock (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Use struct_size() helper (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Flush IOTLB for untrusted device in time (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Clean up iommu_no_mapping (Jerry Snitselaar) [1742234]
- [vfio] type1: Add domain at(de)taching group helpers (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Return ID associated with an auxiliary domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Aux-domain specific domain attach/detach (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Move common code out of iommu_attch_device() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add per-device IOMMU feature ops entries (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Make intel_iommu_enable_pasid() more generic (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Switch to bitmap_zalloc() (Jerry Snitselaar) [1742234]
- [iommu] Bind process address spaces to devices (Jerry Snitselaar) [1742234]
- [iommu] Add APIs for multiple domains per device (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Log CBFRSYNRA register on context fault (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Don't disable SMMU in kdump kernel (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Disable tagged pointers (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Link domains and devices (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Add a master->domain pointer (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Store SteamIDs in master (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Rename arm_smmu_master_data to arm_smmu_master (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable: Add ARM Mali midgard MMU page table format (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Save the right domain ID used by hardware (Jerry Snitselaar) [1742234]
- [iommu] iova: Fix tracking of recently failed iova address (Jerry Snitselaar) [1742234]
- [iommu] Fix IOMMU debugfs fallout (Jerry Snitselaar) [1742234]
- [kernel] iommu: Document iommu_ops.is_attach_deferred() (Jerry Snitselaar) [1742234]
- [kernel] iommu: Document iommu_ops.iotlb_sync_map() (Jerry Snitselaar) [1742234]
- [kernel] iommu: Fix flush_tlb_all typo (Jerry Snitselaar) [1742234]
- [iommu] io-pgtable-arm-v7s: Only kmemleak_ignore L2 tables (Jerry Snitselaar) [1722978]
- [iommu] Use dev_printk() when possible (Jerry Snitselaar) [1742234]
- [kernel] iommu: Allow io-pgtable to be used outside of iommu/ (Jerry Snitselaar) [1722978]
- [iommu] iova: Allow compiling the library without IOMMU support (Jerry Snitselaar) [1742234]
- [iommu] amd: Use dev_printk() when possible (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove clear_flush_young notifier (Jerry Snitselaar) [1742234]
- [iommu] amd: Print reason for iommu_map_page failure in map_sg (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Get domain ID before clear pasid entry (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Set context field after value initialized (Jerry Snitselaar) [1742234]
- [kernel] pci/ats: Add inline to pci_prg_resp_pasid_required() (Jerry Snitselaar) [1724921 1724927]
- [iommu] vt-d: Enable ATS only if the device uses page aligned address (Jerry Snitselaar) [1724922]
- [pci] ats: Add pci_ats_page_aligned() interface (Jerry Snitselaar) [1724922]
- [iommu] vt-d: Fix PRI/PASID dependency issue (Jerry Snitselaar) [1724921 1724927]
- [pci] ats: Add pci_prg_resp_pasid_required() interface (Jerry Snitselaar) [1724921 1724927]
- [iommu] vt-d: Allow interrupts from the entire bus for aliased devices (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add helper to set an IRTE to verify only the bus number (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove misleading "domain 0" test from domain_exit() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove unused dmar_remove_one_dev_info() argument (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove unnecessary local variable initializations (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Use dev_printk() when possible (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove change_pte notifier (Jerry Snitselaar) [1742234]
- iommu/vt-d: Implement dma_[un]map_resource() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Support page request in scalable mode (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Leave scalable mode default off (Jerry Snitselaar) [1742234]
- [iommu] of: Fix probe-deferral (Jerry Snitselaar) [1742234]
- [iommu] Check for iommu_ops == NULL in iommu_probe_device() (Jerry Snitselaar) [1742234]
- [iommu] of: Don't call iommu_ops->add_device directly (Jerry Snitselaar) [1742234]
- powerpc/iommu: Use device_iommu_mapped() (Jerry Snitselaar) [1742234]
- [powerpc] iommu: Use device_iommu_mapped() (Jerry Snitselaar) [1742234]
- [iommu] of: Use device_iommu_mapped() (Jerry Snitselaar) [1742234]
- [iommu] of: Use helper functions to access dev->iommu_fwspec (Jerry Snitselaar) [1742234]
- [iommu] dma: Use helper functions to access dev->iommu_fwspec (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Use helper functions to access dev->iommu_fwspec (Jerry Snitselaar) [1722978]
- [acpi] iort: Fix rc_dma_get_range() (Jerry Snitselaar) [1722978]
- [kernel] iommu: Change tlb_range_add to iotlb_range_add and tlb_sync to iotlb_sync (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Make arm-smmu-v3 explicitly non-modular (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Make arm-smmu explicitly non-modular (Jerry Snitselaar) [1722978]
- [iommu] Audit and remove any unnecessary uses of module.h (Jerry Snitselaar) [1742234]
- [iommu] irq_remapping: Remove unused header files (Jerry Snitselaar) [1742234]
- [iommu] Do physical merging in iommu_map_sg() (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove leading 0s in error log messages (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix line-break in error log reporting (Jerry Snitselaar) [1742234]
- [iommu] amd: Use pr_fmt() (Jerry Snitselaar) [1742234]
- [iommu] amd: Allow to upgrade page-size (Jerry Snitselaar) [1742234]
- [iommu] amd: Restart loop if cmpxchg64 succeeded in alloc_pte() (Jerry Snitselaar) [1742234]
- [iommu] amd: Allow downgrading page-sizes in alloc_pte() (Jerry Snitselaar) [1742234]
- [iommu] amd: Ignore page-mode 7 in free_sub_pt() (Jerry Snitselaar) [1742234]
- [iommu] amd: Introduce free_sub_pt() function (Jerry Snitselaar) [1742234]
- [iommu] amd: Collect page-table pages in freelist (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove deferred invalidation (Jerry Snitselaar) [1724930]
- [iommu] vt-d: Shared virtual address in scalable mode (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add first level page table interface (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Setup context and enable RID2PASID support (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Pass pasid table to context mapping (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Setup pasid entry for RID2PASID support (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add second level page table interface (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Reserve a domain id for FL and PT modes (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add 256-bit invalidation descriptor support (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Move page table helpers into header (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Manage scalalble mode PASID tables (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Enumerate the scalable mode capability (Jerry Snitselaar) [1742234]
- [kernel] iommu/vtd: Cleanup dma_remapping.h header (Jerry Snitselaar) [1742234]
- [documentation] dt-bindings: arm-smmu: Add binding doc for Qcom smmu-500 (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Add support for qcom, smmu-v2 variant (Jerry Snitselaar) [1722978]
- [documentation] dt-bindings: arm-smmu: Add bindings for qcom, smmu-v2 (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Add the device_link between masters and smmu (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Invoke pm_runtime across the driver (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Add pm_runtime/sleep ops (Jerry Snitselaar) [1722978]
- [clk] add managed version of clk_bulk_get_all (Jerry Snitselaar) [1722978]
- [clk] add new APIs to operate on all available clocks (Jerry Snitselaar) [1722978]
- [clk] bulk: add of_clk_bulk_get() (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Use explicit mb() when moving cons pointer (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Avoid memory corruption from Hisilicon MSI payloads (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Fix big-endian CMD_SYNC writes (Jerry Snitselaar) [1722978]
- [iommu] revert "iommu/io-pgtable-arm: Check for v7s-incapable systems" (Jerry Snitselaar) [1722978]
- [iommu] Fix a typo (Jerry Snitselaar) [1742234]
- [iommu] Tidy up window attributes (Jerry Snitselaar) [1742234]
- [iommu] amd: Add default branch in amd_iommu_capable() (Jerry Snitselaar) [1742234]
- [iommu] amd: Move iommu_init_pci() to .init section (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support to show context internals (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support for Interrupt remapping (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support to show register contents (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Enable base Intel IOMMU debugfs support (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Update register definitions to VT-d 3.0 specification (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Relocate struct/function declarations to its header files (Jerry Snitselaar) [1742234]
- [of] iommu/of: make of_pci_map_rid() available for other devices too (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu-v3: Remove unnecessary wrapper function (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Add SPDX header (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Fix a couple of minor comment typos (Jerry Snitselaar) [1722978]
- [kernel] iommu/shmobile: Remove unused linux/platform_data/sh_ipmmu.h header (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Handle memory shortage on pasid table allocation (Jerry Snitselaar) [1742234]
- [iommu] Add sysfs attribyte for domain type (Jerry Snitselaar) [1742234]
- [iommu] amd: Add basic debugfs infrastructure for AMD IOMMU (Jerry Snitselaar) [1742234]
- [iommu] Enable debugfs exposure of IOMMU driver internals (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove the obsolete per iommu pasid tables (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Apply per pci device pasid table in SVA (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Allocate and free pasid table (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Per PCI device pasid table interfaces (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add for_each_device_domain() helper (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Move device_domain_info to header (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Apply global PASID in SVA (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Avoid using idr_for_each_entry() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Global PASID name space (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix dev iotlb pfsid use (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Add definitions for PFSID (Jerry Snitselaar) [1742234]
- [iommu] amd: Argument page_size could be uninitialized (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu-v3: Abort all transactions if SMMU is enabled in kdump kernel (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Prevent any devices access to memory without registration (Jerry Snitselaar) [1722978]
- [iommu] [] iommu/arm-smmu-v3: sync the OVACKFLG to PRIQ consumer register (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm-v7s: Abort allocation when table address overflows the PTE (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Fix pgtable allocation in selftest (Jerry Snitselaar) [1722978]
- [netdrv] iavf: initialize ITRN registers with correct values (Stefan Assmann) [1721697]
- [netdrv] iavf: fix MAC address setting for VFs when filter is rejected (Stefan Assmann) [1721697]
- [netdrv] iavf: allow permanent MAC address to change (Stefan Assmann) [1721697]
- [netdrv] iavf: remove unused debug function iavf_debug_d (Stefan Assmann) [1721697]
- [netdrv] Use skb_frag_off accessors (Stefan Assmann) [1721697]
- [netdrv] Use skb accessors in network drivers (Stefan Assmann) [1721697]
- [netdrv] iavf: fix dereference of null rx_buffer pointer (Stefan Assmann) [1721697]
- [netdrv] iavf: Fix up debug print macro (Stefan Assmann) [1721697]
- [netdrv] iavf: use struct_size() helper (Stefan Assmann) [1721697]
- [netdrv] iavf: allow null RX descriptors (Stefan Assmann) [1721697]
- [netdrv] iavf: add call to iavf_[add|del]_cloud_filter (Stefan Assmann) [1721697]
- [netdrv] iavf: Refactor init state machine (Stefan Assmann) [1721697]
- [netdrv] iavf: Refactor the watchdog state machine (Stefan Assmann) [1721697]
- [netdrv] iavf: Remove timer for work triggering, use delaying work instead (Stefan Assmann) [1721697]
- [netdrv] iavf: Move commands processing to the separate function (Stefan Assmann) [1721697]
- [netdrv] iavf: Fix the math for valid length for ADq enable (Stefan Assmann) [1721697]
- [netdrv] iavf: Change GFP_KERNEL to GFP_ATOMIC in kzalloc() (Stefan Assmann) [1721697]
- [netdrv] iavf: wait longer for close to complete (Stefan Assmann) [1721697]
- [netdrv] iavf: use signed variable (Stefan Assmann) [1721697]
- [netdrv] iavf: Create VLAN tag elements starting from the first element (Stefan Assmann) [1721697]
- [netdrv] iavf: update comments and file checks to match iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: rename i40e_device to iavf_device (Stefan Assmann) [1721697]
- [netdrv] iavf: change remaining i40e defines to be iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: rename iavf_client.h defines to match driver name (Stefan Assmann) [1721697]
- [netdrv] iavf: rename iavf_status structure flags (Stefan Assmann) [1721697]
- [netdrv] iavf: replace i40e variables with iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: rename i40e functions to be iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: change iavf_status_code to iavf_status (Stefan Assmann) [1721697]
- [netdrv] iavf: Rename i40e_adminq* files to iavf_adminq* (Stefan Assmann) [1721697]
- [netdrv] iavf: iavf_client: use struct_size() helper (Stefan Assmann) [1721697]
- [netdrv] iavf: use struct_size() in kzalloc() (Stefan Assmann) [1721697]
- [netdrv] iavf: Limiting RSS queues to CPUs (Stefan Assmann) [1721697]
- [netdrv] iavf: Use printf instead of gnu_printf for iavf_debug_d (Stefan Assmann) [1721697]
- [netdrv] igb/igc: use ktime accessors for skb->tstamp (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix for ethtool -m issue on X722 NIC (Stefan Assmann) [1721695]
- [netdrv] intel: Demote MTU change prints to debug (Stefan Assmann) [1721695]
- [netdrv] i40e: implement VF stats NDO (Stefan Assmann) [1721695]
- [netdrv] i40e: enable X710 support (Stefan Assmann) [1721695]
- [netdrv] i40e: Add UDP segmentation offload support (Stefan Assmann) [1721695]
- [netdrv] i40e: prevent memory leak in i40e_setup_macvlans (Stefan Assmann) [1721695]
- [netdrv] i40e: Refactoring VF MAC filters counting to make more reliable (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix LED blinking flow for X710T*L devices (Stefan Assmann) [1721695]
- [netdrv] i40e: allow ethtool to report SW and FW versions in recovery mode (Stefan Assmann) [1721695]
- [netdrv] i40e: initialize ITRN registers with correct values (Stefan Assmann) [1721695]
- [netdrv] i40e: Extend PHY access with page change flag (Stefan Assmann) [1721695]
- [netdrv] i40e: Extract detection of HW flags into a function (Stefan Assmann) [1721695]
- [netdrv] i40e: Wrong 'Advertised FEC modes' after set FEC to AUTO (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix for persistent lldp support (Stefan Assmann) [1721695]
- [netdrv] i40e: clear __I40E_VIRTCHNL_OP_PENDING on invalid min Tx rate (Stefan Assmann) [1721695]
- [netdrv] i40e: use BIT macro to specify the cloud filter field flags (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix message for other card without FEC (Stefan Assmann) [1721695]
- [netdrv] i40e: fix missed "Negotiated" string in i40e_print_link_message() (Stefan Assmann) [1721695]
- [netdrv] i40e: mark additional missing bits as reserved (Stefan Assmann) [1721695]
- [netdrv] i40e: remove I40E_AQC_ADD_CLOUD_FILTER_OIP (Stefan Assmann) [1721695]
- [netdrv] i40e: use ktime_get_real_ts64 instead of ktime_to_timespec64 (Stefan Assmann) [1721695]
- [netdrv] i40e: check __I40E_VF_DISABLE bit in i40e_sync_filters_subtask (Stefan Assmann) [1721695]
- [netdrv] i40e: Remove EMPR traces from debugfs facility (Stefan Assmann) [1721695]
- [netdrv] i40e: Implement debug macro hw_dbg using dev_dbg (Stefan Assmann) [1721695]
- [netdrv] i40e: fix hw_dbg usage in i40e_hmc_get_object_va (Stefan Assmann) [1721695]
- [netdrv] i40e: simplify Rx buffer recycle (Stefan Assmann) [1721695]
- [netdrv] i40e: fix retrying in i40e_aq_get_phy_capabilities (Stefan Assmann) [1721695]
- [netdrv] i40e: Persistent LLDP support (Stefan Assmann) [1721695]
- [netdrv] i40e: allow reset in recovery mode (Stefan Assmann) [1721695]
- [netdrv] i40e: Remove function i40e_update_dcb_config() (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix crash caused by stress setting of VF MAC addresses (Stefan Assmann) [1721695]
- [netdrv] i40e: reset veb.tc_stats when resetting veb.stats (Stefan Assmann) [1721695]
- [netdrv] i40e: Update FW API version to 1.9 (Stefan Assmann) [1721695]
- [netdrv] i40e: check_recovery_mode had wrong if statement (Stefan Assmann) [1721695]
- [netdrv] i40e: Add drop mode parameter to set mac config (Stefan Assmann) [1721695]
- [netdrv] i40e: fix shifts of signed values (Stefan Assmann) [1721695]
- [netdrv] i40e: add check on i40e_configure_tx_ring() return value (Stefan Assmann) [1721695]
- [netdrv] i40e: Check if transceiver implements DDM before access (Stefan Assmann) [1721695]
- [netdrv] i40e: reduce stack usage in i40e_set_fc (Stefan Assmann) [1721695]
- [netdrv] i40e: no need to check return value of debugfs_create functions (Stefan Assmann) [1721695]
- [netdrv] i40e: Remove unicast log when VF is leaving multicast mode (Stefan Assmann) [1721695]
- [netdrv] i40e: verify string count matches even on early return (Stefan Assmann) [1721695]
- [netdrv] i40e: Log info when PF is entering and leaving Allmulti mode (Stefan Assmann) [1721695]
- [netdrv] i40e: Update visual effect for advertised FEC mode (Stefan Assmann) [1721695]
- [netdrv] i40e: fix code comments (Stefan Assmann) [1721695]
- [netdrv] i40e: don't report link up for a VF who hasn't enabled queues (Stefan Assmann) [1721695]
- [netdrv] i40e: Log disable-fw-lldp flag change by ethtool (Stefan Assmann) [1721695]
- [netdrv] i40e: fix incorrect ethtool statistics veb and veb.tc_ (Stefan Assmann) [1721695]
- [netdrv] Use skb_frag_off accessors (Stefan Assmann) [1721695]
- [netdrv] i40e: Use dev_get_drvdata (Stefan Assmann) [1721695]
- [netdrv] Use skb accessors in network drivers (Stefan Assmann) [1721695]
- [netdrv] i40e: Add macvlan support on i40e (Stefan Assmann) [1721695]
- [netdrv] i40e/i40e_virtchnl_pf: Use struct_size() in kzalloc() (Stefan Assmann) [1721695]
- [netdrv] i40e: update copyright string (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix descriptor count manipulation (Stefan Assmann) [1721695]
- [netdrv] i40e: missing priorities for any QoS traffic (Stefan Assmann) [1721695]
- [netdrv] i40e: Add log entry while creating or deleting TC0 (Stefan Assmann) [1721695]
- [netdrv] i40e: fix incorrect function documentation comment (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix for missing "link modes" info in ethtool (Stefan Assmann) [1721695]
- [netdrv] i40e: fix 'Unknown bps' in dmesg for 2.5Gb/5Gb speeds (Stefan Assmann) [1721695]
- [netdrv] i40e: mark expected switch fall-through (Stefan Assmann) [1721695]
- [netdrv] i40e: Missing response checks in driver when starting/stopping FW LLDP (Stefan Assmann) [1721695]
- [netdrv] i40e: remove duplicate stat calculation for tx_errors (Stefan Assmann) [1721695]
- [netdrv] i40e: Check if the BAR size is large enough before writing to registers (Stefan Assmann) [1721695]
- [netdrv] i40e: Missing response checks in driver when starting/stopping FW LLDP (Stefan Assmann) [1721695]
- [netdrv] i40e: add input validation for virtchnl handlers (Stefan Assmann) [1721695]
- [netdrv] i40e: Improve AQ log granularity (Stefan Assmann) [1721695]
- [netdrv] i40e: Add bounds check for ch[] array (Stefan Assmann) [1721695]
- [netdrv] i40e: Use signed variable (Stefan Assmann) [1721695]
- [netdrv] i40e: add constraints for accessing veb array (Stefan Assmann) [1721695]
- [netdrv] i40e: let untrusted VF to create up to 16 VLANs (Stefan Assmann) [1721695]
- [netdrv] i40e: add functions stubs to support EEE (Stefan Assmann) [1721695]
- [netdrv] i40e: Use LLDP ethertype define ETH_P_LLDP (Stefan Assmann) [1721695]
- [netdrv] r8169: disable TSO on a single version of RTL8168c to fix performance (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix sporadic transmit timeout issue (Corinna Vinschen) [1730024]
- [netdrv] r8169: inline rtl8169_free_rx_databuff (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix performance issue on RTL8168evl (Corinna Vinschen) [1730024]
- [netdrv] r8169: allocate rx buffers using alloc_pages_node (Corinna Vinschen) [1730024]
- [netdrv] r8169: sync PCIe PHY init with vendor driver 8.047.01 (Corinna Vinschen) [1730024]
- [netdrv] r8169: add helper r8168_mac_ocp_modify (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove access to legacy register MultiIntr (Corinna Vinschen) [1730024]
- [netdrv] r8169: make use of xmit_more (Corinna Vinschen) [1730024]
- [netdrv] r8169: don't use MSI before RTL8168d (Corinna Vinschen) [1730024]
- [netdrv] revert ("r8169: remove 1000/Half from supported modes") (Corinna Vinschen) [1730024]
- [netdrv] r8169: enable HW csum and TSO (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove r8169_csum_workaround (Corinna Vinschen) [1730024]
- [netdrv] r8169: implement callback ndo_features_check (Corinna Vinschen) [1730024]
- [netdrv] r8169: set GSO size and segment limits (Corinna Vinschen) [1730024]
- [netdrv] r8169: align setting PME with vendor driver (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_set_rx_mode (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix a typo in a comment (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_rx (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix RTL8168g PHY init (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix issue with confused RX unit after PHY power-down on RTL8411b (Corinna Vinschen) [1730024]
- [netdrv] r8169: sync few chip names with vendor driver (Corinna Vinschen) [1730024]
- [netdrv] r8169: add random MAC address fallback (Corinna Vinschen) [1730024]
- [netdrv] revert "r8169: improve handling VLAN tag" (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove not needed call to dma_sync_single_for_device (Corinna Vinschen) [1730024]
- [netdrv] r8169: consider that 32 Bit DMA is the default (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve handling VLAN tag (Corinna Vinschen) [1730024]
- [netdrv] r8169: don't activate ASPM in chip if OS can't control ASPM (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve handling of Abit Fatal1ty F-190HD (Corinna Vinschen) [1730024]
- [netdrv] r8169: use helper rtl_is_8168evl_up for setting register MaxTxPacketSize (Corinna Vinschen) [1730024]
- [netdrv] r8169: add helper rtl_is_8168evl_up (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_coalesce_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: let mdio read functions return -ETIMEDOUT (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove struct rtl_cfg_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove member coalesce_info from struct rtl_cfg_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove callback hw_start from struct rtl_cfg_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: rename CPCMD_QUIRK_MASK and apply it on all chip versions (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve setting interrupt mask (Corinna Vinschen) [1730024]
- [netdrv] r8169: silence sparse warning in rtl8169_start_xmit (Corinna Vinschen) [1730024]
- [netdrv] r8169: factor out firmware handling (Corinna Vinschen) [1730024]
- [netdrv] r8169: rename r8169.c to r8169_main.c (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl_fw_request_firmware and rtl_fw_release_firmware (Corinna Vinschen) [1730024]
- [netdrv] r8169: make rtl_fw_format_ok and rtl_fw_data_ok more independent (Corinna Vinschen) [1730024]
- [netdrv] r8169: simplify rtl_fw_write_firmware (Corinna Vinschen) [1730024]
- [netdrv] r8169: add enum rtl_fw_opcode (Corinna Vinschen) [1730024]
- [netdrv] r8169: use paged versions of phylib MDIO access functions (Corinna Vinschen) [1730024]
- [netdrv] r8169: avoid tso csum function indirection (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove struct jumbo_ops (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove struct mdio_ops (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve r8169_csum_workaround (Corinna Vinschen) [1730024]
- [netdrv] r8169: decouple rtl_phy_write_fw from actual driver code (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_fw_format_ok (Corinna Vinschen) [1730024]
- [netdrv] r8169: enable WoL speed down on more chip versions (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix MAC address being lost in PCI D3 (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove 1000/Half from supported modes (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove support for RTL_GIGA_MAC_VER_01 (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve RTL8168d PHY initialization (Corinna Vinschen) [1730024]
- [netdrv] r8169: change type of member mac_version in rtl8169_private (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove unneeded return statement in rtl_hw_init_8168g (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove rtl_hw_init_8168ep (Corinna Vinschen) [1730024]
- [netdrv] treewide: Add SPDX license identifier - Makefile/Kconfig (Corinna Vinschen) [1730024]
- [netdrv] treewide: Add SPDX license identifier for more missed files (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl8168g_set_pause_thresholds (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl_set_fifo_size (Corinna Vinschen) [1730024]
- [netdrv] r8169: move EEE LED config to rtl8168_config_eee_mac (Corinna Vinschen) [1730024]
- [netdrv] r8169: simplify rtl_writephy_batch and rtl_ephy_init (Corinna Vinschen) [1730024]
- [netdrv] r8169: speed up rtl_loop_wait (Corinna Vinschen) [1730024]
- [netdrv] r8169: make use of phy_set_asym_pause (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove rtl_write_exgmac_batch (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove manual autoneg restart workaround (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl_reset_packet_filter (Corinna Vinschen) [1730024]
- [netdrv] r8169: add helpers rtl_eri_set/clear_bits (Corinna Vinschen) [1730024]
- [netdrv] r8169: make ERIAR_EXGMAC the default in eri functions (Corinna Vinschen) [1730024]
- [netdrv] r8169: use pci_dev_id() helper (Corinna Vinschen) [1730024]
- [kernel] phy: fix write to mii-ctrl1000 register (Petr Oros) [1772010]
- [netdrv] bcmgenet: don't set phydev->link from MAC (Petr Oros) [1772010]
- [netdrv] mdio_bus: Fix PTR_ERR applied after initialization to constant (Petr Oros) [1772010]
- [netdrv] phy: micrel: add Asym Pause workaround for KSZ9021 (Petr Oros) [1772010]
- [netdrv] phy: fix race in genphy_update_link (Petr Oros) [1772010]
- [netdrv] phy: consider AN_RESTART status when reading link status (Petr Oros) [1772010]
- [kernel] fixed_phy: Add forward declaration for struct gpio_desc; (Petr Oros) [1772010]
- [netdrv] phy: fixed_phy: print gpio error only if gpio node is present (Petr Oros) [1772010]
- [netdrv] phy: mscc: initialize stats array (Petr Oros) [1772010]
- [netdrv] phy: bcm7xxx: define soft_reset for 40nm EPHY (Petr Oros) [1772010]
- [netdrv] Add genphy_c45_config_aneg() function to phy-c45.c (Petr Oros) [1772010]
- [netdrv] phy: sfp: hwmon: Fix scaling of RX power (Petr Oros) [1772010]
- [kernel] hwmon: Fix HWMON_P_MIN_ALARM mask (Petr Oros) [1772010]
- [netdrv] phy: rename Asix Electronics PHY driver (Petr Oros) [1772010]
- [netdrv] sfp: read eeprom in maximum 16 byte increments (Petr Oros) [1772010]
- [netdrv] phylink: avoid reducing support mask (Petr Oros) [1772010]
- [netdrv] phy: dp83867: Set up RGMII TX delay (Petr Oros) [1772010]
- [netdrv] phy: dp83867: do not call config_init twice (Petr Oros) [1772010]
- [netdrv] phy: dp83867: increase SGMII autoneg timer duration (Petr Oros) [1772010]
- [netdrv] phy: dp83867: fix speed 10 in sgmii mode (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: report if the PHY fails to boot firmware (Petr Oros) [1772010]
- [netdrv] phylink: ensure consistent phy interface mode (Petr Oros) [1772010]
- [netdrv] phylink: ensure inband AN works correctly (Petr Oros) [1772010]
- [netdrv] phy: aquantia: readd XGMII support for AQR107 (Petr Oros) [1772010]
- [netdrv] phy: realtek: Replace phy functions with non-locked version in rtl8211e_config_init() (Petr Oros) [1772010]
- [netdrv] meson: fixup g12a glue ephy id (Petr Oros) [1772010]
- [netdrv] phy: realtek: fix double page ops in generic Realtek driver (Petr Oros) [1772010]
- [netdrv] phy: realtek: add missing page operations (Petr Oros) [1772010]
- [netdrv] phy: realtek: Change TX-delay setting for RGMII modes only (Petr Oros) [1772010]
- [netdrv] phy: realtek: Add rtl8211e rx/tx delays config (Petr Oros) [1772010]
- [netdrv] phy: improve pause mode reporting in phy_print_status (Petr Oros) [1772010]
- [kernel] phy: improve resuming from hibernation (Petr Oros) [1772010]
- [netdrv] phy: fix phy_validate_pause (Petr Oros) [1772010]
- [netdrv] phy: micrel: make sure the factory test bit is cleared (Petr Oros) [1772010]
- [netdrv] phy: marvell: Fix buffer overrun with stats counters (Petr Oros) [1772010]
- [netdrv] phy: avoid unneeded MDIO reads in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: improve genphy_soft_reset (Petr Oros) [1772010]
- [netdrv] spi: micrel eth switch: declare missing of table (Petr Oros) [1772010]
- [netdrv] phy: marvell: add new default led configure for m88e151x (Petr Oros) [1772010]
- [netdrv] phy: vitesse: Remove support for VSC8514 (Petr Oros) [1772010]
- [netdrv] phy: mscc: add support for VSC8514 PHY (Petr Oros) [1772010]
- [netdrv] mdio: rename mdio_device reset to reset_gpio (Petr Oros) [1772010]
- [netdrv] phy: add support for reset-controller (Petr Oros) [1772010]
- [documentation] dt-bindings: add PHY reset controller binding (Petr Oros) [1772010]
- [netdrv] phy: remove dead code from phy_sanitize_settings (Petr Oros) [1772010]
- [netdrv] phy: don't set autoneg if it's not supported (Petr Oros) [1772010]
- [netdrv] phy: micrel: add Asym Pause workaround (Petr Oros) [1772010]
- [netdrv] phy: warn if phylib and ethtool PHY mode definitions are out of sync (Petr Oros) [1772010]
- [netdrv] phy: add support for new modes in phylib (Petr Oros) [1772010]
- [netdrv] phy: shrink PHY settings array (Petr Oros) [1772010]
- [netdrv] phy: switch drivers to use dynamic feature detection (Petr Oros) [1772010]
- [netdrv] phy: fix setting autoneg_complete in genphy_update_link (Petr Oros) [1772010]
- [netdrv] phy: replace genphy_10g_driver with genphy_c45_driver (Petr Oros) [1772010]
- [netdrv] phy: remove unnecessary callback settings in C45 drivers (Petr Oros) [1772010]
- [netdrv] phy: improve link partner capability detection (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: clean-up gxl variant driver (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: add g12a support (Petr Oros) [1772010]
- [netdrv] phy: add amlogic g12a mdio mux support (Petr Oros) [1772010]
- [documentation] dt-bindings: phy: add g12a mdio mux documentation (Petr Oros) [1772010]
- [netdrv] phy: realtek: remove setting callback get_features and use phylib fallback (Petr Oros) [1772010]
- [netdrv] phy: fix autoneg mismatch case in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: add the suspend/resume callbacks for the 88x2210 (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: implement suspend/resume callbacks (Petr Oros) [1772010]
- [netdrv] phy: deal properly with autoneg incomplete in genphy_c45_read_lpa (Petr Oros) [1772010]
- [netdrv] phy: use c45 standard to detect link partner autoneg capability (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add SGMII statistics (Petr Oros) [1772010]
- [netdrv] phy: improve genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add suspend / resume callbacks for AQR107 family (Petr Oros) [1772010]
- [netdrv] phy: realtek: use genphy_read_abilities (Petr Oros) [1772010]
- [netdrv] phy: mdio-bcm-unimac: remove redundant !timeout check (Petr Oros) [1772010]
- [netdrv] phy: marvell: add PHY tunable fast link down support for 88E1540 (Petr Oros) [1772010]
- [uapi] ethtool: add PHY Fast Link Down support (Petr Oros) [1772010]
- [netdrv] phy: aquantia: inform about proprietary 1000Base-T2 mode being in use (Petr Oros) [1772010]
- [netdrv] phy: aquantia: report PHY details like firmware version (Petr Oros) [1772010]
- [netdrv] phy: aquantia: print remote capabilities if link partner is Aquantia PHY (Petr Oros) [1772010]
- [kernel] phy: bcm54xx: Encode link speed and activity into LEDs (Petr Oros) [1772010]
- [netdrv] phy: aquantia: simplify aqr_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: don't clear BMCR in genphy_soft_reset (Petr Oros) [1772010]
- [netdrv] phy: Re-parent menus for MDIO bus drivers correctly (Petr Oros) [1772010]
- [netdrv] phy: Correct Cygnus/Omega PHY driver prompt (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add downshift support (Petr Oros) [1772010]
- [netdrv] phy: Move Omega PHY entry to Cygnus PHY driver (Petr Oros) [1772010]
- [netdrv] phy: Prepare for moving Omega out of bcm7xxx (Petr Oros) [1772010]
- [netdrv] phy: Add DP83825I to the DP83822 driver (Petr Oros) [1772010]
- [netdrv] phy: aquantia: check for changed interface mode in read_status (Petr Oros) [1772010]
- [netdrv] phy: aquantia: check for supported interface modes in config_init (Petr Oros) [1772010]
- [netdrv] phy: improve handling link_change_notify callback (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: fix interrupt support (Petr Oros) [1772010]
- [gpio] gpiolib: devprop: Fix syntax error (Petr Oros) [1772010]
- [kernel] gpiolib: export devprop_gpiochip_set_names() (Petr Oros) [1772010]
- [netdrv] phy: mdio-mux: fix Kconfig dependencies (Petr Oros) [1772010]
- [netdrv] phy: use phy_modify_mmd_changed in genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: remove gen10g_no_soft_reset (Petr Oros) [1772010]
- [netdrv] phy: don't export gen10g_read_status (Petr Oros) [1772010]
- [netdrv] phy: remove gen10g_config_init (Petr Oros) [1772010]
- [netdrv] phy: remove gen10g_suspend and gen10g_resume (Petr Oros) [1772010]
- [netdrv] phy: use genphy_c45_aneg_done in genphy_aneg_done (Petr Oros) [1772010]
- [netdrv] phy: micrel ksz8061: link failure after cable connect (Petr Oros) [1772010]
- [netdrv] phy: phylink: fix uninitialized variable in phylink_get_mac_state (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add hwmon support (Petr Oros) [1772010]
- [netdrv] phy: aquantia: rename aquantia.c to aquantia_main.c (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use the generic C45 helper to read the 2110 features (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Let genphy_c45_pma_read_abilities set Aneg bit (Petr Oros) [1772010]
- [netdrv] phy: dp83867: add soft reset delay (Petr Oros) [1772010]
- [netdrv] phy: mdio-mux: Add support for Generic Mux controls (Petr Oros) [1772010]
- [netdrv] phy: improve auto-neg emulation in swphy (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: add support for the 88x2110 PHY (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Force reading of 2.5/5G (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use a #define for 88X3310 family id (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use 2500BASEX when using 2.5GBASET (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use linkmode_set_bit helper instead of __set_bit (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use get_features to get the PHY abilities (Petr Oros) [1772010]
- [netdrv] phy: aquantia: use genphy_c45_read_status (Petr Oros) [1772010]
- [netdrv] phy: add genphy_c45_read_status (Petr Oros) [1772010]
- [netdrv] phy: don't change modes we don't care about in genphy_c45_read_lpa (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add support for auto-negotiation configuration (Petr Oros) [1772010]
- [netdrv] phy: aquantia: remove false 5G and 10G speed ability for AQCS109 (Petr Oros) [1772010]
- [netdrv] phy: check PMAPMD link status only in genphy_c45_read_link (Petr Oros) [1772010]
- [netdrv] mdio_bus: Fix use-after-free on device_register fails (Petr Oros) [1772010]
- [netdrv] phy: at803x: disable delay only for RGMII mode (Petr Oros) [1772010]
- [netdrv] phy: at803x: don't inline helpers (Petr Oros) [1772010]
- [netdrv] phy: aquantia: Use get_features for the PHYs abilities (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: use genphy_c45_check_and_restart_aneg in mv3310_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: add genphy_c45_check_and_restart_aneg (Petr Oros) [1772010]
- [netdrv] phy: use genphy_config_eee_advert in genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: export genphy_config_eee_advert (Petr Oros) [1772010]
- [netdrv] phy: don't use 10BaseT/half as default in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: remove orphaned register read in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: improve mv3310_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: disable aneg in genphy_c45_pma_setup_forced (Petr Oros) [1772010]
- [netdrv] phy: use mii_10gbt_stat_mod_linkmode_lpa_t in genphy_c45_read_lpa (Petr Oros) [1772010]
- [kernel] phy: add helper mii_10gbt_stat_mod_linkmode_lpa_t (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: check for newly set aneg (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: use genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: add genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [kernel] phy: add helper linkmode_adv_to_mii_10gbt_adv_t (Petr Oros) [1772010]
- [netdrv] mdio_bus: Fix PTR_ERR() usage after initialization to constant (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Support generic PHY status read (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Don't explicitly set Pause and Asym_Pause (Petr Oros) [1772010]
- [netdrv] phy: use phy_resolve_aneg_linkmode in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: improve phy_resolve_aneg_linkmode (Petr Oros) [1772010]
- [netdrv] phy: fix potential race in the phylib state machine (Petr Oros) [1772010]
- [kernel] phy: don't use locking in phy_is_started (Petr Oros) [1772010]
- [netdrv] phy: fix interrupt handling in non-started states (Petr Oros) [1772010]
- [netdrv] phy: simplify genphy_config_eee_advert (Petr Oros) [1772010]
- [netdrv] phylink: avoid resolving link state too early (Petr Oros) [1772010]
- [netdrv] phylink: add phylink_init_eee() helper (Petr Oros) [1772010]
- [netdrv] phylink: only call mac_config() during resolve when link is up (Petr Oros) [1772010]
- [netdrv] phy: use phy_modify_changed in genphy_config_advert (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: fix usage of new MMD modifying helpers (Petr Oros) [1772010]
- [netdrv] phy: add register modifying helpers returning 1 on change (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add support for AQCS109 (Petr Oros) [1772010]
- [netdrv] phy: disregard "Clause 22 registers present" bit in get_phy_c45_devs_in_pkg (Petr Oros) [1772010]
- [netdrv] phy: let genphy_c45_read_link manage the devices to check (Petr Oros) [1772010]
- [netdrv] phy: don't double-read link status register if link is up (Petr Oros) [1772010]
- [netdrv] fixed-phy: Add fixed_phy_register_with_gpiod() API (Petr Oros) [1772010]
- [netdrv] phy: fixed_phy: Fix fixed_phy not checking GPIO (Petr Oros) [1772010]
- [netdrv] phy: consider latched link-down status in polling mode (Petr Oros) [1772010]
- [netdrv] sfp: do not probe SFP module before we're attached (Petr Oros) [1772010]
- [netdrv] phy: make use of new MMD accessors (Petr Oros) [1772010]
- [kernel] phy: provide full set of accessor functions to MMD registers (Petr Oros) [1772010]
- [netdrv] phy: improve genphy_c45_read_link (Petr Oros) [1772010]
- [netdrv] phy: fixed-phy: Drop GPIO from fixed_phy_add() (Petr Oros) [1772010]
- [netdrv] dp83640: expire old TX-skb (Petr Oros) [1772010]
- [netdrv] phy: aquantia: replace magic numbers with constants (Petr Oros) [1772010]
- [netdrv] phy: aquantia: use macro PHY_ID_MATCH_MODEL (Petr Oros) [1772010]
- [netdrv] phy: aquantia: remove unneeded includes (Petr Oros) [1772010]
- [netdrv] phy: aquantia: Shorten name space prefix to aqr_ (Petr Oros) [1772010]
- [netdrv] revert "net: phy: marvell: avoid pause mode on SGMII-to-Copper for 88e151x" (Petr Oros) [1772010]
- [netdrv] phy: at803x: Use helpers to access MMD PHY registers (Petr Oros) [1772010]
- [netdrv] phy: change phy_start_interrupts to phy_request_interrupt (Petr Oros) [1772010]
- [netdrv] phy: start interrupts in phy_start (Petr Oros) [1772010]
- [netdrv] phy: warn if phy_start is called from invalid state (Petr Oros) [1772010]
- [netdrv] phy: start state machine in phy_start only (Petr Oros) [1772010]
- [netdrv] phy: Add SDPX tag based on COPYING file (Petr Oros) [1772010]
- [netdrv] phy: Fixup GPLv2 SPDX tags based on license text (Petr Oros) [1772010]
- [netdrv] phy: Fixup GPLv2+ SPDX tags based on license text (Petr Oros) [1772010]
- [netdrv] phy: Remove redundent License text when SPDX header is present (Petr Oros) [1772010]
- [netdrv] phy: Convert some PHY and MDIO driver files to SPDX headers (Petr Oros) [1772010]
- [netdrv] phy: at803x: Disable phy delay for RGMII mode (Petr Oros) [1772010]
- [netdrv] phy: improve phy_init_hw (Petr Oros) [1772010]
- [netdrv] phy: fix issue with loading PHY driver w/o initramfs (Petr Oros) [1772010]
- [netdrv] phy: remove phy_stop_interrupts (Petr Oros) [1772010]
- [netdrv] phy: ensure phylib state machine is stopped after calling phy_stop (Petr Oros) [1772010]
- [netdrv] phy: stop PHY if needed when entering phy_disconnect (Petr Oros) [1772010]
- [netdrv] phy: micrel: use phy_read_mmd and phy_write_mmd (Petr Oros) [1772010]
- [netdrv] phy: improve get_phy_id (Petr Oros) [1772010]
- [kernel] phy: remove state PHY_CHANGELINK (Petr Oros) [1772010]
- [netdrv] phy: mdio_bus: add missing device_del() in mdiobus_register() error handling (Petr Oros) [1772010]
- [netdrv] phy: check return code when requesting PHY driver module (Petr Oros) [1772010]
- [netdrv] phy: Add helpers to determine if PHY driver is generic (Petr Oros) [1772010]
- [netdrv] phy: improve logging in phylib (Petr Oros) [1772010]
- [netdrv] phy: don't include asm/irq.h directly (Petr Oros) [1772010]
- [netdrv] phy: remove preliminary workaround for not loading PHY driver (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: Use the genphy_soft_reset callback (Petr Oros) [1772010]
- [netdrv] phy: marvell: Fix deadlock from wrong locking (Petr Oros) [1772010]
- [netdrv] phy: marvell: Errata for mv88e6390 internal PHYs (Petr Oros) [1772010]
- [netdrv] phy: micrel: set soft_reset callback to genphy_soft_reset for KSZ9031 (Petr Oros) [1772010]
- [netdrv] phy: fix too strict check in phy_start_aneg (Petr Oros) [1772010]
- [kernel] phy.h: fix obvious errors in doc and kerneldoc content (Petr Oros) [1772010]
- [netdrv] phy: mscc: Fix the VSC 8531/41 Chip Init sequence (Petr Oros) [1772010]
- [netdrv] phy: Fix the issue that netif always links up after resuming (Petr Oros) [1772010]
- [netdrv] phy: print stack trace in phy_error (Petr Oros) [1772010]
- [netdrv] phy: improve phy state checking (Petr Oros) [1772010]
- [netdrv] fixed phy: Add fixed_phy_change_carrier() (Petr Oros) [1772010]
- [netdrv] phy: mdio-gpio: Add phy_ignore_ta_mask to platform data (Petr Oros) [1772010]
- [kernel] phy: mdio-gpio: Add platform_data support for phy_mask (Petr Oros) [1772010]
- [kernel] gpio: Export gpiod_get_from_of_node() (Petr Oros) [1772010]
- [netdrv] phy: Revert toggling reset changes (Petr Oros) [1772010]
- [netdrv] phy: sfp: correct store of detected link modes (Petr Oros) [1772010]
- [netdrv] phy: micrel: add toggling phy reset if PHY is not attached (Petr Oros) [1772010]
- [netdrv] phy: Fix not to call phy_resume() if PHY is not attached (Petr Oros) [1772010]
- [netdrv] phy: improve generic EEE ethtool functions (Petr Oros) [1772010]
- [netdrv] phy: add workaround for issue where PHY driver doesn't bind to the device (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix deadlock in vsc85xx_default_config (Petr Oros) [1772010]
- [netdrv] phy: vitesse: remove duplicate support for VSC8574 (Petr Oros) [1772010]
- [netdrv] phy: icplus: allow configuring the interrupt function on IP101GR (Petr Oros) [1772010]
- [netdrv] phy: icplus: implement .did_interrupt for IP101A/G (Petr Oros) [1772010]
- [netdrv] phy: icplus: rename IP101A_G_NO_IRQ to IP101A_G_IRQ_ALL_MASK (Petr Oros) [1772010]
- [netdrv] phy: icplus: use the BIT macro where possible (Petr Oros) [1772010]
- [netdrv] phy: icplus: keep all ip101a_g functions together (Petr Oros) [1772010]
- [documentation] dt-bindings: phy: add bindings for the IC Plus Corp. IP101A/G PHYs (Petr Oros) [1772010]
- [documentation] dt-bindings: vendor-prefix: add prefix for IC Plus Corp (Petr Oros) [1772010]
- [netdrv] phy: mdio-gpio: Fix working over slow can_sleep GPIOs (Petr Oros) [1772010]
- [netdrv] phy: check for implementation of both callbacks in phy_drv_supports_irq (Petr Oros) [1772010]
- [netdrv] phy: icplus: add config_intr callback (Petr Oros) [1772010]
- [kernel] phy: remove states PHY_STARTING and PHY_PENDING (Petr Oros) [1772010]
- [netdrv] phy: leds: Don't make our own link speed names (Petr Oros) [1772010]
- [netdrv] phy: improve and inline phy_change (Petr Oros) [1772010]
- [netdrv] phy: simplify phy_mac_interrupt and related functions (Petr Oros) [1772010]
- [netdrv] phy: don't set state PHY_CHANGELINK in phy_change (Petr Oros) [1772010]
- [kernel] phy: improve struct phy_device member interrupts handling (Petr Oros) [1772010]
- [netdrv] phy: remove flag PHY_HAS_INTERRUPT from driver configs (Petr Oros) [1772010]
- [netdrv] phy: replace PHY_HAS_INTERRUPT with a check for config_intr and ack_interrupt (Petr Oros) [1772010]
- [netdrv] phy: use phy_check_link_status in more places in the state machine (Petr Oros) [1772010]
- [kernel] phy: remove state PHY_AN (Petr Oros) [1772010]
- [netdrv] phy: add phy_check_link_status (Petr Oros) [1772010]
- [netdrv] phy: remove useless check in state machine case PHY_RESUMING (Petr Oros) [1772010]
- [netdrv] phy: remove useless check in state machine case PHY_NOLINK (Petr Oros) [1772010]
- [netdrv] phy: make phy_trigger_machine static (Petr Oros) [1772010]
- [netdrv] phy: bcm7xxx: Add entry for BCM7255 (Petr Oros) [1772010]
- [netdrv] phy: Allow BCM54616S PHY to setup internal TX/RX clock delay (Petr Oros) [1772010]
- [netdrv] phy: mdio-mux-bcm-iproc: simplify getting .driver_data (Petr Oros) [1772010]
- [documentation] dt-bindings: add support for Microchip KSZ9131 (Petr Oros) [1772010]
- [netdrv] phy: micrel: add Microchip KSZ9131 initial driver (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix memory leak in vsc8574_config_pre_init (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix signedness bug in vsc85xx_downshift_get (Petr Oros) [1772010]
- [netdrv] phy: merge phy_start_aneg and phy_start_aneg_priv (Petr Oros) [1772010]
- [netdrv] phy: simplify handling of PHY_RESUMING in state machine (Petr Oros) [1772010]
- [netdrv] phy: improve handling of PHY_RUNNING in state machine (Petr Oros) [1772010]
- [netdrv] phy: trigger state machine immediately in phy_start_machine (Petr Oros) [1772010]
- [netdrv] phy: sfp: remove sfp_mutex's definition (Petr Oros) [1772010]
- [netdrv] phy: mscc: add support for VSC8574 PHY (Petr Oros) [1772010]
- [netdrv] phy: mscc: add support for VSC8584 PHY (Petr Oros) [1772010]
- [dt-bindings] vsc8531: add two additional LED modes for VSC8584 (Petr Oros) [1772010]
- [netdrv] phy: mscc: remove unneeded temporary variable (Petr Oros) [1772010]
- [netdrv] phy: mscc: shorten `x != 0` condition to `x` (Petr Oros) [1772010]
- [netdrv] phy: mscc: remove unneeded parenthesis (Petr Oros) [1772010]
- [netdrv] phy: mscc: Add EEE init sequence (Petr Oros) [1772010]
- [netdrv] phy: mscc: add ethtool statistics counters (Petr Oros) [1772010]
- [netdrv] phy: mscc: migrate to phy_select/restore_page functions (Petr Oros) [1772010]
- [netdrv] phy: phylink: fix SFP interface autodetection (Petr Oros) [1772010]
- [netdrv] phy: Convert to using pOFn instead of device_node.name (Petr Oros) [1772010]
- [netdrv] phy: improve handling delayed work (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix printf format (Petr Oros) [1772010]
- [netdrv] phy: mdio-bcm-unimac: mark PM functions as __maybe_unused (Petr Oros) [1772010]
- [netdrv] phy: marvell: Fix build (Petr Oros) [1772010]
- [netdrv] phy: marvell: Avoid unnecessary soft reset (Petr Oros) [1772010]
- [netdrv] phy: Stop with excessive soft reset (Petr Oros) [1772010]
- [netdrv] phy: sfp: Fix unregistering of HWMON SFP device (Petr Oros) [1772010]
- [netdrv] phy: fix WoL handling when suspending the PHY (Petr Oros) [1772010]
- [net] core: add member wol_enabled to struct net_device (Petr Oros) [1772010]
- [netdrv] phy: mdio-bcm-unimac: Allow configuring MDIO clock divider (Petr Oros) [1772010]
- [netdrv] phy: don't reschedule state machine when PHY is halted (Petr Oros) [1772010]
- [netdrv] phy: phylink: ensure the carrier is off when starting phylink (Petr Oros) [1772010]
- [netdrv] phy: call state machine synchronously in phy_stop (Petr Oros) [1772010]
- [net] linkwatch: add check for netdevice being present to linkwatch_do_dev (Petr Oros) [1772010]
- [netdrv] sfp: fix oops with ethtool -m (Petr Oros) [1772010]
- [netdrv] mdio: remove duplicated include from mdio_bus.c (Petr Oros) [1772010]
- [netdrv] phy: et011c: Remove incorrect PHY_POLL flags (Petr Oros) [1772010]
- [netdrv] phy: sfp: Handle unimplemented hwmon limits and alarms (Petr Oros) [1772010]
- [netdrv] phy: mscc: read 'vsc8531, led-d-mode' as an u32 (Petr Oros) [1772010]
- [netdrv] phy: mscc: read 'vsc8531, edge-slowdown' as an u32 (Petr Oros) [1772010]
- [netdrv] phy: mscc: read 'vsc8531, vddmac' as an u32 (Petr Oros) [1772010]
- [netdrv] phy: mscc: factorize function for getting LED mode from DT (Petr Oros) [1772010]
- [netdrv] phy: mscc: factorize code for LEDs mode (Petr Oros) [1772010]
- [netdrv] dp83640: Mark expected switch fall-throughs (Petr Oros) [1772010]
- [netdrv] phylink: add helper for configuring 2500BaseX modes (Petr Oros) [1772010]
- [netdrv] phy: sftp: print debug message with text, not numbers (Petr Oros) [1772010]
- [netdrv] phy: Add support for Broadcom Omega internal Combo GPHY (Petr Oros) [1772010]
- [netdrv] phy: Add pm support to Broadcom iProc mdio mux driver (Petr Oros) [1772010]
- [netdrv] phy: Add support to configure clock in Broadcom iProc mdio mux (Petr Oros) [1772010]
- [documentation] dt-bindings: Add clock handle to Broadcom iProc mdio mux (Petr Oros) [1772010]
- [netdrv] phy: Use devm api for mdio bus allocation in bcm iproc mdio mux (Petr Oros) [1772010]
- [netdrv] phy: Disable external master access in bcm mdio mux driver (Petr Oros) [1772010]
- [arm64] dts: Fix the base address of the Broadcom iProc mdio mux (Petr Oros) [1772010]
- [netdrv] phy: Fix the register offsets in Broadcom iProc mdio mux driver (Petr Oros) [1772010]
- [documentation] dt-bindings: Fix Broadcom iProc mdio mux driver base address (Petr Oros) [1772010]
- [netdrv] phy: mscc: the extended page access register is 16 bits (Petr Oros) [1772010]
- [netdrv] phy: marvell: Replace mdelay() with msleep() in m88e1116r_config_init() (Petr Oros) [1772010]
- [kernel] phy: add helper phy_polling_mode (Petr Oros) [1772010]
- [netdrv] phy: prevent PHYs w/o Clause 22 regs from calling genphy_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: add GBit master / slave error detection (Petr Oros) [1772010]
- [netdrv] phy: sfp: Do not use "imply HWMON" (Petr Oros) [1772010]
- [netdrv] phy: sfp: Add HWMON support for module sensors (Petr Oros) [1772010]
- [kernel] hwmon: Add helper to tell if a char is invalid in a name (Petr Oros) [1772010]
- [kernel] hwmon: Add support for power min, lcrit, min_alarm and lcrit_alarm (Petr Oros) [1772010]
- [kernel] hwmon: Add missing HWMON_T_LCRIT_ALARM define (Petr Oros) [1772010]
- [netdrv] phy: Drop OF dependency for MDIO_BCM_UNIMAC (Petr Oros) [1772010]
- [gpio] gpiolib: Mark gpio_suffixes array with __maybe_unused (Petr Oros) [1772010]
- [netdrv] phy: vitesse: Add support for VSC73xx (Petr Oros) [1772010]
- [netdrv] phy: dp83tc811: Fix SGMII enable/disable (Petr Oros) [1772010]
- [netdrv] phy: dp83tc811: Add INT_STAT3 (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Check read_status results (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Use correct mdio bus (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Check phy_driver ready before accessing (Petr Oros) [1772010]
- [netdrv] mdio-mux-gpio: Remove VLA usage (Petr Oros) [1772010]
- [netdrv] phy: fixed-phy: Make the error path simpler (Petr Oros) [1772010]
- [netdrv] phy: Allow compile test of GPIO consumers if !GPIOLIB (Petr Oros) [1772010]
- [watchdog] hpwdt: Reflect changes (Joseph Szczypek) [1769477]
- [documentation] watchdog/hpwdt: Update documentation (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Add module parameter kdumptimeout (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Have core ping watchdog (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Advertize max_hw_heartbeat_ms (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Stop hpwdt on unregister (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: drop warning after registering device (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Joseph Szczypek) [1769477]
- [nvme] make fabrics command run on a separate request queue (David Milburn) [1766361]
- [nvme] Restart request timers in resetting state (David Milburn) [1766361]
- [nvme] nvme-rdma: fix possible use-after-free in connect timeout (David Milburn) [1766361]
- [block] blk-mq: remove blk_mq_complete_request_sync (David Milburn) [1766361]
- [nvme] wait until all completed request's complete fn is called (David Milburn) [1766361]
- [nvme] don't abort completed request in nvme_cancel_request (David Milburn) [1766361]
- [block] blk-mq: introduce blk_mq_tagset_wait_completed_request() (David Milburn) [1766361]
- [block] blk-mq: introduce blk_mq_request_completed() (David Milburn) [1766361]

* Tue Nov 26 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-155.el8]
- [hwtracing] intel_th: pci: Add Jasper Lake PCH support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Comet Lake PCH support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix possible memory leak in mode_store() (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix overflow in shift of an unsigned int (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix missing allocation failure check on a kstrndup (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix an uninitialized mutex (Jiri Olsa) [1771015]
- [hwtracing] intel_th: gth: Fix the window switching sequence (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Tiger Lake support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Preserve pre-existing buffer configuration (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Prevent freeing buffers while locked windows exist (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Get rid of the window size limit (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu-sink: An example msu buffer "sink" (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Introduce buffer interface (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Start read iterator from a non-empty window (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Split sgt array and pointer in multiwindow mode (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Support multipage blocks (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Ice Lake NNPI support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix single mode with disabled IOMMU (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Remove set but not used variable 'last' (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix unused variable warning on arm64 platform (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Add current window tracking (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Add a sysfs attribute to trigger window switch (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Correct the block wrap detection (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Add switch triggering support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: gth: Factor out trace start/stop (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Factor out pipeline draining (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Switch over to scatterlist (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Replace open-coded list_{first, last, next}_entry variants (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Only report useful IRQs to subdevices (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Start handling IRQs (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Use MSI interrupt signalling (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Communicate IRQ via resource (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Add "rtit" source device (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Skip subdevices if their MMIO is missing (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Rework resource passing between glue layers and core (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix single mode with IOMMU (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Comet Lake support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: gth: Fix an off-by-one in output unassigning (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Don't reference unassigned outputs (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pti: Use sysfs_match_string() helper (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Only create useful device nodes (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Mark expected switch fall-throughs (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix an off-by-one in attribute store (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Fix resource handling for ACPI glue layer (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Fix device removal logic (Jiri Olsa) [1771015]
- [hwtracing] hwtracing/intel_th/msu.c: change return type to vm_fault_t (Jiri Olsa) [1771015]
- [scripts] kbuild: modversions: Fix relative CRC byte order interpretation (Don Zickus) [1772940]
- [tools] tools x86 uapi asm: Sync the pt_regs.h copy with the kernel sources (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for trace sequences APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for APIs used to extract common fields from a record (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_parse_header_page() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for parse event APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event filter APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event fields APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_read_number_field() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for print field APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for get field value APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for find field APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for libtraceevent event get APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for list events APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event find APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_read_number() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for registering print function (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for function related libtraceevent APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event handler APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_strerror() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for page size APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for host endian APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for file endian APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for get/set cpus APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for header_page APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for tep_handler related APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Add support for man pages with multiple names (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Introduce man pages (Michael Petlan) [1743208]
- [tools] perf/x86/regs: Use PERF_REG_EXTENDED_MASK (Michael Petlan) [1743208]
- [tools] perf record: Fix s390 missing module symbol and warning for non-root users (Michael Petlan) [1743208]
- [tools] perf machine: Read also the end of the kernel (Michael Petlan) [1743208]
- [tools] perf test vmlinux-kallsyms: Ignore aliases to _etext when searching on kallsyms (Michael Petlan) [1743208]
- [tools] perf session: Add missing swap ops for namespace events (Michael Petlan) [1743208]
- [tools] perf namespace: Protect reading thread's namespace (Michael Petlan) [1743208]
- [tools] perf data: Fix 'strncat may truncate' build failure with recent gcc (Michael Petlan) [1743208]
- [tools] perf stat: Support 'percore' event qualifier (Michael Petlan) [1743208]
- [tools] perf stat: Factor out aggregate counts printing (Michael Petlan) [1743208]
- [tools] perf tools: Add a 'percore' event qualifier (Michael Petlan) [1743208]
- [tools] perf docs: Add description for stderr (Michael Petlan) [1743208]
- [tools] perf intel-pt: Fix sample timestamp wrt non-taken branches (Michael Petlan) [1743208]
- [tools] perf intel-pt: Fix improved sample timestamp (Michael Petlan) [1743208]
- [tools] perf intel-pt: Fix instructions sampling rate (Michael Petlan) [1743208]
- [tools] perf regs x86: Add X86 specific arch__intr_reg_mask() (Michael Petlan) [1743208]
- [tools] perf parse-regs: Add generic support for arch__intr/user_reg_mask() (Michael Petlan) [1743208]
- [tools] perf parse-regs: Split parse_regs (Michael Petlan) [1743208]
- [tools] perf vendor events arm64: Add Cortex-A57 and Cortex-A72 events (Michael Petlan) [1743208]
- [tools] perf vendor events arm64: Map Brahma-B53 CPUID to cortex-a53 events (Michael Petlan) [1743208]
- [tools] perf vendor events arm64: Remove [[:xdigit:]] wildcard (Michael Petlan) [1743208]
- [tools] perf jevents: Remove unused variable (Michael Petlan) [1743208]
- [tools] perf test zstd: Fixup verbose mode output (Michael Petlan) [1743208]
- [tools] perf tests: Implement Zstd comp/decomp integration test (Michael Petlan) [1743208]
- [tools] perf inject: Enable COMPRESSED record decompression (Michael Petlan) [1743208]
- [tools] perf report: Implement perf.data record decompression (Michael Petlan) [1743208]
- [tools] perf record: Implement -z, --compression_level[=<n>] option (Michael Petlan) [1743208]
- [tools] perf report: Add stub processing of compressed events for -D (Michael Petlan) [1743208]
- [tools] perf record: Implement compression for AIO trace streaming (Michael Petlan) [1743208]
- [tools] perf record: Implement compression for serial trace streaming (Michael Petlan) [1743208]
- [tools] perf tools: Introduce Zstd streaming based compression API (Michael Petlan) [1743208]
- [tools] perf mmap: Implement dedicated memory buffer for data compression (Michael Petlan) [1743208]
- [tools] perf record: Implement COMPRESSED event record and its attributes (Michael Petlan) [1743208]
- [tools] perf session: Define 'bytes_transferred' and 'bytes_compressed' metrics (Michael Petlan) [1743208]
- [tools] perf build tests: Add NO_LIBZSTD=1 to make_minimal (Michael Petlan) [1743208]
- [tools] perf machine: Null-terminate version char array upon fgets(/proc/version) error (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Add uncore_upi JSON support (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add 'About' dialog box (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add context menu (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add copy to clipboard (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add tree level (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Fix error when shrinking / enlarging font (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Move view creation (Michael Petlan) [1743208]
- [tools] perf tools x86: Add support for recording and printing XMM registers (Michael Petlan) [1743208]
- [tools] perf parse-regs: Improve error output when faced with unknown register name (Michael Petlan) [1743208]
- [tools] perf record: Fix suggestion to get list of registers usable with --user-regs and --intr-regs (Michael Petlan) [1743208]
- [tools] perf tools: Speed up report for perf compiled with linwunwind (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Remove hard coded install paths from pkg-config file (Michael Petlan) [1743208]
- [tools] csky: Add support for libdw (Michael Petlan) [1743208]
- [tools] perf test: Fix spelling mistake "leadking" -> "leaking" (Michael Petlan) [1743208]
- [tools] perf annotate: Remove hist__account_cycles() from callback (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Silvermont to v14 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update GoldmontPlus to v1.01 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Goldmont to v13 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Bonnell to V4 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update KnightsLanding events to v9 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Haswell events to v28 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update IvyBridge events to v21 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update SandyBridge events to v16 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update JakeTown events to v20 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update IvyTown events to v20 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update HaswellX events to v20 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update BroadwellX events to v14 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update SkylakeX events to v1.12 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Skylake events to v42 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Broadwell-DE events to v7 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Broadwell events to v23 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update metrics from TMAM 3.5 (Michael Petlan) [1743208]
- [tools] perf record: Implement --mmap-flush=<number> option (Michael Petlan) [1743208]
- [tools] tools build: Implement libzstd feature check, LIBZSTD_DIR and NO_LIBZSTD defines (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Rename input arguments and local variables of libtraceevent from pevent to tep (Michael Petlan) [1743208]
- [tools] perf tools, tools lib traceevent: Rename "pevent" member of struct tep_event_filter to "tep" (Michael Petlan) [1743208]
- [tools] perf tools, tools lib traceevent: Rename "pevent" member of struct tep_event to "tep" (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Rename input arguments of libtraceevent APIs from pevent to tep (Michael Petlan) [1743208]
- [tools] tools tools, tools lib traceevent: Make traceevent APIs more consistent (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Remove call to exit() from tep_filter_add_filter_str() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Remove tep filter trivial APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Removed unneeded !! and return parenthesis (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Implement new traceevent APIs for accessing struct tep_handler fields (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Coding style fixes (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Change description of few APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Add more debugging to see various internal ring buffer entries (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Implement a new API, tep_list_events_copy() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Add mono clocks to be parsed in seconds (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Handle trace_printk() "px" (Michael Petlan) [1743208]
- [tools] perf list: Output tool events (Michael Petlan) [1743208]
- [tools] perf evsel: Support printing evsel name for 'duration_time' (Michael Petlan) [1743208]
- [tools] perf stat: Implement duration_time as a proper event (Michael Petlan) [1743208]
- [tools] perf stat: Revert checks for duration_time (Michael Petlan) [1743208]
- [tools] perf list: Fix s390 counter long description for L1D_RO_EXCL_WRITES (Michael Petlan) [1743208]
- [tools] perf tools: Add header defining used namespace struct to event.h (Michael Petlan) [1743208]
- [tools] perf trace beauty renameat: No need to include linux/fs.h (Michael Petlan) [1743208]
- [tools] perf augmented_raw_syscalls: Use a PERCPU_ARRAY map to copy more string bytes (Michael Petlan) [1743208]
- [tools] perf augmented_raw_syscalls: Copy strings from all syscalls with 1st or 2nd string arg (Michael Petlan) [1743208]
- [tools] perf trace: Add 'string' event alias to select syscalls with string args (Michael Petlan) [1743208]
- [x86] perf/x86: Always store regs->ip in perf_callchain_kernel() (Michael Petlan) [1743208]
- [x86] perf/x86: Remove pmu->pebs_no_xmm_regs (Michael Petlan) [1743208]
- [x86] perf/x86: Clean up PEBS_XMM_REGS (Michael Petlan) [1743208]
- [kernel] perf/x86: Disable extended registers for non-supported PMUs (Michael Petlan) [1743208]
- [kernel] perf/ioctl: Add check for the sample_period value (Michael Petlan) [1743208]
- [kernel] perf/core: Fix perf_sample_regs_user() mm check (Michael Petlan) [1743208]
- [kernel] perf/ring-buffer: Use regular variables for nesting (Michael Petlan) [1743208]
- [kernel] perf/ring-buffer: Always use {READ, WRITE}_ONCE() for rb->user_page data (Michael Petlan) [1743208]
- [kernel] perf/ring_buffer: Add ordering to rb->nest increment (Michael Petlan) [1743208]
- [kernel] perf/ring_buffer: Fix exposing a temporarily decreased data_head (Michael Petlan) [1743208]
- [x86] perf/x86/intel/ds: Fix EVENT vs. UEVENT PEBS constraints (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Allow PEBS multi-entry in watermark mode (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Fix INTEL_FLAGS_EVENT_CONSTRAINT* masking (Michael Petlan) [1743208]
- [x86] perf/x86/amd/iommu: Make the 'amd_iommu_attr_groups' symbol static (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Add Tremont core PMU support (Michael Petlan) [1743208]
- [x86] perf/x86/intel/uncore: Add Intel Icelake uncore support (Michael Petlan) [1743208]
- [x86] perf/x86/msr: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86/intel/rapl: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86/intel/cstate: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86: Support constraint ranges (Michael Petlan) [1743208]
- [x86] perf/x86/lbr: Avoid reading the LBRs when adaptive PEBS handles them (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Support adaptive PEBS v4 (Michael Petlan) [1743208]
- [x86] perf/x86/intel/ds: Extract code of event update in short period (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Extract memory code PEBS parser for reuse (Michael Petlan) [1743208]
- [x86] perf/x86: Support outputting XMM registers (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Force resched when TFA sysctl is modified (Michael Petlan) [1743208]
- [kernel] perf/core: Add perf_pmu_resched() as global function (Michael Petlan) [1743208]
- [kernel] perf/headers: Fix stale comment for struct perf_addr_filter (Michael Petlan) [1743208]
- [kernel] perf/core: Make perf_swevent_init_cpu() static (Michael Petlan) [1743208]
- [x86] perf/x86: Add sanity checks to x86_schedule_events() (Michael Petlan) [1743208]
- [x86] perf/x86: Optimize x86_schedule_events() (Michael Petlan) [1743208]
- [x86] perf/x86: Clear ->event_constraint[] on put (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Optimize intel_get_excl_constraints() (Michael Petlan) [1743208]
- [x86] perf/x86: Remove PERF_X86_EVENT_COMMITTED (Michael Petlan) [1743208]
- [x86] perf/x86: Simplify x86_pmu.get_constraints() interface (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Simplify intel_tfa_commit_scheduling() (Michael Petlan) [1743208]
- [tools] perf evsel: Do not rely on errno values for precise_ip fallback (Michael Petlan) [1715508]
- [kernel] redhat: perf kABI-check failure fix (Michael Petlan) [1715508]
- [tools] perf vendor events: Remove P8 HW events which are not supported (Michael Petlan) [1715508]
- [x86] cpufeature: Fix various quality problems in the <asm/cpu_device_hd.h> header (Michael Petlan) [1715508]
- [x86] cpufeature: Add facility to check for min microcode revisions (Michael Petlan) [1715508]
- [tools] perf tools: Remove needless asm/unistd.h include fixing build in some places (Michael Petlan) [1715508]
- [tools] tools build: Add -ldl to the disassembler-four-args feature test (Michael Petlan) [1715508]
- [tools] perf cs-etm: Always allocate memory for cs_etm_queue::prev_packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Don't check cs_etm_queue::prev_packet validity (Michael Petlan) [1715508]
- [tools] perf report: Report OOM in status line in the GTK UI (Michael Petlan) [1715508]
- [tools] perf bench numa: Add define for RUSAGE_THREAD if not present (Michael Petlan) [1715508]
- [tools] tools lib traceevent: Change tag string for error (Michael Petlan) [1715508]
- [tools] perf annotate: Fix build on 32 bit for BPF annotation (Michael Petlan) [1715508]
- [tools] perf bpf: Return value with unlocking in perf_env__find_btf() (Michael Petlan) [1715508]
- [tools] perf bpf: Return NULL when RB tree lookup fails in perf_env__find_btf() (Michael Petlan) [1715508]
- [tools] perf tools: Fix map reference counting (Michael Petlan) [1715508]
- [tools] perf evlist: Fix side band thread draining (Michael Petlan) [1715508]
- [tools] perf tools: Check maps for bpf programs (Michael Petlan) [1715508]
- [tools] perf bpf: Return NULL when RB tree lookup fails in perf_env__find_bpf_prog_info() (Michael Petlan) [1715508]
- [tools] tools include uapi: Sync sound/asound.h copy (Michael Petlan) [1715508]
- [tools] perf top: Always sample time to satisfy needs of use of ordered queuing (Michael Petlan) [1715508]
- [tools] perf evsel: Use hweight64() instead of hweight_long(attr.sample_regs_user) (Michael Petlan) [1715508]
- [tools] tools lib traceevent: Fix missing equality check for strcmp (Michael Petlan) [1715508]
- [tools] perf stat: Disable DIR_FORMAT feature for 'perf stat record' (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-sqlite.py: Fix use of parent_id in calls_view (Michael Petlan) [1715508]
- [tools] perf header: Fix lock/unlock imbalances when processing BPF/BTF info (Michael Petlan) [1715508]
- [tools] perf pmu: Fix parser error for uncore event alias (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Fix never-ending loop (Michael Petlan) [1715508]
- [tools] perf machine: Update kernel map address and re-order properly (Michael Petlan) [1715508]
- [tools] tools headers uapi: Synchronize i915_drm.h (Michael Petlan) [1715508]
- [tools] tools headers uapi: Update drm/i915_drm.h (Michael Petlan) [1715508]
- [tools] perf evsel: Fix max perf_event_attr.precise_ip detection (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix TSC slip (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add missing case value (Michael Petlan) [1715508]
- [tools] perf bpf: Show more BPF program info in print_bpf_prog_info() (Michael Petlan) [1715508]
- [tools] perf bpf: Extract logic to create program names from perf_event__synthesize_one_bpf_prog() (Michael Petlan) [1715508]
- [tools] perf tools: Save bpf_prog_info and BTF of new BPF programs (Michael Petlan) [1715508]
- [tools] perf evlist: Introduce side band thread (Michael Petlan) [1715508]
- [tools] perf annotate: Enable annotation of BPF programs (Michael Petlan) [1715508]
- [tools] perf build: Check what binutils's 'disassembler()' signature to use (Michael Petlan) [1715508]
- [tools] tools build: Add -lrt to FEATURE_CHECK_LDFLAGS-libaio (Michael Petlan) [1715508]
- [tools] tools build: Add test-reallocarray.c to test-all.c to fix the build (Michael Petlan) [1715508]
- [tools] perf bpf: Process PERF_BPF_EVENT_PROG_LOAD for annotation (Michael Petlan) [1715508]
- [tools] perf symbols: Introduce DSO_BINARY_TYPE__BPF_PROG_INFO (Michael Petlan) [1715508]
- [tools] perf feature detection: Add -lopcodes to feature-libbfd (Michael Petlan) [1715508]
- [tools] perf top: Add option --no-bpf-event (Michael Petlan) [1715508]
- [tools] perf bpf: Save BTF information as headers to perf.data (Michael Petlan) [1715508]
- [tools] perf bpf: Save BTF in a rbtree in perf_env (Michael Petlan) [1715508]
- [tools] perf bpf: Save bpf_prog_info information as headers to perf.data (Michael Petlan) [1715508]
- [tools] perf bpf: Save bpf_prog_info in a rbtree in perf_env (Michael Petlan) [1715508]
- [tools] perf bpf: Make synthesize_bpf_events() receive perf_session pointer instead of perf_tool (Michael Petlan) [1715508]
- [tools] perf bpf: Synthesize bpf events with bpf_program__get_prog_info_linear() (Michael Petlan) [1715508]
- [tools] perf record: Replace option --bpf-event with --no-bpf-event (Michael Petlan) [1715508]
- [tools] perf tests: Fix a memory leak in test__perf_evsel__tp_sched_test() (Michael Petlan) [1715508]
- [tools] perf tests: Fix memory leak by expr__find_other() in test__expr() (Michael Petlan) [1715508]
- [tools] perf tests: Fix a memory leak of cpu_map object in the openat_syscall_event_on_all_cpus test (Michael Petlan) [1715508]
- [tools] perf evsel: Free evsel->counts in perf_evsel__exit() (Michael Petlan) [1715508]
- [tools] perf top: Fix global-buffer-overflow issue (Michael Petlan) [1715508]
- [tools] perf maps: Purge all maps from the 'names' tree (Michael Petlan) [1715508]
- [tools] perf map: Remove map from 'names' tree in __maps__remove() (Michael Petlan) [1715508]
- [tools] perf hist: Add missing map__put() in error case (Michael Petlan) [1715508]
- [tools] perf top: Fix error handling in cmd_top() (Michael Petlan) [1715508]
- [tools] perf top: Delete the evlist before perf_session, fixing heap-use-after-free issue (Michael Petlan) [1715508]
- [tools] perf build-id: Fix memory leak in print_sdt_events() (Michael Petlan) [1715508]
- [tools] perf config: Fix a memory leak in collect_config() (Michael Petlan) [1715508]
- [tools] perf config: Fix an error in the config template documentation (Michael Petlan) [1715508]
- [tools] perf list: Don't forget to drop the reference to the allocated thread_map (Michael Petlan) [1715508]
- [tools] perf tools: Add doc about how to build perf with Asan and UBSan (Michael Petlan) [1715508]
- [tools] perf vendor events: Remove P8 HW events which are not supported (Michael Petlan) [1715508]
- [tools] perf stat: Improve scaling (Michael Petlan) [1715508]
- [tools] perf stat: Fix --no-scale (Michael Petlan) [1715508]
- [tools] perf script: Support relative time (Michael Petlan) [1715508]
- [tools] perf report: Indicate JITed code better in report (Michael Petlan) [1715508]
- [tools] perf report: Show all sort keys in help output (Michael Petlan) [1715508]
- [tools] perf record: Clarify help for --switch-output (Michael Petlan) [1715508]
- [tools] perf record: Allow to limit number of reported perf.data files (Michael Petlan) [1715508]
- [tools] perf list: Filter metrics too (Michael Petlan) [1715508]
- [tools] perf tools report: Add custom scripts to script menu (Michael Petlan) [1715508]
- [tools] perf ui browser: Fix ui popup argv browser for many entries (Michael Petlan) [1715508]
- [tools] perf script: Add array bound checking to list_scripts (Michael Petlan) [1715508]
- [tools] perf tools: Add some new tips describing the new options (Michael Petlan) [1715508]
- [tools] perf report: Implement browsing of individual samples (Michael Petlan) [1715508]
- [tools] perf report: Support builtin perf script in scripts menu (Michael Petlan) [1715508]
- [tools] perf report: Support running scripts for current time range (Michael Petlan) [1715508]
- [tools] perf report: Support time sort key (Michael Petlan) [1715508]
- [tools] perf script: Filter COMM/FORK/.. events by CPU (Michael Petlan) [1715508]
- [tools] perf tools: Update x86's syscall_64.tbl, no change in tools/perf behaviour (Michael Petlan) [1715508]
- [tools] perf script python: Add printdate function to SQL exporters (Michael Petlan) [1715508]
- [tools] perf report: Use less for scripts output (Michael Petlan) [1715508]
- [tools] perf session: Add process callback to reader object (Michael Petlan) [1715508]
- [tools] perf header: Add DIR_FORMAT feature to describe directory data (Michael Petlan) [1715508]
- [tools] perf data: Make perf_data__size() work over directory (Michael Petlan) [1715508]
- [tools] perf data: Add perf_data__update_dir() function (Michael Petlan) [1715508]
- [tools] perf data: Don't store auxtrace index for directory data file (Michael Petlan) [1715508]
- [tools] perf data: Support having perf.data stored as a directory (Michael Petlan) [1715508]
- [tools] perf vendor events amd: perf PMU events for AMD Family 17h (Michael Petlan) [1715508]
- [tools] perf probe: Fix getting the kernel map (Michael Petlan) [1715508]
- [tools] perf report: Parse time quantum (Michael Petlan) [1715508]
- [tools] perf time-utils: Add utility function to print time stamps in nanoseconds (Michael Petlan) [1715508]
- [tools] perf report: Support output in nanoseconds (Michael Petlan) [1715508]
- [tools] perf script: Support insn output for normal samples (Michael Petlan) [1715508]
- [tools] perf data: Force perf_data__open|close zero data->file.path (Michael Petlan) [1715508]
- [tools] perf session: Fix double free in perf_data__close (Michael Petlan) [1715508]
- [tools] perf evsel: Probe for precise_ip with simple attr (Michael Petlan) [1715508]
- [tools] perf tools: Read and store caps/max_precise in perf_pmu (Michael Petlan) [1715508]
- [tools] perf hist: Fix memory leak of srcline (Michael Petlan) [1715508]
- [tools] perf hist: Add error path into hist_entry__init (Michael Petlan) [1715508]
- [tools] perf diff: Support --pid/--tid filter options (Michael Petlan) [1715508]
- [tools] perf diff: Support --cpu filter option (Michael Petlan) [1715508]
- [tools] perf diff: Support --time filter option (Michael Petlan) [1715508]
- [tools] perf thread: Generalize function to copy from thread addr space from intel-bts code (Michael Petlan) [1715508]
- [tools] perf annotate: Calculate the max instruction name, align column to that (Michael Petlan) [1715508]
- [tools] perf clang: Remove needless extra semicolon (Michael Petlan) [1715508]
- [tools] perf bpf: Automatically add BTF ELF markers (Michael Petlan) [1715508]
- [tools] perf beauty msg_flags: Add missing s lost when adding prefix suppression logic (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Add call tree (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out CallGraphModelBase (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Improve TreeModel abstraction (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out TreeWindowBase (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-postgresql.py: Export calls parent_id (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-postgresql.py: Fix invalid input syntax for integer error (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-sqlite.py: Export calls parent_id (Michael Petlan) [1715508]
- [tools] perf db-export: Add calls parent_id to enable creation of call trees (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix divide by zero when TSC is not available (Michael Petlan) [1715508]
- [tools] perf auxtrace: Improve address filter error message when there is no DSO (Michael Petlan) [1715508]
- [tools] perf time-utils: Refactor time range parsing code (Michael Petlan) [1715508]
- [tools] tools lib traceevent: Fix buffer overflow in arg_eval (Michael Petlan) [1715508]
- [tools] perf probe: Clarify error message about not finding kernel modules debuginfo (Michael Petlan) [1715508]
- [tools] replace open encodings for NUMA_NO_NODE (Michael Petlan) [1715508]
- [tools] perf script python: Add Python3 support to stat-cpi.py (Michael Petlan) [1715508]
- [tools] perf tools: Add perf_exe() helper to find perf binary (Michael Petlan) [1715508]
- [tools] perf script: Handle missing fields with -F +. (Michael Petlan) [1715508]
- [tools] perf data: Add perf_data__open_dir_data function (Michael Petlan) [1715508]
- [tools] perf data: Add perf_data__(create_dir|close_dir) functions (Michael Petlan) [1715508]
- [tools] perf data: Fail check_backup in case of error (Michael Petlan) [1715508]
- [tools] perf data: Make check_backup work over directories (Michael Petlan) [1715508]
- [tools] perf tools: Add rm_rf_perf_data function (Michael Petlan) [1715508]
- [tools] perf tools: Add pattern name checking to rm_rf (Michael Petlan) [1715508]
- [tools] perf tools: Add depth checking to rm_rf (Michael Petlan) [1715508]
- [tools] perf data: Add global path holder (Michael Petlan) [1715508]
- [tools] perf data: Move size to struct perf_data_file (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Add top calls report (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Remove no selection error (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Remove SQLTableDialogDataItem (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Create new dialog data item classes (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Move report name into ReportVars (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out ReportVars (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out ReportDialogBase (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Move column headers (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Hide Call Graph option if no calls table (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Remove leftover debugging prints (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Fix missing shebang (Michael Petlan) [1715508]
- [tools] perf thread-stack: Hide x86 retpolines (Michael Petlan) [1715508]
- [tools] perf thread-stack: Improve thread_stack__no_call_return() (Michael Petlan) [1715508]
- [tools] perf tools: Make rm_rf() remove single file (Michael Petlan) [1715508]
- [tools] perf cpumap: Increase debug level for cpu_map__snprint verbose output (Michael Petlan) [1715508]
- [tools] perf bpf-event: Add missing new line into pr_debug call (Michael Petlan) [1715508]
- [tools] perf script: Allow +- operator for type specific fields option (Michael Petlan) [1715508]
- [tools] perf evsel: Force sample_type for slave events (Michael Petlan) [1715508]
- [tools] perf session: Don't report zero period samples for slave events (Michael Petlan) [1715508]
- [tools] perf trace: Allow dumping a BPF map after setting up BPF events (Michael Petlan) [1715508]
- [tools] perf bpf: Add bpf_map dumper (Michael Petlan) [1715508]
- [tools] perf doc: Fix documentation of the Flags section in perf.data (Michael Petlan) [1715508]
- [tools] perf doc: Fix HEADER_CMDLINE description in perf.data documentation (Michael Petlan) [1715508]
- [tools] perf report: Don't shadow inlined symbol with different addr range (Michael Petlan) [1715508]
- [tools] perf tools: Use sysfs__mountpoint() when reading cpu topology (Michael Petlan) [1715508]
- [tools] perf tools: Add numa_topology object (Michael Petlan) [1715508]
- [tools] perf tools: Add cpu_topology object (Michael Petlan) [1715508]
- [tools] perf tests shell: Skip trace+probe_vfs_getname.sh if built without trace support (Michael Petlan) [1715508]
- [tools] perf header: Remove unused 'cpu_nr' field from 'struct cpu_topo' (Michael Petlan) [1715508]
- [tools] perf header: Get rid of write_it label (Michael Petlan) [1715508]
- [tools] perf list: Display metric expressions for --details option (Michael Petlan) [1715508]
- [tools] perf tools: Fix legacy events symbol separator parsing (Michael Petlan) [1715508]
- [tools] perf tools: Rename build libperf to perf (Michael Petlan) [1715508]
- [tools] perf tools: Rename LIB_FILE to LIBPERF_A (Michael Petlan) [1715508]
- [tools] perf tools: Compile perf with libperf-in.o instead of libperf.a (Michael Petlan) [1715508]
- [tools] perf cs-etm: Modularize auxtrace_buffer fetch function (Michael Petlan) [1715508]
- [tools] perf cs-etm: Modularize main packet processing loop (Michael Petlan) [1715508]
- [tools] perf cs-etm: Modularize main decoder function (Michael Petlan) [1715508]
- [tools] perf cs-etm: Make cs_etm__run_decoder() queue independent (Michael Petlan) [1715508]
- [tools] perf cs-etm: Rethink kernel address initialisation (Michael Petlan) [1715508]
- [tools] perf cs-etm: Cleaning up function cs_etm__alloc_queue() (Michael Petlan) [1715508]
- [tools] perf cs-etm: Fix erroneous comment (Michael Petlan) [1715508]
- [tools] perf cs-etm: Introducing function cs_etm__init_trace_params() (Michael Petlan) [1715508]
- [tools] perf cs-etm: Fix memory leak in error path (Michael Petlan) [1715508]
- [tools] perf cs-etm: Introducing function cs_etm_decoder__init_dparams() (Michael Petlan) [1715508]
- [tools] perf cs-etm: Fix wrong return values in error path (Michael Petlan) [1715508]
- [tools] perf cs-etm: Remove unused structure field "time" and "timestamp" (Michael Petlan) [1715508]
- [tools] perf cs-etm: Remove unused structure field "state" (Michael Petlan) [1715508]
- [tools] perf build: Add missing FEATURE_CHECK_LDFLAGS-libcrypto (Michael Petlan) [1715508]
- [tools] perf unwind: Do not put libunwind-{x86, aarch64} in FEATURE_TESTS_BASIC (Michael Petlan) [1715508]
- [tools] perf coresight: Do not test for libopencsd by default (Michael Petlan) [1715508]
- [tools] perf trace: Filter out gnome-terminal* parent (Michael Petlan) [1715508]
- [tools] perf trace: Check if the 'fd' is negative when mapping it to pathname (Michael Petlan) [1715508]
- [tools] perf beauty ioctl cmd: The 'fd' arg is signed (Michael Petlan) [1715508]
- [tools] perf utils: Silence "Couldn't synthesize bpf events" warning for EPERM (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add proper header file for symbols (Michael Petlan) [1715508]
- [tools] perf record: Implement --affinity=node|cpu option (Michael Petlan) [1715508]
- [tools] perf auxtrace: Add timestamp to auxtrace errors (Michael Petlan) [1715508]
- [tools] perf intel-pt: Packet splitting can happen only on 32-bit (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix CYC timestamp calculation after OVF (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix overlap calculation for padding (Michael Petlan) [1715508]
- [tools] perf auxtrace: Define auxtrace record alignment (Michael Petlan) [1715508]
- [tools] perf thread-stack: Represent jmps to the start of a different symbol (Michael Petlan) [1715508]
- [tools] perf thread-stack: Tidy thread_stack__no_call_return() by adding more local variables (Michael Petlan) [1715508]
- [tools] perf thread-stack: Tidy thread_stack__push_cp() usage (Michael Petlan) [1715508]
- [tools] perf tools: Fix split_kallsyms_for_kcore() for trampoline symbols (Michael Petlan) [1715508]
- [tools] perf vendor events intel: Fix Load_Miss_Real_Latency on CLX (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for exception return packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for exception packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add traceID in packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Change tuple from traceID-CPU# to traceID-metadata (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add exception number in exception packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for trace discontinuity (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for instruction range packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add last instruction information in packet (Michael Petlan) [1715508]
- [tools] perf tools: Add documentation for BPF event selection (Michael Petlan) [1715508]
- [tools] perf report: Move symbol annotation to the resort phase (Michael Petlan) [1715508]
- [tools] perf evsel: Add output_resort_cb method (Michael Petlan) [1715508]
- [tools] perf hists: Add argument to hists__resort_cb_t callback (Michael Petlan) [1715508]
- [tools] perf record: Apply affinity masks when reading mmap buffers (Michael Petlan) [1715508]
- [tools] perf tools: Add fallback versions for CPU_{OR, EQUAL}() (Michael Petlan) [1715508]
- [tools] perf record: Bind the AIO user space buffers to nodes (Michael Petlan) [1715508]
- [tools] perf record: Allocate affinity masks (Michael Petlan) [1715508]
- [tools] perf pmu: Remove set_drv_config API (Michael Petlan) [1715508]
- [tools] perf coresight: Remove set_drv_config() API (Michael Petlan) [1715508]
- [tools] perf arm cs-etm: Use event attributes to send sink information to kernel (Michael Petlan) [1715508]
- [tools] perf pmu: Move EVENT_SOURCE_DEVICE_PATH to PMU header file (Michael Petlan) [1715508]
- [tools] perf bpf-loader: Remove unecessary includes from bpf-loader.h (Michael Petlan) [1715508]
- [tools] perf powerpc kvm-stat: Add missing evlist.h header (Michael Petlan) [1715508]
- [tools] perf kvm stat: Replace kvm-stat.h includes with forward declarations (Michael Petlan) [1715508]
- [tools] perf pmu: Remove needless evsel.h only needs one fwd decl (Michael Petlan) [1715508]
- [tools] perf tests pmu: Add missing headers (Michael Petlan) [1715508]
- [tools] perf hist: Remove the needless callchain.h include from hist.h (Michael Petlan) [1715508]
- [tools] perf tools: Add missing include <callchain.h> in various places (Michael Petlan) [1715508]
- [tools] perf thread: Don't include symbol.h, symbol_conf.h is enough (Michael Petlan) [1715508]
- [tools] perf evsel: No need to include symbol.h in evsel.h, symbol_conf.h is enough (Michael Petlan) [1715508]
- [tools] perf tools: Add missing include for symbols.h (Michael Petlan) [1715508]
- [tools] perf hist: Remove symbol.h from hist.h, just fwd decls are needed (Michael Petlan) [1715508]
- [tools] perf tests: Add missing headers so far obtained indirectly (Michael Petlan) [1715508]
- [tools] perf map: Move structs and prototypes for map groups to a separate header (Michael Petlan) [1715508]
- [tools] pref tools: Add missing map.h includes (Michael Petlan) [1715508]
- [tools] perf symbols: Introduce map_symbol.h (Michael Petlan) [1715508]
- [tools] perf callchain: Uninline callchain_cursor_reset() to remove map.h dependency (Michael Petlan) [1715508]
- [tools] perf srccode: Move struct definition from map.h to srccode.h (Michael Petlan) [1715508]
- [tools] perf arm pmu: Add missing linux/string.h header (Michael Petlan) [1715508]
- [tools] perf powerpc: Add missing headers to skip-callchain-idx.c (Michael Petlan) [1715508]
- [tools] perf augmented_syscalls: Convert to bpf_map() (Michael Petlan) [1715508]
- [tools] perf bpf examples: Convert etcsnoop to use bpf_map() (Michael Petlan) [1715508]
- [tools] perf trace: Fixup etcsnoop example (Michael Petlan) [1715508]
- [tools] perf augmented_raw_syscalls: Use bpf_map() (Michael Petlan) [1715508]
- [tools] perf bpf: Convert pid_map() to bpf_map() (Michael Petlan) [1715508]
- [tools] perf bpf: Add bpf_map() helper (Michael Petlan) [1715508]
- [tools] perf bpf: Fix synthesized PERF_RECORD_KSYMBOL/BPF_EVENT (Michael Petlan) [1715508]
- [tools] perf sched: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf hist: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf symbols: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf util: Use cached rbtree for rblists (Michael Petlan) [1715508]
- [tools] perf callchain: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf machine: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] Update rbtree implementation (Michael Petlan) [1715508]
- [tools] perf callchain: No need to include perf.h (Michael Petlan) [1715508]
- [tools] perf comm: Remove needless headers from comm.h (Michael Petlan) [1715508]
- [tools] perf namespaces: Remove namespaces.h from .h headers (Michael Petlan) [1715508]
- [tools] perf symbols: Remove some unnecessary includes from symbol.h (Michael Petlan) [1715508]
- [tools] perf symbols: Remove include map.h from dso.h (Michael Petlan) [1715508]
- [tools] perf block-range: Add missing headers (Michael Petlan) [1715508]
- [tools] perf tools: Move branch structs to branch.h (Michael Petlan) [1715508]
- [tools] perf annotate: Remove lots of headers from annotate.h (Michael Petlan) [1715508]
- [tools] perf symbols: Move symbol_conf to separate file (Michael Petlan) [1715508]
- [tools] perf color: Add missing stdarg.g to color.h (Michael Petlan) [1715508]
- [tools] perf utils: Move perf_config using routines from color.c to separate object (Michael Petlan) [1715508]
- [tools] perf top: Synthesize BPF events for pre-existing loaded BPF programs (Michael Petlan) [1715508]
- [tools] perf tools: Synthesize PERF_RECORD_* for loaded BPF programs (Michael Petlan) [1715508]
- [tools] perf tools: Handle PERF_RECORD_BPF_EVENT (Michael Petlan) [1715508]
- [tools] perf tools: Handle PERF_RECORD_KSYMBOL (Michael Petlan) [1715508]
- [tools] tools headers uapi: Sync tools/include/uapi/linux/perf_event.h (Michael Petlan) [1715508]
- [tools] tools headers uapi: Sync tools/include/uapi/linux/perf_event.h (Michael Petlan) [1715508]
- [tools] perf report: Display names in s390 diagnostic counter sets (Michael Petlan) [1715508]
- [tools] perf tools: Remove duplicate headers (Michael Petlan) [1715508]
- [tools] perf session: Add reader__process_events function (Michael Petlan) [1715508]
- [tools] perf session: Add 'data_offset' member to reader object (Michael Petlan) [1715508]
- [tools] perf session: Add 'data_size' member to reader object (Michael Petlan) [1715508]
- [tools] perf session: Add reader object (Michael Petlan) [1715508]
- [tools] perf session: Get rid of file_size variable (Michael Petlan) [1715508]
- [tools] perf session: Rearrange perf_session__process_events function (Michael Petlan) [1715508]
- [tools] perf tools: Replace automatic const char[] variables by statics (Michael Petlan) [1715508]
- [tools] perf/doc: Update design.txt for exclude_{host|guest} flags (Michael Petlan) [1715508]
- [x86] perf/x86/intel/pt: Remove software double buffering PMU capability (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Fix AUX software double buffering (Michael Petlan) [1715508]
- [x86] perf/x86/amd: Update generic hardware cache events for Family 17h (Michael Petlan) [1715508]
- [x86] perf/x86/amd: Add event map for AMD Family 17h (Michael Petlan) [1715508]
- [x86] perf/x86: Fix incorrect PEBS_REGS (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Fix AUX record suppression (Michael Petlan) [1715508]
- [kernel] perf/core: Fix the address filtering fix (Michael Petlan) [1715508]
- [kernel] perf/core: Fix perf_event_disable_inatomic() race (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Initialize TFA MSR (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Fix handling of wakeup_events for multi-entry PEBS (Michael Petlan) [1715508]
- [kernel] perf/core: Restore mmap record type correctly (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Make dev_attr_allow_tsx_force_abort static (Michael Petlan) [1715508]
- [kernel] uprobes: convert uprobe.ref to refcount_t (Michael Petlan) [1715508]
- [kernel] perf, bpf: Consider events with attr.bpf_event as side-band events (Michael Petlan) [1715508]
- [kernel] perf/core: Mark expected switch fall-through (Michael Petlan) [1715508]
- [x86] perf/x86/intel/uncore: Fix client IMC events return huge result (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Use high order allocations for AUX buffers optimistically (Michael Petlan) [1715508]
- [x86] events: Mark expected switch-case fall-throughs (Michael Petlan) [1715508]
- [kernel] perf, pt, coresight: Fix address filters for vmas with non-zero offset (Michael Petlan) [1715508]
- [kernel] perf: Copy parent's address filter offsets on clone (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Add counter freezing quirk for Goldmont (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Clean up counter freezing quirk (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Clean up SNB PEBS quirk (Michael Petlan) [1715508]
- [x86] perf/x86/kvm: Avoid unnecessary work in guest filtering (Michael Petlan) [1715508]
- [perf] aux: Make perf_event accessible to setup_aux() (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Convert ring_buffer.aux_refcount to refcount_t (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Convert ring_buffer.refcount to refcount_t (Michael Petlan) [1715508]
- [kernel] perf: Convert perf_event_context.refcount to refcount_t (Michael Petlan) [1715508]
- [kernel] perf/uprobes: Convert to SPDX license identifier (Michael Petlan) [1715508]
- [kernel] perf/hw_breakpoints: Convert to SPDX license identifier (Michael Petlan) [1715508]
- [kernel] perf/core: Convert to SPDX license identifiers (Michael Petlan) [1715508]
- [kernel] perf, bpf: Introduce PERF_RECORD_BPF_EVENT (Michael Petlan) [1715508]
- [kernel] perf, bpf: Introduce PERF_RECORD_KSYMBOL (Michael Petlan) [1715508]
- [kernel] perf: Remove duplicated workqueue.h include from perf_event.h (Michael Petlan) [1715508]
- [tools] perf/core: Remove unused perf_flags (Michael Petlan) [1715508]
- [x86] perf/core, arch/x86: Strengthen exclusion checks with PERF_PMU_CAP_NO_EXCLUDE (Michael Petlan) [1715508]
- [x86] perf/core, arch/x86: Use PERF_PMU_CAP_NO_EXCLUDE for exclusion incapable PMUs (Michael Petlan) [1715508]
- [kernel] perf/core: Add PERF_PMU_CAP_NO_EXCLUDE for exclusion incapable PMUs (Michael Petlan) [1715508]
- [kernel] perf/core: Add function to test for event exclusion flags (Michael Petlan) [1715508]

* Tue Nov 26 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-154.el8]
- [kernel] mm/hmm: fix ZONE_DEVICE anon page mapping reuse (Jerome Glisse) [1498655 1597758]
- [gpu] drm/nouveau/dmem: missing mutex_lock in error path (Jerome Glisse) [1498655 1597758]
- [mm] hmm: always return EBUSY for invalid ranges in hmm_range_{fault, snapshot} (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: move hmm_vma_range_done and hmm_vma_fault to nouveau (Jerome Glisse) [1498655 1597758]
- [kernel] mm: factor out a devm_request_free_mem_region helper (Jerome Glisse) [1498655 1597758]
- [mm] don't clear ->mapping in hmm_devmem_free (Jerome Glisse) [1498655 1597758]
- [mm] remove the struct hmm_device infrastructure (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Fix error flows in hmm_invalidate_range_start (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Remove confusing comment and logic from hmm_release (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Poison hmm_range during unregister (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Remove racy protection against double-unregistration (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Use lockdep instead of comments (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Hold on to the mmget for the lifetime of the range (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Do not use list*_rcu() for hmm->ranges (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Simplify hmm_get_or_create and make it reliable (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: Remove duplicate condition test before wait_event_timeout (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Hold a mmgrab from hmm to mm (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Use hmm_mirror not mm as an argument for hmm_range_register (Jerome Glisse) [1498655 1597758]
- [mm] hmm: fix use after free with struct hmm in the mmu notifiers (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Only set FAULT_FLAG_ALLOW_RETRY for non-blocking (Jerome Glisse) [1498655 1597758]
- [mm] hmm: support automatic NUMA balancing (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: clean up some coding style and comments (Jerome Glisse) [1498655 1597758]
- [mm] hmm.c: suppress compilation warnings when CONFIG_HUGETLB_PAGE is not set (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: convert various hmm_pfn_* to device_entry which is a better name (Jerome Glisse) [1498655 1597758]
- [mm] hmm: add a helper function that fault pages and map them to a device (Jerome Glisse) [1498655 1597758]
- [mm] hmm: allow to mirror vma of a file on a DAX backed filesystem (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: add helpers to test if mm is still alive or not (Jerome Glisse) [1498655 1597758]
- [mm] hmm: mirror hugetlbfs (snapshoting, faulting and DMA mapping) (Jerome Glisse) [1498655 1597758]
- [documentation] [documentation] mm/hmm: add default fault flags to avoid the need to pre-fill pfns arrays (Jerome Glisse) [1498655 1597758]
- [mm] hmm: improve driver API to work and wait over a range (Jerome Glisse) [1498655 1597758]
- [mm] hmm: improve and rename hmm_vma_fault() to hmm_range_fault() (Jerome Glisse) [1498655 1597758]
- [mm] hmm: improve and rename hmm_vma_get_pfns() to hmm_range_snapshot() (Jerome Glisse) [1498655 1597758]
- [mm] hmm: do not erase snapshot when a range is invalidated (Jerome Glisse) [1498655 1597758]
- [mm] hmm: use reference counting for HMM struct (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: convert to use vm_fault_t (Jerome Glisse) [1498655 1597758]
- [mm] hmm.c: remove set but not used variable 'devmem' (Jerome Glisse) [1498655 1597758]
- [mm] hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL (Jerome Glisse) [1498655 1597758]
- [mm] hmm: replace hmm_devmem_pages_create() with devm_memremap_pages() (Jerome Glisse) [1498655 1597758]
- [mm] hmm: use devm semantics for hmm_devmem_{add, remove} (Jerome Glisse) [1498655 1597758]
- [mm] hmm: invalidate device page table at start of invalidation (Jerome Glisse) [1498655 1597758]
- [mm] hmm: use a structure for update callback parameters (Jerome Glisse) [1498655 1597758]
- [mm] hmm: properly handle migration pmd (Jerome Glisse) [1498655 1597758]
- [mm] hmm: fix utf8 . (Jerome Glisse) [1498655 1597758]
- [mm] hmm.c: remove unused variables align_start and align_end (Jerome Glisse) [1498655 1597758]
- [hid] hyperv: Use in-place iterator API in the channel callback (Benjamin Tissoires) [1740778 1772010]
- [hid] logitech-hidpp: do all FF cleanup in hidpp_ff_destroy() (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: rework device validation (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: split g920_get_config() (Benjamin Tissoires) [1740778]
- [hid] fix error message in hid_open_report() (Benjamin Tissoires) [1740778]
- [hid] Fix assumption that devices have inputs (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: add Trekstor Primebook C11B to descriptor override (Benjamin Tissoires) [1740778]
- [hid] apple: Fix stuck function keys when using FN (Benjamin Tissoires) [1740778]
- [hid] wacom: Fix several minor compiler warnings (Benjamin Tissoires) [1740778]
- [hid] Add quirk for HP X500 PIXART OEM mouse (Benjamin Tissoires) [1740778]
- [hid] hidraw: Fix invalid read in hidraw_ioctl (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Fix crash when initial logi_dj_recv_query_paired_devices fails (Benjamin Tissoires) [1740778]
- [hid] logitech: Fix general protection fault caused by Logitech driver (Benjamin Tissoires) [1740778]
- [hid] sony: Fix memory corruption issue on cleanup (Benjamin Tissoires) [1740778]
- [hid] prodikeys: Fix general protection fault during probe (Benjamin Tissoires) [1740778]
- [hid] wacom: correct misreported EKR ring values (Benjamin Tissoires) [1740778]
- [hid] cp2112: prevent sleeping function called from invalid context (Benjamin Tissoires) [1740778]
- [hid] wacom: Correct distance scale for 2nd-gen Intuos devices (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove support for the G700 over USB (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech-hidpp: add USB PID for a few more supported mice" (Benjamin Tissoires) [1740778]
- [hid] sony: Fix race condition between rumble and device remove (Benjamin Tissoires) [1740778]
- [hid] hiddev: do cleanup in failure of opening a device (Benjamin Tissoires) [1740778]
- [hid] hiddev: avoid opening a disconnected device (Benjamin Tissoires) [1740778]
- [hid] input: fix a4tech horizontal wheel custom usage (Benjamin Tissoires) [1740778]
- [hid] Add quirk for HP X1200 PIXART OEM mouse (Benjamin Tissoires) [1740778]
- [hid] holtek: test for sanity of intfdata (Benjamin Tissoires) [1740778]
- [hid] wacom: fix bit shift for Cintiq Companion 2 (Benjamin Tissoires) [1740778]
- [hid] quirks: Set the INCREMENT_USAGE_ON_DUPLICATE quirk on Saitek X52 (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Really fix return value of logi_dj_recv_query_hidpp_devices (Benjamin Tissoires) [1740778]
- [hid] Add 044f:b320 ThrustMaster, Inc. 2 in 1 DT (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add the Powerplay receiver (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add USB PID for a few more supported mice (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: rename "gaming" receiver to "lightspeed" (Benjamin Tissoires) [1740778]
- [hid] Add another Primax PIXART OEM mouse quirk (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: add touchring adjustment for 2nd Gen Pro Small (Benjamin Tissoires) [1740778]
- [hid] quirks: Refactor ELAN 400 and 401 handling (Benjamin Tissoires) [1740778]
- [hid] video: fbdev: don't print error message on framebuffer_alloc() failure (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Fix forwarding of very long HID++ reports (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Huion HS64 tablet (Benjamin Tissoires) [1740778]
- [hid] wacom: add new MobileStudio Pro support (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: read the number of expected touches on a per collection basis (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: support the 'report valid' usage for touch (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: read HID_DG_CONTACTMAX from any feature report (Benjamin Tissoires) [1740778]
- [hid] wacom: Add 2nd gen Intuos Pro Small support (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee Rainbow CV720 (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: fix return value of logi_dj_recv_query_hidpp_devices (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 372 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 335 (Benjamin Tissoires) [1740778]
- [hid] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 333 (Benjamin Tissoires) [1740778]
- [hid] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 307 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 297 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 282 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 267 (Benjamin Tissoires) [1740778]
- [hid] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 265 (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Fix 064d:c52f receiver support (Benjamin Tissoires) [1740778]
- [hid] revert "hid: core: Call request_module before doing device_add" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: core: Do not call request_module() in async context" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: Increase maximum report size allowed by hid_field_extract()" (Benjamin Tissoires) [1740778]
- [hid] a4tech: fix horizontal scrolling (Benjamin Tissoires) [1740778]
- [hid] hyperv: Add a module description line (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 194 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 178 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 177 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 149 (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: Add support for the S510 remote control (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: hid: make const array consumer_rdesc_start static (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: make const array template static (Benjamin Tissoires) [1740778]
- [hid] multitouch: handle faulty Elo touch device (Benjamin Tissoires) [1740778]
- [input] treewide: Add SPDX license identifier for more missed files (Benjamin Tissoires) [1740778]
- [hid] wacom: Sync INTUOSP2_BT touch state after each frame if necessary (Benjamin Tissoires) [1740778]
- [hid] wacom: Correct button numbering 2nd-gen Intuos Pro over Bluetooth (Benjamin Tissoires) [1740778]
- [hid] wacom: Send BTN_TOUCH in response to INTUOSP2_BT eraser contact (Benjamin Tissoires) [1740778]
- [hid] wacom: Don't report anything prior to the tool entering range (Benjamin Tissoires) [1740778]
- [hid] wacom: Don't set tool type until we're in range (Benjamin Tissoires) [1740778]
- [hid] wacom: correct touch resolution x/y typo (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: Correct pad syncing (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: only switch the mode on devices with LEDs (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Add usb-id for the 27MHz MX3000 receiver (Benjamin Tissoires) [1740778]
- [hid] rmi: Use SET_REPORT request on control endpoint for Acer Switch 3 and 5 (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for the MX5500 keyboard (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for the Logitech MX5500's Bluetooth Mini-Receiver (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: add iBall Aer3 to descriptor override (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: fix spelling in printk (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for KEY_KBD_LAYOUT_NEXT (Benjamin Tissoires) [1740778]
- [hid] input: fix assignment of .value (Benjamin Tissoires) [1740778]
- [hid] input: make sure the wheel high resolution multiplier is set (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add usbhid dependency in Kconfig (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for HID++ 1.0 consumer keys reports (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for HID++ 1.0 extra mouse buttons reports (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for HID++ 1.0 wheel reports (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: make hidpp10_set_register_bit a bit more generic (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add input_device ptr to struct hidpp_device (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: do not hardcode very long report length (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: handle devices attached to 27MHz wireless receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: use RAP instead of FAP to get the protocol version (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove unused origin_is_hid_core function parameter (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove double assignment from __hidpp_send_report (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: do not make failure to get the name fatal (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: ignore very-short or empty names (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: make .probe usbhid capable (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: allow non HID++ devices to be handled by this module (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for Logitech Bluetooth Mini-Receiver (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: make appending of the HID++ descriptors conditional (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: remove false-positive error on double queueing of delayed-work (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: pick a better name for non-unifying receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: deal with some KVMs adding an extra interface to the usbdev (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: replace dev_err calls with hid_err calls (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for 27 MHz mouse-only receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for 27 MHz receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for the gaming unifying receiver (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for non unifying receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add logi_dj_recv_queue_unknown_work helper (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: support sharing struct dj_receiver_dev between USB-interfaces (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: rename dj_receiver_dev.hdev to dj_receiver_dev.hidpp (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: protect the paired_dj_devices access in add_djhid_dev with the lock (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: remove unused querying_devices variable (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: do not schedule the dj report itself (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: remove USB dependency (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: declare and use a few HID++ 1.0 constants (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: use BIT() macro for RF Report types (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: fix variable naming in logi_dj_hidpp_event (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: reshuffle logi_dj_recv_forward_* (Benjamin Tissoires) [1740778]
- [hid] logitech: Stop setting drvdata to NULL on probe failure and remove (Benjamin Tissoires) [1740778]
- [hid] quirks: do not blacklist Logitech devices (Benjamin Tissoires) [1740778]
- [hid] u2fzero: fail probe if not using USB transport (Benjamin Tissoires) [1740778]
- [hid] u2fzero: fix compiling error in u2fzero_probe() (Benjamin Tissoires) [1740778]
- [hid] revert "hid: i2c-hid: Disable runtime PM on Synaptics touchpad" (Benjamin Tissoires) [1740778]
- [hid] add driver for U2F Zero built-in LED and RNG (Benjamin Tissoires) [1740778]
- [hid] core: Do not call request_module() in async context (Benjamin Tissoires) [1740778]
- [hid] macally: Add support for Macally ikey keyboard (Benjamin Tissoires) [1740778]
- [hid] core: Call request_module before doing device_add (Benjamin Tissoires) [1740778]
- [hid] core: move Usage Page concatenation to Main item (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: change low battery level threshold from 31 to 30 percent (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove hidpp_is_connected() (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: simplify printing of HID++ version (Benjamin Tissoires) [1740778]
- [hid] picolcd: Convert to use sysfs_streq() (Benjamin Tissoires) [1740778]
- [hid] hid-sensor-custom: simplify getting .driver_data (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for Assistant key (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Disable runtime PM on Synaptics touchpad (Benjamin Tissoires) [1740778]
- [hid] quirks: Fix keyboard + touchpad on Lenovo Miix 630 (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for "Toggle Display" key (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for "Full Screen" key (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for keyboard Brightness Up/Down/Toggle keys (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for Expose/Overview key (Benjamin Tissoires) [1740778]
- [hid] input: fix mapping of aspect ratio key (Benjamin Tissoires) [1740778]
- [hid] logitech: Handle 0 scroll events for the m560 (Benjamin Tissoires) [1740778]
- [hid] debug: fix race condition with between rdesc_show() and device removal (Benjamin Tissoires) [1740778]
- [hid] logitech: check the return value of create_singlethread_workqueue (Benjamin Tissoires) [1740778]
- [hid] steam: fix deadlock with input devices (Benjamin Tissoires) [1740778]
- [hid] uclogic: remove redudant duplicated null check on ver_ptr (Benjamin Tissoires) [1740778]
- [hid] quirks: Drop misused kernel-doc annotation (Benjamin Tissoires) [1740778]
- [hid] quirks: use correct format chars in dbg_hid (Benjamin Tissoires) [1740778]
- [hid] Remove Waltop tablets from hid_have_special_driver (Benjamin Tissoires) [1740778]
- [hid] Remove KYE tablets from hid_have_special_driver (Benjamin Tissoires) [1740778]
- [hid] Remove hid-uclogic entries from hid_have_special_driver (Benjamin Tissoires) [1740778]
- [hid] uclogic: Do not initialize non-USB devices (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee G5 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support Gray-coded rotary encoders (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support faking Wacom pad device ID (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for XP-Pen Deco 01 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for XP-Pen Star G640 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for XP-Pen Star G540 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee EX07S frame controls (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee M540 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee 2150 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support v2 protocol (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support fragmented high-res reports (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support in-range reporting emulation (Benjamin Tissoires) [1740778]
- [hid] uclogic: Designate current protocol v1 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Re-initialize tablets on resume (Benjamin Tissoires) [1740778]
- [hid] uclogic: Extract tablet parameter discovery into a module (Benjamin Tissoires) [1740778]
- [hid] uclogic: Extract report descriptors to a module (Benjamin Tissoires) [1740778]
- [hid] Clarify vendor ID reuse by Ugee tablets (Benjamin Tissoires) [1740778]
- [hid] viewsonic: Support PD1011 signature pad (Benjamin Tissoires) [1740778]
- [hid] kye: Add support for EasyPen M406XE (Benjamin Tissoires) [1740778]
- [hid] wacom: Add support for Pro Pen slim (Benjamin Tissoires) [1740778]
- [hid] roccat: Mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [hid] wacom: Mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [hid] fix Logitech WingMan Formula GP joined axes (Benjamin Tissoires) [1740778]
- [hid] multitouch: Lenovo X1 Tablet Gen3 trackpoint and buttons (Benjamin Tissoires) [1740778]
- [hid] steam: fix boot loop with bluetooth firmware (Benjamin Tissoires) [1740778]
- [hid] Add ASUS T100CHI keyboard dock battery quirks (Benjamin Tissoires) [1740778]
- [hid] Add support for Toshiba WT10A tablet bluetooth keyboard (Benjamin Tissoires) [1740778]
- [hid] wacom: Move HID fix for AES serial number into wacom_hid_usage_quirk (Benjamin Tissoires) [1740778]
- [hid] elan: Make array buf static, shrinks object size (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Ignore input report if there's no data present on Elan touchpanels (Benjamin Tissoires) [1740778]
- [hid] core: simplify active collection tracking (Benjamin Tissoires) [1740778]
- [hid] Support for Maltron L90 keyboard media keys (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Disable runtime PM on Goodix touchpad (Benjamin Tissoires) [1740778]
- [hid] sony: Fix SHANWAN PS3 GamePad rumble and led settings support (Benjamin Tissoires) [1740778]
- [hid] sony: Transform one-time SHANWAN check into quirk (Benjamin Tissoires) [1740778]
- [hid] core: replace the collection tree pointers with indices (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Add Odys Winbook 13 to descriptor override (Benjamin Tissoires) [1740778]
- [hid] lenovo: Add checks to fix of_led_classdev_register (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: add MSI interrupt support (Benjamin Tissoires) [1740778]
- [hid] debug: Change to use DEFINE_SHOW_ATTRIBUTE macro (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: fixes incorrect error handling (Benjamin Tissoires) [1740778]
- [hid] logitech: Use LDJ_DEVICE macro for existing Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Enable high-resolution scrolling on Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Add function to enable HID++ 1.0 "scrolling acceleration" (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: fix typo, hiddpp to hidpp (Benjamin Tissoires) [1740778]
- [hid] input: use the Resolution Multiplier for high-resolution scrolling (Benjamin Tissoires) [1740778]
- [hid] core: process the Resolution Multiplier (Benjamin Tissoires) [1740778]
- [hid] core: store the collections as a basic tree (Benjamin Tissoires) [1740778]
- [hid] cougar: Add support for Cougar 700K Gaming Keyboard (Benjamin Tissoires) [1740778]
- [hid] hidraw: enforce minors_lock locking via lockdep (Benjamin Tissoires) [1740778]
- [hid] quirks: fix RetroUSB.com devices (Benjamin Tissoires) [1740778]
- [kernel] hid: input: support Microsoft wireless radio control hotkey (Benjamin Tissoires) [1740778]
- [kernel] hid: use macros in IS_INPUT_APPLICATION (Benjamin Tissoires) [1740778]
- [hid] ite: Add USB id match for another ITE based keyboard rfkill key quirk (Benjamin Tissoires) [1740778]
- [hid] revert "hid: input: Create a utility class for counting scroll events" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: Add function to enable HID++ 1.0 "scrolling acceleration"" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: Enable high-resolution scrolling on Logitech mice" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: Use LDJ_DEVICE macro for existing Logitech mice" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: fix a used uninitialized GCC warning" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: input: simplify/fix high-res scroll event handling" (Benjamin Tissoires) [1740778]
- [hid] Add quirk for Primax PIXART OEM mice (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Disable runtime PM for LG touchscreen (Benjamin Tissoires) [1740778]
- [hid] steam: remove input device when a hid client is running (Benjamin Tissoires) [1740778]
- [hid] revert "hid: uhid: use strlcpy() instead of strncpy()" (Benjamin Tissoires) [1740778]
- [hid] uhid: forbid UHID_CREATE under KERNEL_DS or elevated privileges (Benjamin Tissoires) [1740778]
- [hid] iio/hid-sensors: Fix IIO_CHAN_INFO_RAW returning wrong values for signed numbers (Benjamin Tissoires) [1740778]
- [hid] input: Ignore battery reported by Symbol DS4308 (Benjamin Tissoires) [1740778]
- [hid] Add quirk for Microsoft PIXART OEM mouse (Benjamin Tissoires) [1740778]
- [kernel] hid: fix up .raw_event() documentation (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: add Direkt-Tek DTLAPY133-1 to descriptor override (Benjamin Tissoires) [1740778]
- [hid] input: simplify/fix high-res scroll event handling (Benjamin Tissoires) [1740778]
- [hid] we do not randomly make new drivers 'default y' (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: properly terminate i2c_hid_dmi_desc_override_table[] array (Benjamin Tissoires) [1740778]
- [hid] alps: allow incoming reports when only the trackstick is opened (Benjamin Tissoires) [1740778]
- [hid] revert "hid: add NOGET quirk for Eaton Ellipse MAX UPS" (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Add a small delay after sleep command for Raydium touchpanel (Benjamin Tissoires) [1740778]
- [hid] usbhid: Add quirk for Redragon/Dragonrise Seymur 2 (Benjamin Tissoires) [1740778]
- [hid] wacom: Work around HID descriptor bug in DTK-2451 and DTH-2452 (Benjamin Tissoires) [1740778]
- [hid] google: add dependency on Cros EC for Hammer (Benjamin Tissoires) [1740778]
- [hid] elan: fix spelling mistake "registred" -> "registered" (Benjamin Tissoires) [1740778]
- [hid] google: drop superfluous const before SIMPLE_DEV_PM_OPS() (Benjamin Tissoires) [1740778]
- [hid] google: add support tablet mode switch for Whiskers (Benjamin Tissoires) [1740778]
- [hid] magicmouse: add support for Apple Magic Trackpad 2 (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: override HID descriptors for certain devices (Benjamin Tissoires) [1740778]
- [hid] hid-bigbenff: driver for BigBen Interactive PS3OFMINIPAD gamepad (Benjamin Tissoires) [1740778]
- [hid] logitech: fix a used uninitialized GCC warning (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: using list_head for ipc write queue (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: use resource-managed api (Benjamin Tissoires) [1740778]
- [hid] intel_ish-hid: Enhance API to get ring buffer sizes (Benjamin Tissoires) [1740778]
- [hid] input: Set INPUT_PROP_-property for HID_UP_DIGITIZERS (Benjamin Tissoires) [1740778]
- [hid] microsoft: the driver now neeed MEMLESS_FF infrastructure (Benjamin Tissoires) [1740778]
- [hid] cougar: Stop processing vendor events on hid-core (Benjamin Tissoires) [1740778]
- [hid] cougar: Make parameter 'g6_is_space' dinamically settable (Benjamin Tissoires) [1740778]
- [hid] microsoft: Add rumble support for Xbox One S controller (Benjamin Tissoires) [1740778]
- [hid] microsoft: Convert private data to be a proper struct (Benjamin Tissoires) [1740778]
- [hid] logitech: Use LDJ_DEVICE macro for existing Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Enable high-resolution scrolling on Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Add function to enable HID++ 1.0 "scrolling acceleration" (Benjamin Tissoires) [1740778]
- [hid] input: Create a utility class for counting scroll events (Benjamin Tissoires) [1740778]
- [hid] multitouch: simplify the application retrieval (Benjamin Tissoires) [1740778]
- [hid] input: do not append a suffix if the name already has it (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Remove RESEND_REPORT_DESCR quirk and its handling (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: disable runtime PM operations on hantick touchpad (Benjamin Tissoires) [1740778]
- [hid] sensor-hub: Restore fixup for Lenovo ThinkPad Helix 2 sensor hub report (Benjamin Tissoires) [1740778]
- [hid] core: fix NULL pointer dereference (Benjamin Tissoires) [1740778]
- [hid] hid-saitek: Add device ID for RAT 7 Contagion (Benjamin Tissoires) [1740778]
- [hid] core: fix memory leak on probe (Benjamin Tissoires) [1740778]
- [hid] add support for Apple Magic Keyboards (Benjamin Tissoires) [1740778]
- [hid] intel_ish-hid: tx_buf memory leak on probe/remove (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: Prevent loading of driver on Mehlow (Benjamin Tissoires) [1740778]
- [hid] cougar: Add support for the Cougar 500k Gaming Keyboard (Benjamin Tissoires) [1740778]
- [hid] cougar: make compare_device_paths reusable (Benjamin Tissoires) [1740778]
- [hid] multitouch: handle palm for touchscreens (Benjamin Tissoires) [1740778]
- [hid] multitouch: touchscreens also use confidence reports (Benjamin Tissoires) [1740778]
- [hid] multitouch: report MT_TOOL_PALM for non-confident touches (Benjamin Tissoires) [1740778]
- [hid] microsoft: support the Surface Dial (Benjamin Tissoires) [1740778]
- [hid] core: do not upper bound the collection stack (Benjamin Tissoires) [1740778]
- [hid] input: enable Totem on the Dell Canvas 27 (Benjamin Tissoires) [1740778]
- [hid] multitouch: remove one copy of values (Benjamin Tissoires) [1740778]
- [hid] multitouch: ditch mt_report_id (Benjamin Tissoires) [1740778]
- [hid] multitouch: store a per application quirks value (Benjamin Tissoires) [1740778]
- [hid] multitouch: Store per collection multitouch data (Benjamin Tissoires) [1740778]
- [hid] multitouch: make sure the static list of class is not changed (Benjamin Tissoires) [1740778]
- [hid] elan: Add support for touchpad on the Toshiba Click Mini L9W (Benjamin Tissoires) [1740778]
- [hid] elan: Add USB-id for HP x2 10-n000nd touchpad (Benjamin Tissoires) [1740778]
- [hid] elan: Add a flag for selecting if the touchpad has a LED (Benjamin Tissoires) [1740778]
- [hid] elan: Query resolution from the touchpad (Benjamin Tissoires) [1740778]
- [hid] elan: Query device max_x and max_y value from touchpad (Benjamin Tissoires) [1740778]
- [hid] elan: Hardcode finger-count and usb-interface (Benjamin Tissoires) [1740778]
- [hid] elan: Correctly report MT_PRESSURE instead of TOOL_WIDTH (Benjamin Tissoires) [1740778]
- [hid] elan: Stop claiming we have TOUCH_MAJOR and then never reporting it (Benjamin Tissoires) [1740778]
- [hid] elan: Remove unused max_area_x and max_area_y vatiables (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sc->output_report_dmabuf (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_battery_probe() (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_leds_init() (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_register_sensors() (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_register_touchpad() (Benjamin Tissoires) [1740778]
- [hid] wacom: convert Wacom custom usages to standard HID usages (Benjamin Tissoires) [1740778]
- [hid] wacom: Move handling of HID quirks into a dedicated function (Benjamin Tissoires) [1740778]
- [hid] wacom: Replace touch_max fixup code with static touch_max definitions (Benjamin Tissoires) [1740778]
- [hid] wiimote: add support for Guitar-Hero devices (Benjamin Tissoires) [1740778]
- [hid] usbhid: use irqsave() in USB's complete callback (Benjamin Tissoires) [1740778]
- [hid] redragon: fix num lock and caps lock LEDs (Benjamin Tissoires) [1740778]
- [hid] hid-ntrig: add error handling for sysfs_create_group (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Add vddl regulator control (Benjamin Tissoires) [1740778]
- [uapi] input: document meanings of KEY_SCREEN and KEY_ZOOM (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - avoid processing unknown IRQs (Benjamin Tissoires) [1740778]
- [input] revert "input: elantech - enable SMBus on new (2018+) systems" (Benjamin Tissoires) [1740778]
- [input] elantech - annotate fall-through case in elantech_use_host_notify() (Benjamin Tissoires) [1740778]
- [samples] treewide: Add SPDX license identifier - Makefile/Kconfig (Benjamin Tissoires) [1740778]
- [kernel] input: elan_i2c - remove Lenovo Legion Y7000 PnpID (Benjamin Tissoires) [1740778]
- [input] synaptics - enable RMI mode for HP Spectre X360 (Benjamin Tissoires) [1740778]
- [input] elantech - enable SMBus on new (2018+) systems (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 234 (Benjamin Tissoires) [1740778]
- [input] hyperv-keyboard: Use in-place iterator API in the channel callback (Benjamin Tissoires) [1740778]
- [input] usbtouchscreen - initialize PM mutex before using it (Benjamin Tissoires) [1740778]
- [input] alps - fix a mismatch between a condition check and its comment (Benjamin Tissoires) [1740778]
- [input] psmouse - fix build error of multiple definition (Benjamin Tissoires) [1740778]
- [input] alps - don't handle ALPS cs19 trackpoint-only device (Benjamin Tissoires) [1740778]
- [input] hyperv-keyboard - remove dependencies on PAGE_SIZE for ring buffer (Benjamin Tissoires) [1740778]
- [input] synaptics - fix misuse of strlcpy (Benjamin Tissoires) [1740778]
- [input] synaptics - whitelist Lenovo T580 SMBus intertouch (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBUS on T480 thinkpad trackpad (Benjamin Tissoires) [1740778]
- [input] joydev - extend absolute mouse detection (Benjamin Tissoires) [1740778]
- [kernel] input: elan_i2c - export the device id whitelist (Benjamin Tissoires) [1740778]
- [kernel] pm: suspend: Rename pm_suspend_via_s2idle() (Benjamin Tissoires) [1740778]
- [kernel] pm: sleep: Add kerneldoc comments to some functions (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBus on ThinkPad E480 and E580 (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - remove set but not used variable 'sensor_flags' (Benjamin Tissoires) [1740778]
- [input] uinput - add compat ioctl number translation for UI_*_FF_UPLOAD (Benjamin Tissoires) [1740778]
- [input] libps2 - mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - write config register values to the right offset (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - fix enum_fmt (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - fill initial format (Benjamin Tissoires) [1740778]
- [uapi] input: add KEY_KBD_LAYOUT_NEXT (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - fix possible double free (Benjamin Tissoires) [1740778]
- [input] hyperv-keyboard - add module description (Benjamin Tissoires) [1740778]
- [input] i8042 - signal wakeup from atkbd/psmouse (Benjamin Tissoires) [1740778]
- [input] evdev - use struct_size() in kzalloc() and vzalloc() (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add hardware ID for multiple Lenovo laptops (Benjamin Tissoires) [1740778]
- [input] wacom_serial4 - add support for Wacom ArtPad II tablet (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add id for touchpad found in Lenovo s21e-20 (Benjamin Tissoires) [1740778]
- [input] i8042 - rework DT node name comparisons (Benjamin Tissoires) [1740778]
- [input] synaptics_i2c - remove redundant spinlock (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for touchpad in Lenovo V330-15ISK (Benjamin Tissoires) [1740778]
- [input] revert "input: elan_i2c - add ACPI ID for touchpad in ASUS Aspire F5-573G" (Benjamin Tissoires) [1740778]
- [input] elantech - enable 3rd button support on Fujitsu CELSIUS H780 (Benjamin Tissoires) [1740778]
- [uapi] input: input_event - fix the CONFIG_SPARC64 mixup (Benjamin Tissoires) [1740778]
- [input] uinput - fix undefined behavior in uinput_validate_absinfo() (Benjamin Tissoires) [1740778]
- [uapi] input: input_event - provide override for sparc64 (Benjamin Tissoires) [1740778]
- [input] soc_button_array - fix mapping of the 5th GPIO in a PNP0C40 device (Benjamin Tissoires) [1740778]
- [input] soc_button_array - add usage-page 0x01 usage-id 0xca mapping (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for touchpad in ASUS Aspire F5-573G (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBus for HP EliteBook 840 G4 (Benjamin Tissoires) [1740778]
- [input] synaptics - enable RMI on ThinkPad T560 (Benjamin Tissoires) [1740778]
- [documentation] input: add `REL_WHEEL_HI_RES` and `REL_HWHEEL_HI_RES` (Benjamin Tissoires) [1740778]
- [uapi] input: restore EV_ABS ABS_RESERVED (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBus for HP 15-ay000 (Benjamin Tissoires) [1740778]
- [input] synaptics - add PNP ID for ThinkPad P50 to SMBus (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15ARR (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add support for ELAN0621 touchpad (Benjamin Tissoires) [1740778]
- [documentation] revert "input: Add the `REL_WHEEL_HI_RES` event code" (Benjamin Tissoires) [1740778]
- [input] atkbd - clean up indentation issue (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ELAN0620 to the ACPI table (Benjamin Tissoires) [1740778]
- [input] synaptics - avoid using uninitialized variable when probing (Benjamin Tissoires) [1740778]
- [input] xen-kbdfront - mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15IGM (Benjamin Tissoires) [1740778]
- [input] of_touchscreen - add support for touchscreen-min-x|y (Benjamin Tissoires) [1740778]
- [input] elants_i2c - use DMA safe i2c when possible (Benjamin Tissoires) [1740778]
- [input] uinput - add a schedule point in uinput_inject_events() (Benjamin Tissoires) [1740778]
- [input] evdev - add a schedule point in evdev_write() (Benjamin Tissoires) [1740778]
- [input] mousedev - add a schedule point in mousedev_write() (Benjamin Tissoires) [1740778]
- [uapi] input: reserve 2 events code because of HID (Benjamin Tissoires) [1740778]
- [input] i8042 - enable keyboard wakeups by default when s2idle is used (Benjamin Tissoires) [1740778]
- [input] uinput - allow for max == min during input_absinfo validation (Benjamin Tissoires) [1740778]
- [input] atakbd - fix Atari CapsLock behaviour (Benjamin Tissoires) [1740778]
- [input] atakbd - fix Atari keymap (Benjamin Tissoires) [1740778]
- [documentation] input: Add the `REL_WHEEL_HI_RES` event code (Benjamin Tissoires) [1740778]
- [input] mark expected switch fall-throughs (Benjamin Tissoires) [1740778]
- [input] evdev - switch to bitmap API (Benjamin Tissoires) [1740778]
- [input] elan_i2c_smbus - cast sizeof to int for comparison (Benjamin Tissoires) [1740778]
- [uapi] input: stop telling users to snail-mail Vojtech (Benjamin Tissoires) [1740778]
- [documentation] input: add MT_TOOL_DIAL (Benjamin Tissoires) [1740778]
- [input] i8042 - increment wakeup_count for the respective port (Benjamin Tissoires) [1740778]
- [input] xen-kbdfront - allow better run-time configuration (Benjamin Tissoires) [1740778]
- [xen] Sync up with the canonical protocol definitions in Xen (Benjamin Tissoires) [1740778]
- [cpufreq] dev_pm_qos_update_request() can return 1 on success (Al Stone) [1739729 1725581]
- [cpufreq] Make cpufreq_generic_init() return void (Al Stone) [1739729 1725581]
- [cpufreq] Add QoS requests for userspace constraints (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Reuse refresh_frequency_limits() (Al Stone) [1739729 1725581]
- [cpufreq] Register notifiers with the PM QoS framework (Al Stone) [1739729 1725581]
- [base] pm / qos: Add support for MIN/MAX frequency constraints (Al Stone) [1739729 1725581]
- [base] pm / qos: Pass request type to dev_pm_qos_read_value() (Al Stone) [1739729 1725581]
- [base] pm / qos: Rename __dev_pm_qos_read_value() and dev_pm_qos_raw_read_value() (Al Stone) [1739729 1725581]
- [base] pm / qos: Pass request type to dev_pm_qos_{add|remove}_notifier() (Al Stone) [1739729 1725581]
- [cpufreq] Avoid calling cpufreq_verify_current_freq() from handle_update() (Al Stone) [1739729 1725581]
- [cpufreq] Consolidate cpufreq_update_current_freq() and __cpufreq_get() (Al Stone) [1739729 1725581]
- [cpufreq] Don't skip frequency validation for has_target() drivers (Al Stone) [1739729 1725581]
- [cpufreq] Use has_target() instead of !setpolicy (Al Stone) [1739729 1725581]
- [cpufreq] Remove redundant !setpolicy check (Al Stone) [1739729 1725581]
- [kernel] cpufreq: Move the IS_ENABLED(CPU_THERMAL) macro into a stub (Al Stone) [1739729 1725581]
- [opp] Don't use IS_ERR on invalid supplies (Al Stone) [1739729 1725581]
- [kernel] pm: sleep: Update struct wakeup_source documentation (Al Stone) [1739729 1725581]
- [base] base: power: remove wakeup_sources_stats_dentry variable (Al Stone) [1739729 1725581]
- [cpufreq] pcc-cpufreq: Fail initialization if driver cannot be registered (Al Stone) [1739729 1725581]
- [opp] Make dev_pm_opp_set_rate() handle freq = 0 to drop performance votes (Al Stone) [1739729 1725581]
- [opp] Don't overwrite rounded clk rate (Al Stone) [1739729 1725581]
- [base] pm: sleep: Show how long dpm_suspend_start() and dpm_suspend_end() take (Al Stone) [1739729 1725581]
- [base] pm / clk: Remove error message on out-of-memory condition (Al Stone) [1739729 1725581]
- [base] base: power: clock_ops: Use of_clk_get_parent_count() (Al Stone) [1739729 1725581]
- [opp] Allocate genpd_virt_devs from dev_pm_opp_attach_genpd() (Al Stone) [1739729 1725581]
- [opp] Attach genpds to devices from within OPP core (Al Stone) [1739729 1725581]
- [base] pm / domains: Add GENPD_FLAG_RPM_ALWAYS_ON flag (Al Stone) [1739729 1725581]
- [cpufreq] Don't find governor for setpolicy drivers in cpufreq_init_policy() (Al Stone) [1739729 1725581]
- [cpufreq] Explain the kobject_put() in cpufreq_policy_alloc() (Al Stone) [1739729 1725581]
- [x86] cpufreq: Call transition notifier only once for each policy (Al Stone) [1739729 1725581]
- [cpufreq] Fix kobject memleak (Al Stone) [1739729 1725581]
- [cpufreq] centrino: Fix centrino_setpolicy() kerneldoc comment (Al Stone) [1739729 1725581]
- [base] pm / domains: Allow to attach a CPU via genpd_dev_pm_attach_by_id|name() (Al Stone) [1739729 1725581]
- [base] pm / domains: Search for the CPU device outside the genpd lock (Al Stone) [1739729 1725581]
- [base] pm / domains: Drop unused in-parameter to some genpd functions (Al Stone) [1739729 1725581]
- [base] pm / domains: Use the base device for driver_deferred_probe_check_state() (Al Stone) [1739729 1725581]
- [base] pm / domains: Enable genpd_dev_pm_attach_by_id|name() for single PM domain (Al Stone) [1739729 1725581]
- [base] pm / domains: Allow OF lookup for multi PM domain case from ->attach_dev() (Al Stone) [1739729 1725581]
- [base] pm / domains: Don't kfree() the virtual device in the error path (Al Stone) [1739729 1725581]
- [cpufreq] Move ->get callback check outside of __cpufreq_get() (Al Stone) [1739729 1725581]
- [x86] tsc: Rework time_cpufreq_notifier() (Al Stone) [1739729 1725581]
- [x86] tsc: Fix UV TSC initialization (Al Stone) [1739729 1725581]
- [x86] tsc: Prevent result truncation on 32bit (Al Stone) [1739729 1725581]
- [x86] tsc: Consolidate init code (Al Stone) [1739729 1725581]
- [x86] tsc: Make use of tsc_calibrate_cpu_early() (Al Stone) [1739729 1725581]
- [x86] tsc: Split native_calibrate_cpu() into early and late parts (Al Stone) [1739729 1725581]
- [x86] tsc: Use TSC as sched clock early (Al Stone) [1739729 1725581]
- [x86] tsc: Initialize cyc2ns when tsc frequency is determined (Al Stone) [1739729 1725581]
- [x86] tsc: Calibrate tsc only once (Al Stone) [1739729 1725581]
- [x86] tsc: Redefine notsc to behave as tsc=unstable (Al Stone) [1739729 1725581]
- [x86] platform/uv: Provide is_early_uv_system() (Al Stone) [1739729 1725581]
- [base] pm / domains: remove unnecessary unlikely() (Al Stone) [1739729 1725581]
- [cpufreq] Remove needless bios_limit check in show_bios_limit() (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq/acpi-cpufreq.c: This fixes the following checkpatch warning (Al Stone) [1739729 1725581]
- [base] pm / core: Propagate dev->power.wakeup_path when no callbacks (Al Stone) [1739729 1725581]
- [base] pm / domains: Add genpd governor for CPUs (Al Stone) [1739729 1725581]
- [cpuidle] Export the next timer expiration for CPUs (Al Stone) [1739729 1725581]
- [base] pm / core: Introduce dpm_async_fn() helper (Al Stone) [1739729 1725581]
- [cpufreq] boost: Remove CONFIG_CPU_FREQ_BOOST_SW Kconfig option (Al Stone) [1739729 1725581]
- [opp] Introduce dev_pm_opp_find_freq_ceil_by_volt() (Al Stone) [1739729 1725581]
- [base] pm / domains: Add support for CPU devices to genpd (Al Stone) [1739729 1725581]
- [base] pm / domains: Add generic data pointer to struct genpd_power_state (Al Stone) [1739729 1725581]
- [cpufreq] rhel: cpufreq: switch printk users from pf and pF to ps and pS, respectively (Al Stone) [1739729 1725581]
- [base] pm / core: fix kerneldoc comment for device_pm_wait_for_dev() (Al Stone) [1739729 1725581]
- [base] pm / core: fix kerneldoc comment for dpm_watchdog_handler() (Al Stone) [1739729 1725581]
- [cpufreq] stats: Use lock by stat to replace global spin lock (Al Stone) [1739729 1725581]
- [cpufreq] Remove cpufreq_driver check in cpufreq_boost_supported() (Al Stone) [1739729 1725581]
- [cpufreq] ppc_cbe: fix possible object reference leak (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq: Convert some slow-path static_cpu_has() callers to boot_cpu_has() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Update max frequency on global turbo changes (Al Stone) [1739729 1725581]
- [base] pm / wakeup: Use pm_pr_dbg() instead of pr_debug() (Al Stone) [1739729 1725581]
- [cpufreq] Add cpufreq_cpu_acquire() and cpufreq_cpu_release() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Driver-specific handling of _PPC updates (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Load only on Intel hardware (Al Stone) [1739729 1725581]
- [cpufreq] scpi: Fix use after free (Al Stone) [1739729 1725581]
- [base] pm / domains: Avoid a potential deadlock (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Fix up iowait_boost computation (Al Stone) [1739729 1725581]
- [opp] pm / opp: Update performance state when freq == old_freq (Al Stone) [1739729 1725581]
- [base] pm / wakeup: Drop wakeup_source_drop() (Al Stone) [1739729 1725581]
- [base] pm / wakeup: Rework wakeup source timer cancellation (Al Stone) [1739729 1725581]
- [base] pm / domains: Remove one unnecessary blank line (Al Stone) [1739729 1725581]
- [base] pm / domains: Return early for all errors in _genpd_power_off() (Al Stone) [1739729 1725581]
- [base] pm / domains: Improve warn for multiple states but no governor (Al Stone) [1739729 1725581]
- [opp] Fix handling of multiple power domains (Al Stone) [1739729 1725581]
- [base] pm / qos: Fix typo in file description (Al Stone) [1739729 1725581]
- [base] pm-runtime: Call pm_runtime_active|suspended_time() from sysfs (Al Stone) [1739729 1725581]
- [base] pm-runtime: Consolidate code to get active/suspended time (Al Stone) [1739729 1725581]
- [base] pm: Add and use pr_fmt() (Al Stone) [1739729 1725581]
- [cpufreq] Improve kerneldoc comments for cpufreq_cpu_get/put() (Al Stone) [1739729 1725581]
- [cpufreq] acpi-cpufreq: Report if CPU doesn't support boost technologies (Al Stone) [1739729 1725581]
- [base] driver core: Fix PM-runtime for links added during consumer probe (Al Stone) [1739729 1725581]
- [cpufreq] Pass updated policy to driver ->setpolicy() callback (Al Stone) [1739729 1725581]
- [cpufreq] Fix two debug messages in cpufreq_set_policy() (Al Stone) [1739729 1725581]
- [cpufreq] Reorder and simplify cpufreq_update_policy() (Al Stone) [1739729 1725581]
- [cpufreq] Add kerneldoc comments for two core functions (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Fix use-after-free in scmi_cpufreq_exit() (Al Stone) [1739729 1725581]
- [kernel] pm / core: Add support to skip power management in device/driver model (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Rework iowait boosting to be less aggressive (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Eliminate intel_pstate_get_base_pstate() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Avoid redundant initialization of local vars (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq / cppc: Work around for Hisilicon CPPC cpufreq (Al Stone) [1739729 1725581]
- [cpufreq] speedstep: convert BUG() to BUG_ON() (Al Stone) [1739729 1725581]
- [cpufreq] powernv: fix missing check of return value in init_powernv_pstates() (Al Stone) [1739729 1725581]
- [cpufreq] pcc-cpufreq: remove unneeded semicolon (Al Stone) [1739729 1725581]
- [kernel] pm / domains: Mark "name" const in dev_pm_domain_attach_by_name() (Al Stone) [1739729 1725581]
- [kernel] pm / domains: Mark "name" const in genpd_dev_pm_attach_by_name() (Al Stone) [1739729 1725581]
- [cpufreq] Replace double NOT (!!) with single NOT (!) (Al Stone) [1739729 1725581]
- [base] pm / suspend: Print debug messages for device using direct-complete (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Add reasons for failure and debug messages (Al Stone) [1739729 1725581]
- [base] driver core: Fix possible supplier PM-usage counter imbalance (Al Stone) [1739729 1725581]
- [base] pm-runtime: Fix __pm_runtime_set_status() race with runtime resume (Al Stone) [1739729 1725581]
- [cpufreq] dt: Implement online/offline() callbacks (Al Stone) [1739729 1725581]
- [cpufreq] Allow light-weight tear down and bring up of CPUs (Al Stone) [1739729 1725581]
- [base] pm-runtime: Take suppliers into account in __pm_runtime_set_status() (Al Stone) [1739729 1725581]
- [opp] no need to check return value of debugfs_create functions (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Register an Energy Model (Al Stone) [1739729 1725581]
- [opp] pm / opp: Introduce a power estimation helper (Al Stone) [1739729 1725581]
- [opp] pm / opp: Remove unused parameter of _generic_set_opp_clk_only() (Al Stone) [1739729 1725581]
- [cpufreq] scpi: Register an Energy Model (Al Stone) [1739729 1725581]
- [cpufreq] dt: Register an Energy Model (Al Stone) [1739729 1725581]
- [cpufreq] stats: Fix concurrency issues while resetting stats (Al Stone) [1739729 1725581]
- [cpufreq] stats: Declare freq-attr right after their callbacks (Al Stone) [1739729 1725581]
- [base] driver core: Do not call rpm_put_suppliers() in pm_runtime_drop_link() (Al Stone) [1739729 1725581]
- [base] driver core: Fix handling of runtime PM flags in device_link_add() (Al Stone) [1739729 1725581]
- [base] driver core: Do not resume suppliers under device_links_write_lock() (Al Stone) [1739729 1725581]
- [base] driver core: Avoid careless re-use of existing device links (Al Stone) [1739729 1725581]
- [base] driver core: Fix DL_FLAG_AUTOREMOVE_SUPPLIER device link flag handling (Al Stone) [1739729 1725581]
- [base] driver core: Add flag to autoremove device link on supplier unbind (Al Stone) [1739729 1725581]
- [base] driver core: Rename flag AUTOREMOVE to AUTOREMOVE_CONSUMER (Al Stone) [1739729 1725581]
- [base] pm-runtime: update accounting_timestamp on enable (Al Stone) [1739729 1725581]
- [cpufreq] scpi: Use auto-registration of thermal cooling device (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Use auto-registration of thermal cooling device (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq-dt: Use auto-registration of thermal cooling device (Al Stone) [1739729 1725581]
- [cpufreq] Auto-register the driver as a thermal cooling device if asked (Al Stone) [1739729 1725581]
- [cpufreq] thermal: cpu_cooling: Require thermal core to be compiled in (Al Stone) [1739729 1725581]
- [cpufreq] Use struct kobj_attribute instead of struct global_attr (Al Stone) [1739729 1725581]
- [base] pm / wakeup: fix kerneldoc comment for pm_wakeup_dev_event() (Al Stone) [1739729 1725581]
- [base] pm: domains: no need to check return value of debugfs_create functions (Al Stone) [1739729 1725581]
- [opp] Add support for parsing the 'opp-level' property (Al Stone) [1739729 1725581]
- [kernel] cpufreq: Replace open-coded << with BIT() (Al Stone) [1739729 1725581]
- [base] pm: clock_ops: fix missing clk_prepare() return value check (Al Stone) [1739729 1725581]
- [cpufreq] e_powersaver: Use struct_size() in kzalloc() (Al Stone) [1739729 1725581]
- [cpufreq] Don't update new_policy on failures (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Fix frequency invariance in slow path (Al Stone) [1739729 1725581]
- [cpufreq] check if policy is inactive early in __cpufreq_get() (Al Stone) [1739729 1725581]
- [opp] cpufreq: scpi/scmi: Fix freeing of dynamic OPPs (Al Stone) [1739729 1725581]
- [base] pm: sleep: call devfreq suspend/resume (Al Stone) [1739729 1725581]
- [devfreq] pm / devfreq: add devfreq_suspend/resume() functions (Al Stone) [1739729 1725581]
- [base] pm / domains: remove define_genpd_open_function() and define_genpd_debugfs_fops() (Al Stone) [1739729 1725581]
- [base] pm / domains: Propagate performance state updates (Al Stone) [1739729 1725581]
- [base] pm / domains: Factorize dev_pm_genpd_set_performance_state() (Al Stone) [1739729 1725581]
- [base] pm / domains: Save OPP table pointer in genpd (Al Stone) [1739729 1725581]
- [opp] Don't return 0 on error from of_get_required_opp_performance_state() (Al Stone) [1739729 1725581]
- [opp] Add dev_pm_opp_xlate_performance_state() helper (Al Stone) [1739729 1725581]
- [opp] Improve _find_table_of_opp_np() (Al Stone) [1739729 1725581]
- [base] pm / domains: Make genpd performance states orthogonal to the idlestates (Al Stone) [1739729 1725581]
- [opp] Fix missing debugfs supply directory for OPPs (Al Stone) [1739729 1725581]
- [opp] Use opp_table->regulators to verify no regulator case (Al Stone) [1739729 1725581]
- [base] pm: Switch to use ptR (Al Stone) [1739729 1725581]
- [cpufreq] powernv: add of_node_put() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Force HWP min perf before offline (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq: change CONFIG_6xx to CONFIG_PPC_BOOK3S_32 (Al Stone) [1739729 1725581]
- [opp] Fix parsing of multiple phandles in "operating-points-v2" property (Al Stone) [1739729 1725581]
- [opp] Remove of_dev_pm_opp_find_required_opp() (Al Stone) [1739729 1725581]
- [base] opp: Rename and relocate of_genpd_opp_to_performance_state() (Al Stone) [1739729 1725581]
- [opp] Configure all required OPPs (Al Stone) [1739729 1725581]
- [opp] Add dev_pm_opp_{set|put}_genpd_virt_dev() helper (Al Stone) [1739729 1725581]
- [base] pm / domains: Add genpd_opp_to_performance_state() (Al Stone) [1739729 1725581]
- [opp] Populate OPPs from "required-opps" property (Al Stone) [1739729 1725581]
- [opp] Populate required opp tables from "required-opps" property (Al Stone) [1739729 1725581]
- [opp] Separate out custom OPP handler specific code (Al Stone) [1739729 1725581]
- [opp] Identify and mark genpd OPP tables (Al Stone) [1739729 1725581]
- [base] pm / domains: Rename genpd virtual devices as virt_dev (Al Stone) [1739729 1725581]
- [cpufreq] remove unused arm_big_little_dt driver (Al Stone) [1739729 1725581]
- [cpufreq] drop ARM_BIG_LITTLE_CPUFREQ support for ARM64 (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Fix compilation for !CONFIG_ACPI (Al Stone) [1739729 1725581]
- [base] pm / domains: Deal with multiple states but no governor in genpd (Al Stone) [1739729 1725581]
- [base] pm / domains: Don't treat zero found compatible idle states as an error (Al Stone) [1739729 1725581]
- [cpufreq] conservative: Take limits changes into account properly (Al Stone) [1739729 1725581]
- [opp] pm / opp: _of_add_opp_table_v2(): increment count only if OPP is added (Al Stone) [1739729 1725581]
- [cpufreq] dt: Try freeing static OPPs only if we have added them (Al Stone) [1739729 1725581]
- [opp] Return error on error from dev_pm_opp_get_opp_count() (Al Stone) [1739729 1725581]
- [opp] Improve error handling in dev_pm_opp_of_cpumask_add_table() (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq / cppc: Mark acpi_ids as used (Al Stone) [1739729 1725581]
- [opp] Pass OPP table to _of_add_opp_table_v{1|2}() (Al Stone) [1739729 1725581]
- [opp] Prevent creating multiple OPP tables for devices sharing OPP nodes (Al Stone) [1739729 1725581]
- [opp] Use a single mechanism to free the OPP table (Al Stone) [1739729 1725581]
- [opp] Don't remove dynamic OPPs from _dev_pm_opp_remove_table() (Al Stone) [1739729 1725581]
- [opp] Create separate kref for static OPPs list (Al Stone) [1739729 1725581]
- [opp] Don't take OPP table's kref for static OPPs (Al Stone) [1739729 1725581]
- [opp] Parse OPP table's DT properties from _of_init_opp_table() (Al Stone) [1739729 1725581]
- [opp] Pass index to _of_init_opp_table() (Al Stone) [1739729 1725581]
- [opp] Protect dev_list with opp_table lock (Al Stone) [1739729 1725581]
- [opp] Don't try to remove all OPP tables on failure (Al Stone) [1739729 1725581]
- [opp] Free OPP table properly on performance state irregularities (Al Stone) [1739729 1725581]
- [cpufreq] Convert to using pOFn instead of device_node.name (Al Stone) [1739729 1725581]
- [cpufreq] remove unnecessary unlikely() (Al Stone) [1739729 1725581]
- [base] pm / clk: signedness bug in of_pm_clk_add_clks() (Al Stone) [1739729 1725581]
- [trace] cpufreq: trace frequency limits change (Al Stone) [1739729 1725581]
- [cpufreq] pcc-cpufreq: Disable dynamic scaling on many-CPU systems (Al Stone) [1739729 1725581]
- [base] pm / domains: Stop deferring probe at the end of initcall (Al Stone) [1739729 1725581]
- [base] driver: core: Allow subsystems to continue deferring probe (Al Stone) [1739729 1725581]
- [base] driver core: allow stopping deferred probe after init (Al Stone) [1739729 1725581]
- [base] driver core: add a debugfs entry to show deferred devices (Al Stone) [1739729 1725581]
- [base] pm / domains: Introduce dev_pm_domain_attach_by_name() (Al Stone) [1739729 1725581]
- [base] pm / domains: Introduce option to attach a device by name to genpd (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: use match_string() helper (Al Stone) [1739729 1725581]
- [fs] ceph: use ceph_evict_inode to cleanup inode's resource (Jeff Layton) [1767959]
- [fs] ceph: return -EINVAL if given fsc mount option on kernel w/o support (Jeff Layton) [1767959]
- [fs] ceph: don't try to handle hashed dentries in non-O_CREAT atomic_open (Jeff Layton) [1767959]
- [fs] ceph: add missing check in d_revalidate snapdir handling (Jeff Layton) [1767959]
- [fs] ceph: fix RCU case handling in ceph_d_revalidate() (Jeff Layton) [1767959]
- [fs] ceph: fix use-after-free in __ceph_remove_cap() (Jeff Layton) [1767959]
- [block] rbd: cancel lock_dwork if the wait is interrupted (Jeff Layton) [1767959]
- [fs] ceph: just skip unrecognized info in ceph_reply_info_extra (Jeff Layton) [1767959]
- [fs] ceph: call ceph_mdsc_destroy from destroy_fs_client (Jeff Layton) [1767959]
- [net] libceph: use ceph_kvmalloc() for osdmap arrays (Jeff Layton) [1767959]
- [net] libceph: avoid a __vmalloc() deadlock in ceph_kvmalloc() (Jeff Layton) [1767959]
- [fs] ceph: include ceph_debug.h in cache.c (Jeff Layton) [1767959]
- [fs] ceph: move static keyword to the front of declarations (Jeff Layton) [1767959]
- [block] rbd: pull rbd_img_request_create() dout out into the callers (Jeff Layton) [1767959]
- [fs] ceph: reconnect connection if session hang in opening state (Jeff Layton) [1767959]
- [net] libceph: drop unused con parameter of calc_target() (Jeff Layton) [1767959]
- [fs] ceph: use release_pages() directly (Jeff Layton) [1767959]
- [block] rbd: fix response length parameter for encoded strings (Jeff Layton) [1767959]
- [fs] ceph: allow arbitrary security.* xattrs (Jeff Layton) [1767959]
- [fs] ceph: only set CEPH_I_SEC_INITED if we got a MAC label (Jeff Layton) [1767959]
- [fs] ceph: turn ceph_security_invalidate_secctx into static inline (Jeff Layton) [1767959]
- [fs] ceph: add buffered/direct exclusionary locking for reads and writes (Jeff Layton) [1767959]
- [net] libceph: handle OSD op ceph_pagelist_append() errors (Jeff Layton) [1767959]
- [fs] ceph: don't return a value from void function (Jeff Layton) [1767959]
- [fs] ceph: don't freeze during write page faults (Jeff Layton) [1767959]
- [fs] ceph: update the mtime when truncating up (Jeff Layton) [1767959]
- [fs] ceph: fix indentation in __get_snap_name() (Jeff Layton) [1767959]
- [fs] ceph: remove incorrect comment above __send_cap (Jeff Layton) [1767959]
- [fs] ceph: remove CEPH_I_NOFLUSH (Jeff Layton) [1767959]
- [fs] ceph: remove unneeded test in try_flush_caps (Jeff Layton) [1767959]
- [fs] ceph: have __mark_caps_flushing return flush_tid (Jeff Layton) [1767959]
- [fs] ceph: fix comments over ceph_add_cap (Jeff Layton) [1767959]
- [fs] ceph: eliminate session->s_trim_caps (Jeff Layton) [1767959]
- [fs] ceph: fetch cap_gen under spinlock in ceph_add_cap (Jeff Layton) [1767959]
- [fs] ceph: remove ceph_get_cap_mds and __ceph_get_cap_mds (Jeff Layton) [1767959]
- [fs] ceph: don't SetPageError on writepage errors (Jeff Layton) [1767959]
- [fs] ceph: auto reconnect after blacklisted (Jeff Layton) [1767959]
- [fs] ceph: invalidate all write mode filp after reconnect (Jeff Layton) [1767959]
- [fs] ceph: return -EIO if read/write against filp that lost file locks (Jeff Layton) [1767959]
- [fs] ceph: add helper function that forcibly reconnects to ceph cluster (Jeff Layton) [1767959]
- [fs] ceph: pass filp to ceph_get_caps() (Jeff Layton) [1767959]
- [fs] ceph: track and report error of async metadata operation (Jeff Layton) [1767959]
- [fs] ceph: allow closing session in restarting/reconnect state (Jeff Layton) [1767959]
- [net] libceph: add function that clears osd client's abort_err (Jeff Layton) [1767959]
- [net] libceph: add function that reset client's entity addr (Jeff Layton) [1767959]
- [fs] ceph: don't list vxattrs in listxattr() (Jeff Layton) [1767959]
- [fs] ceph: fix directories inode i_blkbits initialization (Jeff Layton) [1767959]
- [block] rbd: restore zeroing past the overlap when reading from parent (Jeff Layton) [1767959]
- [net] libceph: don't call crypto_free_sync_skcipher() on a NULL tfm (Jeff Layton) [1767959]
- [net] libceph: fix PG split vs OSD (re)connect race (Jeff Layton) [1767959]
- [fs] ceph: don't try fill file_lock on unsuccessful GETFILELOCK reply (Jeff Layton) [1767959]
- [fs] ceph: clear page dirty before invalidate page (Jeff Layton) [1767959]
- [fs] ceph: fix buffer free while holding i_ceph_lock in fill_inode() (Jeff Layton) [1767959]
- [fs] ceph: fix buffer free while holding i_ceph_lock in __ceph_build_xattrs_blob() (Jeff Layton) [1767959]
- [fs] ceph: fix buffer free while holding i_ceph_lock in __ceph_setxattr() (Jeff Layton) [1767959]
- [kernel] libceph: allow ceph_buffer_put() to receive a NULL ceph_buffer (Jeff Layton) [1767959]
- [fs] ceph: fix end offset in truncate_inode_pages_range call (Jeff Layton) [1767959]
- [fs] ceph: initialize superblock s_time_gran to 1 (Jeff Layton) [1767959]
- [block] rbd: setallochint only if object doesn't exist (Jeff Layton) [1767959]
- [block] rbd: support for object-map and fast-diff (Jeff Layton) [1767959]
- [block] rbd: call rbd_dev_mapping_set() from rbd_dev_image_probe() (Jeff Layton) [1767959]
- [net] libceph: export osd_req_op_data() macro (Jeff Layton) [1767959]
- [net] libceph: change ceph_osdc_call() to take page vector for response (Jeff Layton) [1767959]
- [kernel] libceph: bump CEPH_MSG_MAX_DATA_LEN (again) (Jeff Layton) [1767959]
- [block] rbd: new exclusive lock wait/wake code (Jeff Layton) [1767959]
- [block] rbd: quiescing lock should wait for image requests (Jeff Layton) [1767959]
- [block] rbd: lock should be quiesced on reacquire (Jeff Layton) [1767959]
- [block] rbd: introduce copyup state machine (Jeff Layton) [1767959]
- [block] rbd: rename rbd_obj_setup_*() to rbd_obj_init_*() (Jeff Layton) [1767959]
- [block] rbd: move OSD request allocation into object request state machines (Jeff Layton) [1767959]
- [block] rbd: factor out __rbd_osd_setup_discard_ops() (Jeff Layton) [1767959]
- [block] rbd: factor out rbd_osd_setup_copyup() (Jeff Layton) [1767959]
- [block] rbd: introduce obj_req->osd_reqs list (Jeff Layton) [1767959]
- [fs] libceph: rename r_unsafe_item to r_private_item (Jeff Layton) [1767959]
- [block] rbd: introduce image request state machine (Jeff Layton) [1767959]
- [block] rbd: move OSD request submission into object request state machines (Jeff Layton) [1767959]
- [block] rbd: get rid of RBD_OBJ_WRITE_{FLAT, GUARD} (Jeff Layton) [1767959]
- [block] rbd: replace obj_req->tried_parent with obj_req->read_state (Jeff Layton) [1767959]
- [block] rbd: get rid of obj_req->xferred, obj_req->result and img_req->xferred (Jeff Layton) [1767959]
- [fs] ceph: don't NULL terminate virtual xattrs (Jeff Layton) [1767959]
- [fs] ceph: return -ERANGE if virtual xattr value didn't fit in buffer (Jeff Layton) [1767959]
- [fs] ceph: make getxattr_cb return ssize_t (Jeff Layton) [1767959]
- [fs] ceph: more precise CEPH_CLIENT_CAPS_PENDING_CAPSNAP (Jeff Layton) [1767959]
- [fs] ceph: kick flushing and flush snaps before sending normal cap message (Jeff Layton) [1767959]
- [fs] ceph: clear CEPH_I_KICK_FLUSH flag inside __kick_flushing_caps() (Jeff Layton) [1767959]
- [fs] ceph: increment change_attribute on local changes (Jeff Layton) [1767959]
- [fs] ceph: handle change_attr in cap messages (Jeff Layton) [1767959]
- [fs] ceph: add change_attr field to ceph_inode_info (Jeff Layton) [1767959]
- [kernel] iversion: add a routine to update a raw value with a larger one (Jeff Layton) [1767959]
- [fs] ceph: allow querying of STATX_BTIME in ceph_getattr (Jeff Layton) [1767959]
- [kernel] libceph: turn on CEPH_FEATURE_MSG_ADDR2 (Jeff Layton) [1767959]
- [fs] ceph: handle btime in cap messages (Jeff Layton) [1767959]
- [fs] ceph: add btime field to ceph_inode_info (Jeff Layton) [1767959]
- [net] libceph: rename ceph_encode_addr to ceph_encode_banner_addr (Jeff Layton) [1767959]
- [net] libceph: use TYPE_LEGACY for entity addrs instead of TYPE_NONE (Jeff Layton) [1767959]
- [net] ceph: fix decode_locker to use ceph_decode_entity_addr (Jeff Layton) [1767959]
- [fs] ceph: have MDS map decoding use entity_addr_t decoder (Jeff Layton) [1767959]
- [net] libceph: correctly decode ADDR2 addresses in incremental OSD maps (Jeff Layton) [1767959]
- [net] libceph: fix watch_item_t decoding to use ceph_decode_entity_addr (Jeff Layton) [1767959]
- [net] libceph: switch osdmap decoding to use ceph_decode_entity_addr (Jeff Layton) [1767959]
- [net] libceph: ADDR2 support for monmap (Jeff Layton) [1767959]
- [net] libceph: add ceph_decode_entity_addr (Jeff Layton) [1767959]
- [net] libceph: fix sa_family just after reading address (Jeff Layton) [1767959]
- [fs] ceph: remove request from waiting list before unregister (Jeff Layton) [1767959]
- [fs] ceph: don't blindly unregister session that is in opening state (Jeff Layton) [1767959]
- [fs] ceph: fix infinite loop in get_quota_realm() (Jeff Layton) [1767959]
- [fs] ceph: add selinux support (Jeff Layton) [1767959]
- [fs] ceph: rename struct ceph_acls_info to ceph_acl_sec_ctx (Jeff Layton) [1767959]
- [fs] ceph: fix debug print format in __set_xattr() (Jeff Layton) [1767959]
- [fs] ceph: fix warning PTR_ERR_OR_ZERO can be used (Jeff Layton) [1767959]
- [fs] ceph: hold i_ceph_lock when removing caps for freeing inode (Jeff Layton) [1767959]
- [fs] ceph: ensure d_name/d_parent stability in ceph_mdsc_lease_send_msg() (Jeff Layton) [1767959]
- [fs] ceph: use READ_ONCE to access d_parent in RCU critical section (Jeff Layton) [1767959]
- [fs] ceph: fix dir_lease_is_valid() (Jeff Layton) [1767959]
- [fs] ceph: close race between d_name_cmp() and update_dentry_lease() (Jeff Layton) [1767959]
- [fs] ceph: fix improper use of smp_mb__before_atomic() (Jeff Layton) [1767959]
- [fs] ceph: fix "ceph.dir.rctime" vxattr value (Jeff Layton) [1767959]
- [fs] ceph: remove unused vxattr length helpers (Jeff Layton) [1767959]
- [fs] ceph: fix listxattr vxattr buffer length calculation (Jeff Layton) [1767959]
- [fs] ceph: add ceph.snap.btime vxattr (Jeff Layton) [1767959]
- [fs] ceph: carry snapshot creation time with inodes (Jeff Layton) [1767959]
- [fs] ceph: clean up ceph.dir.pin vxattr name sizeof() (Jeff Layton) [1767959]
- [fs] ceph: silence a checker warning in mdsc_show() (Jeff Layton) [1767959]
- [net] libceph: remove ceph_get_direct_page_vector() (Jeff Layton) [1767959]
- [fs] ceph: don't open-code the check for dead lockref (Jeff Layton) [1767959]
- [net] ceph: no need to check return value of debugfs_create functions (Jeff Layton) [1767959]
- [fs] ceph: fix ceph_mdsc_build_path to not stop on first component (Jeff Layton) [1767959]
- [fs] ceph: fix error handling in ceph_get_caps() (Jeff Layton) [1767959]
- [fs] ceph: avoid iput_final() while holding mutex or in dispatch thread (Jeff Layton) [1767959]
- [fs] ceph: single workqueue for inode related works (Jeff Layton) [1767959]
- [fs] ceph: flush dirty inodes before proceeding with remount (Jeff Layton) [1767959]
- [fs] ceph: fix unaligned access in ceph_send_cap_releases (Jeff Layton) [1767959]
- [net] libceph: make ceph_pr_addr take an struct ceph_entity_addr pointer (Jeff Layton) [1767959]
- [net] libceph: fix unaligned accesses in ceph_entity_addr handling (Jeff Layton) [1767959]
- [block] rbd: don't assert on writes to snapshots (Jeff Layton) [1767959]
- [block] rbd: client_mutex is never nested (Jeff Layton) [1767959]
- [fs] ceph: print inode number in __caps_issued_mask debugging messages (Jeff Layton) [1767959]
- [fs] ceph: just call get_session in __ceph_lookup_mds_session (Jeff Layton) [1767959]
- [fs] ceph: simplify arguments and return semantics of try_get_cap_refs (Jeff Layton) [1767959]
- [fs] ceph: fix comment over ceph_drop_caps_for_unlink (Jeff Layton) [1767959]
- [fs] ceph: move wait for mds request into helper function (Jeff Layton) [1767959]
- [fs] ceph: have ceph_mdsc_do_request call ceph_mdsc_submit_request (Jeff Layton) [1767959]
- [fs] ceph: after an MDS request, do callback and completions (Jeff Layton) [1767959]
- [fs] ceph: use pathlen values returned by set_request_path_attr (Jeff Layton) [1767959]
- [fs] ceph: use __getname/__putname in ceph_mdsc_build_path (Jeff Layton) [1767959]
- [fs] ceph: use ceph_mdsc_build_path instead of clone_dentry_name (Jeff Layton) [1767959]
- [fs] ceph: fix potential use-after-free in ceph_mdsc_build_path (Jeff Layton) [1767959]
- [fs] ceph: dump granular cap info in "caps" debugfs file (Jeff Layton) [1767959]
- [fs] ceph: make iterate_session_caps a public symbol (Jeff Layton) [1767959]
- [fs] ceph: fix NULL pointer deref when debugging is enabled (Jeff Layton) [1767959]
- [fs] ceph: properly handle granular statx requests (Jeff Layton) [1767959]
- [fs] ceph: remove superfluous inode_lock in ceph_fsync (Jeff Layton) [1767959]
- [kernel] libceph: fix clang warning for CEPH_DEFINE_OID_ONSTACK (Jeff Layton) [1767959]
- [block] rbd: convert all rbd_assert(0) to BUG() (Jeff Layton) [1767959]
- [block] rbd: avoid clang -Wuninitialized warning (Jeff Layton) [1767959]
- [fs] ceph: snapshot nfs re-export (Jeff Layton) [1767959]
- [fs] ceph: quota: fix quota subdir mounts (Jeff Layton) [1767959]
- [fs] ceph: factor out ceph_lookup_inode() (Jeff Layton) [1767959]
- [fs] ceph: remove duplicated filelock ref increase (Jeff Layton) [1767959]
- [fs] ceph: fix ci->i_head_snapc leak (Jeff Layton) [1767959]
- [fs] ceph: handle the case where a dentry has been renamed on outstanding req (Jeff Layton) [1767959]
- [fs] ceph: ensure d_name stability in ceph_dentry_hash() (Jeff Layton) [1767959]
- [fs] ceph: only use d_name directly when parent is locked (Jeff Layton) [1767959]
- [fs] mark expected switch fall-throughs (Jeff Layton) [1767959]
- [fs] ceph: fix use-after-free on symlink traversal (Jeff Layton) [1767959]
- [net] libceph: fix breakage caused by multipage bvecs (Jeff Layton) [1767959]
- [block] rbd: drop wait_for_latest_osdmap() (Jeff Layton) [1767959]
- [net] libceph: wait for latest osdmap in ceph_monc_blacklist_add() (Jeff Layton) [1767959]
- [block] rbd: set io_min, io_opt and discard_granularity to alloc_size (Jeff Layton) [1767959]
- [block] rbd: advertise support for RBD_FEATURE_DEEP_FLATTEN (Jeff Layton) [1767959]
- [block] rbd: whole-object write and zeroout should copyup when snapshots exist (Jeff Layton) [1767959]
- [block] rbd: copyup with an empty snapshot context (aka deep-copyup) (Jeff Layton) [1767959]
- [block] rbd: introduce rbd_obj_issue_copyup_ops() (Jeff Layton) [1767959]
- [block] rbd: stop copying num_osd_ops in rbd_obj_issue_copyup() (Jeff Layton) [1767959]
- [block] rbd: factor out __rbd_osd_req_create() (Jeff Layton) [1767959]
- [block] rbd: clear ->xferred on error from rbd_obj_issue_copyup() (Jeff Layton) [1767959]
- [block] rbd: remove experimental designation from kernel layering (Jeff Layton) [1767959]
- [fs] ceph: add mount option to limit caps count (Jeff Layton) [1767959]
- [fs] ceph: periodically trim stale dentries (Jeff Layton) [1767959]
- [fs] ceph: delete stale dentry when last reference is dropped (Jeff Layton) [1767959]
- [fs] ceph: remove dentry_lru file from debugfs (Jeff Layton) [1767959]
- [fs] ceph: touch existing cap when handling reply (Jeff Layton) [1767959]
- [fs] ceph: pass inclusive lend parameter to filemap_write_and_wait_range() (Jeff Layton) [1767959]
- [block] rbd: round off and ignore discards that are too small (Jeff Layton) [1767959]
- [block] rbd: handle DISCARD and WRITE_ZEROES separately (Jeff Layton) [1767959]
- [block] rbd: get rid of obj_req->obj_request_count (Jeff Layton) [1767959]
- [net] libceph: use struct_size() for kmalloc() in crush_decode() (Jeff Layton) [1767959]
- [fs] ceph: send cap releases more aggressively (Jeff Layton) [1767959]
- [fs] ceph: support getting ceph.dir.pin vxattr (Jeff Layton) [1767959]
- [fs] ceph: support versioned reply (Jeff Layton) [1767959]
- [fs] ceph: map snapid to anonymous bdev ID (Jeff Layton) [1767959]
- [fs] ceph: split large reconnect into multiple messages (Jeff Layton) [1767959]
- [fs] ceph: decode feature bits in session message (Jeff Layton) [1767959]
- [fs] ceph: set special inode's blocksize to page size (Jeff Layton) [1767959]
- [fs] ceph: avoid repeatedly adding inode to mdsc->snap_flush_list (Jeff Layton) [1767959]
- [fs] ceph: quota: cleanup license mess (Jeff Layton) [1767959]
- [net] libceph: avoid KEEPALIVE_PENDING races in ceph_con_keepalive() (Jeff Layton) [1767959]
- [fs] ceph: clear inode pointer when snap realm gets dropped by its inode (Jeff Layton) [1767959]
- [block] rbd: don't return 0 on unmap if RBD_DEV_FLAG_REMOVING is set (Jeff Layton) [1767959]
- [fs] ceph: use vmf_error() in ceph_filemap_fault() (Jeff Layton) [1767959]
- [net] libceph: allow setting abort_on_full for rbd (Jeff Layton) [1767959]
- [fs] ceph: don't encode inode pathes into reconnect message (Jeff Layton) [1767959]
- [fs] ceph: update wanted caps after resuming stale session (Jeff Layton) [1767959]
- [fs] ceph: skip updating 'wanted' caps if caps are already issued (Jeff Layton) [1767959]
- [fs] ceph: don't request excl caps when mount is readonly (Jeff Layton) [1767959]
- [fs] ceph: don't update importing cap's mseq when handing cap export (Jeff Layton) [1767959]
- [net] libceph: switch more to bool in ceph_tcp_sendmsg() (Jeff Layton) [1767959]
- [net] libceph: use MSG_SENDPAGE_NOTLAST with ceph_tcp_sendpage() (Jeff Layton) [1767959]
- [net] libceph: use sock_no_sendpage() as a fallback in ceph_tcp_sendpage() (Jeff Layton) [1767959]
- [net] libceph: drop last_piece logic from write_partial_message_data() (Jeff Layton) [1767959]
- [fs] ceph: remove redundant assignment (Jeff Layton) [1767959]
- [fs] ceph: cleanup splice_dentry() (Jeff Layton) [1767959]
- [fs] libceph: assume argonaut on the server side (Jeff Layton) [1767959]
- [fs] ceph: quota: fix null pointer dereference in quota check (Jeff Layton) [1767959]
- [fs] ceph: add non-blocking parameter to ceph_try_get_caps() (Jeff Layton) [1767959]
- [net] libceph: check reply num_data_items in setup_request_data() (Jeff Layton) [1767959]
- [net] libceph: preallocate message data items (Jeff Layton) [1767959]
- [net] libceph, rbd, ceph: move ceph_osdc_alloc_messages() calls (Jeff Layton) [1767959]
- [net] libceph: introduce alloc_watch_request() (Jeff Layton) [1767959]
- [net] libceph: assign cookies in linger_submit() (Jeff Layton) [1767959]
- [net] libceph: enable fallback to ceph_msg_new() in ceph_msgpool_get() (Jeff Layton) [1767959]
- [fs] ceph: num_ops is off by one in ceph_aio_retry_work() (Jeff Layton) [1767959]
- [net] libceph: no need to call osd_req_opcode_valid() in osd_req_encode_op() (Jeff Layton) [1767959]
- [fs] ceph: set timeout conditionally in __cap_delay_requeue (Jeff Layton) [1767959]
- [net] libceph: don't consume a ref on pagelist in ceph_msg_data_add_pagelist() (Jeff Layton) [1767959]
- [net] libceph: introduce ceph_pagelist_alloc() (Jeff Layton) [1767959]
- [net] libceph: osd_req_op_cls_init() doesn't need to take opcode (Jeff Layton) [1767959]
- [kernel] libceph: bump CEPH_MSG_MAX_DATA_LEN (Jeff Layton) [1767959]
- [fs] ceph: only allow punch hole mode in fallocate (Jeff Layton) [1767959]
- [fs] ceph: refactor ceph_sync_read() (Jeff Layton) [1767959]
- [fs] ceph: check if LOOKUPNAME request was aborted when filling trace (Jeff Layton) [1767959]
- [fs] ceph: fix dentry leak in ceph_readdir_prepopulate (Jeff Layton) [1767959]
- [fs] revert "ceph: fix dentry leak in splice_dentry()" (Jeff Layton) [1767959]
- [fs] ceph: check snap first in ceph_set_acl() (Jeff Layton) [1767959]
- [block] rbd: add __init/__exit annotations (Jeff Layton) [1767959]
- [fs] ceph: reset cap hold timeout only for requeued inode (Jeff Layton) [1767959]
- [fs] ceph: don't drop message if it contains more data than expected (Jeff Layton) [1767959]
- [fs] ceph: support cephfs' own feature bits (Jeff Layton) [1767959]
- [net] crush: fix using plain integer as NULL warning (Jeff Layton) [1767959]
- [net] libceph: remove unnecessary non NULL check for request_key (Jeff Layton) [1767959]
- [fs] ceph: refactor error handling code in ceph_reserve_caps() (Jeff Layton) [1767959]
- [fs] ceph: refactor ceph_unreserve_caps() (Jeff Layton) [1767959]
- [fs] ceph: change to void return type for __do_request() (Jeff Layton) [1767959]
- [fs] ceph: compare fsc->max_file_size and inode->i_size for max file size limit (Jeff Layton) [1767959]
- [fs] ceph: add additional size check in ceph_setattr() (Jeff Layton) [1767959]
- [fs] ceph: add additional offset check in ceph_write_iter() (Jeff Layton) [1767959]
- [fs] ceph: add additional range check in ceph_fallocate() (Jeff Layton) [1767959]
- [fs] ceph: add new field max_file_size in ceph_fs_client (Jeff Layton) [1767959]
- [net] ceph: fix whitespace (Jeff Layton) [1767959]
- [fs] ceph: adding new return type vm_fault_t (Jeff Layton) [1767959]
- [kernel] libceph: remove now unused ceph_{en, de}code_timespec() (Jeff Layton) [1767959]
- [fs] ceph: use timespec64 for r_stamp (Jeff Layton) [1767959]
- [fs] libceph: use timespec64 for r_mtime (Jeff Layton) [1767959]
- [fs] ceph: use timespec64 for inode timestamp (Jeff Layton) [1767959]
- [fs] ceph: stop using current_kernel_time() (Jeff Layton) [1767959]
- [net] libceph: use timespec64 in for keepalive2 and ticket validity (Jeff Layton) [1767959]
- [fs] ceph: add d_drop for some error cases in ceph_symlink() (Jeff Layton) [1767959]
- [fs] ceph: add d_drop for some error cases in ceph_mknod() (Jeff Layton) [1767959]
- [fs] ceph: return errors from posix_acl_equiv_mode() correctly (Jeff Layton) [1767959]
- [net] libceph: amend "bad option arg" error message (Jeff Layton) [1767959]
- [net] libceph: stop parsing when a bad int arg is detected (Jeff Layton) [1767959]
- [kernel] libceph: change ceph_pagelist_encode_string() to take u32 (Jeff Layton) [1767959]
- [net] libceph: make ceph_osdc_notify{, _ack}() payload_len u32 (Jeff Layton) [1767959]
- [fs] ceph: restore ctime as well in the case of restoring old mode (Jeff Layton) [1767959]
- [fs] ceph: add retry logic for error -ERANGE in ceph_get_acl() (Jeff Layton) [1767959]

* Tue Nov 26 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-153.el8]
- [tools] objtool: Support repeated uses of the same C jump table (Yauheni Kaliuta) [1747617]
- [tools] objtool: Refactor jump table code (Yauheni Kaliuta) [1747617]
- [tools] objtool: Fix sibling call detection (Yauheni Kaliuta) [1747617]
- [tools] objtool: Add --backtrace support (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Improve handling of corrupted ELF during map initialization (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Fix negative FD close() in xsk_setup_xdp_prog() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Change size to u64 for bpf_map_{area_alloc, charge_init}() (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: Fix btf_dump padding test case (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Fix struct end padding in btf_dump (Yauheni Kaliuta) [1747617]
- [tools] bpf: Allow narrow loads of bpf_sysctl fields with offset > 0 (Yauheni Kaliuta) [1747617]
- [tools] bpftool: move "__printf()" attributes to header file (Yauheni Kaliuta) [1747617]
- [media] bpf: media: properly use bpf_prog_array api (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix format string for p_err() in detect_common_prefix() (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix argument for p_err() in BTF do_dump() (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix arguments for p_err() in do_event_pipe() (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix format strings and arguments for jsonw_printf() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision tracking of stack slots (Yauheni Kaliuta) [1747617]
- [kernel] bpf: handle 32-bit zext during constant blinding (Yauheni Kaliuta) [1747617]
- [net] bpf: allow narrow loads of some sk_reuseport_md fields with offset > 0 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision tracking in presence of bpf2bpf calls (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add config fragment BPF_JIT (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_btf_dump with O= (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_cgroup_storage on s390 (Yauheni Kaliuta) [1747617]
- [tools] bpftool: close prog FD before exit on showing a single program (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix "bind{4, 6} deny specific IP & port" on s390 (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools infrastructure (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add error message on pin failure (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix error message (prog -> object) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: tests for jmp to 1st insn (Yauheni Kaliuta) [1747617]
- [x86] bpf: fix x64 JIT code generation for jmp to 1st insn (Yauheni Kaliuta) [1747617]
- [tools] libbpf: set BTF FD for prog only when there is supported .BTF.ext data (Yauheni Kaliuta) [1747617]
- [tools] libbpf : make libbpf_num_possible_cpus function thread safe (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix missing __WORDSIZE definition (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix erroneous multi-closing of BTF FD (Yauheni Kaliuta) [1747617]
- [tools] libbpf: silence GCC8 warning about string truncation (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add another gso_segs access (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix sendmsg6_prog on s390 (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Avoid designated initializers for unnamed union members (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Fix endianness macro usage for some compilers (Yauheni Kaliuta) [1747617]
- [tools] libbpf: sanitize VAR to conservative 1-byte INT (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix SIGSEGV when BTF loading fails, but .BTF.ext exists (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_xdp_noinline on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix "valid read map access into a read-only array 1" on s390 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Disable GCC -fgcse optimization for ___bpf_prog_run() (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix perf_buffer on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: structure test_{progs, maps, verifier} test runners uniformly (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_verifier/test_maps make dependencies (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix another GCC8 warning for strncpy (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: skip nmi test when perf hw events are disabled (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: remove logic duplication in test_verifier (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add selftests for wide loads (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: rename verifier/wide_store.c to verifier/wide_access.c (Yauheni Kaliuta) [1747617]
- [net] bpf: allow wide aligned loads for bpf_sock_addr user_ip6 and msg_src_ip6 (Yauheni Kaliuta) [1747617]
- [samples] bpf: build with -D__TARGET_ARCH_$(SRCARCH) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: put test_stub.o into $(OUTPUT) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: make directory prerequisites order-only (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix attach_probe on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: use typedef'ed arrays as map values (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add trickier size resolution tests (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix BTF verifier size resolution logic (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix compiling loop{1, 2, 3}.c on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: make PT_REGS_* work in userspace (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix s930 -> s390 typo (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: compile progs with -D__TARGET_ARCH_$(SRCARCH) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: do not ignore clang failures (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: avoid fall-through warnings (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix bpf_target_sparc check (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix ptr to u64 conversion warning on 32-bit platforms (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision bit propagation for BPF_ST instructions (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Fix ORC unwinding in non-JIT BPF code (Yauheni Kaliuta) [1747617]
- [tools] objtool: Add support for C jump tables (Yauheni Kaliuta) [1747617]
- [tools] objtool: Don't use ignore flag for fake jumps (Yauheni Kaliuta) [1747617]
- [tools] objtool: Support per-function rodata sections (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_reuseport_array on s390 (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add completion for bpftool prog "loadall" (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cgroup: Fix build error without CONFIG_NET (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_attach_probe map definition (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add verifier tests for wide stores (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add perf_buffer_ prefix to README (Yauheni Kaliuta) [1747617]
- [tools] bpftool: switch map event_pipe to libbpf's perf_buffer (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: test perf buffer API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: auto-set PERF_EVENT_ARRAY size to number of CPUs (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add perf buffer API (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add test_tcp_rtt to .gitignore (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_align liveliness expectations (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add "prog run" subcommand to test-run programs (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert legacy BPF maps to BTF-defined ones (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert selftests using BTF-defined maps to new syntax (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add __uint and __type macro for BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] libbpf: capture value in BTF type info for BTF-defined map defs (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert existing tracepoint tests to new APIs (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add kprobe/uprobe selftests (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: switch test to new attach_perf_event API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add raw tracepoint attach API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add tracepoint attach API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add kprobe/uprobe attach API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add ability to attach/detach BPF program to perf event (Yauheni Kaliuta) [1747617]
- [tools] libbpf: introduce concept of bpf_link (Yauheni Kaliuta) [1747617]
- [tools] libbpf: make libbpf_strerror_r agnostic to sign of error (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: fix inlines in test_lwt_seg6local (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: standardize to static __always_inline (Yauheni Kaliuta) [1747617]
- [samples] bpf: Add support for fq's EDT to HBM (Yauheni Kaliuta) [1747617]
- [tools] bpf, libbpf, smatch: Fix potential NULL pointer dereference (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix GCC8 warning for strncpy (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: add tests for shifts by zero (Yauheni Kaliuta) [1747617]
- [x86] bpf, x32: Fix bug with ALU64 {LSH, RSH, ARSH} BPF_K shift by 0 (Yauheni Kaliuta) [1747617]
- [x86] bpf, x32: Fix bug with ALU64 {LSH, RSH, ARSH} BPF_X shift by 0 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision tracking (Yauheni Kaliuta) [1747617]
- [tools] bpf: fix uapi bpf_prog_info fields alignment (Yauheni Kaliuta) [1747617]
- [kernel] devmap: Allow map lookups from eBPF (Yauheni Kaliuta) [1747617]
- [net] bpf_xdp_redirect_map: Perform map lookup in eBPF helper (Yauheni Kaliuta) [1747617]
- [net] devmap: Rename ifindex member in bpf_redirect_info (Yauheni Kaliuta) [1747617]
- [kernel] devmap/cpumap: Use flush list instead of bitmap (Yauheni Kaliuta) [1747617]
- [kernel] xskmap: Move non-standard list manipulation to helper (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix -Wstrict-aliasing in test_sockopt_sk.c (Yauheni Kaliuta) [1747617]
- [tools] bpftool: support cgroup sockopt (Yauheni Kaliuta) [1747617]
- [documentation] bpf: add sockopt documentation (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add sockopt test that exercises BPF_F_ALLOW_MULTI (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add sockopt test that exercises sk helpers (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add sockopt test (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: test sockopt section name (Yauheni Kaliuta) [1747617]
- [tools] libbpf: support sockopt hooks (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1747617]
- [kernel] bpf: implement getsockopt and setsockopt hooks (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix cgroup bpf release synchronization (Yauheni Kaliuta) [1747617]
- [samples] bpf: make the use of xdp samples consistent (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix BPF_ALU32 | BPF_ARSH on BE arches (Yauheni Kaliuta) [1747617]
- [tools] bpftool: use correct argument in cgroup errors (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix compiler warning with CONFIG_MODULES=n (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: build tests with debug info (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix max() type mismatch for 32bit (Yauheni Kaliuta) [1747617]
- [trace] xdp: Add tracepoint for bulk XDP_TX (Yauheni Kaliuta) [1747617]
- [tools] selftests, bpf: Add test for veth native XDP (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix spelling mistake "conflictling" -> "conflicting" (Yauheni Kaliuta) [1747617]
- [kernel] bpf: precise scalar_value tracking (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add realistic loop tests (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add basic verifier tests for loops (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix tests (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix callees pruning callers (Yauheni Kaliuta) [1747617]
- [kernel] bpf: introduce bounded loops (Yauheni Kaliuta) [1747617]
- [kernel] bpf: extend is_branch_taken to registers (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix tests due to const spill/fill (Yauheni Kaliuta) [1747617]
- [kernel] bpf: track spill/fill of constants (Yauheni Kaliuta) [1747617]
- [tools] libbpf: constify getter APIs (Yauheni Kaliuta) [1747617]
- [samples] bpf: refactor header include path (Yauheni Kaliuta) [1747617]
- [samples] bpf: remove unnecessary include options in Makefile (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert tests w/ custom values to BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: switch BPF_ANNOTATE_KV_PAIR tests to BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add test for BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] libbpf: allow specifying map definitions using BTF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: split initialization and loading of BTF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: identify maps by section index in addition to offset (Yauheni Kaliuta) [1747617]
- [tools] libbpf: refactor map initialization (Yauheni Kaliuta) [1747617]
- [tools] libbpf: streamline ELF parsing error-handling (Yauheni Kaliuta) [1747617]
- [tools] libbpf: extract BTF loading logic (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add common min/max macro to libbpf_internal.h (Yauheni Kaliuta) [1747617]
- [net] bpf: fix the check that forwarding is enabled in bpf_ipv6_fib_lookup (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Fix build error without CONFIG_INET (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert socket_cookie test to sk storage (Yauheni Kaliuta) [1747617]
- [tools] bpf/tools: sync bpf.h (Yauheni Kaliuta) [1747617]
- [net] bpf: export bpf_sock for BPF_PROG_TYPE_SOCK_OPS prog type (Yauheni Kaliuta) [1747617]
- [net] bpf: export bpf_sock for BPF_PROG_TYPE_CGROUP_SOCK_ADDR prog type (Yauheni Kaliuta) [1747617]
- [tools] bpf: Add test for SO_REUSEPORT_DETACH_BPF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix check for presence of associated BTF for map creation (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: signedness bug in enable_all_controllers() (Yauheni Kaliuta) [1747617]
- [samples] bpf: fix include path in Makefile (Yauheni Kaliuta) [1747617]
- [kernel] bpf: silence warning messages in core (Yauheni Kaliuta) [1747617]
- [tools] bpf: use libbpf_num_possible_cpus internally (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: remove bpf_util.h from BPF C progs (Yauheni Kaliuta) [1747617]
- [tools] bpf: add a new API libbpf_num_possible_cpus() (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf : clean up feature/ when make clean (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix constness of source arg for bpf helpers (Yauheni Kaliuta) [1747617]
- [samples] bpf: don't run probes at the local make stage (Yauheni Kaliuta) [1747617]
- [tools] libbpf: remove qidconf and better support external bpf programs (Yauheni Kaliuta) [1747617]
- [tools] bpf: Add bpf_map_lookup_elem selftest for xskmap (Yauheni Kaliuta) [1747617]
- [tools] bpf/tools: sync bpf.h (Yauheni Kaliuta) [1747617]
- [net] bpf: Allow bpf_map_lookup_elem() on an xskmap (Yauheni Kaliuta) [1747617]
- [documentation] docs: bpf: get rid of two warnings (Yauheni Kaliuta) [1747617]
- [net] bpf: allow CGROUP_SKB programs to use bpf_skb_cgroup_id() helper (Yauheni Kaliuta) [1747617]
- [samples] bpf: print a warning about headers_install (Yauheni Kaliuta) [1747617]
- [kernel] bpf: remove redundant assignment to err (Yauheni Kaliuta) [1747617]
- [samples] bpf: hbm: fix spelling mistake "notifcations" -> "notificiations" (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: measure RTT from xdp using xdping (Yauheni Kaliuta) [1747617]
- [documentation] bpf: doc: update answer for 32-bit subregister question (Yauheni Kaliuta) [1747617]
- [kernel] bpf: move memory size checks to bpf_map_charge_init() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: rework memlock-based memory accounting for maps (Yauheni Kaliuta) [1747617]
- [kernel] bpf: group memory related fields in struct bpf_map_memory (Yauheni Kaliuta) [1747617]
- [net] bpf: add memlock precharge for socket local storage (Yauheni Kaliuta) [1747617]
- [kernel] bpf: add memlock precharge check for cgroup_local_storage (Yauheni Kaliuta) [1747617]
- [samples] bpf: Add more stats to HBM (Yauheni Kaliuta) [1747617]
- [samples] bpf: Add cn support to hbm_out_kern.c (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Update __cgroup_bpf_run_filter_skb with cn (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cgroup inet skb programs can return 0 to 3 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Create BPF_PROG_CGROUP_INET_EGRESS_RUN_ARRAY (Yauheni Kaliuta) [1747617]
- [tools] libbpf: reduce unnecessary line wrapping (Yauheni Kaliuta) [1747617]
- [tools] libbpf: typo and formatting fixes (Yauheni Kaliuta) [1747617]
- [tools] libbpf: simplify two pieces of logic (Yauheni Kaliuta) [1747617]
- [tools] libbpf: use negative fd to specify missing BTF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix error code returned on corrupted ELF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: check map name retrieved from ELF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: simplify endianness check (Yauheni Kaliuta) [1747617]
- [tools] libbpf: preserve errno before calling into user callback (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix detection of corrupted BPF instructions section (Yauheni Kaliuta) [1747617]
- [tools] libbpf: prevent overwriting of log_level in bpf_object__load_progs() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: tracing: properly use bpf_prog_array api (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cgroup: properly use bpf_prog_array api (Yauheni Kaliuta) [1747617]
- [kernel] bpf: remove __rcu annotations from bpf_prog_array (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add auto-detach test (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: enable all available cgroup v2 controllers (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert test_cgrp2_attach2 example into kselftest (Yauheni Kaliuta) [1747617]
- [samples] bpf: fix a couple of style issues in bpf_load (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fail test_tunnel.sh if subtests fail (Yauheni Kaliuta) [1747617]
- [tools] bpftool: make -d option print debug output from verifier (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add bpf_object__load_xattr() API function to pass log_level (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add -d option to get debug output from libbpf (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix warning that PTR_ERR_OR_ZERO can be used (Yauheni Kaliuta) [1747617]
- [tools] bpf: style fix in while(!feof()) loop (Yauheni Kaliuta) [1747617]
- [kernel] bpf: check signal validity in nmi for bpf_send_signal() helper (Yauheni Kaliuta) [1747617]
- [tools] bpftool: auto-complete BTF IDs for btf dump (Yauheni Kaliuta) [1747617]
- [samples] bpf: add ibumad sample to .gitignore (Yauheni Kaliuta) [1747617]
- [x86] x32: bpf: eliminate zero extension code-gen (Yauheni Kaliuta) [1747617]
- [s390] bpf: eliminate zero extension code-gen (Yauheni Kaliuta) [1747617]
- [powerpc] bpf: eliminate zero extension code-gen (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: enable hi32 randomization for all tests (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: adjust several test_verifier helpers for insn insertion (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add "prog_flags" to bpf_program/bpf_prog_load_attr/bpf_load_program_attr (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: randomize high 32-bit when BPF_F_TEST_RND_HI32 is set (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync uapi header bpf.h (Yauheni Kaliuta) [1747617]
- [uapi] bpf: introduce new bpf prog load flags "BPF_F_TEST_RND_HI32" (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: insert zero extension according to analysis result (Yauheni Kaliuta) [1747617]
- [kernel] bpf: introduce new mov32 variant for doing explicit zero extension (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: mark patched-insn with sub-register zext flag (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: mark verified-insn with sub-register zext flag (Yauheni Kaliuta) [1747617]
- [tools] bpf: add selftest in test_progs for bpf_send_signal() helper (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf uapi header bpf.h to tools directory (Yauheni Kaliuta) [1747617]
- [kernel] bpf: implement bpf_send_signal() helper (Yauheni Kaliuta) [1747617]
- [tools] bpftool: update bash-completion w/ new c option for btf dump (Yauheni Kaliuta) [1747617]
- [tools] bpftool/docs: add description of btf dump C option (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add C output format option to btf dump subcommand (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add btf_dump BTF-to-C conversion tests (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add btf_dump API for BTF-to-C conversion (Yauheni Kaliuta) [1747617]
- [tools] libbpf: switch btf_dedup() to hashmap for dedup table (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add tests for libbpf's hashmap (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add resizable non-thread safe internal hashmap (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: use btf__parse_elf to check presence of BTF/BTF.ext (Yauheni Kaliuta) [1747617]
- [tools] bpftool: use libbpf's btf__parse_elf API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add btf__parse_elf API to load .BTF and .BTF.ext (Yauheni Kaliuta) [1747617]
- [tools] libbpf: ensure libbpf.h is included along libbpf_internal.h (Yauheni Kaliuta) [1747617]
- [samples] bpf: Do not define bpf_printk macro (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: Move bpf_printk to bpf_helpers.h (Yauheni Kaliuta) [1747617]
- [kernel] bpf: convert explored_states to hash table (Yauheni Kaliuta) [1747617]
- [kernel] bpf: split explored_states (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cleanup explored_states (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add pyperf scale test (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: adjust verifier scale test (Yauheni Kaliuta) [1747617]
- [kernel] bpf: bump jmp sequence limit (Yauheni Kaliuta) [1747617]
- [tools] libbpf: emit diff of mismatched public API, if any (Yauheni Kaliuta) [1747617]
- [tools] bpf, selftest: test global data/bss/rodata sections (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: test_tc_tunnel: skip unsupported tests (Jiri Benc) [1749814]
- [tools] selftests/bpf: More compatible nc options in test_tc_edt (Jiri Benc) [1749814]
- [net] xdp: check device pointer before clearing (Jiri Benc) [1749814]
- [net] bpf: udp: Avoid calling reuseport's bpf_prog from udp_gro (Jiri Benc) [1749814]
- [net] bpf: sockmap, fix use after free from sleep in psock backlog workqueue (Jiri Benc) [1749814]
- [include] bpf: sockmap, restore sk_write_space when psock gets dropped (Jiri Benc) [1749814]
- [net] bpfilter: fallback to netfilter if failed to load bpfilter kernel module (Jiri Benc) [1749814]
- [net] pass net_device argument to the eth_get_headlen (Jiri Benc) [1749814]
- [net] flow_dissector: handle no-skb use case (Jiri Benc) [1749814]
- [net] plumb network namespace into __skb_flow_dissect (Jiri Benc) [1749814]
- [net] bpfilter: dont use module_init in non-modular code (Jiri Benc) [1749814]
- [net] xsk: fix XDP socket ring buffer memory ordering (Jiri Benc) [1749814]
- [tools] selftests/bpf: install files test_xdp_vlan.sh (Jiri Benc) [1749814]
- [net] fix bpf_xdp_adjust_head regression for generic-XDP (Jiri Benc) [1749814]
- [tools] selftests/bpf: reduce time to execute test_xdp_vlan.sh (Jiri Benc) [1749814]
- [tools] selftests/bpf: add wrapper scripts for test_xdp_vlan.sh (Jiri Benc) [1749814]
- [tools] bpf: fix XDP vlan selftests test_xdp_vlan.sh (Jiri Benc) [1749814]
- [net] core: support XDP generic on stacked devices. (Jiri Benc) [1749814]
- [netdrv] netvsc: unshare skb in VF rx handler (Jiri Benc) [1749814]
- [net] convert rps_needed and rfs_needed to new static branch api (Jiri Benc) [1749814]
- [net] core: Document __skb_flow_dissect() flags argument (Jiri Benc) [1749814]
- [net] gso: Fix skb_segment splat when splitting gso_size mangled skb having linear-headed frag_list (Jiri Benc) [1749814]
- [net] sock_map, fix missing ulp check in sock hash case (Jiri Benc) [1749814]
- [net] Fix missing meta data in skb with vlan packet (Jiri Benc) [1749814]
- [include] skbuff.h: fix using plain integer as NULL warning (Jiri Benc) [1749814]
- [netdrv] netdevsim: Fix error handling in nsim_fib_init and nsim_fib_exit (Jiri Benc) [1761359]
- [netdrv] netdevsim: Restore per-network namespace accounting for fib entries (Jiri Benc) [1761359]
- [netdrv] netdevsim: Make nsim_num_vf static (Jiri Benc) [1761359]
- [netdrv] netdevsim: fix fall-through annotation (Jiri Benc) [1761359]
- [netdrv] netdevsim: implement ndo_get_devlink_port (Jiri Benc) [1761359]
- [netdrv] netdevsim: move netdev creation/destruction to dev probe (Jiri Benc) [1761359]
- [netdrv] netdevsim: extend device attrs to support port addition and deletion (Jiri Benc) [1761359]
- [netdrv] netdevsim: implement dev probe/remove skeleton with port initialization (Jiri Benc) [1761359]
- [netdrv] netdevsim: change debugfs tree topology (Jiri Benc) [1761359]
- [netdrv] netdevsim: generate random switch id instead of using dev id (Jiri Benc) [1761359]
- [netdrv] netdevsim: merge sdev into dev (Jiri Benc) [1761359]
- [netdrv] netdevsim: rename dev_init/exit() functions and make them independent on ns (Jiri Benc) [1761359]
- [netdrv] netdevsim: add bus attributes to add new and delete devices (Jiri Benc) [1761359]
- [netdrv] netdevsim: use ida for bus device ids (Jiri Benc) [1761359]
- [netdrv] netdevsim: add stub netdevsim driver implementation (Jiri Benc) [1761359]
- [netdrv] netdevsim: move device registration and related code to bus.c (Jiri Benc) [1761359]
- [netdrv] netdevsim: put netdevsim bus code into separate file (Jiri Benc) [1761359]
- [netdrv] netdevsim: rename devlink.c to dev.c to contain per-dev(asic) items (Jiri Benc) [1761359]
- [netdrv] netdevsim: create devlink instance per netdevsim instance (Jiri Benc) [1761359]
- [netdrv] netdevsim: move device registration on bus to be done earlier in init (Jiri Benc) [1761359]
- [netdrv] netdevsim: move sdev-specific init/uninit code into separate functions (Jiri Benc) [1761359]
- [netdrv] netdevsim: make bpf_offload_dev_create() per-sdev instead of first ns (Jiri Benc) [1761359]
- [netdrv] netdevsim: move shared dev creation and destruction into separate file (Jiri Benc) [1761359]
- [netdrv] netdevsim: let net core to free netdevsim netdev (Jiri Benc) [1761359]
- [netdrv] netdevsim: remove nsim_dellink() implementation (Jiri Benc) [1761359]
- [include] driver core: add BUS_ATTR_WO() macro (Jiri Benc) [1761359]
- arm64: bpf: do not allocate executable memory (Yauheni Kaliuta) [1762214]
- modules: page-align module section allocations only for arches supporting strict module rwx (Yauheni Kaliuta) [1762214]
- modules: always page-align module section allocations (Yauheni Kaliuta) [1762214]
- modules: fix compile error if don't have strict module rwx (Yauheni Kaliuta) [1762214]
- modules: Use vmalloc special flag (Yauheni Kaliuta) [1762214]
- modules: fix BUG when load module with rodata=n (Yauheni Kaliuta) [1762214]
- x86/modules: Avoid breaking W^X while loading modules (Yauheni Kaliuta) [1762214]
- x86/alternatives, jumplabel: Use text_poke_early() before mm_init() (Yauheni Kaliuta) [1762214]
- x86/kprobes: Set instruction page as executable (Yauheni Kaliuta) [1762214]
- x86/ftrace: Set trampoline pages as executa (Yauheni Kaliuta) [1762214]
- [tools] bpftool: Fix json dump crash on powerpc (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix race in flow dissector tests (Yauheni Kaliuta) [1747615]
- [arm64] insn: Fix ldadd instruction encoding (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: tolerate missing pahole when generating BTF (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: handle old pahole more gracefully when generating BTF (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: add ability to generate BTF type info for vmlinux (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: hardcode genksyms path and remove GENKSYMS variable (Yauheni Kaliuta) [1747615]
- [scripts] bpf: fix script for generating man page on BPF helpers (Yauheni Kaliuta) [1747615]
- [tools] add smp_* barrier variants to include infrastructure (Yauheni Kaliuta) [1747615]
- [tools] tools headers barrier: Fix arm64 tools build failure wrt smp_load_{acquire, release} (Yauheni Kaliuta) [1747615]
- [tools] bpf, x32: Fix bug for BPF_JMP | {BPF_JSGT, BPF_JSLE, BPF_JSLT, BPF_JSGE} (Yauheni Kaliuta) [1747615]
- [x86] unwind/orc: Fall back to using frame pointers for generated code (Yauheni Kaliuta) [1747615]
- [x86] unwind: Add hardcoded ORC entry for NULL (Yauheni Kaliuta) [1747615]
- [x86] unwind: Handle NULL pointer calls better in frame unwinder (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix accessing bpf_sysctl.file_pos on s390 (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix narrower loads on s390 (Yauheni Kaliuta) [1747615]
- [net] bpf: rename bpf_ctx_wide_store_ok to bpf_ctx_wide_access_ok (Yauheni Kaliuta) [1747615]
- [net] bpf: allow wide (u64) aligned stores for some fields of bpf_sock_addr (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: improve unexpected success reporting in test_syctl (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix "ctx:write sysctl:write read ok" on s390 (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix format string for p_err() in query_flow_dissector() (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add raw_tracepoint_writable prog type to header (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix NULL deref in btf_type_is_resolve_source_only (Yauheni Kaliuta) [1747615]
- [net] bpf: Set sk_bpf_storage back to NULL for cloned sk (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix nested bpf tracepoints with per-cpu data (Yauheni Kaliuta) [1747615]
- [net] bpf: Fix out of bounds memory access in bpf_sk_storage (Yauheni Kaliuta) [1747615]
- [kernel] sysctl: define proc_do_static_key() (Yauheni Kaliuta) [1747615]
- [x86] bpf, x64: fix stack layout of JITed bpf code (Yauheni Kaliuta) [1747615]
- [kernel] bpf, devmap: Add missing RCU read lock on flush (Yauheni Kaliuta) [1747615]
- [kernel] bpf, devmap: Add missing bulk queue free (Yauheni Kaliuta) [1747615]
- [kernel] bpf, devmap: Fix premature entry free on destroying map (Yauheni Kaliuta) [1747615]
- [powerpc] bpf: use unsigned division instruction for 64-bit operations (Yauheni Kaliuta) [1747615]
- [tools] bpf: fix div64 overflow tests to properly detect errors (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync BPF_FIB_LOOKUP flag changes with BPF uapi (Yauheni Kaliuta) [1747615]
- [uapi] bpf: simplify definition of BPF_FIB_LOOKUP related flags (Yauheni Kaliuta) [1747615]
- [tools] bpf: lpm_trie: check left child of last leftmost node for NULL (Yauheni Kaliuta) [1747615]
- [tools] bpf: expand section tests for test_section_names (Yauheni Kaliuta) [1747615]
- [tools] bpf: more msg_name rewrite tests to test_sock_addr (Yauheni Kaliuta) [1747615]
- [tools] bpf, bpftool: enable recvmsg attach types (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: enable recvmsg attach types (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync tooling uapi header (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix unconnected udp hooks (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Fix JSON output when lookup fails (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: move test_lirc_mode2_user to TEST_GEN_PROGS_EXTENDED (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Return btf_fd for load_sk_storage_btf (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: fix compiler warning in flow_dissector test (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: complete sub-register zero extension checks (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: move sub-register zero extension checks into subreg.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: add zero extend checks for ALU32 and/or/xor (Yauheni Kaliuta) [1747615]
- [samples] bpf: suppress compiler warning (Yauheni Kaliuta) [1747615]
- [samples] bpf: fix to change the buffer size for read() (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix BTF raw dump of FWD's fwd_kind (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix bpf_get_current_task (Yauheni Kaliuta) [1747615]
- [tools] libbpf: move logging helpers into libbpf_internal.h (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add test_sysctl and map_tests/tests.h to .gitignore (Yauheni Kaliuta) [1747615]
- [kernel] bpf: relax inode permission check for retrieving bpf program (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add prog detach to flow_dissector test (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add missing \n to flow_dissector CHECK errors (Yauheni Kaliuta) [1747615]
- [tools] libbpf: don't fail when feature probing fails (Yauheni Kaliuta) [1747615]
- [tools] bpf: test ref bit from data path and add new tests for syscall path (Yauheni Kaliuta) [1747615]
- [kernel] bpf, lru: avoid messing with eviction heuristics upon syscall lookup (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add map_lookup_elem_sys_only for lookups from syscall side (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync kernel btf.h header (Yauheni Kaliuta) [1747615]
- [uapi] bpf: btf: fix the brackets of BTF_INT_OFFSET() (Yauheni Kaliuta) [1747615]
- [kernel] bpf: devmap: fix use-after-free Read in __dev_map_entry_free (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix undefined behavior in narrow load handling (Yauheni Kaliuta) [1747615]
- [tools] libbpf: detect supported kernel BTF features and sanitize BTF (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: Add files generated after build to .gitignore (Yauheni Kaliuta) [1747615]
- [tools] bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1747615]
- [uapi] bpf: fix minor issues in documentation for BPF helpers (Yauheni Kaliuta) [1747615]
- [uapi] bpf: fix recurring typo in documentation for BPF helpers (Yauheni Kaliuta) [1747615]
- [tools] bpf: add various test cases for backward jumps (Yauheni Kaliuta) [1747615]
- [documentation] docs/btf: fix the missing section marks (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: initialize bpf_object pointers where needed (Yauheni Kaliuta) [1747615]
- [tools] libbpf: add libbpf_util.h to header install (Yauheni Kaliuta) [1747615]
- [tools] bpf: fix perf build error with uClibc (seen on ARC) (Yauheni Kaliuta) [1747615]
- [tools] bpftool: exclude bash-completion/bpftool from .gitignore pattern (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: set RLIMIT_MEMLOCK properly for test_libbpf_open.c (Yauheni Kaliuta) [1747615]
- [net] bpf: Use PTR_ERR_OR_ZERO in bpf_fd_sk_storage_update_elem() (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Use vmalloc special flag (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Fail bpf_probe_write_user() while mm is switched (Yauheni Kaliuta) [1747615]
- [kernel] mm/tlb: Provide default nmi_uaccess_okay() (Yauheni Kaliuta) [1747615]
- [kernel] asm-generic/tlb: Guard with #ifdef CONFIG_MMU (Yauheni Kaliuta) [1747615]
- [tools] bpf: Add ene-to-end test for bpf_sk_storage_* helpers (Yauheni Kaliuta) [1747615]
- [tools] bpf: Add BPF_MAP_TYPE_SK_STORAGE test to test_maps (Yauheni Kaliuta) [1747615]
- [tools] bpf: Add verifier tests for the bpf_sk_storage (Yauheni Kaliuta) [1747615]
- [tools] bpf: Refactor BTF encoding macro to test_btf.h (Yauheni Kaliuta) [1747615]
- [tools] bpf: Support BPF_MAP_TYPE_SK_STORAGE in bpf map probing (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools (Yauheni Kaliuta) [1747615]
- [net] bpf: Introduce bpf sk local storage (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: test writable buffers in raw tps (Yauheni Kaliuta) [1747615]
- [tools] sync bpf.h (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add writable context for raw tracepoints (Yauheni Kaliuta) [1747615]
- [arm64] bpf, arm64: use more scalable stadd over ldxr / stxr loop in xadd (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix indendation in bash-completion/bpftool (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add bash completions for btf command (Yauheni Kaliuta) [1747615]
- [tools] bpftool/docs: add btf sub-command documentation (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add ability to dump BTF types (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Fix errno variable usage (Yauheni Kaliuta) [1747615]
- [tools] bpftool: show flow_dissector attachment status (Yauheni Kaliuta) [1747615]
- [net] bpf: support BPF_PROG_QUERY for BPF_FLOW_DISSECTOR attach_type (Yauheni Kaliuta) [1747615]
- [samples] bpf: add hbm sample to .gitignore (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix samples/bpf build failure due to undefined UINT32_MAX (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: fix segfault in bpf_object__init_maps' pr_debug statement (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: handle old kernels more graceful wrt global data sections (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: expand test_tc_tunnel with SIT encap (Yauheni Kaliuta) [1747615]
- [net] bpf: update skb->protocol in bpf_skb_net_grow (Yauheni Kaliuta) [1747615]
- [tools] bpf/flow_dissector: don't adjust nhoff by ETH_HLEN in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: properly return error from bpf_flow_load (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: run flow dissector tests in skb-less mode (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add flow dissector bpf_skb_load_bytes helper test (Yauheni Kaliuta) [1747615]
- [net] bpf: when doing BPF_PROG_TEST_RUN for flow dissector use no-skb mode (Yauheni Kaliuta) [1747615]
- [kernel] bpf: drop bpf_verifier_lock (Yauheni Kaliuta) [1747615]
- [kernel] bpf: remove global variables (Yauheni Kaliuta) [1747615]
- [documentation] bpf: document the verifier limits (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix BPF_LOG_BUF_SIZE off-by-one error (Yauheni Kaliuta) [1747615]
- [documentation] bpf: move BPF_PROG_TYPE_FLOW_DISSECTOR documentation to a new common place (Yauheni Kaliuta) [1747615]
- [tools] bpf: Increase MAX_NR_MAPS to 17 in test_verifier.c (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix compile errors due to unsync linux/in6.h and netinet/in.h (Yauheni Kaliuta) [1747615]
- [documentation] bpf: Document BPF_PROG_TYPE_CGROUP_SYSCTL (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix a compilation error (Yauheni Kaliuta) [1747615]
- [kernel] bpf: cpumap memory prefetchw optimizations for struct page (Yauheni Kaliuta) [1747615]
- [kernel] bpf: cpumap do bulk allocation of SKBs (Yauheni Kaliuta) [1747615]
- [net] core: introduce build_skb_around (Yauheni Kaliuta) [1747615]
- [kernel] bpf: cpumap use ptr_ring_consume_batched (Yauheni Kaliuta) [1747615]
- [tools] libbpf: optimize barrier for XDP socket rings (Yauheni Kaliuta) [1747615]
- [tools] bpftool: show btf_id in map listing (Yauheni Kaliuta) [1747615]
- [tools] bpftool: re-organize newline printing for map listing (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Support sysctl hook (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix printf formatter for ptrdiff_t argument (Yauheni Kaliuta) [1747615]
- [kernel] bpf: use BPF_CAST_CALL for casting bpf call (Yauheni Kaliuta) [1747615]
- [uapi] bpf: allow clearing all sock_ops callback flags (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: add VRF test cases to lwt_ip_encap test (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: make flow dissector tests more extensible (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: two scale tests (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Improve handling of ENOSPC on reuseport_array map dumps (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Use print_entry_error() in case of ENOENT when dumping (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add a note on program statistics in man page (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix short option name for printing version in man pages (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix man page documentation for "pinmaps" keyword (Yauheni Kaliuta) [1747615]
- [tools] bpftool: reset errno for "bpftool cgroup tree" (Yauheni Kaliuta) [1747615]
- [tools] bpftool: remove blank line after btf_id when listing programs (Yauheni Kaliuta) [1747615]
- [net] bpf: reserve flags in bpf_skb_net_shrink (Yauheni Kaliuta) [1747615]
- [tools] bpf: fix whitespace for ENCAP_L2 defines in bpf.h (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: bring back (void *) cast to set_ipv4_csum in test_tc_tunnel (Yauheni Kaliuta) [1747615]
- [tools] selftests/btf: add VAR and DATASEC case for dedup tests (Yauheni Kaliuta) [1747615]
- [tools] btf: add support for VAR and DATASEC in btf_dedup() (Yauheni Kaliuta) [1747615]
- [kernel] bpf: refactor "check_reg_arg" to eliminate code redundancy (Yauheni Kaliuta) [1747615]
- [kernel] bpf: factor out reg and stack slot propagation into "propagate_liveness_reg" (Yauheni Kaliuta) [1747615]
- [kernel] bpf: refactor propagate_liveness to eliminate code redundance (Yauheni Kaliuta) [1747615]
- [kernel] bpf: refactor propagate_liveness to eliminate duplicated for loop (Yauheni Kaliuta) [1747615]
- [netdrv] netdevsim: move sdev specific bpf debugfs files to sdev dir (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Fix distinct pointer types warning for ARCH=i386 (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: C based test for sysctl and strtoX (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test bpf_strtol and bpf_strtoul helpers (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test ARG_PTR_TO_LONG arg type (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Add sysctl and strtoX helpers to bpf_helpers.h (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_strtol and bpf_strtoul helpers (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce ARG_PTR_TO_{INT,LONG} arg types (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test file_pos field in bpf_sysctl ctx (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test bpf_sysctl_{get, set}_new_value helpers (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test sysctl_get_current_value helper (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test bpf_sysctl_get_name helper (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test BPF_CGROUP_SYSCTL (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test sysctl section name (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Support sysctl hook (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Add file_pos field to bpf_sysctl ctx (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_sysctl_{get, set}_new_value helpers (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_sysctl_get_current_value helper (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_sysctl_get_name helper (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Sysctl hook (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Add base proto function for cgroup-bpf programs (Yauheni Kaliuta) [1747615]
- [net] bpf: explicitly prohibit ctx_{in, out} in non-skb BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] selftests_bpf: add L2 encap to test_tc_tunnel (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync bpf.h to tools/ for BPF_F_ADJ_ROOM_ENCAP_L2 (Yauheni Kaliuta) [1747615]
- [net] bpf: add layer 2 encap support to bpf_skb_adjust_room (Yauheni Kaliuta) [1747615]
- [tools] selftests_bpf: extend test_tc_tunnel for UDP encap (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix missing bpf_check_uarg_tail_zero in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [s390] Convert IS_ENABLED uses to __is_defined (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: add selftest for __sk_buff context in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] libbpf: add support for ctx_{size, }_{in, out} in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [net] bpf: support input __sk_buff context in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] bpftool: show btf id in program information (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Fix build with gcc-8 (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix crash in XDP socket part with new larger BPF_LOG_BUF_SIZE (Yauheni Kaliuta) [1747615]
- [tools] bpf, bpftool: fix a few ubsan warnings (Yauheni Kaliuta) [1747615]
- [tools] bpf, selftest: add test cases for BTF Var and DataSec (Yauheni Kaliuta) [1747615]
- [tools] bpf, selftest: test {rd, wr}only flags and direct value access (Yauheni Kaliuta) [1747615]
- [tools] bpf: bpftool support for dumping data/bss/rodata sections (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: add support for BTF Var and DataSec (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: support global data/bss/rodata sections (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: refactor relocation handling (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync {btf, bpf}.h uapi header from tools infrastructure (Yauheni Kaliuta) [1747615]
- [kernel] bpf: allow for key-less BTF in array map (Yauheni Kaliuta) [1747615]
- [kernel] bpf: kernel side support for BTF Var and DataSec (Yauheni Kaliuta) [1747615]
- [documentation] bpf: add specification for BTF Var and DataSec kinds (Yauheni Kaliuta) [1747615]
- [kernel] bpf: allow . char as part of the object name (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add syscall side map freeze support (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add program side {rd, wr}only support for maps (Yauheni Kaliuta) [1747615]
- [kernel] bpf: do not retain flags that are not tied to map lifetime (Yauheni Kaliuta) [1747615]
- [kernel] bpf: implement lookup-free direct value access for maps (Yauheni Kaliuta) [1747615]
- [net] ipv6: Add neighbor helpers that use the ipv6 stub (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Ignore -Wformat-nonliteral warning (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Add missed newline in verifier verbose log (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test unbounded var_off stack access (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Sanity check max value for var_off stack access (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test indirect var_off stack access in unpriv mode (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Reject indirect var_off stack access in unpriv mode (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test indirect var_off stack access in raw mode (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Reject indirect var_off stack access in raw mode (Yauheni Kaliuta) [1747615]
- [samples] bpf: fix build with new clang (Yauheni Kaliuta) [1747615]
- [samples] selftests/bpf: add NULL check for ksym_search (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: ksym_search won't check symbols exists (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: synthetic tests to push verifier limits (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add few verifier scale tests (Yauheni Kaliuta) [1747615]
- [tools] libbpf: teach libbpf about log_level bit 2 (Yauheni Kaliuta) [1747615]
- [kernel] bpf: increase verifier log limit (Yauheni Kaliuta) [1747615]
- [kernel] bpf: increase complexity limit and maximum program size (Yauheni Kaliuta) [1747615]
- [kernel] bpf: verbose jump offset overflow check (Yauheni Kaliuta) [1747615]
- [kernel] bpf: convert temp arrays to kvcalloc (Yauheni Kaliuta) [1747615]
- [kernel] bpf: improve verification speed by not remarking live_read (Yauheni Kaliuta) [1747615]
- [kernel] bpf: improve verification speed by droping states (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add verifier stats and log_level bit 2 (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: remove duplicate .flags initialization in ctx_skb.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: fix -Wformat-invalid-specifier for bpf_obj_id.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: fix -Wformat-security warning for flow_dissector_load.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: tests.h should depend on .c files, not the output (Yauheni Kaliuta) [1747615]
- [tools] bpf: add bpffs multi-dimensional array tests in test_btf (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test variable offset stack access (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Support variable offset stack access from helpers (Yauheni Kaliuta) [1747615]
- [net] ipv6: Move ipv6 stubs to a separate header file (Yauheni Kaliuta) [1747615]
- [tools] bpf: generate pkg-config file for libbpf (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: don't depend on hardcoded perf sample_freq (Yauheni Kaliuta) [1747615]
- [tools] bpf: test_tc_tunnel.sh needs reverse path filtering disabled (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: tc-bpf flow shaping with EDT (Yauheni Kaliuta) [1747615]
- [net] bpf: make bpf_skb_ecn_set_ce callable from BPF_PROG_TYPE_SCHED_ACT (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: convert bpf tunnel test to encap modes (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: convert bpf tunnel test to BPF_F_ADJ_ROOM_FIXED_GSO (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: convert bpf tunnel test to BPF_ADJ_ROOM_MAC (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools (Yauheni Kaliuta) [1747615]
- [net] bpf: add bpf_skb_adjust_room encap flags (Yauheni Kaliuta) [1747615]
- [net] bpf: add bpf_skb_adjust_room flag BPF_F_ADJ_ROOM_FIXED_GSO (Yauheni Kaliuta) [1747615]
- [net] bpf: add bpf_skb_adjust_room mode BPF_ADJ_ROOM_MAC (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: extend bpf tunnel test with tso (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: extend bpf tunnel test with gre (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: expand bpf tunnel test to ipv6 (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: expand bpf tunnel test with decap (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: bpf tunnel encap test (Yauheni Kaliuta) [1747615]
- [net] bpf: in bpf_skb_adjust_room avoid copy in tx fast path (Yauheni Kaliuta) [1747615]
- [samples] bpf: add xdp_sample_pkts to .gitignore (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add tests for bpf_tcp_check_syncookie and bpf_skc_lookup_tcp (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: test references to sock_common (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: allow specifying helper for BPF_SK_LOOKUP (Yauheni Kaliuta) [1747615]
- [tools] update uapi/linux/bpf.h (Yauheni Kaliuta) [1747615]
- [net] bpf: add helper to check for a valid SYN cookie (Yauheni Kaliuta) [1747615]
- [net] bpf: add skc_lookup_tcp helper (Yauheni Kaliuta) [1747615]
- [kernel] bpf: allow helpers to return PTR_TO_SOCK_COMMON (Yauheni Kaliuta) [1747615]
- [kernel] bpf: track references based on is_acquire_func (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Add arm target register definitions (Yauheni Kaliuta) [1747615]
- [documentation] bpf, doc: add RISC-V JIT to BPF documentation (Yauheni Kaliuta) [1747615]
- [uapi] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1747615]
- [uapi] bpf: add documentation for helpers bpf_spin_lock(), bpf_spin_unlock() (Yauheni Kaliuta) [1747615]

* Mon Nov 25 2019 Bruno Meneguele <bmeneg@redhat.com> [4.18.0-152.el8]
- [perf] perf: Add CCPI2 PMU support in ThunderX2 UNCORE driver (Robert Richter) [1726054]
- [documentation] documentation: perf: Update documentation for ThunderX2 PMU uncore driver (Robert Richter) [1726054]
- [scsi] lpfc: Update lpfc version to 12.6.0.2 (Dick Kennedy) [1771674]
- [scsi] lpfc: revise nvme max queues to be hdwq count (Dick Kennedy) [1771674]
- [scsi] lpfc: Initialize cpu_map for not present cpus (Dick Kennedy) [1771674]
- [scsi] lpfc: fix inlining of lpfc_sli4_cleanup_poll_list() (Dick Kennedy) [1771674]
- [scsi] lpfc: fix: coverity: lpfc_cmpl_els_rsp(): Null pointer dereferences (Dick Kennedy) [1771674]
- [scsi] lpfc: fix: coverity: lpfc_get_scsi_buf_s3(): Null pointer dereferences (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix lpfc_cpumask_of_node_init() (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix a kernel warning triggered by lpfc_sli4_enable_intr() (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix a kernel warning triggered by lpfc_get_sgl_per_hdwq() (Dick Kennedy) [1771674]
- [scsi] lpfc: Update lpfc version to 12.6.0.1 (Dick Kennedy) [1771674]
- [scsi] lpfc: Add enablement of multiple adapter dumps (Dick Kennedy) [1771674]
- [scsi] lpfc: Change default IRQ model on AMD architectures (Dick Kennedy) [1771674]
- [scsi] lpfc: Add registration for CPU Offline/Online events (Dick Kennedy) [1771674]
- [scsi] lpfc: Clarify FAWNN error message (Dick Kennedy) [1771674]
- [scsi] lpfc: Sync with FC-NVMe-2 SLER change to require Conf with SLER (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix dynamic fw log enablement check (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix unexpected error messages during RSCN handling (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix kernel crash at lpfc_nvme_info_show during remote port bounce (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix configuration of BB credit recovery in service parameters (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix duplicate unreg_rpi error in port offline flow (Dick Kennedy) [1771674]
- [infiniband] ib/srp: Add missing new line after displaying fast_io_fail_tmo param (Kamal Heib) [1678461 1720899]
- [net] sunrpc: The RDMA back channel mustn't disappear while requests are outstanding (Kamal Heib) [1720899]
- [infiniband] rdma/nldev: Skip counter if port doesn't match (Kamal Heib) [1720899]
- [rdma] uverbs: Prevent potential underflow (Kamal Heib) [1720899]
- [infiniband] ib/core: Use rdma_read_gid_l2_fields to compare GID L2 fields (Kamal Heib) [1720899]
- [infiniband] rdma/siw: free siw_base_qp in kref release routine (Kamal Heib) [1720899]
- [infiniband] rdma/iwcm: move iw_rem_ref() calls out of spinlock (Kamal Heib) [1720899]
- [infiniband] ib/core: Fix wrong iterating on ports (Kamal Heib) [1720899]
- [infiniband] rdma/nldev: Reshuffle the code to avoid need to rebind QP in error path (Kamal Heib) [1720899]
- [infiniband] rdma/cm: Fix memory leak in cm_add/remove_one (Kamal Heib) [1720899]
- [infiniband] rdma/core: Fix an error handling path in 'res_get_common_doit()' (Kamal Heib) [1720899]
- [infiniband] rdma/iwcm: Fix a lock inversion issue (Kamal Heib) [1720899]
- [infiniband] rdma/siw: Fix serialization issue in write_space() (Kamal Heib) [1720899]
- [infiniband] rdma/vmw_pvrdma: Free SRQ only once (Kamal Heib) [1757294 1720899]
- [infiniband] rdma: Fix double-free in srq creation error flow (Kamal Heib) [1720899]
- [infiniband] rdma/siw: Fix page address mapping in TX path (Kamal Heib) [1720899]
- [infiniband] rdma/cma: Fix false error message (Kamal Heib) [1720899]
- [infiniband] rdma/{cxgb3, cxgb4, i40iw}: Remove common code (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/core: Fix use after free and refcnt leak on ndev in_device in iwarp_query_port (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/core: Add common iWARP query port (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/i40iw: Associate ibdev to netdev before IB device registration (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/cxgb3: Use ib_device_set_netdev() (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma: Introduce ib_port_phys_state enum (Kamal Heib) [1760097 1745655 1720899]
- [sched] topology: Improve load balancing on AMD EPYC systems (Phil Auld) [1757535]
- [netdrv] broadcom: Use dev_get_drvdata (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add a new BNXT_FW_RESET_STATE_POLL_FW_DOWN state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.100 (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Increase timeout for HWRM_DBG_COREDUMP_XX commands (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Don't proceed in .ndo_set_rx_mode() when device is not in open state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix compile error regression with CONFIG_BNXT_SRIOV not set (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add FW fatal devlink_health_reporter (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add bnxt_fw_exception() to handle fatal firmware errors (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add RESET_FW state logic to bnxt_fw_reset_task() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Do not send firmware messages if firmware is in error state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Retain user settings on a VF after RESET_NOTIFY event (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add devlink health reset reporter (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle firmware reset (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle RESET_NOTIFY async event from firmware (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add new FW devlink_health_reporter (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add BNXT_STATE_IN_FW_RESET state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Enable health monitoring (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Pre-map the firmware health monitoring registers (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Discover firmware error recovery capabilities (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle firmware reset status during IF_UP (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Register buffers for VFs before reserving resources (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor bnxt_sriov_enable() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Prepare bnxt_init_one() to be called multiple times (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Suppress all error messages in hwrm_do_send_msg() in silent mode (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Simplify error checking in the SR-IOV message forwarding functions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Convert error code in firmware message response to standard code (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Remove the -1 error return code from bnxt_hwrm_do_send_msg() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Use a common function to print the same ethtool -f error message (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix allocation of zero statistics block size regression (Jonathan Toppins) [1724766]
- [netdrv] bnxt: no need to check return value of debugfs_create functions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add PCI IDs for 57500 series NPAR devices (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Support all variants of the 5750X chip family (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor bnxt_init_one() and turn on TPA support on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Support TPA counters on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Allocate the larger per-ring statistics block for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor ethtool ring statistics logic (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add hardware GRO setup function for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add TPA ID mapping logic for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add fast path logic for TPA on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Set TPA GRO mode flags on 57500 chips properly (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor tunneled hardware GRO logic (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle standalone RX_AGG completions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Expand bnxt_tpa_info struct to support 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor TPA logic (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add TPA structure definitions for BCM57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.89 (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Suppress HWRM errors for HWRM_NVM_GET_VARIABLE command (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix to include flow direction in L2 key (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Use correct src_fid to determine direction of the flow (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix handling FRAG_ERR when NVM_INSTALL_UPDATE cmd fails (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Improve RX doorbell sequence (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix VNIC clearing logic for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix VNIC accounting when enabling aRFS on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add page_pool_destroy() during RX ring cleanup (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: add page_pool support (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: optimized XDP_REDIRECT support (Jonathan Toppins) [1724766 1669220]
- [netdrv] bnxt_en: Refactor __bnxt_xmit_xdp() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: rename some xdp functions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Device serial number is supported only for PFs (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add support for aRFS on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Query firmware capability to support aRFS on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Separate RDMA MR/AH context allocation (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: read the clause type from the PHY ID (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Read package version from firmware (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Check new firmware capability to display extended stats (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add support for PCIe statistics (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor bnxt_alloc_stats() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Update firmware interface to 1.10.0.69 (Jonathan Toppins) [1724766]
- [netdrv] bnxt: remove ndo_get_port_parent_id implementation for physical ports (Jonathan Toppins) [1724766]
- [netdrv] bnxt: pass switch ID through devlink_port_attrs_set() (Jonathan Toppins) [1724766]
- [netdrv] bnxt: move bp->switch_id initialization to PF probe (Jonathan Toppins) [1724766]
- [netdrv] bnxt: remove ndo_get_phys_port_name implementation (Jonathan Toppins) [1724766]
- [netdrv] bnxt: implement ndo_get_devlink_port (Jonathan Toppins) [1724766]
- [netdrv] bnxt: Implement ndo_get_port_parent_id() (Jonathan Toppins) [1724766]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix firmware signaled resource change logic in open (Jonathan Toppins) [1724766]
- [netdrv] bnx2x: Mark expected switch fall-thoughs (Jonathan Toppins) [1724766]
- [netdrv] bnx2x: Mark expected switch fall-throughs (Jonathan Toppins) [1724766]
- [tools] selftests: kvm: vmx_dirty_log_test: skip the test when VMX is not supported (Vitaly Kuznetsov) [1771575]
- [tools] selftests: kvm: consolidate VMX support checks (Vitaly Kuznetsov) [1771575]
- [tools] selftests: kvm: vmx_set_nested_state_test: don't check for VMX support twice (Vitaly Kuznetsov) [1771575]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 321 (Stefano Garzarella) [1769904]
- [net] vsock: Send reset control packet when socket is partially bound (Stefano Garzarella) [1769904]
- [net] vsock/virtio: fix sock refcnt holding during the shutdown (Stefano Garzarella) [1769855]
- [kernel] vsock/virtio: remove unused 'work' field from 'struct virtio_vsock_pkt' (Stefano Garzarella) [1769855]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 482 (Stefano Garzarella) [1769855]
- [net] vsock/virtio: set SOCK_DONE on peer shutdown (Stefano Garzarella) [1769855]
- [net] vsock/virtio: discard packets if credit is not respected (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: send a credit update when buffer size is changed (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: a better comment on credit update (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: fix locking in virtio_transport_inc_tx_pkt() (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: reduce credit update messages (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: change the maximum packet size allowed (Stefano Garzarella) [1679971]
- [vhost] vsock: split packets to send using multiple buffers (Stefano Garzarella) [1679971]
- [net] vsock/virtio: limit the memory used per-socket (Stefano Garzarella) [1769744]
- [net] vsock/virtio: free packets during the socket release (Stefano Garzarella) [1769744]
- [net] vsock: Fix a lockdep warning in __vsock_release() (Stefano Garzarella) [1769714]
- [net] vsock: correct removal of socket from the list (Stefano Garzarella) [1769714]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Stefano Garzarella) [1769714]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 321 (Stefano Garzarella) [1769714]
- [net] Fix ERROR:do not initialise statics to 0 in af_vsock.c (Stefano Garzarella) [1769714]
- [net] vsock: bind to random port for VMADDR_PORT_ANY (Stefano Garzarella) [1769714]
- [tools] tc-testing: added tests with cookie for conntrack TC action (Ivan Vecera) [1739606]
- [net] cls_bpf: fix NULL deref on offload filter removal (Ivan Vecera) [1739606]
- [tools] tc-testing: fixed two failing pedit tests (Ivan Vecera) [1739606]
- [tools] tc-testing: implement tests for new fast_init action flag (Ivan Vecera) [1739606]
- [net] sched: update action implementations to support flags (Ivan Vecera) [1739606]
- [net] sched: use temporary variable for actions indexes (Ivan Vecera) [1739606]
- [net] sched: extend TCA_ACT space with TCA_ACT_FLAGS (Ivan Vecera) [1739606]
- [net] sched: modify stats helper functions to support regular stats (Ivan Vecera) [1739606]
- [net] sched: don't expose action qstats to skb_tc_reinsert() (Ivan Vecera) [1739606]
- [net] sched: extract qstats update code into functions (Ivan Vecera) [1739606]
- [net] sched: extract bstats update code into function (Ivan Vecera) [1739606]
- [net] sched: extract common action counters update code into function (Ivan Vecera) [1739606]
- [tools] tc-testing: list required kernel options for act_ct action (Ivan Vecera) [1739606]
- [net] fq_codel: do not include <linux/jhash.h> (Ivan Vecera) [1739606]
- [net] sch_generic: Use pfifo_fast as fallback scheduler for CAN hardware (Ivan Vecera) [1739606]
- [net] sched: taprio: fix -Wmissing-prototypes warnings (Ivan Vecera) [1739606]
- [net] sched: act_police: re-use tcf_tm_dump() (Ivan Vecera) [1739606]
- [tools] tc-testing: updated pedit TDC tests (Ivan Vecera) [1739606]
- [net] sched: Avoid using yield() in a busy waiting loop (Ivan Vecera) [1739606]
- [tools] tc-testing: updated pedit test cases (Ivan Vecera) [1739606]
- [net] sched: etf: Fix ordering of packets with same txtime (Ivan Vecera) [1739606]
- [tools] tc-testing: updated pedit test cases (Ivan Vecera) [1739606]
- [net] taprio: Fix returning EINVAL when configuring without flags (Ivan Vecera) [1739606]
- [net] net_sched: fix backward compatibility for TCA_ACT_KIND (Ivan Vecera) [1739606]
- [net] net_sched: fix backward compatibility for TCA_KIND (Ivan Vecera) [1739606]
- [net] sched: Set default of CONFIG_NET_TC_SKB_EXT to N (Ivan Vecera) [1739606]
- [net] sch_netem: fix rcu splat in netem_enqueue() (Ivan Vecera) [1739606]
- [net] net_sched: remove need_resched() from qdisc_run() (Ivan Vecera) [1739606]
- [net] sched: cbs: Avoid division by zero when calculating the port rate (Ivan Vecera) [1739606]
- [net] sched: taprio: Avoid division by zero on invalid link speed (Ivan Vecera) [1739606]
- [net] sched: taprio: Fix potential integer overflow in taprio_set_picos_per_byte (Ivan Vecera) [1739606]
- [net] sched: cbs: Fix not adding cbs instance to list (Ivan Vecera) [1739606]
- [net] Fix Kconfig indentation (Ivan Vecera) [1739606]
- [net] net_sched: add policy validation for action attributes (Ivan Vecera) [1739606]
- [net] net_sched: add max len check for TCA_KIND (Ivan Vecera) [1739606]
- [net] taprio: Add support for hardware offloading (Ivan Vecera) [1739606]
- [net] sched: use get_dev() action API in flow_action infra (Ivan Vecera) [1739606]
- [net] sched: take reference to psample group in flow_action infra (Ivan Vecera) [1739606]
- [net] sched: extend flow_action_entry with destructor (Ivan Vecera) [1739606]
- [net] sch_hhf: ensure quantum and hhf_non_hh_weight are non-zero (Ivan Vecera) [1739606]
- [net] net_sched: check cops->tcf_block in tc_bind_tclass() (Ivan Vecera) [1739606]
- [net] sched: fix reordering issues (Ivan Vecera) [1739606]
- [net] net_sched: act_police: add 2 new attributes to support police 64bit rate and peakrate (Ivan Vecera) [1739606]
- [net] openvswitch: Set OvS recirc_id from tc chain index (Ivan Vecera) [1739606]
- [net] sk_buff: drop all skb extensions on free and skb scrubbing (Ivan Vecera) [1739606]
- [net] minor cleanup in skb_ext_add() (Ivan Vecera) [1739606]
- [include] net: drop the unused helper skb_ext_get() (Ivan Vecera) [1739606]
- [net] fix possible user-after-free in skb_ext_add() (Ivan Vecera) [1739606]
- [net] sk_buff: add skb extension infrastructure (Ivan Vecera) [1739606]
- [net] sched: cbs: remove redundant assignment to variable port_rate (Ivan Vecera) [1739606]
- [tools] tc-testing: don't hardcode 'ip' in nsPlugin.py (Ivan Vecera) [1739606]
- [net] sched: cbs: Set default link speed to 10 Mbps in cbs_set_port_rate (Ivan Vecera) [1739606]
- [net] taprio: Set default link speed to 10 Mbps in taprio_set_picos_per_byte (Ivan Vecera) [1739606]
- [net] taprio: Fix kernel panic in taprio_destroy (Ivan Vecera) [1739606]
- [netdrv] mlx5e: Move local var definition into ifdef block (Ivan Vecera) [1739606]
- [net] sched: cls_matchall: cleanup flow_action before deallocating (Ivan Vecera) [1739606]
- [net] sched: act_vlan: implement stats_update callback (Ivan Vecera) [1739606]
- [net] sched: act_sample: fix psample group handling on overwrite (Ivan Vecera) [1739606]
- [net] sched: flower: don't take rtnl lock for cls hw offloads API (Ivan Vecera) [1739606]
- [net] sched: copy tunnel info when setting flow_action entry->tunnel (Ivan Vecera) [1739606]
- [net] sched: take reference to action dev before calling offloads (Ivan Vecera) [1739606]
- [net] sched: take rtnl lock in tc_setup_flow_action() (Ivan Vecera) [1739606]
- [net] sched: conditionally obtain rtnl lock in cls hw offloads API (Ivan Vecera) [1739606]
- [net] sched: add API for registering unlocked offload block callbacks (Ivan Vecera) [1739606]
- [net] sched: notify classifier on successful offload add/delete (Ivan Vecera) [1739606]
- [net] sched: refactor block offloads counter usage (Ivan Vecera) [1739606]
- [net] sched: change tcf block offload counter type to atomic_t (Ivan Vecera) [1739606]
- [net] sched: protect block offload-related fields with rw_semaphore (Ivan Vecera) [1739606]
- [net] net_sched: fix a NULL pointer deref in ipt action (Ivan Vecera) [1739606]
- [tools] tc-testing: concurrency: wrap piped rule update commands (Ivan Vecera) [1739606]
- [tools] tc-testing: use dedicated DUMMY interface name for dummy dev (Ivan Vecera) [1739606]
- [net] flow_offload: convert block_ing_cb_list to regular list type (Ivan Vecera) [1739606]
- [netdrv] sched: use major priority number as hardware priority (Ivan Vecera) [1739606]
- [tools] tc-testing: added tdc tests for matchall filter (Ivan Vecera) [1739606]
- [net] taprio: remove unused variable 'entry_list_policy' (Ivan Vecera) [1739606]
- [tools] tc-testing: updated skbedit action tests with batch create/delete (Ivan Vecera) [1739606]
- [net] sched: update skbedit action for batched events operations (Ivan Vecera) [1739606]
- [net] fq_codel: remove set but not used variables 'prev_ecn_mark' and 'prev_drop_count' (Ivan Vecera) [1739606]
- [net] flow_offload: support get multi-subsystem block (Ivan Vecera) [1739606]
- [net] flow_offload: move tc indirect block to flow offload (Ivan Vecera) [1739606]
- [net] cls_api: add flow_indr_block_call function (Ivan Vecera) [1739606]
- [net] cls_api: remove the tcf_block cache (Ivan Vecera) [1739606]
- [net] cls_api: modify the tc_indr_block_ing_cmd parameters. (Ivan Vecera) [1739606]
- [net] sched: sch_taprio: fix memleak in error path for sched list parse (Ivan Vecera) [1739606]
- [net] fq_codel: Kill useless per-flow dropped statistic (Ivan Vecera) [1739606]
- [net] Increase fq_codel count in the bulk dropper (Ivan Vecera) [1739606]
- [include] sched: sample: allow accessing psample_group with rtnl (Ivan Vecera) [1739606]
- [tools] tc-testing: updated vlan action tests with batch create/delete (Ivan Vecera) [1739606]
- [net] sched: update vlan action for batched events operations (Ivan Vecera) [1739606]
- [tools] tc-testing: Clarify the use of tdc's -d option (Ivan Vecera) [1739606]
- [net] sched: Fix a possible null-pointer dereference in dequeue_func() (Ivan Vecera) [1739606]
- [tools] tc-testing: added tdc tests for [b|p]fifo qdisc (Ivan Vecera) [1739606]
- [net] ife: error out when nla attributes are empty (Ivan Vecera) [1739606]
- [net] sched: verify that q!=NULL before setting q->flags (Ivan Vecera) [1739606]
- [net] net_sched: unset TCQ_F_CAN_BYPASS when adding filters (Ivan Vecera) [1739606]
- [net] fix: taprio: Change type of txtime-delay parameter to u32 (Ivan Vecera) [1739606]
- [tools] tc-tests: updated skbedit tests (Ivan Vecera) [1739606]
- [include] pkt_sched: Include const.h (Ivan Vecera) [1739606]
- [tools] tc-testing: introduce scapyPlugin for basic traffic (Ivan Vecera) [1739606]
- [tools] tc-testing: Allow tdc plugins to see test case data (Ivan Vecera) [1739606]
- [tools] tc-testing: added tdc tests for prio qdisc (Ivan Vecera) [1739606]
- [tools] tc-testing: updated mirred action tests with batch create/delete (Ivan Vecera) [1739606]
- [net] sched: update mirred action for batched events operations (Ivan Vecera) [1739606]
- [net] sched: em_ipt: add support for addrtype matching (Ivan Vecera) [1739606]
- [net] sched: em_ipt: keep the user-specified nfproto and dump it (Ivan Vecera) [1739606]
- [net] sched: em_ipt: set the family based on the packet if it's unspecified (Ivan Vecera) [1739606]
- [net] sched: em_ipt: match only on ip/ipv6 traffic (Ivan Vecera) [1739606]
- [net] taprio: Adjust timestamps for TCP packets (Ivan Vecera) [1739606]
- [net] taprio: make clock reference conversions easier (Ivan Vecera) [1739606]
- [net] taprio: Add support for txtime-assist mode (Ivan Vecera) [1739606]
- [net] taprio: Remove inline directive (Ivan Vecera) [1739606]
- [net] taprio: calculate cycle_time when schedule is installed (Ivan Vecera) [1739606]
- [net] etf: Add skip_sock_check (Ivan Vecera) [1739606]
- [include] etf: Don't use BIT() in UAPI headers. (Ivan Vecera) [1739606]
- [tools] tc-testing: add ingress qdisc tests (Ivan Vecera) [1739606]
- [tools] tc-testing: Restore original behaviour for namespaces in tdc (Ivan Vecera) [1739606]
- [include] net: sched: act_ctinfo: tidy UAPI definition (Ivan Vecera) [1739606]
- [include] act_ctinfo: Don't use BIT() in UAPI headers. (Ivan Vecera) [1739606]
- [net] sched: cls_matchall: allow to delete filter (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: fix policy validation (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: fix action creation (Ivan Vecera) [1739606]
- [tools] tc-tests: updated skbedit tests (Ivan Vecera) [1739606]
- [tools] tc-tests: added path to ip command in tdc (Ivan Vecera) [1739606]
- [net] sched: remove NET_CLS_IND config option (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: use extack error reporting (Ivan Vecera) [1739606]
- [net] sched: ingress: set 'unlocked' flag for clsact Qdisc ops (Ivan Vecera) [1739606]
- [net] sched: ingress: set 'unlocked' flag for Qdisc ops (Ivan Vecera) [1739606]
- [tools] tc-tests: updated fw with bind actions by reference use cases (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: minor size optimisation (Ivan Vecera) [1739606]
- [net] flow_offload: use struct_size() in kzalloc() (Ivan Vecera) [1739606]
- [net] sched: don't use tc_action->order during action dump (Ivan Vecera) [1739606]
- [net] sch_htb: redefine htb qdisc overlimits (Ivan Vecera) [1739606]
- [tools] selftests: tc-testing: Add pedit tests (Ivan Vecera) [1739606]
- [net] sched: add ingress mirred action to hardware IR (Ivan Vecera) [1757520]
- [include] net: tc_act: add helpers to detect ingress mirred actions (Ivan Vecera) [1757520]
- [net] sched: add skbedit of ptype action to hardware IR (Ivan Vecera) [1757520]
- [include] net: tc_act: add skbedit_ptype helper functions (Ivan Vecera) [1757520]
- [net] openvswitch: load and reference the NAT helper. (Flavio Leitner) [1752970]
- [net] openvswitch: load NAT helper (Flavio Leitner) [1752970]
- [net] netfilter: nf_nat: register NAT helpers. (Flavio Leitner) [1752970]
- [net] netfilter: add API to manage NAT helpers. (Flavio Leitner) [1752970]
- [net] netfilter: use macros to create module aliases. (Flavio Leitner) [1752970]
- [net] xfrm: remove a duplicated assignment (Sabrina Dubroca) [1760002]
- [net] xfrm: remove empty xfrmi_init_net (Sabrina Dubroca) [1760002]
- [net] xfrm: remove unneeded export_symbols (Sabrina Dubroca) [1760002]
- [include] xfrm: clean an indentation issue, remove a space (Sabrina Dubroca) [1760002]
- [net] xfrm6: remove BUG_ON from xfrm6_dst_ifdown (Sabrina Dubroca) [1760002]
- [net] xfrm: policy: add missing indentation (Sabrina Dubroca) [1760002]
- [net] xfrm: Fix bucket count reported to userspace (Sabrina Dubroca) [1760002]
- [net] xfrm: use complete IPv6 addresses for hash (Sabrina Dubroca) [1760002]
- [net] xfrm: use correct size to initialise sp->ovec (Sabrina Dubroca) [1760002]
- [net] xfrm: allow driver to quietly refuse offload (Sabrina Dubroca) [1760002]
- [net] esp: remove redundant define esph (Sabrina Dubroca) [1760002]
- [net] ip6_vti: simplify stats handling in vti6_xmit (Sabrina Dubroca) [1760002]
- [net] xfrm: fix 'passing zero to ERR_PTR()' warning (Sabrina Dubroca) [1760002]
- [net] xfrm: remove blank lines at EOF (Sabrina Dubroca) [1760002]
- [net] xfrm: don't check offload_handle for nonzero (Sabrina Dubroca) [1760002]
- [net] ipv6: xfrm: use 64-bit timestamps (Sabrina Dubroca) [1760002]
- [net] devlink: Introduce PCI VF port flavour and port attribute (Petr Oros) [1761495]
- [net] devlink: Introduce PCI PF port flavour and port attribute (Petr Oros) [1761495]
- [net] devlink: Return physical port fields only for applicable port flavours (Petr Oros) [1761495]
- [net] devlink: Refactor physical port attributes (Petr Oros) [1761495]
- [net] ipv4: fix race condition between route lookup and invalidation (Guillaume Nault) [1765639]
- [net] add {READ|WRITE}_ONCE() annotations on ->rskq_accept_head (Guillaume Nault) [1765639]
- [net] ipv4/icmp: fix rt dst dev null pointer dereference (Guillaume Nault) [1765639]
- [net] ipip: validate header length in ipip_tunnel_xmit (Guillaume Nault) [1765639]
- [net] ipv4: Use return value of inet_iif() for __raw_v4_lookup in the while loop (Guillaume Nault) [1765639]
- [net] ipv4: Fix raw socket lookup for local traffic (Guillaume Nault) [1765639]
- [net] ipv4: Return error for RTA_VIA attribute (Guillaume Nault) [1765639]
- [net] ipmr: fix unresolved entry dumps (Guillaume Nault) [1765639]
- [net] ipvs: don't ignore errors in case refcounting ip_vs module fails (Davide Caratti) [1687094]
- [net] ipvs: fix tinfo memory leak in start_sync_thread (Davide Caratti) [1687094]
- [net] tcp: fix a possible lockdep splat in tcp_done() (Marcelo Leitner) [1764654]
- [net] tcp: add rcu protection around tp->fastopen_rsk (Marcelo Leitner) [1764654]
- [net] tcp: annotate lockless access to tcp_memory_pressure (Marcelo Leitner) [1764654]
- [net] tcp: fix tcp_ecn_withdraw_cwr() to clear TCP_ECN_QUEUE_CWR (Marcelo Leitner) [1764654]
- [net] tcp: inherit timestamp on mtu probe (Marcelo Leitner) [1764654]
- [net] tcp: remove empty skb from write queue in error cases (Marcelo Leitner) [1764654]
- [net] tcp: get rid of tcp_check_send_head() (Marcelo Leitner) [1764654]
- [net] tcp: make sure EPOLLOUT wont be missed (Marcelo Leitner) [1764654]
- [net] ipv4: set the tcp_min_rtt_wlen range from 0 to one day (Marcelo Leitner) [1764654]
- [net] net-tcp: /proc/sys/net/ipv4/tcp_probe_interval is a u32 not int (Marcelo Leitner) [1764654]
- [net] tcp: fix a race in inet_diag_dump_icsk() (Marcelo Leitner) [1764654]
- [net] netfilter: nft_meta: Add NFT_META_I/OIFKIND meta type (Florian Westphal) [1763657]
- [net] netfilter: nft_xfrm: use state family, not hook one (Florian Westphal) [1763654]
- [net] netfilter: nf_tables: add xfrm expression (Florian Westphal) [1763654]
- [net] netfilter: nf_tables: rt: allow checking if dst has xfrm attached (Florian Westphal) [1763654]
- [netdrv] mlx5e: Fix unnecessary flow_block_cb_is_busy call (Ivan Vecera) [1737890]
- [netdrv] nfp: flower: verify that block cb is not busy before binding (Ivan Vecera) [1737890]
- [netdrv] net/mlx5e: Provide cb_list pointer when setting up tc block on rep (Ivan Vecera) [1737890]
- [net] sched: Fix NULL-pointer dereference in tc_indr_block_ing_cmd() (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block structure and use it (Ivan Vecera) [1737890]
- [net] flow_offload: rename tc_setup_cb_t to flow_setup_cb_t (Ivan Vecera) [1737890]
- [include] flow_offload: include linux/kernel.h from flow_offload.h (Ivan Vecera) [1737890]
- [net] flow_offload: remove netns parameter from flow_block_cb_alloc() (Ivan Vecera) [1737890]
- [net] openvswitch: rename flow_stats to sw_flow_stats (Ivan Vecera) [1737890]
- [netdrv] mlx5e: Fix unused variable warning when CONFIG_MLX5_ESWITCH is off (Ivan Vecera) [1737890]
- [netdrv] net: flow_offload: rename tc_cls_flower_offload to flow_cls_offload (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_is_busy() and use it (Ivan Vecera) [1737890]
- [net] sched: remove tcf block API (Ivan Vecera) [1737890]
- [include] sched: use new symbol for TC kABI version (Ivan Vecera) [1737890]
- [netdrv] use flow block API (Ivan Vecera) [1737890]
- [net] sched: use flow block API (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_{priv, incref, decref}() (Ivan Vecera) [1737890]
- [net] flow_offload: add list handling functions (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_alloc() and flow_block_cb_free() (Ivan Vecera) [1737890]
- [net] flow_offload: rename TCF_BLOCK_BINDER_TYPE_* to FLOW_BLOCK_BINDER_TYPE_* (Ivan Vecera) [1737890]
- [net] flow_offload: rename TC_BLOCK_{UN}BIND to FLOW_BLOCK_{UN}BIND (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_setup_simple() (Ivan Vecera) [1737890]
- [net] openvswitch: free vport unless register_netdevice() succeeds (Stefano Brivio) [1765580]
- [net] openvswitch: Clear the L4 portion of the key for "later" fragments. (Stefano Brivio) [1765580]
- [net] openvswitch: Properly set L4 keys on "later" IP fragments (Stefano Brivio) [1765580]
- [net] openvswitch: Print error when ovs_execute_actions() fails (Stefano Brivio) [1765580]
- [net] openvswitch: do not free vport if register_netdevice() is failed. (Stefano Brivio) [1765580]
- [net] xfrm: policy: remove pcpu policy cache (Xin Long) [1743519]
- [net] netem: correct the parent's backlog when corrupted packet was dropped (Davide Caratti) [1764553]
- [net] netem: fix error path for corrupted GSO frames (Davide Caratti) [1764553]
- [net] avoid potential infinite loop in tc_ctl_action() (Davide Caratti) [1764553]
- [net] act_mirred: Fix mirred_init_module error handling (Davide Caratti) [1764553]
- [net] sch_dsmark: fix potential NULL deref in dsmark_init() (Davide Caratti) [1764553]
- [net] sch_cbq: validate TCA_CBQ_WRROPT to avoid crash (Davide Caratti) [1764553]
- [net] sched: sch_sfb: don't call qdisc_put() while holding tree lock (Davide Caratti) [1764553]
- [net] sched: multiq: don't call qdisc_put() while holding tree lock (Davide Caratti) [1764553]
- [net] sched: sch_htb: don't call qdisc_put() while holding tree lock (Davide Caratti) [1764553]
- [net] sched: fix possible crash in tcf_action_destroy() (Davide Caratti) [1764553]
- [net] sch_netem: fix a divide by zero in tabledist() (Davide Caratti) [1764553]
- [net] sched: act_sample: don't push mac header on ip6gre ingress (Davide Caratti) [1764553]
- [net] net_sched: let qdisc_put() accept NULL pointer (Davide Caratti) [1764553]
- [net] tcp: adjust rto_base in retransmits_timed_out() (Marcelo Leitner) [1756775]
- [net] tcp: better handle TCP_USER_TIMEOUT in SYN_SENT state (Marcelo Leitner) [1756775]
- [include] netlink: use 48 byte ctx instead of 6 signed longs for callback (Petr Oros) [1751273]
- [net] rtnetlink: skip metrics loop for dst_default_metrics (Petr Oros) [1751273]
- [include] netlink: Add field to skip in-kernel notifications (Petr Oros) [1751273]
- [include] netlink: Document all fields of 'struct nl_info' (Petr Oros) [1751273]
- [net] ipoib: show VF broadcast address (Petr Oros) [1751273]
- [net] remove empty netlink_tap_exit_net (Petr Oros) [1751273]
- [net] netlink: make netlink_walk_start() void return type (Petr Oros) [1751273]
- [include] net: nexthop uapi (Petr Oros) [1751273]
- [net] Treat sock->sk_drops as an unsigned int when printing (Petr Oros) [1751273]
- [net] fix two coding style issues (Petr Oros) [1751273]
- [net] ipset: drop ipset_nest_start() and ipset_nest_end() (Petr Oros) [1751273]
- [net] netlink: make nla_nest_start() add NLA_F_NESTED flag (Petr Oros) [1751273]
- [net] netfilter: nf_tables: fix a missing check of nla_put_failure (Petr Oros) [1751273]
- [net] ncsi: fix a missing check for nla_nest_start (Petr Oros) [1751273]
- [net] genetlink: use idr_alloc_cyclic for family->id assignment (Petr Oros) [1751273]
- [net] netlink: Check address length before reading groups field (Petr Oros) [1751273]
- [net] core: Fix rtnetlink kernel-doc headers (Petr Oros) [1751273]
- [net] rhashtable: Remove obsolete rhashtable_walk_init function (Petr Oros) [1751273]
- [net] netfilter: nf_tables: use rhashtable_walk_enter instead of rhashtable_walk_init (Petr Oros) [1751273]
- [net] netlink: reduce NLA_POLICY_NESTED{, _ARRAY} arguments (Petr Oros) [1751273]
- [net] netlink: rename NETLINK_DUMP_STRICT_CHK -> NETLINK_GET_STRICT_CHK (Petr Oros) [1751273]
- [include] netlink: replace __NLA_ENSURE implementation (Petr Oros) [1751273]
- [include] netlink: fix typo in nla_parse_nested() comment (Petr Oros) [1751273]
- [net] netlink: remove hash::nelems check in netlink_insert (Petr Oros) [1751273]
- [net] netlink: Make groups check less stupid in netlink_bind() (Petr Oros) [1751273]
- [include] genetlink: constify genl_err_attr() argument (Petr Oros) [1751273]
- [net] netlink: do not store start function in netlink_cb (Petr Oros) [1751273]
- [include] linux: Add skb_frag_t page_offset accessors (Petr Oros) [1757515]
- [include] net: add missing documentation in linux/skbuff.h (Petr Oros) [1757515]
- [net] l2tp: Fix possible NULL pointer dereference (Stefano Brivio) [1764185]
- [net] l2ip: fix possible use-after-free (Stefano Brivio) [1764185]
- [net] l2tp: use rcu_dereference_sk_user_data() in l2tp_udp_encap_recv() (Stefano Brivio) [1764185]
- [net] l2tp: fix infoleak in l2tp_ip6_recvmsg() (Stefano Brivio) [1764185]
- [net] l2tp: copy 4 more bytes to linear part if necessary (Stefano Brivio) [1764185]
- [net] l2tp: fix reading optional fields of L2TPv3 (Stefano Brivio) [1764185]
- [net] l2tp: remove ->recv_payload_hook (Stefano Brivio) [1764185]
- [net] l2tp: don't export l2tp_session_queue_purge() (Stefano Brivio) [1764185]
- [net] l2tp: remove .show from struct l2tp_tunnel (Stefano Brivio) [1764185]
- [netdrv] vxlan: do not destroy fdb if register_netdevice() is failed (Stefano Brivio) [1763793]
- [net] ip6erspan: remove the incorrect mtu limit for ip6erspan (Stefano Brivio) [1763286]
- [net] ipv6: Handle missing host route in __ipv6_ifa_notify (Stefano Brivio) [1763286]
- [net] ipv6: drop incoming packets having a v4mapped source address (Stefano Brivio) [1763286]
- [net] ip6_gre: fix a dst leak in ip6erspan_tunnel_xmit (Stefano Brivio) [1763286]
- [net] mld: fix memory leak in mld_del_delrec() (Stefano Brivio) [1763286]
- [net] ipv6: rt6_check should return NULL if 'from' is NULL (Stefano Brivio) [1763286]
- [net] ipv6_sockglue: Fix a missing-check bug in ip6_ra_control() (Stefano Brivio) [1763286]
- [net] ipv6_gre: Fix GRO to work on IPv6 over GRE tap (Stefano Brivio) [1763286]
- [net] ipv4: Return -ENETUNREACH if we can't create route but saddr is valid (Stefano Brivio) [1686686]
- [net] netfilter: nft_connlimit: disable bh on garbage collection (Florian Westphal) [1762844]
- [net] netfilter: ebtables: Fix argument order to ADD_COUNTER (Florian Westphal) [1762844]
- [net] netfilter: ebtables: CONFIG_COMPAT: reject trailing data after last rule (Florian Westphal) [1762844]
- [net] netfilter: ebtables: CONFIG_COMPAT: drop a bogus WARN_ON (Florian Westphal) [1762844]
- [net] netfilter: bridge: set skb transport_header before entering NF_INET_PRE_ROUTING (Florian Westphal) [1762844]
- [net] netfilter: ebtables: also count base chain policies (Florian Westphal) [1762844]
- [net] netfilter: ebtables: compat: un-break 32bit setsockopt when no rules are present (Florian Westphal) [1762844]
- [net] sctp: change sctp_prot .no_autobind with true (Xin Long) [1762625]
- [net] sctp: destroy bucket if failed to bind addr (Xin Long) [1762625]
- [net] sctp: remove redundant assignment when call sctp_get_port_local (Xin Long) [1762625]
- [net] sctp: change return type of sctp_get_port_local (Xin Long) [1762625]
- [net] sctp: Fix the link time qualifier of 'sctp_ctrlsock_exit()' (Xin Long) [1762625]
- [net] sctp: fix the missing put_user when dumping transport thresholds (Xin Long) [1762625]
- [net] sctp: use transport pf_retrans in sctp_do_8_2_transport_strike (Xin Long) [1762625]
- [net] sctp: allow users to set ep ecn flag by sockopt (Xin Long) [1762625]
- [net] sctp: allow users to set netns ecn flag with sysctl (Xin Long) [1762625]
- [net] sctp: make ecn flag per netns and endpoint (Xin Long) [1762625]
- [net] sctp: remove net sctp.x_enable working as a global switch (Xin Long) [1762625]
- [net] sctp: add SCTP_AUTH_SUPPORTED sockopt (Xin Long) [1762625]
- [net] sctp: add sctp_auth_init and sctp_auth_free (Xin Long) [1762625]
- [net] sctp: use ep and asoc auth_enable properly (Xin Long) [1762625]
- [net] sctp: add SCTP_ASCONF_SUPPORTED sockopt (Xin Long) [1762625]
- [net] sctp: check asoc peer.asconf_capable before processing asconf (Xin Long) [1762625]
- [net] sctp: not set peer.asconf_capable in sctp_association_init (Xin Long) [1762625]
- [net] sctp: add asconf_enable in struct sctp_endpoint (Xin Long) [1762625]
- [net] sctp: fix memleak in sctp_send_reset_streams (Xin Long) [1762625]
- [net] sctp: fix the transport error_count check (Xin Long) [1762625]
- [net] sched: fix corrupted L2 header with MPLS 'push' and 'pop' actions (Ivan Vecera) [1737820]
- [net] avoid errors when trying to pop MLPS header on non-MPLS packets (Ivan Vecera) [1737820]
- [net] netfilter: connlabels: prefer static lock initialiser (Ivan Vecera) [1737820]
- [net] sched: include mpls actions in hardware intermediate representation (Ivan Vecera) [1737820]
- [net] sched: Make NET_ACT_CT depends on NF_NAT (Ivan Vecera) [1737820]
- [tools] tc-tests: Add tc action ct tests (Ivan Vecera) [1737820]
- [net] sched: cls_flower: Add matching on conntrack info (Ivan Vecera) [1737820]
- [net] flow_dissector: add connection tracking dissection (Ivan Vecera) [1737820]
- [net] sched: Introduce action ct (Ivan Vecera) [1737820]
- [tools] tc-tests: actions: add MPLS tests (Ivan Vecera) [1737820]
- [net] sched: add mpls manipulation actions to TC (Ivan Vecera) [1737820]
- [net] core: add MPLS update core helper and use in OvS (Ivan Vecera) [1737820]
- [net] core: move pop MPLS functionality from OvS to core helper (Ivan Vecera) [1737820]
- [net] core: move push MPLS functionality from OvS to core helper (Ivan Vecera) [1737820]
- [net] sched: Introduce act_ctinfo action (Ivan Vecera) [1737820]
- [netdrv] mlx5e: Allow dissector meta key in tc flower (Ivan Vecera) [1762861]
- [tools] selftests: tc: add ingress device matching support (Ivan Vecera) [1762861]
- [net] flow_offload: implement support for meta key (Ivan Vecera) [1762861]
- [net] sched: cls_flower: use flow_dissector for ingress ifindex (Ivan Vecera) [1762861]
- [net] flow_dissector: add support for ingress ifindex dissection (Ivan Vecera) [1762861]
- [net] udp: only do GSO if # of segs > 1 (Guillaume Nault) [1762357]
- [net] udp: fix gso_segs calculations (Guillaume Nault) [1762357]
- [tools] selftests: rtnetlink: add small test case with 'promote_secondaries' enabled (Petr Oros) [1759177]
- [net] ipv4: fix infinite loop on secondary addr promotion (Petr Oros) [1759177]
- [tools] selftests: rtnetlink: add addresses with fixed life time (Petr Oros) [1759177]
- [net] ipv4: remove erroneous advancement of list pointer (Petr Oros) [1759177]
- [net] ipv4: fix rcu lockdep splat due to wrong annotation (Petr Oros) [1759177]
- [net] ipv4: provide __rcu annotation for ifa_list (Petr Oros) [1759177]
- [drivers] use in_dev_for_each_ifa_rtnl/rcu (Petr Oros) [1759177]
- [net] use new in_dev_ifa iterators (Petr Oros) [1759177]
- [net] netfilter: use in_dev_for_each_ifa_rcu (Petr Oros) [1759177]
- [net] devinet: use in_dev_for_each_ifa_rcu in more places (Petr Oros) [1759177]
- [net] inetdevice: provide replacement iterators for in_ifaddr walk (Petr Oros) [1759177]
- [fs] afs: do not send list of client addresses (Petr Oros) [1759177]
- [net] sctp: add SCTP_SEND_FAILED_EVENT event (Xin Long) [1751129]
- [net] sctp: add SCTP_ADDR_MADE_PRIM event (Xin Long) [1751129]
- [net] sctp: add SCTP_ADDR_REMOVED event (Xin Long) [1751129]
- [net] sctp: add SCTP_ADDR_ADDED event (Xin Long) [1751129]
- [netdrv] team: call RCU read lock when walking the port_list (Hangbin Liu) [1724896]
- [net] packet: fix race in tpacket_snd() (Davide Caratti) [1760276]
- [net] packet: fix memory leak in packet_set_ring() (Davide Caratti) [1760276]
- [net] packet: unconditionally free po->rollover (Davide Caratti) [1760276]
- [net] llc: fix skb leak in llc_build_and_send_ui_pkt() (Davide Caratti) [1760276]
- [net] af_key: fix leaks in key_pol_get_resp and dump_sp. (Davide Caratti) [1760276]
- [net] packet: in recvmsg msg_name return at least sizeof sockaddr_ll (Davide Caratti) [1760276]
- [net] packet: Set __GFP_NOWARN upon allocation in alloc_pg_vec (Davide Caratti) [1760276]
- [net] packet: fix 4gb buffer limit due to overflow check (Davide Caratti) [1760276]
- [net] llc: do not use sk_eat_skb() (Davide Caratti) [1760276]
- [fs] proc: fix /proc/net/* after setns(2) (Davide Caratti) [1760276]
- [net] Unpublish sk from sk_reuseport_cb before call_rcu (Paolo Abeni) [1760409]
- [net] Fix null de-reference of device refcount (Paolo Abeni) [1760409]
- [include] ipv4: Define __ipv4_neigh_lookup_noref when CONFIG_INET is disabled (Paolo Abeni) [1760409]
- [net] neighbor: Call __ipv4_neigh_lookup_noref in neigh_xmit (Paolo Abeni) [1760409]
- [net] ebpf: record usage of flow dissector (Jiri Benc) [1749812]
- [tools] selftests/bpf: More compatible nc options in test_lwt_ip_encap (Jiri Benc) [1749812]
- [tools] selftests/bpf: Set rp_filter in test_flow_dissector (Jiri Benc) [1749812]
- [net] bpf: lwtunnel: fix reroute supplying invalid dst (Jiri Benc) [1749812]
- [kernel] rh_features: convert to atomic allocation (Jiri Benc) [1749812]
- [net] xsk: lock the control mutex in sock_diag interface (Jiri Benc) [1749812]
- [documentation] networking: fix af_xdp.rst Sphinx warnings (Jiri Benc) [1749812]
- [documentation] flow_dissector: rst'ify documentation (Jiri Benc) [1749812]
- [documentation] flow_dissector: document BPF flow dissector environment (Jiri Benc) [1749812]
- [net] xsk: fix umem memory leak on cleanup (Jiri Benc) [1749812]
- [net] xsk: fix to reject invalid options in Tx descriptor (Jiri Benc) [1749812]
- [net] xsk: fix to reject invalid flags in xsk_bind (Jiri Benc) [1749812]
- [net] xsk: fix potential crash in xsk_diag_put_umem() (Jiri Benc) [1749812]
- [net] bpfilter: re-add header search paths to tools include to fix build error (Jiri Benc) [1749812]
- [documentation] xsk: add FAQ to facilitate for first time users (Jiri Benc) [1749812]
- [net] bpf/test_run: fix unkillable BPF_PROG_TEST_RUN for flow dissector (Jiri Benc) [1749812]
- [tools] sync uapi/linux/if_link.h header (Jiri Benc) [1749812]
- [net] xdp: allow generic and driver XDP on one interface (Jiri Benc) [1749812]
- [net] xdp: Provide extack messages when prog attachment failed (Jiri Benc) [1749812]
- [net] bpfilter: remove extra header search paths for bpfilter_umh (Jiri Benc) [1749812]
- [include] bpf: fix missing prototype warnings (Jiri Benc) [1749812]
- [net] xsk: add sock_diag interface for AF_XDP (Jiri Benc) [1749812]
- [net] xsk: add id to umem (Jiri Benc) [1749812]
- [net] xsk: track AF_XDP sockets on a per-netns list (Jiri Benc) [1749812]
- [include] redhat: rh_kabi: introduce RH_KABI_EXTEND_WITH_SIZE (Jiri Benc) [1749812]
- [net] tcp: Avoid TCP syncookie rejected by SO_REUSEPORT socket (Jiri Benc) [1749812]
- [net] tcp: use monotonic timestamps for PAWS (Jiri Benc) [1749812]
- [net] tcp: remove one indentation level in tcp_create_openreq_child (Jiri Benc) [1749812]
- [netdrv] ppp: Fix memory leak in ppp_write (Guillaume Nault) [1759312]
- [netdrv] ppp: deflate: Fix possible crash in deflate_init (Guillaume Nault) [1759312]
- [netdrv] pppoe: fix reception of frames with no mac header (Guillaume Nault) [1759312]
- [net] tcp_bbr: fix quantization code to not raise cwnd if not probing bandwidth (Florian Westphal) [1759208]
- [net] tcp_bbr: refactor bbr_target_cwnd() for general inflight provisioning (Florian Westphal) [1759208]
- [net] tcp_bbr: centralize code to set gains (Florian Westphal) [1759208]
- [net] tcp_bbr: apply PROBE_RTT cwnd cap even if acked==0 (Florian Westphal) [1759208]
- [net] tcp_bbr: in restart from idle, see if we should exit PROBE_RTT (Florian Westphal) [1759208]
- [net] tcp_bbr: add bbr_check_probe_rtt_done() helper (Florian Westphal) [1759208]
- [net] xfrm/xfrm_policy: fix dst dev null pointer dereference in collect_md mode (Hangbin Liu) [1734589]
- [tools] selftests: forwarding: gre_multipath: Fix flower filters (Hangbin Liu) [1756832]
- [tools] selftests: forwarding: gre_multipath: Enable IPv4 forwarding (Hangbin Liu) [1756832]
- [tools] set sysctl bc_forwarding properly in router_broadcast.sh (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: enable forwarding before ipv4 from/iif test (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: use pre-defined DEV_ADDR (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: fix local IPv4 address typo (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: print the result and return 1 if any tests failed (Hangbin Liu) [1756832]
- [tools] selftests: fib_tests: Fix 'Command line is not complete' errors (Hangbin Liu) [1756832]
- [tools] selftests: Update fib_tests to handle missing ping6 (Hangbin Liu) [1756832]
- [tools] fib_tests: Add tests for metrics on routes (Hangbin Liu) [1756832]
- [tools] selftests: udpgso_bench.sh explicitly requires bash (Hangbin Liu) [1756832]
- [tools] selftests/net: add tls to .gitignore (Hangbin Liu) [1756832]
- [net] ipv4: avoid mixed n_redirects and rate_tokens usage (Paolo Abeni) [1753092]
- [lib] netlink: set bad attribute also on maxtype check (Petr Oros) [1757776]
- [lib] netlink: add validation of NLA_F_NESTED flag (Petr Oros) [1757776]
- [net] ila: Fix rhashtable walker list corruption (Petr Oros) [1757776]
- [lib] ila: make lockdep happy again (Petr Oros) [1757776]
- [net] genetlink: do not validate dump requests if there is no policy (Petr Oros) [1757776]
- [include] netlink: Fix nlmsg_parse as a wrapper for strict message parsing (Petr Oros) [1757776]
- [net] tipc: fix missing indentation in source code (Petr Oros) [1757776]
- [net] genetlink: optionally validate strictly/dumps (Petr Oros) [1757776]
- [lib] netlink: add strict parsing for future attributes (Petr Oros) [1757776]
- [include] netlink: re-add parse/validate functions in strict mode (Petr Oros) [1757776]
- [net] netlink: make validation more configurable for future strictness (Petr Oros) [1757776]
- [lib] netlink: add NLA_MIN_LEN (Petr Oros) [1757776]
- [net] genetlink: make policy common to family (Petr Oros) [1757776]
- [net] ila: Flush netlink command to clear xlat table (Petr Oros) [1757776]
- [net] ila: Create main ila source file (Petr Oros) [1757776]
- [net] ila: Call library function alloc_bucket_locks (Petr Oros) [1757776]
- [net] ila: Fix use of rhashtable walk in ila_xlat.c (Petr Oros) [1757776]
- [net] rtnetlink: fix rtnl_valid_stats_req() nlmsg_len check (Petr Oros) [1757750]
- [net] mpls: netconf: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] mpls: route: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: route: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: addrlabel: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: netconf: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: addr: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv4: ipmr: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv4: route: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv4: netconf: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] namespace: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] rtnetlink: ifinfo: perform strict checks also for doit handler (Petr Oros) [1757750]
- [net] rtnetlink: stats: reject requests for unknown stats (Petr Oros) [1757750]
- [net] rtnetlink: stats: validate attributes in get as well as dumps (Petr Oros) [1757750]
- [net] netlink: add helper to retrieve NETLINK_F_STRICT_CHK (Petr Oros) [1757750]
- [include] linux/netlink.h: drop unnecessary extern prefix (Petr Oros) [1757750]
- [net] rtnetlink: avoid frame size warning in rtnl_newlink() (Petr Oros) [1757750]
- [net] rtnetlink: remove a level of indentation in rtnl_newlink() (Petr Oros) [1757750]
- [net] rtnetlink: Add more extack messages to rtnl_newlink (Petr Oros) [1757750]
- [net] netfilter: nf_tables: allow lookups in dynamic sets (Florian Westphal) [1759074]
- [net] netfilter: nf_tables: check the result of dereferencing base_chain->stats (Florian Westphal) [1759074]
- [net] revert "netfilter: nft_hash: add map lookups for hashing operations" (Florian Westphal) [1759074]
- [net] netfilter: nf_tables: don't prevent event handler from device cleanup on netns exit (Florian Westphal) [1759074]
- [net] netfilter: nft_ct: enable conntrack for helpers (Florian Westphal) [1759074]
- [net] netfilter: conntrack: always store window size un-scaled (Florian Westphal) [1758668]
- [net] netfilter: synproxy: fix rst sequence number mismatch (Florian Westphal) [1758668]
- [net] netfilter: synproxy: fix erroneous tcp mss option (Florian Westphal) [1758668]
- [net] netfilter: nfnetlink: avoid deadlock due to synchronous request_module (Florian Westphal) [1758668]
- [net] netfilter: nf_queue: fix reinject verdict handling (Florian Westphal) [1758668]
- [net] netfilter: conntrack: Use consistent ct id hash calculation (Florian Westphal) [1758668]
- [net] netfilter: ctnetlink: don't use conntrack/expect object addresses as id (Florian Westphal) [1758668]
- [net] netfilter: bridge: Don't sabotage nf_hook calls for an l3mdev slave (Florian Westphal) [1758668]
- [net] netfilter: avoid using skb->nf_bridge directly (Florian Westphal) [1758668]
- [net] netfilter: nat: can't use dst_hold on noref dst (Florian Westphal) [1758668]
- [net] netfilter: bridge: Don't sabotage nf_hook calls from an l3mdev (Florian Westphal) [1758668]
- [net] netfilter: conntrack: fix removal of conntrack entries when l4tracker is removed (Florian Westphal) [1758668]
- [net] netfilter: xt_hashlimit: fix a possible memory leak in htable_create() (Florian Westphal) [1758668]
- [net] netfilter: xt_TEE: add missing code to get interface index in checkentry. (Florian Westphal) [1758668]
- [net] netfilter: xt_TEE: fix wrong interface selection (Florian Westphal) [1758668]
- [net] netfilter: xtables: avoid BUG_ON (Florian Westphal) [1758668]
- [net] netfilter: nat: limit port clash resolution attempts (Florian Westphal) [1758646]
- [net] netfilter: nat: remove l4 protocol port rovers (Florian Westphal) [1758646]
- [net] neighbour: remove stray semicolon (Ivan Vecera) [1757459]
- [net] neighbor: Initialize protocol when new pneigh_entry are created (Ivan Vecera) [1757459]
- [net] neighbour: register rtnl doit handler (Ivan Vecera) [1757459]
- [net] neighbor: Add protocol attribute (Ivan Vecera) [1757459]
- [net] neighbor: Add extack messages for add and delete commands (Ivan Vecera) [1757459]
- [net] rtnetlink: address is mandatory for rtnl_fdb_get (Ivan Vecera) [1757105]
- [netdrv] vxlan: support for ndo_fdb_get (Ivan Vecera) [1757105]
- [net] rtnetlink: support for fdb get (Ivan Vecera) [1757105]
- [net] bridge: support for ndo_fdb_get (Ivan Vecera) [1757105]
- [net] ipmr: remove hard code cache_resolve_queue_len limit (Hangbin Liu) [1631022]
- [net] ipv6/addrconf: allow adding multicast addr if IFA_F_MCAUTOJOIN is set (Hangbin Liu) [1740961]
- [net] xfrm interface: fix management of phydev (Xin Long) [1727240]
- [net] xfrm interface: fix list corruption for x-netns (Xin Long) [1727240]
- [net] xfrm interface: ifname may be wrong in logs (Xin Long) [1727240]
- [net] xfrm interface: avoid corruption on changelink (Xin Long) [1727240]
- [net] netlink: add validation function to policy (Ivan Vecera) [1753333]
- [net] netlink: add attribute range validation to policy (Ivan Vecera) [1753333]
- [net] sched: police: allow accessing police->params with rtnl (Ivan Vecera) [1731416]
- [net] sched: remove block pointer from common offload structure (Ivan Vecera) [1731416]
- [net] nfp: flower: add qos offload install and remove functionality. (Ivan Vecera) [1731416]
- [net] nfp: flower: add qos offload framework (Ivan Vecera) [1731416]
- [net] sched: add block pointer to tc_cls_common_offload structure (Ivan Vecera) [1731416]
- [net] sched: allow stats updates from offloaded police actions (Ivan Vecera) [1731416]
- [net] sched: extend matchall offload for hardware statistics (Ivan Vecera) [1731416]
- [net] sched: add police action to the hardware intermediate representation (Ivan Vecera) [1731416]
- [net] sched: move police action structures to header (Ivan Vecera) [1731416]
- [net] sched: remove unused functions for matchall offload (Ivan Vecera) [1731416]
- [net] dsa: use intermediate representation for matchall offload (Ivan Vecera) [1731416]
- [netdrv] mlxsw: use intermediate representation for matchall offload (Ivan Vecera) [1731416]
- [net] tipc: disallow enabling of loopback interface bearer (Jon Maloy) [1717305]
- [net] tipc: add NULL pointer check before calling kfree_rcu (Jon Maloy) [1747392]
- [net] xsk: Return the whole xdp_desc from xsk_umem_consume_tx (Ivan Vecera) [1748497]
- [net] devlink: add warning for ndo_get_port_parent_id set when not needed (Petr Oros) [1737133]
- [net] devlink: introduce devlink_compat_switch_id_get() helper (Petr Oros) [1737133]
- [net] devlink: extend port attrs for switch ID (Petr Oros) [1737133]
- [net] devlink: convert devlink_port_attrs bools to bits (Petr Oros) [1737133]
- [net] devlink: add warning for ndo_get_phys_port_name set when not needed (Petr Oros) [1737133]
- [netdrv] nfp: move devlink port type set after netdev registration (Petr Oros) [1737133]
- [netdrv] dsa: move devlink_port_attrs_set() call before register (Petr Oros) [1737133]
- [netdrv] mlxsw: Move devlink_port_attrs_set() call before register (Petr Oros) [1737133]
- [netdrv] bnxt: set devlink port type after registration (Petr Oros) [1737133]
- [netdrv] bnxt: call devlink_port_type_eth_set() before port register (Petr Oros) [1737133]
- [netdrv] bnxt: set devlink port attrs properly (Petr Oros) [1737133]
- [netdrv] dsa: add missing net/devlink.h include (Petr Oros) [1737133]
- [netdrv] bnxt: add missing net/devlink.h include (Petr Oros) [1737133]
- [netdrv] revert "devlink: Add a generic wake_on_lan port parameter" (Petr Oros) [1737133]
- [netdrv] bnxt_en: Add bnxt_en initial port params table and register it (Petr Oros) [1737133]
- [netdrv] mlxsw: spectrum: Assume CONFIG_NET_DEVLINK is always enabled (Petr Oros) [1737527]
- [netdrv] netdevsim: assume CONFIG_NET_DEVLINK is always enabled (Petr Oros) [1737527]
- [net] devlink: introduce devlink_compat_phys_port_name_get() (Petr Oros) [1737527]
- [net] replace ndo_get_devlink with ndo_get_devlink_port (Petr Oros) [1737527]
- [net] devlink: select NET_DEVLINK from drivers (Petr Oros) [1737527]
- [net] devlink: add port type spinlock (Petr Oros) [1737527]
- [net] devlink: warn on setting type on unregistered port (Petr Oros) [1737527]
- [net] devlink: disallow port_attrs_set() to be called before register (Petr Oros) [1737527]
- [net] devlink: don't pass return value of __devlink_port_type_set() (Petr Oros) [1737527]
- [net] devlink: don't take devlink_mutex for devlink_compat_* (Petr Oros) [1737527]
- [net] devlink: add couple of missing mutex_destroy() calls (Petr Oros) [1737527]
- [net] devlink: fix kdoc (Petr Oros) [1737527]
- [net] devlink: require non-NULL ops for devlink instances (Petr Oros) [1737527]
- [net] devlink: hold a reference to the netdevice around ethtool compat (Petr Oros) [1737527]
- [net] devlink: create a special NDO for getting the devlink instance (Petr Oros) [1737527]
- [net] devlink: Add WARN_ON to catch errors of not cleaning devlink objects (Petr Oros) [1737527]
- [netdrv] s390/qeth: fix xmit_more support (Ivan Vecera) [1734516]
- [netdrv] revert "[netdrv] gve: account for lack of netdev_xmit_more() definition (RHEL-only)" (Ivan Vecera) [1734516]
- [netdrv] net/mlx5e: Fix wrong xmit_more application (Ivan Vecera) [1734516]
- [include] net: use correct this_cpu primitive in dev_recursion_level (Ivan Vecera) [1734516]
- [netdrv] drivers: net: aurora: use netdev_xmit_more helper (Ivan Vecera) [1734516]
- [netdrv] drivers: net: sfc: use netdev_xmit_more helper (Ivan Vecera) [1734516]
- [netdrv] drivers: mellanox: use netdev_xmit_more() helper (Ivan Vecera) [1734516]
- [netdrv] net: move skb->xmit_more hint to softnet data (Ivan Vecera) [1734516]
- [net] place xmit recursion in softnet data (Ivan Vecera) [1734516]

* Fri Nov 15 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-151.el8]
- [netdrv] net: ena: clean up indentation issue (John Linville) [1770979]
- [netdrv] net: ena: Select DIMLIB for ENA_ETHERNET (John Linville) [1770979]
- [netdrv] net: ena: fix incorrect update of intr_delay_resolution (John Linville) [1770979]
- [netdrv] net: ena: fix retrieval of nonadaptive interrupt moderation intervals (John Linville) [1770979]
- [netdrv] net: ena: fix update of interrupt moderation register (John Linville) [1770979]
- [netdrv] net: ena: remove all old adaptive rx interrupt moderation code from ena_com (John Linville) [1770979]
- [netdrv] net: ena: remove ena_restore_ethtool_params() and relevant fields (John Linville) [1770979]
- [netdrv] net: ena: remove old adaptive interrupt moderation code from ena_netdev (John Linville) [1770979]
- [netdrv] net: ena: remove code duplication in ena_com_update_nonadaptive_moderation_interval _*() (John Linville) [1770979]
- [netdrv] net: ena: enable the interrupt_moderation in driver_supported_features (John Linville) [1770979]
- [netdrv] net: ena: reimplement set/get_coalesce() (John Linville) [1770979]
- [netdrv] net: ena: switch to dim algorithm for rx adaptive interrupt moderation (John Linville) [1770979]
- [netdrv] net: ena: add intr_moder_rx_interval to struct ena_com_dev and use it (John Linville) [1770979]

* Thu Nov 14 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-150.el8]
- [fs] autofs: add ignore mount option (Ian Kent) [1743441]
- [fs] autofs: improve ioctl sbi checks (Ian Kent) [1672133]
- [crypto] crypto: ccp - Retry SEV INIT command in case of integrity check failure. (Gary Hook) [1767627]
- [crypto] crypto: ccp - Verify access to device registers before initializing (Gary Hook) [1756867]
- [crypto] crypto: ccp - Change a message to reflect status instead of failure (Gary Hook) [1756867]
- [netdrv] ixgbevf: Bump version for RHEL 8.2.0 (Ken Cox) [1721701]
- [netdrv] ixgbevf: Fix secpath usage for IPsec Tx offload (Ken Cox) [1721701]
- [netdrv] ixgbevf: make array api static const, makes object smaller (Ken Cox) [1721701]
- [netdrv] ixgbevf: Link lost in VM on ixgbevf when restoring from freeze or suspend (Ken Cox) [1721701]
- [netdrv] ixgbevf: fix a compilation error of skb_frag_t (Ken Cox) [1721701]
- [netdrv] net: Use skb accessors in network drivers (Ken Cox) [1721701]
- [netdrv] ixgbevf: Use cached link state instead of re-reading the value for ethtool (Ken Cox) [1721701]
- [netdrv] ixgbevf: fix possible divide by zero in ixgbevf_update_itr (Ken Cox) [1721701]
- [netdrv] ixgbevf: fix a missing check of ixgbevf_write_msg_read_ack (Ken Cox) [1721701]
- [infiniband] IB/hfi1: Use a common pad buffer for 9B and 16B packets (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Avoid excessive retry for TID RDMA READ request (Honggang Li) [1719676]
- [infiniband] RDMA/hfi1: Prevent memory leak in sdma_init (Honggang Li) [1719676]
- [infiniband] IB/hfi1: remove unlikely() from IS_ERR*() condition (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Define variables as unsigned long to fix KASAN warning (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1, qib}: Add a counter for credit waits (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add traces for TID RDMA READ (Honggang Li) [1719676]
- [infiniband] infiniband: hfi1: fix memory leaks (Honggang Li) [1719676]
- [infiniband] infiniband: hfi1: fix a memory leak bug (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Drop stale TID RDMA packets that cause TIDErr (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add additional checks when handling TID RDMA WRITE DATA packet (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add additional checks when handling TID RDMA READ RESP packet (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Unsafe PSN checking for TID RDMA READ Resp packet (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Drop stale TID RDMA packets (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Fix Spectre v1 vulnerability (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Remove unused define (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Do not update hcrc for a KDETH packet during fault injection (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Drop all TID RDMA READ RESP packets after r_next_psn (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Field not zero-ed when allocating TID flow memory (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Unreserve a flushed OPFN request (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Check for error on call to alloc_rsm_map_table (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fix variable shadowing issue in rvt_create_cq (Honggang Li) [1719676]
- [infiniband] RDMA/rvt: Do not use a kernel header in the ABI (Honggang Li) [1719676]
- [infiniband] IB/hfi1: No need to use try_module_get for debugfs (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Add trace for map_mr_sg (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Enhance trace information for FRWR debug (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add missing INVALIDATE opcodes for trace (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Reduce excessive aspm inlines (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1, qib}: Add helpers to hide SWQE WR details (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1, qib}: Remove AH refcount for UD QPs (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Set QP allowed opcodes after QP allocation (Honggang Li) [1719676]
- [infiniband] IB/{hfi1, qib, rdmavt}: Put qp in error state when cq is full (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fracture single lock used for posting and processing RWQEs (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Move receive work queue struct into uapi directory (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Move rvt_cq_wc struct into uapi directory (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Add new completion inline (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, qib, hfi1}: Convert to new completion API (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Spelling s/statisfied/satisfied/ (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Handle port down properly in pio (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Handle wakeup of orphaned QPs for pio (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Wakeup QPs orphaned on wait list after flush (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Use aborts to trigger RC throttling (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Create inline to get extended headers (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Silence txreq allocation warnings (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Avoid hardlockup with flushlist_lock (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Correct tid qp rcd to match verbs context (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Close PSM sdma_progress sleep window (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Validate fault injection opcode user input (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Use struct_size() helper (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Use struct_size() helper (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Validate page aligned for a given virtual address (Honggang Li) [1719676]
- [infiniband] IB/{qib, hfi1, rdmavt}: Correct ibv_devinfo max_mr value (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Insure freeze_work work_struct is canceled on shutdown (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fix alloc_qpn() WARN_ON() (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Remove set but not used variables 'offset' and 'fspsn' (Honggang Li) [1719676]
- [infiniband] RDMA/rdmavt: Catch use-after-free access of AH structures (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Remove reference to RHF.VCRCErr (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add selected Rcv counters (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, qib, hfi1}: Use new routine to release reference counts (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Use more efficient allowed_ops (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fix ab/ba include issues (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Make opfn.h self sufficient (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1): Miscellaneous comment fixes (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add debugfs to control expansion ROM write protect (Honggang Li) [1719676]
- [infiniband] hfi1: Convert hfi1_unit_table to XArray (Honggang Li) [1719676]
- [infiniband] hfi1: Convert vesw_idr to XArray (Honggang Li) [1719676]
- [infiniband] RDMA/rdmavt: Use correct sizing on buffers holding page DMA addresses (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Fix two format strings (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add running average for adaptive pio (Honggang Li) [1719676]
- [infiniband] mm: replace all open encodings for NUMA_NO_NODE (Honggang Li) [1719676]
- [infiniband] drivers/IB,hfi1: do not se mmap_sem (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Suppress a compiler warning (Honggang Li) [1719676]
- [scsi] qla2xxx: Update driver version (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: don't use zero for FC4_PRIORITY_NVME (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: initialize fc4_type_priority (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: fix NPIV tear down process (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Remove an include directive (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix device connect issues in P2P configuration (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Improve logging for scan thread (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Capture FW dump on MPI heartbeat stop event (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Check for MB timeout while capturing ISP27/28xx FW dump (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Set remove flag for all VP (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Add error handling for PLOGI ELS passthrough (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Dual FCP-NVMe target port support (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix a dma_pool_free() call (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix memory leak when sending I/O fails (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix driver unload hang (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix SRB leak on switch command timeout (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix double scsi_done for abort path (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Do command completion on abort timeout (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Reduce the number of forward declarations (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: fixup incorrect usage of host_byte (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix partial flash write of MBI (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Remove WARN_ON_ONCE in qla2x00_status_cont_entry() (Himanshu Madhani) [1763248]
- [scsi] qla2xxx: Fix conflict_port check for NULL (Himanshu Madhani) [1763248]
- [netdrv] Bump version for RHEL 8.2.0 (Ken Cox) [1721700]
- [netdrv] ixgbe: Fix secpath usage for IPsec TX offload. (Ken Cox) [1721700]
- [netdrv] ixgbe: fix double clean of Tx descriptors with xdp (Ken Cox) [1721700]
- [netdrv] ixgbe: Prevent u8 wrapping of ITR value to something less than 10us (Ken Cox) [1721700]
- [netdrv] ixgbe: use skb_get_queue_mapping in tx path (Ken Cox) [1721700]
- [netdrv] ixgbe: fix memory leaks (Ken Cox) [1721700]
- [netdrv] ixgbe: sync the first fragment unconditionally (Ken Cox) [1721700]
- [netdrv] ixgbe: Use kzfree() rather than its implementation. (Ken Cox) [1721700]
- [netdrv] ixgbe: simplify Rx buffer recycle (Ken Cox) [1721700]
- [netdrv] ixgbe: no need to check return value of debugfs_create functions (Ken Cox) [1721700]
- [netdrv] ixgbe: fix possible deadlock in ixgbe_service_task() (Ken Cox) [1721700]
- [netdrv] net: Use skb accessors in network drivers (Ken Cox) [1721700]
- [netdrv] ixgbe: fix potential u32 overflow on shift (Ken Cox) [1721700]
- [netdrv] ixgbe: Avoid NULL pointer dereference with VF on non-IPsec hw (Ken Cox) [1721700]
- [netdrv] ixgbe: Check DDM existence in transceiver before access (Ken Cox) [1721700]
- [netdrv] ixgbe: implement support for SDP/PPS output on X550 hardware (Ken Cox) [1721700]
- [netdrv] ixgbe: Use LLDP ethertype define ETH_P_LLDP (Ken Cox) [1721700]
- [netdrv] ixgbe: add a kernel documentation comment for ixgbe_ptp_get_ts_config (Ken Cox) [1721700]
- [netdrv] ixgbe: use 'cc' instead of 'hw_cc' for local variable (Ken Cox) [1721700]
- [netdrv] ixgbe: fix PTP SDP pin setup on X540 hardware (Ken Cox) [1721700]
- [netdrv] ixgbe: reduce PTP Tx timestamp timeout to 1 second (Ken Cox) [1721700]
- [netdrv] ixgbe: fix AF_XDP tx packet count (Ken Cox) [1721700]
- [netdrv] ixgbe: fix AF_XDP tx byte count (Ken Cox) [1721700]
- [netdrv] ixgbe: remove umem from adapter (Ken Cox) [1721700]
- [netdrv] ixgbe: add tracking of AF_XDP zero-copy state for each queue pair (Ken Cox) [1721700]
- [netdrv] ixgbe: fix mdio bus registration (Ken Cox) [1721700]
- [netdrv] nfp: bpf: implement jitting of JMP32 (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: support removing dead code (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: support optimizing dead branches (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: save original program length (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: split up the skip flag (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: don't use instruction number for jump target (Pablo Cascon) [1729067]
- [scsi] scsi: target: iscsi: rename some variables to avoid confusion. (Maurizio Lombardi) [1769801]
- [scsi] scsi: target: iscsi: tie the challenge length to the hash digest size (Maurizio Lombardi) [1769801]
- [scsi] scsi: target: iscsi: CHAP: add support for SHA1, SHA256 and SHA3-256 (Maurizio Lombardi) [1769801]
- [scsi] scsi: target: compare full CHAP_A Algorithm strings (Maurizio Lombardi) [1769801]
- [arm64] arm64: topology: Use PPTT to determine if PE is a thread (Jeremy Linton) [1721297]
- [acpi] ACPI/PPTT: Add support for ACPI 6.3 thread flag (Jeremy Linton) [1721297]
- [acpi] ACPI / LPSS: Save/restore LPSS private registers also on Lynxpoint (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [documentation] docs: fix numaperf.rst and add it to the doc tree (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Rename arm_smmu_v3_set_proximity() 'node' local variable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [misc] h8300: pci: Remove local declaration of pcibios_penalize_isa_irq (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [mm] mmc: sdhci-acpi: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [ata] ata: pata_acpi: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [gpu] vga-switcheroo: make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: intel_ips: make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: intel_pmc: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: apple-gmux: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [x86] x86/intel/lpss: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [x86] x86/Kconfig: Select PCI_LOCKLESS_CONFIG if PCI is enabled (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [mfd] mfd: Fix unmet dependency warning for MFD_TPS68470 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] drivers/acpi/scan.c: document why we don't need the device_hotplug_lock (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Fix regression in acpi_device_set_power() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix off-by-one check in iort_dev_find_its_id() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: video: Add new hw_changes_brightness quirk, set it on PB Easynote MZ35 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: blacklist: fix clang warning for unused DMI table (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPICA: Update table load object initialization" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Make acpi_sleep_state_supported() non-static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Remove needless __ghes_check_estatus() calls (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Unexport acpi_device_get_power() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PCI / ACPI: Use cached ACPI device state to get PCI device power state (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190703 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update table load object initialization (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update for object initialization sequence (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: remove legacy module-level code due to deprecation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Namespace: simplify creation of the initial/default namespace (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: intel: Drop double removal of address space handler (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: APD: remove redundant assignment to pointer clk (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Introduce "poweroff" callbacks for ACPI PM domain and LPSS (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Simplify and fix PM domain hibernation callbacks (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PM: ACPI/PCI: Resume all devices during hibernation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PCI: PM/ACPI: Refresh all stale power state data in pci_pm_complete() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PPTT: Add function to return ACPI 6.3 Identical tokens (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PPTT: Modify node flag detection to find last IDENTICAL (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: Introduce concept of a _PR0 dependent device (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Allow transitions to D0 to occur in special cases (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Avoid evaluating _PS3 on transitions from D3hot to D3cold (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi: utils: Cleanup acpi_dev_match_cb (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Make AC and battery drivers available on !X86 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] coresight: acpi: Support for AMBA components (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Clear status of GPEs on first direct enable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: configfs: Resolve objects on host-directed table loads (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: tables: Allow BGRT to be overridden (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / sleep: Switch to use acpi_dev_get_first_match_dev() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [include] gpio: merrifield: Fix build err without CONFIG_ACPI (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: OSL: Make a W=1 kernel-doc warning go away (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / property: Don't limit named child node matching to data nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPIT: Correct LPIT end address for lpit_process() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/irq: Implement helper to create hierachical domains (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] node: Add memory-side caching attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] node: Add heterogenous memory access attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] node: Link memory nodes to their compute nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [documentation] doc/mm: New documentation for memory performance (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Call pm_set_suspend_via_firmware() during hibernation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PCI: PM: Add missing wakeup.flags.valid checks (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix build error when IOMMU_SUPPORT is disabled (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Set enable_for_wake for wakeup GPEs during suspend-to-idle (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190509 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Linux: move ACPI_DEBUG_DEFAULT flag out of ifndef (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: bus: change _ADR representation to 64 bits (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / property: fix handling of data_nodes in acpi_get_next_subnode() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: fix an uninitialized memory_target (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Update acpi_hmat_type enum with ACPI_HMAT_TYPE_PROXIMITY (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: fix memory leaks in hmat_init() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Check ATS capability in root complex nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / DPTF: Use dev_get_drvdata() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: event: replace strcpy() by strscpy() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Use acpi_lpss_* instead of acpi_subsys_* functions for hibernate (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Reject platform device creation on NUMA node mapping failure (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: button: reinitialize button state upon resume (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190405 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Namespace: add check to avoid null pointer dereference (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190329 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: utilities: fix spelling of PCC to platform_comm_channel (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename nameseg length macro/define for clarity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename nameseg compare macro for clarity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename nameseg copy macro for clarity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Print debug messages when enabling GPEs for wakeup (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Register memory side cache attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Register performance attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Register processor domain to its memory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Parse and report heterogeneous memory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi: Add HMAT to generic parsing tables (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi: Create subtable parsing infrastructure (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [arm64] arm64: numa: rework ACPI NUMA initialization (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Add support for PMCG (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: video: Use vendor backlight on Sony VPCEH3U1E (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / utils: Remove deprecated function since no user left (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: Clean up whitespace (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Add labels for PNP button devices (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Simplify acpi_bus_extract_wakeup_device_power_package() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Fix comment typos (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPICA: Clear status of GPEs before enabling them" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Namespace: remove address node from global list after method termination (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Clear status of GPEs before enabling them (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: use different default debug value than ACPICA (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / utils: Drop reference in test for device presence (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: sysfs: Prevent get_status() from returning acpi_status (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / device_sysfs: Avoid OF modalias creation for removed device (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / configfs: Mark local data structures static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / configfs: Mark local functions static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: tables: Simplify PPTT leaf node detection (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / bus: Respect PRP0001 when retrieving device match data (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190215 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/ACPICA: Trivial: fix spelling mistakes and fix whitespace formatting (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: add GTDT Revision 3 support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: HMAT updates (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: PPTT add additional fields in Processor Structure Flags (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: add Error Disconnect Recover Notification value (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: MADT: add support for statistical profiling in GICC (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: add PCC operation region support for AML interpreter (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [clk] clk: x86: Move clk-lpss.h to platform_data/x86 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: APEI: Fix possible out-of-bounds access to BERT region (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / processor: Set P_LVL{2, 3sc] } idle state descriptions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / CPPC: Add a helper to get desired performance (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: SRAT: add Generic Affinity Structure subtable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: Add Trigger order to PCC Identifier structure in PDTT (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: Adding predefined methods _NBS, _NCH, _NIC, _NIH, and _NIG (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update/clarify messages for control method failures (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debugger: Fix possible fault with the "test objects" command (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Interpreter: Emit warning for creation of a zero-length op region (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Remove legacy module-level code support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / x86: Make PWM2 device always present at Lenovo Yoga Book (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / video: Extend chassis-type detection with a "Lunch Box" check (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / video: Refactor and fix dmi_is_desktop() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Add support for the SDEI GHES Notification type (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [firmware] firmware: arm_sdei: Add ACPI GHES registration helper (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PPTT: Add acpi_pptt_warn_missing() to consolidate logs (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Use separate fixmap pages for arm64 NMI-like notifications (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Only use queued estatus entry during in_nmi_queue_one_entry() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Split ghes_read_estatus() to allow a peek at the CPER length (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Make GHES estatus header validation more user friendly (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Pass ghes and estatus separately to avoid a later copy (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Let the notification helper specify the fixmap slot (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Move locking to the notification helper (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Switch NOTIFY_SEA to use the estatus queue (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Move NOTIFY_SEA between the estatus-queue and NOTIFY_NMI (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't allow ghes_ack_error() to mask earlier errors (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Generalise the estatus queue's notify code (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't update struct ghes' flags in read/clear estatus (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Remove spurious GHES_TO_CLEAR check (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't store CPER records physical address in struct ghes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Make estatus pool allocation a static size (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Make hest.c manage the estatus memory pool (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Switch estatus pool to use vmalloc memory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Remove silent flag from ghes_read_estatus() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't wait to serialise with oops messages when panic()ing (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Set debug output flags independent of ACPICA (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Get rid of acpi_sleep_dispatch() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for BSG2150 ACPI nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPI / EC: Remove old CLEAR_ON_RESUME quirk" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Simplify boot EC checks in acpi_ec_add() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Eliminate acpi_config_boot_ec() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Make acpi_ec_dsdt_probe() more straightforward (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Make acpi_ec_ecdt_probe() more straightforward (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Declare boot_ec as static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / DPTF: remove header search path to the parent directory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Clean up probing for early EC (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: debug: Clean up acpi_aml_init() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: no need to check return value of debugfs_create functions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Look for ECDT EC after calling acpi_load_tables() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190108 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: All acpica: Update copyrights to 2019 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: acpiexec: Add option to dump extra info for memory leaks (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Convert more ACPI errors to firmware errors (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: APEI: EINJ: Use DEFINE_DEBUGFS_ATTRIBUTE for debugfs files (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Fix parsing HEST that includes Deferred Machine Check subtable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: table override from built-in initrd (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] APEI / ERST: Switch to use new generic UUID API (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Add generic intel_soc_pmic_exec_mipi_pmic_seq_element handling (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Implement exec_mipi_pmic_seq_element for CHT Whiskey Cove PMIC (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix build when CONFIG_IOMMU_API=n (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: Fix TS-pin current-source handling (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: NUMA: Use correct type for printing addresses on i386-PAE (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: power: Skip duplicate power resource references in _PRx (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Fix build failure when CONFIG_NLS is set to 'n' (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: Add an ifdef around amlcode and dsdt_amlcode (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Make PCI slot detection driver depend on PCI (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Stub out ACS functions when CONFIG_PCI is not set (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PCI/ACPI: Allow ACPI to be built without CONFIG_PCI set (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / OSI: Add OEM _OSI string to enable dGPU direct output (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Loop in full LPS0 mode only (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC / PM: Disable non-wakeup GPEs for suspend-to-idle (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Don't call iommu_ops->add_device directly (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Use device_iommu_mapped() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Use helper functions to access dev->iommu_fwspec (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [include] driver core: Introduce device_iommu_mapped() function (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [iommu] iommu/sysfs: Rename iommu_release_device() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [iommu] iommu: Consolitate ->add/remove_device() calls (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [iommu] iommu: Introduce wrappers around dev->iommu_fwspec (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: add DSDT AmlCode new declaration name support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20181213 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: change coding style to match ACPICA, no functional change (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debug output: Add option to display method/object evaluation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: disassembler: disassemble OEMx tables as AML (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Add "Windows 2018.2" string in the _OSI support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Expressions in package elements are not supported (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update buffer-to-string conversions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: add comments, no functional change (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Remove defines that use deprecated flag (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Add "Windows 2018" string in the _OSI support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [pci] PCI: Remove unused attr variable in pci_dma_configure (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Refactor _CCA enforcement (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Ignore acpi_device_fix_up_power() return value (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI, APEI, EINJ: Change to use DEFINE_SHOW_ATTRIBUTE macro (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for INT3515 ACPI nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix iort_get_platform_device_domain() uninitialized pointer value (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: SPCR: Consider baud rate 0 as preconfigured state (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / glue: Add acpi_platform_notify() function (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] drivers core: Prepare support for multiple platform notifications (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / platform: Add SMB0001 HID to forbidden_id_list (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Fix handling of buffer-size in acpi_ex_write_data_to_field() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20181031 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: iASL: Enhance error detection (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: iASL: adding definition and disassembly for TPM2 revision 3 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debugger: refactor to fix unused variable warning (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: fix IOSF_MBI dependency (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: Add depends on IOSF_MBI to Kconfig entry (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: Block P-Unit I2C access during read-modify-write (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [include] PM / Domains: Document flags for genpd (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for INT33FE ACPI nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / OSL: Use 'jiffies' as the time bassis for acpi_os_get_timer() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: probe ECDT before loading AML tables regardless of module-level code flag (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Remove acpi_gbl_group_module_level_code and only use acpi_gbl_execute_tables_as_methods instead (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: AML Parser: fix parse loop to correctly skip erroneous extended opcodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: AML interpreter: add region addresses in global list during initialization (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: TAD: Add low-level support for real time capability (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: Export acpi_device_get_power() for use by modular build drivers (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: remove redundant 'default n' from Kconfig (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / SBS: Fix rare oops when removing modules (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / SBS: Fix GPE storm on recent MacBookPro's (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20181003 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Never run _REG on system_memory and system_IO (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Split large interpreter file (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update for field unit access (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename some of the Field Attribute defines (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update for generic_serial_bus and attrib_raw_process_bytes protocol (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / processor: Fix the return value of acpi_processor_ids_walk() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Resume BYT/CHT I2C controllers from resume_noirq (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Add a device link from the GPU to the BYT I2C5 controller (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Add a device link from the GPU to the CHT I2C7 controller (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make acpi_lpss_find_device() also find PCI devices (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make hid_uid_match helper accept a NULL uid argument (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make hid_uid_match helper take an acpi_device as first argument (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi:ipmi: Convert ipmi_user_t to struct ipmi_user 0001-x86-smp-fix-non-SMP-broken-build-due-to-redefinition.patch brew_job bzlist bzlist-v2 run.sh testing_desc v4-notes v5-notes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Exclude I2C busses shared with PUNIT from pmc_atom_d3_mask (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Convert drivers to use SPDX identifier (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Sort headers alphabetically (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / property: Switch to bitmap_zalloc() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Add alternative ACPI HIDs for Cherry Trail DMA controllers (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: custom_method: remove meaningless null check before debugfs_remove() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Force LPSS quirks on boot (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / bus: Only call dmi_check_system() on X86 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: fix menuconfig presentation of ACPI submenu (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] xen/ACPI: don't upload Px/Cx data for disabled processors (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [x86] x86/smp: fix non-SMP broken build due to redefinition of apic_id_is_primary_thread (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: CrystalCove: Extend PMOP support to support all possible fields (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Clear status of all events when entering sleep states (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20180810 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: acpiexec: fix a small memory leak regression (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Reference count: add additional debugging details (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: acpi_exec: fixing -fi option (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debugger: Cleanup interface to the AML disassembler (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Utilities: split hex detection into smaller functions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update an error message for a duplicate table (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: Add ACPI i2c-multi-instantiate pseudo driver (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [kernel] PM / reboot: Eliminate race between reboot and suspend (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / x86: utils: Remove status workaround from acpi_device_always_present() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for fwnodes with multiple i2c devices (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Initialize status to ACPI_STA_DEFAULT (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / EC: Add another entry for Thinkpad X1 Carbon 6th (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: bus: Fix a pointer coding style issue (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] arm64 / ACPI: clean the additional checks before calling ghes_notify_sea() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Add static attribute to indirect_io_hosts[] (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: Do not export energy_full[_design] on devices without full_charge_capacity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / EC: Use ec_no_wakeup on ThinkPad X1 Yoga 3rd (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: get rid of negations in conditions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: use specialized print macros (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: reorder headers alphabetically (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: drop inclusion of init.h (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: battery: remove redundant old_present check on insertion (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Use data node name and reg property for graphs (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Allow direct graph endpoint references (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Make the ACPI graph API private (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Allow making references to non-device nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Convert ACPI reference args to generic fwnode reference args (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / OSI: Add OEM _OSI string to enable NVidia HDMI audio (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPI / bus: Parse tables as term_list for Dell XPS 9570 and Precision M5530" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: save NVS memory for ASUS 1025C laptop (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / button: fix defined but not used warning (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20180629 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Revert "iASL compiler: allow compilation of externals with paths that refer to existing names" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Revert "iASL: change processing of external op namespace nodes for correctness" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / x86: enable touchscreen on Dell Venue Pro 7139 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: Default to s2idle in all machines supporting LP S0 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / button: increment wakeup count only when notified (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [powerpc] powerpc/papr_scm: Fix an off-by-one check in papr_scm_meta_{get, set} (Gustavo Duarte) [1731035]
- [nvdimm] libnvdimm/altmap: Track namespace boundaries in altmap (Gustavo Duarte) [1731035]
- [powerpc] powerpc/nvdimm: Pick nearby online node if the device node is not online (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Force a scm-unbind if initial scm-bind fails (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Update drc_pmem_unbind() to use H_SCM_UNBIND_ALL (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries: Update SCM hcall op-codes in hvcall.h (Gustavo Duarte) [1731035]
- [mm] mm/nvdimm: add is_ioremap_addr and use that to check ioremap address (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries/scm: Use a specific endian format for storing uuid from the device tree (Gustavo Duarte) [1731035]
- [powerpc] powerpc/nvdimm: Add support for multibyte read/write for metadata (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries/scm: Mark the region volatile if cache flush not required (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/nvdimm: Add an informative message if we fail to allocate altmap block (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm: Consolidate numa_enable check and min_common_depth check (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm: Fix node look up with numa=off boot (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/drconf: Use NUMA_NO_NODE on failures instead of node 0 (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/radix: Use the right page size for vmemmap mapping (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/hash/4k: Don't use 64K page size for vmemmap with 4K pagesize (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Use the correct bind address (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm: Fallback to RAM if the altmap is unusable (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Use ibm, unit-guid as the iset cookie (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Fix DIMM device registration race (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Remove endian conversions (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Update DT properties (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Fix resource end address (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Use depend instead of select (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries: Add driver for PAPR SCM regions (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries: PAPR persistent memory support (Gustavo Duarte) [1731035]
- [mm] mm, vmstat: reduce zone->lock holding time by /proc/pagetypeinfo (Waiman Long) [1770314]
- [mm] mm, vmstat: hide /proc/pagetypeinfo from normal users (Waiman Long) [1770314]
- [crypto] crypto: chtls - remove cdev_list_lock (Neil Horman) [1737078]
- [crypto] crypto/chelsio/chtls: listen fails with multiadapt (Neil Horman) [1737078]
- [tools] cpupower : Handle set and info subcommands correctly (Steve Best) [1769973]
- [s390] s390/qeth: use IQD Multi-Write (Philipp Rudo) [1731028]
- [s390] s390/qdio: implement IQD Multi-Write (Philipp Rudo) [1731028]
- [s390] s390/qeth: add xmit_more support for IQD devices (Philipp Rudo) [1731028]
- [s390] s390/qeth: add BQL support for IQD devices (Philipp Rudo) [1731028]
- [s390] s390/qeth: when in TX NAPI mode, use napi_consume_skb() (Philipp Rudo) [1731028]
- [s390] s390/qeth: add TX NAPI support for IQD devices (Philipp Rudo) [1731028]
- [s390] s390/qeth: collect accurate TX statistics (Philipp Rudo) [1731028]
- [s390] s390/qdio: let drivers opt-out from Output Queue scanning (Philipp Rudo) [1731028]
- [s390] s390/qdio: enable drivers to poll for Output completions (Philipp Rudo) [1731028]
- [usb] xhci-pci: allow host runtime PM as default for Intel Alpine and Titan Ridge (Myron Stowe) [1769877]
- [x86] x86/atomic: Fix smp_mb__{before,after}_atomic() (Prarit Bhargava) [1769789]
- [kernel] stacktrace: Don't skip first entry on noncurrent tasks (Waiman Long) [1766681]
- [kernel] tracing: Fix user stack trace "??" output (Waiman Long) [1766681]
- [kernel] tracing: Fix out-of-range read in trace_stack_print() (Waiman Long) [1766681]
- [kernel] stacktrace: Constify 'entries' arguments (Waiman Long) [1766681]
- [kernel] stacktrace: Force USER_DS for stack_trace_save_user() (Waiman Long) [1766681]
- [x86] x86/stacktrace: Prevent infinite loop in arch_stack_walk_user() (Waiman Long) [1766681]
- [kernel] stacktrace: Use PF_KTHREAD to check for kernel threads (Waiman Long) [1766681]
- [kernel] stacktrace: Unbreak stack_trace_save_tsk_reliable() (Waiman Long) [1766681]
- [x86] x86/stacktrace: Use common infrastructure (Waiman Long) [1766681]
- [kernel] stacktrace: Keep stack_trace structure and remove snprint_stack_trace() (Waiman Long) [1766681]
- [kernel] stacktrace: Provide common infrastructure (Waiman Long) [1766681]
- [kernel] livepatch: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] tracing: Remove the last struct stack_trace usage (Waiman Long) [1766681]
- [kernel] tracing: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] tracing: Make ftrace_trace_userstack() static and conditional (Waiman Long) [1766681]
- [kernel] tracing: Use percpu stack trace buffer more intelligently (Waiman Long) [1766681]
- [kernel] tracing: Simplify stacktrace retrieval in histograms (Waiman Long) [1766681]
- [kernel] lockdep: Remove save argument from check_prev_add() (Waiman Long) [1766681]
- [kernel] lockdep: Remove unused trace argument from print_circular_bug() (Waiman Long) [1766681]
- [drm] drm: Simplify stacktrace handling (Waiman Long) [1766681]
- [md] dm persistent data: Simplify stack trace handling (Waiman Long) [1766681]
- [md] dm bufio: Simplify stack trace retrieval (Waiman Long) [1766681]
- [fs] btrfs: ref-verify: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] dma/debug: Simplify stracktrace retrieval (Waiman Long) [1766681]
- [lib] fault-inject: Simplify stacktrace retrieval (Waiman Long) [1766681]
- [mm] mm/page_owner: Simplify stack trace handling (Waiman Long) [1766681]
- [mm] mm/kmemleak: Simplify stacktrace handling (Waiman Long) [1766681]
- [mm] mm/slub: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] latency_top: Simplify stack trace handling (Waiman Long) [1766681]
- [fs] proc: Simplify task stack retrieval (Waiman Long) [1766681]
- [kernel] backtrace-test: Simplify stack trace handling (Waiman Long) [1766681]
- [lib] lib/stackdepot: Provide functions which operate on plain storage arrays (Waiman Long) [1766681]
- [kernel] stacktrace: Provide helpers for common stack trace operations (Waiman Long) [1766681]
- [kernel] tracing: Cleanup stack trace code (Waiman Long) [1766681]
- [kernel] tracing: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [drm] drm: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [kernel] latency_top: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [mm] mm/kasan: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [mm] mm/page_owner: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [mm] mm/slub: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [kernel] lockdep: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [kernel] s390/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] parisc/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] arm64/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] riscv/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] unicore32/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] sh/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] arm/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] [x86] x86/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] um/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [mm] mm/page_owner: clamp read count to PAGE_SIZE (Waiman Long) [1766681]
- [kernel] tracing: Export trace_dump_stack to modules (Waiman Long) [1766681]
- [kernel] tracing: Have stack tracer trace full stack (Waiman Long) [1766681]
- [kernel] trace: Use rcu_dereference_raw for hooks from trace-event subsystem (Waiman Long) [1766681]
- [kernel] tracing: Have trace_stack nr_entries compare not be so subtle (Waiman Long) [1766681]
- [cpuidle] cpuidle: governor: Add new governors to cpuidle_governors again (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: do not set an owner to allow modunload (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: set haltpoll as preferred governor (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: allow governor switch on cpuidle_register_driver() (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: Add cpuidle.governor= command line parameter (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: vcpu hotplug support (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: disable host side polling when kvm virtualized (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: add haltpoll governor (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: header file stubs must be "static inline" (Marcelo Tosatti) [1759282]
- [cpuidle] governors: unify last_state_idx (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: add poll_limit_ns to cpuidle_device structure (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: poll_state: Fix default time limit (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: poll_state: Disregard disable idle states (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: poll_state: Revise loop termination condition (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: menu: Fix wakeup statistics updates for polling state (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: return -ENODEV on modinit failure (Marcelo Tosatti) [1759282]
- [cpuidle] add cpuidle-haltpoll driver (Marcelo Tosatti) [1759282]
- [mm] mem-hotplug: fix node spanned pages when we have a node with only ZONE_MOVABLE (Baoquan He) [1756210]
- [x86] x86, efi: never relocate kernel below lowest acceptable address (Kairui Song) [1747367]
- [fs] CIFS: Force reval dentry if LOOKUP_REVAL flag is set (Dave Wysochanski) [1767664]
- [fs] CIFS: Force revalidate inode when dentry is stale (Dave Wysochanski) [1767664]
- [fs] CIFS: Gracefully handle QueryInfo errors during open (Dave Wysochanski) [1767664]
- [block] blk-mq: make sure that line break can be printed (Ming Lei) [1741462]
- [block] blk-mq: avoid sysfs buffer overflow with too many CPU cores (Ming Lei) [1741462]
- [netdrv] bnx2x: Fix VF's VLAN reconfiguration in reload. (Manish Chopra) [1720393]
- [netdrv] bnx2x: Prevent ptp_task to be rescheduled indefinitely (Manish Chopra) [1720393]
- [netdrv] bnx2x: Check if transceiver implements DDM before access (Manish Chopra) [1720393]
- [fs] xfs: allocate xattr buffer on demand (Eric Sandeen) [1684599]
- [fs] xfs: consolidate attribute value copying (Eric Sandeen) [1684599]
- [fs] xfs: move remote attr retrieval into xfs_attr3_leaf_getvalue (Eric Sandeen) [1684599]
- [fs] xfs: remove unnecessary indenting from xfs_attr3_leaf_getvalue (Eric Sandeen) [1684599]
- [fs] xfs: make attr lookup returns consistent (Eric Sandeen) [1684599]
- [i2c] i2c: i801: Add support for Intel Comet Lake (David Arcari) [1761547]
- [powerpc] powerpc/xmon: Improve output of XIVE interrupts (Diego Domingos) [1731130]
- [powerpc] powerpc/xmon: Fix output of XIVE IPI (Diego Domingos) [1731130]
- [powerpc] powerpc/xmon: Add a dump of all XIVE interrupts (Diego Domingos) [1731130]
- [powerpc] powerpc/xive: Fix dump of XIVE interrupt under pseries (Diego Domingos) [1731130]
- [powerpc] powerpc/xmon: Check for HV mode when dumping XIVE info from OPAL (Diego Domingos) [1731130]
- [fs] xfs: convert inode to extent format after extent merge due to shift (Brian Foster) [1745253]
- [mmc] mmc: sdhci-pci: Add support for Intel CML (Alexander Beregalov) [1761593]
- [powerpc] powerpc/mm/mce: Keep irqs disabled during lockless page table walk (Gustavo Duarte) [1524649]
- [tools] seltests/powerpc: Add a selftest for memcpy_mcsafe (Gustavo Duarte) [1524649]
- [powerpc] powerpc/memcpy: Fix stack corruption for smaller sizes (Gustavo Duarte) [1524649]
- [powerpc] powerpc: add machine check safe copy_to_user (Gustavo Duarte) [1524649]
- [powerpc] powerpc/memcpy: Add memcpy_mcsafe for pmem (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Handle UE event for memcpy_mcsafe (Gustavo Duarte) [1524649]
- [kernel] extable: Add function to search only kernel exception table (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Make machine_check_ue_event() static (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Fix MCE handling for huge pages (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Schedule work from irq_work (Gustavo Duarte) [1524649]
- [x86] x86/boot/64: Round memory hole size up to next PMD page (Frank Ramsay) [1755602]
- [x86] x86/boot/64: Make level2_kernel_pgt pages invalid outside kernel area (Frank Ramsay) [1755602]
- [idle] intel_idle: add support for Jacobsville (Steve Best) [1481744]
- [powercap] powercap/intel_rapl: add support for ICX (Steve Best) [1724421]
- [block] blk-mq: apply normal plugging for HDD (Ming Lei) [1759380]
- [block] blk-mq: honor IO scheduler for multiqueue devices (Ming Lei) [1759380]
- [block] blk-mq: simplify blk_mq_make_request() (Ming Lei) [1759380]
- [block] blk-mq: remove blk_mq_put_ctx() (Ming Lei) [1759380]
- [nvdimm] libnvdimm: Enable unit test infrastructure compile checks (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm: Use PAGE_SIZE instead of SZ_4K for align check (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/label: Remove the dpa align check (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pfn_dev: Add page size and struct page size to pfn superblock (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pfn_dev: Add a build check to make sure we notice when struct page size change (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pmem: Advance namespace seed for specific probe errors (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/region: Rewrite _probe_success() to _advance_seeds() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/security: Consolidate 'security' operations (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/security: Tighten scope of nvdimm->busy vs security operations (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/security: Introduce a 'frozen' attribute (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm, region: Use struct_size() in kzalloc() (Jeff Moyer) [1724965]
- [tools] tools/testing/nvdimm: Fix fallthrough warning (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/of_pmem: Provide a unique name for bus provider (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Fix wait_nvdimm_bus_probe_idle() ABBA deadlock (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Stop holding nvdimm_bus_list_mutex over __nd_ioctl() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Prepare the nd_ioctl() path to be re-entrant (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/region: Register badblocks before namespaces (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Prevent duplicate device_unregister() calls (Jeff Moyer) [1724965]
- [drivers] drivers/base: Introduce kill_device() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm, namespace: Drop uuid_t implementation detail (Jeff Moyer) [1724965]
- [dax] device-dax: Add a 'resource' attribute (Jeff Moyer) [1724965]
- [dax] device-dax: Drop register_filesystem() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pmem: Bypass CONFIG_HARDENED_USERCOPY overhead (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm: Fix compilation warnings with W=1 (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/namespace: Fix label tracking error (Jeff Moyer) [1724965]
- [dax] device-dax: Add a 'modalias' attribute to DAX 'bus' devices (Jeff Moyer) [1724965]
- [dax] device-dax: Add a 'target_node' attribute (Jeff Moyer) [1724965]
- [dax] device-dax: Auto-bind device after successful new_id (Jeff Moyer) [1724965]
- [dax] acpi/nfit, device-dax: Identify differentiated memory with a unique numa-node (Jeff Moyer) [1724965]
- [dax] device-dax: Add /sys/class/dax backwards compatibility (Jeff Moyer) [1724965]
- [dax] device-dax: Add support for a dax override driver (Jeff Moyer) [1724965]
- [dax] device-dax: Move resource pinning+mapping into the common driver (Jeff Moyer) [1724965]
- [dax] device-dax: Introduce bus + driver model (Jeff Moyer) [1724965]
- [dax] device-dax: Start defining a dax bus model (Jeff Moyer) [1724965]
- [dax] device-dax: Remove multi-resource infrastructure (Jeff Moyer) [1724965]
- [dax] device-dax: Kill dax_region base (Jeff Moyer) [1724965]
- [dax] device-dax: Kill dax_region ida (Jeff Moyer) [1724965]
- [kernel] memremap: Convert to XArray (Jeff Moyer) [1724965]
- [drivers] drivers/dax/device.c: convert variable to vm_fault_t type (Jeff Moyer) [1724965]
- [drivers] driver core: Rewrite test_async_driver_probe to cover serialization and NUMA affinity (Jeff Moyer) [1724965]
- [drivers] libnvdimm: Schedule device registration on node local to the device (Jeff Moyer) [1724965]
- [drivers] PM core: Use new async_schedule_dev command (Jeff Moyer) [1724965]
- [drivers] driver core: Attach devices on CPU local to device node (Jeff Moyer) [1724965]
- [kernel] async: Add support for queueing on specific NUMA node (Jeff Moyer) [1724965]
- [kernel] workqueue: Provide queue_work_node to queue work near a given NUMA node (Jeff Moyer) [1724965]
- [drivers] driver core: Probe devices asynchronously instead of the driver (Jeff Moyer) [1724965]
- [drivers] device core: Consolidate locking and unlocking of parent and device (Jeff Moyer) [1724965]
- [drivers] driver core: Establish order of operations for device_add and device_del via bitflag (Jeff Moyer) [1724965]
- [drivers] driver core: Add missing dev->bus->need_parent_lock checks (Jeff Moyer) [1724965]
- [drivers] driver core: Move async_synchronize_full call (Jeff Moyer) [1724965]

* Tue Nov 12 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-149.el8]
- [scsi] scsi: qedi: update driver version to 8.37.0.20 (Nilesh Javali) [1724588]
- [scsi] scsi: qedi: Check targetname while finding boot target information (Nilesh Javali) [1724588]
- [scsi] scsi: qedi: remove set but not used variables 'cdev' and 'udev' (Nilesh Javali) [1724588]
- [scsi] scsi: qedi: remove memset/memcpy to nfunc and use func instead (Nilesh Javali) [1724588]
- [scsi] qedi: Use hwfns and affin_hwfn_idx to get MSI-X vector index (Nilesh Javali) [1724588]
- [scsi] scsi: qedf: Update the version to 8.42.3.0 (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Fix race betwen fipvlan request and response path (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Use discovery list to traverse rports (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Decrease the LL2 MTU size to 2500 (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Check for module unloading bit before processing link update AEN (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Initiator fails to re-login to switch after link down (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Add debug information for unsolicited processing (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Add support for 20 Gbps speed (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Interpret supported caps value correctly (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Add shutdown callback handler (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Update module description string (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Fix crash during sg_reset (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Stop sending fipvlan request on unload (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Print message during bailout conditions (Nilesh Javali) [1724589]
- [scsi] qedf: Use hwfns and affin_hwfn_idx to get MSI-X vector index to use (Nilesh Javali) [1724589]
- [scsi] scsi: bnx2fc: Handle scope bits when array returns BUSY or TSF (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: remove set but not used variables 'task', 'port', 'orig_task' (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: remove set but not used variables 'lport', 'host' (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: remove set but not used variable 'fh' (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: fix bnx2fc_cmd refcount imbalance in send_srr (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: fix bnx2fc_cmd refcount imbalance in send_rec (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Update the driver version to 2.12.10 (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Limit the IO size according to the FW capability (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Do not allow both a cleanup completion and abort completion for the same request (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Separate out completion flags and variables for abort and cleanup (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Only put reference to io_req in bnx2fc_abts_cleanup if cleanup times out (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Redo setting source FCoE MAC (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: fix incorrect cast to u64 on shift operation (Nilesh Javali) [1724598]
- [netdrv] qed: Fix build error without CONFIG_DEVLINK (Manish Chopra) [1720392]
- [netdrv] RDMA/qedr: Fix the hca_type and hca_rev returned in device attributes (Manish Chopra) [1720392]
- [netdrv] qede: qede_fp: simplify a bit 'qede_rx_build_skb()' (Manish Chopra) [1720392]
- [netdrv] qede: Make two functions static (Manish Chopra) [1720392]
- [netdrv] qede: Handle infinite driver spinning for Tx timestamp. (Manish Chopra) [1720392]
- [netdrv] qed: fix spelling mistake "fullill" -> "fulfill" (Manish Chopra) [1720392]
- [netdrv] qed: Fix Config attribute frame format. (Manish Chopra) [1720392]
- [netdrv] qed*: Fix size of config attribute dump. (Manish Chopra) [1720392]
- [netdrv] net: qed: Move static keyword to the front of declaration (Manish Chopra) [1720392]
- [netdrv] qede: Add support for dumping the grc data. (Manish Chopra) [1720392]
- [netdrv] qed: Add APIs for configuring grc dump config flags. (Manish Chopra) [1720392]
- [netdrv] qede: Add support for reading the config id attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add APIs for reading config id attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add cleanup in qed_slowpath_start() (Manish Chopra) [1720392]
- [netdrv] qed: Add driver API for flashing the config attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add API for configuring NVM attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add new ethtool supported port types based on media. (Manish Chopra) [1720392]
- [netdrv] net/ethernet/qlogic/qed: force the string buffer NULL-terminated (Manish Chopra) [1720392]
- [netdrv] qed: RDMA - Fix the hw_ver returned in device attributes (Manish Chopra) [1720392]
- [netdrv] qed*: Change dpi_addr to be denoted with __iomem (Manish Chopra) [1720392]
- [netdrv] qed: reduce maximum stack frame size (Manish Chopra) [1720392]
- [netdrv] qed: Prefer pcie_capability_read_word() (Manish Chopra) [1720392]
- [netdrv] qed: Add support for Timestamping the unicast PTP packets. (Manish Chopra) [1720392]
- [netdrv] qed: Fix -Wmaybe-uninitialized false positive (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - Fix default window size to be based on chip (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - Fix tc for MPA ll2 connection (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - fix uninitialized callback (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - Use READ_ONCE and smp_store_release to access ep->state (Manish Chopra) [1720392]
- [netdrv] qed: remove redundant assignment to rc (Manish Chopra) [1720392]
- [netdrv] qed: Fix static checker warning (Manish Chopra) [1720392]
- [netdrv] qed: fix spelling mistake "inculde" -> "include" (Manish Chopra) [1720392]
- [netdrv] qed: Reduce the severity of ptp debug message. (Manish Chopra) [1720392]
- [netdrv] qed*: Add iWARP 100g support (Manish Chopra) [1720392]
- [netdrv] qed: Add qed devlink parameters table (Manish Chopra) [1720392]
- [netdrv] qed: Set the doorbell address correctly (Manish Chopra) [1720392]
- [netdrv] qedr: Change the MSI-X vectors selection to be based on affined engine (Manish Chopra) [1720392]
- [netdrv] qed: Modify offload protocols to use the affined engine (Manish Chopra) [1720392]
- [netdrv] qed*: Change hwfn used for sb initialization (Manish Chopra) [1720392]
- [netdrv] qed: Add llh ppfid interface and 100g support for offload protocols (Manish Chopra) [1720392]
- [netdrv] qed: Modify api for performing a dmae to another PF (Manish Chopra) [1720392]
- [virt] kvm: arm/arm64: vgic: Use the appropriate TRACE_INCLUDE_PATH (Auger Eric) [1749501]
- [arm64] kvm: Kill hyp_alternate_select() (Auger Eric) [1749501]
- [arm64] kvm: Replace hyp_alternate_select with has_vhe() (Auger Eric) [1749501]
- [arm64] kvm: Drop hyp_alternate_select for checking for ARM64_WORKAROUND_834220 (Auger Eric) [1749501]
- [documentation] kvm: arm/arm64: vgic: Allow more than 256 vcpus for KVM_IRQ_LINE (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Use a single IO device per redistributor (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Remove spurious semicolons (Auger Eric) [1749501]
- [arm64] perf_event: Add missing header needed for smp_processor_id() (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Make function comments match function declarations (Auger Eric) [1749501]
- [arm64] kvm: Remove VMID rollover I-cache maintenance (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-irqfd: Implement kvm_arch_set_irq_inatomic (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Check the LPI translation cache on MSI injection (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Cache successful MSI->LPI translation (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on vgic teardown (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on ITS disable (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on disabling LPIs (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on specific commands (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Add MSI-LPI translation cache invalidation (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Add __vgic_put_lpi_locked primitive (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Add LPI translation cache definition (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-v2: Handle SGI bits in GICD_I{S, C}PENDR0 as WI (Auger Eric) [1749501]
- [arm64] kvm: Replace hardcoded '1' with SYS_PAR_EL1_F (Auger Eric) [1749501]
- [arm64] sysreg: Add some field definitions for PAR_EL1 (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Fix potential deadlock when ap_list is long (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Properly initialise private IRQ affinity (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Reevaluate level sensitive interrupts on enable (Auger Eric) [1749501]
- [arm64] kvm: arm64: Don't write junk to sysregs on reset (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: Sync ICH_VMCR_EL2 back when about to block (Auger Eric) [1749501]
- [arm64] kvm: hyp: debug-sr: Mark expected switch fall-through (Auger Eric) [1749501]
- [arm64] kvm: arm64: Update kvm_arm_exception_class and esr_class_str for new EC (Auger Eric) [1749501]
- [virt] kvm: arm: vgic-v3: Mark expected switch fall-through (Auger Eric) [1749501]
- [arm64] kvm: regmap: Fix unexpected switch fall-through (Auger Eric) [1749501]
- [arm64] sve: Fix a couple of magic numbers for the Z-reg count (Auger Eric) [1749501]
- [arm64] sve: Factor out FPSIMD to SVE state conversion (Auger Eric) [1749501]
- [arm64] kvm: arm/arm64: Initialise host's MPIDRs by reading the actual register (Auger Eric) [1749501]
- [arm64] kvm: arm64: Migrate _elx sysreg accessors to msr_s/mrs_s (Auger Eric) [1749501]
- [arm64] sysreg: Make mrs_s and msr_s macros work with Clang and LTO (Auger Eric) [1749501]
- [documentation] kvm: doc: Add API documentation on the KVM_REG_ARM_WORKAROUNDS register (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: Add save/restore support for firmware workaround state (Auger Eric) [1749501]
- [arm64] kvm: Propagate full Spectre v2 workaround state to KVM guests (Auger Eric) [1749501]
- [arm64] sve: Fix missing SVE/FPSIMD endianness conversions (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Fix kvm_device leak in vgic_its_destroy (Auger Eric) [1749501]
- [arm64] kvm: arm64: Filter out invalid core register IDs in KVM_GET_REG_LIST (Auger Eric) [1749501]
- [arm64] kvm: arm64: Skip more of the SError vaxorcism (Auger Eric) [1749501]
- [arm64] kvm: arm64: Re-mask SError after the one instruction window (Auger Eric) [1749501]
- [arm64] Update silicon-errata.txt for Neoverse-N1 #1349291 (Auger Eric) [1749501]
- [arm64] kvm: arm64: Defer guest entry when an asynchronous exception is pending (Auger Eric) [1749501]
- [arm64] kvm: arm64: Consume pending SError as early as possible (Auger Eric) [1749501]
- [arm64] kvm: arm64: Make indirect vectors preamble behaviour symmetric (Auger Eric) [1749501]
- [arm64] kvm: arm64: Abstract the size of the HYP vectors pre-amble (Auger Eric) [1749501]
- [arm64] assembler: Switch ESB-instruction with a vanilla nop if !ARM64_HAS_RAS (Auger Eric) [1749501]
- [arm64] kvm: arm64/sve: Fix vq_present() macro to yield a bool (Auger Eric) [1749501]
- [arm64] kvm: arm64: Implement vq_present() as a macro (Auger Eric) [1749501]
- [arm64] fpsimd: Don't disable softirq when touching FPSIMD/SVE state (Auger Eric) [1749501]
- [arm64] fpsimd: Introduce fpsimd_save_and_flush_cpu_state() and use it (Auger Eric) [1749501]
- [arm64] fpsimd: Remove the prototype for sve_flush_cpu_state() (Auger Eric) [1749501]
- [scripts] genksyms: Teach parser about 128-bit built-in types (Auger Eric) [1749501]
- [tools] kvm: selftests: introduce aarch64_vcpu_add_default (Auger Eric) [1749501]
- [tools] kvm: selftests: introduce aarch64_vcpu_setup (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: Move cc/it checks under hyp's Makefile to avoid instrumentation (Auger Eric) [1749501]
- [arm64] kvm: arm64: Move pmu hyp code under hyp's Makefile to avoid instrumentation (Auger Eric) [1749501]
- [documentation] arm64: docs: Document perf event attributes (Auger Eric) [1749501]
- [arm64] kvm: Fix perf cycle counter support for VHE (Auger Eric) [1749501]
- [arm64] kvm: Avoid isb's by using direct pmxevtyper sysreg (Auger Eric) [1749501]
- [arm64] kvm: Enable VHE support for :G/:H perf event modifiers (Auger Eric) [1749501]
- [arm64] kvm: Enable !VHE support for :G/:H perf event modifiers (Auger Eric) [1749501]
- [arm64] arm_pmu: Add !VHE support for exclude_host/exclude_guest attributes (Auger Eric) [1749501]
- [arm64] kvm: Add accessors to track guest/host only counters (Auger Eric) [1749501]
- [arm64] arm_pmu: Remove unnecessary isb instruction (Auger Eric) [1749501]
- [arm64] perf: Add support for chaining event counters (Auger Eric) [1749501]
- [arm64] perf: Disable PMU while processing counter overflows (Auger Eric) [1749501]
- [arm64] perf: Clean up armv8pmu_select_counter (Auger Eric) [1749501]
- [arm64] kvm: arm: Remove pgtable page standard functions from stage-2 page tables (Auger Eric) [1749501]
- [netdrv] e1000e: Add support for Tiger Lake (Ken Cox) [1767480]
- [netdrv] ethernet: Delete unnecessary checks before the macro call dev_kfree_skb (Corinna Vinschen) [1721705]
- [netdrv] igb: Use dev_get_drvdata where possible (Corinna Vinschen) [1721705]
- [netdrv] net: Use skb accessors in network drivers (Corinna Vinschen) [1721705]
- [netdrv] igb: add RR2DCDELAY to ethtool registers dump (Corinna Vinschen) [1721705]
- [netdrv] igb: minor ethool regdump amendment (Corinna Vinschen) [1721705]
- [netdrv] igb: clear out skb->tstamp after reading the txtime (Corinna Vinschen) [1721705]
- [netdrv] igb: mark expected switch fall-through (Corinna Vinschen) [1721705]
- [netdrv] igb: mark expected switch fall-through (Corinna Vinschen) [1721705]
- [netdrv] igb/igc: warn when fatal read failure happens (Corinna Vinschen) [1721705]
- [netdrv] igb: fix various indentation issues (Corinna Vinschen) [1721705]
- [netdrv] igb: Exclude device from suspend direct complete optimization (Corinna Vinschen) [1721705]
- [netdrv] intel: correct return from set features callback (Corinna Vinschen) [1721705]
- [netdrv] net: Use skb accessors in network drivers (Corinna Vinschen) [1721708]
- [s390] s390/kaslr: reserve memory for kasan usage (Philipp Rudo) [1725888]
- [s390] s390/mem_detect: provide single get_mem_detect_end (Philipp Rudo) [1725888]
- [s390] s390/setup: adjust start_code of init_mm to _text (Philipp Rudo) [1725888]
- [s390] s390/boot: add missing declarations and includes (Philipp Rudo) [1725888]
- [s390] locking/lockdep: check for freed initmem in static_obj() (Philipp Rudo) [1725888]
- [s390] s390/kernel: add support for kernel address space layout randomization (KASLR) (Philipp Rudo) [1725888]
- [s390] s390/kernel: introduce .dma sections (Philipp Rudo) [1725888]
- [s390] s390/sclp: do not use static sccbs (Philipp Rudo) [1725888]
- [s390] s390/kprobes: use static buffer for insn_page (Philipp Rudo) [1725888]
- [s390] s390/kernel: convert SYSCALL and PGM_CHECK handlers to .quad (Philipp Rudo) [1725888]
- [s390] s390/kernel: build a relocatable kernel (Philipp Rudo) [1725888]
- [s390] s390/extmem: remove code for 31 bit addressing mode (Philipp Rudo) [1725888]
- [s390] s390/setup: remove obsolete #ifdef (Philipp Rudo) [1725888]
- [net] net/core: work around section mismatch warning for ptp_classifier (Philipp Rudo) [1725888]
- [sound] ALSA: bebob: fix to detect configured source of sampling clock for Focusrite Saffire Pro i/o series (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: link the order of establishing connections and Syt-match clock mode (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: expand delay of start for IR context just for version 3 firmware (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: expand sleep just after breaking connections for protocol version 1 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC/SOF - enable SND_SOC_SOF_HDA_COMMON_HDMI_CODEC (Jaroslav Kysela) [1710702]
- [sound] ALSA: timer: Fix mutex deadlock at releasing card (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: Add quirk for boards using pmc_plt_clk_0 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: eve: Enable mclk and ssp sclk early (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: dt-bindings: rt5682: add button delay device property (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: rt5682: improve the sensitivity of push button (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: bxt_rt298: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: sof_rt5682: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: bxt-da7219-max98357a: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: add support for snd-hda-codec-hdmi (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: fix include guard name (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: use snd-hda-codec-hdmi (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: hdac_hda: add support for HDMI/DP as a HDA codec (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/hdmi - implement mst_no_extra_pcms flag (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF - remove the dead code (skylake/kabylake) (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel - fix the card names (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pci: Add prepare/complete PM callbacks (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: Add support for DSP D0i3 state when entering S0ix (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: return -ENOTSUPP if D0I3 is not supported (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-dsp: implement suspend/resume for S0ix<->S0 transition (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ignore suspend/resume for D0ix compatible streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: implement prepare/complete callbacks (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add a flag suspend_ignored for sof stream (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add a flag to indicate the system suspend target (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add support for sending compact IPC (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: add helpers for setting D0 substate for ADSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: configure D0ix IPC flags in set_power_state (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: HDA: add cAVS specific compact IPC header file (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: Don't read mailbox for PM_GATE reply (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ipc: introduce message for DSP power gating (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: rename sof_send_pm_ipc to sof_send_pm_ctx_ipc (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: HDA: use macro for register polling retry count (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-dsp: align the comments for D0I3C update (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: parse and store d0i3_compatible flag (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: token: add tokens for PCM compatible with D0i3 substate (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add flag to snd_sof_pcm_stream for D0i3 compatible stream (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: APL: add set_power_state() ops (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add set_power_state() ops (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-dsp: Add helper for setting DSP D0ix substate (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add set_power_state() to dsp_ops for power state update (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: reset default d0_substate at probe() and resume() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add a field to store the current D0 substate of DSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: eve: implement set_bias_level function for rt5514 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: only support INFO_BATCH for legacy platforms (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: define INFO_ flags in dsp_ops (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: initial support to JasperLake. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for JSL (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: add dev_err() traces for snd_sof_dsp_read_poll_timeout() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-loader: improve error handling (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: sof: include types.h at header.h (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Fix randbuild error (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: check errors when parsing LED tokens (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: remove always-true redundant test (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: bdw: fix operator precedence warnings (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: byt: fix operator precedence warnings (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: imx: Read ESAI parameters and send them to DSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: acpi led support for switch controls (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: imx: Describe ESAI parameters to be sent to DSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pci: add debug module param (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: acpi: add debug module param (Jaroslav Kysela) [1710702]
- [sound] ALSA: Revert "ASoC: SOF: Force polling mode on CFL and CNL" (Jaroslav Kysela) [1710702]
- [sound] ALSA: AsoC: SOF: refactor control load code (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: enable dual control for pga (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: enable sync_write in hdac_bus (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: simple_card_utils.h: Add missing include (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: Add context data to any IPC timeout. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix reset of host_period_bytes (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ipc: introduce no_stream_position in sof_ipc_stream_params struct (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: core: check for mandatory fw_ready op during SOF probe (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ipc: retain DSP context after FW exception. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: trace: move to opt-in with Kconfig and module parameter (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Fix 2 front mics of codec 0x623 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Add support for ALC623 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Fix mutex deadlock in HDMI codec driver (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Fix pending unsol events at shutdown (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: Correct a typo in the clock proc string (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: add support for MOTU UltraLite (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: code refactoring to handle model specific switch for protocol v2 (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: minor code refactoring for protocol version 2 (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: detect SPH source of sampling clock (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: print for unknown source of sampling clock (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: fix wrong spelling for macro (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: Fix prototype of helper function to return negative value (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Disable quirks for BOSS Katana amplifiers (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: sound: usb: usb true/false for bool return type (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Add DSD support for Gustard U16/X26 USB Interface (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: Allow non-Intel device probe gracefully (Jaroslav Kysela) [1710702]
- [sound] ALSA: Revert "ALSA: hda: Flush interrupts on disabling" (Jaroslav Kysela) [1710702]
- [sound] ALSA: PCI: Fix missing inline for pci_pr3_present() (Jaroslav Kysela) [1710702]
- [sound] ALSA: PCI: Add a helper to check Power Resource Requirements _PR3 existence (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Fix copy&paste error in the validator (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Add DSD support for EVGA NU Audio (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: postpone to start IR context (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: handle several AMDTP streams in callback handler of IRQ target (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: cancel flushing isoc context in the laste step to process context callback (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: replace ack callback to flush isoc contexts in AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: replace pointer callback to flush isoc contexts in AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: add irq_target member into amdtp_domain struct (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: tune the minimum available size of PCM period (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: tune the maximum available size of PCM period (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: schedule hardware IRQ according to the size of PCM period (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireface: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-tascam: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-digi00x: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: dice: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: oxfw: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireworks: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: use variable size of queue for isoc packets instead of fixed size (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireface: use the same size of period for PCM substreams in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-tascam: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-digi00x: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: dice: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: oxfw: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireworks: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireface: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-tascam: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-digi00x: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: dice: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: oxfw: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireworks: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: add a member into AMDTP domain for events per period (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Enable headset mic on Asus MJ401TA (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek: Reduce the Headphone static noise on XPS 9350/9360 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Add support for ALC711 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Force runtime PM on Nvidia HDMI codecs (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Add laptop imic fixup for ASUS M9V laptop (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: Add Tigerlake/Jasperlake PCI ID (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: Allow HDA to be runtime suspended when dGPU is not bound to a driver (Jaroslav Kysela) [1710702]
- [sound] ALSA: hdac: clear link output stream mapping (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: dapm: fix a memory leak bug (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: debug: fix possible memory leak in sof_dfsentry_write() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add a check for devm_clk_get (Jaroslav Kysela) [1710702]
- [sound] ALSA: Fix Kconfig indentation (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: control: return true when kcontrol values change (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: fix intel DSP config (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: add Intel DSP configuration / probe code (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: core: Fix pcm code debugfs error (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoc: rockchip: i2s: Fix RPM imbalance (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: wm_adsp: Don't generate kcontrols without READ flags (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: bytcr_rt5651: add null check to support_button_press (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: sof_rt5682: add remove function to disable jack (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: rt5682: add NULL handler to set_jack function (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: sof_rt5682: use separate route map for dmic (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: Disable DMI L1 entry during capture (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: initialise and verify FW crash dump data. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix warnings during FW load (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pcm: harden PCM STOP sequence (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pcm: fix resource leak in hw_free (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: fix parse fail issue for byte/bool tuple types (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: loader: fix kernel oops on firmware boot failure (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: wm_adsp: Fix theoretical NULL pointer for alg_region (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: max98373: check for device node before parsing (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: topology: Fix a signedness bug in soc_tplg_dapm_widget_create() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: soc-component: fix a couple missing error assignments (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: wm8994: Do not register inapplicable controls for WM1811 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: samsung: arndale: Add missing OF node dereferencing (Jaroslav Kysela) [1710702]
- [infiniband] RDMA/bnxt_re: Fix spelling mistake "missin_resp" -> "missing_resp" (Kamal Heib) [1724772]
- [infiniband] RDMA: Fix goto target to release the allocated memory (Kamal Heib) [1724772]
- [infiniband] IB/bnxt_re: Do not notifify GID change event (Kamal Heib) [1724772]
- [infiniband] RDMA/bnxt_re: Honor vlan_id in GID entry comparison (Kamal Heib) [1724772]
- [infiniband] ib/bnxt: Remove mention of idr_alloc from comment (Kamal Heib) [1724772]
- [infiniband] RDMA/bnxt_re: Use correct sizing on buffers holding page DMA addresses (Kamal Heib) [1724772]
- [infiniband] bnxt_re: Clean cq for kernel consumers only (Kamal Heib) [1724772]
- [infiniband] bnxt_re: fix the regression due to changes in alloc_pbl (Kamal Heib) [1724772]
- [scsi] scsi: lpfc: Make lpfc_debugfs_ras_log_data static (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix NULL check before mempool_destroy is not needed (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix spelling error in MAGIC_NUMER_xxx (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix build error of lpfc_debugfs.c for vfree/vmalloc (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: lpfc_nvmet: Fix Use plain integer as NULL pointer (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: lpfc_attr: Fix Use plain integer as NULL pointer (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Update lpfc version to 12.6.0.0 (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add additional discovery log messages (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add FC-AL support to lpe32000 models (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add FA-WWN Async Event reporting (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add log macros to allow print by serverity or verbosity setting (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Make FW logging dynamically configurable (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Revise interrupt coalescing for missing scenarios (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Remove lock contention target write path (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Slight fast-path performance optimizations (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix coverity error of dereference after null check (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix hardlockup in lpfc_abort_handler (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix bad ndlp ptr in xri aborted handling (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix SLI3 hba in loop mode not discovering devices (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix lockdep errors in sli_ringtx_put (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix reporting of read-only fw error errors (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix lpfc_nvmet_mrq to be bound by hdw queue count (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Make function lpfc_defer_pt2pt_acc static (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: add support for posting FC events on FPIN reception (Dick Kennedy) [1768102]
- [infiniband] RDMA/siw: Mark Software iWARP Driver as tech-preview (Kamal Heib) [1767292]
- [crypto] crypto: ccp - Replace dma_pool_alloc + memset with dma_pool_zalloc (Gary Hook) [1724859]
- [crypto] crypto: ccp/gcm - use const time tag comparison. (Gary Hook) [1724859]
- [crypto] crypto: ccp - Switch to SPDX license identifiers (Gary Hook) [1724859]
- [crypto] crypto: ccp - Validate the the error value used to index error messages (Gary Hook) [1724859]
- [crypto] crypto: ccp - Make ccp_register_rsa_alg static (Gary Hook) [1724859]
- [crypto] crypto: ccp - Update copyright notices and dates (Gary Hook) [1724859]
- [crypto] cross-tree: phase out dma_zalloc_coherent() (Gary Hook) [1724859]
- [x86] x86/umwait: Fix error handling in umwait_init() (Steve Best) [1724525]
- [documentation] Documentation/ABI: Document umwait control sysfs interfaces (Steve Best) [1724525]
- [x86] x86/umwait: Add sysfs interface to control umwait maximum time (Steve Best) [1724525]
- [x86] x86/umwait: Add sysfs interface to control umwait C0.2 state (Steve Best) [1724525]
- [x86] x86/umwait: Initialize umwait control values (Steve Best) [1724525]
- [x86] x86/cpufeatures: Enumerate user wait instructions (Steve Best) [1724525]
- [fs] virtiofs: Remove set but not used variable 'fc' (Vivek Goyal) [1694161]
- [fs] virtiofs: Retry request submission from worker context (Vivek Goyal) [1694161]
- [fs] virtiofs: Count pending forgets as in_flight forgets (Vivek Goyal) [1694161]
- [fs] virtiofs: Set FR_SENT flag only after request has been sent (Vivek Goyal) [1694161]
- [fs] virtiofs: No need to check fpq->connected state (Vivek Goyal) [1694161]
- [fs] virtiofs: Do not end request in submission context (Vivek Goyal) [1694161]
- [fs] fuse: don't advise readdirplus for negative lookup (Vivek Goyal) [1694161]
- [fs] fuse: don't dereference req->args on finished request (Vivek Goyal) [1694161]
- [fs] virtio-fs: don't show mount options (Vivek Goyal) [1694161]
- [fs] virtio-fs: Change module name to virtiofs.ko (Vivek Goyal) [1694161]
- [include] bitops: protect variables in bit_clear_unless() macro (Vivek Goyal) [1694161]
- [include] bitops: protect variables in set_mask_bits() macro (Vivek Goyal) [1694161]
- [fs] fuse: Make fuse_args_to_req static (Vivek Goyal) [1694161]
- [fs] fuse: fix memleak in cuse_channel_open (Vivek Goyal) [1694161]
- [fs] fuse: fix beyond-end-of-page access in fuse_parse_cache() (Vivek Goyal) [1694161]
- [fs] fuse: unexport fuse_put_request (Vivek Goyal) [1694161]
- [fs] fuse: kmemcg account fs data (Vivek Goyal) [1694161]
- [fs] fuse: on 64-bit store time in d_fsdata directly (Vivek Goyal) [1694161]
- [fs] fuse: fix missing unlock_page in fuse_writepage() (Vivek Goyal) [1694161]
- [fs] virtio-fs: add virtiofs filesystem (Vivek Goyal) [1694161]
- [fs] fuse: allow skipping control interface and forced unmount (Vivek Goyal) [1694161]
- [fs] fuse: dissociate DESTROY from fuseblk (Vivek Goyal) [1694161]
- [fs] fuse: delete dentry if timeout is zero (Vivek Goyal) [1694161]
- [fs] fuse: separate fuse device allocation and installation in fuse_conn (Vivek Goyal) [1694161]
- [fs] fuse: add fuse_iqueue_ops callbacks (Vivek Goyal) [1694161]
- [fs] fuse: extract fuse_fill_super_common() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_dequeue_forget() function (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_get_unique() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_send_init_request() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_len_args() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_end_request() (Vivek Goyal) [1694161]
- [fs] fuse: fix request limit (Vivek Goyal) [1694161]
- [fs] fuse: stop copying pages to fuse_req (Vivek Goyal) [1694161]
- [fs] fuse: stop copying args to fuse_req (Vivek Goyal) [1694161]
- [fs] fuse: clean up fuse_req (Vivek Goyal) [1694161]
- [fs] fuse: simplify request allocation (Vivek Goyal) [1694161]
- [fs] fuse: unexport request ops (Vivek Goyal) [1694161]
- [fs] fuse: convert retrieve to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert release to simple api (Vivek Goyal) [1694161]
- [fs] cuse: convert init to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert init to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert writepages to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert readdir to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert readpages to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert direct_io to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add simple background helper (Vivek Goyal) [1694161]
- [fs] fuse: convert sync write to simple api (Vivek Goyal) [1694161]
- [fs] fuse: covert readpage to simple api (Vivek Goyal) [1694161]
- [fs] fuse: fuse_short_read(): don't take fuse_req as argument (Vivek Goyal) [1694161]
- [fs] fuse: convert ioctl to simple api (Vivek Goyal) [1694161]
- [fs] fuse: move page alloc (Vivek Goyal) [1694161]
- [fs] fuse: convert readlink to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add pages to fuse_args (Vivek Goyal) [1694161]
- [fs] fuse: convert destroy to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add nocreds to fuse_args (Vivek Goyal) [1694161]
- [fs] fuse: convert fuse_force_forget() to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add noreply to fuse_args (Vivek Goyal) [1694161]
- [fs] fuse: convert flush to simple api (Vivek Goyal) [1694161]
- [fs] fuse: simplify 'nofail' request (Vivek Goyal) [1694161]
- [fs] fuse: rearrange and resize fuse_args fields (Vivek Goyal) [1694161]
- [fs] fuse: flatten 'struct fuse_args' (Vivek Goyal) [1694161]
- [fs] fuse: fix deadlock with aio poll and fuse_iqueue::waitq.lock (Vivek Goyal) [1694161]
- [fs] cuse: fix broken release (Vivek Goyal) [1694161]
- [fs] fuse: cleanup fuse_wait_on_page_writeback (Vivek Goyal) [1694161]
- [fs] fuse: require /dev/fuse reads to have enough buffer capacity (take 2) (Vivek Goyal) [1694161]
- [fs] Revert "fuse: require /dev/fuse reads to have enough buffer capacity" (Vivek Goyal) [1694161]
- [fs] fuse: extract helper for range writeback (Vivek Goyal) [1694161]
- [fs] fuse: add FUSE_WRITE_KILL_PRIV (Vivek Goyal) [1694161]
- [fs] fuse: clean up fuse_alloc_inode (Vivek Goyal) [1694161]
- [fs] fuse: Add ioctl flag for x32 compat ioctl (Vivek Goyal) [1694161]
- [fs] fuse: document fuse_fsync_in.fsync_flags (Vivek Goyal) [1694161]
- [fs] fuse: require /dev/fuse reads to have enough buffer capacity (Vivek Goyal) [1694161]
- [fs] fuse: retrieve: cap requested size to negotiated max_write (Vivek Goyal) [1694161]
- [fs] fuse: allow filesystems to have precise control over data cache (Vivek Goyal) [1694161]
- [fs] fuse: convert printk -> pr_* (Vivek Goyal) [1694161]
- [fs] fuse: fix writepages on 32bit (Vivek Goyal) [1694161]
- [fs] fuse: cache readdir calls if filesystem opts out of opendir (Vivek Goyal) [1694161]
- [fs] fuse: support clients that don't implement 'opendir' (Vivek Goyal) [1694161]
- [fs] fuse: lift bad inode checks into callers (Vivek Goyal) [1694161]
- [fs] fuse: multiplex cached/direct_io file operations (Vivek Goyal) [1694161]
- [fs] fuse add copy_file_range to direct io fops (Vivek Goyal) [1694161]
- [fs] fuse: use iov_iter based generic splice helpers (Vivek Goyal) [1694161]
- [fs] fuse: Switch to using async direct IO for FOPEN_DIRECT_IO (Vivek Goyal) [1694161]
- [fs] fuse: use atomic64_t for khctr (Vivek Goyal) [1694161]
- [fs] fuse: clean up aborted (Vivek Goyal) [1694161]
- [fs] fuse: Protect ff->reserved_req via corresponding fi->lock (Vivek Goyal) [1694161]
- [fs] fuse: Protect fi->nlookup with fi->lock (Vivek Goyal) [1694161]
- [fs] fuse: Introduce fi->lock to protect write related fields (Vivek Goyal) [1694161]
- [fs] fuse: Convert fc->attr_version into atomic64_t (Vivek Goyal) [1694161]
- [fs] fuse: Add fuse_inode argument to fuse_prepare_release() (Vivek Goyal) [1694161]
- [fs] fuse: Verify userspace asks to requeue interrupt that we really sent (Vivek Goyal) [1694161]
- [fs] fuse: Do some refactoring in fuse_dev_do_write() (Vivek Goyal) [1694161]
- [fs] fuse: Wake up req->waitq of only if not background (Vivek Goyal) [1694161]
- [fs] fuse: Optimize request_end() by not taking fiq->waitq.lock (Vivek Goyal) [1694161]
- [fs] fuse: Kill fasync only if interrupt is queued in queue_interrupt() (Vivek Goyal) [1694161]
- [fs] fuse: Remove stale comment in end_requests() (Vivek Goyal) [1694161]
- [fs] fuse: Replace page without copying in fuse_writepage_in_flight() (Vivek Goyal) [1694161]
- [fs] fuse: fix leaked aux requests (Vivek Goyal) [1694161]
- [fs] fuse: only reuse auxiliary request in fuse_writepage_in_flight() (Vivek Goyal) [1694161]
- [fs] fuse: clean up fuse_writepage_in_flight() (Vivek Goyal) [1694161]
- [fs] fuse: extract fuse_find_writeback() helper (Vivek Goyal) [1694161]
- [fs] cuse: fix ioctl (Vivek Goyal) [1694161]
- [fs] fuse: Fix memory leak in fuse_dev_free() (Vivek Goyal) [1694161]
- [fs] fuse: fix revalidation of attributes for permission check (Vivek Goyal) [1694161]
- [fs] fuse: fix fsync on directory (Vivek Goyal) [1694161]
- [fs] fuse: Add bad inode check in fuse_destroy_inode() (Vivek Goyal) [1694161]
- [fs] fuse: enable caching of symlinks (Vivek Goyal) [1694161]
- [fs] fuse: only invalidate atime in direct read (Vivek Goyal) [1694161]
- [fs] fuse: realloc page array (Vivek Goyal) [1694161]
- [fs] fuse: add max_pages to init_out (Vivek Goyal) [1694161]
- [fs] fuse: allocate page array more efficiently (Vivek Goyal) [1694161]
- [fs] fuse: reduce size of struct fuse_inode (Vivek Goyal) [1694161]
- [fs] fuse: use iversion for readdir cache verification (Vivek Goyal) [1694161]
- [fs] fuse: use mtime for readdir cache verification (Vivek Goyal) [1694161]
- [fs] fuse: add readdir cache version (Vivek Goyal) [1694161]
- [fs] fuse: allow using readdir cache (Vivek Goyal) [1694161]
- [fs] fuse: allow caching readdir (Vivek Goyal) [1694161]
- [fs] fuse: extract fuse_emit() helper (Vivek Goyal) [1694161]
- [fs] fuse: add FOPEN_CACHE_DIR (Vivek Goyal) [1694161]
- [fs] fuse: split out readdir.c (Vivek Goyal) [1694161]
- [fs] fuse: Use hash table to link processing request (Vivek Goyal) [1694161]
- [fs] fuse: kill req->intr_unique (Vivek Goyal) [1694161]
- [fs] fuse: change interrupt requests allocation algorithm (Vivek Goyal) [1694161]
- [fs] fuse: do not take fc->lock in fuse_request_send_background() (Vivek Goyal) [1694161]
- [fs] fuse: introduce fc->bg_lock (Vivek Goyal) [1694161]
- [fs] fuse: add locking to max_background and congestion_threshold changes (Vivek Goyal) [1694161]
- [fs] fuse: use READ_ONCE on congestion_threshold and max_background (Vivek Goyal) [1694161]
- [fs] fuse: use list_first_entry() in flush_bg_queue() (Vivek Goyal) [1694161]
- [fs] fuse: reduce allocation size for splice_write (Vivek Goyal) [1694161]
- [fs] fuse: use kvmalloc to allocate array of pipe_buffer structs. (Vivek Goyal) [1694161]
- [fs] fuse: convert last timespec use to timespec64 (Vivek Goyal) [1694161]
- [fs] fs: fuse: Adding new return type vm_fault_t (Vivek Goyal) [1694161]
- [fs] fuse: simplify fuse_abort_conn() (Vivek Goyal) [1694161]
- [infiniband] RDMA/siw: Fix IPv6 addr_list locking (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix 64/32bit pointer inconsistency (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix SGL mapping issues (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix potential NULL de-ref (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Change CQ flags from 64->32 bits (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix a memory leak in siw_init_cpulist() (Kamal Heib) [1725830 1720892]
- [infiniband] Do not dereference 'siw_crypto_shash' before checking (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Remove set but not used variables 'rv' (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix error return code in siw_init_module() (Kamal Heib) [1725830 1720892]
- [infiniband] RMDA/siw: Require a 64 bit arch (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Mark expected switch fall-throughs (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: Remove set but not used variable 's' (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: Add missing dependencies on LIBCRC32C and DMA_VIRT_OPS (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Add missing rtnl_lock around access to ifa (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: Use proper enumerated type in map_cqe_status (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Remove unnecessary kthread create/destroy printouts (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix DEFINE_PER_CPU compilation when ARCH_NEEDS_WEAK_PER_CPU (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: addition to kernel build environment (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: completion queue methods (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: receive path (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: transmit path (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: queue pair methods (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: application buffer management (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: application interface (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: connection management (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: network and RDMA core interface (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: main include file (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: iWarp wire packet format (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/cma: fix null-ptr-deref Read in cma_cleanup (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Rewrite PID namespace check to be reliable (Kamal Heib) [1720892]
- [infiniband] RDMA/counters: Properly implement PID checks (Kamal Heib) [1720892]
- [infiniband] IB/core: Fix NULL pointer dereference when bind QP to counter (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Fix MR npages calculation for IB_ACCESS_HUGETLB (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix error code in stat_get_doit_qp() (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Prevent QP counter binding if counters unsupported (Kamal Heib) [1720892]
- [infiniband] RDMA/hns: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix -Wunused-const-variable warnings (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Added configuration of RDMA dynamic interrupt moderation to netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Provide RDMA DIM support for ULPs (Kamal Heib) [1720892]
- [infiniband] linux/dim: Implement RDMA adaptive moderation (DIM) (Kamal Heib) [1720892]
- [infiniband] IB/mad: Fix use-after-free in ib mad completion handling (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Track driver QP types in resource tracker (Kamal Heib) [1720892]
- [infiniband] RDMA/devices: Remove the lock around remove_client_context (Kamal Heib) [1720892]
- [infiniband] RDMA/devices: Do not deadlock during client removal (Kamal Heib) [1720892]
- [infiniband] IB/core: Add mitigation for Spectre V1 (Kamal Heib) [1720892]
- [infiniband] IB/counters: Always initialize the port counter object (Kamal Heib) [1720892]
- [infiniband] IB/core: Fix querying total rdma stats (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix race when resolving IP address (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Modernize ops->connect (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Remove rpcrdma_req::rl_buffer (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Refactor chunk encoding (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Streamline rpcrdma_post_recvs (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Simplify rpcrdma_rep_create (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Wake RPCs directly in rpcrdma_wc_send path (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Reduce context switching due to Local Invalidation (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Add mechanism to place MRs back on the free list (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Remove fr_state (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Remove the RPCRDMA_REQ_F_PENDING flag (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Fix occasional transport deadlock (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Replace use of xdr_stream_pos in rpcrdma_marshal_req (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Fix use-after-free in rpcrdma_post_recvs (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Make rdma_counter.h compile stand alone (Kamal Heib) [1720892]
- [infiniband] IB/core: Work on the caller socket net namespace in nldev_newlink() (Kamal Heib) [1663224 1720892]
- [infiniband] RDMA/rxe: Fill in wc byte_len with IB_WC_RECV_RDMA_WITH_IMM (Kamal Heib) [1720892]
- [infiniband] ibverbs/rxe: Remove variable self-initialization (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow get default counter statistics through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow get counter mode through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow counter manual mode configration through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Allow manual mode configuration support (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Get sum value of all counters when perform a sysfs stat read (Kamal Heib) [1720892]
- [infiniband] RDMA/netlink: Implement counter dumpit calback (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow counter auto mode configration through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Add "auto" configuration mode support (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Add set/clear per-port auto mode support (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Make is_visible_in_pid_ns() as an API (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Add an API to attach a task to a resource (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Introduce statistic counter (Kamal Heib) [1720892]
- [infiniband] IB/ipoib: Add child to parent list only if device initialized (Kamal Heib) [1720892]
- [infiniband] RDMA/uverbs: remove redundant assignment to variable ret (Kamal Heib) [1720892]
- [infiniband] IB/ipoib: Remove memset after vzalloc in ipoib_cm.c (Kamal Heib) [1720892]
- [infiniband] IB: Remove unneeded memset (Kamal Heib) [1720892]
- [infiniband] RDMA/netlink: Audit policy settings for netlink attributes (Kamal Heib) [1720892]
- [infiniband] docs: infiniband: convert docs to ReST and rename to *.rst (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Use IB_WR_REG_MR_INTEGRITY for PI handover (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Introduce rdma_rw_inv_key helper (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Validate integrity handover device cap (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Rename signature qp create flag and signature device capability (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Add an integrity MR pool support (Kamal Heib) [1720892]
- [infiniband] IB/iser: Unwind WR union at iser_tx_desc (Kamal Heib) [1720892]
- [infiniband] IB/iser: Use IB_WR_REG_MR_INTEGRITY for PI handover (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Introduce and implement new IB_WR_REG_MR_INTEGRITY work request (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Update set_sig_data_segment attribute for new signature API (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Pass UMR segment flags instead of boolean (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Add attr for max number page list length for PI operation (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Implement mlx5_ib_map_mr_sg_pi and mlx5_ib_alloc_mr_integrity (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Add signature attrs element for ib_mr structure (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Introduce ib_map_mr_sg_pi to map data/protection sgl's (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Introduce IB_MR_TYPE_INTEGRITY and ib_alloc_mr_integrity API (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Save the MR type in the ib_mr structure (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Introduce new header file for signature operations (Kamal Heib) [1720892]
- [infiniband] RDMA/odp: Do not leak dma maps when working with huge pages (Kamal Heib) [1720892]
- [infiniband] RDMA/uverbs: Use offsetofend instead of opencoding (Kamal Heib) [1720892]
- [infiniband] [scsi] scsi: RDMA/srp: Fix a sleep-in-invalid-context bug (Kamal Heib) [1720892]
- [infiniband] RDMA: Check umem pointer validity prior to release (Kamal Heib) [1720892]
- [infiniband] RDMA/hns: Remove asynchronic QP destroy (Kamal Heib) [1720892]
- [infiniband] RDMA: Convert destroy_wq to be void (Kamal Heib) [1720892]
- [infiniband] RDMA/netlink: Resort policy array (Kamal Heib) [1720892]
- [infiniband] RDMA: Report available cdevs through RDMA_NLDEV_CMD_GET_CHARDEV (Kamal Heib) [1720892]
- [infiniband] RDMA: Add NLDEV_GET_CHARDEV to allow char dev discovery and autoload (Kamal Heib) [1720892]
- [infiniband] ipoib: correcly show a VF hardware address (Kamal Heib) [1720892]
- [infiniband] RDMA: Move rdma_node_type to uapi/ (Kamal Heib) [1720892]
- [infiniband] rdma: Remove nes (Kamal Heib) [1720892]
- [infiniband] RDMA/ipoib: Remove check for ETH_SS_TEST (Kamal Heib) [1720892]
- [infiniband] RDMA: Convert CQ allocations to be under core responsibility (Kamal Heib) [1720892]
- [infiniband] RDMA/hns: Return correct error code from hns_roce_v1_rsv_lp_qp() (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Don't expose DMA addresses (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb4: Don't expose DMA addresses (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Use sizeof() notation instead of plain sizeof (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA: Clear CQ objects during their allocation (Kamal Heib) [1720892]
- [infiniband] RDMA: Clean destroy CQ in drivers do not return errors (Kamal Heib) [1720892]
- [infiniband] RDMA/i40iw: Remove useless NULL checks (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Delete and properly mark unimplemented resize CQ function (Kamal Heib) [1720892]
- [infiniband] RDMA/nes: Avoid memory allocation during CQ destroy (Kamal Heib) [1720892]
- [infiniband] RDMA: Move owner into struct ib_device_ops (Kamal Heib) [1720892]
- [infiniband] RDMA: Move uverbs_abi_ver into struct ib_device_ops (Kamal Heib) [1720892]
- [infiniband] RDMA: Move driver_id into struct ib_device_ops (Kamal Heib) [1720892]
- [infiniband] rdma: Delete the ib_ucm module (Kamal Heib) [1720892]
- [infiniband] ucma: Convert ctx_idr to XArray (Kamal Heib) [1720892]
- [infiniband] ucma: Convert multicast_idr to XArray (Kamal Heib) [1720892]
- [infiniband] RDMA/ucma: Use struct_size() helper (Kamal Heib) [1720892]
- [infiniband] RDMA/srp: Accept again source addresses that do not have a port number (Kamal Heib) [1720892]
- [infiniband] RDMA/ipoib: implement ethtool .get_link() callback (Kamal Heib) [1720892]
- [infiniband] RDMA/uverbs: check for allocation failure in uapi_add_elm() (Kamal Heib) [1720892]
- [infiniband] RDMA: Convert put_page() to put_user_page*() (Kamal Heib) [1720892]
- [infiniband] RDMA/nes: Remove second wait queue initialization call (Kamal Heib) [1720892]
- [infiniband] RDMA/nes: Remove useless NULL checks (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Make ib_destroy_cq() void (Kamal Heib) [1720892]
- [infiniband] RDMA/ipoib: Remove check of destroy CQ (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Return void from ib_device_check_mandatory() (Kamal Heib) [1720892]
- [infiniband] RDMA/umem: Move page_shift from ib_umem to ib_odp_umem (Kamal Heib) [1720892]
- [infiniband] RDMA/qedr: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb4: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix doc typo (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Add info regarding SG count failure (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Print the correct number of sig MRs (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Fix doc typo (Kamal Heib) [1720892]
- [infiniband] IB/isert: Remove unused sig_attrs argument (Kamal Heib) [1720892]
- [infiniband] IB/iser: Remove unused sig_attrs argument (Kamal Heib) [1720892]
- [infiniband] IB/iser: Refactor iscsi_iser_check_protection function (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Entropy in admin commands id (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Print address on AH creation failure (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Be consistent with success flow return value (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Use API to get contiguous memory blocks aligned to device supported page size (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove unused includes (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Use rdma block iterator in chunk list creation (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove unneeded admin commands abort flow (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Use kvzalloc instead of kzalloc with fallback (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove check that prevents destroy of resources in error flows (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Handle mmap insertions overflow (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Fix success return value in case of error (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove MAYEXEC flag check from mmap flow (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add driver to Kconfig/Makefile (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the efa module (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add EFA verbs implementation (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add common command handlers (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Implement functions that submit and complete admin commands (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the ABI definitions (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the com service API definitions (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the efa_com.h file (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the efa.h header file (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add EFA device definitions (Kamal Heib) [1720892]
- [infiniband] RDMA: Add EFA related definitions (Kamal Heib) [1720892]
- [fs] CIFS: Fix use after free of file info structures (Dave Wysochanski) [1757865]
- [mm] mm, memory_hotplug: fix scan_movable_pages() for gigantic hugepages (Rafael Aquini) [1730172]
- [char] ipmi: Don't allow device module unload when in use (Tony Camuso) [1759916]
- [netdrv] net: phy: Also request modules for C45 IDs (Gary Hook) [1764274]
- [s390] s390/dasd: Fix error handling during online processing (Philipp Rudo) [1764492]
- [s390] s390/cpumsf: Check for CPU Measurement sampling (Philipp Rudo) [1764490]
- [edac] EDAC/amd64: Support asymmetric dual-rank DIMMs (Gary Hook) [1753384]
- [edac] EDAC/amd64: Cache secondary Chip Select registers (Gary Hook) [1753384]
- [edac] EDAC/amd64: Decode syndrome before translating address (Gary Hook) [1753384]
- [edac] EDAC/amd64: Find Chip Select memory size using Address Mask (Gary Hook) [1753384]
- [edac] EDAC/amd64: Initialize DIMM info for systems with more than two channels (Gary Hook) [1753384]
- [edac] EDAC/amd64: Recognize DRAM device type ECC capability (Gary Hook) [1753384]
- [edac] EDAC/amd64: Support more than two controllers for chip selects handling (Gary Hook) [1753384]
- [scsi] scsi: fnic: fix msix interrupt allocation (Govindarajulu Varadarajan) [1745083]
- [scsi] scsi: fnic: print port speed only at driver init or speed change (Govindarajulu Varadarajan) [1745083]
- [netdrv] qmi_wwan: apply SET_DTR quirk to Sierra WP7607 (Lubomir Rintel) [1729083]

* Thu Nov 07 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-148.el8]
- [tools] libbpf: remove compile time warning from libbpf_util.h (Yauheni Kaliuta) [1747341]
- [tools] libbpf: remove dependency on barrier.h in xsk.h (Yauheni Kaliuta) [1747341]
- [kernel] seccomp, bpf: disable preemption before calling into bpf prog (Yauheni Kaliuta) [1747341]
- [lib] bpf: test_bpf: turn off preemption in function __run_once (Yauheni Kaliuta) [1747341]
- [tools] libbpf: remove unnecessary cast-to-void (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix sysctl.c warning (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix using uninitialized ioctl results (Yauheni Kaliuta) [1747341]
- [tools] libbpf: proper XSKMAP cleanup (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix invalid munmap call (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix XDP socket ring buffer memory ordering (Yauheni Kaliuta) [1747341]
- [tools] libbpf: remove likely/unlikely in xsk.h (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: xdp_redirect, correctly get dummy program id (Yauheni Kaliuta) [1747341]
- [net] bpf: fix access to skb_shared_info->gso_segs (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix out of bounds backwards jmps due to dead code removal (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix use after free in prog symbol exposure (Yauheni Kaliuta) [1747341]
- [include] bpf: Fix preempt_enable_no_resched() abuse (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test cases for pkt/null checks in subprogs (Yauheni Kaliuta) [1747341]
- [kernel] bpf: mark registers in all frames after pkt/null checks (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add binary to gitignore (Yauheni Kaliuta) [1747341]
- [net] bpf: Check address length before reading address family (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: disable preemption around BPF calls (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: switch kernel context to struct bpf_flow_dissector (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: fix clamping of BPF flow_keys for non-zero nhoff (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: allow access only to a subset of __sk_buff fields (Yauheni Kaliuta) [1747341]
- [net] net/flow_dissector: pass flow_keys->n_proto to BPF programs (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix vlan handling in flow dissector program (Yauheni Kaliuta) [1747341]
- [tools] bpf, libbpf: fix quiet install_headers (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add libelf dependency to shared library build (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add xsk.h to install_headers target (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add btf_dedup test for VOID equivalence check (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix btf_dedup equivalence check handling of different kinds (Yauheni Kaliuta) [1747341]
- [documentation] bpf, doc: fix BTF docs reflow of bullet list (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test case for invalid call stack in dead code (Yauheni Kaliuta) [1747341]
- [kernel] bpf: remove incorrect 'verifier bug' warning (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Only print ref_obj_id for refcounted reg (Yauheni Kaliuta) [1747341]
- [tools] tool: use bpf_program__get_prog_info_linear() in prog.c:do_dump() (Yauheni Kaliuta) [1747341]
- [tools] tools lib bpf: Introduce bpf_program__get_prog_info_linear() (Yauheni Kaliuta) [1747341]
- [tools] perf tools: Fix errors under optimization level '-Og' (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Try harder when allocating memory for large maps (Yauheni Kaliuta) [1747341]
- [tools] tools: bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add fwd enum resolution test for btf_dedup (Yauheni Kaliuta) [1747341]
- [tools] btf: resolve enum fwds in btf_dedup (Yauheni Kaliuta) [1747341]
- [tools] bpf: Add an example for bpf_get_listener_sock (Yauheni Kaliuta) [1747341]
- [tools] bpf: Test ref release issue in bpf_tcp_sock and bpf_sk_fullsock (Yauheni Kaliuta) [1747341]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747341]
- [net] bpf: Add bpf_get_listener_sock(struct bpf_sock *sk) helper (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Fix bpf_tcp_sock and bpf_sk_fullsock issue related to bpf_sk_release (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix to reject unknown flags in xsk_socket__create() (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix segfault of test_progs when prog loading failed (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix replace_map_fd_with_map_ptr's ldimm64 second imm field (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: test_progs: initialize duration in singal_pending test (Yauheni Kaliuta) [1747341]
- [tools] libbpf: force fixdep compilation at the start of the build (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: fix compilation with out-of-tree $(OUTPUT) (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test that GSO works in lwt_ip_encap (Yauheni Kaliuta) [1747341]
- [bpf] bpf: hbm: fix spelling mistake "deault" -> "default" (Yauheni Kaliuta) [1747341]
- [tools] bpf: add test cases for non-pointer sanitiation logic (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - misc (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - spinlock (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - tracepoint (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - stackmap (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - xdp (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - pkt access (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - preparations (Yauheni Kaliuta) [1747341]
- [bpf] bpf: HBM test script (Yauheni Kaliuta) [1747341]
- [bpf] bpf: User program for testing HBM (Yauheni Kaliuta) [1747341]
- [bpf] bpf: Sample HBM BPF program to limit egress bw (Yauheni Kaliuta) [1747341]
- [include] bpf: sync bpf.h to tools and update bpf_helpers.h (Yauheni Kaliuta) [1747341]
- [net] bpf: add bpf helper bpf_skb_ecn_set_ce (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: silence compiler warning for xdpsock_user.c (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: set unlimited RLIMIT_MEMLOCK for test_sock_fields (Yauheni Kaliuta) [1747341]
- [documentation] docs/bpf: minor casing/punctuation fixes (Yauheni Kaliuta) [1747341]
- [documentation] docs/btf: reflow text to fill up to 78 characters (Yauheni Kaliuta) [1747341]
- [documentation] docs/btf: fix typos, improve wording (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix u64_stats_init() usage in bpf_prog_alloc() (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add btf_dedup test of FWD/STRUCT resolution (Yauheni Kaliuta) [1747341]
- [tools] btf: allow to customize dedup hash table size (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix formatting for btf_ext__get_raw_data (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix btf_dedup testing code (Yauheni Kaliuta) [1747341]
- [tools] tools: libbpf: make sure readelf shows full names in build checks (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: use libbpf where easy (Yauheni Kaliuta) [1747341]
- [tools] tools: libbpf: add a correctly named define for map iteration (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: remove load_sock_ops in favour of bpftool (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: force IPv4 in ping (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: use __bpf_constant_htons in test_prog.c for flow dissector (Yauheni Kaliuta) [1747341]
- [tools] bpf: add missing entries to bpf_helpers.h (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: selftests: add map lookup to test_map_in_map bpf prog (Yauheni Kaliuta) [1747341]
- [kernel] bpf: set inner_map_meta->spin_lock_off correctly (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: fix: broken sample regarding removed function (Yauheni Kaliuta) [1747341]
- [tools] tools/bpftool: recognize bpf_prog_info run_time_ns and run_cnt (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: sync bpf.h into tools (Yauheni Kaliuta) [1747341]
- [kernel] bpf: expose program stats via bpf_prog_info (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix build without bpf_syscall (Yauheni Kaliuta) [1747341]
- [kernel] bpf: enable program stats (Yauheni Kaliuta) [1747341]
- [kernel] bpf: check that BPF programs run with preemption disabled (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: convert xdpsock to use libbpf for AF_XDP access (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add support for using AF_XDP sockets (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: make sure signal interrupts BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Fix dummy program unloading for xdp_redirect samples (Yauheni Kaliuta) [1747341]
- [s390] s390/net: convert pnetids to ascii (Yauheni Kaliuta) [1747341]
- [net] bpf: add skb->queue_mapping write access from tc clsact (Yauheni Kaliuta) [1747341]
- [tools] tools/libbpf: support bigger BTF data sizes (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: test_lwt_ip_encap: add negative tests. (Yauheni Kaliuta) [1747341]
- [tools] libbpf: Introduce bpf_object__btf (Yauheni Kaliuta) [1747341]
- [tools] libbpf: Introduce bpf_map__resize (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: replace bzero with memset (Yauheni Kaliuta) [1747341]
- [net] net: fix GSO in bpf_lwt_push_ip_encap (Yauheni Kaliuta) [1747341]
- [net] net: fix double-free in bpf_lwt_xmit_reroute (Yauheni Kaliuta) [1747341]
- [net] bpf: fix memory leak in bpf_lwt_xmit_reroute (Yauheni Kaliuta) [1747341]
- [net] bpf: make LWTUNNEL_BPF dependent on INET (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: add test_lwt_ip_encap selftest (Yauheni Kaliuta) [1747341]
- [include] bpf: sync <kdir>/include/.../bpf.h with tools/include/.../bpf.h (Yauheni Kaliuta) [1747341]
- [net] bpf: add handling of BPF_LWT_REROUTE to lwt_bpf.c (Yauheni Kaliuta) [1747341]
- [net] ipv6_stub: add ipv6_route_input stub/proxy. (Yauheni Kaliuta) [1747341]
- [net] bpf: handle GSO in bpf_lwt_push_encap (Yauheni Kaliuta) [1747341]
- [net] bpf: implement BPF_LWT_ENCAP_IP mode in bpf_lwt_push_encap (Yauheni Kaliuta) [1747341]
- [net] bpf: add plumbing for BPF_LWT_ENCAP_IP in bpf_lwt_push_encap (Yauheni Kaliuta) [1747341]
- [net] bpf: offload: add priv field for drivers (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: doc, add text about feature-subcommand (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: relax sub-register mode compilation criteria (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: centre kernel bpf objects under new subdir "progs" (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: extend sub-register mode compilation to all bpf object files (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: add "alu32" to .gitignore (Yauheni Kaliuta) [1747341]
- [tools] bpf: Add test_sock_fields for skb->sk and bpf_tcp_sock (Yauheni Kaliuta) [1747341]
- [tools] bpf: Add skb->sk, bpf_sk_fullsock and bpf_tcp_sock tests to test_verifer (Yauheni Kaliuta) [1747341]
- [nclude] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Add struct bpf_tcp_sock and BPF_FUNC_tcp_sock (Yauheni Kaliuta) [1747341]
- [net] bpf: Refactor sock_ops_convert_ctx_access (Yauheni Kaliuta) [1747341]
- [net] bpf: Add state, dst_ip4, dst_ip6 and dst_port to bpf_sock (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Add a bpf_sock pointer to __sk_buff and a bpf_sk_fullsock helper (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: remove btf__get_strings() superseded by raw data API (Yauheni Kaliuta) [1747341]
- [tools] btf: expose API to work with raw btf_ext data (Yauheni Kaliuta) [1747341]
- [tools] btf: expose API to work with raw btf data (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add log_level to bpf_load_program_attr (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add missing strings.h include (Yauheni Kaliuta) [1747341]
- [s390] s390/net: move pnet constants (Yauheni Kaliuta) [1747341]
- [tools] bpf: test_maps: fix possible out of bound access warning (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: doc, fix incorrect text (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test reading the offloaded program (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add test for mixing generic and offload XDP (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: print traceback when test fails (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix the expected messages (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add const qualifier to btf__get_map_kv_tids() map_name parameter (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add "any alignment" annotation for some tests (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: use localhost in tcp_{server, client}.py (Yauheni Kaliuta) [1747341]
- [s390] s390: bpf: fix JMP32 code-gen (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: remove generated verifier/tests.h on 'make clean' (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Check the prog id before exiting (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Add a "force" flag to XDP samples (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Extend RLIMIT_MEMLOCK for xdp_{sample_pkts, router_ipv4} (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Convert XDP samples to libbpf usage (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: xdp_redirect_cpu have not need for read_trace_pipe (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test for BPF_F_LOCK (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: sync uapi/bpf.h (Yauheni Kaliuta) [1747341]
- [kernel] bpf: introduce BPF_F_LOCK flag (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add bpf_spin_lock C test (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add simple BPF_PROG_TEST_RUN examples for flow dissector (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add bpf_spin_lock verifier tests (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: sync include/uapi/linux/bpf.h (Yauheni Kaliuta) [1747341]
- [kernel] bpf: add support for bpf_spin_lock to cgroup local storage (Yauheni Kaliuta) [1747341]
- [kernel] bpf: introduce bpf_spin_lock (Yauheni Kaliuta) [1747341]
- [net] bpf: Correctly annotate implicit fall through in bpf_base_func_proto (Yauheni Kaliuta) [1747341]
- [kernel] bpf, cgroups: clean up kerneldoc warnings (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix bitrotted kerneldoc (Yauheni Kaliuta) [1747341]
- [include] bpf: BPF_PROG_TYPE_CGROUP_{SKB, SOCK, SOCK_ADDR} require cgroups enabled (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: mark verifier test that uses bpf_trace_printk as BPF_PROG_TYPE_TRACEPOINT (Yauheni Kaliuta) [1747341]
- [net] bpf: add BPF_PROG_TEST_RUN support for flow dissector (Yauheni Kaliuta) [1747341]
- [net] net/flow_dissector: move bpf case into __skb_flow_bpf_dissect (Yauheni Kaliuta) [1747341]
- [net] Revert "[net] flow_dissector: disable preemption around BPF calls" (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: warn about risky prog array updates (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: remove duplicated include (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up the rest of test_verifier (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_verifier (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: prepare for break up of verifier tests (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: makefile support sub-register code-gen test mode (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: functional and min/max reasoning unit tests for JMP32 (Yauheni Kaliuta) [1747341]
- [s390] s390: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [powerpc] ppc: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [arm64] arm64: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [x86] x86_64: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: JIT blinds support JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: interpreter support for JMP32 (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: teach cfg code about JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: disassembler support JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier support JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: refactor verifier min/max code for condition jump (Yauheni Kaliuta) [1747341]
- [include] bpf: allocate 0x06 to new eBPF instruction class JMP32 (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: suppress readelf stderr when probing for BTF support (Yauheni Kaliuta) [1747341]
- [net] bpf: allow BPF programs access skb_shared_info->gso_segs field (Yauheni Kaliuta) [1747341]
- [tools] tool: feature probing, change default action (Yauheni Kaliuta) [1747341]
- [kernel] bpf: notify offload JITs about optimizations (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: record original instruction index (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: add tests for dead code removal (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: remove unconditional branches by 0 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: remove dead code (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: hard wire branches to dead code (Yauheni Kaliuta) [1747341]
- [kernel] bpf: change parameters of call/branch offset adjustment (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: don't hardcode iptables/nc path in test_tcpnotify_user (Yauheni Kaliuta) [1747341]
- [tools] libbpf: Show supported ELF section names when failing to guess prog/attach type (Yauheni Kaliuta) [1747341]
- [documentation] bpf: btf: add btf documentation (Yauheni Kaliuta) [1747341]
- [kernel] perf: Make perf_event_output() propagate the output() return (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix a (false) compiler warning (Yauheni Kaliuta) [1747341]
- [tools] tool: add bash completion for peek/push/enqueue/pop/dequeue (Yauheni Kaliuta) [1747341]
- [tools] tool: add pop and dequeue commands (Yauheni Kaliuta) [1747341]
- [tools] tool: add push and enqueue commands (Yauheni Kaliuta) [1747341]
- [tools] tool: add peek command (Yauheni Kaliuta) [1747341]
- [tools] tool: don't print empty key/value for maps (Yauheni Kaliuta) [1747341]
- [tools] tool: make key optional in lookup command (Yauheni Kaliuta) [1747341]
- [tools] tool: make key and value optional in update command (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: support __int128 in bpftool map pretty dumper (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add bpffs pretty print test for int128 (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: refactor test_btf pretty printing for multiple map value formats (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add int128 raw test in test_btf (Yauheni Kaliuta) [1747341]
- [kernel] bpf: btf: support 128 bit integer type (Yauheni Kaliuta) [1747341]
- [tools] libbpf: don't define CC and AR (Yauheni Kaliuta) [1747341]
- [include] bpf: remove leftovers after v5.0 update (Yauheni Kaliuta) [1715770]
- [target] scsi: target: cxgbit: add support for IEEE_8021QAZ_APP_SEL_STREAM selector (Vishal Kulkarni) [1725820]
- [netdrv] cxgb4i: add support for IEEE_8021QAZ_APP_SEL_STREAM selector (Vishal Kulkarni) [1725818]
- [net] SUNRPC: Fix possible autodisconnect during connect due to old last_used (Dave Wysochanski) [1724692]
- [fs] NFSv4: Add lease_time and lease_expired to 'nfs4:' line of mountstats (Dave Wysochanski) [1727369]
- [scsi] scsi: zfcp: fix reaction on bit error threshold notification (Philipp Rudo) [1764494]
- [iommu] iommu/arm-smmu: Error out only if not enough context interrupts (Mark Langsdorf) [1658736]
- [netdrv] cxgb4:Fix out-of-bounds MSI-X info array access (Vishal Kulkarni) [1763194]
- [fs] vfs: Fix EOVERFLOW testing in put_compat_statfs64 (Eric Sandeen) [1757902]
- [security] selinux: fix context string corruption in convert_context() (Ondrej Mosnacek) [1758086]
- [fs] cifs: use cifsInodeInfo->open_file_lock while iterating to avoid a panic (Dave Wysochanski) [1757865]
- [kernel] alarmtimer: Use EOPNOTSUPP instead of ENOTSUPP (Vladis Dronov) [1760638]
- [netdrv] cxgb4: RHEL-only disable device dump (Jonathan Toppins) [1708456]
- [fs] xfs: Fix deadlock between AGI and AGF with RENAME_WHITEOUT (Brian Foster) [1759564]
- [x86] x86/stacktrace: Prevent access_ok() warnings in arch_stack_walk_user() (Jerome Marchand) [1757758]
- [s390] s390/sclp: Fix bit checked for has_sipl (Philipp Rudo) [1748347]
- [fs] dax: dax_layout_busy_page() should not unmap cow pages (Jeff Moyer) [1752109]
- [fs] dax: Fix missed wakeup in put_unlocked_entry() (Jeff Moyer) [1752109]
- [fs] dax: Fix missed wakeup with PMD faults (Jeff Moyer) [1752109]
- [fs] dax: Fix xarray entry association for mixed mappings (Jeff Moyer) [1752109]
- [mm] mm: page_mkclean vs MADV_DONTNEED race (Jeff Moyer) [1752109]
- [fs] dax: Flush partial PMDs correctly (Jeff Moyer) [1752109 1724979]
- [fs] dax: Use non-exclusive wait in wait_entry_unlocked() (Jeff Moyer) [1752109]
- [x86] x86/mm: Fix decoy address handling vs 32-bit builds (Jeff Moyer) [1752109 1585079]
- [fs] dax: Fix unlock mismatch with updated API (Jeff Moyer) [1752109 1724956]
- [fs] dax: Don't access a freed inode (Jeff Moyer) [1752109 1724956]
- [fs] dax: Check page->mapping isn't NULL (Jeff Moyer) [1752109 1585079 1724956]
- [fs] dax: Avoid losing wakeup in dax_lock_mapping_entry (Jeff Moyer) [1752109]
- [fs] dax: Fix huge page faults (Jeff Moyer) [1752109]
- [fs] dax: Fix dax_unlock_mapping_entry for PMD pages (Jeff Moyer) [1752109]
- [fs] dax: Reinstate RCU protection of inode (Jeff Moyer) [1752109]
- [fs] dax: Make sure the unlocking entry isn't locked (Jeff Moyer) [1752109]
- [fs] dax: Remove optimisation from dax_lock_mapping_entry (Jeff Moyer) [1752109]
- [fs] dax: Convert page fault handlers to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax_lock_mapping_entry to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax writeback to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert __dax_invalidate_entry to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax_layout_busy_page to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax_insert_pfn_mkwrite to XArray (Jeff Moyer) [1752109]
- [fs] dax: Hash on XArray instead of mapping (Jeff Moyer) [1752109]
- [fs] dax: Rename some functions (Jeff Moyer) [1752109]
- [fs] dax: Fix deadlock in dax_lock_mapping_entry() (Jeff Moyer) [1752109 1585079 1641544]
- [drivers] device-dax: Add missing address_space_operations (Jeff Moyer) [1752109 1585079]
- [x86] x86/mm/pat: Prepare {reserve, free}_memtype() for "decoy" addresses (Jeff Moyer) [1752109 1585079]
- [mm] mm, memory_failure: Teach memory_failure() about dev_pagemap pages (Jeff Moyer) [1703560 1752109 1585079]
- [fs] filesystem-dax: Introduce dax_lock_mapping_entry() (Jeff Moyer) [1752109 1585079]
- [mm] mm, memory_failure: Collect mapping size in collect_procs() (Jeff Moyer) [1752109 1585079]
- [mm] mm, madvise_inject_error: Let memory_failure() optionally take a page reference (Jeff Moyer) [1752109 1585079]
- [mm] mm, madvise_inject_error: Disable MADV_SOFT_OFFLINE for ZONE_DEVICE pages (Jeff Moyer) [1752109 1585079]
- [fs] filesystem-dax: Set page->index (Jeff Moyer) [1752109 1585079]
- [drivers] device-dax: Set page->index (Jeff Moyer) [1752109 1585079]
- [drivers] device-dax: Enable page_mapping() (Jeff Moyer) [1752109 1585079]
- [drivers] device-dax: Convert to vmf_insert_mixed and vm_fault_t (Jeff Moyer) [1752109 1585079]
- [pci] PCI: Add quirk to disable MSI-X support for Amazon's Annapurna Labs Root Port (Myron Stowe) [1732357]
- [pci] PCI/VPD: Prevent VPD access for Amazon's Annapurna Labs Root Port (Myron Stowe) [1732357]
- [pci] PCI: Add ACS quirk for Amazon Annapurna Labs root ports (Myron Stowe) [1732357]
- [pci] PCI: Add Amazon's Annapurna Labs vendor ID (Myron Stowe) [1732357]
- [arm64] arm64: PCI: Preserve firmware configuration when desired (Myron Stowe) [1732372]
- [arm64] arm64: PCI: Allow resource reallocation if necessary (Myron Stowe) [1732372]
- [pci] PCI: Don't auto-realloc if we're preserving firmware config (Myron Stowe) [1732372]
- [pci] PCI/ACPI: Evaluate PCI Boot Configuration _DSM (Myron Stowe) [1732372]
- [irqchip] irqchip/gic-v2m: Add support for Amazon Graviton variant of GICv3+GICv2m (Myron Stowe) [1732382]
- [pci] PCI: al: Add Amazon Annapurna Labs PCIe host controller driver (Myron Stowe) [1732357]
- [netdrv] mlx4: fix spelling mistake "veify" -> "verify" (Alaa Hleihel) [1724340]
- [netdrv] IB/mlx4: Fix memory leaks (Alaa Hleihel) [1724340]
- [netdrv] net/mlx4_en: fix a memory leak bug (Alaa Hleihel) [1724340]
- [netdrv] IB/mlx4: Delete unused func arg (Alaa Hleihel) [1724340]
- [netdrv] net/mlx4_en: ethtool, Remove unsupported SFP EEPROM high pages query (Alaa Hleihel) [1724340 1724339]
- [netdrv] net/mlx4_core: Change the error print to info print (Alaa Hleihel) [1724340 1724339]
- [netdrv] mlx4: Convert pv_id_table to XArray (Alaa Hleihel) [1724340 1724339]
- [netdrv] IB/mlx4: Fix race condition between catas error reset and aliasguid flows (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: Fix qp mtt size calculation (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: Fix locking in SRIOV mode when switching between events and polling (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: Fix reset flow when in command polling mode (Alaa Hleihel) [1724340 1724338]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Alaa Hleihel) [1724340 1724338]
- [netdrv] IB/mlx4: Increase the timeout for CM cache (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: A write memory barrier is sufficient in EQ ci update (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4: Mark expected switch fall-through (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4: remove unneeded semicolon (Alaa Hleihel) [1724340 1724338]
- [parport] parport: parport_serial: Add support for Sunix Multi I/O boards (John Linville) [1663781]
- [tty] serial: 8250_pci: Add support for Sunix serial boards (John Linville) [1663781]
- [scsi] hpsa: update driver version (Joseph Szczypek) [1761968]
- [scsi] scsi: hpsa: add missing hunks in reset-patch (Joseph Szczypek) [1761968]
- [netdrv] igc: Clean up unused shadow_vfta pointer (David Arcari) [1721713]
- [netdrv] igc: Add Rx checksum support (David Arcari) [1721713]
- [netdrv] igc: Add set_rx_mode support (David Arcari) [1721713]
- [netdrv] igc: Add SCTP CRC checksumming functionality (David Arcari) [1721713]
- [netdrv] igc: Add tx_csum offload functionality (David Arcari) [1721713]
- [netdrv] igc: Remove unneeded PCI bus defines (David Arcari) [1721713]
- [netdrv] igc: Add NVM checksum validation (David Arcari) [1721713]
- [netdrv] igc: Remove useless forward declaration (David Arcari) [1721713]
- [netdrv] ethernet: Delete unnecessary checks before the macro call dev_kfree_skb (David Arcari) [1721713]
- [netdrv] igc: Add more SKUs for i225 device (David Arcari) [1721713]
- [netdrv] igc: Update the MAC reset flow (David Arcari) [1721713]
- [netdrv] igc: Remove the unused field from a device specification structure (David Arcari) [1721713]
- [netdrv] igc: Remove the polarity field from a PHY information structure (David Arcari) [1721713]
- [netdrv] net: Use skb accessors in network drivers (David Arcari) [1721713]
- [netdrv] igc: Prefer pcie_capability_read_word() (David Arcari) [1721713]
- [netdrv] igc: Cleanup the redundant code (David Arcari) [1721713]
- [netdrv] igc: Add flow control support (David Arcari) [1721713]
- [netdrv] igc: Remove the obsolete workaround (David Arcari) [1721713]
- [netdrv] igc: Clean up unused pointers (David Arcari) [1721713]
- [netdrv] igc: Fix double definitions (David Arcari) [1721713]
- [netdrv] igb/igc: warn when fatal read failure happens (David Arcari) [1721713]
- [scsi] scsi: qla2xxx: Fix different size DMA Alloc/Unmap (Himanshu Madhani) [1753031]
- [scsi] qla2xxx: call dma_free_coherent with correct size in all cases in qla24xx_sp_unmap (Himanshu Madhani) [1753031]
- [arm64] crypto: arm64/crc32 - remove PMULL based CRC32 driver (Mark Salter) [1742821]
- [arm64] arm64/lib: improve CRC32 performance for deep pipelines (Mark Salter) [1742821]
- [arm64] arm64/lib: add accelerated crc32 routines (Mark Salter) [1742821]
- [arm64] arm64: cpufeature: add feature for CRC32 instructions (Mark Salter) [1742821]
- [lib] lib/crc32: make core crc32() routines weak so they can be overridden (Mark Salter) [1742821]
- [arm64] arm64: cpu: Move errata and feature enable callbacks closer to callers (Mark Salter) [1742821]
- [arm64] arm64: kill config_sctlr_el1() (Mark Salter) [1742821]
- [include] ethtool: Add SFF-8436 and SFF-8636 max EEPROM length definitions (Petr Oros) [1757522]
- [net] bridge/mdb: remove wrong use of NLM_F_MULTI (Hangbin Liu) [1756799]
- [net] bridge: mcast: don't delete permanent entries when fast leave is enabled (Hangbin Liu) [1756799]
- [net] bridge: multicast: use rcu to access port list from br_multicast_start_querier (Hangbin Liu) [1756799]
- [net] bridge: Fix ethernet header pointer before check skb forwardable (Hangbin Liu) [1756799]
- [net] clear skb->tstamp in bridge forwarding path (Hangbin Liu) [1756799]
- [net] bridge: br_arp_nd_proxy: set icmp6_router if neigh has NTF_ROUTER (Hangbin Liu) [1756799]
- [net] vlan: Inherit MPLS features from parent device (Hangbin Liu) [1724306]
- [netdrv] linux/dim: Fix overflow in dim calculation (Ivan Vecera) [1737807]
- [lib] dim: Fix -Wunused-const-variable warnings (Ivan Vecera) [1737807]
- [lib] linux/dim: Add completions count to dim_sample (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Move implementation to .c files (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Rename externally used net_dim members (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Rename net_dim_sample() to net_dim_update_sample() (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Rename externally exposed macros (Ivan Vecera) [1737807]
- [include] linux/dim: Remove "net" prefix from internal DIM members (Ivan Vecera) [1737807]
- [include] linux/dim: Move logic to dim.h (Ivan Vecera) [1737807]
- [tools] selftests: add a test case for cls_lower handle overflow (Ivan Vecera) [1761512]
- [net] idr: introduce idr_for_each_entry_continue_ul() (Ivan Vecera) [1761512]
- [net] idr: fix overflow case for idr_for_each_entry_ul() (Ivan Vecera) [1761512]
- [net] sctp: add chunks to sk_backlog when the newsk sk_socket is not set (Xin Long) [1734271]
- [net] netns: enable to dump full nsid translation table (Petr Oros) [1757748]
- [net] netns: enable to specify a nsid for a get request (Petr Oros) [1757748]
- [net] netns: add support of NETNSA_TARGET_NSID (Petr Oros) [1757748]
- [net] netns: introduce 'struct net_fill_args' (Petr Oros) [1757748]
- [net] netns: remove net arg from rtnl_net_fill() (Petr Oros) [1757748]
- [net] mpls: fix warning with multi-label encap (Hangbin Liu) [1756788]
- [net] mpls: Return error for RTA_GATEWAY attribute (Hangbin Liu) [1756788]
- [net] macsec: drop skb sk before calling gro_cells_receive (Xin Long) [1745819]
- [net] team: add ethtool get_link_ksettings (Hangbin Liu) [1724896]
- [net] sched: flower: don't call synchronize_rcu() on mask creation (Ivan Vecera) [1751856]
- [net] sched: flower: refactor reoffload for concurrent access (Ivan Vecera) [1751856]
- [net] sched: flower: fix filter net reference counting (Ivan Vecera) [1751856]
- [net] sched: flower: use correct ht function to prevent duplicates (Ivan Vecera) [1751856]
- [net] sched: flower: insert filter to ht before offloading it to hw (Ivan Vecera) [1751856]
- [net] sched: ensure tc flower reoffload takes filter ref (Ivan Vecera) [1751856]
- [net] sched: flower: set unlocked flag for flower proto ops (Ivan Vecera) [1751856]
- [net] sched: flower: track rtnl lock state (Ivan Vecera) [1751856]
- [net] sched: flower: protect flower classifier state with spinlock (Ivan Vecera) [1751856]
- [net] sched: flower: handle concurrent tcf proto deletion (Ivan Vecera) [1751856]
- [net] sched: flower: handle concurrent filter insertion in fl_change (Ivan Vecera) [1751856]
- [net] sched: flower: protect masks list with spinlock (Ivan Vecera) [1751856]
- [net] sched: flower: handle concurrent mask insertion (Ivan Vecera) [1751856]
- [net] sched: flower: add reference counter to flower mask (Ivan Vecera) [1751856]
- [net] sched: flower: track filter deletion with flag (Ivan Vecera) [1751856]
- [net] sched: flower: introduce reference counting for filters (Ivan Vecera) [1751856]
- [net] sched: flower: refactor fl_change (Ivan Vecera) [1751856]
- [net] sched: flower: don't check for rtnl on head dereference (Ivan Vecera) [1751856]
- [kernel] exit from RHEL 8.2 early ystream mode (Phillip Lougher)

* Fri Nov 01 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.13.el8]
- [x86] kvm: svm: Remove unneeded WBINVD and DF_FLUSH when starting SEV guests (Janakarajan Natarajan) [1762517]
- [x86] kvm: svm: Reduce WBINVD/DF_FLUSH invocations (Janakarajan Natarajan) [1762517]
- [x86] kvm: svm: Guard against DEACTIVATE when performing WBINVD/DF_FLUSH (Janakarajan Natarajan) [1762517]
- [x86] kvm: svm: Serialize access to the SEV ASID bitmap (Janakarajan Natarajan) [1762517]
- [xen] remove pre-xen3 fallback handlers (Vitaly Kuznetsov) [1759997]
- [net] SUNRPC: Count ops completing with tk_status < 0 (Dave Wysochanski) [1636572]
- [net] SUNRPC: Use proper printk specifiers for unsigned long long (Dave Wysochanski) [1636572]
- [net] SUNRPC: Move call to rpc_count_iostats before rpc_call_done (Dave Wysochanski) [1636572]
- [net] SUNRPC: Add tracking of RPC level errors (Dave Wysochanski) [1636572]
- [net] SUNRPC: Refactor rpc_restart_call/rpc_restart_call_prepare (Dave Wysochanski) [1636572]
- [net] SUNRPC: Fix up task signalling (Dave Wysochanski) [1636572]
- [net] SUNRPC: Track writers of the 'channel' file to improve cache_listeners_exist (Dave Wysochanski) [1741333]
- [net] sunrpc/cache: handle missing listeners better. (Dave Wysochanski) [1741333]
- [pci] PCI/ACPI: Advertise _HPX Type 3 support via _OSC (Myron Stowe) [1712756]
- [pci] PCI/ACPI: Implement _HPX Type 3 Setting Record (Myron Stowe) [1712756]
- [netdrv] e1000e: Add support for Comet Lake (David Arcari) [1764549]
- [netdrv] e1000e: Add support for S0ix (Ken Cox) [1721709]
- [netdrv] e1000e: Make speed detection on hotplugging cable more reliable (Ken Cox) [1721709]
- [netdrv] ethernet: Delete unnecessary checks before the macro call dev_kfree_skb (Ken Cox) [1721709]
- [netdrv] e1000e: add workaround for possible stalled packet (Ken Cox) [1721709]
- [netdrv] e1000e: Use dev_get_drvdata where possible (Ken Cox) [1721709]
- [netdrv] net: Use skb accessors in network drivers (Ken Cox) [1721709]
- [netdrv] e1000e: PCIm function state support (Ken Cox) [1721709]
- [netdrv] e1000e: Make watchdog use delayed work (Ken Cox) [1721709]
- [netdrv] e1000e: Reduce boot time by tightening sleep ranges (Ken Cox) [1721709]
- [netdrv] e1000e: Increase pause and refresh time (Ken Cox) [1721709]
- [scsi] scsi: megaraid_sas: Introduce module parameter for default queue depth (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Fix a compilation warning (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Make a bunch of functions static (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Make some functions static (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: fix panic on loading firmware crashdump (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: fix spelling mistake "megarid_sas" -> "megaraid_sas" (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Update driver version to 07.710.50.00 (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add module parameter for FW Async event logging (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enable msix_load_balance for Invader and later controllers (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Fix calculation of target ID (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Make some symbols static (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Update driver version to 07.710.06.00-rc1 (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Introduce various Aero performance modes (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Use high IOPS queues based on IO workload (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Set affinity for high IOPS reply queues (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enable coalescing for high IOPS queues (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add support for High IOPS queues (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add support for MPI toolbox commands (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Offload Aero RAID5/6 division calculations to driver (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: RAID1 PCI bandwidth limit algorithm is applicable for only Ventura (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: megaraid_sas: Add check for count returned by HOST_DEVICE_LIST DCMD (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Handle sequence JBOD map failure at driver level (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Don't send FPIO to RL Bypass queue (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: In probe context, retry IOC INIT once if firmware is in fault (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Release Mutex lock before OCR in case of DCMD timeout (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Call disable_irq from process IRQ poll (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Remove few debug counters from IO path (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add support for Non-secure Aero PCI IDs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add 32 bit atomic descriptor support to AERO adapters (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Use struct_size() helper (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Remove unused including <linux/version.h> (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: use DEVICE_ATTR_{RO, RW} (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: use octal permissions instead of constants (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: make max_sectors visible in sys (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variables 'buff_addr' and 'ci_h' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variable 'sge_sz' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variables 'host' and 'wait_time' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variable 'cur_state' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Update driver version to 07.708.03.00 (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Export RAID map through debugfs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Fix MSI-X vector print (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add debug prints for device list (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add prints in suspend and resume path (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Print firmware interrupt status (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Print FW fault information (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Export RAID map id through sysfs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Print BAR information from driver (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Dump system registers for debugging (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Dump system interface regs from sysfs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add formatting option for megasas_dump (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enhance internal DCMD timeout prints (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enhance prints in OCR and TM path (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Load balance completions across all MSI-X (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: IRQ poll to avoid CPU hard lockups (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Block PCI config space access from userspace during OCR (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Rework code around controller reset (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: fw_reset_no_pci_access required for MFI adapters only (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Remove unused variable target_index (Tomas Henzl) [1726251]
- [x86] perf/x86/msr: Add Comet Lake CPU support (Michael Petlan) [1763290]
- [x86] perf/x86/intel: Add Comet Lake CPU support (Michael Petlan) [1763290]
- [x86] perf/x86/cstate: Add Comet Lake CPU support (Michael Petlan) [1763290]
- [x86] perf/x86/intel: Update KBL Package C-state events to also include PC8/PC9/PC10 counters (Michael Petlan) [1763290]
- [x86] x86/cpu: Add Comet Lake to the Intel CPU models header (Michael Petlan) [1763290]
- [s390] s390/qeth: reject oversized SNMP requests (Philipp Rudo) [1726414]
- [s390] s390/qeth: serialize cmd reply with concurrent timeout (Philipp Rudo) [1726414]
- [s390] s390/qeth: move cast type selection into fill_header() (Philipp Rudo) [1726414]
- [s390] s390/qeth: extract helper for route validation (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate skb RX processing in L3 driver (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate pm code (Philipp Rudo) [1726414]
- [s390] s390/qeth: streamline SNMP cmd code (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove static cmd buffer infrastructure (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate MPC cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate vnicc cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate diag cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate various cmds with sub-types (Philipp Rudo) [1726414]
- [s390] s390/qeth: clarify parameter for simple assist cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate simple IPA cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: allocate a single cmd on read channel (Philipp Rudo) [1726414]
- [s390] s390/qeth: command-chain the IDX sequence (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert RCD code to common IO infrastructure (Philipp Rudo) [1726414]
- [s390] s390/qeth: add support for dynamically allocated cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove 'channel' parameter from callbacks (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert device-specific trace entries (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove OSN-specific IO code (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove qeth_wait_for_buffer() (Philipp Rudo) [1726414]
- [s390] s390/qeth: clean up setting of BLKT defaults (Philipp Rudo) [1726414]
- [s390] s390/qeth: restart pending READ cmd from callback (Philipp Rudo) [1726414]
- [s390] s390/qeth: simplify DOWN state handling (Philipp Rudo) [1726414]
- [s390] s390/qeth: use mm helpers (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't mask TX errors on IQD devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle error when updating TX queue count (Philipp Rudo) [1726414]
- [s390] s390/qeth: fix VLAN attribute in bridge_hostnotify udev event (Philipp Rudo) [1726414]
- [s390] s390/qeth: check dst entry before use (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle limited IPv4 broadcast in L3 TX path (Philipp Rudo) [1726414]
- [s390] s390/qeth: trust non-IP cast type in qeth_l3_fill_header() (Philipp Rudo) [1726414]
- [s390] s390/qeth: extract helper to determine L2 cast type (Philipp Rudo) [1726414]
- [s390] s390/qeth: cache max number of available buffer elements (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't clear Output buffers on every queue init (Philipp Rudo) [1726414]
- [s390] s390/qeth: use IS_* helpers for checking device type (Philipp Rudo) [1726414]
- [s390] s390/qeth: clean up stale buffer state documentation (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove RX seqno in skb->cb (Philipp Rudo) [1726414]
- [s390] s390: qeth: address type mismatch warning (Philipp Rudo) [1726414]
- [s390] s390/qeth: stop/wake TX queues based on their fill level (Philipp Rudo) [1726414]
- [s390] s390/qeth: simplify QoS code (Philipp Rudo) [1726414]
- [s390] s390/qeth: add TX multiqueue support for OSA devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: add TX multiqueue support for IQD devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't keep statistics for tx timeout (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't bother updating the last-tx time (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle error from qeth_update_from_chp_desc() (Philipp Rudo) [1726414]
- [s390] s390/qeth: clarify naming for some QDIO helpers (Philipp Rudo) [1726414]
- [s390] s390/qeth: send IDX cmds via qeth_send_control_data() (Philipp Rudo) [1726414]
- [s390] s390/qeth: use callback to finalize cmd (Philipp Rudo) [1726414]
- [s390] s390/qeth: let qeth_notify_reply() set the notify reason (Philipp Rudo) [1726414]
- [s390] s390/qeth: clarify default cmd callback (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't poll for cmd IO completion (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert IP table spinlock to mutex (Philipp Rudo) [1726414]
- [s390] s390/qeth: defer IPv6 address notifier events (Philipp Rudo) [1726414]
- [s390] s390/qeth: add wrapper for IP table access (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove locking for RX modeset cache (Philipp Rudo) [1726414]
- [s390] s390/qeth: defer RX modesetting (Philipp Rudo) [1726414]
- [s390] s390/qeth: fix race when initializing the IP address table (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't erase configuration while probing (Philipp Rudo) [1726414]
- [s390] s390/qeth: drop redundant state checking (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't special-case HW trap during suspend (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove driver-wide workqueue (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't defer close_dev work during recovery (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove a redundant check for card->dev (Philipp Rudo) [1726414]
- [s390] s390/qeth: call dev_close() during recovery (Philipp Rudo) [1726414]
- [s390] s390/qeth: unconditionally clear MAC_REGISTERED flag (Philipp Rudo) [1726414]
- [s390] s390/qeth: enable/disable the HW trap a little earlier (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove RECOVER state (Philipp Rudo) [1726414]
- [s390] s390/qeth: split out OSN netdev ops (Philipp Rudo) [1726414]
- [s390] s390/qeth: add support for ETHTOOL_GRINGPARAM (Philipp Rudo) [1726414]
- [s390] s390/qeth: overhaul ethtool statistics (Philipp Rudo) [1726414]
- [s390] s390/qeth: move ethtool code into its own file (Philipp Rudo) [1726414]
- [s390] s390/qeth: reduce ethtool statistics (Philipp Rudo) [1726414]
- [s390] s390/qeth: use a static Output Queue array (Philipp Rudo) [1726414]
- [s390] s390/qeth: allow manual recovery when device is SOFTSETUP (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert remaining legacy cmd callbacks (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert bridgeport callbacks (Philipp Rudo) [1726414]
- [s390] s390/qeth: allow cmd callbacks to return errnos (Philipp Rudo) [1726414]
- [s390] s390/qeth: limit trace to valid data of command request (Philipp Rudo) [1726414]
- [s390] s390/qeth: align csum offload with TSO control logic (Philipp Rudo) [1726414]
- [s390] s390/qeth: enable only required csum offload features (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate filling of low-level cmd length fields (Philipp Rudo) [1726414]
- [s390] s390/qeth: reduce data length for ARP cache query (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove VLAN tracking for L2 devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: detach netdevice while card is offline (Philipp Rudo) [1726414]
- [s390] s390/qeth: delay netdevice registration (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove TX disable from online path (Philipp Rudo) [1726414]
- [s390] s390/qeth: register MAC address earlier (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate open/stop netdev ops (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove bogus netif_wake_queue() (Philipp Rudo) [1726414]
- [s390] s390/qeth: streamline TX buffer management (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't process hsuid in qeth_l3_setup_netdev() (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove unused fallback in Layer3's MAC code (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove two IPA command helpers (Philipp Rudo) [1726414]
- [s390] s390/qeth: replace open-coded cmd setup (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove card list (Philipp Rudo) [1726414]
- [s390] s390/qeth: unify transmit code (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle af_iucv skbs in qeth_l3_fill_header() (Philipp Rudo) [1726414]
- [s390] s390/qeth: sanitize ARP requests (Philipp Rudo) [1726414]
- [s390] s390/qdio: restrict QAOB usage to IQD unicast queues (Philipp Rudo) [1726414]
- [s390] s390/qdio: add sanity checks to the fast-requeue path (Philipp Rudo) [1726414]
- [s390] s390/qdio: don't touch the dsci in tiqdio_add_input_queues() (Philipp Rudo) [1726414]
- [s390] s390/qdio: (re-)initialize tiqdio list entries (Philipp Rudo) [1726414]
- [s390] s390/qdio: optimize state inspection of HW-owned SBALs (Philipp Rudo) [1726414]
- [s390] s390/qdio: use get_buf_state() in debug_get_buf_state() (Philipp Rudo) [1726414]
- [s390] s390/qdio: allow to scan all Output SBALs in one go (Philipp Rudo) [1726414]
- [s390] s390/qdio: consolidate index tracking for queue scan (Philipp Rudo) [1726414]
- [s390] s390/qdio: limit direct access to first_to_check cursor (Philipp Rudo) [1726414]
- [s390] s390/qdio: eliminate queue's last_move cursor (Philipp Rudo) [1726414]
- [s390] s390/qdio: simplify SBAL range calculation (Philipp Rudo) [1726414]
- [s390] s390/qdio: pass up count of ready-to-process SBALs (Philipp Rudo) [1726414]
- [s390] s390/qdio: fix output of DSCI value in debug file (Philipp Rudo) [1726414]
- [s390] s390/qdio: clean up qdio_check_outbound_after_thinint() (Philipp Rudo) [1726414]
- [s390] s390/qdio: clean up pci_out_supported() (Philipp Rudo) [1726414]
- [s390] s390/qdio: make SBAL address array type-safe (Philipp Rudo) [1726414]
- [s390] s390/qdio: clean up AOB handling (Philipp Rudo) [1726414]
- [s390] s390/ccwgroup: add get_ccwgroupdev_by_busid() (Philipp Rudo) [1726414]

* Wed Oct 30 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.12.el8]
- [net] xprtrdma: Remove stale comment (Kamal Heib) [1720891]
- [net] xprtrdma: Update comments that reference ib_drain_qp (Kamal Heib) [1720891]
- [net] xprtrdma: Remove pr_err() call sites from completion handlers (Kamal Heib) [1720891]
- [net] xprtrdma: Eliminate struct rpcrdma_create_data_internal (Kamal Heib) [1720891]
- [net] xprtrdma: Aggregate the inline settings in struct rpcrdma_ep (Kamal Heib) [1720891]
- [net] xprtrdma: Remove rpcrdma_create_data_internal::rsize and wsize (Kamal Heib) [1720891]
- [net] xprtrdma: Eliminate rpcrdma_ia::ri_device (Kamal Heib) [1720891]
- [net] xprtrdma: More Send completion batching (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up sendctx functions (Kamal Heib) [1720891]
- [net] xprtrdma: Trace marshaling failures (Kamal Heib) [1720891]
- [net] xprtrdma: Increase maximum number of backchannel requests (Kamal Heib) [1720891]
- [net] xprtrdma: Backchannel can use GFP_KERNEL allocations (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up regbuf helpers (Kamal Heib) [1720891]
- [net] xprtrdma: De-duplicate "allocate new, free old regbuf" (Kamal Heib) [1720891]
- [net] xprtrdma: Allocate req's regbufs at xprt create time (Kamal Heib) [1720891]
- [net] xprtrdma: rpcrdma_regbuf alignment (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up rpcrdma_create_rep() and rpcrdma_destroy_rep() (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up rpcrdma_create_req() (Kamal Heib) [1720891]
- [scsi] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 502 (Kamal Heib) [1720891]
- [infiniband] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Kamal Heib) [1720891]
- [net] xprtrdma: Use struct_size() in kzalloc() (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Fix panic when port_data isn't initialized (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Pass udata on uverbs error unwind (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Clear out the udata before error unwind (Kamal Heib) [1720891]
- [infiniband] RDMA/srp: Rename SRP sysfs name after IB device rename trigger (Kamal Heib) [1720891]
- [infiniband] treewide: Add SPDX license identifier - Makefile/Kconfig (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Change system parameters callback from dumpit to doit (Kamal Heib) [1720891]
- [infiniband] RDMA: Directly cast the sockaddr union to sockaddr (Kamal Heib) [1720891]
- [infiniband] RDMA/ipoib: Allow user space differentiate between valid dev_port (Kamal Heib) [1720891]
- [infiniband] RDMA/device: Don't fire uevent before device is fully initialized (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Remove hugetlb flag (Kamal Heib) [1720891]
- [infiniband] RDMA/bnxt_re: Use core helpers to get aligned DMA address (Kamal Heib) [1720891]
- [infiniband] RDMA/bnxt_re: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720891]
- [infiniband] RDMA/i40iw: Use core helpers to get aligned DMA address within a supported page size (Kamal Heib) [1720891]
- [infiniband] RDMA/i40iw: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720891]
- [infiniband] RDMA/verbs: Add a DMA iterator to return aligned contiguous memory blocks (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Add API to find best driver supported page size in an MR (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Allow detaching gid attribute netdevice for RoCE (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Use rdma_read_gid_attr_ndev_rcu to access netdev (Kamal Heib) [1720891]
- [infiniband] RDMA/cma: Use rdma_read_gid_attr_ndev_rcu to access netdev (Kamal Heib) [1720891]
- [infiniband] RDMA: Introduce and use GID attr helper to read RoCE L2 fields (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Add vlan enable bit for hip08 (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Update some fields of qp context (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Delete unused variable in hns_roce_v2_modify_qp function (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Add enable judgement for UD vlan (Kamal Heib) [1720891]
- [infiniband] IB/mlx5: Consider vlan of lower netdev for macvlan GID entries (Kamal Heib) [1720891]
- [infiniband] IB/cm: Reduce dependency on gid attribute ndev check (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Consider skb reserve space based on netdev of GID (Kamal Heib) [1720891]
- [infiniband] RDMA: Get rid of iw_cm_verbs (Kamal Heib) [1720891]
- [infiniband] RDMA/cxgb4: Use ib_device_set_netdev() (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Do not invoke init_port on compat devices (Kamal Heib) [1720891]
- [infiniband] IB/core: Set qp->real_qp before it may be accessed (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Initialize uverbs_attr_bundle ucontext in ib_uverbs_get_context (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Initialize udata struct on destroy flows (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Handle page combining avoidance correctly in ib_umem_add_sg_table() (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Introduce RDMA subsystem ibdev_* print functions (Kamal Heib) [1720891]
- [infiniband] uverbs: Convert idr to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA: Remove rdma_user_mmap_page (Kamal Heib) [1720891]
- [infiniband] RDMA/mlx5: Use get_zeroed_page() for clock_info (Kamal Heib) [1720891]
- [infiniband] RDMA/mlx5: Do not allow the user to write to the clock page (Kamal Heib) [1720891]
- [infiniband] RDMA/cma: Consider scope_id while binding to ipv6 ll address (Kamal Heib) [1720891]
- [infiniband] IB/core: Allow vlan link local address based RoCE GIDs (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add a netlink command to change net namespace of rdma device (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Introduce a helper function to change net namespace of rdma device (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Avoid freeing netdevs in disable_device() (Kamal Heib) [1720891]
- [infiniband] RDMA/ocrdma: Remove use of idr use pci bdf instead (Kamal Heib) [1720891]
- [infiniband] RDMA/drivers: Convert easy drivers to use ib_device_set_netdev() (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Use correct value for SG entries in sg_copy_to_buffer() (Kamal Heib) [1720891]
- [infiniband] RDMA: Handle SRQ allocations by IB/core (Kamal Heib) [1720891]
- [infiniband] qedr: Convert srqidr to XArray (Kamal Heib) [1720891]
- [infiniband] qedr: Convert qpidr to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA: Handle AH allocations by IB/core (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Fix bad endianess of port_pd variable (Kamal Heib) [1720891]
- [infiniband] RDMA/mad: Reduce MAD scope to mlx5_ib only (Kamal Heib) [1720891]
- [infiniband] RDMA/ocrdma: Remove a set-but-not-used variable (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Support object allocation in atomic context (Kamal Heib) [1720891]
- [infiniband] IB: When attrs.udata/ufile is available use that instead of uobject (Kamal Heib) [1720891]
- [infiniband] RDMA/nldev: Return device protocol (Kamal Heib) [1720891]
- [infiniband] RDMA/cm: Move debug counters to be under relevant IB device (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Combine contiguous PAGE_SIZE regions in SGEs (Kamal Heib) [1720891]
- [infiniband] RDMA/cm: Remove useless zeroing of static global variable (Kamal Heib) [1720891]
- [infiniband] RDMA/cma: Set proper port number as index (Kamal Heib) [1720891]
- [infiniband] IB: Pass only ib_udata in function prototypes (Kamal Heib) [1720891]
- [infiniband] IB: Remove 'uobject->context' dependency in object destroy APIs (Kamal Heib) [1720891]
- [infiniband] cxgb4: Convert mmidr to XArray (Kamal Heib) [1720891]
- [infiniband] cxgb4: Convert qpidr to XArray (Kamal Heib) [1720891]
- [infiniband] cxgb4: Convert cqidr to XArray (Kamal Heib) [1720891]
- [infiniband] IB: Pass uverbs_attr_bundle down ib_x destroy path (Kamal Heib) [1720891]
- [infiniband] IB: Pass uverbs_attr_bundle down uobject destroy path (Kamal Heib) [1720891]
- [infiniband] IB: ucontext should be set properly for all cmd & ioctl paths (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Don't compare specific bit after boolean AND (Kamal Heib) [1720891]
- [infiniband] RDMA/netlink: Remove unused data structure (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add command to set ib_core device net namspace sharing mode (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add interface to read device namespace sharing mode (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Extend ib_device_get_by_index for net namespace (Kamal Heib) [1720891]
- [infiniband] RDMA: Check net namespace access for uverbs, umad, cma and nldev (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add module param to disable device sharing among net ns (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Support core port attributes in non init_net (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Implement compat device/sysfs tree in net namespace (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Restrict sysfs entries view to init_net (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Introduce ib_core_device to hold device (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Use correct sizing on buffers holding page DMA addresses (Kamal Heib) [1720891]
- [infiniband] RDMA/mthca: Use correct sizing on buffers holding page DMA addresses (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Allow the compiler to verify declaration and definition consistency (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Annotate uverbs_request_next_ptr() return value as a __user pointer (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Add a __user annotation to a pointer (Kamal Heib) [1720891]
- [infiniband] IB/rxe: Replace av->network_type with skb->protocol (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add SMP details to MAD tracing (Kamal Heib) [1720891]
- [infiniband] IB/UMAD: Add umad trace points (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add agent trace points (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add recv path trace point (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add send path trace points (Kamal Heib) [1720891]
- [infiniband] RDMA/vmw_pvrdma: Skip zeroing device attrs (Kamal Heib) [1720891]
- [infiniband] IB/iser: remove uninitialized variable len (Kamal Heib) [1720891]
- [infiniband] IB/core: Ensure an invalidate_range callback on ODP MR (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Fix slab-out-bounds access which lead to kernel crash later (Kamal Heib) [1720891]
- [infiniband] drivers: infiniband: Fix whitespace in kconfig (Kamal Heib) [1720891]
- [infiniband] RDMA/nes: remove redundant check on udata (Kamal Heib) [1720891]
- [infiniband] cma: Convert portspace IDRs to XArray (Kamal Heib) [1720891]
- [infiniband] ucm: Convert ctx_id_table to XArray (Kamal Heib) [1720891]
- [infiniband] ib core: Convert query_idr to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA/cm: Convert local_id_table to XArray (Kamal Heib) [1720891]
- [infiniband] IB/mad: Convert ib_mad_clients to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA: Use __packed annotation instead of __attribute__ ((packed)) (Kamal Heib) [1720891]
- [char] tpm: Remove a deprecated comments about implicit sysfs locking (Jerry Snitselaar) [1725580 1742257]
- [char] tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for interrupts (Jerry Snitselaar) [1725580 1742257]
- [char] tpm_tis_core: Turn on the TPM before probing IRQ's (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Fix null pointer dereference on chip register error path (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Fix TPM 1.2 Shutdown sequence to prevent future TPM operations (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Actually fail on TPM errors during "get random" (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 505 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 399 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Add SPDX license identifier - Makefile/Kconfig (Jerry Snitselaar) [1725580 1742257]
- [tools] selftests/tpm2: Open tpm dev in unbuffered mode (Jerry Snitselaar) [1725580 1742257]
- [tools] selftests/tpm2: Extend tests to cover partial reads (Jerry Snitselaar) [1725580 1742257]
- [tools] selftests: add TPM 2.0 tests (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: fix -Wvarags warning (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: Move trusted.h to include/keys [ver #2] (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: Expose common functionality [ver #2] (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Wrap the buffer from the caller to tpm_buf in tpm_send() (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: correctly initialize digests and fix locking issue (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: allow module init if TPM is inactive or deactivated (Jerry Snitselaar) [1725580 1742257]
- [net] net/smc: make sure EPOLLOUT is raised (Philipp Rudo) [1726415]
- [net] net/smc: avoid fallback in case of non-blocking connect (Philipp Rudo) [1726415]
- [net] net/smc: do not schedule tx_work in SMC_CLOSED state (Philipp Rudo) [1726415]
- [net] net/smc: common release code for non-accepted sockets (Philipp Rudo) [1726415]
- [net] net/smc: Fix error path in smc_init (Philipp Rudo) [1726415]
- [net] net/smc: hold conns_lock before calling smc_lgr_register_conn() (Philipp Rudo) [1726415]
- [dma] dmaengine: ioatdma: support latency tolerance report (LTR) for v3.4 (Jerry Snitselaar) [1661996]
- [dma] dmaengine: ioatdma: add descriptor pre-fetch support for v3.4 (Jerry Snitselaar) [1661996]
- [dma] dmaengine: ioatdma: disable DCA enabling on IOATDMA v3.4 (Jerry Snitselaar) [1661996]
- [dma] dmaengine: ioatdma: Add Snow Ridge ioatdma device id (Jerry Snitselaar) [1661996]
- [kernel] mutex: Fix up mutex_waiter usage (Waiman Long) [1736609]
- [kernel] locking/mutex: Use mutex flags macro instead of hard code (Waiman Long) [1736609]
- [kernel] locking/mutex: Make __mutex_owner static to mutex.c (Waiman Long) [1736609]
- [kernel] locking/mutex: Test for initialized mutex (Waiman Long) [1736609]
- [kernel] kernel/locking/mutex.c: remove caller signal_pending branch predictions (Waiman Long) [1736609]
- [kernel] Revert "locking/pvqspinlock: Don't wait if vCPU is preempted" (Waiman Long) [1736609]
- [kernel] locking/rwsem: Check for operations on an uninitialized rwsem (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make handoff writer optimistically spin on owner (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add ACQUIRE comments (Waiman Long) [1736609]
- [tty] tty/ldsem, locking/rwsem: Add missing ACQUIRE to read_failed sleep loop (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath sleep loop (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath exit when queue is empty (Waiman Long) [1736609]
- [kernel] locking/rwsem: Don't call owner_on_cpu() on read-owner (Waiman Long) [1736609]
- [kernel] locking/rwsem: Guard against making count negative (Waiman Long) [1736609]
- [kernel] locking/rwsem: Adaptive disabling of reader optimistic spinning (Waiman Long) [1736609]
- [kernel] locking/rwsem: Enable time-based spinning on reader-owned rwsem (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make rwsem->owner an atomic_long_t (Waiman Long) [1736609]
- [kernel] locking/rwsem: Enable readers spinning on writer (Waiman Long) [1736609]
- [kernel] locking/rwsem: Clarify usage of owner's nonspinaable bit (Waiman Long) [1736609]
- [kernel] locking/rwsem: Wake up almost all readers in wait queue (Waiman Long) [1736609]
- [kernel] locking/rwsem: More optimal RT task handling of null owner (Waiman Long) [1736609]
- [kernel] locking/rwsem: Always release wait_lock before waking up tasks (Waiman Long) [1736609]
- [kernel] locking/rwsem: Implement lock handoff to prevent lock starvation (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make rwsem_spin_on_owner() return owner state (Waiman Long) [1736609]
- [kernel] locking/rwsem: Code cleanup after files merging (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add rwsem_init.c to keep __init_rwsem() kABI (Waiman Long) [1736609]
- [kernel] locking/rwsem: Merge rwsem.h and rwsem-xadd.c into rwsem.c (Waiman Long) [1736609]
- [kernel] locking/rwsem: Implement a new locking scheme (Waiman Long) [1736609]
- [kernel] locking/rwsem: Remove rwsem_wake() wakeup optimization (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make owner available even if !CONFIG_RWSEM_SPIN_ON_OWNER (Waiman Long) [1736609]
- [kernel] locking/lock_events: Use raw_cpu_{add, inc}() for stats (Waiman Long) [1736609]
- [kernel] locking/lock_events: Use this_cpu_add() when necessary (Waiman Long) [1736609]
- [kernel] locking/rwsem: Revert "[kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath ..." (Waiman Long) [1736609]
- [block] block: don't release queue's sysfs lock during switching elevator (Ming Lei) [1760151]
- [block] blk-mq: move lockdep_assert_held() into elevator_exit (Ming Lei) [1760151]
- [block] block: fix race between switching elevator and removing queues (Ming Lei) [1760151]
- [md] raid5: use bio_end_sector in r5_next_bio (Nigel Croxon) [1754949]
- [md] raid5: remove STRIPE_OPS_REQ_PENDING (Nigel Croxon) [1754949]
- [md] md: add feature flag MD_FEATURE_RAID0_LAYOUT (Nigel Croxon) [1754949]
- [md] md/raid0: avoid RAID0 data corruption due to layout confusion. (Nigel Croxon) [1754949]
- [md] raid5: don't set STRIPE_HANDLE to stripe which is in batch list (Nigel Croxon) [1754949]
- [md] raid5: don't increment read_errors on EILSEQ return (Nigel Croxon) [1754949]
- [md] md/raid5: use bio_end_sector to calculate last_sector (Nigel Croxon) [1730670]
- [md] md/raid1: fail run raid1 array when active disk less than one (Nigel Croxon) [1730670]
- [md] md raid0/linear: Mark array as 'broken' and fail BIOs if a member is gone (Nigel Croxon) [1730670]
- [md] raid5 improve too many read errors msg by adding limits (Nigel Croxon) [1730670]
- [md] md: don't report active array_state until after revalidate_disk() completes. (Nigel Croxon) [1730670]
- [md] md: only call set_in_sync() when it is expected to succeed. (Nigel Croxon) [1730670]
- [md] raid1: factor out a common routine to handle the completion of sync write (Nigel Croxon) [1730670]
- [md] md: don't call spare_active in md_reap_sync_thread if all member devices can't work (Nigel Croxon) [1730670]
- [md] md: don't set In_sync if array is frozen (Nigel Croxon) [1730670]
- [md] md: allow last device to be forcibly removed from RAID1/RAID10. (Nigel Croxon) [1730670]
- [md] md/raid10: end bio when the device faulty (Nigel Croxon) [1730670]
- [md] md/raid1: end bio when the device faulty (Nigel Croxon) [1730670]
- [md] md/raid6: Set R5_ReadError when there is read failure on parity disk (Nigel Croxon) [1730670]
- [md] raid1: use an int as the return value of raise_barrier() (Nigel Croxon) [1730670]
- [md] md/raid1: Fix a warning message in remove_wb() (Nigel Croxon) [1730670]
- [crypto] crypto: ccp - Fix SEV_VERSION_GREATER_OR_EQUAL (Gary Hook) [1754634]
- [crypto] crypto: ccp - Do not free psp_master when PLATFORM_INIT fails (Gary Hook) [1754634]
- [crypto] crypto: ccp - Use kmemdup in ccp_copy_and_save_keypart() (Gary Hook) [1754634]
- [crypto] crypto: ccp - introduce SEV_GET_ID2 command (Gary Hook) [1754634]
- [netdrv] e1000e: start network tx queue only when link is up (Oleksandr Natalenko) [1747869]
- [netdrv] Revert "e1000e: fix cyclic resets at link up with active tx" (Oleksandr Natalenko) [1747869]
- [mm] mm/zsmalloc.c: fix build when CONFIG_COMPACTION=n (Rafael Aquini) [1735181]
- [mm] mm/zsmalloc.c: fix race condition in zs_destroy_pool (Rafael Aquini) [1735181]
- [mm] mm/zsmalloc.c: migration can leave pages in ZS_EMPTY indefinitely (Rafael Aquini) [1735181]
- [mm] mm, page_owner: handle THP splits correctly (Rafael Aquini) [1735181]
- [mm] hugetlbfs: fix hugetlb page migration/fault race causing SIGBUS (Rafael Aquini) [1735181]
- [mm] mm/usercopy: use memory range to be accessed for wraparound check (Rafael Aquini) [1735181]
- [mm] mm/memcontrol.c: fix use after free in mem_cgroup_iter() (Rafael Aquini) [1735181]
- [mm] mm/hmm: fix bad subpage pointer in try_to_unmap_one (Rafael Aquini) [1735181]
- [mm] mm: vmscan: check if mem cgroup is disabled or not before calling memcg slab shrinker (Rafael Aquini) [1735181]
- [mm] mm: revert "kmemleak: allow to coexist with fault injection" (Rafael Aquini) [1735181]
- [mm] mm/vmalloc: sync unmappings in __purge_vmap_area_lazy() (Rafael Aquini) [1735181]
- [mm] mm/vmalloc.c: add priority threshold to __purge_vmap_area_lazy() (Rafael Aquini) [1735181]
- [mm] mm/cma.c: fail if fixed declaration can't be honored (Rafael Aquini) [1735181]
- [mm] mm/mmu_notifier: use hlist_add_head_rcu() (Rafael Aquini) [1735181]
- [mm] mm/mincore.c: fix race between swapoff and mincore (Rafael Aquini) [1735181]
- [mm] mm, swap: fix race between swapoff and some swap operations (Rafael Aquini) [1735181]
- [mm] mm/failslab.c: by default, do not fail allocations with direct reclaim only (Rafael Aquini) [1735181]
- [mm] mm: vmscan: scan anonymous pages on file refaults (Rafael Aquini) [1735181]
- [mm] mm/vmscan.c: prevent useless kswapd loops (Rafael Aquini) [1735181]
- [mm] mm/page_idle.c: fix oops because end_pfn is larger than max_pfn (Rafael Aquini) [1760459 1735181]
- [mm] mm/mempolicy.c: fix an incorrect rebind node in mpol_rebind_nodemask (Rafael Aquini) [1735181]
- [mm] mm/vmscan.c: fix trying to reclaim unevictable LRU page (Rafael Aquini) [1735181]
- [mm] mm/mlock.c: change count_mm_mlocked_page_nr return type (Rafael Aquini) [1735181]
- [mm] mm/mlock.c: mlockall error for flag MCL_ONFAULT (Rafael Aquini) [1735181]
- [mm] mm/list_lru.c: fix memory leak in __memcg_init_list_lru_node (Rafael Aquini) [1735181]
- [mm] memcg: make it work on sparse non-0-node systems (Rafael Aquini) [1735181]
- [mm] prctl_set_mm: downgrade mmap_sem to read lock (Rafael Aquini) [1735181]
- [mm] mm/debug.c: fix __dump_page when mapping->host is not set (Rafael Aquini) [1735181]
- [mm] mm/debug.c: fix __dump_page() for poisoned pages (Rafael Aquini) [1735181]
- [mm] mm: update references to page _refcount (Rafael Aquini) [1735181]
- [mm] mm: lower the printk loglevel for __dump_page messages (Rafael Aquini) [1735181]
- [mm] mm: print more information about mapping in __dump_page (Rafael Aquini) [1735181]
- [mm] hugetlb: use same fault hash key for shared and private mappings (Rafael Aquini) [1735181]
- [mm] mm/hugetlb.c: don't put_page in lock of hugetlb_lock (Rafael Aquini) [1735181]
- [mm] mm: fix inactive list balancing between NUMA nodes and cgroups (Rafael Aquini) [1735181]
- [mm] mm/migrate.c: add missing flush_dcache_page for non-mapped page migrate (Rafael Aquini) [1735181]
- [mm] mm: mempolicy: make mbind() return -EIO when MPOL_MF_STRICT is specified (Rafael Aquini) [1734286 1735181]
- [mm] mm/hotplug: fix offline undo_isolate_page_range() (Rafael Aquini) [1735181]
- [mm] mm/sparse: fix a bad comparison (Rafael Aquini) [1735181]
- [mm] mm, swap: bounds check swap_info array accesses to avoid NULL derefs (Rafael Aquini) [1735181]
- [mm] mm/vmalloc.c: don't dereference possible NULL pointer in __vunmap() (Rafael Aquini) [1735181]
- [mm] mm: hwpoison: fix thp split handing in soft_offline_in_use_page() (Rafael Aquini) [1735181]
- [mm] hugetlbfs: fix races and page leaks during migration (Rafael Aquini) [1735181]
- [mm] tmpfs: fix uninitialized return value in shmem_link (Rafael Aquini) [1735181]
- [mm] tmpfs: fix link accounting when a tmpfile is linked in (Rafael Aquini) [1735181]
- [mm] mm: migrate: don't rely on __PageMovable() of newpage after unlocking it (Rafael Aquini) [1735181]
- [mm] oom, oom_reaper: do not enqueue same task twice (Rafael Aquini) [1735181]
- [mm] mm: page_mapped: don't assume compound page is huge or THP (Rafael Aquini) [1735181]
- [mm] mm, memcg: fix reclaim deadlock with writeback (Rafael Aquini) [1735181]
- [mm] mm, swap: fix swapoff with KSM pages (Rafael Aquini) [1735181]
- [mm] mm/huge_memory: fix lockdep complaint on 32-bit i_size_read() (Rafael Aquini) [1735181]
- [mm] mm/huge_memory: splitting set mapping+index before unfreeze (Rafael Aquini) [1735181]
- [mm] mm/huge_memory: rename freeze_page() to unmap_page() (Rafael Aquini) [1735181]
- [mm] mm/page_alloc.c: fix calculation of pgdat->nr_zones (Rafael Aquini) [1735181]
- [mm] mm: use swp_offset as key in shmem_replace_page() (Rafael Aquini) [1735181]
- [mm] mm: cleancache: fix corruption on missed inode invalidation (Rafael Aquini) [1735181]
- [mm] mm/vmstat.c: fix NUMA statistics updates (Rafael Aquini) [1735181]
- [mm] mm, swap: make CONFIG_THP_SWAP depend on CONFIG_SWAP (Rafael Aquini) [1735181]
- [mm] ARM: 8820/1: mm: Stop printing the virtual memory layout (Rafael Aquini) [1655192]
- [netdrv] net: dsa: bcm_sf2: Remove print of base address (Rafael Aquini) [1655192]
- [netdrv] net: systemport: Remove print of base address (Rafael Aquini) [1655192]
- [netdrv] net: phy: mdio-bcm-unimac: Remove print of base address (Rafael Aquini) [1655192]
- [x86] x86/mm: Don't leak kernel addresses (Rafael Aquini) [1655192]
- [x86] x86/realmode: Make set_real_mode_mem() static inline (Rafael Aquini) [1655192]
- [x86] x86/realmode: Don't leak the trampoline kernel address (Rafael Aquini) [1655192]
- [arm64] arm64/vdso: don't leak kernel addresses (Rafael Aquini) [1655192]
- [powerpc] powerpc/traps: Fix the message printed when stack overflows (Rafael Aquini) [1655192]
- [kernel] kdb: print real address of pointers instead of hashed addresses (Rafael Aquini) [1655192]
- [kernel] kdb: use correct pointer when 'btc' calls 'btt' (Rafael Aquini) [1655192]

* Tue Oct 29 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.11.el8]
- [fs] signal: Allow cifs and drbd to receive their terminating signals (Leif Sahlberg) [1757670]
- [fs] smb3: fix unmount hang in open_shroot (Leif Sahlberg) [1757670]
- [fs] cifs: update internal module number (Leif Sahlberg) [1757670]
- [fs] cifs: replace various strncpy with strscpy and similar (Leif Sahlberg) [1757670]
- [fs] cifs: Use kzfree() to zero out the password (Leif Sahlberg) [1757670]
- [fs] cifs: set domainName when a domain-key is used in multiuser (Leif Sahlberg) [1757670]
- [fs] SMB3: Kernel oops mounting a encryptData share with CONFIG_DEBUG_VIRTUAL (Leif Sahlberg) [1757670]
- [fs] smb3: send CAP_DFS capability during session setup (Leif Sahlberg) [1757670]
- [fs] SMB3: Fix potential memory leak when processing compound chain (Leif Sahlberg) [1757670]
- [fs] SMB3: Fix deadlock in validate negotiate hits reconnect (Leif Sahlberg) [1757670]
- [fs] cifs: fix rmmod regression in cifs.ko caused by force_sig changes (Leif Sahlberg) [1757670]
- [fs] cifs: update internal module number (Leif Sahlberg) [1757670]
- [fs] cifs: flush before set-info if we have writeable handles (Leif Sahlberg) [1757670]
- [fs] smb3: optimize open to not send query file internal info (Leif Sahlberg) [1757670]
- [fs] CIFS: fix deadlock in cached root handling (Leif Sahlberg) [1757670]
- [fs] cifs: fix crash in cifs_dfs_do_automount (Leif Sahlberg) [1757670]
- [fs] cifs: fix parsing of symbolic link error response (Leif Sahlberg) [1757670]
- [fs] cifs: refactor and clean up arguments in the reparse point parsing (Leif Sahlberg) [1757670]
- [fs] SMB3: query inode number on open via create context (Leif Sahlberg) [1757670]
- [fs] smb3: Send netname context during negotiate protocol (Leif Sahlberg) [1757670]
- [fs] smb3: do not send compression info by default (Leif Sahlberg) [1757670]
- [fs] smb3: add new mount option to retrieve mode from special ACE (Leif Sahlberg) [1757670]
- [fs] smb3: Allow query of symlinks stored as reparse points (Leif Sahlberg) [1757670]
- [fs] cifs: Fix a race condition with cifs_echo_request (Leif Sahlberg) [1757670]
- [fs] cifs: always add credits back for unsolicited PDUs (Leif Sahlberg) [1757670]
- [fs] fs: cifs: cifsssmb: Change return type of convert_ace_to_cifs_ace (Leif Sahlberg) [1757670]
- [fs] add some missing definitions (Leif Sahlberg) [1757670]
- [fs] cifs: fix typo in debug message with struct field ia_valid (Leif Sahlberg) [1757670]
- [fs] smb3: minor cleanup of compound_send_recv (Leif Sahlberg) [1757670]
- [fs] CIFS: Fix module dependency (Leif Sahlberg) [1757670]
- [fs] cifs: simplify code by removing CONFIG_CIFS_ACL ifdef (Leif Sahlberg) [1757670]
- [fs] cifs: Fix check for matching with existing mount (Leif Sahlberg) [1757670]
- [fs] cifs: Properly handle auto disabling of serverino option (Leif Sahlberg) [1757670]
- [fs] smb3: if max_credits is specified then display it in /proc/mounts (Leif Sahlberg) [1757670]
- [fs] Fix match_server check to allow for auto dialect negotiate (Leif Sahlberg) [1757670]
- [fs] cifs: add missing GCM module dependency (Leif Sahlberg) [1757670]
- [fs] SMB3.1.1: Add GCM crypto to the encrypt and decrypt functions (Leif Sahlberg) [1757670]
- [fs] SMB3: Add SMB3.1.1 GCM to negotiated crypto algorigthms (Leif Sahlberg) [1757670]
- [fs] fs: cifs: Drop unlikely before IS_ERR(_OR_NULL) (Leif Sahlberg) [1757670]
- [fs] cifs: Use kmemdup in SMB2_ioctl_init() (Leif Sahlberg) [1757670]
- [fs] SMB3: retry on STATUS_INSUFFICIENT_RESOURCES instead of failing write (Leif Sahlberg) [1757670]
- [fs] cifs: fix panic in smb2_reconnect (Leif Sahlberg) [1757670]
- [fs] CIFS: cifs_read_allocate_pages: don't iterate through whole page array on ENOMEM (Leif Sahlberg) [1757670]
- [fs] dfs_cache: fix a wrong use of kfree in flush_cache_ent() (Leif Sahlberg) [1757670]
- [fs] fs/cifs/smb2pdu.c: fix buffer free in SMB2_ioctl_free (Leif Sahlberg) [1757670]
- [fs] cifs: fix memory leak of pneg_inbuf on -EOPNOTSUPP ioctl case (Leif Sahlberg) [1757670]
- [fs] cifs: add support for SEEK_DATA and SEEK_HOLE (Leif Sahlberg) [1757670]
- [fs] cifs: Allocate memory for all iovs in smb2_ioctl (Leif Sahlberg) [1757670]
- [fs] cifs: Don't match port on SMBDirect transport (Leif Sahlberg) [1757670]
- [fs] cifs:smbd Use the correct DMA direction when sending data (Leif Sahlberg) [1757670]
- [fs] cifs:smbd When reconnecting to server, call smbd_destroy() after all MIDs have been called (Leif Sahlberg) [1757670]
- [fs] smb3: trivial cleanup to smb2ops.c (Leif Sahlberg) [1757670]
- [fs] cifs: cleanup smb2ops.c and normalize strings (Leif Sahlberg) [1757670]
- [fs] smb3: display session id in debug data (Leif Sahlberg) [1757670]
- [fs] cifs: update module internal version number (Leif Sahlberg) [1757670]
- [fs] cifs: fix crash querying symlinks stored as reparse-points (Leif Sahlberg) [1757670]
- [fs] SMB3: Clean up query symlink when reparse point (Leif Sahlberg) [1757670]
- [fs] cifs: fix strcat buffer overflow and reduce raciness in smb21_set_oplock_level() (Leif Sahlberg) [1757670]
- [fs] Negotiate and save preferred compression algorithms (Leif Sahlberg) [1757670]
- [fs] cifs: rename and clarify CIFS_ASYNC_OP and CIFS_NO_RESP (Leif Sahlberg) [1757670]
- [fs] smb3: Add protocol structs for change notify support (Leif Sahlberg) [1757670]
- [fs] cifs: fix smb3_zero_range for Azure (Leif Sahlberg) [1757670]
- [fs] cifs: zero-range does not require the file is sparse (Leif Sahlberg) [1757670]
- [fs] Add new flag on SMB3.1.1 read (Leif Sahlberg) [1757670]
- [fs] cifs: add fiemap support (Leif Sahlberg) [1757670]
- [fs] SMB3: Add defines for new negotiate contexts (Leif Sahlberg) [1757670]
- [fs] cifs: fix bi-directional fsctl passthrough calls (Leif Sahlberg) [1757670]
- [fs] cifs: smbd: take an array of reqeusts when sending upper layer data (Leif Sahlberg) [1757670]
- [fs] SMB3: Add handling for different FSCTL access flags (Leif Sahlberg) [1757670]
- [fs] cifs: Add support for FSCTL passthrough that write data to the server (Leif Sahlberg) [1757670]
- [fs] cifs: remove superfluous inode_lock in cifs_{strict_}fsync (Leif Sahlberg) [1757670]
- [fs] cifs: Call MID callback before destroying transport (Leif Sahlberg) [1757670]
- [fs] smbd: Make upper layer decide when to destroy the transport (Leif Sahlberg) [1757670]
- [fs] SMB3: update comment to clarify enumerating snapshots (Leif Sahlberg) [1757670]
- [fs] CIFS: check CIFS_MOUNT_NO_DFS when trying to reuse existing sb (Leif Sahlberg) [1757670]
- [fs] CIFS: Show locallease in /proc/mounts for cifs shares mounted with locallease feature. (Leif Sahlberg) [1757670]
- [fs] cifs: Fix DFS cache refresher for DFS links (Leif Sahlberg) [1757670]
- [fs] cifs: don't use __constant_cpu_to_le32() (Leif Sahlberg) [1757670]
- [fs] SMB3: Track total time spent on roundtrips for each SMB3 command (Leif Sahlberg) [1757670]
- [fs] cifs: use the right include for signal_pending() (Leif Sahlberg) [1757670]
- [fs] CIFS: Mask off signals when sending SMB packets (Leif Sahlberg) [1757670]
- [infiniband] RDMA/umem: Revert broken 'off by one' fix (Kamal Heib) [1720888]
- [infiniband] RDMA/umem: minor bug fix in error handling path (Kamal Heib) [1720888]
- [infiniband] RDMA/uverbs: Don't do double free of allocated PD (Kamal Heib) [1720888]
- [infiniband] RDMA: Handle ucontext allocations by IB/core (Kamal Heib) [1720888]
- [infiniband] cross-tree: phase out dma_zalloc_coherent() (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Fix a WARN() message (Kamal Heib) [1720888]
- [infiniband] RDMA/uverbs: Store PR pointer before it is overwritten (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Cosmetic change - move member initialization to correct block (Kamal Heib) [1720888]
- [infiniband] rdma_rxe: Use netlink messages to add/delete links (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Add RDMA_NLDEV_CMD_NEWLINK/DELLINK support (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Close a race after ib_register_device (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Add ib_device_get_by_name() and use it in rxe (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Use driver_unregister and new unregistration API (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Provide APIs from the core code to help unregistration (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Use ib_device_get_by_netdev() instead of open coding (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Add ib_device_get_by_netdev() (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Add ib_device_set_netdev() as an alternative to get_netdev (Kamal Heib) [1720888]
- [infiniband] RDMA/cache: Move the cache per-port data into the main ib_port_data (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Consolidate ib_device per_port data into one place (Kamal Heib) [1720888]
- [infiniband] RDMA: Add and use rdma_for_each_port (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Don't expose number of not-visible entries (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Connect QP number to .doit callback (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Provide parent IDs for PD, MR and QP objects (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Share with user-space object IDs (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Prepare restrack_root to addition of extra fields per-type (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Hide restrack DB from IB/core (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Reduce scope of synchronization lock while updating DB (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Add resource tracker doit callback (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Translate from ID to restrack object (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Convert internal DB from hash to XArray (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Move device addition deletion to device.c (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Introduce and use ib_setup_port_attrs() (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Use simpler device_del() instead of device_unregister() (Kamal Heib) [1720888]
- [infiniband] RDMA/nes: Remove useless usecnt variable and redundant memset (Kamal Heib) [1720888]
- [infiniband] IB/{hw, sw}: Remove 'uobject->context' dependency in object creation APIs (Kamal Heib) [1720888]
- [infiniband] RDMA/qedr: remove set but not used variable 'ib_ctx' (Kamal Heib) [1720888]
- [infiniband] RDMA/mthca: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720888]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Kamal Heib) [1720888]
- [infiniband] RDMA/mthca: Clear QP objects during their allocation (Kamal Heib) [1720888]
- [include] IB/verbs: Add helper function rdma_udata_to_drv_context (Kamal Heib) [1720888]
- [infiniband] IB/uverbs: Add ib_ucontext to uverbs_attr_bundle sent from ioctl and cmd flows (Kamal Heib) [1720888]
- [infiniband] IB/ipoib: Use __func__ instead of function's name (Kamal Heib) [1720888]
- [infiniband] RDMA/iwpm: Remove set but not used variable 'msg_seq' (Kamal Heib) [1720888]
- [infiniband] RDMA/nes: Use for_each_sg_dma_page iterator for umem SGL (Kamal Heib) [1720888]
- [net] xprtrdma: Check inline size before providing a Write chunk (Kamal Heib) [1720888]
- [infiniband] RDMA/ocrdma: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720888]
- [infiniband] RDMA/vmw_pvrdma: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720888]
- [infiniband] RDMA/devices: Re-organize device.c locking (Kamal Heib) [1720888]
- [infiniband] RDMA/devices: Use xarray to store the client_data (Kamal Heib) [1720888]
- [infiniband] RDMA/devices: Use xarray to store the clients (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Use an ida instead of a free page in alloc_name (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Get rid of reg_state (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Check that the rename is nop under the lock (Kamal Heib) [1720888]
- [infiniband] RDMA: Handle PD allocations by IB/core (Kamal Heib) [1720888]
- [infiniband] RDMA/hns: fix spelling mistake "reseved" -> "reserved" (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Share driver structure size with core (Kamal Heib) [1720888]
- [infiniband] IB/cma: Define option to set ack timeout and pack tos_set (Kamal Heib) [1720888]
- [infiniband] drivers/IB,core: reduce scope of mmap_sem (Kamal Heib) [1720888]
- [infiniband] drivers/IB,usnic: reduce scope of mmap_sem (Kamal Heib) [1720888]
- [net] svcrdma: Remove syslog warnings in work completion handlers (Kamal Heib) [1720888]
- [net] svcrdma: Squelch compiler warning when SUNRPC_DEBUG is disabled (Kamal Heib) [1720888]
- [net] svcrdma: Use struct_size() in kmalloc() (Kamal Heib) [1720888]
- [infiniband] RDMA/iwpm: move kdoc comments to functions (Kamal Heib) [1720888]
- [infiniband] RDMA/cma: Remove CM_ID statistics provided by rdma-cm module (Kamal Heib) [1720888]
- [infiniband] scsi: RDMA/srpt: Rework I/O context allocation (Kamal Heib) [1720888]
- [infiniband] scsi: RDMA/srpt: Fix handling of command / TMF submission failure (Kamal Heib) [1720888]
- [infiniband] RDMA/IWPM: Support no port mapping requirements (Kamal Heib) [1720888]
- [infiniband] RDMA/IWPM: refactor the IWPM message attribute names (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Improve loopback marking (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Move rxe_init_av() to rxe_av.c (Kamal Heib) [1720888]
- [infiniband] IB/core: Remove ib_sg_dma_address() and ib_sg_dma_len() (Kamal Heib) [1720888]
- [infiniband] IB/uverbs: Expose XRC ODP device capabilities (Kamal Heib) [1720888]
- [include] IB/core: Allocate a bit for SRQ ODP support (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Use the ops infrastructure to keep all callbacks in one place (Kamal Heib) [1720888]
- [infiniband] RDMA/cxgb4: Sort SRQ ops alphabetically (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Refactor user/kernel restrack additions (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Simplify restrack interface (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Prepare CAP_NET_ADMIN checks for .doit callbacks (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Factor out the PID namespace check (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Dynamically generate restrack dumpit callbacks (Kamal Heib) [1720888]
- [infiniband] IB/usnic: Remove stub functions (Kamal Heib) [1720888]
- [infiniband] RDMA: Add indication for in kernel API support to IB device (Kamal Heib) [1720888]
- [infiniband] IB/mlx5: Introduce async DEVX obj query API (Kamal Heib) [1720888]
- [infiniband] IB/mlx5: Introduce MLX5_IB_OBJECT_DEVX_ASYNC_CMD_FD (Kamal Heib) [1720888]
- [infiniband] infiniband: prefix header search paths with $(srctree)/ (Kamal Heib) [1720888]
- [infiniband] infiniband: remove unneeded header search paths (Kamal Heib) [1720888]
- [infiniband] infiniband: ipoib: no need to check return value of debugfs_create functions (Kamal Heib) [1720888]
- [infiniband] infiniband: usnic: no need to check return value of debugfs_create functions (Kamal Heib) [1720888]
- [infiniband] infiniband: ocrdma: no need to check return value of debugfs_create functions (Kamal Heib) [1720888]
- [infiniband] RDMA/ocrdma: Use PCI-ID as an identification in debugfs (Kamal Heib) [1720888]
- [infiniband] IB/umad: Do not check status of nonseekable_open() (Kamal Heib) [1720888]
- [infiniband] IB/umad: Avoid additional device reference during open()/close() (Kamal Heib) [1720888]
- [infiniband] IB/rxe: Remove unnecessary rxe variable (Kamal Heib) [1720888]
- [infiniband] IB/core: Simplify rdma cgroup registration (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Use __ib_device_get_by_name() in ib_device_rename() (Kamal Heib) [1720888]
- [infiniband] RDMA: Rename port_callback to init_port (Kamal Heib) [1720888]
- [infiniband] RDMA: Clear CTX objects during their allocation (Kamal Heib) [1720888]
- [infiniband] RDMA: Clear PD objects during their allocation (Kamal Heib) [1720888]
- [infiniband] RDMA/ocrdma: Fix out of bounds index check in query pkey (Kamal Heib) [1720888]
- [infiniband] IB/{core, hw}: Have ib_umem_get extract the ib_ucontext from ib_udata (Kamal Heib) [1720888]
- [infiniband] IB/{core, uverbs}: Move ib_umem_xxx functions from ib_core to ib_uverbs (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Don't depend device ODP capabilities on kconfig option (Kamal Heib) [1720888]
- [infiniband] IB/srp: Use struct_size() in kzalloc() (Kamal Heib) [1720888]
- [infiniband] IB/core: Use struct_size() in kzalloc() (Kamal Heib) [1720888]
- [infiniband] IB/usnic: Use struct_size() in kmalloc() (Kamal Heib) [1720888]
- [infiniband] IB/cm: Use struct_size() in kmalloc() (Kamal Heib) [1720888]
- [mm] mm: introduce put_user_page*(), placeholder versions (Rafael Aquini) [1746371]
- [mm] mm/gup: add FOLL_LONGTERM capability to GUP fast (Rafael Aquini) [1746371]
- [mm] mm/gup: change GUP fast to use flags rather than a write 'bool' (Rafael Aquini) [1746371]
- [mm] mm/gup: change write parameter to flags in fast walk (Rafael Aquini) [1746371]
- [mm] mm/gup: replace get_user_pages_longterm() with FOLL_LONGTERM (Rafael Aquini) [1746371]
- [s390] s390/mm: fix pxd_bad with folded page tables (Rafael Aquini) [1746371]
- [s390] s390/mm: fix dump_pagetables top level page table walking (Rafael Aquini) [1746371]
- [s390] s390/mm: convert to the generic get_user_pages_fast code (Rafael Aquini) [1746371]
- [s390] s390/mm: make the pxd_offset functions more robust (Rafael Aquini) [1746371]
- [mm] mm/gup: fix gup_pmd_range() for dax (Rafael Aquini) [1746371]
- [mm] mm/gup: remove the 'write' parameter from gup_fast_permitted() (Rafael Aquini) [1746371]
- [mm] mm/gup: fix follow_page_mask() kerneldoc comment (Rafael Aquini) [1746371]
- [mm] mm/gup: fix __get_user_pages_fast() comment (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: prevent integer overflow in ioctl (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: add additional pinning methods (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: time put_page() (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: fix unsigned comparison to zero in __gup_benchmark_ioctl (Rafael Aquini) [1746371]
- [mm] mm: remove caller signal_pending branch predictions (Rafael Aquini) [1746371]
- [mm] mm: remove unnecessary local variable addr in __get_user_pages_fast() (Rafael Aquini) [1746371]
- [mm] mm: change return type int to vm_fault_t for fault handlers (Rafael Aquini) [1746371]
- [mm] mm: make mm->pinned_vm an atomic64 counter (Rafael Aquini) [1746371]

* Fri Oct 25 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.10.el8]
- [kernel] sched/core: Schedule new worker even if PI-blocked (Waiman Long) [1758629]
- [char] random: add a spinlock_t to struct batched_entropy (Waiman Long) [1758629]
- [crypto] crypto: chacha20 - Fix chacha20_block() keystream alignment (again) (Waiman Long) [1758629]
- [fs] locking/percpu-rwsem: Remove preempt_disable variants (Waiman Long) [1758629]
- [x86] x86/tsc: Add option to disable tsc clocksource watchdog (Waiman Long) [1758629]
- [x86] x86/irq: Handle spurious interrupt after shutdown gracefully (Waiman Long) [1758629]
- [x86] x86/ioapic: Implement irq_get_irqchip_state() callback (Waiman Long) [1758629]
- [kernel] genirq: Add optional hardware synchronization for shutdown (Waiman Long) [1758629]
- [kernel] genirq: Fix misleading synchronize_irq() documentation (Waiman Long) [1758629]
- [kernel] genirq: Delay deactivation in free_irq() (Waiman Long) [1758629]
- [kernel] genirq: Remove redundant NULL pointer check in __free_irq() (Waiman Long) [1758629]
- [kernel] genirq: Synchronize only with single thread on free_irq() (Waiman Long) [1758629]
- [kernel] genirq: Update code comments wrt recycled thread_mask (Waiman Long) [1758629]
- [usb] usb: core: remove flags variable in __usb_hcd_giveback_urb() (Waiman Long) [1758629]
- [usb] usb: core: remove local_irq_save() around ->complete() handler (Waiman Long) [1758629]
- [media] media: tm6000: use irqsave() in USB's complete callback (Waiman Long) [1758629]
- [media] media: em28xx-audio: use irqsave() in USB's complete callback (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Optimize __cpa_flush_range() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Factor common code between cpa_flush_*() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Move CLFLUSH test into cpa_flush_array() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Move CLFLUSH test into cpa_flush_range() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Use flush_tlb_kernel_range() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Unconditionally avoid WBINDV when we can (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Move flush_tlb_all() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Use flush_tlb_all() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Avoid the 4k pages check completely (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Do the range check early (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Optimize same protection check (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Add sanity check for existing mappings (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Avoid static protection checks on unmap (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Add large page preservation statistics (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Add debug mechanism (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Allow range check for static protections (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Rework static_protections() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Split, rename and clean up try_preserve_large_page() (Waiman Long) [1758629]
- [x86] x86/mm/init32: Mark text and rodata RO in one go (Waiman Long) [1758629]
- [mm] mm/kasan/quarantine.c: make quarantine_lock a raw_spinlock_t (Waiman Long) [1758629]
- [mm] mm/list_lru.c: fold __list_lru_count_one() into its caller (Waiman Long) [1758629]
- [mm] mm: workingset: make shadow_lru_isolate() use locking suffix (Waiman Long) [1758629]
- [mm] mm: workingset: remove local_irq_disable() from count_shadow_nodes() (Waiman Long) [1758629]
- [iommu] iommu/amd: Remove redundant WARN_ON() (Waiman Long) [1758629]
- [mm] mm/list_lru: introduce list_lru_shrink_walk_irq() (Waiman Long) [1758629]
- [mm] mm/list_lru.c: pass struct list_lru_node* as an argument to __list_lru_walk_one() (Waiman Long) [1758629]
- [mm] mm/list_lru.c: move locking from __list_lru_walk_one() to its caller (Waiman Long) [1758629]
- [mm] mm/list_lru.c: use list_lru_walk_one() in list_lru_walk_node() (Waiman Long) [1758629]
- [kernel] userns: use irqsave variant of refcount_dec_and_lock() (Waiman Long) [1758629]
- [kernel] userns: use refcount_t for reference counting instead atomic_t (Waiman Long) [1758629]
- [kernel] bdi: use irqsave variant of refcount_dec_and_lock() (Waiman Long) [1758629]
- [mm] bdi: use refcount_t for reference counting instead atomic_t (Waiman Long) [1758629]
- [char] random: remove preempt disabled region (Waiman Long) [1758629]
- [misc] ocxl: Update for AFU descriptor template version 1.1 (Steve Best) [1751207]
- [misc] ocxl: Make ocxl_remove() static (Steve Best) [1751207]
- [misc] ocxl: do not use C++ style comments in uapi header (Steve Best) [1751207]
- [misc] ocxl: Allow contexts to be attached with a NULL mm (Steve Best) [1751207]
- [misc] ocxl: Fix return value check in afu_ioctl() (Steve Best) [1751207]
- [misc] ocxl: Provide global MMIO accessors for external drivers (Steve Best) [1751207]
- [misc] ocxl: move event_fd handling to frontend (Steve Best) [1751207]
- [misc] ocxl: afu_irq only deals with IRQ IDs, not offsets (Steve Best) [1751207]
- [misc] ocxl: Allow external drivers to use OpenCAPI contexts (Steve Best) [1751207]
- [misc] ocxl: Create a clear delineation between ocxl backend & frontend (Steve Best) [1751207]
- [misc] ocxl: Don't pass pci_dev around (Steve Best) [1751207]
- [misc] ocxl: Split pci.c (Steve Best) [1751207]
- [misc] ocxl: Remove some unused exported symbols (Steve Best) [1751207]
- [misc] ocxl: Remove superfluous 'extern' from headers (Steve Best) [1751207]
- [misc] ocxl: read_pasid never returns an error, so make it void (Steve Best) [1751207]
- [misc] ocxl: Rename struct link to ocxl_link (Steve Best) [1751207]
- [misc] ocxl: remove set but not used variables 'tid' and 'lpid' (Steve Best) [1751207]
- [misc] ocxl: Fix endiannes bug in read_afu_name() (Steve Best) [1751207]
- [misc] ocxl/afu_irq: Don't include <asm/pnv-ocxl.h> (Steve Best) [1751207]
- [misc] ocxl: Clarify error path in setup_xsl_irq() (Steve Best) [1751207]
- [misc] ocxl: Fix endiannes bug in ocxl_link_update_pe() (Steve Best) [1751207]
- [misc] ocxl: Fix access to the AFU Descriptor Data (Steve Best) [1751207]
- [netdrv] gve: account for lack of netdev_xmit_more() definition (RHEL-only) (John Linville) [1728864]
- [netdrv] gve: Copy and paste bug in gve_get_stats() (John Linville) [1728864]
- [netdrv] gve: Fix case where desc_cnt and data_cnt can get out of sync (John Linville) [1728864]
- [netdrv] gve: replace kfree with kvfree (John Linville) [1728864]
- [netdrv] gve: Remove the exporting of gve_probe (John Linville) [1728864]
- [netdrv] gve: fix unused variable/label warnings (John Linville) [1728864]
- [netdrv] gve: Fix error return code in gve_alloc_qpls() (John Linville) [1728864]
- [netdrv] gve: fix -ENOMEM null check on a page allocation (John Linville) [1728864]
- [netdrv] gve: Fix u64_stats_sync to initialize start (John Linville) [1728864]
- [netdrv] gve: Add ethtool support (John Linville) [1728864]
- [netdrv] gve: Add workqueue and reset support (John Linville) [1728864]
- [netdrv] gve: Add transmit and receive support (John Linville) [1728864]
- [netdrv] gve: Add basic driver framework for Compute Engine Virtual NIC (John Linville) [1728864]
- [mfd] mfd: intel-lpss: Add Intel Comet Lake PCI IDs (David Arcari) [1761586]
- [scsi] scsi: core: save/restore command resid for error handling (Ewan Milne) [1760503]
- [scsi] scsi: sd: Ignore a failure to sync cache due to lack of authorization (Ewan Milne) [1760503]
- [scsi] scsi: core: Add sysfs attributes for VPD pages 0h and 89h (Ewan Milne) [1760503]
- [scsi] scsi: core: Log SCSI command age with errors (Ewan Milne) [1760503]
- [scsi] scsi: scsi_dh_rdac: zero cdb in send_mode_select() (Ewan Milne) [1760503]
- [scsi] scsi: sd: Improve unaligned completion resid message (Ewan Milne) [1760503]
- [scsi] scsi: core: Reduce memory required for SCSI logging (Ewan Milne) [1760503]
- [scsi] scsi: core: Complain if scsi_target_block() fails (Ewan Milne) [1760503]
- [scsi] scsi: core: Make scsi_internal_device_unblock_nowait() reject invalid new_state (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debugfs: Use for_each_set_bit to simplify code (Ewan Milne) [1760503]
- [scsi] scsi: scsi_dh_alua: always use a 2 second delay before retrying RTPG (Ewan Milne) [1760503]
- [scsi] scsi: sd_zbc: Fix compilation warning (Ewan Milne) [1760503]
- [scsi] scsi: devinfo: BLIST_TRY_VPD_PAGES for SanDisk Cruzer Blade (Ewan Milne) [1760503]
- [scsi] scsi: core: use scmd_printk() to print which command timed out (Ewan Milne) [1760503]
- [scsi] scsi: Avoid that .queuecommand() gets called for a blocked SCSI device (Ewan Milne) [1760503]
- [scsi] scsi: core: don't preallocate small SGL in case of NO_SG_CHAIN (Ewan Milne) [1760503]
- [scsi] scsi: scsi_dh_alua: Fix possible null-ptr-deref (Ewan Milne) [1760503]
- [scsi] scsi: st: add a SPDX tag to st.c (Ewan Milne) [1760503]
- [scsi] scsi: sr: add a SPDX tag to sr.c (Ewan Milne) [1760503]
- [scsi] scsi: sg: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: sd: switch remaining files to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: sd: add a SPDX tag to sd.c (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_srp: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_spi: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_sas: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_iscsi: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_fc: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: core: switch the remaining scsi midlayer files to use SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: core: add SPDX tags to scsi midlayer files missing licensing information (Ewan Milne) [1760503]
- [scsi] Revert "scsi: sd: Keep disk read-only when re-reading partition" (Ewan Milne) [1760503]
- [scsi] scsi: core: set result when the command cannot be dispatched (Ewan Milne) [1760503]
- [scsi] scsi: core: map PQ=1, PDT=other values to SCSI_SCAN_TARGET_PRESENT (Ewan Milne) [1760503]
- [scsi] scsi: core: don't hold device refcount in IO path (Ewan Milne) [1760503]
- [scsi] scsi: sd: Quiesce warning if device does not report optimal I/O size (Ewan Milne) [1760503]
- [scsi] scsi: core: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Ewan Milne) [1760503]
- [scsi] scsi: core: Avoid that a kernel warning appears during system resume (Ewan Milne) [1760503]
- [scsi] scsi: core: Also call destroy_rcu_head() for passthrough requests (Ewan Milne) [1760503]
- [scsi] scsi: core: replace GFP_ATOMIC with GFP_KERNEL in scsi_scan.c (Ewan Milne) [1760503]
- [scsi] scsi: sd: Optimal I/O size should be a multiple of physical block size (Ewan Milne) [1760503]
- [scsi] scsi: sd: Fix typo in sd_first_printk() (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: Implement support for write protect (Ewan Milne) [1760503]
- [scsi] scsi: sd_zbc: Fix zone information messages (Ewan Milne) [1760503]
- [scsi] scsi: sd: Improve sd_print_capacity() (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: fix write_same with virtual_gb problem (Ewan Milne) [1760503]
- [scsi] scsi: sd: Protect against READ(6) or WRITE(6) with zero block transfer length (Ewan Milne) [1760503]
- [scsi] scsi: core: Remove an atomic instruction from the hot path (Ewan Milne) [1760503]
- [scsi] scsi: sd: Rename 'SCpnt' into 'cmd' (Ewan Milne) [1760503]
- [scsi] scsi: sd: Clean up sd_setup_read_write_cmnd() (Ewan Milne) [1760503]
- [scsi] scsi: sd: Create helper functions for read/write commands (Ewan Milne) [1760503]
- [scsi] scsi: sd: Simplify misaligned I/O check (Ewan Milne) [1760503]
- [scsi] scsi: sd: Be consistent about blocks vs. sectors (Ewan Milne) [1760503]
- [scsi] scsi: sd: Remove a local variable (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: add cmd abort option to every_nth (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: skip long delays when ndelay small (Ewan Milne) [1760503]
- [x86] efi/x86: Do not clean dummy variable in kexec path (Bhupesh Sharma) [1724436]
- [scsi] scsi: csiostor: create per port irq affinity mask set (Jonathan Toppins) [1725816]
- [pci] PCI: let pci_disable_link_state propagate errors (Myron Stowe) [1735834]
- [scsi] scsi: scsi_transport_fc: Add FPIN fc event codes (Ewan Milne) [1755587]
- [scsi] scsi: scsi_transport_fc: refactor event posting routines (Ewan Milne) [1755587]
- [scsi] scsi: fc: add FPIN ELS definition (Ewan Milne) [1755587]
- [scsi] scsi: lib/sg_pool.c: clear 'first_chunk' in case of no preallocation (Ewan Milne) [1747162]
- [scsi] scsi: core: Run queue when state is set to running after being blocked (Ewan Milne) [1691599]
- [scsi] scsi: sd: Fix a race between closing an sd device and sd I/O (Ewan Milne) [1689118]
- [net] net/ibmvnic: Fix EOI when running in XIVE mode. (Steve Best) [1761378]
- [powerpc] powerpc/mce: Fix SLB rebolting during MCE recovery path. (Desnes Augusto Nunes do Rosario) [1725842]
- [powerpc] powerpc/pseries: hwpoison the pages upon hitting UE (Desnes Augusto Nunes do Rosario) [1725842]
- [x86] perf/x86/amd: Change/fix NMI latency mitigation to use a timestamp (David Arcari) [1730134]
- [arm64] arm64: entry: Remove unneeded need_resched() loop (Mark Langsdorf) [1737075]
- [arm64] arm64: preempt: Fix big-endian when checking preempt count in assembly (Mark Langsdorf) [1737075]
- [arm64] arm64: preempt: Provide our own implementation of asm/preempt.h (Mark Langsdorf) [1737075]
- [include] preempt: Move PREEMPT_NEED_RESCHED definition into arch code (Mark Langsdorf) [1737075]
- [x86] x86/intel_rdt: Ensure a CPU remains online for the region's pseudo-locking sequence (Alexander Beregalov) [1724902]
- [kernel] perf/core: Add sanity check to deal with pinned event failure (Alexander Beregalov) [1724902]
- [arm64] arm64/sve: Fix wrong free for task->thread.sve_state (Andrew Jones) [1756450]
- [scsi] scsi: lpfc: Update lpfc version to 12.4.0.1 (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: cleanup: remove unused fcp_txcmlpq_cnt (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Complete removal of FCoE T10 PI support on SLI-4 adapters (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Update async event logging (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix list corruption detected in lpfc_put_sgl_per_hdwq (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix hdwq sgl locks and irq handling (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix spinlock_irq issues in lpfc_els_flush_cmd() (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix list corruption in lpfc_sli_get_iocbq (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix host hang at boot or slow boot (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix coverity errors on NULL pointer checks (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix NVMe ABTS in response to receiving an ABTS (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix discovery failures when target device connectivity bounces (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix GPF on scsi command completion (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix locking on mailbox command completion (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix device recovery errors after PLOGI failures (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix rpi release when deleting vport (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix NVME io abort failures causing hangs (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix miss of register read failure check (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix premature re-enabling of interrupts in lpfc_sli_host_down (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix pt2pt discovery on SLI3 HBAs (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix reset recovery paths that are not recovering (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Convert existing pf users to ps (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: fix 12.4.0.0 GPF at boot (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Remove bg debugfs buffers (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Resolve checker warning for lpfc_new_io_buf() (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Update lpfc version to 12.4.0.0 (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Merge per-protocol WQ/CQ pairs into single per-cpu pair (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add NVMe sequence level error recovery support (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Support dynamic unbounded SGL lists on G7 hardware. (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add MDS driver loopback diagnostics support (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add first and second level hardware revisions to sysfs reporting (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Migrate to px and pf in kernel print calls (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add simple unlikely optimizations to reduce NVME latency (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix coverity warnings (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix nvme first burst module parameter description (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix BlockGuard enablement on FCoE adapters (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix reported physical link speed on a disabled trunked link (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix Max Frame Size value shown in fdmishow output (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix upcall to bsg done in non-success cases (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix sli4 adapter initialization with MSI (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix nvme sg_seg_cnt display if HBA does not support NVME (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix nvme target mode ABTSing a received ABTS (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix hang when downloading fw on port enabled for nvme (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix too many sg segments spamming in kernel log (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix crash due to port reset racing vs adapter error handling (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix deadlock on host_lock during cable pulls (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix error in remote port address change (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix driver nvme rescan logging (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix sg_seg_cnt for HBAs that don't support NVME (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix propagation of devloss_tmo setting to nvme transport (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix loss of remote port after devloss due to lack of RPIs (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix devices that don't return after devloss followed by rediscovery (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix null ptr oops updating lpfc_devloss_tmo via sysfs attribute (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix FLOGI handling across multiple link up/down conditions (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix irq raising in lpfc_sli_hba_down (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix Oops in nvme_register with target logout/login (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix issuing init_vpi mbox on SLI-3 card (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix ADISC reception terminating login state if a NVME target (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix discovery when target has no GID_FT information (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix leak of ELS completions on adapter reset (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix failure to clear non-zero eq_delay after io rate reduction (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix crash on driver unload in wq free (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix ELS field alignments (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix PLOGI failure with high remoteport count (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: remove NULL check before some freeing functions (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: use spin_lock_irqsave in IRQ context (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: remove redundant code (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Remove unnecessary null check before kfree (Dick Kennedy) [1757574]
- [scripts] scripts/spelling.txt: drop "sepc" from the misspelling list (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: reduce stack size with CONFIG_GCC_PLUGIN_STRUCTLEAK_VERBOSE (Dick Kennedy) [1757574]
- [scsi] lpfc: add sysfs interface to post NVME RSCN (Dick Kennedy) [1757574]
- [scsi] lpfc: add support for translating an RSCN rcv into a discovery rescan (Dick Kennedy) [1757574]
- [scsi] lpfc: add support to generate RSCN events for nport (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: use sg helper to iterate over scatterlist (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Avoid unused function warnings (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Make some symbols static (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Remove set but not used variables 'qp' (Dick Kennedy) [1757574]
- [lib] lib/vsprintf: Reinstate printing of legacy clock IDs (Prarit Bhargava) [1751075]
- [lib] vsprintf: fix data type of variable in string_nocheck() (Prarit Bhargava) [1751075]
- [scripts] kconfig: tests: fix recursive inclusion unit test (Prarit Bhargava) [1751075]
- [kernel] printk: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Prarit Bhargava) [1751075]
- [kernel] printk: Add SPDX license identifier for missed files (Prarit Bhargava) [1751075]
- [kernel] printk: Add SPDX license identifier for more missed files (Prarit Bhargava) [1751075]
- [kernel] panic: add an option to replay all the printk message in buffer (Prarit Bhargava) [1751075]
- [kernel] panic: avoid the extra noise dmesg (Prarit Bhargava) [1751075]
- [lib] vsprintf: Do not break early boot with probing addresses (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Make function pointer_string static (Prarit Bhargava) [1751075]
- [lib] vsprintf: Limit the length of inlined error messages (Prarit Bhargava) [1751075]
- [lib] vsprintf: Avoid confusion between invalid address and value (Prarit Bhargava) [1751075]
- [lib] vsprintf: Prevent crash when dereferencing invalid pointers (Prarit Bhargava) [1751075]
- [lib] vsprintf: Consolidate handling of unknown pointer specifiers (Prarit Bhargava) [1751075]
- [lib] vsprintf: Factor out pO handler as kobject_string() (Prarit Bhargava) [1751075]
- [lib] vsprintf: Factor out pV handler as va_format() (Prarit Bhargava) [1751075]
- [lib] vsprintf: Factor out p[iI] handler as ip_addr_string() (Prarit Bhargava) [1751075]
- [lib] vsprintf: Do not check address of well-known strings (Prarit Bhargava) [1751075]
- [lib] vsprintf: Consistent pK handling for kptr_restrict == 0 (Prarit Bhargava) [1751075]
- [lib] vsprintf: Shuffle restricted_pointer() (Prarit Bhargava) [1751075]
- [kernel] printk: Tie printk_once / printk_deferred_once into .data.once for reset (Prarit Bhargava) [1751075]
- [lib] lib: Use new kselftest header (Prarit Bhargava) [1751075]
- [lib] lib/test_printf: Add empty module_exit function (Prarit Bhargava) [1751075]
- [scripts] checkpatch: add pt as a valid vsprintf extension (Prarit Bhargava) [1751075]
- [lib] lib/test_printf: Switch to bitmap_zalloc() (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf.c: move sizeof(struct printf_spec) next to its definition (Prarit Bhargava) [1751075]
- [kernel] printk/docs: Add extra integer types to printk-formats (Prarit Bhargava) [1751075]
- [kernel] printk: Remove no longer used LOG_PREFIX. (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Remove pCr remnant in comment (Prarit Bhargava) [1751075]
- [kernel] printk: Pass caller information to log_store(). (Prarit Bhargava) [1751075]
- [kernel] kernel/sysctl: add panic_print into sysctl (Prarit Bhargava) [1751075]
- [kernel] panic: add options to print system info when panic happens (Prarit Bhargava) [1751075]
- [include] include/linux/printk.h: drop silly "static inline asmlinkage" from dump_stack() (Prarit Bhargava) [1751075]
- [kernel] printk: Add caller information to printk() output. (Prarit Bhargava) [1751075]
- [kernel] printk: Remove print_prefix() calls with NULL buffer. (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Print time and date in human readable format via pt (Prarit Bhargava) [1751075]
- [kernel] printk: fix printk_time race. (Prarit Bhargava) [1751075]
- [kernel] printk: Make printk_emit() local function. (Prarit Bhargava) [1751075]
- [documentation] doc: printk-formats: Remove bogus kobject references for device nodes (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Hash printed address for netdev bits fallback (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Hash legacy clock addresses (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Prepare for more general use of ptr_to_id() (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Make ptr argument conts in ptr_to_id() (Prarit Bhargava) [1751075]
- [kernel] printk: fix integer overflow in setup_log_buf() (Prarit Bhargava) [1751075]
- [kernel] printk: do not preliminary split up cont buffer (Prarit Bhargava) [1751075]
- [kernel] printk: lock/unlock console only for new logbuf entries (Prarit Bhargava) [1751075]
- [kernel] printk: keep kernel cont support always enabled (Prarit Bhargava) [1751075]
- [kernel] printk: Give error on attempt to set log buffer length to over 2G (Prarit Bhargava) [1751075]
- [kernel] printk: Add KBUILD_MODNAME and remove a redundant print prefix (Prarit Bhargava) [1751075]
- [kernel] printk: Correct wrong casting (Prarit Bhargava) [1751075]
- [kernel] printk: CON_PRINTBUFFER console registration is a bit racy (Prarit Bhargava) [1751075]
- [kernel] printk: Do not miss new messages when replaying the log (Prarit Bhargava) [1751075]
- [kernel] Revert "printk: make sure to print log on console." (Prarit Bhargava) [1751075]
- [lib] vsprintf: print OF node name using full_name (Prarit Bhargava) [1751075]
- [kernel] printk/tracing: Do not trace printk_nmi_enter() (Prarit Bhargava) [1751075]
- [misc] notifier: Remove notifier header file wherever not used (Prarit Bhargava) [1751075]
- [init] init: allow initcall tables to be emitted using relative references (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Do not handle pO[^F] as px (Prarit Bhargava) [1751075]
- [kernel] console: Replace #if 0 with atomic var 'ignore_console_lock_warning' (Prarit Bhargava) [1751075]
- [lib] vsprintf: Use hw RNG for ptr_key (Prarit Bhargava) [1751075]
- [kernel] printk: Fix warning about unused suppress_message_printing (Prarit Bhargava) [1751075]
- [char] random: Return nbytes filled from hw RNG (Prarit Bhargava) [1751075]
- [char] random: Fix whitespace pre random-bytes work (Prarit Bhargava) [1751075]
- [kernel] printk/nmi: Prevent deadlock when accessing the main log buffer in NMI (Prarit Bhargava) [1751075]
- [kernel] printk: Create helper function to queue deferred console handling (Prarit Bhargava) [1751075]
- [kernel] printk: Split the code for storing a message into the log buffer (Prarit Bhargava) [1751075]
- [kernel] printk: Clean up syslog_print_all() (Prarit Bhargava) [1751075]
- [kernel] printk: Export is_console_locked (Prarit Bhargava) [1751075]
- [kernel] printk: Remove unnecessary kmalloc() from syslog during clear (Prarit Bhargava) [1751075]
- [kernel] printk: Make CONSOLE_LOGLEVEL_QUIET configurable (Prarit Bhargava) [1751075]
- [kernel] printk: make sure to print log on console. (Prarit Bhargava) [1751075]
- [lib] lib/test_printf.c: accept "ptrval" as valid result for plain 'p' tests (Prarit Bhargava) [1751075]
- [kernel] softirq: Remove tasklet_hrtimer (Prarit Bhargava) [1737073]
- [include] list: add function list_rotate_to_front() (Prarit Bhargava) [1737073]
- [clocksource] clocksource/drivers/tcb_clksrc: Rename the file for consistency (Prarit Bhargava) [1737073]
- [clocksource] clocksource/drivers/tcb_clksrc: Move Kconfig option (Prarit Bhargava) [1737073]
- [clocksource] clocksource/drivers/tcb_clksrc: Use tcb as sched_clock (Prarit Bhargava) [1737073]
- [kernel] irq_work: Do not raise an IPI when queueing work on the local CPU (Prarit Bhargava) [1737073]
- [tty] tty/sysrq: Convert show_lock to raw_spinlock_t (Prarit Bhargava) [1737073]
- [net] xfrm: Replace hrtimer tasklet with softirq hrtimer (Prarit Bhargava) [1737073]
- [netdrv] mac80211_hwsim: Replace hrtimer tasklet with softirq hrtimer (Prarit Bhargava) [1737073]
- [kernel] kthread: Do not use TIMER_IRQSAFE (Prarit Bhargava) [1737073]
- [kernel] kthread: Convert worker lock to raw spinlock (Prarit Bhargava) [1737073]
- [netdrv] mac80211_hwsim: Timer should be initialized before device registered (Prarit Bhargava) [1737073]
- [net] xfrm: use time64_t for in-kernel timestamps (Prarit Bhargava) [1737073]
- [x86] x86/intel: Aggregate microserver naming (Prarit Bhargava) [1725644]
- [x86] x86/intel: Aggregate big core graphics naming (Prarit Bhargava) [1725644]
- [x86] x86/intel: Aggregate big core mobile naming (Prarit Bhargava) [1725644]
- [x86] x86/intel: Aggregate big core client naming (Prarit Bhargava) [1725644]
- [tools] turbostat: Replace GPLv2 boilerplate/reference with SPDX - rule 335 (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: update version number (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: rename has_hsw_msrs() (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Fix Haswell Core systems (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Add support for Hygon Fam 18h (Dhyana) RAPL (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Fix caller parameter of get_tdp_amd() (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Fix CPUC1 display value (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: do not enforce 1ms (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: read from pipes too (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Add Ice Lake NNPI support (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: add Jacobsville support (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: remove duplicate pc10 column (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: fix file descriptor leaks (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: fix leak of file descriptor on error return path (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: fix buffer overrun (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Make interval calculation per thread to reduce jitter (Prarit Bhargava) [1725644]
- [tools] tools/power/x86: Enable compiler optimisations and Fortify by default (Prarit Bhargava) [1725644]
- [x86] x86/cpu: Add Ice Lake NNPI to Intel family (Prarit Bhargava) [1725644]

* Tue Oct 22 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.9.el8]
- [tools] perf tools: Fix segfault in cpu_cache_level__read() (Michael Petlan) [1761995]
- [scsi] qla2xxx: Update driver version to 10.01.00.19.08.2-k (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix Nport ID display value (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix N2N link up fail (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix N2N link reset (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Optimize NPIV tear down process (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix stale mem access on driver unload (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix unbound sleep in fcport delete path. (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Silence fwdump template message (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix stale session (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix stuck login session (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix driver reload for ISP82xx (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix flash read for Qlogic ISPs (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix message indicating vectors used by driver (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: fix spelling mistake "initializatin" -> "initialization" (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a recently introduced kernel warning (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a NULL pointer dereference (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qla24xx_async_abort_cmd() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove two superfluous if-tests (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce qla2x00_els_dcmd2_free() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Inline the qla2x00_fcport_event_handler() function (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Report invalid mailbox status codes (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove superfluous sts_entry_* casts (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Let the compiler check the type of the SCSI command context pointer (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if sp->done() is not called from the completion path (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make sure that aborted commands are freed (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce qla2xxx_get_next_handle() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Modify NVMe include directives (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qlt_handle_abts_completion() more robust (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a race condition between aborting and completing a SCSI command (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce the function qla2xxx_init_sp() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Enable type checking for the SRB free and done callback functions (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Rework key encoding in qlt_find_host_by_d_id() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Set the responder mode if appropriate for ELS pass-through IOCBs (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make it explicit that ELS pass-through IOCBs use little endian (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Check secondary image if reading the primary image fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Change the return type of qla24xx_read_flash_data() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce the be_id_t and le_id_t data types for FC src/dst IDs (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if a soft reset fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use memcpy() and strlcpy() instead of strcpy() and strncpy() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Check the PCI info string output buffer size (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if waiting for pending commands times out (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare fourth qla2x00_set_model_info() argument const (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Always check the qla2x00_wait_for_hba_online() return value (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Suppress multiple Coverity complaint about out-of-bounds accesses (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Suppress a Coveritiy complaint about integer overflow (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove unreachable code from qla83xx_idc_lock() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix qla24xx_process_bidir_cmd() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify a debug statement (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove dead code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if parsing the version string fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if a mailbox command times out (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use strlcpy() instead of strncpy() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Do not corrupt vha->plogi_ack_list (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Report the firmware status code if a mailbox command fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix session lookup in qlt_abort_work() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qla24xx_abort_sp_done() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove two superfluous tests (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a superfluous pointer check (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qlt_lport_dump() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reduce the number of casts in GID list code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Verify locking assumptions at runtime (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Change data_dsd into an array (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare qla_tgt_cmd.cdb const (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reduce the scope of three local variables in qla2xxx_queuecommand() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Change the return type of qla2x00_update_ms_fdmi_iocb() into void (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare the fourth ql_dump_buffer() argument const (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a superfluous forward declaration (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove an include directive from qla_mr.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Include the <asm/unaligned.h> header file from qla_dsd.h (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use tabs instead of spaces for indentation (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Improve Linux kernel coding style conformance (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Really fix qla2xxx_eh_abort() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla2x00_abort_srb() again decrease the sp reference count (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Allow NVMe IO to resume with short cable pull (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix hang in fcport delete path (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use common update-firmware-options routine for ISP27xx+ (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix NVMe port discovery after a short device port loss (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Correct error handling during initialization failures (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Retry fabric Scan on IOCB queue full (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix premature timer expiration (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix Relogin to prevent modifying scan_state flag (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reject EH_{abort|device_reset|target_request} (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Skip FW dump on LOOP initialization error (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use Correct index for Q-Pair array (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix abort timeout race condition. (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix DMA unmap leak (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Replace vmalloc + memset with vzalloc (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove unnecessary null check (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: remove double assignment in qla2x00_update_fcport (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Add cleanup for PCI EEH recovery (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that lockdep complains about unsafe locking in tcm_qla2xxx_close_session() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that qlt_send_resp_ctio() corrupts memory (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use __le64 instead of uint32_t[2] for sending DMA addresses to firmware (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce the dsd32 and dsd64 data structures (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Check the size of firmware data structures at compile time (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Pass little-endian values to the firmware (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla24xx_async_abort_cmd() static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove unnecessary locking from the target code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove qla_tgt_cmd.released (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if a command is released that is owned by the firmware (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: target: Fix offline port handling and host reset handling (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix abort handling in tcm_qla2xxx_write_pending() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix error handling in qlt_alloc_qfull_cmd() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qlt_send_term_imm_notif() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix use-after-free issues in qla2xxx_qpair_sp_free_dma() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a qla24xx_enable_msix() error path (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that qla2x00_mem_free() crashes if called twice (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla2x00_mem_free() easier to verify (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Increase the size of the mailbox arrays from 4 to 8 (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Log the status code if a firmware command fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that Coverity complains about dereferencing a NULL rport pointer (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Uninline qla2x00_init_timer() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_is_reserved_id() from qla_inline.h into qla_init.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_clear_loop_id() from qla_inline.h into qla_init.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a set-but-not-used variable (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare qla2x00_find_new_loop_id() static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_set_reserved_loop_ids() definition (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a format specifier (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Update two source code comments (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Silence Successful ELS IOCB message (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix device staying in blocked state (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_set_fcport_state() from a .h into a .c file (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove two superfluous casts (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove qla_tgt_cmd.data_work and qla_tgt_cmd.data_work_free (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move the <linux/io-64-nonatomic-lo-hi.h> include directive (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare qla24xx_build_scsi_crc_2_iocbs() static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move the port_state_str[] definition from a .h to a .c file (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Insert spaces where required (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix formatting of pointer types (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Leave a blank line after declarations (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use tabs to indent code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix FC-AL connection target discovery (Himanshu Madhani) [1728845]
- [scsi] scsi: tcm_qla2xxx: Minimize #include directives (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Unregister resources in the opposite order of the registration order (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Unregister chrdev if module initialization fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use get/put_unaligned where appropriate (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla2x00_process_response_queue() easier to read (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare local symbols static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use ARRAY_SIZE() in the definition of QLA_LAST_SPEED (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a comment that refers to the SCSI host lock (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove useless set memory to zero use memset() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Cleanup fcport memory to prevent leak (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Further limit FLASH region write access from SysFS (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix incorrect region-size setting in optrom SYSFS routines (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe during probe (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Increase the max_sgl_segments to 1024 (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reset the FCF_ASYNC_{SENT|ACTIVE} flags (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Set the qpair in SRB to NULL when SRB is released (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a small typo in qla_bsg.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix comment alignment in qla_bsg.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: deadlock by configfs_depend_item (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: use lower_32_bits and upper_32_bits instead of reinventing them (Himanshu Madhani) [1728845]
- [md] dm snapshot: rework COW throttling to fix deadlock (Mike Snitzer) [1758605]
- [md] dm snapshot: introduce account_start_copy() and account_end_copy() (Mike Snitzer) [1758605]
- [netdrv] ice: Bump version (Jonathan Toppins) [1721711]
- [netdrv] ice: Enable DDP package download (Jonathan Toppins) [1721711]
- [netdrv] ice: Initialize DDP package structures (Jonathan Toppins) [1721711]
- [netdrv] ice: Implement Dynamic Device Personalization (DDP) download (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix FW version formatting in dmesg (Jonathan Toppins) [1721711]
- [netdrv] ice: send driver version to firmware (Jonathan Toppins) [1721711]
- [netdrv] ice: Rework around device/function capabilities (Jonathan Toppins) [1721711]
- [netdrv] ice: change default number of receive descriptors (Jonathan Toppins) [1721711]
- [netdrv] ice: Minor refactor in queue management (Jonathan Toppins) [1721711]
- [netdrv] ice: Allow for delayed LLDP MIB change registration (Jonathan Toppins) [1721711]
- [netdrv] ice: update Tx context struct (Jonathan Toppins) [1721711]
- [netdrv] ice: Report VF link status with opcode to get resources (Jonathan Toppins) [1721711]
- [netdrv] ice: Check for DCB capability before initializing DCB (Jonathan Toppins) [1721711]
- [netdrv] ice: report link down for VF when PF's queues are not enabled (Jonathan Toppins) [1721711]
- [netdrv] ice: Reliably reset VFs (Jonathan Toppins) [1721711]
- [netdrv] ice: change work limit to a constant (Jonathan Toppins) [1721711]
- [netdrv] ice: small efficiency fixes (Jonathan Toppins) [1721711]
- [netdrv] ice: move code closer together (Jonathan Toppins) [1721711]
- [netdrv] ice: clean up arguments (Jonathan Toppins) [1721711]
- [netdrv] ice: Check root pointer for validity (Jonathan Toppins) [1721711]
- [netdrv] ice: Add ice_get_main_vsi to get PF/main VSI (Jonathan Toppins) [1721711]
- [netdrv] ice: Update fields in ice_vsi_set_num_qs when reconfiguring (Jonathan Toppins) [1721711]
- [netdrv] ice: Only disable VLAN pruning for the VF when all VLANs are removed (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove enable DCB when SW LLDP is activated (Jonathan Toppins) [1721711]
- [netdrv] ice: Report stats when VSI is down (Jonathan Toppins) [1721711]
- [netdrv] ice: Always notify FW of VF reset (Jonathan Toppins) [1721711]
- [netdrv] ice: Correctly handle return values for init DCB (Jonathan Toppins) [1721711]
- [netdrv] ice: Limit Max TCs on devices with more than 4 ports (Jonathan Toppins) [1721711]
- [netdrv] ice: Cleanup defines in ice_type.h (Jonathan Toppins) [1721711]
- [netdrv] ice: print extra message if topology issue (Jonathan Toppins) [1721711]
- [netdrv] ice: add print of autoneg state to link message (Jonathan Toppins) [1721711]
- [netdrv] ice: update driver unloading field for Queue Shutdown AQ command (Jonathan Toppins) [1721711]
- [netdrv] ice: add needed PFR during driver unload (Jonathan Toppins) [1721711]
- [netdrv] ice: Deduce TSA value from the priority value in the CEE mode (Jonathan Toppins) [1721711]
- [netdrv] ice: Report what the user set for coalesce [tx|rx]-usecs (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix resource leak in ice_remove_rule_internal() (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix EMP reset handling (Jonathan Toppins) [1721711]
- [netdrv] ice: fix adminq calls during remove (Jonathan Toppins) [1721711]
- [netdrv] ice: Rework ice_ena_msix_range (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix VF configuration issues due to reset (Jonathan Toppins) [1721711]
- [netdrv] ice: Alloc queue management bitmaps and arrays dynamically (Jonathan Toppins) [1721711]
- [netdrv] ice: add support for virtchnl_queue_select.[tx|rx]_queues bitmap (Jonathan Toppins) [1721711]
- [netdrv] ice: add support for enabling/disabling single queues (Jonathan Toppins) [1721711]
- [netdrv] ice: fix potential infinite loop (Jonathan Toppins) [1721711]
- [netdrv] ice: fix ice_is_tc_ena (Jonathan Toppins) [1721711]
- [netdrv] ice: add validation in OP_CONFIG_VSI_QUEUES VF message (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't clog kernel debug log with VF MDD events errors (Jonathan Toppins) [1721711]
- [netdrv] ice: Introduce a local variable for a VSI in the rebuild path (Jonathan Toppins) [1721711]
- [netdrv] ice: shorten local and add debug prints (Jonathan Toppins) [1721711]
- [netdrv] ice: Sanitize ice_ena_vsi and ice_dis_vsi (Jonathan Toppins) [1721711]
- [netdrv] ice: added sibling head to parse nodes (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix ethtool port and PFC stats for 4x25G cards (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't allow VSI to remove unassociated ucast filter (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix issues updating VSI MAC filters (Jonathan Toppins) [1721711]
- [netdrv] ice: update ethtool stats on-demand (Jonathan Toppins) [1721711]
- [netdrv] ice: Add input handlers for virtual channel handlers (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't clear auto_fec bit in ice_cfg_phy_fec() (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix flag used for module query (Jonathan Toppins) [1721711]
- [netdrv] ice: silence some bogus error messages (Jonathan Toppins) [1721711]
- [netdrv] ice: Rename ethtool private flag for lldp (Jonathan Toppins) [1721711]
- [netdrv] ice: reject VF attempts to enable head writeback (Jonathan Toppins) [1721711]
- [netdrv] ice: Copy dcbx configuration only if mode is correct (Jonathan Toppins) [1721711]
- [netdrv] ice: Treat DCBx state NOT_STARTED as valid (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't call synchronize_irq() for VF's from the host (Jonathan Toppins) [1721711]
- [netdrv] ice: Account for all states of FW DCBx and LLDP (Jonathan Toppins) [1721711]
- [netdrv] ice: Allow egress control packets from PF_VSI (Jonathan Toppins) [1721711]
- [netdrv] ice: improve print for VF's when adding/deleting MAC filters (Jonathan Toppins) [1721711]
- [netdrv] ice: Change type for queue counts (Jonathan Toppins) [1721711]
- [netdrv] ice: Move VF resources definition to SR-IOV specific file (Jonathan Toppins) [1721711]
- [netdrv] ice: Increase size of Mailbox receive queue for many VFs (Jonathan Toppins) [1721711]
- [netdrv] ice: Reduce wait times during VF bringup/reset (Jonathan Toppins) [1721711]
- [netdrv] ice: update GLINT_DYN_CTL and GLINT_VECT2FUNC register access (Jonathan Toppins) [1721711]
- [netdrv] ice: Do not always bring up PF VSI in ice_ena_vsi() (Jonathan Toppins) [1721711]
- [netdrv] ice: allow empty Rx descriptors (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix kernel hang with DCB reset in CEE mode (Jonathan Toppins) [1721711]
- [netdrv] ice: Set WB_ON_ITR when we don't re-enable interrupts (Jonathan Toppins) [1721711]
- [netdrv] ice: fix set pause param autoneg check (Jonathan Toppins) [1721711]
- [netdrv] ice: Restructure VFs initialization flows (Jonathan Toppins) [1721711]
- [netdrv] ice: Assume that more than one Rx queue is rare in ice_napi_poll (Jonathan Toppins) [1721711]
- [netdrv] ice: Use the software based tail when checking for hung Tx ring (Jonathan Toppins) [1721711]
- [netdrv] ice: Bump version number (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove flag to track VF interrupt status (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove unnecessary flag ICE_FLAG_MSIX_ENA (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't return error for disabling LAN Tx queue that does exist (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove duplicate code in ice_alloc_rx_bufs (Jonathan Toppins) [1721711]
- [netdrv] ice: Add stats for Rx drops at the port level (Jonathan Toppins) [1721711]
- [netdrv] ice: Update number of VF queue before setting VSI resources (Jonathan Toppins) [1721711]
- [netdrv] ice: Set up Tx scheduling tree based on alloc VSI Tx queues (Jonathan Toppins) [1721711]
- [netdrv] ice: Only bump Rx tail and release buffers once per napi_poll (Jonathan Toppins) [1721711]
- [netdrv] ice: Disable VFs until reset is completed (Jonathan Toppins) [1721711]
- [netdrv] ice: Do not configure port with no media (Jonathan Toppins) [1721711]
- [netdrv] ice: separate out control queue lock creation (Jonathan Toppins) [1721711]
- [netdrv] ice: Always set prefena when configuring an Rx queue (Jonathan Toppins) [1721711]
- [netdrv] ice: Move vector base setup to PF VSI (Jonathan Toppins) [1721711]
- [netdrv] ice: track hardware stat registers past rollover (Jonathan Toppins) [1721711]
- [netdrv] ice: add lp_advertising flow control support (Jonathan Toppins) [1721711]
- [netdrv] ice: Use struct_size() helper (Jonathan Toppins) [1721711]
- [netdrv] ice: Use LLDP ethertype define ETH_P_LLDP (Jonathan Toppins) [1721711]
- [netdrv] ice: Trivial cosmetic changes (Jonathan Toppins) [1721711]
- [netdrv] ice: Recognize higher speeds (Jonathan Toppins) [1721711]
- [netdrv] ice: Use a different ICE_DBG bit for firmware log messages (Jonathan Toppins) [1721711]
- [netdrv] ice: Update function header (Jonathan Toppins) [1721711]
- [netdrv] ice: Move define for ICE_AQC_DRIVER_UNLOADING (Jonathan Toppins) [1721711]
- [netdrv] ice: Align to updated AQ command formats (Jonathan Toppins) [1721711]
- [netdrv] ice: Use continue instead of an else block (Jonathan Toppins) [1721711]
- [netdrv] ice: Change minimum descriptor count value for Tx/Rx rings (Jonathan Toppins) [1721711]
- [netdrv] ice: Add switch rules to handle LLDP packets (Jonathan Toppins) [1721711]
- [netdrv] ice: Cleanup ice_update_link_info (Jonathan Toppins) [1721711]
- [netdrv] ice: Use right type for ice_cfg_vsi_lan return (Jonathan Toppins) [1721711]
- [netdrv] ice: Add support for Forward Error Correction (FEC) (Jonathan Toppins) [1721711]
- [netdrv] ice: Add support for virtchnl_vector_map.[rxq|txq]_map (Jonathan Toppins) [1721711]
- [netdrv] ice: Introduce ice_init_mac_fltr and move ice_napi_del (Jonathan Toppins) [1721711]
- [netdrv] ice: Use GLINT_DYN_CTL to disable VF's interrupts (Jonathan Toppins) [1721711]
- [netdrv] ice: Add a helper to trigger software interrupt (Jonathan Toppins) [1721711]
- [netdrv] ice: Configure RSS LUT key only if RSS is enabled (Jonathan Toppins) [1721711]
- [netdrv] ice: Add ice_get_fw_log_cfg to init FW logging (Jonathan Toppins) [1721711]
- [netdrv] ice: Minor cleanup in ice_switch.h (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove redundant and premature event config (Jonathan Toppins) [1721711]
- [netdrv] ice: Change message level (Jonathan Toppins) [1721711]
- [netdrv] ice: Check all VFs for MDD activity, don't disable (Jonathan Toppins) [1721711]
- [netdrv] ice: Refactor interrupt tracking (Jonathan Toppins) [1721711]
- [netdrv] ice: Add handler for ethtool selftest (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't call ice_cfg_itr() for SR-IOV (Jonathan Toppins) [1721711]
- [netdrv] ice: Set minimum default Rx descriptor count to 512 (Jonathan Toppins) [1721711]
- [netdrv] ice: Resolve static analysis warning (Jonathan Toppins) [1721711]
- [netdrv] ice: Implement toggling ethtool rx-vlan-filter (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove direct write for GLLAN_RCTL_0 (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix LINE_SPACING style issue (Jonathan Toppins) [1721711]
- [netdrv] ice: Silence semantic parser warnings (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix couple of issues in ice_vsi_release (Jonathan Toppins) [1721711]
- [netdrv] ice: Reorganize ice_vf struct (Jonathan Toppins) [1721711]
- [netdrv] ice: Use bitfields when possible (Jonathan Toppins) [1721711]
- [netdrv] ice: Reorganize tx_buf and ring structs (Jonathan Toppins) [1721711]
- [netdrv] ice: Format ethtool reported stats (Jonathan Toppins) [1721711]
- [netdrv] ice: Gracefully handle reset failure in ice_alloc_vfs() (Jonathan Toppins) [1721711]
- [netdrv] ice: Refactor the LLDP MIB change event handling (Jonathan Toppins) [1721711]
- [netdrv] ice: Advertise supported link modes if none requested (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix hang when ethtool disables FW LLDP (Jonathan Toppins) [1721711]
- [netdrv] ice: Call out dev/func caps when printing (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove braces for single statement blocks (Jonathan Toppins) [1721711]
- [netdrv] ice: Cleanup an unnecessary variable initialization (Jonathan Toppins) [1721711]
- [netdrv] ice: Implement LLDP persistence (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix double spacing (Jonathan Toppins) [1721711]
- [kernel] sched/debug: Fix potential deadlock when writing to sched_features (Vladis Dronov) [1760060]
- [kernel] sched/debug: Use match_string() helper instead of open-coded logic (Vladis Dronov) [1760060]
- [hid] HID: intel-ish-hid: ipc: add EHL device id (Tony Camuso) [1716756]
- [hid] HID: remove NO_D3 flag when remove driver (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: fix wrong driver_data usage (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Fix a use after free in load_fw_from_host() (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add SPDX license identifier - Makefile/Kconfig (Tony Camuso) [1716756]
- [platform] platform/chrome: Add ChromeOS EC ISHTP driver (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: prefix header search paths with $(srctree)/ (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add Comet Lake PCI device ID (Tony Camuso) [1716756]
- [platform] platform/chrome: cros_ec: Add EC host command support using rpmsg (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: fix spelling mistake "multipe" -> "multiple" (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ISH firmware loader client driver (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add interface function for PCI device pointer (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Use the new interface functions in HID ish client (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Move functions related to bus and device (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add interface functions for struct ishtp_cl (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Move the common functions from client.h (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Store ishtp_cl_device instance in device (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Move driver registry functions (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Simplify ishtp_cl_link() (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Hide members of struct ishtp_cl_device (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add match callback to ishtp bus type (Tony Camuso) [1716756]
- [hid] HID: intel-ish: enable raw interface to HID devices on ISH (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Use VID/PID from ISH (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Switch to use new generic UUID API (Tony Camuso) [1716756]
- [hid] HID: intel-ish: ipc: handle PIMR before ish_wakeup also clear PISR busy_clear bit (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: use helper function to search client id (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ishtp: add helper function for client search (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: use helper function to access client buffer (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ishtp: add helper functions for client buffer operation (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: use helper function for private driver data set/get (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ishtp: add helper function for driver data get/set (Tony Camuso) [1716756]
- [platform] platform/chrome: Move cros-ec transport drivers to drivers/platform. (Tony Camuso) [1716756]
- [tools] tools: PCI: Fix compiler warning in pcitest (Myron Stowe) [1753749]
- [iommu] iommu: Fix integer truncation (Myron Stowe) [1753749]
- [pci] PCI/P2PDMA: Ignore root complex whitelist when an IOMMU is present (Myron Stowe) [1753749]
- [pci] PCI: Cleanup setup-bus.c comments and whitespace (Myron Stowe) [1753749]
- [include] CPER: Remove unnecessary use of user-space types (Myron Stowe) [1753749]
- [include] CPER: Add UEFI spec references (Myron Stowe) [1753749]
- [pci] PCI: Fix comment typos (Myron Stowe) [1753749]
- [pci] PCI: Cleanup register definition width and whitespace (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove pointless MY_NAME definition (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove pointless PCIE_MODULE_NAME definition (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove unused dbg/err/info/warn() wrappers (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Log messages with pci_dev, not pcie_device (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Replace pciehp_debug module param with dyndbg (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove pciehp_debug uses (Myron Stowe) [1753749]
- [pci] PCI/AER: Log messages with pci_dev, not pcie_device (Myron Stowe) [1753749]
- [pci] PCI/DPC: Log messages with pci_dev, not pcie_device (Myron Stowe) [1753749]
- [pci] PCI/PME: Replace dev_printk(KERN_DEBUG) with dev_info() (Myron Stowe) [1753749]
- [pci] PCI/AER: Replace dev_printk(KERN_DEBUG) with dev_info() (Myron Stowe) [1753749]
- [pci] PCI: Replace dev_printk(KERN_DEBUG) with dev_info(), etc (Myron Stowe) [1753749]
- [pci] PCI: Replace printk(KERN_INFO) with pr_info(), etc (Myron Stowe) [1753749]
- [pci] PCI: Use dev_printk() when possible (Myron Stowe) [1753749]
- [iommu] iommu/dma: Reserve IOVA for PCIe inaccessible DMA address (Myron Stowe) [1753749]
- [pci] PCI: Add dma_ranges window list (Myron Stowe) [1753749]
- [pci] PCI: endpoint: Fix a potential NULL pointer dereference (Myron Stowe) [1753749]
- [tools] tools: PCI: Handle pcitest.sh independently from pcitest (Myron Stowe) [1753749]
- [tools] tools: PCI: Add 'h' in optstring of getopt() (Myron Stowe) [1753749]
- [tools] tools: PCI: Change pcitest compiling process (Myron Stowe) [1753749]
- [tools] tools: PCI: Fix compilation warnings (Myron Stowe) [1753749]
- [tools] tools: PCI: Exit with error code when test fails (Myron Stowe) [1753749]
- [pci] PCI: Mark Atheros AR9462 to avoid bus reset (Myron Stowe) [1753749]
- [pci] switchtec: Fix unintended mask of MRPC event (Myron Stowe) [1753749]
- [pci] switchtec: Increase PFF limit from 48 to 255 (Myron Stowe) [1753749]
- [pci] PCI/LINK: Disable bandwidth notification interrupt during suspend (Myron Stowe) [1753749]
- [pci] PCI/P2PDMA: Allow P2P DMA between any devices under AMD ZEN Root Complex (Myron Stowe) [1753749]
- [maintainers] MAINTAINERS: Add Karthikeyan Mitran and Hou Zhiqiang for Mobiveil PCI (Myron Stowe) [1753749]
- [platform] platform/chrome: chromeos_laptop: use pci_dev_id() helper (Myron Stowe) [1753749]
- [iommu] iommu/amd: Use pci_dev_id() helper (Myron Stowe) [1753749]
- [drm] drm/amdkfd: Use pci_dev_id() helper (Myron Stowe) [1753749]
- [powerpc] powerpc/powernv/npu: Use pci_dev_id() helper (Myron Stowe) [1753749]
- [x86] x86/PCI: Fix PCI IRQ routing table memory leak (Myron Stowe) [1753749]
- [pci] PCI: Remove unused pci_request_region_exclusive() (Myron Stowe) [1753749]
- [pci] PCI: Mark expected switch fall-throughs (Myron Stowe) [1753749]
- [pci] PCI/ACPI: Remove the need for 'struct hotplug_params' (Myron Stowe) [1753749]
- [pci] PCI/ACPI: Do not export pci_get_hp_params() (Myron Stowe) [1753749]
- [pci] PCI: rpaphp: Get/put device node reference during slot alloc/dealloc (Myron Stowe) [1753749]
- [pci] PCI: rpadlpar: Fix leaked device_node references in add/remove paths (Myron Stowe) [1753749]
- [pci] PCI: Assign bus numbers present in EA capability for bridges (Myron Stowe) [1753749]
- [pci] PCI: OF: Support "external-facing" property (Myron Stowe) [1753749]
- [documentation] dt-bindings: Add "external-facing" PCIe port property (Myron Stowe) [1753749]
- [pci] PCI: Init PCIe feature bits for managed host bridge alloc (Myron Stowe) [1753749]
- [pci] PCI/AER: Change pci_aer_init() stub to return void (Myron Stowe) [1753749]
- [s390] s390/zcrypt: CEX7S exploitation support (Philipp Rudo) [1726416]
- [s390] s390/pkey: Add sysfs attributes to emit AES CIPHER key blobs (Philipp Rudo) [1726416]
- [s390] s390/crypto: Support for SHA3 via CPACF (MSA6) (Philipp Rudo) [1726416]
- [s390] s390/crypto: xts-aes-s390 fix extra run-time crypto self tests finding (Philipp Rudo) [1726416]
- [s390] s390: vfio-ap: fix warning reset not completed (Philipp Rudo) [1726416]
- [s390] crypto: s390 - Rename functions to avoid conflict with crypto/sha256.h (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: fix wrong handling of cca cipher keygenflags (Philipp Rudo) [1726416]
- [s390] crypto: s390/xts-aes - invoke fallback for ciphertext stealing (Philipp Rudo) [1726416]
- [s390] s390/paes: Prepare paes functions for large key blobs (Philipp Rudo) [1726416]
- [s390] s390/pkey: add CCA AES cipher key support (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: Add low level functions for CCA AES cipher keys (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: extend cca_findcard function and helper (Philipp Rudo) [1726416]
- [s390] s390/pkey: pkey cleanup: narrow in-kernel API, fix some variable types (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: adjust switch fall through comments for -Wimplicit-fallthrough (Philipp Rudo) [1726416]
- [s390] crypto: s390/aes - fix name clash after AES library refactor (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: new sysfs attributes serialnr and mkvps (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: add base code for cca crypto card info support (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: move cca misc functions to new code file (Philipp Rudo) [1726416]
- [s390] s390: use __u{16, 32, 64} instead of uint{16, 32, 64}_t in uapi header (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: remove the exporting of ap_query_configuration (Philipp Rudo) [1726416]
- [s390] s390/crypto: sha: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/crypto: prng: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/crypto: ghash: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/pkey: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: support special flagged EP11 cprbs (Philipp Rudo) [1726416]
- [s390] s390/crypto: fix possible sleep during spinlock aquired (Philipp Rudo) [1726416]
- [s390] s390/crypto: use TRNG for seeding/reseeding (Philipp Rudo) [1726416]
- [s390] s390/crypto: rework generate_entropy function for pseudo random dd (Philipp Rudo) [1726416]
- [s390] s390: zcrypt: initialize variables before_use (Philipp Rudo) [1726416]
- [powerpc] powerpc/pseries: Track LMB nid instead of using device tree (Steve Best) [1758742]
- [powerpc] powerpc/pseries/memory-hotplug: Only update DT once per memory DLPAR request (Steve Best) [1758742]
- [net] hv_sock: Fix hang when a connection is closed (Cathy Avery) [1739477]
- [net] hv_sock: Use consistent types for UUIDs (Cathy Avery) [1739477]
- [net] hvsock: fix epollout hang from race condition (Cathy Avery) [1739477]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Cathy Avery) [1739477]
- [net] hv_sock: perf: loop in send() to maximize bandwidth (Cathy Avery) [1739477]
- [net] hv_sock: perf: Allow the socket buffer size options to influence the actual socket buffers (Cathy Avery) [1739477]
- [net] hv_sock: Add support for delayed close (Cathy Avery) [1739477]
- [powerpc] powerpc/rtas: allow rescheduling while changing cpu states (Steve Best) [1758651]
- [powerpc] powerpc/pseries/mobility: use cond_resched when updating device tree (Steve Best) [1758651]
- [tools] selftests/powerpc: Fix compile error on tlbie_test due to newer gcc (Desnes Augusto Nunes do Rosario) [1755707]
- [tools] selftests/powerpc: Add test case for tlbie vs mtpidr ordering issue (Desnes Augusto Nunes do Rosario) [1755707]
- [powerpc] powerpc/mm: Fixup tlbie vs mtpidr/mtlpidr ordering issue on POWER9 (Desnes Augusto Nunes do Rosario) [1755707]
- [powerpc] powerpc/book3s64/radix: Rename CPU_FTR_P9_TLBIE_BUG feature flag (Desnes Augusto Nunes do Rosario) [1755707]
- [powerpc] powerpc/book3s64/mm: Don't do tlbie fixup for some hardware revisions (Desnes Augusto Nunes do Rosario) [1755707]
- [scsi] scsi: zfcp: make DIX experimental, disabled, and independent of DIF (Philipp Rudo) [1723829]
- [s390] s390: add support for IBM z15 machines (Philipp Rudo) [1757015]
- [s390] s390/pci: add mio_enabled attribute (Philipp Rudo) [1757118]
- [s390] s390: fix setting of mio addressing control (Philipp Rudo) [1757118]
- [s390] s390/pci: correctly handle MIO opt-out (Philipp Rudo) [1757118]
- [s390] s390/pci: deal with devices that have no support for MIO instructions (Philipp Rudo) [1757118]
- [s390] s390/pci: fix assignment of bus resources (Philipp Rudo) [1757118]
- [s390] s390/pci: fix struct definition for set PCI function (Philipp Rudo) [1757118]
- [s390] s390/pci: fix MSI message data (Philipp Rudo) [1757123]
- [powerpc] powerpc/tm: Add tm-poison test (Steve Best) [1756721]
- [powerpc] powerpc/powernv: Add new opal message type (Desnes Augusto Nunes do Rosario) [1706975]
- [powerpc] powerpc/powernv: Enhance opal message read interface (Desnes Augusto Nunes do Rosario) [1706975]
- [char] hwrng: core - don't wait on add_early_randomness() (Laurent Vivier) [1660802]
- [firmware] efi: Export Runtime Configuration Interface table to sysfs (Al Stone) [1665518]
- [nvme] nvme: Treat discovery subsystems as unique subsystems (Ewan Milne) [1757525]
- [powerpc] powerpc/powernv/opal: Use standard interrupts property when available (Steve Best) [1757173]
- [powerpc] powerpc: dump kernel log before carrying out fadump or kdump (Steve Best) [1756922]
- [kernel] genirq/affinity: Create affinity mask for single vector (Ming Lei) [1733420]
- [virt] kvm: arm/arm64: Only skip MMIO insn once (Andrew Jones) [1733928]
- [vfio] type1: remove duplicate retrieval of reserved regions (Auger Eric) [1704597]
- [vfio] type1: Add IOVA range capability support (Auger Eric) [1704597]
- [vfio] type1: check dma map request is within a valid iova range (Auger Eric) [1704597]
- [vfio] type1: Update iova list on detach (Auger Eric) [1704597]
- [vfio] type1: Check reserved region conflict and update iova list (Auger Eric) [1704597]
- [vfio] type1: Introduce iova list and add iommu aperture validity check (Auger Eric) [1704597]
- [iommu] Revisit iommu_insert_resv_region() implementation (Auger Eric) [1704597]
- [iommu] vt-d: Differentiate relaxable and non relaxable RMRRs (Auger Eric) [1704597]
- [iommu] Introduce IOMMU_RESV_DIRECT_RELAXABLE reserved memory regions (Auger Eric) [1704597]
- [iommu] vt-d: Handle PCI bridge RMRR device scopes in intel_iommu_get_resv_regions (Auger Eric) [1704597]
- [iommu] vt-d: Handle RMRR with PCI bridge device scopes (Auger Eric) [1704597]
- [iommu] vt-d: Introduce is_downstream_to_pci_bridge helper (Auger Eric) [1704597]
- [iommu] vt-d: Duplicate iommu_resv_region objects per device list (Auger Eric) [1704597]
- [iommu] Fix a leak in iommu_insert_resv_region (Auger Eric) [1704597]
- [pci] hv: Avoid use of hv_pci_dev->pci_slot after freeing it (Mohammed Gamal) [1737569]

* Thu Oct 17 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.8.el8]
- [x86] kvm: x86: omit "impossible" pmu MSRs from MSR list (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Fix consistency check on injected exception error code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: omit absent pmu MSRs from MSR list (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: Fix libkvm build error (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Limit guest PMCs to those supported on the host (Vitaly Kuznetsov) [1749495]
- [virt] kvm: x86, powerpc: do not allow clearing largepages debugfs entry (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: x86: clarify what is reported on KVM_GET_MSRS failure (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Set VMENTER_L1D_FLUSH_NOT_REQUIRED if !X86_BUG_L1TF (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: add test for dirty logging inside nested guests (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: fix nested guest live migration with PML (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: assign two bits to track SPTE kinds (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Expose XSAVEERPTR to the guest (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Enumerate support for CLZERO instruction (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Use AMD CPUID semantics for AMD vCPUs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Improve emulation of CPUID leaves 0BH and 1FH (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix userspace set invalid CR4 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix a spurious -E2BIG in __do_cpuid_func (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Loosen filter for adaptive tuning of lapic_timer_advance_ns (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: cleanup and fix host 64-bit mode checks (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: fix build warnings in hv_enable_direct_tlbflush() on i386 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Don't check kvm_rebooting in __kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Drop ____kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Add error handling to VMREAD helper (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Optimize VMX instruction error and fault handling (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Check kvm_rebooting in kvm_spurious_fault() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: limit atomic switch MSRs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: Intercept RDPRU (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add "significant index" flag to a few CPUID leaves (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Skip invalid pages during zapping iff root_count is zero (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Explicitly track only a single invalid mmu generation (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "kvm: x86/mmu: Remove is_obsolete() call" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: reclaim the zapped-obsolete page first"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: collapse TLB flushes when zap all pages"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: zap pages in batch"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: add tracepoint for kvm_mmu_invalidate_all_pages"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: show mmu_valid_gen in shadow page related tracepoints"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Use fast invalidate mechanism to zap MMIO sptes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Treat invalid shadow pages as obsolete (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Tune lapic_timer_advance_ns smoothly (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add comments to document various emulation types (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Handle single-step #DB for EMULTYPE_SKIP on EPT misconfig (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Remove emulation_result enums, EMULATE_{DONE, FAIL, USER_EXIT} (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Remove EMULATE_FAIL handling in handle_invalid_guest_state() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move triple fault request into RM int injection (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Handle emulation failure directly in kvm_task_switch() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Exit to userspace on emulation skip failure (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move #UD injection for failed emulation into emulation code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add explicit flag for forced emulation on #UD (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move #GP injection for VMware into x86_emulate_instruction() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Don't attempt VMWare emulation on #GP with non-zero error code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Refactor kvm_vcpu_do_singlestep() to remove out param (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Clean up handle_emulation_failure() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Relocate MMIO exit stats counting (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Check Host Address Space Size on vmentry of nested guests (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: hyperv_cpuid: add check for NoNonArchitecturalCoreSharing bit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: hyper-v: set NoNonArchitecturalCoreSharing CPUID bit when SMT is impossible (Vitaly Kuznetsov) [1749495]
- [kernel] cpu/smt: create and export cpu_smt_possible() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: hyperv: Fix Direct Synthetic timers assert an interrupt w/o lapic_in_kernel (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Manually flush collapsible SPTEs only when toggling flags (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Remove duplicate guest mode handling (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Introduce VM_MODE_PXXV48_4K (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Create VM earlier for dirty log test (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Move vm type into _vm_create() internally (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: announce KVM_CAP_HYPERV_ENLIGHTENED_VMCS support only when it is available (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: svm: remove unneeded nested_enable_evmcs() hook (Vitaly Kuznetsov) [1749495]
- [x86] kvm/hyper-v/vmx: Add direct tlb flush support (Vitaly Kuznetsov) [1749495]
- [documentation] kvm/hyper-v: Add new KVM capability KVM_CAP_HYPERV_DIRECT_TLBFLUSH (Vitaly Kuznetsov) [1749495]
- [x86] hyper-v: Fix definition of struct hv_vp_assist_page (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add Intel PMU MSRs to msrs_to_save[] (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Use IPI shorthands in kvm guest when support (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix INIT signal handling in various CPU states (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Introduce exit reason for receiving INIT signal on guest-mode (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Stop the preemption timer during vCPU reset (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Micro optimize IPI latency (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Nested KVM MMUs need PAE root too (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: set ctxt->have_exception in x86_decode_insn() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: always stop emulation on page fault (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: trace nested VM-Enter failures detected by H/W (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: add tracepoint for failed nested VM-Enter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: Fix a check in nested_svm_vmrun() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Return to userspace with internal error on unexpected exit reason (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add kvm_emulate_{rd, wr}msr() to consolidate VXM/SVM code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Refactor up kvm_{g, s}et_msr() to simplify callers (Vitaly Kuznetsov) [1749495]
- [documentation] doc: kvm: Fix return description of KVM_SET_MSRS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Tune PLE Window tracepoint (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Change ple_window type to unsigned int (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Remove tailing newline for tracepoints (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Trace vcpu_id for vmexit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Manually calculate reserved bits when loading PDPTRS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Disable posted interrupts for non-standard IRQs delivery modes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Fix and tweak the comments for VM-Enter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Assert that struct kvm_vcpu is always as offset zero (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add pv tlb shootdown tracepoint (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Unconditionally call x86 ops that are always implemented (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Consolidate "is MMIO SPTE" code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Add explicit access mask for MMIO SPTEs (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: x86: Rename access permissions cache member in struct kvm_vcpu_arch (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: eliminate hardcoded RIP advancement from vmrun_interception() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: eliminate weird goto from vmrun_interception() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: remove hardcoded instruction length from intercepts (Vitaly Kuznetsov) [1749495]
- [x86] kvm: add xsetbv to the emulator (Vitaly Kuznetsov) [1749495]
- [x86] kvm: clear interrupt shadow on EMULTYPE_SKIP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: propagate errors from skip_emulated_instruction() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: don't pretend to advance RIP in case wrmsr_interception() results in #GP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix x86_decode_insn() return when fetching insn bytes fails (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: use Intel speculation bugs and features as derived in generic x86 code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: always expose VIRT_SSBD to guests (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: fix reporting of AMD speculation bug CPUID leaf (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Call kvm_arch_vcpu_blocking early into the blocking sequence (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Reintroduce fast invalidate/zap for flushing memslot (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: work around leak of uninitialized stack contents (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: handle page fault in vmread (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Don't update RIP or do single-step on faulting emulation (Vitaly Kuznetsov) [1749495]
- [tools] selftests/kvm: make platform_info_test pass on AMD (Vitaly Kuznetsov) [1749495]
- [x86] revert "kvm: x86/mmu: Zap only the relevant pages when removing a memslot" (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: fix state save/load on processors without XSAVE (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: fix vmx_set_nested_state_test (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: provide common function to enable eVMCS (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: do not try running the VM in vmx_set_nested_state_test (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: svm: remove redundant assignment of var new_entry (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: Adding config fragments (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Update gitignore file for latest changes (Vitaly Kuznetsov) [1749495]
- [virt] kvm: remove unnecessary PageReserved check (Vitaly Kuznetsov) [1749495]
- [x86] kvm: remove useless calls to kvm_para_available (Vitaly Kuznetsov) [1749495]
- [x86] kvm: no need to check return value of debugfs_create functions (Vitaly Kuznetsov) [1749495]
- [s390] kvm: remove kvm_arch_has_vcpu_debugfs() (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix leak vCPU's VMCS value into other pCPU (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Check preempted_in_kernel for involuntary preemption (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Don't need to wakeup vCPU twice afer timer fire (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Boost queue head vCPU to mitigate lock waiter preemption (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: move Documentation/virtual to Documentation/virt (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add fixed counters to PMU filter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: dump VMCS on failed entry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/vpmu: refine kvm_pmu err msg when event creation failed (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Boost vCPUs that are delivering interrupts (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Remove superfluous define from vmx.c (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: Fix detection of AMD Errata 1096 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Inject timer interrupt via posted interrupt (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Don't call kvm_spurious_fault() from .fixup (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Replace vmx_vmenter()'s call to kvm_spurious_fault() with UD2 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Fix fastop function ELF metadata (Vitaly Kuznetsov) [1749495]
- [x86] paravirt: Fix callee-saved function ELF sizes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Make lapic timer unpinned (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/vpmu: reset pmc->counter to 0 for pmu fixed_counters (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Ignore segment base for VMX memory operand when segment not FS or GS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: ioapic and apic debug macros cleanup (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: some tsc debug cleanup (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: fix coccinelle warnings (Vitaly Kuznetsov) [1749495]
- [x86] kvm: avoid constant-conversion warning (Vitaly Kuznetsov) [1749495]
- [x86] kvm: avoid -Wsometimes-uninitized warning (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: virtual: Add toctree hooks (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: kvm: Convert cpuid.txt to .rst (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Unconditionally enable irqs in guest context (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: PMU Event Filter (Vitaly Kuznetsov) [1749495]
- [kernel] kvm: x86: Fix -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Properly check if "page" is valid in kvm_vcpu_unmap (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Retry tune per-vCPU timer_advance_ns if adaptive tuning goes insane (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: write down valid APIC registers (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: ARBPRI is a reserved register for x2APIC (Vitaly Kuznetsov) [1749495]
- [x86] kvm nvmx: Check Host Segment Registers and Descriptor Tables on vmentry of nested guests (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Stash L1's CR3 in vmcs01.GUEST_CR3 on nested entry w/o EPT (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: add tracepoints around __direct_map and FNAME(fetch) (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: change kvm_mmu_page_get_gfn BUG_ON to WARN_ON (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: remove now unneeded hugepage gfn adjustment (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: make FNAME(fetch) and __direct_map more similar (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Do not release the page inside mmu_set_spte() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: remove has_leaf_count from struct kvm_cpuid_param (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: rename do_cpuid_1_ent (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: set struct kvm_cpuid_entry2 flags in do_cpuid_1_ent (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: extract do_cpuid_7_mask and support multiple subleafs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: do_cpuid_ent works on a whole CPUID function (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: remove the trailing newline used in the fmt parameter of TP_printk (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: add nrips module parameter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: degrade WARN to pr_warn_ratelimited (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Pass through AMD_STIBP_ALWAYS_ON in GET_SUPPORTED_CPUID (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Remove unnecessary sync_roots from handle_invept (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: kvm: document CPUID bit for MSR_KVM_POLL_CONTROL (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: x86: Expose PV_SCHED_YIELD CPUID feature bit to guest (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Implement PV sched yield hypercall (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Yield to IPI target if necessary (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: list VMX MSRs in KVM_GET_MSR_INDEX_LIST (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: allow setting the VMFUNC controls MSR (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: include conditional controls in /dev/kvm KVM_GET_MSRS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix apic dangling pointer in vcpu (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: check CPUID before allowing read/write of IA32_XSS (Vitaly Kuznetsov) [1749495]
- [tools] tests: kvm: Check for a kernel warning (Vitaly Kuznetsov) [1749495]
- [tools] kvm: tests: Sort tests in the Makefile alphabetically (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: fix typo in documentation (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: shadow pin based execution controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Leave preemption timer running when it's disabled (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Drop hv_timer_armed from 'struct loaded_vmcs' (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Preset *DT exiting in vmcs02 when emulating UMIP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Preserve last USE_MSR_BITMAPS when preparing vmcs02 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Explicitly initialize controls shadow at VMCS allocation (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't reset VMCS controls shadow on VMCS switch (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Shadow VMCS controls on a per-VMCS basis (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Shadow VMCS secondary execution controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Shadow VMCS primary execution controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Shadow VMCS pin controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Add builder macros for shadowing controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Use adjusted pin controls for vmcs02 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Copy PDPTRs to/from vmcs12 only when necessary (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't update GUEST_BNDCFGS if it's clean in HV eVMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Update vmcs12 for MSR_IA32_DEBUGCTLMSR when it's written (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Update vmcs12 for SYSENTER MSRs when they're written (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Update vmcs12 for MSR_IA32_CR_PAT when it's written (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't speculatively write APIC-access page address (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't speculatively write virtual-APIC page address (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't dump VMCS if virtual APIC page can't be mapped (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't reread VMCS-agnostic state when switching VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't "put" vCPU or host state when switching VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: simplify vmx_prepare_switch_to_{guest, host} (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't rewrite GUEST_PML_INDEX during nested VM-Entry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Write ENCLS-exiting bitmap once per vmcs02 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Always sync GUEST_BNDCFGS when it comes from vmcs01 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Always signal #GP on WRMSR to MSR_IA32_CR_PAT with bad value (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Rename prepare_vmcs02_*_full to prepare_vmcs02_*_rare (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Sync rarely accessed guest fields only when needed (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Add helpers to identify shadowed VMCS fields (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Use descriptive names for VMCS sync functions and flags (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Lift sync_vmcs12() out of prepare_vmcs12() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Track vmcs12 offsets for shadowed VMCS fields (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Intercept VMWRITEs to GUEST_{CS, SS}_AR_BYTES (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Intercept VMWRITEs to read-only shadow VMCS fields (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Handle NMIs, #MCs and async #PFs in common irqs-disabled fn (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move kvm_{before, after}_interrupt() calls to vendor code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Store the host kernel's IDT base in a global variable (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Read cached VM-Exit reason to detect external interrupt (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: small cleanup in handle_exception (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Fix handling of #MC that occurs during VM-Entry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: move MSR_IA32_POWER_CTL handling to common code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: offset is ensure to be in range (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: use same convention to name kvm_lapic_{set, clear}_vector() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: check kvm_apic_sw_enabled() is enough (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: add host poll control msrs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: segment limit check: use access length (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: fix limit checking in get_vmx_mem_address() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add Intel CPUID.1F cpuid emulation support (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Use DR_TRAP_BITS instead of hard-coded 15 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: clean up conditions for asynchronous page fault handling (Vitaly Kuznetsov) [1749495]
- [documentation] docs: amd-memory-encryption.rst get rid of warnings (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Convert kvm_lock to a mutex (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: remove unneeded 'asm volatile ("")' from vmcs_write64 (Vitaly Kuznetsov) [1749495]
- [virt] kvm: irqchip: Use struct_size() in kzalloc() (Vitaly Kuznetsov) [1749495]
- [x86] kvm/vmx: drop bad asm() clobber from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: hide vcpu_setup in processor code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Emulate MSR_IA32_MISC_ENABLE MWAIT bit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Provide a capability to disable cstate msr read intercepts (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: documentation: Add disable pause exits to KVM_CAP_X86_DISABLE_EXITS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: refine kvm_get_arch_capabilities() (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Directly return result from kvm_arch_check_processor_compat() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Optimize timer latency further (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Delay trace_kvm_wait_lapic_expire tracepoint to after vmexit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Extract adaptive tune timer advancement logic (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nsvm: properly map nested VMCB (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix reserved bits related calculation errors caused by MKTME (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move kvm_set_mmio_spte_mask() from x86.c to mmu.c (Vitaly Kuznetsov) [1749495]
- [virt] kvm: fix compile on s390 part 2 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: fix return value for reserved EFER (Vitaly Kuznetsov) [1749495]
- [tools] kvm_stat: fix fields filter for child events (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: aarch64: compile with warnings on (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/pmu: do not mask the value that is written to fixed PMUs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/pmu: mask the result of rdpmc according to the width of the counters (Vitaly Kuznetsov) [1749495]
- [x86] kvm/pmu: Set AMD's virt PMU version to 1 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: do not spam dmesg with VMCS/VMCB dumps (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Check irqchip mode before assign irqfd (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Remove duplicated TEST_ASSERT in hyperv_cpuid.c (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Expose per-vCPU timer_advance_ns to userspace (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Fix lapic_timer_advance_ns parameter overflow (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Fix -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Fix using __this_cpu_read() in preemptible context (Vitaly Kuznetsov) [1749495]
- [virt] kvm: fix compilation on s390 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Include CPUID leaf 0x8000001e in kvm's supported CPUID (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Include multiple indices with CPUID leaf 0x8000001d (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Fix a condition in test_hv_cpuid() (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix spinlock taken warning during host resume (Vitaly Kuznetsov) [1749495]
- [virt] kvm: fix compilation on aarch64 (Vitaly Kuznetsov) [1749495]
- [x86] revert "kvm: nvmx: Expose RDPMC-exiting only when guest supports PMU" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix L1TF mitigation for shadow MMU (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Disable intercept for FS/GS base MSRs in vmcs02 when possible (Vitaly Kuznetsov) [1749495]
- [tools] tests: kvm: Add tests to .gitignore (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: Introduce KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2 (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix kvm_clear_dirty_log_protect off-by-(minus-)one (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix the bitmap range to copy during clear dirty (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: use direct accessors for RIP and RSP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Use accessors for GPRs outside of dedicated caching logic (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Omit caching logic for always-available GPRs (Vitaly Kuznetsov) [1749495]
- [x86] kvm, x86: Properly check whether a pfn is an MMIO or not (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use page_address_valid in a few more locations (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map for accessing the enlightened VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map for accessing the shadow VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nsvm: Use the new mapping API for mapping guest memory (Vitaly Kuznetsov) [1749495]
- [x86] kvm/x86: Use kvm_vcpu_map in emulator_cmpxchg_emulated (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map when mapping the posted interrupt descriptor table (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map when mapping the virtual APIC page (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map when mapping the L1 MSR bitmap (Vitaly Kuznetsov) [1749495]
- [x86] nvmx: handle_vmptrld: Use kvm_vcpu_map when copying VMCS12 from guest memory (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Introduce a new guest mapping API (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Handle PFNs outside of kernel reach when touching GPTEs (Vitaly Kuznetsov) [1749495]
- [x86] nvmx: Update the PML table without mapping and unmapping the page (Vitaly Kuznetsov) [1749495]
- [x86] nvmx: handle_vmon: Read 4 bytes from guest memory (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Implement HWCR support (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Include architectural defs header in capabilities.h (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: clean up some debug output (Vitaly Kuznetsov) [1749495]
- [virt] kvm_main: fix some comments (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Skip delta_tsc shift-and-divide if the dividend is zero (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Check for a pending timer intr prior to start_hv_timer() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Refactor ->set_hv_timer to use an explicit expired param (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Explicitly cancel the hv timer if it's pre-expired (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Busy wait for timer to expire when using hv_timer (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Nop emulation of MSR_IA32_POWER_CTL (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add support of clear Trace_ToPA_PMI status (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Inject PMI for KVM guest (Vitaly Kuznetsov) [1749495]
- [documentation] revert "kvm: doc: Document the life cycle of a VM and its resources" (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: kvm: fix dirty log ioctl arch lists (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Make steal_time visible (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Inject #GP if guest attempts to set unsupported EFER bits (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Skip EFER vs. guest CPUID checks for host-initiated writes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Return -EINVAL when signaling failure in VM-Entry helpers (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Return -EINVAL when signaling failure in pre-VM-Entry helpers (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Rename and split top-level consistency checks to match SDM (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Move guest non-reg state checks to VM-Exit path (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Check "load IA32_PAT" VM-entry control on vmentry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Check "load IA32_PAT" VM-exit control on vmentry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: optimize check for valid PAT value (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: clear VM_EXIT_SAVE_IA32_PAT (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: print more APICv fields in dump_vmcs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Raise #GP when guest vCPU do not support PMU (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: doc: Document the life cycle of a VM and its resources (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: skip populating logical dest map if apic is not sw enabled (Bandan Das) [1728503]
- [powerpc] kvm: ppc: book3s: Fix incorrect guest-to-user-translation error handling (David Gibson) [1749504]
- [powerpc] kvm: Fall through switch case explicitly (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Fix CR0 setting in TM emulation (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Invalidate ERAT when flushing guest TLB entries (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Only write DAWR[X] when handling h_set_dawr in real mode (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: xive: Fix spelling mistake "acessing" -> "accessing" (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Make sure to load LPID for radix VCPUs (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Flush TLB on secondary radix threads (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Move HPT guest TLB flushing to C code (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Handle virtual mode in XIVE VCPU push code (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: smb->smp comment fixup (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s: Allocate guest TCEs on demand too (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Avoid lockdep debugging in TCE realmode handlers (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Fix lockdep warning when entering the guest (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Implement real mode H_PAGE_INIT handler (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Implement virtual mode H_PAGE_INIT handler (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s: Protect memslots while validating user address (David Gibson) [1749504]
- [pci] PCI: hv: Use bytes 4 and 5 from instance ID as the PCI domain numbers (Mohammed Gamal) [1671288]
- [pci] PCI: hv: Detect and fix Hyper-V PCI domain number collision (Mohammed Gamal) [1671288]
- [fs] Revert "lockd: Show pid of lockd for remote locks" (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix an Oops in nfs4_do_setattr (Benjamin Coddington) [1732409]
- [fs] NFSv4: Check the return value of update_open_stateid() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix delegation state recovery (Benjamin Coddington) [1732409]
- [fs] pnfs/flexfiles: Fix PTR_ERR() dereferences in ff_layout_track_ds_error (Benjamin Coddington) [1732409]
- [fs] Revert "NFS: readdirplus optimization by cache mechanism" (memleak) (Benjamin Coddington) [1732409]
- [fs] svcrdma: Ignore source port when computing DRC hash (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Use the correct TCP timeout for flexfiles I/O (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Fix bug only first CB_NOTIFY_LOCK is handled (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Again fix a race where CB_NOTIFY_LOCK fails to wake a waiter (Benjamin Coddington) [1732409]
- [fs] SUNRPC fix regression in umount of a secure mount (Benjamin Coddington) [1732409]
- [fs] NFS4: Fix v4.0 client state corruption when mount (Benjamin Coddington) [1732409]
- [fs] NFSv4: When recovering state fails with EAGAIN, retry the same recovery (Benjamin Coddington) [1732409]
- [fs] pnfs: Fix a problem where we gratuitously start doing I/O through the MDS (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure the bvecs are reset when we re-encode the RPC request (Benjamin Coddington) [1732409]
- [fs] sunrpc/cache: remove the exporting of cache_seq_next (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a use after free when a server rejects the RPCSEC_GSS credential (Benjamin Coddington) [1732409]
- [fs] xprtrdma: Fix an frwr_map recovery nit (Benjamin Coddington) [1732409]
- [fs] NFSv4.1 fix incorrect return value in copy_file_range (Benjamin Coddington) [1732409]
- [fs] NFS: Fix handling of reply page vector (Benjamin Coddington) [1732409]
- [fs] NFS: Forbid setting AF_INET6 to "struct sockaddr_in"->sin_family. (Benjamin Coddington) [1732409]
- [fs] nfsd: Don't release the callback slot unless it was actually held (Benjamin Coddington) [1732409]
- [fs] nfsd/nfsd3_proc_readdir: fix buffer count and page pointers (Benjamin Coddington) [1732409]
- [fs] sunrpc: don't mark uninitialised items as VALID. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: fix uninitialized variable warning (Benjamin Coddington) [1732409]
- [fs] pNFS/flexfiles: Fix layoutstats handling during read failovers (Benjamin Coddington) [1732409]
- [fs] NFS: Fix a typo in nfs_init_timeout_values() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't let RPC_SOFTCONN tasks time out if the transport is connected (Benjamin Coddington) [1732409]
- [fs] NFS: fix mount/umount race in nlmclnt. (Benjamin Coddington) [1732409]
- [fs] NFS: Fix nfs4_lock_state refcounting in nfs4_alloc_{lock, unlock}data() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove redundant check for the reply length in call_decode() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Handle the SYSTEM_ERR rpc error (Benjamin Coddington) [1732409]
- [fs] SUNRPC: rpc_decode_header() must always return a non-zero value on error (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use the ENOTCONN error on socket disconnect (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix the minimal size for reply buffer allocation (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a client regression when handling oversized replies (Benjamin Coddington) [1732409]
- [fs] pNFS: Fix a typo in pnfs_update_layout (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Take the transport send lock before binding+connecting (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Micro-optimise when the task is known not to be sleeping (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Check whether the task was transmitted before rebind/reconnect (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove redundant calls to RPC_IS_QUEUED() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up (Benjamin Coddington) [1732409]
- [fs] nfsd: allow nfsv3 readdir request to be larger. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Respect RPC call timeouts when retrying transmission (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up RPC back channel transmission (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Prevent thundering herd when the socket is not connected (Benjamin Coddington) [1732409]
- [fs] nfsd: fix wrong check in write_v4_end_grace() (Benjamin Coddington) [1732409]
- [fs] nfsd: fix memory corruption caused by readdir (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow dynamic allocation of back channel slots (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Bump the default callback session slot count to 16 (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert remaining GFP_NOIO, and GFP_NOWAIT sites in sunrpc (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Clean up mirror DS initialisation (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Remove dead code in ff_layout_mirror_valid() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfile: Simplify nfs4_ff_layout_select_ds_stateid() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfile: Simplify nfs4_ff_layout_ds_version() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Simplify ff_layout_get_ds_cred() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Simplify nfs4_ff_find_or_create_ds_client() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Simplify nfs4_ff_layout_select_ds_fh() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Speed up read failover when DSes are down (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Don't invalidate DS deviceids for being unresponsive (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Remove bogus checks for invalid deviceids (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Avoid unnecessary layout invalidations (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: refactor calls to fs4_ff_layout_prepare_ds() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Handle early exit in layoutget by returning an error (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Send LAYOUTERROR when failing over mirrored reads (Benjamin Coddington) [1732409]
- [fs] NFSv4.2: Add client support for the generic 'layouterror' RPC call (Benjamin Coddington) [1732409]
- [fs] NFSv4/flexfiles: Abort I/O early if the layout segment was invalidated (Benjamin Coddington) [1732409]
- [fs] NFSv4/pnfs: Fix barriers in nfs4_mark_deviceid_unavailable() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Fix up sparse RCU annotations (Benjamin Coddington) [1732409]
- [fs] NFSv4/flexfiles: Fix invalid deref in FF_LAYOUT_DEVID_NODE() (Benjamin Coddington) [1732409]
- [fs] NFS: Add missing encode / decode sequence_maxsz to v4.2 operations (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Don't process the sequence op more than once. (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Reinitialise sequence results before retransmitting a request (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix an Oops in udp_poll() (Benjamin Coddington) [1732409]
- [fs] NFS/pnfs: Bulk destroy of layouts needs to be safe w.r.t. umount (Benjamin Coddington) [1732409]
- [fs] NFS: Fix a soft lockup in the delegation recovery code (Benjamin Coddington) [1732409]
- [fs] nfsd: fix performance-limiting session calculation (Benjamin Coddington) [1732409]
- [fs] svcrpc: fix UDP on servers with lots of threads (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove the redundant 'zerocopy' argument to xs_sendpages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Further cleanups of xs_sendpages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert socket page send code to use iov_iter() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert xs_send_kvec() to use iov_iter_kvec() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Initiate a connection close on an ESHUTDOWN error in stream receive (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't suppress socket errors when a message read completes (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Handle zero length fragments correctly (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't reset the stream record info when the receive worker is running (Benjamin Coddington) [1732409]
- [fs] nfs: fix xfstest generic/099 failed on nfsv3 (Benjamin Coddington) [1732409]
- [fs] NFS: Fix typo in comments of nfs_readdir_alloc_pages() (Benjamin Coddington) [1732409]
- [fs] NFS: Remove redundant semicolon (Benjamin Coddington) [1732409]
- [fs] NFS: readdirplus optimization by cache mechanism (Benjamin Coddington) [1732409]
- [fs] fs/nfs: Fix nfs_parse_devname to not modify it's argument (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove pointless test in unx_match() (Benjamin Coddington) [1732409]
- [fs] NFS: drop useless LIST_HEAD (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure rq_bytes_sent is reset before request transmission (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use poll() to fix up the socket requeue races (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Set memalloc_nofs_save() on all rpciod/xprtiod jobs (Benjamin Coddington) [1732409]
- [fs] NFS: Fix sparse annotations for nfs_set_open_stateid_locked() (Benjamin Coddington) [1732409]
- [fs] NFS: Fix up documentation warnings (Benjamin Coddington) [1732409]
- [fs] NFS: ENOMEM should also be a fatal error. (Benjamin Coddington) [1732409]
- [fs] NFS: EINTR is also a fatal error. (Benjamin Coddington) [1732409]
- [fs] NFS: Ensure NFS writeback allocations don't recurse back into NFS. (Benjamin Coddington) [1732409]
- [fs] NFS: Pass error information to the pgio error cleanup routine (Benjamin Coddington) [1732409]
- [fs] NFS: Clean up list moves of struct nfs_page (Benjamin Coddington) [1732409]
- [fs] NFS: Don't recoalesce on error in nfs_pageio_complete_mirror() (Benjamin Coddington) [1732409]
- [fs] NFS: Fix an I/O request leakage in nfs_do_recoalesce (Benjamin Coddington) [1732409]
- [fs] NFS: Fix I/O request leakages (Benjamin Coddington) [1732409]
- [fs] Revert "nfsd4: return default lease period" (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use au_rslack when computing reply buffer size (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add rpc_auth::au_ralign field (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Make AUTH_SYS and AUTH_NULL set au_verfsize (Benjamin Coddington) [1732409]
- [fs] NFS: Account for XDR pad of buf->pages (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Introduce rpc_prepare_reply_pages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove xdr_buf_trim() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Introduce trace points in rpc_auth_gss.ko (Benjamin Coddington) [1732409]
- [fs] xprtrdma: Squelch a sparse warning (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use struct xdr_stream when decoding RPC Reply header (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up rpc_verify_header() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use struct xdr_stream when constructing RPC Call header (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add build option to disable support for insecure enctypes (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove rpc_xprt::tsh_size (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove some dprintk() call sites from auth functions (Benjamin Coddington) [1732409]
- [fs] NFS: Add trace events to report non-zero NFS status codes (Benjamin Coddington) [1732409]
- [fs] NFS: Remove print_overflow_msg() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add trace event that reports reply page vector alignment (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add XDR overflow trace event (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add xdr_stream::rqst field (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Display symbolic flag names in RPC trace events (Benjamin Coddington) [1732409]
- [fs] rpc: properly check debugfs dentry before using it (Benjamin Coddington) [1732409]
- [fs] svcrpc: fix unlikely races preventing queueing of sockets (Benjamin Coddington) [1732409]
- [fs] svcrpc: svc_xprt_has_something_to_do seems a little long (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't allow compiler optimisation of svc_xprt_release_slot() (Benjamin Coddington) [1732409]
- [fs] nfsd: fix an IS_ERR() vs NULL check (Benjamin Coddington) [1732409]
- [fs] nfsd: Fix error return values for nfsd4_clone_file_range() (Benjamin Coddington) [1732409]
- [fs] nfs: Fix NULL pointer dereference of dev_name (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Address Kerberos performance/behavior regression (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure we respect the RPCSEC_GSS sequence number limit (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure rq_bytes_sent is reset before request transmission (Benjamin Coddington) [1732409]
- [fs] NFSv4.2 fix unnecessary retry in nfs4_copy_file_range (Benjamin Coddington) [1732409]
- [fs] sunrpc: kernel BUG at kernel/cred.c:825! (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix TCP receive code on archs with flush_dcache_page() (Benjamin Coddington) [1732409]
- [fs] sunrpc: convert to DEFINE_SHOW_ATTRIBUTE (Benjamin Coddington) [1732409]
- [fs] sunrpc: Add xprt after nfs4_test_session_trunk() (Benjamin Coddington) [1732409]
- [fs] sunrpc: convert unnecessary GFP_ATOMIC to GFP_NOFS (Benjamin Coddington) [1732409]
- [fs] sunrpc: handle ENOMEM in rpcb_getport_async (Benjamin Coddington) [1732409]
- [fs] NFS: remove unnecessary test for IS_ERR(cred) (Benjamin Coddington) [1732409]
- [fs] NFSv4.2 fix async copy reboot recovery (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix some kernel doc complaints (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify defining common RPC trace events (Benjamin Coddington) [1732409]
- [fs] NFS: Fix NFSv4 symbolic trace point output (Benjamin Coddington) [1732409]
- [fs] nfs: fixed broken compilation in nfs_callback_up_net() (Benjamin Coddington) [1732409]
- [fs] nfs: minor typo in nfs4_callback_up_net() (Benjamin Coddington) [1732409]
- [fs] sunrpc: fix debug message in svc_create_xprt() (Benjamin Coddington) [1732409]
- [fs] sunrpc: remove svc_rdma_bc_class (Benjamin Coddington) [1732409]
- [fs] sunrpc: remove unused bc_up operation from rpc_xprt_ops (Benjamin Coddington) [1732409]
- [fs] sunrpc: use SVC_NET() in svcauth_gss_* functions (Benjamin Coddington) [1732409]
- [fs] nfsd: drop useless LIST_HEAD (Benjamin Coddington) [1732409]
- [fs] SUNRPC discard cr_uid from struct rpc_cred. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: simplify auth_unix. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove crbind rpc_cred operation (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove generic cred code. (Benjamin Coddington) [1732409]
- [fs] NFS/NFSD/SUNRPC: replace generic creds with 'struct cred'. (Benjamin Coddington) [1732409]
- [fs] NFS: struct nfs_open_dir_context: convert rpc_cred pointer to cred. (Benjamin Coddington) [1732409]
- [fs] NFS: change access cache to use 'struct cred'. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove RPCAUTH_AUTH_NO_CRKEY_TIMEOUT (Benjamin Coddington) [1732409]
- [fs] NFS: move credential expiry tracking out of SUNRPC into NFS. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: add side channel to use non-generic cred for rpc call. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: introduce RPC_TASK_NULLCREDS to request auth_none (Benjamin Coddington) [1732409]
- [fs] NFS/SUNRPC: don't lookup machine credential until rpcauth_bindcred(). (Benjamin Coddington) [1732409]
- [fs] SUNRPC: discard RPC_DO_ROOTOVERRIDE() (Benjamin Coddington) [1732409]
- [fs] NFSv4: don't require lock for get_renew_cred or get_machine_cred (Benjamin Coddington) [1732409]
- [fs] NFSv4: add cl_root_cred for use when machine cred is not available. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove machine_cred field from struct auth_cred (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove uid and gid from struct auth_cred (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove groupinfo from struct auth_cred. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: add 'struct cred *' to auth_cred and rpc_cred (Benjamin Coddington) [1732409]
- [fs] cred: allow get_cred() and put_cred() to be given NULL. (Benjamin Coddington) [1732409]
- [fs] cred: export get_task_cred(). (Benjamin Coddington) [1732409]
- [fs] cred: add get_cred_rcu() (Benjamin Coddington) [1732409]
- [fs] cred: add cred_fscmp() for comparing creds. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: allow /proc entries without CONFIG_SUNRPC_DEBUG (Benjamin Coddington) [1732409]
- [fs] nfs: fix comment to nfs_generic_pg_test which does the opposite (Benjamin Coddington) [1732409]
- [fs] NFSv4: cleanup remove unused nfs4_xdev_fs_type (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove xprt_connect_status() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a race with XPRT_CONNECTING (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix disconnection races (Benjamin Coddington) [1732409]
- [fs] Revert "[net] Revert "sunrpc: Ensure we always close the socket after a connection shuts down"" (Benjamin Coddington) [1732409]
- [fs] lockd: Show pid of lockd for remote locks (Benjamin Coddington) [1732409]
- [fs] NFSD remove OP_CACHEME from 4.2 op_flags (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't force a redundant disconnection in xs_read_stream() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up socket polling (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use the discard iterator rather than MSG_TRUNC (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Treat EFAULT as a truncated message in xs_read_stream_request() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up handling of the XDRBUF_SPARSE_PAGES flag (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix RPC receive hangs (Benjamin Coddington) [1732409]
- [fs] nfsd: Return EPERM, not EACCES, in some SETATTR cases (Benjamin Coddington) [1732409]
- [fs] sunrpc: fix cache_head leak due to queued request (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a potential race in xprt_connect() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a memory leak in call_encode() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix leak of krb5p encode pages (Benjamin Coddington) [1732409]
- [fs] SUNRPC: call_connect_status() must handle tasks that got transmitted (Benjamin Coddington) [1732409]
- [fs] nfs: don't dirty kernel pages read by direct-io (Benjamin Coddington) [1732409]
- [fs] NFS: use locks_copy_lock() to copy locks. (Benjamin Coddington) [1732409]
- [fs] nfsd: clean up indentation, increase indentation in switch statement (Benjamin Coddington) [1732409]
- [fs] nfsd: fix a warning in __cld_pipe_upcall() (Benjamin Coddington) [1732409]
- [fs] lockd: fix decoding of TEST results (Benjamin Coddington) [1732409]
- [fs] nfsd4: fix crash on writing v4_end_grace before nfsd startup (Benjamin Coddington) [1732409]
- [fs] nfsd4: skip unused assignment (Benjamin Coddington) [1732409]
- [fs] nfsd4: forbid all renames during grace period (Benjamin Coddington) [1732409]
- [fs] nfsd4: remove unused nfs4_check_olstateid parameter (Benjamin Coddington) [1732409]
- [fs] nfsd4: zero-length WRITE should succeed (Benjamin Coddington) [1732409]
- [fs] NFSv4.2 copy do not allocate memory under the lock (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a NFSv4 state manager deadlock (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix an Oops during delegation callbacks (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a bogus get/put in generic_key_to_expire() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a Oops when destroying the RPCSEC_GSS credential cache (Benjamin Coddington) [1732409]
- [fs] NFSv4: Ensure that the state manager exits the loop on SIGKILL (Benjamin Coddington) [1732409]
- [fs] NFSv4: Don't exit the state manager without clearing NFS4CLNT_MANAGER_RUNNING (Benjamin Coddington) [1732409]
- [fs] SUNRPC: drop pointless static qualifier in xdr_get_next_encode_buffer() (Benjamin Coddington) [1732409]
- [fs] nfsd: COPY and CLONE operations require the saved filehandle to be set (Benjamin Coddington) [1732409]
- [fs] sunrpc: correct the computation for page_ptr when truncating (Benjamin Coddington) [1732409]
- [fs] NFS: fix spelling mistake, EACCESS -> EACCES (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use atomic(64)_t for seq_send(64) (Benjamin Coddington) [1732409]
- [fs] nfsd: Fix an Oops in free_session() (Benjamin Coddington) [1732409]
- [fs] nfsd: correctly decrement odstate refcount in error path (Benjamin Coddington) [1732409]
- [fs] nfsd: fix fall-through annotations (Benjamin Coddington) [1732409]
- [fs] knfsd: Improve lookup performance in the duplicate reply cache using an rbtree (Benjamin Coddington) [1732409]
- [fs] knfsd: Further simplify the cache lookup (Benjamin Coddington) [1732409]
- [fs] knfsd: Simplify NFS duplicate replay cache (Benjamin Coddington) [1732409]
- [fs] knfsd: Remove dead code from nfsd_cache_lookup (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify TCP receive code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Replace the cache_detail->hash_lock with a regular spinlock (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove non-RCU protected lookup (Benjamin Coddington) [1732409]
- [fs] NFS: Fix up a typo in nfs_dns_ent_put (Benjamin Coddington) [1732409]
- [fs] NFS: Lockless DNS lookups (Benjamin Coddington) [1732409]
- [fs] knfsd: Lockless lookup of NFSv4 identities. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Lockless server RPCSEC_GSS context lookup (Benjamin Coddington) [1732409]
- [fs] knfsd: Allow lockless lookups of the exports (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Make server side AUTH_UNIX use lockless lookups (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow cache lookups to use RCU protection rather than the r/w spinlock (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert the auth cred cache to use refcount_t (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert auth creds to use refcount_t (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify lookup code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up the AUTH cache code (Benjamin Coddington) [1732409]
- [fs] NFS: change sign of nfs_fh length (Benjamin Coddington) [1732409]
- [fs] sunrpc: safely reallow resvport min/max inversion (Benjamin Coddington) [1732409]
- [fs] nfs: remove redundant call to nfs_context_set_write_error() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a compile warning for cmpxchg64() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: use cmpxchg64() in gss_seq_send64_fetch_and_inc() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor sunrpc_cache_lookup (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add lockless lookup of the server's auth domain (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove the server 'authtab_lock' and just use RCU (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix lookup revalidate of regular files (Benjamin Coddington) [1732409]
- [fs] NFS: Refactor nfs_lookup_revalidate() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Replace krb5_seq_lock with a lockless scheme (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Lockless lookup of RPCSEC_GSS mechanisms (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove rpc_authflavor_lock in favour of RCU locking (Benjamin Coddington) [1732409]
- [fs] NFS: Remove private spinlock in struct nfs_pgio_header (Benjamin Coddington) [1732409]
- [fs] NFSv3: Improve NFSv3 performance when server returns no post-op attributes (Benjamin Coddington) [1732409]
- [fs] NFSv4: Split out NFS v4.2 copy completion functions (Benjamin Coddington) [1732409]
- [fs] NFS: Reduce indentation of nfs4_recovery_handle_error() (Benjamin Coddington) [1732409]
- [fs] NFS: Reduce indentation of the switch statement in nfs4_reclaim_open_state() (Benjamin Coddington) [1732409]
- [fs] NFS: Split out the body of nfs4_reclaim_open_state() (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Fix the r/wsize checking (Benjamin Coddington) [1732409]
- [fs] NFSv4: Convert struct nfs4_state to use refcount_t (Benjamin Coddington) [1732409]
- [fs] NFSv4: Convert open state lookup to use RCU (Benjamin Coddington) [1732409]
- [fs] NFS: Convert lookups of the open context to RCU (Benjamin Coddington) [1732409]
- [fs] NFS: Simplify internal check for whether file is open for write (Benjamin Coddington) [1732409]
- [fs] NFS: Convert lookups of the lock context to RCU (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't allocate more pages than we need to fit a layoutget response (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't zero out the array in nfs4_alloc_pages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Unexport xdr_partial_copy_from_skb() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up xs_udp_data_receive() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow AF_LOCAL sockets to use the generic stream receive (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up - rename xs_tcp_data_receive() to xs_stream_data_receive() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify TCP receive code by switching to using iterators (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a bvec array to struct xdr_buf for use with iovec_iter() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a label for RPC calls that require allocation on receive (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert the xprt->sending queue back to an ordinary wait queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix priority queue fairness (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert xprt receive queue to use an rbtree (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't take transport->lock unnecessarily when taking XPRT_LOCK (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Cleanup: remove the unused 'task' argument from the request_send() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up transport write space handling (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Turn off throttling of RPC slots for TCP sockets (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow soft RPC calls to time out when waiting for the XPRT_LOCK (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow calls to xprt_transmit() to drain the entire transmit queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Enqueue swapper tagged RPCs at the head of the transmit queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Support for congestion control when queuing is enabled (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Improve latency for interactive tasks (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Move RPC retransmission stat counter to xprt_transmit() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify xprt_prepare_transmit() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't reset the request 'bytes_sent' counter when releasing XPRT_LOCK (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Treat the task and request as separate in the xprt_ops->send_request() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up the back channel transmit (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor RPC call encoding (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a transmission queue for RPC requests (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Distinguish between the slot allocation list and receive queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Minor cleanup for call_transmit() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor xprt_transmit() to remove wait for reply code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor xprt_transmit() to remove the reply queue code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Rename xprt->recv_lock to xprt->queue_lock (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't wake queued RPC calls multiple times in xprt_transmit (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Test whether the task is queued before grabbing the queue spinlocks (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a helper to wake up a sleeping rpc_task and set its status (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor the transport request pinning (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify dealing with aborted partially transmitted messages (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add socket transmit queue offset tracking (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Move reset of TCP state variables into the reconnect code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Rename TCP receive-specific state variables (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Avoid holding locks across the XDR encoding of the RPC message (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify identification of when the message send/receive is complete (Benjamin Coddington) [1732409]
- [fs] SUNRPC: The transmitted message must lie in the RPCSEC window of validity (Benjamin Coddington) [1732409]
- [fs] SUNRPC: If there is no reply expected, bail early from call_decode (Benjamin Coddington) [1732409]
- [fs] nfsd: remove set but not used variable 'dirp' (Benjamin Coddington) [1732409]
- [fs] NFSD introduce async copy feature (Benjamin Coddington) [1732409]
- [fs] NFSD OFFLOAD_CANCEL xdr (Benjamin Coddington) [1732409]
- [fs] NFSD OFFLOAD_STATUS xdr (Benjamin Coddington) [1732409]
- [fs] NFSD CB_OFFLOAD xdr (Benjamin Coddington) [1732409]
- [fs] NFS: Don't open code clearing of delegation state (Benjamin Coddington) [1732409]
- [fs] NFSv4.1 fix infinite loop on I/O. (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a tracepoint Oops in initiate_file_draining() (Benjamin Coddington) [1732409]
- [fs] pNFS: Ensure we return the error if someone kills a waiting layoutget (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a tracepoint Oops in initiate_file_draining() (Benjamin Coddington) [1732409]
- [fs] sunrpc: Add comment defining gssd upcall API keywords (Benjamin Coddington) [1732409]
- [fs] nfsd: Remove callback_cred (Benjamin Coddington) [1732409]
- [fs] nfsd: Use correct credential for NFSv4.0 callback with GSS (Benjamin Coddington) [1732409]
- [fs] sunrpc: Extract target name into svc_cred (Benjamin Coddington) [1732409]
- [fs] sunrpc: Enable the kernel to specify the hostname part of service principals (Benjamin Coddington) [1732409]
- [fs] pNFS: Remove unwanted optimisation of layoutget (Benjamin Coddington) [1732409]
- [fs] pNFS/flexfiles: ff_layout_pg_init_read should exit on error (Benjamin Coddington) [1732409]
- [fs] pNFS: Treat RECALLCONFLICT like DELAY... (Benjamin Coddington) [1732409]
- [fs] pNFS: When updating the stateid in layoutreturn, also update the recall range (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a sleep in atomic context in nfs4_callback_sequence() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix locking in pnfs_generic_recover_commit_reqs (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a typo in nfs4_init_channel_attrs() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Don't busy wait if NFSv4 session draining is interrupted (Benjamin Coddington) [1732409]
- [fs] NFS recover from destination server reboot for copies (Benjamin Coddington) [1732409]
- [fs] nfsd: use true and false for boolean values (Benjamin Coddington) [1732409]
- [fs] nfsd: constify write_op[] (Benjamin Coddington) [1732409]
- [fs] fs/nfsd: Delete invalid assignment statements in nfsd4_decode_exchange_id (Benjamin Coddington) [1732409]
- [fs] NFSD: Handle full-length symlinks (Benjamin Coddington) [1732409]
- [fs] NFSD: Refactor the generic write vector fill helper (Benjamin Coddington) [1732409]
- [fs] nfsd: Mark expected switch fall-through (Benjamin Coddington) [1732409]
- [fs] nfsd: fix leaked file lock with nfs exported overlayfs (Benjamin Coddington) [1732409]
- [fs] NFS add a simple sync nfs4_proc_commit after async COPY (Benjamin Coddington) [1732409]
- [fs] NFS handle COPY ERR_OFFLOAD_NO_REQS (Benjamin Coddington) [1732409]
- [fs] NFS send OFFLOAD_CANCEL when COPY killed (Benjamin Coddington) [1732409]
- [fs] NFS export nfs4_async_handle_error (Benjamin Coddington) [1732409]
- [fs] NFS handle COPY reply CB_OFFLOAD call race (Benjamin Coddington) [1732409]
- [fs] NFS add support for asynchronous COPY (Benjamin Coddington) [1732409]
- [fs] NFS COPY xdr handle async reply (Benjamin Coddington) [1732409]
- [fs] NFS OFFLOAD_CANCEL xdr (Benjamin Coddington) [1732409]
- [fs] NFS CB_OFFLOAD xdr (Benjamin Coddington) [1732409]
- [fs] NFS: Use an appropriate work queue for direct-write completion (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix error handling in nfs4_sp4_select_mode() (Benjamin Coddington) [1732409]
- [fs] pnfs: Use true and false for boolean values (Benjamin Coddington) [1732409]
- [fs] pnfs: pnfs_find_lseg() should not check NFS_LSEG_LAYOUTRETURN (Benjamin Coddington) [1732409]
- [fs] NFS: Mark expected switch fall-throughs (Benjamin Coddington) [1732409]
- [fs] NFSv4: Mark the inode change attribute up to date in update_changeattr() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Detect nlink changes on cross-directory renames too (Benjamin Coddington) [1732409]
- [fs] NFSv4: bump/drop the nlink count on the parent dir when we mkdir/rmdir (Benjamin Coddington) [1732409]
- [fs] pnfs: Fix handling of NFS4ERR_OLD_STATEID replies to layoutreturn (Benjamin Coddington) [1732409]
- [fs] sunrpc: whitespace fixes (Benjamin Coddington) [1732409]
- [fs] NFSv4 client live hangs after live data migration recovery (Benjamin Coddington) [1732409]
- [fs] NFSv4.0 fix client reference leak in callback (Benjamin Coddington) [1732409]
- [fs] sunrpc: kstrtoul() can also return -ERANGE (Benjamin Coddington) [1732409]
- [fs] NFS: silence a harmless uninitialized variable warning (Benjamin Coddington) [1732409]
- [fs] net/sunrpc: Make rpc_auth_create_args a const (Benjamin Coddington) [1732409]
- [fs] pnfs/blocklayout: off by one in bl_map_stripe() (Benjamin Coddington) [1732409]
- [fs] nfs: Referrals not inheriting proto setting from parent (Benjamin Coddington) [1732409]
- [fs] nfs: initiate returning delegation when reclaiming one that's been recalled (Benjamin Coddington) [1732409]
- [fs] fs: nfs: Adding new return type vm_fault_t (Benjamin Coddington) [1732409]
- [fs] nfs: add error check in nfs_idmap_prepare_message() (Benjamin Coddington) [1732409]
- [fs] NFS: More excessive attribute revalidation in nfs_execute_ok() (Benjamin Coddington) [1732409]
- [fs] NFS: Fix excessive attribute revalidation in nfs_execute_ok() (Benjamin Coddington) [1732409]
- [fs] NFS: Ensure we immediately start writeback on rescheduled writes (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Fix a potential layoutget/layoutrecall deadlock (Benjamin Coddington) [1732409]
- [fs] pNFS: Parse the results of layoutget on open even if permissions checks fail (Benjamin Coddington) [1732409]
- [fs] NFS: Allow optimisation of lseek(fd, SEEK_CUR, 0) on directories (Benjamin Coddington) [1732409]
- [fs] pNFS: Wait for stale layoutget calls to complete in pnfs_update_layout() (Benjamin Coddington) [1732409]
- [fs] pNFS/flexfiles: Ensure we always return a layout if it has layoutstats (Benjamin Coddington) [1732409]
- [fs] pNFS: Ignore non-recalled layouts in pnfs_layout_need_return() (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't update the stateid when replying NFS4ERR_DELAY to a layout recall (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't discard layout segments that are marked for return (Benjamin Coddington) [1732409]
- [fs] nfsd: don't advertise a SCSI layout for an unsupported request_queue (Benjamin Coddington) [1732409]
- [fs] nfsd: fix corrupted reply to badly ordered compound (Benjamin Coddington) [1732409]
- [fs] nfsd: clarify check_op_ordering (Benjamin Coddington) [1732409]
- [fs] nfsd: update obselete comment referencing the BKL (Benjamin Coddington) [1732409]
- [fs] nfsd4: cleanup sessionid in nfsd4_destroy_session (Benjamin Coddington) [1732409]
- [fs] nfsd4: less confusing nfsd4_compound_in_session (Benjamin Coddington) [1732409]
- [fs] nfsd4: support change_attr_type attribute (Benjamin Coddington) [1732409]
- [fs] nfsd: fix NFSv4 time_delta attribute (Benjamin Coddington) [1732409]
- [fs] nfsd4: return default lease period (Benjamin Coddington) [1732409]
- [fs] nfsd4: extend reclaim period for reclaiming clients (Benjamin Coddington) [1732409]
- [netdrv] i40e: Do not check VF state in i40e_ndo_get_vf_config (Stefan Assmann) [1752498]
- [netdrv] i40e: Add support for X710 device (Stefan Assmann) [1752891]
- [mm] mm/oom_kill.c: add task UID to info message on an oom kill (Joel Savitz) [1693039]
- [pci] ACPICA: Increase total number of possible Owner IDs (Al Stone) [1713050]
- [powerpc] powerpc/pseries: correctly track irq state in default idle (Steve Best) [1751971]
- [powerpc] powerpc/imc: Dont create debugfs files for cpu-less nodes (Steve Best) [1726031]
- [fs] userfaultfd_release: always remove uffd flags and clear vm_userfaultfd_ctx (Alex Gladkov) [1749763]
- [infiniband] RDMA/bnxt_re: Fix stack-out-of-bounds in bnxt_qplib_rcfw_send_message (Selvin Xavier) [1643312]
- [drm] drm/bochs: Fix connector leak during driver unload (Sam Bobroff) [1463490]
- [tools] selftests: Remove forced unbuffering for test running (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Add test plan API to kselftest.h and adjust callers (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Remove KSFT_TAP_LEVEL (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Move test output to diagnostic lines (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Distinguish between missing and non-executable (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Add plan line and fix result line syntax (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Extract logic for multiple test runs (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Use runner.sh for emit targets (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Extract single-test shell logic from lib.mk (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] x86/selftests/pkeys: Fork() to check for state being preserved (Vladis Dronov) [1738880]
- [x86] x86/pkeys: Properly copy pkey state at fork() (Vladis Dronov) [1738880]
- [netdrv] cxgb4: fix a memory leak bug (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Prefer pcie_capability_read_word() (Jonathan Toppins) [1725776]
- [netdrv] allocate_flower_entry: should check for null deref (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: reduce kernel stack usage in cudbg_collect_mem_region() (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Add MPS refcounting for alloc/free mac filters (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Add MPS TCAM refcounting for cxgb4 change mac (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Add MPS TCAM refcounting for raw mac filters (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Re-work the logic for mps refcounting (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/libcxgb/cxgb4i/cxgbit: enable eDRAM page pods for iSCSI (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Set initial IRQ affinity hints (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Make t4_get_tp_e2c_map static (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Revert "cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on page size" (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: offload VLAN flows regardless of VLAN ethtype (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: use firmware API for validating filter spec (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Enable hash filter with offload (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Fix error path in cxgb4_init_module (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Delete all hash and TCAM filters before resource cleanup (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/cxgb4vf_main: Mark expected switch fall-through (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/cxgb4vf: Display advertised FEC in ethtool (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Update 1.23.3.0 as the latest firmware supported. (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Update 1.22.9.0 as the latest firmware supported. (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/l2t: Use struct_size() in kvzalloc() (Jonathan Toppins) [1725776]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Jonathan Toppins) [1725776]
- [netdrv] crypto/chelsio/chtls: macro correction in tx path (Jonathan Toppins) [1725776]

* Tue Oct 15 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.7.el8]
- [kernel] rcu: Add sparse check to rcu_assign_pointer() (Waiman Long) [1737054]
- [kernel] rcu: Fix obsolete DYNTICK_IRQ_NONIDLE comment (Waiman Long) [1737054]
- [kernel] rcu: Repair rcu_nmi_exit() docbook header (Waiman Long) [1737054]
- [kernel] rcu: Remove preemption disabling from expedited CPU selection (Waiman Long) [1737054]
- [kernel] rcu: Rename rcu_process_callbacks() to rcu_core() for Tree RCU (Waiman Long) [1737054]
- [kernel] rcu: Rename rcu_check_callbacks() to rcu_sched_clock_irq() (Waiman Long) [1737054]
- [kernel] rcu: Docbook for rcu_head_init() and rcu_head_after_call_rcu() (Waiman Long) [1737054]
- [documentation] doc: Fix outdated links (Waiman Long) [1737054]
- [documentation] doc: CPU-hotplug notifiers cannot invoke synchronize_srcu() or srcu_barrier() (Waiman Long) [1737054]
- [documentation] doc: Now jiffies_till_sched_qs solicits help from cond_resched() (Waiman Long) [1737054]
- [kernel] rcuperf: Stop abusing IS_ENABLED() (Waiman Long) [1737054]
- [kernel] rcutorture: Add grace period after CPU offline (Waiman Long) [1737054]
- [kernel] torture: Explain and simplify odd "for" loop in mkinitrd.sh (Waiman Long) [1737054]
- [kernel] rcutorture: Record grace periods in forward-progress histogram (Waiman Long) [1737054]
- [kernel] rcu: Prevent needless ->gp_seq_needed update in __note_gp_changes() (Waiman Long) [1737054]
- [kernel] rcu: Do RCU GP kthread self-wakeup from softirq and interrupt (Waiman Long) [1737054]
- [kernel] rcu: Add sysrq rcu_node-dump capability (Waiman Long) [1737054]
- [kernel] rcu: Protect rcu_check_gp_kthread_starvation() access to ->gp_flags (Waiman Long) [1737054]
- [kernel] rcu: Improve diagnostics for failed RCU grace-period start (Waiman Long) [1737054]
- [kernel] rcu: Update NOCB comments (Waiman Long) [1737054]
- [kernel] rcu: Remove unused rcu_cpu_kthread_cpu per-CPU variable (Waiman Long) [1737054]
- [kernel] rcu: Move rcu_cpu_has_work to rcu_data structure (Waiman Long) [1737054]
- [kernel] rcu: Remove unused rcu_cpu_kthread_loops per-CPU variable (Waiman Long) [1737054]
- [kernel] rcu: Move rcu_cpu_kthread_status to rcu_data structure (Waiman Long) [1737054]
- [kernel] rcu: Move rcu_cpu_kthread_task to rcu_data structure (Waiman Long) [1737054]
- [kernel] rcu: Accommodate zero jiffies_till_first_fqs and kthread kicking (Waiman Long) [1737054]
- [kernel] rcu: Remove wrapper definitions for obsolete RCU update functions (Waiman Long) [1737054]
- [kernel] rcu: Discard separate per-CPU callback counts (Waiman Long) [1737054]
- [kernel] rcu: Inline _synchronize_rcu_expedited() into synchronize_rcu_expedited() (Waiman Long) [1737054]
- [kernel] rcu: Consolidate PREEMPT and !PREEMPT synchronize_rcu() (Waiman Long) [1737054]
- [kernel] rcu: Consolidate PREEMPT and !PREEMPT synchronize_rcu_expedited() (Waiman Long) [1737054]
- [kernel] rcu: Determine expedited-GP IPI handler at build time (Waiman Long) [1737054]
- [kernel] rcu: Inline rcu_kthread_do_work() into its sole remaining caller (Waiman Long) [1737054]
- [kernel] rcu: Eliminate RCU_BH_FLAVOR and RCU_SCHED_FLAVOR (Waiman Long) [1737054]
- [kernel] rcu: Inline force_quiescent_state() into rcu_force_quiescent_state() (Waiman Long) [1737054]
- [kernel] rcu: Make expedited IPI handler return after handling critical section (Waiman Long) [1737054]
- [kernel] rcu: Rename and comment changes due to only one rcuo kthread per CPU (Waiman Long) [1737054]
- [kernel] sched: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] sched: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [net] net/core: Replace call_rcu_bh() and synchronize_rcu_bh() (Waiman Long) [1737054]
- [net] netpoll: allow cleanup to be synchronous (Waiman Long) [1737054]
- [net] netfilter: Replace call_rcu_bh(), rcu_barrier_bh(), and synchronize_rcu_bh() (Waiman Long) [1737054]
- [kernel] uprobes: Use synchronize_rcu() not synchronize_sched() (Waiman Long) [1737054]
- [kernel] rcutorture: Don't do busted forward-progress testing (Waiman Long) [1737054]
- [kernel] rcutorture: Use 100ms buckets for forward-progress callback histograms (Waiman Long) [1737054]
- [kernel] rcutorture: Recover from OOM during forward-progress tests (Waiman Long) [1737054]
- [kernel] rcutorture: Print forward-progress test age upon failure (Waiman Long) [1737054]
- [kernel] rcutorture: Print time since GP end upon forward-progress failure (Waiman Long) [1737054]
- [kernel] rcutorture: Print histogram of CB invocation at OOM time (Waiman Long) [1737054]
- [kernel] rcutorture: Print GP age upon forward-progress failure (Waiman Long) [1737054]
- [kernel] rcu: Print per-CPU callback counts for forward-progress failures (Waiman Long) [1737054]
- [kernel] rcu: Account for nocb-CPU callback counts in RCU CPU stall warnings (Waiman Long) [1737054]
- [kernel] rcutorture: Dump grace-period diagnostics upon forward-progress OOM (Waiman Long) [1737054]
- [kernel] rcutorture: Prepare for asynchronous access to rcu_fwd_startat (Waiman Long) [1737054]
- [kernel] torture: Remove unnecessary "ret" variables (Waiman Long) [1737054]
- [kernel] rcutorture: Affinity forward-progress test to avoid housekeeping CPUs (Waiman Long) [1737054]
- [kernel] rcutorture: Break up too-long rcu_torture_fwd_prog() function (Waiman Long) [1737054]
- [kernel] rcutorture: Remove cbflood facility (Waiman Long) [1737054]
- [kernel] torture: Bring any extra CPUs online during kernel startup (Waiman Long) [1737054]
- [kernel] rcutorture: Add call_rcu() flooding forward-progress tests (Waiman Long) [1737054]
- [tools] rcutorture/formal: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [tools] tools/kernel.h: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [net] net/decnet: Replace rcu_barrier_bh() with rcu_barrier() (Waiman Long) [1737054]
- [net] net/core/skmsg: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] cgroups: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] types: Remove call_rcu_bh() and call_rcu_sched() (Waiman Long) [1737054]
- [include] percpu-rwsem: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [net] net/bridge: Replace call_rcu_bh() and rcu_barrier_bh() (Waiman Long) [1737054]
- [kernel] srcu: Use "ssp" instead of "sp" for srcu_struct pointer (Waiman Long) [1737054]
- [kernel] srcu: Lock srcu_data structure in srcu_gp_start() (Waiman Long) [1737054]
- [mm] mm: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] percpu-refcount: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] events: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] workqueue: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] modules: Replace synchronize_sched() and call_rcu_sched() (Waiman Long) [1737054]
- [kernel] sched/membarrier: synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] lockdep: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] kprobes: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [init] main: Replace rcu_barrier_sched() with rcu_barrier() (Waiman Long) [1737054]
- [kernel] tracing: Replace synchronize_sched() and call_rcu_sched() (Waiman Long) [1737054]
- [kernel] tracepoints: Free early tracepoints after RCU is initialized (Waiman Long) [1737054]
- [kernel] tracing: Fix synchronizing to event changes with tracepoint_synchronize_unregister() (Waiman Long) [1737054]
- [kernel] tracepoint: Make rcuidle tracepoint callers use SRCU (Waiman Long) [1737054]
- [fs] fs/file: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [cpufreq] cpufreq/cpufreq_governor: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [cpufreq] cpufreq/intel_pstate: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [vhost] drivers/vhost: Replace synchronize_rcu_bh() with synchronize_rcu() (Waiman Long) [1737054]
- [netdrv] ethernet/sis: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [char] drivers/ipmi: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [crypto] crypto/pcrypt: Replace synchronize_rcu_bh() with synchronize_rcu() (Waiman Long) [1737054]
- [mm] mm: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [kernel] locking/mutex: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [fs] userfaultfd: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [net] smsc: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [scripts] checkpatch.pl: Suggest lockdep instead of asserting !spin_is_locked() (Waiman Long) [1737054]
- [scripts] checkpatch: Create table of obsolete APIs and apply to RCU (Waiman Long) [1737054]
- [maintainers] MAINTAINERS: Add Joel Fernandes as RCU reviewer (Waiman Long) [1737054]
- [kernel] rcu: Avoid signed integer overflow in rcu_preempt_deferred_qs() (Waiman Long) [1737054]
- [kernel] rcu: Replace this_cpu_ptr() with __this_cpu_read() (Waiman Long) [1737054]
- [kernel] rcu: Speed up expedited GPs when interrupting RCU reader (Waiman Long) [1737054]
- [kernel] rcu: Trace end of grace period before end of grace period (Waiman Long) [1737054]
- [kernel] rcu: Adjust the comment of function rcu_is_watching (Waiman Long) [1737054]
- [kernel] rcu: Add jiffies-since-GP-activity to show_rcu_gp_kthreads() (Waiman Long) [1737054]
- [kernel] rcu: Add state name to show_rcu_gp_kthreads() output (Waiman Long) [1737054]
- [kernel] rcu: Parameterize rcu_check_gp_start_stall() (Waiman Long) [1737054]
- [kernel] rcu: Avoid double multiply by HZ (Waiman Long) [1737054]
- [documentation] doc: Fix "struction" typo in RCU memory-ordering documentation (Waiman Long) [1737054]
- [documentation] doc: Correct parameter in stallwarn (Waiman Long) [1737054]
- [documentation] doc: RCU scheduler spinlock rcu_read_unlock() restriction remains (Waiman Long) [1737054]
- [documentation] doc: Make listing in RCU perf/scale requirements use rcu_assign_pointer() (Waiman Long) [1737054]
- [documentation] doc: Remove obsolete (non-)requirement about disabling preemption (Waiman Long) [1737054]
- [documentation] doc: Make reader aware of rcu_dereference_protected (Waiman Long) [1737054]
- [documentation] doc: rcu: Encourage use of rcu_barrier in checklist (Waiman Long) [1737054]
- [documentation] doc: rcu: Remove obsolete checklist item about synchronize_rcu usage (Waiman Long) [1737054]
- [documentation] doc: rcu: Remove obsolete suggestion from checklist (Waiman Long) [1737054]
- [documentation] doc: rcu: Add more rationale for using rcu_read_lock_sched in checklist (Waiman Long) [1737054]
- [documentation] doc: rcu: Update core and full API in whatisRCU (Waiman Long) [1737054]
- [documentation] doc: Document rcutorture forward-progress test kernel parameters (Waiman Long) [1737054]
- [documentation] doc: rcu: Update description of gp_seq fields in rcu_data (Waiman Long) [1737054]
- [documentation] doc: rcu: Better clarify the rcu_segcblist ->len field (Waiman Long) [1737054]
- [documentation] doc: rcu: Update Data-Structures for RCU flavor consolidation (Waiman Long) [1737054]
- [documentation] doc: Remove rcu_dynticks from Data-Structures (Waiman Long) [1737054]
- [documentation] doc: Update information about resched_cpu (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for kernel/rcu/update.c (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for kernel/rcu/tree_plugin.h (Waiman Long) [1737054]
- [kernel] rcu: Stop expedited grace periods from relying on stop-machine (Waiman Long) [1737054]
- [kernel] srcu: Prevent __call_srcu() counter wrap with read-side critical section (Waiman Long) [1737054]
- [include] srcu: Fix kernel-doc missing notation (Waiman Long) [1737054]
- [x86] x86/PCI: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [tools] rcutorture: Make use of nolibc when available (Waiman Long) [1737054]
- [tools] rcutorture: Import a copy of nolibc (Waiman Long) [1737054]
- [tools] rcutorture: Check initrd/init instead of initrd only (Waiman Long) [1737054]
- [tools] rcutorture: Always strip using the cross-compiler (Waiman Long) [1737054]
- [tools] rcutorture: Add cross-compile capability to initrd.sh (Waiman Long) [1737054]
- [tools] rcutorture: Make initrd/init execute in userspace (Waiman Long) [1737054]
- [tools] rcutorture: Add initrd support for systems lacking dracut (Waiman Long) [1737054]
- [tools] rcutorture: Automatically create initrd directory (Waiman Long) [1737054]
- [documentation] doc: Remove rcu_preempt_state reference in stallwarn (Waiman Long) [1737054]
- [documentation] doc: Clarify RCU data-structure comment about rcu_tree fanout (Waiman Long) [1737054]
- [documentation] doc: Set down forward-progress requirements (Waiman Long) [1737054]
- [powerpc] powerpc: Convert hugepd_free() to use call_rcu() (Waiman Long) [1737054]
- [s390] s390/mm: Convert tlb_table_flush() to use call_rcu() (Waiman Long) [1737054]
- [kernel] sparc/oprofile: Convert timer_stop() to use synchronize_rcu() (Waiman Long) [1737054]
- [kernel] sched/membarrier: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] rcu: Consolidate the RCU update functions invoked by sync.c (Waiman Long) [1737054]
- [kernel] rcu: Eliminate synchronize_rcu_mult() (Waiman Long) [1737054]
- [kernel] rcu: Fix rcu_{node, data} comments about gp_seq_needed (Waiman Long) [1737054]
- [kernel] rcu: Remove unused rcu_state externs (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for kernel/rcu/tree.c (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for sync.c (Waiman Long) [1737054]
- [include] srcu: Add notrace variant of srcu_dereference (Waiman Long) [1737054]
- [documentation] PM/EM: Document the Energy Model framework (Phil Auld) [1718927]
- [kernel] sched/doc: Document Energy Aware Scheduling (Phil Auld) [1718927]
- [kernel] sched/fair: Remove unneeded prototype of capacity_of() (Phil Auld) [1718927]
- [kernel] sched/fair: Skip LLC NOHZ logic for asymmetric systems (Phil Auld) [1718927]
- [kernel] sched/fair: Tune down misfit NOHZ kicks (Phil Auld) [1718927]
- [kernel] sched/fair: Comment some nohz_balancer_kick() kick conditions (Phil Auld) [1718927]
- [kernel] sched/fair: Prune, fix and simplify the nohz_balancer_kick() comment block (Phil Auld) [1718927]
- [kernel] sched/fair: Explain LLC nohz kick condition (Phil Auld) [1718927]
- [kernel] sched/fair: Simplify nohz_balancer_kick() (Phil Auld) [1718927]
- [kernel] sched/topology: Fix percpu data types in struct sd_data & struct s_data (Phil Auld) [1718927]
- [kernel] sched/fair: Simplify post_init_entity_util_avg() by calling it with a task_struct pointer argument (Phil Auld) [1718927]
- [kernel] sched/fair: Fix util_avg of new tasks for asymmetric systems (Phil Auld) [1718927]
- [kernel] sched/fair: Optimize update_blocked_averages() (Phil Auld) [1718927]
- [kernel] sched/topology: Introduce a sysctl for Energy Aware Scheduling (Phil Auld) [1718927]
- [kernel] Revert "sched/core: Take the hotplug lock in sched_init_smp()" (Phil Auld) [1718927]
- [kernel] cpu/hotplug: Mute hotplug lockdep during init (Phil Auld) [1718927]
- [kernel] sched/fair: Select an energy-efficient CPU on task wake-up (Phil Auld) [1718927]
- [kernel] sched/fair: Introduce an energy estimation helper function (Phil Auld) [1718927]
- [kernel] sched/fair: Add over-utilization/tipping point indicator (Phil Auld) [1718927]
- [kernel] sched/fair: Clean-up update_sg_lb_stats parameters (Phil Auld) [1718927]
- [kernel] sched/toplogy: Introduce the 'sched_energy_present' static key (Phil Auld) [1718927]
- [kernel] sched/topology: Make Energy Aware Scheduling depend on schedutil (Phil Auld) [1718927]
- [kernel] sched/topology: Disable EAS on inappropriate platforms (Phil Auld) [1718927]
- [kernel] sched/topology: Add lowest CPU asymmetry sched_domain level pointer (Phil Auld) [1718927]
- [kernel] sched/topology: Reference the Energy Model of CPUs when available (Phil Auld) [1718927]
- [kernel] PM: Introduce an Energy Model management framework (Phil Auld) [1718927]
- [kernel] sched/cpufreq: Prepare schedutil for Energy Aware Scheduling (Phil Auld) [1718927]
- [kernel] sched/topology: Relocate arch_scale_cpu_capacity() to the internal header (Phil Auld) [1718927]
- [kernel] sched/core: Take the hotplug lock in sched_init_smp() (Phil Auld) [1718927]
- [kernel] sched/core: Disable SD_PREFER_SIBLING on asymmetric CPU capacity domains (Phil Auld) [1718927]
- [kernel] sched/fair: Don't move tasks to lower capacity CPUs unless necessary (Phil Auld) [1718927]
- [kernel] sched/fair: Set rq->rd->overload when misfit (Phil Auld) [1718927]
- [kernel] sched/fair: Wrap rq->rd->overload accesses with READ/WRITE_ONCE() (Phil Auld) [1718927]
- [kernel] sched/core: Change root_domain->overload type to int (Phil Auld) [1718927]
- [kernel] sched/fair: Change 'prefer_sibling' type to bool (Phil Auld) [1718927]
- [kernel] sched/fair: Kick nohz balance if rq->misfit_task_load (Phil Auld) [1718927]
- [kernel] sched/fair: Consider misfit tasks when load-balancing (Phil Auld) [1718927]
- [kernel] sched/fair: Add sched_group per-CPU max capacity (Phil Auld) [1718927]
- [kernel] sched/fair: Add 'group_misfit_task' load-balance type (Phil Auld) [1718927]
- [kernel] sched/topology: Add static_key for asymmetric CPU capacity optimizations (Phil Auld) [1718927]
- [kernel] sched/core, workqueues: Distangle worker accounting from rq lock (Phil Auld) [1737067]
- [kernel] workqueue: Use normal rcu (Phil Auld) [1737067]
- [kernel] tick/broadcast: Fix warning about undefined tick_broadcast_oneshot_offline() (Phil Auld) [1737067]
- [kernel] timer/trace: Improve timer tracing (Phil Auld) [1737067]
- [include] timer/trace: Replace deprecated vsprintf pointer extension pf by ps (Phil Auld) [1737067]
- [kernel] timer: Move trace point to get proper index (Phil Auld) [1737067]
- [kernel] tick/sched: Update tick_sched struct documentation (Phil Auld) [1737067]
- [kernel] tick: Remove outgoing CPU from broadcast masks (Phil Auld) [1737067]
- [kernel] timekeeping: Consistently use unsigned int for seqcount snapshot (Phil Auld) [1737067]
- [kernel] sched/fair: Robustify CFS-bandwidth timer locking (Phil Auld) [1737067]
- [kernel] tick/sched : Remove redundant cpu_online() check (Phil Auld) [1737067]
- [misc] sched/swait: Rename to exclusive (Phil Auld) [1737067]
- [kernel] sched/swait: Switch to full exclusive mode (Phil Auld) [1737067]
- [kernel] sched/swait: Remove __prepare_to_swait (Phil Auld) [1737067]
- [netdrv] net: ena: don't wake up tx queue when down (John Linville) [1722628]
- [netdrv] Revert "net: ena: ethtool: add extra properties retrieval via get_priv_flags" (John Linville) [1722628]
- [netdrv] net: ena: Fix bug where ring allocation backoff stopped too late (John Linville) [1722628]
- [netdrv] net: ena: update driver version from 2.0.3 to 2.1.0 (John Linville) [1722628]
- [netdrv] net: ena: remove inline keyword from functions in *.c (John Linville) [1722628]
- [netdrv] net: ena: add ethtool function for changing io queue sizes (John Linville) [1722628]
- [netdrv] net: ena: allow queue allocation backoff when low on memory (John Linville) [1722628]
- [netdrv] net: ena: make ethtool show correct current and max queue sizes (John Linville) [1722628]
- [netdrv] net: ena: enable negotiating larger Rx ring size (John Linville) [1722628]
- [netdrv] net: ena: add MAX_QUEUES_EXT get feature admin command (John Linville) [1722628]
- [netdrv] net: ena: use dev_info_once instead of static variable (John Linville) [1722628]
- [netdrv] net: ena: add good checksum counter (John Linville) [1722628]
- [netdrv] net: ena: optimise calculations for CQ doorbell (John Linville) [1722628]
- [netdrv] net: ena: add support for changing max_header_size in LLQ mode (John Linville) [1722628]
- [netdrv] net: ena: allow automatic fallback to polling mode (John Linville) [1722628]
- [netdrv] net: ena: add newline at the end of pr_err prints (John Linville) [1722628]
- [netdrv] net: ena: arrange ena_probe() function variables in reverse christmas tree (John Linville) [1722628]
- [netdrv] net: ena: replace free_tx/rx_ids union with single free_ids field in ena_ring (John Linville) [1722628]
- [netdrv] net: ena: ethtool: add extra properties retrieval via get_priv_flags (John Linville) [1722628]
- [netdrv] net: ena: add handling of llq max tx burst size (John Linville) [1722628]
- [netdrv] net: ena: gcc 8: fix compilation warning (John Linville) [1722628]
- [netdrv] net: ena: fix ena_com_fill_hash_function() implementation (John Linville) [1722628]
- [netdrv] net: ena: improve latency by disabling adaptive interrupt moderation by default (John Linville) [1722628]
- [netdrv] net: ena: fix return value of ena_com_config_llq_info() (John Linville) [1722628]
- [netdrv] net: ena: fix incorrect test of supported hash function (John Linville) [1722628]
- [netdrv] net: ena: fix: Free napi resources when ena_up() fails (John Linville) [1722628]
- [netdrv] net: ena: fix: set freed objects to NULL to avoid failing future allocations (John Linville) [1722628]
- [netdrv] net: ena: fix swapped parameters when calling ena_com_indirect_table_fill_entry (John Linville) [1722628]
- [arm64] arm64: kexec: Add comment to explain use of __flush_icache_range() (Mark Salter) [1757450]
- [arm64] arm64: kexec: machine_kexec should call __flush_icache_range (Mark Salter) [1757450]
- [arm64] arm64: Do not issue IPIs for user executable ptes (Mark Salter) [1757450]
- [arm64] arm64: hibernate: Avoid sending cross-calling with interrupts disabled (Mark Salter) [1757450]
- [arm64] arm64: mm: Export __flush_icache_range() to modules (Mark Salter) [1757450]
- [arm64] arm64: IPI each CPU after invalidating the I-cache for kernel mappings (Mark Salter) [1757450]
- [s390] s390/dasd: Handle out-of-space constraint (Philipp Rudo) [1525398]
- [s390] s390/dasd: Use ALIGN_DOWN macro (Philipp Rudo) [1525398]
- [s390] s390/dasd: Make dasd_setup_queue() a discipline function (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add new ioctl to release space (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add dasd_sleep_on_queue_interruptible() (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add missing intensity definition (Philipp Rudo) [1525398]
- [s390] s390/dasd: Fix whitespace (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add dynamic formatting support for ESE volumes (Philipp Rudo) [1525398]
- [s390] s390/dasd: Recognise data for ESE volumes (Philipp Rudo) [1525398]
- [s390] s390/dasd: Put sub-order definitions in a separate section (Philipp Rudo) [1525398]
- [s390] s390/dasd: Make layout analysis ESE compatible (Philipp Rudo) [1525398]
- [s390] s390/dasd: Remove old defines and function (Philipp Rudo) [1525398]
- [s390] s390/dasd: Remove unused structs and function prototypes (Philipp Rudo) [1525398]
- [tools] perf report: Dump s390 counter set data to file (Philipp Rudo) [1731036]
- [tools] perf report: Display arch specific diagnostic counter sets, starting with s390 (Philipp Rudo) [1731036]
- [tools] perf report: Add s390 diagnosic sampling descriptor size (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf_diag: Add support for CPU-MF SVN 6 (Philipp Rudo) [1731036]
- [s390] s390/cpumf: Fix warning from check_processor_id (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf_diag: Add support for s390 counter facility diagnostic trace (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: Handle EBUSY return code from CPU counter facility reservation (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: add ctr_stcctm() function (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: move common functions into a separate file (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: introduce kernel_cpumcf_avail() function (Philipp Rudo) [1731036]
- [s390] s390/cpu_mf: replace stcctm5() with the stcctm() function (Philipp Rudo) [1731036]
- [s390] s390/cpu_mf: add store cpu counter multiple instruction support (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: Add minimal in-kernel interface for counter measurements (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: introduce kernel_cpumcf_alert() to obtain measurement alerts (Philipp Rudo) [1731036]
- [s390] s390/cpu_mf: move struct cpu_cf_events and per-CPU variable to header file (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: rename per-CPU counter facility structure and variables (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: prepare for in-kernel counter measurements (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: move counter set controls to a new header file (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: Reject request for sampling in event initialization (Philipp Rudo) [1731036]
- [s390] s390/perf: Change CPUM_CF return code in event init function (Philipp Rudo) [1731036]
- [acpi] ACPI / property: Add two new Thunderbolt property GUIDs to the list (Jarod Wilson) [1483494]
- [acpi] ACPI: property: restore _DSD data subnodes GUID comment (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for Intel Ice Lake (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Expose active parts of NVM even if upgrade is not supported (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Hide switch attributes that are not set (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Do not fail adding switch if some port is not implemented (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Use 32-bit writes when writing ring producer/consumer (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Move NVM upgrade support flag to struct icm (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Correct path indices for PCIe tunnel (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Show key using *pE not *pEp (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Switch to use device_property_count_uXX() (Jarod Wilson) [1483494]
- [include] device property: Add helpers to count items in an array (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Implement CIO reset correctly for Titan Ridge (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make sure device runtime resume completes before taking domain lock (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add SPDX license identifier for more missed files (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make priority unsigned in struct tb_path (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: shash - remove shash_desc::flags (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Start firmware on Titan Ridge Apple systems (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Reword output of tb_dump_hop() (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make rest of the logging to happen at debug level (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make __TB_[SW|PORT]_PRINT take const parameters (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for XDomain connections (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make tb_switch_alloc() return ERR_PTR() (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for DMA tunnels (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add XDomain UUID exchange support (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Run tb_xdp_handle_request() in system workqueue (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Do not tear down tunnels when driver is unloaded (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for Display Port tunnels (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Rework NFC credits handling (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Generalize port finding routines to support all port types (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Scan only valid NULL adapter ports in hotplug (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for full PCIe daisy chains (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Discover preboot PCIe paths the boot firmware established (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Deactivate all paths before restarting them (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Extend tunnel creation to more than 2 adjacent switches (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add helper function to iterate from one port to another (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Assign remote for both ports in case of dual link (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add functions for allocating and releasing HopIDs (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Generalize tunnel creation functionality (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Rename tunnel_pci to tunnel (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Cache adapter specific capability offset into struct port (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Properly disable path (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Set sleep bit when suspending switch (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Configure lanes when switch is initialized (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Move LC specific functionality into a separate file (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add dummy read after port capability list walk on Light Ridge (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Enable TMU access when accessing port space on legacy devices (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Do not allocate switch if depth is greater than 6 (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Take domain lock in switch sysfs attribute callbacks (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Block reads and writes if switch is unplugged (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Drop duplicated get_switch_at_route() (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Remove unused work field in struct tb_switch (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix to check the return value of kmemdup (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: property: Fix a missing check of kzalloc (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: xdomain: Fix to check return value of kmemdup (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix to check return value of ida_simple_get (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix to check for kmemdup failure (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix a missing check of kmemdup (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: property: Fix a NULL pointer dereference (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Prevent root port runtime suspend during NVM upgrade (Jarod Wilson) [1483494]
- [netdrv] net/ibmvnic: prevent more than one thread from running in reset (Steve Best) [1756943]
- [netdrv] net/ibmvnic: unlock rtnl_lock in reset so linkwatch_event can run (Steve Best) [1756943]
- [netdrv] sfc: don't score irq moderation points for GRO (Jarod Wilson) [1736303]
- [netdrv] sfc: Use dev_get_drvdata where possible (Jarod Wilson) [1736303]
- [netdrv] sfc: Remove 'PCIE error reporting unavailable' (Jarod Wilson) [1736303]
- [netdrv] sfc: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jarod Wilson) [1736303]
- [netdrv] sfc: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1736303]
- [netdrv] bonding: no need to print a message if debugfs_create_dir() fails (Jarod Wilson) [1756517]
- [netdrv] bonding: Add vlan tx offload to hw_enc_features (Jarod Wilson) [1756517]
- [netdrv] bonding: fix value exported by Netlink for peer_notif_delay (Jarod Wilson) [1756517]
- [netdrv] bonding: add an option to specify a delay between peer notifications (Jarod Wilson) [1756517]
- [netdrv] bonding: validate ip header before check IPPROTO_IGMP (Jarod Wilson) [1756517]
- [netdrv] bonding/main: fix NULL dereference in bond_select_active_slave() (Jarod Wilson) [1756517]
- [netdrv] bonding: Always enable vlan tx offload (Jarod Wilson) [1756517]
- [netdrv] bonding/options: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding/alb: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding/802.3ad: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding/main: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding: add slave_foo printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding: fix error messages in bond_do_fail_over_mac (Jarod Wilson) [1756517]
- [netdrv] bonding: improve event debug usability (Jarod Wilson) [1756517]
- [netdrv] net: bonding: Inherit MPLS features from slave devices (Jarod Wilson) [1756517]
- [netdrv] bonding: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Jarod Wilson) [1756517]
- [netdrv] bonding: Replace GPLv2 boilerplate/reference with SPDX - rule 90 (Jarod Wilson) [1756517]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 5 (Jarod Wilson) [1756517]
- [netdrv] bonding: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1756517]
- [powerpc] powerpc/fadump: support holes in kernel boot memory area (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: remove RMA_START and RMA_END macros (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: update documentation about option to release opalcore (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: consider f/w load area (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opalcore: provide an option to invalidate /sys/firmware/opal/core file (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opalcore: enable CONFIG_OPAL_CORE for FADUMP (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opalcore: export /sys/firmware/opal/core for analysing opal crashes (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: update documentation about CONFIG_PRESERVE_FA_DUMP (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add support to preserve crash data on FADUMP disabled kernel (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: improve how crashed kernel's memory is reserved (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: consider reserved ranges while releasing memory (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: make crash memory ranges array allocation generic (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: process architected register state data provided by firmware (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: make use of memblock's bottom up allocation mode (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: Update documentation about OPAL platform support (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: handle invalidation of crashdump and re-registraion (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: Warn before processing partial crashdump (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: process the crashdump by exporting it as /proc/vmcore (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: support copying multiple kernel boot memory regions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: define OPAL register/un-register callback functions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: reset metadata address during clean up (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: register kernel metadata address with opal (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: improve fadump_reserve_mem() (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add fadump support on powernv (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opal: add MPIPL interface definitions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/powernv: Make possible for user to force a full ipl cec reboot (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: use FADump instead of fadump for how it is pronounced (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] pseries/fadump: move out platform specific support from generic code (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: release all the memory above boot memory size (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add source info while displaying region contents (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] pseries/fadump: define RTAS register/un-register callback functions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: introduce callbacks for platform specific operations (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: move rtas specific definitions to platform code (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: define an empty fadump_cleanup() (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: use helper functions to reserve/release cpu notes buffer (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: Improve fadump documentation (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: declare helper functions in internal header file (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add helper functions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: move internal macros/definitions to a new header (Desnes Augusto Nunes do Rosario) [1524687]
- [watchdog] watchdog: iTCO: Add support for Cannon Lake PCH iTCO (Alexander Beregalov) [1724532]
- [i2c] i2c: i801: Use iTCO version 6 in Cannon Lake PCH and beyond (Alexander Beregalov) [1724532]
- [i2c] i2c: i801: Allow ACPI AML access I/O ports not reserved for SMBus (Alexander Beregalov) [1724532]
- [block] loop: set PF_MEMALLOC_NOIO for the worker thread (Ming Lei) [1741392]
- [fs] bdev: Fixup error handling in blkdev_get() (Ming Lei) [1741392]
- [block] loop: Fix mount(2) failure due to race with LOOP_SET_FD (Ming Lei) [1741392]
- [block] block, bfq: handle NULL return value by bfq_init_rq() (Ming Lei) [1741392]
- [block] block, bfq: move update of waker and woken list to queue freeing (Ming Lei) [1741392]
- [block] block, bfq: reset last_completed_rq_bfqq if the pointed queue is freed (Ming Lei) [1741392]
- [block] block: aoe: Fix kernel crash due to atomic sleep when exiting (Ming Lei) [1741392]
- [block] rq-qos: use a mb for got_token (Ming Lei) [1741392]
- [block] rq-qos: set ourself TASK_UNINTERRUPTIBLE after we schedule (Ming Lei) [1741392]
- [block] rq-qos: don't reset has_sleepers on spurious wakeups (Ming Lei) [1741392]
- [block] rq-qos: fix missed wake-ups in rq_qos_throttle (Ming Lei) [1741392]
- [include] wait: add wq_has_single_sleeper helper (Ming Lei) [1741392]
- [block] block, bfq: check also in-flight I/O in dispatch plugging (Ming Lei) [1741392]
- [block] block: fix sysfs module parameters directory path in comment (Ming Lei) [1741392]
- [block] block: Allow mapping of vmalloc-ed buffers (Ming Lei) [1741392]
- [block] block/bio-integrity: fix a memory leak bug (Ming Lei) [1741392]
- [block] block: Disable write plugging for zoned block devices (Ming Lei) [1741392]
- [block] blk-throttle: fix zero wait time for iops throttled group (Ming Lei) [1741392]
- [block] block: Fix potential overflow in blk_report_zones() (Ming Lei) [1741392]
- [block] blk-cgroup: turn on psi memstall stuff (Ming Lei) [1741392]
- [block] block: init flush rq ref count to 1 (Ming Lei) [1741392]
- [lib] sbitmap: Replace cmpxchg with xchg (Ming Lei) [1741392]
- [block] block: Remove unused code (Ming Lei) [1741392]
- [block] block, bfq: Init saved_wr_start_at_switch_to_srt in unlikely case (Ming Lei) [1741392]
- [block] block, bfq: re-schedule empty queues if they deserve I/O plugging (Ming Lei) [1741392]
- [block] block, bfq: preempt lower-weight or lower-priority queues (Ming Lei) [1741392]
- [block] block, bfq: detect wakers and unconditionally inject their I/O (Ming Lei) [1741392]
- [block] block, bfq: bring forward seek&think time update (Ming Lei) [1741392]
- [block] block, bfq: update base request service times when possible (Ming Lei) [1741392]
- [block] block, bfq: fix rq_in_driver check in bfq_update_inject_limit (Ming Lei) [1741392]
- [block] block, bfq: reset inject limit when think-time state changes (Ming Lei) [1741392]
- [kernel] cgroup: export css_next_descendant_pre for bfq (Ming Lei) [1741392]
- [block] block: update print_req_error() (Ming Lei) [1741392]
- [block] block: use blk_op_str() in blk-mq-debugfs.c (Ming Lei) [1741392]
- [block] block: add centralize REQ_OP_XXX to string helper (Ming Lei) [1741392]
- [block] block: improve print_req_error (Ming Lei) [1741392]
- [block] block: rename CONFIG_DEBUG_BLK_CGROUP to CONFIG_BFQ_CGROUP_DEBUG (Ming Lei) [1741392]
- [block] bfq-iosched: move bfq_stat_recursive_sum into the only caller (Ming Lei) [1741392]
- [block] blk-cgroup: move struct blkg_stat to bfq (Ming Lei) [1741392]
- [block] blk-cgroup: introduce a new struct blkg_rwstat_sample (Ming Lei) [1741392]
- [block] blk-cgroup: pass blkg_rwstat structures by reference (Ming Lei) [1741392]
- [block] blk-cgroup: factor out a helper to read rwstat counter (Ming Lei) [1741392]
- [block] block: drbd: no need to check return value of debugfs_create functions (Ming Lei) [1741392]
- [block] blk-core: Remove blk_end_request*() declarations (Ming Lei) [1741392]
- [block] block: code cleanup queue_poll_stat_show() (Ming Lei) [1741392]
- [block] block: use right format specifier for op (Ming Lei) [1741392]
- [block] block: get rid of redundant else (Ming Lei) [1741392]
- [block] block: use req_op() to maintain consistency (Ming Lei) [1741392]
- [fs] blkcg, writeback: dead memcgs shouldn't contribute to writeback ownership arbitration (Ming Lei) [1741392]
- [block] blkcg: blkcg_activate_policy() should initialize ancestors first (Ming Lei) [1741392]
- [block] blkcg: perpcu_ref init/exit should be done from blkg_alloc/free() (Ming Lei) [1741392]
- [block] blkcg: update blkcg_print_stat() to handle larger outputs (Ming Lei) [1741392]
- [block] block: bio: Use struct_size() in kmalloc() (Ming Lei) [1741392]
- [block] block: genhd: Use struct_size() helper (Ming Lei) [1741392]
- [block] block: null_blk: fix race condition for null_del_dev (Ming Lei) [1741392]
- [block] blk-mq/debugfs: Fix improper print qualifier (Ming Lei) [1741392]
- [block] loop: Don't change loop device under exclusive opener (Ming Lei) [1741392]

* Wed Oct 09 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.6.el8]
- [documentation] timekeeping.txt: Correct maxCount of n-bit binary counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: clk: Add (devm_)clk_get_optional() functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: uapi: align comments with firmware files (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: rename SOUNDWIRE to ALH (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: add ALH parameters (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: remove SPDX "WITH Linux-syscall-note" from kernel-space headers again (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc.h: fe_compr can be bit field (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc.h: fixup for_each_card_links() macro (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Define a set of DAPM pre/post-up events (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: use bit field for bus_control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple_card_utils.h: care NULL dai at asoc_simple_debug_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: remove an unused field from struct hda_codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Avoid polluting led_* namespace (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Add Hiby device family to quirks for native DSD support (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Update DSD support quirks for Oppo and Rotel (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: DSD auto-detection for Playback Designs (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: remove some dead code (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix possible NULL dereference at create_yamaha_midi_quirk() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Clean up check_input_term() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Remove superfluous bLength checks (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Unify the release of usb_mixer_elem_info objects (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Simplify parse_audio_unit() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: More validations of descriptor units (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Check mixer unit bitmap yet more strictly (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix memory leak at line6_init_pcm() error path (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix invalid NULL check in snd_emuusb_set_samplerate() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Add implicit fb quirk for Behringer UFX1604 (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix a stack buffer overflow bug in check_input_term (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix an OOB bug in parse_audio_mixer_unit (Jaroslav Kysela) [1738610]
- [sound] ALSA: hiface: fix multiple memory leak bugs (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Add Pioneer DDJ-SX3 PCM quirck (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Skip bSynchAddress endpoint check if it is invalid (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix PCM device order (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Unify audioformat release code (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix gpf in snd_usb_pipe_sanity_check (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Scarlett Gen 2 mixer interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: sizeof (byte) is always 1, use that fact. (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix a typo (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix wrong altsetting for LINE6_PODHD500_1 (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix Line6 Helix audio format rates (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix parse of UAC2 Extension Units (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix write on zero-sized buffer (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix sign unintended sign extension on left shifts (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Sanity checks for each pipe and EP types (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Enable .product_name override for Emagic, Unitor 8. (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Use container_of() (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Drop superfluous timer helper function (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: variax: Rewrite complex timer & work combo with a delayed work (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: podhd: Rewrite complex timer & work combo with a delayed work (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: pod: Rewrite complex timer & work combo with a delayed work (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Assure canceling delayed work at disconnection (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 33 (Jaroslav Kysela) [1738610]
- [sound] ALSA: sparc: Mark expected switch fall-throughs (Jaroslav Kysela) [1738610]
- [sound] ALSA: fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ux500: mop500: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ux500: mop500: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ux500: mop500: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: txx9: txx9aclc-generic: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: osk5912: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap3pandora: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-twl4030: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-twl4030: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-twl4030: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-hdmi: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-hdmi: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-hdmi: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-abe-twl6040: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-abe-twl6040: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-abe-twl6040: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: n810: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Fix slot mask settings when using multiple AXRs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Set unused serializers as INACTIVE (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: Fix SDMA users not providing channel names (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Support for auxclk-fs-ratio (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: ams-delta: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: trimslice: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: trimslice: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: trimslice: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm9712: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm9712: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm9712: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8753: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8753: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8753: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_sgtl5000: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_sgtl5000: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_sgtl5000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5677: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5677: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5677: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5640: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5640: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5640: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_max98090: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_max98090: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_alc5632: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_alc5632: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_alc5632: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: pass volume min/max linear value to FW (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ignore unrecoverable CTX_SAVE IPC errors at suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Add earpiece (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun4i-codec: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: spdifrx: manage identification registers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: dfsdm: add 16 bits audio record support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: add cpu_dai_name for DAIs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: add min/max step for volume_table (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sof: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: clarify operator precedence (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASOC: SOF: ipc: prevent logging trace messages (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: add new macro hstream_to_sof_hda_stream() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: make sure RUN bit setting to 0 during clear stream status (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: fix a deadlock with bus->reg_lock (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: modify stream interrupt handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: save handle to sdev in sof_intel_hda_stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove misleading error trace from IRQ thread (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: dont wake dsp up in kcontrol IO (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Fix handling of custom_stop_condition on DAPM graph walks (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: compress: Fix memory leak from snd_soc_new_compress (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: sirf-audio: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: sirf-audio: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: sirf-audio: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sh: sh7760-ac97: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: ssiu: tidyup SSI_MODE1/2 settings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: fixup mod ID calculation in rsnd_ctu_probe_ (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: add missing pin sharing with SSI9 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sh: migor: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tobermory: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: speyside: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: snow: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: snow: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: snow: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994pcm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8580: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_spdif: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smartq_wm8987: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: s3c24xx_uda134x: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec_tlv320aic23: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec_hermes: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: rx1950_uda1380: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: odroid: fix a double-free issue for cpu_dai (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: odroid: fix an use-after-free issue for codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: odroid: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: lowland: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: littlemill: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: jive_wm8750: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: h1940_uda1380: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: bells: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: arndale_rt5631: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: arndale_rt5631: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: arndale_rt5631: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_rt5645: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_rt5645: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_rt5645: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip-max98090: Remove MICBIAS as supply of input pin IN34 (Jaroslav Kysela) [1738610]
- [sound] ALSA: SoC: rockchip: rockchip_max98090: Enable MICBIAS for headset keypress detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3399_gru_sound: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3399_gru_sound: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3399_gru_sound: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rk3399_gru_sound: Support 32, 44.1 and 88.2 kHz sample rates (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3288_hdmi_analog: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3288_hdmi_analog: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3288_hdmi_analog: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: pdm: select CONFIG_RATIONAL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: storm: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: storm: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: storm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: Fix oops with multiple DAI links (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: tosa: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: hx4700: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: kernel: fix typos and some coding style in comments (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Add missing Slimbus0 audio route (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: zylonite: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: z2: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: ttc-dkb: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: spitz: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: pxa2xx-ac97.c: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: poodle: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: palm27x: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: mioa701_wm9713: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: magician: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: imote2: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: em-x270: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: e800_wm9712: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: e750_wm9705: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: e740_wm9705: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: corgi: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: brownstone: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs: mxs-sgtl5000: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs: mxs-sgtl5000: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs: mxs-sgtl5000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-toddr: add sm1 support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-toddr: expose all 8 inputs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: tdmout: add sm1 support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdmout: right_j is not supported (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: tdmin: expose all 16 inputs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdmin: right_j is not supported (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm: fix sample clock inversion (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm: consistently use SND_SOC_DAIFMT defines (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: g12a-tohdmitx: require regmap mmio (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: free reset on device removal (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: add reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-spdifout: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-spdifin: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-pdm: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-frddr: expose all 8 outputs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-frddr: add sm1 support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-fifo: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650-rt5676: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650-rt5514: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt6797-mt6351: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt2701-wm8960: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt2701-cs42448: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Add missing newline at end of file (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood: armada-370-db: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood: armada-370-db: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood: armada-370-db: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: jz4740: qi_lb60: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 239 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Fix incorrect capture position reporting (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Fix NULL ptr dereference when unloading clk dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Don't return failure on machine driver reload (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Do not disable FW notifications (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof_rt5682: use GFP_KERNEL instead of GFP_ATOMIC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: correct naming for dmic16k (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof_rt5682: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for Irbis NB41 netbook (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bxt-da7219-max98357a: add BE dailink for dmic16k (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add MCLK support for BYT platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_rt286: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_ssm4567: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_common: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_rt5514_max98927: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_max98927: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_rt5660: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: kbl_da7219_max98927: add dai_trigger function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: haswell: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_nocodec: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_cx2072x: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: byt-rt5640: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: byt-max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bxt_rt298: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bxt_da7219_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: broadwell: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: fix use-after-free in graph_for_each_link (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: add missing const at graph_get_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: phycore-ac97: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card-utils: care no Platform for DPCM (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: fix use-after-free in graph_dai_link_of_dpcm() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: fix an use-after-free in graph_get_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: wm1133-ev1: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: pcm030-audio-fabric: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: mx27vis-aic32x4: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-spdif: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-spdif: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-spdif: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-sgtl5000: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-sgtl5000: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-sgtl5000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-mc13783: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: mpc8610_hpcd/p1022_ds/p1022_rdk: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: no need to check return value of debugfs_create functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: fsl-asoc-card: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: eukrea-tlv320: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: efika-audio-fabric: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm_adsp: Allow bus error handler to be called directly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm_adsp: no need to check return value of debugfs_create functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: remove multiple defines. (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: add irqflag IRQF_ONESHOT flag (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: Fix misuse of GENMASK macro (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic31xx: suppress error message for EPROBE_DEFER (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tas571x: Fix -Wunused-const-variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Fix charge pump source assignment (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Fix of unmute outputs on probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: add ADC mute control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Improve VAG power and mute control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Fix definition of VAG Ramp Control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5682: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677-spi: Rename driver to differentiate from main codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5665: remove redundant assignment to variable idx (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5514-spi: don't use snd_soc_lookup_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: simplify the EFUSE read function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Remove executable attribute from source files (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: add silence detection and manual PDB control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Convert headers to SPDX (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: fix DC calibration offset not applying (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Relocate my e-mail to .com domain zone (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: nau8825: fix fake interruption when booting (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: nau8822: support master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: soc: codecs: mt6358: change return type of mt6358_codec_init_reg (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: msm8916-wcd-digital: Add sidetone support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98383: fix i2c probe failure (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 496 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdac_hdmi: report codec link up/down status to bus (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec: hdac_hdmi: fix pin connections at cvt enable (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 463 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: mark PM function as __maybe_unused (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: use mdelay for sdmode-delay (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: avoid speaker pop when playback startup (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Fix MFREQ selection issue for async mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cros_ec_codec: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ak4118: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: spi: AD ASoC: declare missing of table (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ab8500: add range to usleep_range (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: snappercl15: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: simone: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: ep93xx-i2s.c: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: edb93xx: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: bcm: cygnus-pcm: Unneeded variable: "ret". (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: psc-i2s.c: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: db1200: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: db1000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: tse850-pcm5142: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: tse850-pcm5142: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: tse850-pcm5142: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9x5_wm8731: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9x5_wm8731: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9x5_wm8731: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9g20_wm8731: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: mikroe-proto: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-wm8904: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-pdmic: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-pcm-dma.c: use devm_snd_dmaengine_pcm_register() (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 234 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-classd: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp-rt5645: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp-da7219-max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 200 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ps3: Remove Unneeded variable: "ret" (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 277 (Jaroslav Kysela) [1738610]
- [sound] ALSA: rme9652: Unneeded variable: "result". (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 274 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hdspm: Fix single speed ADAT capture and playback with RME HDSPe AIO (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 264 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 404 (Jaroslav Kysela) [1738610]
- [sound] ALSA: lx6464es - Remove set but not used variables 'orun_mask, urun_mask' (Jaroslav Kysela) [1738610]
- [sound] ALSA: lx6464es: Remove unneeded variable err (Jaroslav Kysela) [1738610]
- [sound] ALSA: lx6464es - add support for LX6464ESe pci express variant (Jaroslav Kysela) [1738610]
- [sound] ALSA: ice1712: Check correct return value to snd_i2c_sendbytes (EWS/DMX 6Fire) (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 29 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 46 (Jaroslav Kysela) [1738610]
- [sound] ALSA: emu10k1: Remove unneeded variable "change" (Jaroslav Kysela) [1738610]
- [sound] ALSA: echoaudio: Replace kmalloc + memcpy with kmemdup (Jaroslav Kysela) [1738610]
- [sound] ALSA: pci: echoaudio: remove variable which is a constant (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 364 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 118 (Jaroslav Kysela) [1738610]
- [sound] ALSA: cs4281: remove redundant assignment to variable val and remove a goto (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 32 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 116 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 456 (Jaroslav Kysela) [1738610]
- [sound] ALSA: au88x0: Remove unneeded variable: "changed" (Jaroslav Kysela) [1738610]
- [sound] ALSA: asihpi: Remove unneeded variable change (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 88 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ac97: remove unused variable 'snd_ac97_controls_master_mono' (Jaroslav Kysela) [1738610]
- [sound] ALSA: dmasound_atari: Mark expected switch fall-through (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 176 (Jaroslav Kysela) [1738610]
- [sound] ALSA: i2c: ak4xxx-adda: Fix a possible null pointer dereference in build_adc_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: isa/wavefront: remove redundant assignment to pointer bptr (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 370 (Jaroslav Kysela) [1738610]
- [sound] ALSA: sb: remove redundant assignment to variable result (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ALSA: hda: Add codec on bus address table lately" (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Unexport a few more stuff (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Drop export of snd_hdac_bus_add/remove_device() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Add codec on bus address table lately (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: readl/writel need linux/io.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: intel-nhlt: handle NHLT VENDOR_DEFINED DMIC geometry (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: move parts of NHLT code to new module (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Fix 1-minute detection delay when i915 module is not available (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Fix a headphone detection issue when using SOF (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: fix: lock reg_lock before calling snd_hdac_bus_update_rirb (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: add polling mode in snd_hdac_bus_get_response (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sdm845: remove unneeded semicolon (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dmaengine: Replace strncpy() with strscpy_pad() for pcm->name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: remove redundant use of ret variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: Add an op to set callback function for plug event (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_unbind_aux_dev() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add soc_unbind_aux_dev() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_bind_aux_dev() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_link_dais() next to soc_remove_link_dais() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_probe_link_dais() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add new soc_link_init() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_dai() next to soc_remove_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_remove_link_dais() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_remove_link_components() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_probe_link_components() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: make array pd static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1305: make array pd static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: make array pd static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: SoC: simple-card-utils: set 0Hz to sysclk when shutdown (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: ignore 0Hz sysclk (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: make two arrays static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Use regmap_multi_reg_write() when initializing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Reset used registers at probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Group register initialization at probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Fix memory corruption on BE 64b systems (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: support fixed and variable both clock rates (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: fix redundant codes of clock (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: add DT-bindings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dmaengine: Make the pcm->name equal to pcm->id if the name is not set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Fix COMPILE_TEST error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: Include link-name in error messages (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: Fix NULL pointer in of parser (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: Mark links as nonatomic (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add comment to jack at soc_remove_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf-audio: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ep93xx: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: add clock control of MCLK (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph: indicate rebind issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: indicate rebind issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: fix an use-after-free in simple_for_each_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: fix an use-after-free in simple_dai_link_of_dpcm() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for cpu (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_link_components() position (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add snd_soc_dapm_init() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: dapm related setup at one place (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_component() position (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add soc_rtd_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: fix space issues (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: remove forward declaration of headset_init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: move headset jack to card-specific storage (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: move private structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF/Intel: fix selection of SND_INTEL_NHTL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: broadwell: Simplify device probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: Simplify device probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: haswell: Simplify device probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Haswell: Adjust machine device private context (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: Do not fail if the dai_set_sysclk returns -ENOTSUPP (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: edma-pcm: Fix for legacy dma_slave_map based channel lookup (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-i2s: Add S32_LE as support format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-i2s: Move the XSYNCERR workaround to .prepare callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Baytrail: Fix implicit fallthrough warning (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_ssi: Fix clock control issue in master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: Fix primary interpolator max rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: fix tdm out data is valid on rising edge (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: tdm hw support tdm out and 8ch i2s out (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel_ssc_dai: implement left-justified data mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel_ssc_dai: rework DAI format configuration (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: enable SOC_SSC_PDC and SOC_SSC_DMA in Kconfig (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Force suspend/resume during system suspend/resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: fix tdm out data align issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: add mutex protection to set_fmt/set_tdm_slot (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: fix inverted L/R of headphone mixer volume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: fix headphone mixer volume table (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Release topology when we are done with it (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Remove memory available check (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Remove MCPS available check (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Remove static table index when parsing topology (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Print module type instead of id (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: NHLT: Fix debug print format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Expose snd_soc_dapm_new_control_unlocked properly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: topology: fix memory leaks on sm, se and sbe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: topology: Consolidate and fix asoc_tplg_dapm_widget_*_create flow (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: topology: Consolidate how dtexts and dvalues are freed (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-topology: fix modern dai link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-topology: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Use correct function to access iomem space (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Fix an is IS_ERR() vs NULL check (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i: Revert A83t description (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Fix return value check in imx8_probe() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: remove unused DAPM-related variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: Revert initial A83t support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: imx-audmix: register the card on a proper dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Make some functions static (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: rename soc_post_component_init() to soc_rtd_init() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: initialize list at one place (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: fix get control data return type and arguments (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: initialize component list (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-topology: use for_each_component_dais() at remove_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: soc_cleanup_card_resources() become void (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add NOTE to snd_soc_rtdcom_lookup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use device_register() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: switch tdm pins gpio function when playback on or off (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt2701: Fix -Wunused-const-variable warnings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8988: fix typo in wm8988_right_line_controls (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx: Add i.MX8 HW support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Add OF DSP device support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: AMD: Fix Kconfig warning without GPIOLIB (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Add support for DSP formats (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Replace call to params_width by local variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Use the actual format width instead of an hardcoded one (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Use the physical / slot width for the clocks (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Add support for TDM slots (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove unneeded dai_link check from snd_soc_remove_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_initialize_card_lists() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add support for imx8qm (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mchp-i2s-mcc: Fix simultaneous capture and playback in master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mchp-i2s-mcc: Wait for RX/TX RDY only if controller is running (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mchp-i2s-mcc: Fix unprepare of GCLK (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Support more channels (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Pass the channels number as an argument (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Remove duplicated quirks structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix the LRCK period on A83t (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix MCLK Enable bit offset on A83t (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix WSS and SR fields for the A83t (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix the LRCK polarity (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix LRCK and BCLK polarity offsets on newer SoCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: RX and TX counter registers are swapped (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix the MCLK and BCLK dividers on newer SoCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Use module clock as BCLK parent on newer SoCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Move the format configuration to a callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Move the channel configuration to a callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Rework MCLK divider calculation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Replace call to params_channels by local variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Don't use the oversample to calculate BCLK (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Switch to devm for PCM register (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Register regmap and PCM before our component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8904: implement input mode select as a mux (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8904: fix typo in DAPM kcontrol name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add all Chromebooks that need pmc_plt_clk_0 quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: uniphier: Fix double reset assersion when transitioning to suspend state (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: initial support for Intel ALH DAI type (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: Add dummy support for i.MX8 DAIs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: imx-audmux: Add driver suspend and resume to support MEGA Fast (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for EHL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for Tiger Lake (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: Add Cometlake machine driver support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Move pcm_mutex up to card level from snd_soc_pcm_runtime (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: 88pm860x: remove unused variables 'pcm_switch_controls' and 'aif1_mux' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42l56: remove unused variable 'adc_swap_enum' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8328: remove unused variable 'pga_tlv' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic31xx: remove unused variable 'cm_m_enum' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic23: remove unused variable 'tlv320aic23_rec_src' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: remove unused variable 'dac_vol_tlv' and 'adc_vol_tlv' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98371: remove unused variable 'max98371_noload_gain_tlv' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42l73: remove unused variables 'vsp_output_mux' and 'xsp_output_mux' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Print constant literals from format specifier (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt6358: add delay after dmic clock on (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: remove unused variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: remove unused variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt2701: remove unused variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: Fix -Wunused-const-variable warning (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8737: Fix copy-paste error in wm8737_snd_controls (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs4349: Use PM ops 'cs4349_runtime_pm' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8328: Fix copy-paste error in es8328_right_line_controls (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: hsw: remove i386 build warning w/ size_t argument (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: Fix typos in ti/Kconfig (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: Set period size to 240 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Allow reconfiguration of tdm_slots and slot_width (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Retain the independence of DAC and ADC side of the codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: make headset codec optional (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max9850: remove unused variable 'max9850_reg' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98926: remove two unused variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove legacy style of aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun4i-codec: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: speyside: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: support snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdac_hdmi: Offload dapm update at jack detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: byt: Refactor fw ready / mem windows creation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: bdw: Use generic function for fw ready / mem windows creation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Remove call to snd_sof_dsp_mailbox_init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ml26124: remove unused variable 'ngth' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt6351: remove unused variable 'mt_lineout_control' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: intel: skl_hda_dsp_common: create HDMI jack kctl (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tscs454: remove unused variable 'PLL_48K_RATE' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: fix module_put() warning in soc_cleanup_component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: dai_link check under soc_dpcm_debugfs_add() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: define soc_dpcm_debugfs_add() for non CONFIG_DEBUG_FS (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for card->deferred_resume_work (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove unneeded list_empty() check for snd_soc_try_rebind_card() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: call snd_soc_dapm_debugfs_init() at soc_init_card_debugfs() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_add_card_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_dapm_add_routes() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_add_component_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdac_hda: fix page fault issue by removing race (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Direct MMIO accesses (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add support for imx7ulp/imx8mq (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: mark regmap as fast_io (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: large_config_get overhaul (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Implement set_bclk_ratio (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add support for SAI new version (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: derive TX FIFO watermark from FIFO depth (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: add of_match data (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Update Tx/Rx channel enable mask (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add registers definition for multiple datalines (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_dapm_new_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: reuse rtdcom at snd_soc_rtdcom_add() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: don't use for_each_card_links_safe() at snd_soc_find_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: check return value of snd_soc_add_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add comment for for_each_xxx (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: set component->debugfs_root NULL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Add a flag for the R0 calibration test (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Add R0 temperature and TDM1 ADC2DAT Swap control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: don't call clk_get_rate() under atomic context (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98373: Remove executable bits (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_pcm_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_pcm_new() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_mmap() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_page() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_copy_user() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_ioctrl() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_pointer() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_set_bias_level() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_stream_event() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_seq_notifier() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_of_xlate_dai_name() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_of_xlate_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_remove() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_probe() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_is_suspended() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_resume() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_suspend() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_trigger() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_hw_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_hw_params() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_prepare() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_close() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_open() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_get/put() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: add soc-component.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: remove soc_fill_silence() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: remove soc_rtdcom_copy_kernel() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: remove soc_rtdcom_ack() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp3x: use dma address for acp3x dma driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp3x: use dma_ops of parent device for acp3x dma driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: zx-tdm: remove redundant assignment to ts_width on error return path (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: SoC: skylake: no need to check return value of debugfs_create functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: fill some of the runtime stream parameters (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: remove ephemeral variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: create pcm for codec2codec links as well (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: use common NHLT module (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Merge skl_sst and skl into skl_dev struct (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Limit large_config_get to single frame (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Fix use of potentially uninitialized variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Update request-reply IPC model (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Common: Fix NULL dereference in tx_wait_done (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 174 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Fix race condition in IPC rx list (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 490 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Read HIPCT extension before clearing DONE bit (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: move NHLT header to common directory (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: g12a-tohdmitx: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: psc-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: psc-ac97: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: uniphier: aio-dma: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: uniphier: evea: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: inno_rk3036: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: jz4740: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mmp-sspa: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: jz4725b: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: msm8916-wcd: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: sai: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun8i-codec: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun8i-codec-analog: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: xlnx: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs4271: Fix a typo in the CS4171_NR_RATIOS (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: Mark expected switch fall-throughs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: xtfpga-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: spear: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs-saif: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: bcm2835-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_audmix: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: imx-audmux: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt6797: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt8173: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ep93xx-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra20_das: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: g12a-tohdmitx: override codec2codec params (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98373: add 88200 and 96000 sampling rate support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Incorrect SR and WSS computation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: fix missing return of error return code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Support for correct symmetric sample bits (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Correct slot_width posed constraint (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: Fix mono capture (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Fix some acpi vs apci typo in somme comments (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Fix clk PDIR handling for i2s master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: deal with params when necessary (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: name link using stream direction (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: run callbacks in order (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: Add uda1334 codec driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Add RT1308 amplifier driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Makefile - fix the top-level kernel module names (add snd- prefix) (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Improve serializer handling in multi AXR setups (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Add support for RIGHT_J format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Cleanup skl_module_cfg declaration (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Make MCPS and CPS params obsolete (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Combine snd_soc_skl_ipc and snd_soc_skl (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Reset pipeline before its deletion (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Strip T and L from TLV IPCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Properly cleanup on component removal (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Initialize lists before access so they are safe to use (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Add function to cleanup debugfs interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Use recommended SDxFMT programming sequence (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Switch to modern UUID API (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl-pcm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8955: Fix a typo in 'wm8995_pll_factors()' function name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Fail card instantiation if DAI format setup fails (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: move snd_soc_dai_stream_valid() to soc-dai.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use existing snd_soc_dai_digital_mute() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compress_new() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_remove() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_probe() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_resume() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_suspend() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_delay() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_bespoke_trigger() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_trigger() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_prepare() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_shutdown() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_startup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_hw_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: mv soc_dai_hw_params() to soc-dai (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: add soc-dai.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Return -ENOTSUPP from set_channel_map() if no operation provided (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: support dai_link with platforms_num != 1 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: defer card registration if codec component is missing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: don't use soc_find_component() at snd_soc_find_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use soc_find_component() at snd_soc_find_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: soc_find_component() uses snd_soc_dai_link_component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: soc_find_component() uses snd_soc_is_matching_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_find_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: call snd_soc_unbind_card() under mutex_lock; (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: allow no Platform on dai_link (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove legacy style dai_link (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc.h: add sound dai_link connection macro (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: Support hw_free() callback at DAI level (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5665: Fix a typo in the name of a function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Remove dev_err() usage after platform_get_irq() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: recover the channel swap after xrun (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: Wrap some operations to be functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: Add pm runtime function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ssp: BCLK delay parameter (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Add DMIC token for unmute gain ramp time (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix stream id setting (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix link DMA config (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: reset link DMA state in prepare (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: reserve host DMA channel for hostless streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: assign link DMA channel at run-time (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: initial support for Elkhart Lake (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: initial support for Tiger Lake. (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Use generic function for fw ready / mem windows creation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: make sure DMA is start/stop by read the RUN bit (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix HDA direct MMIO access (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove duplicated clear WAKESTS (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: clear stream status and wakests properly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: add function for hda stop chip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: set position buffer in init chip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: correct ROM state mask (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Introduce snd_sof_dsp_get_window_offset (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Introduce snd_sof_dsp_get_mailbox_offset (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: add runtime idle callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: docs: timers: convert docs to ReST and rename to *.rst (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use SOF defined init chip in resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Enable jack detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: reduce ifdef usage for hda (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: remove unused state variable in suspend function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: implement runtime idle for CNL/APL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use the defined stop chip in suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use the SOF defined ppcap functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: release link DMA for paused streams during suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: loader: Don't ignore SRAM block types (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: loader: Use the BAR provided by FW (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Introduce snd_sof_dsp_get_bar_index ops (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: increase default IPC timeouts (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: use timeout configured at probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: add ALH support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: use common code to send PCM_FREE IPC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: reset DMA state in prepare (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: couple host and link DMA during FE hw_free (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pci: mark last_busy value at runtime PM init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fixup HDaudio topology name with DMIC number (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: Add missing include file hdac_hda.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: Initialize hdaudio bus properly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix MSI handling (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Initialize HDA controller after i915 init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: add a parameter to disable MSI (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove duplicated include from hda.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: disallow building without CONFIG_PCI again (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: intel: extend IPC dump information (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Allow all channels in case of parallel DIN/DOUT setup (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Fix a typo in the name of a constant (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Add support for multi DIN/DOUT with TDM slots parameter (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Rename min_frame_size to slot_width (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: add dmic dapm widget and route (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: add dependency to dmic driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: Match Product Family instead of product (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Invalidate only paths reachable for a given stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: use set_get_data in process load (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: Add compatible string for imx6ull (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: keep analog power register at SND_SOC_BIAS_OFF (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Remove magic number register writes (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Revert remove superfluous set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: remove superfluous set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: depop stereo dac (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: handle concurrent interrupts (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: clear interrupts by polarity flip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: move jack-detect init to i2c probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: fall back to DT prop names on error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Add component driver name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: use more of the volume range from DACs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: remove w90x900/nuc900 platform drivers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: nuc900: nuc900-audio: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add dmic dapm widget to support dmic PCM (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add for_each_xxx macro for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: remove useless check on codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: fix null pointer dereference in clean up (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sst: fix kmalloc call with wrong flags (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Fix deadlock in snd_soc_instantiate_card() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Remove erroneous soc_cleanup_card_resources() call (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use snd_soc_dai_link_component for CPU (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: move DAI pre-links initiation to snd_soc_instantiate_card (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: fix warning reported by kbuild test robot and minor issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Mark format integer literals as unsigned (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Tell codec that jack is being removed (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Change SR and WSS computation (Jaroslav Kysela) [1738610]
- [sound] ALSA: SoC: rt274: Fix internal jack assignment in set_jack callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 422 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 395 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 340 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 284 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Add offset to RX channel select (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix sun8i tx channel offset mask (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98090: remove 24-bit format support if RJ is 0 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: da7219: Fix build error without CONFIG_I2C (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Fix COMPILE_TEST build error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Implement set_tdm_slot callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: Make some symbols static (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: remove set but not used variable 'is_right_j ' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Add RT1011 amplifier driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: debug: add new debugfs entries for IPC flood test (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: Introduce SOF_IPC_GLB_TEST_MSG IPC command (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: uapi: mirror firmware changes (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: send time stamp to FW for alignment (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: bump to ABI 3.6 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: soundwire: add initial soundwire support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: add support for mux/demux component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix DSP oops definitions in FW ABI (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ipc: don't check for HIPCCTL register value (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: re-enable IPC IRQ at end of handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: read all IPC registers first (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: cnl-ipc: re-enable IPC IRQ at end of handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: cnl-ipc: move code around for clarity (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: cnl-ipc: read all IPC registers first (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Do not send cmd via SHIM register (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: add mode parameter for snd_sof_debugfs_buf_item (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ASoC: core: use component driver name as component name" (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: sai: manage identification registers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: replace fw ready bitfield with explicit bit ordering (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Baytrail: add quirk for Aegex 10 (RU2) tablet (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: fix typos of SPDX-License-Identifier (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 201 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 194 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 177 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 162 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 149 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use the defined ppcap functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: add COMPILE_TEST for PCI options (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: Add COMPILE_TEST for new machine drivers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: remove dependency on asm/platform_sst_audio.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoc: fix sound/soc/intel/skylake/slk-ssp-clk.c build error on IA64 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: use common helpers to detect CPUs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Add missing voice activation register definitions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: use component driver name as component name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Fix build error with CONFIG_GPIOLIB is not set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: fix undefined references with Baytrail-only support (Jaroslav Kysela) [1738610]
- [sound] ALSA: wcd9335: fix a incorrect use of kstrndup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-codec: fix first delay on Speaker (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-spdif: Add support for H6 SoC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-spdif: Add TX fifo bit flush quirks (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-spdif: Move quirks to the top (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: fix spelling mistake "configued" -> "configured" (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: fix integer overflow on unsigned int multiply (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: force end-of-file for debugfs trace at suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: trace: remove code duplication in sof_wait_trace_avail() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Use struct_size() in kmemdup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: Show KConfig entry (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: Use struct_size() helper (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: remove redundant assignment to pulse_len (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix the hda init chip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: fix a race, leading to IPC timeouts (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: control: correct the copy size for bytes kcontrol put (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: remove warning - initialize workqueue on open (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: clear hw_params_upon_resume flag correctly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: fix error handling with the probe workqueue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: remove snd_soc_unregister_component in case of error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: remove DSP after unregistering machine driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: fixup references at soc_cleanup_card_resources() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Force polling mode on CFL and CNL (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 119 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 64 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: lock client_mutex while removing link components (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: Restore original configuration of DAI format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qdsp6: q6core: Use struct_size() in kmemdup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Use struct_size() helper (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Use struct_size() in krealloc() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: remove unnecessary inclusion of skl.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: move card registration to the end of probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: remove unused DAPM pins (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: enable dev runtime suspend and resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Add machine driver for CX2072X on BYT/CHT platforms (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Add support for Conexant CX2072X CODEC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_asrc: Unify the supported input and output rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: fixup try_module_get()/module_put() timing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add newline for clarity (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: fix compile error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: fix compile error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: fix AMP quirk support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: fix for codec button mapping (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 4 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 3 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 1 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: Fix configuration of DAI format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: WARN() is not related to component->driver->probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: move pcm_new from snd_soc_component_driver to snd_soc_dai_driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: Remap button control-function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: enable IIR filter (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rename functions that pollute the simple_xxx namespace (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: soc-acpi: Fix machine selection order (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677-spi: Handle over reading when flipping bytes (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dpm: fixup DAI active unbalance (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic3x: Add support for high power analog output (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Add reset gpio handling (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Add regcache mask dirty (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_asrc: replace the process_option table with function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_asrc: Fix the issue about unsupported rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: add g12a tohdmitx control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: add basic codec-to-codec link support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: allow muxes to force a disconnect (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: set link name based on link node name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: set data align (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: add memory interface data align (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ak4458: rstn_control - return a non-zero on error only (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: re-introduce mutex locking (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: add soc_pcm_components_open() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: add missing cpu_dai->rate = 0 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: do cpu_dai related operation at same place (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use soc_find_component() at snd_soc_get_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add soc_component_to_node() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup soc_bind_dai_link() comment balance (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: don't use codec_dais on soc_bind_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use i on snd_soc_resume() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: request GPIO when device get probed (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ICL add Icelake chip info struct (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ICL: add Icelake SSP count (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: remove runtime PM calls during pcm open/close (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Add Cometlake PCI IDs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Add Comet Lake PCI IDs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: Reporting accurate hw_ptr for acp3x dma (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: BE dai needs prepare when pause release after resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ak4458: add return value for ak4458_probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC : cs4265 : readable register too low (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix error in verbose ipc command parsing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix race in FW boot timeout handling (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: nocodec: fix undefined reference (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-acpi: fix implicit header use of module.h/export.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Move clock operation to PM runtime (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: i2s: manage identification registers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove ops dependency on the dai id (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove reference to the dai drivers in the private data (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove reference to the current substream (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove function name debug traces (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 282 (Jaroslav Kysela) [1738610]
- [sound] ALSA: xen-front: fix unintention integer overflow on left shifts (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - PCI quirk for Medion E4254 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Apply AMD controller workaround for Raven platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix alienware headset mic (Jaroslav Kysela) [1738610]
- [sound] ALSA: Add Acer Aspire Ethos 8951G model quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi: remove redundant assignment to variable pcm_idx (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix the problem of two front mics on a ThinkCentre (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Enable internal speaker & headset mic of ASUS UX431FL (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Add quirk for HP Pavilion 15 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix overridden device-specific initialization (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fix potential endless loop at applying quirks (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Allow runtime PM for controller if component notifier is used (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Blacklist PC beep for Lenovo ThinkCentre M73/93 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Check beep whitelist before assigning in all codecs (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/ca0132 - Add new SBZ quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fixes inverted Conexant GPIO mic mute led (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Define a fallback_pin_fixup_tbl for alc269 family (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Expand pin_match function to match upcoming new tbls (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Drop unsol event handler for Intel HDMI codecs (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Add a generic reboot_notify (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Let all conexant codec enter D3 when rebooting (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/sigmatel - remove unused variable 'stac9200_core_init' (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Add quirk for HP Envy x360 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Set fifo_size for both playback and capture streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Add a quirk model for fixing Huawei Matebook X right speaker (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Add model description for Chrome headset button quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix a typo in model documentation (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Inform too slow responses (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Apply workaround for another AMD chip 1022:1487 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Remove page allocation redirection (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Workaround for crackled sound on AMD controller (1022:1457) (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Don't override global PCM hw info flag (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Add support of Zhaoxin controller (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/intel: stop probe if DMICS are detected on Skylake+ platforms (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Show the fatal CORB/RIRB error more clearly (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Add a conexant codec entry to let mute led work (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fix intermittent CORB/RIRB stall on Intel chips (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Make hdac_device device-managed (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Flush interrupts on disabling (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Allow audio component for AMD/ATI and Nvidia HDMI (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Don't report spurious jack state changes (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Optimize resume for codecs without jack detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Don't resume forcibly i915 HDMI/DP codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Fix i915 reverse port/pin mapping (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Remove duplicated define (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek: apply ALC891 headset fixup to one Dell machine (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fixed Headphone Mic can't record on Dell platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Simplify snd_hdac_refresh_widgets() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Fix widget_mutex incomplete protection (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/ca0132 - remove redundant assignment to variable 'changed' (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Change front mic location for Lenovo M710q (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek: Add quirks for several Clevo notebook barebones (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ALSA: hda/realtek - Improve the headset mic for Acer Aspire laptops" (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Add Elkhart Lake PCI ID (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: fix a mask for unsolicited event tags (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hda: fix unbalanced codec dev refcount for HDA_DEV_ASOC (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/ca0132: Use struct_size() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Use struct_size() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Update headset mode for ALC256 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: move polling_mode flag to struct hdac_bus (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: assign polling_mode after azx_bus_init (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Improve the headset mic for Acer Aspire laptops (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Force polling mode on CNL for fixing codec communication (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Enable micmute LED for Huawei laptops (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Set default power save node to 0 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Check headset type by unplug and resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: hdac: Fix codec name after machine driver is unloaded and reloaded (Jaroslav Kysela) [1738610]
- [sound] ALSA: hdac: fix memory release for SST and SOF drivers (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 371 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Add SPDX license identifier for missed files (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Add SPDX license identifier for more missed files (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 130 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 336 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 285 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 295 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 273 (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix wrong packet parameter for Alesis iO26 (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: check intermediate state of clock status and retry (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: handle error code when getting current source of clock (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: remove WARN_ON() at destruction of AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: add note for FE-8 (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: add support for MOTU 4pre (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix isoc cycle count to which rx packet is scheduled (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix error path for initialization of stream structures (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: fix to handle correct stream for PCM playback (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: fix NULL pointer dereference to unused stream structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire: fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: localize kernel APIs to start/stop each AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for bus reset handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for initialization/destruction of AMDTP streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add a kernel API to start AMDTP streams in AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add a kernel API to add AMDTP stream into AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add a kernel API to stop a couple of AMDTP streams in AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add AMDTP domain structure to handle several isoc contexts (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: more code refactoring for MOTU data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: process payload of isoc context according to packet descriptors (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: code refactoring for FF data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for MOTU data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for TASCAM data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring for DOT data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for AM824 data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass packet descriptor to data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring to process context payloads (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring to process PCM substream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use packet descriptor for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use packet descriptor for IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add list of packet descriptor (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass no syt information to data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add syt_override member for some protocols (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: operate data block counter in top level of processing for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: operate data block counter in top level of processing for IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass data block counter to data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass data block count as an argument to tracepoints event (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: obsolete ctx_data.tx.first_dbc with CIP_UNALIGHED_DBC flag (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for local variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for post operation to data block counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for error path of parser for CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix different data block counter between probed event and transferred isochronous packet (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix initial value of data block count for IR context without CIP_DBC_IS_END_EVENT (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib/fireface: fix initial value of data block counter for IR context with CIP_NO_HEADER (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix invalid length of rx packet payload for tracepoint events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib/fireworks: fix miss detection of received MIDI messages (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix to process MIDI conformant data channel for AM824 format (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: cache next data_block_counter after probing tracepoints event for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify common tracepoints for both direction (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ALSA: firewire-lib: fix inverted node IDs for amdtp_packet events" (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: ensure to release isochronous resources in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: ensure to release isochronous resources in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: ensure to release isochronous resources in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: minor code refactoring to stop isochronous context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: rename helper functions to begin/finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for condition to stop streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: add helper function to keep isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify midi callback function (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify the count of subscriber for packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: split allocation of isochronous resources from establishment of connection (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: change the range of critical section for stream data in PCM.hw_free callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code refactoring for error path to start duplex stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: change the range of critical section for stream data in PCM.hw_free callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code refactoring for callback function to rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code rafactoring for callback functions to PCM interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix compiler warning due to returning uninitialized value (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: configure stream parameter in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: configure packet format in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: unify substreams counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: rename helper functions for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: expand stop procedure for packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: break packet streaming at bus-reset handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: start duplex streams if supported (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: set packet parameter according to current configuration (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: code refactoring for stop condition of packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: don't set XRUN in stop streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: configure stream parameters in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: configure sampling transfer frequency in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for pcm.hw_params/hw_free (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for rawmidi.open/close (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: unify substream counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code refactoring to initialize/destroy stream data (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: obsolete useless member of private structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: don't set XRUN in stop streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: configure sampling transfer frequency in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: code refactoring to keep isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: code refactoring to stop packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring to keep isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: simplify error path to begin streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: refactoring to move timing of registration for isochronous channel (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: allow PCM capture for Stanton SCS.1m (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: minor code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support allocate_resources operation in latter protocol (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support allocate_resources operation in ff400 protocol (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support allocate_resources operation in ff800 protocol (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: add protocol-specific operation to allocate isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: minor code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: update isochronous resources when starting packet streaming after bus reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for release of isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for reservation of isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for registration of isochronous channels (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: fix destruction of data for isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: Use ULL suffixes for 64-bit constants (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: refactoring to obsolete IR packet handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: refactoring to obsolete IT packet handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix inverted node IDs for amdtp_packet events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix data block counter for incoming packet without CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use 8 byte packet header for IT context to separate CIP header from CIP payload (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring to queueing packets (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: unify packet handler for IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: split helper function to generate CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: unify packet handler for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use 16 bytes IR context header to separate CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: split helper function to check incoming CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: compute pointer to payload buffer in context handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: calculate the length of packet payload in packet handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use clear name for variable of CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use IT context header to compute cycle count for scheduling packet (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: obsolete macro for header of IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add helper function to cancel context inner callback handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use union for directional parameters (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: unify tracing events to 'amdtp_packet' event (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use dynamic array for CIP header of tracing events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use the same unit for payload argument in tracing events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add data_blocks/data_block_counter parameter to in_packet/out_packet tracing events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use the same type of argument for CIP header for tracing event (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: add stream format parameters for PreSonus FireStudio (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 61 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 102 (Jaroslav Kysela) [1738610]
- [sound] ALSA: aoa: onyx: always initialize register read value (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 250 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ac97: Fix double free of ac97_codec_device (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Add SPDX license identifier - Makefile/Kconfig (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: add support for 352.8KHz and 384KHz sample rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: seq: Fix potential concurrent access to the deleted pool (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: fix lost wakeup event scenarios in snd_pcm_drain (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Be more restrictive about when a drain is allowed (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Don't allow paritial drain operations on capture streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Prevent bypasses of set_params (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Fix regression on compressed capture streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: Fix refcount_inc() on zero usage (Jaroslav Kysela) [1738610]
- [sound] ALSA: seq: Break too long mutex context in the write loop (Jaroslav Kysela) [1738610]
- [sound] ALSA: seq: fix incorrect order of dest_client/dest_ports arguments (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 372 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 345 (Jaroslav Kysela) [1738610]
- [sound] ALSA: control: Use struct_size() (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 167 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 151 (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: oss: Use struct_size() helper (Jaroslav Kysela) [1738610]

* Tue Oct 08 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.5.el8]
- [tools] selftests/powerpc: Retry on host facility unavailable (Desnes Augusto Nunes do Rosario) [1739770]
- [tools] selftests/powerpc: Do not fail with reschedule (Desnes Augusto Nunes do Rosario) [1739770]
- [tools] libperf: Warn when exceeding MAX_NR_CPUS in cpumap (Frank Ramsay) [1753332]
- [tools] perf header: Replace MAX_NR_CPUS with cpu__max_cpu() (Frank Ramsay) [1753332]
- [tools] perf machine: Replace MAX_NR_CPUS with perf_env::nr_cpus_online (Frank Ramsay) [1753332]
- [tools] perf session: Replace MAX_NR_CPUS with perf_env::nr_cpus_online (Frank Ramsay) [1753332]
- [tools] perf stat: Replace MAX_NR_CPUS with cpu__max_cpu() (Frank Ramsay) [1753332]
- [tools] perf svghelper: Replace MAX_NR_CPUS with perf_env::nr_cpus_online (Frank Ramsay) [1753332]
- [tools] perf timechart: Refactor svg_build_topology_map() (Frank Ramsay) [1753332]
- [tools] perf tools: Increase MAX_NR_CPUS and MAX_CACHES (Frank Ramsay) [1753332]
- [crypto] crypto: chelsio - count incomplete block in IV (Jonathan Toppins) [1725813]
- [crypto] crypto: chelsio - Fix softlockup with heavy I/O (Jonathan Toppins) [1725813]
- [crypto] crypto: chelsio - Fix NULL pointer dereference (Jonathan Toppins) [1725813]
- [nvme] nvme-pci: Allow PCI bus-level PM to be used if ASPM is disabled (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [pci] PCI/ASPM: Add pcie_aspm_enabled() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Fix async probe remove race (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix controller removal race with scan work (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-rdma: fix possible use-after-free in connect error flow (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix a possible deadlock when passthru commands sent to a multipath device (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-core: Fix extra device_put() call on error path (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-file: fix nvmet_file_flush() always returning an error (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-loop: Flush nvme_delete_wq when removing the port (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: Fix use-after-free bug when a port is removed (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: revalidate nvme_ns_head gendisk in nvme_validate_ns (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] Revert "nvme-pci: don't create a read hctx mapping without read queues" (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix multipath crash when ANA is deactivated (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix memory leak caused by incorrect subsystem free (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: ignore subnqn for ADATA SX6000LNP (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix NULL deref for fabrics options (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix regression upon hot device removal and insertion (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fc: fix module unloads while lports still pending (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-tcp: set the STABLE_WRITES flag when data digests are enabled (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: print a hint while rejecting NSID 0 or 0xffffffff (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-tcp: don't use sendpage for SLAB pages (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: do not select namespaces which are about to be removed (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: also check for a disabled path if there is a single sibling (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: factor out a nvme_path_is_disabled helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: export I/O characteristics attributes in Identify (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: set physical block size and optimal I/O size (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: add delete completion and submission queue to admin cmds tracer (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: fix spelling mistake "spcecific" -> "specific" (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: check for NULL return from pci_alloc_p2pmem() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: limit max_hw_sectors based on the DMA max mapping size (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: don't fall back to a 32-bit DMA mask (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: don't create a read hctx mapping without read queues (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: make nvme_dev_pm_ops static (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fcloop: resolve warnings on RCU usage and sleep warnings (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fcloop: fix inconsistent lock state warnings (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [pci] PCI: PM: Skip devices in D0 for (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [pci] PCI: PM: Avoid possible suspend-to-idle issue (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add I/O characteristics fields (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: enable to inject errors into admin commands (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: prepare for fault injection into admin commands (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: introduce target-side trace (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: print result and status in hex format (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: support for fabrics commands in host-side (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: move opcode symbol print to nvme.h (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: do not export nvme_trace_disk_name (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: properly report state change failure in nvme_reset_work (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: clean up nvme_remove_dead_ctrl a bit (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: set the errno on ctrl state change error (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: adjust irq max_vector using num_possible_cpus() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: use host managed power state for suspend (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove unnecessary zero for static var (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: introduce nvme_is_fabrics to check fabrics cmd (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fc: add message when creating new association (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove queue_count_ops for write_queues and poll_queues (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix possible io failures when removing multipathed ns (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: export get and set features (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: add transport discovery change op (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fcloop: add support for nvmet discovery_event op (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: remove blk_init_request_from_bio (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: initialize the write priority (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: Fix u32 overflow in the number of namespace list calculation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: add transport discovery change event callback support (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: don't limit DMA segement size (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix data_len to 0 for bdev-backed write_zeroes (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-tcp: fix queue mapping when queue count is limited (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: use blk-mq mapping for unmanaged irqs (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: copy MTFA field from identify controller (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: release namespace SRCU protection before performing controller ioctls (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: merge nvme_ns_ioctl into nvme_ioctl (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: remove the ifdef around nvme_nvm_ioctl (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix srcu locking on error return in nvme_get_ns_from_disk (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: Fix known effects (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Sync queues on reset (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Unblock reset_work on IO failure (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Don't disable on timeout in reset state (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Fix controller freeze wait disabling (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: validate cntlid during controller initialisation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: change locking for the per-subsystem controller list (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: trace all async notice events (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fabrics: remove unused argument (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: add known admin effects to augument admin effects log page (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: init shadow doorbell after each reset (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: mark expected switch fall-through (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: mark nvme_core_init and nvme_core_exit static (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: protect discovery change log event list iteration (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: move command size checks to the core (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: check more command sizes (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fabrics: check more command sizes (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove an unneeded variable initialization (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: unquiesce admin queue on shutdown (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: shutdown on timeout during deletion (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: set 0 capacity if namespace block size exceeds PAGE_SIZE (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-rdma: fix a NULL deref when an admin connect times out (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-file: clamp-down file namespace lba_shift (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: include <linux/scatterlist.h> (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: rename nvme_completion instances from rsp to cqe (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-rdma: remove p2p_client initialization from fast-path (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: return a specified error it subsys_alloc fails (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix discover log page when offsets are used (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: never fail double namespace enablement (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: log the error status on Identify Namespace failure (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: tidy up nvme_map_data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: add safety check for subsystem lock during nvmet_ns_changed (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: only call nvme_unmap_data for requests transferring data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove q_dmadev from nvme_queue (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: merge nvme_free_iod into nvme_unmap_data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: move the call to nvme_cleanup_cmd out of nvme_unmap_data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove nvme_init_iod (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: use a flag for polled queues (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: add a rq_integrity_vec helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: add dma_map_bvec helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: add a rq_dma_dir helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: use zero-sized array and struct_size() in kzalloc() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove unused nvme_iod member (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: avoid double errno conversions (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: avoid double dereference to convert le to cpu (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix error flow during ns enable (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add proper write zeroes setup for the multipath device (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: disable Write Zeroes for qemu controllers (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: bring Disconnect into compliance with FC-NVME spec (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add proper discard setup for the multipath device (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: remove nvme_ns_config_oncs (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: fix issues with targetport assoc_list list walking (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add get-feature to admin cmds tracer (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-loop: init nvmet_ctrl fatal_err_work when allocate (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: put ns_head ref if namespace fails allocation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: fix cdw10 buffer overrun (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: don't warn on block content change effects (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: update comment to make the code easier to read (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: convert to SPDX identifiers (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-lightnvm: convert to SPDX identifiers (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: return error from (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: avoid that deleting a controller triggers a circular locking complaint (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: introduce a helper function for controller deletion (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: unexport nvme_delete_ctrl_sync() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: check kstrtoint() return value in queue_count_set() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix indentation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [lightnvm] lightnvm: simplify geometry (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [powerpc] powerpc/tm: Fix FP/VMX unavailable exceptions inside a transaction (Gustavo Duarte) [1750653]
- [powerpc] powerpc/tm: Fix restoring FP/VMX facility incorrectly on interrupts (Gustavo Duarte) [1750653]
- [block] block: split .sysfs_lock into two locks (Ming Lei) [1697383]
- [block] block: add helper for checking if queue is registered (Ming Lei) [1697383]
- [block] blk-mq: don't hold q->sysfs_lock in blk_mq_map_swqueue (Ming Lei) [1697383]
- [block] block: don't hold q->sysfs_lock in elevator_init_mq (Ming Lei) [1697383]
- [block] block: Remove blk_mq_register_dev() (Ming Lei) [1697383]
- [x86] KVM: X86: Fix fpu state crash in kvm guest (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Don't use current->mm to check for a kthread (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Update kernel's FPU state before using for the fsave header (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Use fault_in_pages_writeable() for pre-faulting (Prarit Bhargava) [1737070]
- [mm] mm/gup: continue VM_FAULT_RETRY processing even for pre-faults (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Fault-in user stack if copy_fpstate_to_sigframe() fails (Prarit Bhargava) [1737070]
- [x86] x86/pkeys: Add PKRU value to init_fpstate (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Restore regs in copy_fpstate_to_sigframe() in order to use the fastpath (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Add a fastpath to copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Add a fastpath to __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Defer FPU state load until return to userspace (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Merge the two code paths in __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Restore from kernel memory on the 64-bit path too (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Inline copy_user_to_fpregs_zeroing() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Update xstate's PKRU value on write_pkru() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Prepare copy_fpstate_to_sigframe() for TIF_NEED_FPU_LOAD (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Always store the registers in copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/entry: Add TIF_NEED_FPU_LOAD (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Eager switch PKRU state (Prarit Bhargava) [1737070]
- [x86] x86/pkeys: Don't check if PKRU is zero before writing it (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Only write PKRU if it is different from current (Prarit Bhargava) [1737070]
- [x86] x86/pkeys: Provide *pkru() helpers (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Use a feature number instead of mask in two more helpers (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Make __raw_xsave_addr() use a feature number instead of mask (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Add an __fpregs_load_activate() internal helper (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove user_fpu_begin() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu->initialized (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Don't save fxregs for ia32 frames in copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu->initialized usage in copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Always init the state in fpu__clear() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove preempt_disable() in fpu__clear() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu__restore() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu->initialized usage in __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [x86] x86/entry: Remove unneeded need_resched() loop (Prarit Bhargava) [1737070]
- [x86] x86/uaccess: Introduce user_access_{save, restore}() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Fix i486 + no387 boot crash by only saving FPU registers on context switch if there is an FPU (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove second definition of fpu in __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [net] udp: correct reuseport selection with connected sockets (Paolo Abeni) [1665807]
- [net] udp6: add missing rehash callback to udplite (Paolo Abeni) [1665807]
- [net] udp: add missing rehash callback to udplite (Paolo Abeni) [1665807]
- [net] udp6: prefer listeners bound to an address (Paolo Abeni) [1665807]
- [net] udp: prefer listeners bound to an address (Paolo Abeni) [1665807]
- [net] sched: fix race between deactivation and dequeue for NOLOCK qdisc (Davide Caratti) [1744397]
- [net] check extack._msg before print (Ivan Vecera) [1751279]
- [net] report invalid mtu value via netlink extack (Ivan Vecera) [1751279]
- [net] report min and max mtu network device settings (Ivan Vecera) [1751279]
- [net] failover: change mtu has RTNL (Ivan Vecera) [1751279]
- [net] neigh: fix multiple neigh timer scheduling (Lorenzo Bianconi) [1730632]
- [net] virtchnl: fix 'Unknown bps' in dmesg for 2.5Gb/5Gb speeds (Ivan Vecera) [1748437]
- [net] Add a define for LLDP ethertype (Ivan Vecera) [1748428]
- [net] devlink: Add support for direct reporter health state update (Petr Oros) [1746363]
- [netdrv] Add IANA_VXLAN_UDP_PORT definition to vxlan header file (Ivan Vecera) [1731347]
- [netdrv] Move the definition of the default Geneve udp port to public header file (Ivan Vecera) [1731347]
- [net] openvswitch: Add a new action check_pkt_len (Numan Siddique) [1700733]

* Thu Oct 03 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.4.el8]
- [pci] PCI: Add pci_dev_id() helper (Myron Stowe) [1735874]
- [netdrv] ibmvnic: Warn unknown speed message only when carrier is present (Steve Best) [1749873]
- [netdrv] net/ibmvnic: Fix missing { in __ibmvnic_reset (Steve Best) [1749873]
- [netdrv] net/ibmvnic: free reset work of removed device from queue (Steve Best) [1749873]
- [netdrv] ibmvnic: Do not process reset during or after device removal (Steve Best) [1749873]
- [cpufreq] cpufreq: intel_pstate: Show different max frequency with turbo 3 and HWP (Alexander Beregalov) [1752053]
- [char] hpet: Fix missing '=' character in the __setup() code of hpet_mmap_enable (Prarit Bhargava) [1660796]
- [hwtracing] intel_th: pci: Add support for another Lewisburg PCH (Jiri Olsa) [1714486]
- [x86] x86/entry/32: Fix ENDPROC of common_spurious (Prarit Bhargava) [1730447]
- [x86] x86/irq: Seperate unused system vectors from spurious entry again (Prarit Bhargava) [1730447]
- [vfio] vfio/type1: Handle different mdev isolation type (Tarun Gupta) [1498341]
- [vfio] vfio/type1: Add domain at(de)taching group helpers (Tarun Gupta) [1498341]
- [vfio] vfio/mdev: Add iommu related member in mdev_device (Tarun Gupta) [1498341]
- [documentation] ipmb: place it at driver-api and convert to ReST (Tony Camuso) [1752071]
- [char] ipmi_si_intf: Fix race in timer shutdown handling (Tony Camuso) [1752071]
- [char] ipmi_ssif: avoid registering duplicate ssif interface (Tony Camuso) [1752071]
- [char] ipmi: Free receive messages when in an oops (Tony Camuso) [1752071]
- [char] ipmi_si: Only schedule continuously in the thread in maintenance mode (Tony Camuso) [1752071]
- [char] ipmi_si: Remove ipmi_ from the device attr names (Tony Camuso) [1752071]
- [char] ipmi_si: Convert device attr permissions to octal (Tony Camuso) [1752071]
- [char] ipmi_si: Rework some include files (Tony Camuso) [1752071]
- [char] ipmi_si: Convert timespec64 to timespec (Tony Camuso) [1752071]
- [char] Fix uninitialized variable in ipmb_dev_int.c (Tony Camuso) [1752071]
- [char] fix platform_no_drv_owner.cocci warnings (Tony Camuso) [1752071]
- [char] ipmi: ipmb: don't allocate i2c_client on stack (Tony Camuso) [1752071]
- [char] ipmi: ipmb: Fix build error while CONFIG_I2C is set to m (Tony Camuso) [1752071]
- [char] Add support for IPMB driver (Tony Camuso) [1752071]
- [char] drivers: ipmi: Drop device reference (Tony Camuso) [1752071]
- [char] ipmi_ssif: fix unexpected driver unregister warning (Tony Camuso) [1752071]
- [char] Add SPDX license identifier - Makefile/Kconfig (Tony Camuso) [1752071]
- [char] ipmi_si: use bool type for initialized variable (Tony Camuso) [1752071]
- [char] ipmi_si: fix unexpected driver unregister warning (Tony Camuso) [1752071]
- [char] ipmi: Remove warning if no slave address is present (Tony Camuso) [1752071]
- [char] ipmi:ssif: Only unregister the platform driver if it was registered (Tony Camuso) [1752071]
- [char] ipmi: Add the i2c-addr property for SSIF interfaces (Tony Camuso) [1752071]
- [char] ipmi: avoid atomic_inc in exit function (Tony Camuso) [1752071]
- [char] ipmi: Remove file from ipmi_file_private (Tony Camuso) [1752071]
- [char] ipmi_si: remove an unused variable in try_smi_init() (Tony Camuso) [1752071]
- [char] ipmi: Make ipmi_interfaces_srcu variable static (Tony Camuso) [1752071]
- [char] ipmi: Change to ktime_get_ts64() (Tony Camuso) [1752071]
- [char] ipmi: Free the address list on module cleanup (Tony Camuso) [1752071]
- [edac] EDAC, skx, i10nm: Fix source ID register offset (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Check ECC enabling status per channel (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Add Intel additional Ice-Lake support (Aristeu Rozanski) [1485543 1482412]
- [x86] x86/CPU: Add more Icelake model numbers (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx, i10nm: Make skx_common.c a pure library (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_common: Add code to recognise new compound error code (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Fix randconfig builds (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Add a driver for Intel 10nm server processors (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_edac: Delete duplicated code (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_common: Separate common code out from skx_edac (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Let EDAC core show the decoded result for debugfs (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Move debugfs node under EDAC's hierarchy (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Prepend hex formatting with '0x' (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Fix function calling order in skx_exit() (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_edac: Fix logical channel intermediate decoding (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, {i7core,sb,skx}_edac: Fix uncorrected error counting (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC: Correct DIMM capacity unit symbol (Aristeu Rozanski) [1485543 1482412]
- [x86] x86/mce: Add notifier_block forward declaration (Aristeu Rozanski) [1485543 1482412]
- [netdrv] net: thunderx: fix NULL pointer dereference in nicvf_open/nicvf_stop (Dean Nelson) [1657380]
- [netdrv] net: thunder: fix a potential NULL pointer dereference (Dean Nelson) [1657380]
- [netdrv] net: thunderx: remove link change polling code and info from nicpf (Dean Nelson) [1657380]
- [netdrv] net: thunderx: move link state polling function to VF (Dean Nelson) [1657380]
- [netdrv] net: thunderx: add mutex to protect mailbox from concurrent calls for same VF (Dean Nelson) [1657380]
- [netdrv] net: thunderx: rework xcast message structure to make it fit into 64 bit (Dean Nelson) [1657380]
- [netdrv] net: thunderx: add nicvf_send_msg_to_pf result check for set_rx_mode_task (Dean Nelson) [1657380]
- [netdrv] net: thunderx: make CFG_DONE message to run through generic send-ack sequence (Dean Nelson) [1657380]
- [netdrv] net: thunderx: replace global nicvf_rx_mode_wq work queue for all VFs to private for each of them. (Dean Nelson) [1657380]
- [netdrv] net: thunderx: set tso_hdrs pointer to NULL in nicvf_free_snd_queue (Dean Nelson) [1657380]
- [x86] perf/x86/intel/rapl: Cosmetic rename internal variables in response to multi-die/pkg support (David Arcari) [1616309]
- [x86] perf/x86/intel/uncore: Cosmetic renames in response to multi-die/pkg support (David Arcari) [1616309]
- [hwmon] hwmon/coretemp: Cosmetic: Rename internal variables to zones from packages (David Arcari) [1616309]
- [thermal] thermal/x86_pkg_temp_thermal: Cosmetic: Rename internal variables to zones from packages (David Arcari) [1616309]
- [x86] perf/x86/intel/cstate: Support multi-die/package (David Arcari) [1616309]
- [x86] perf/x86/intel/rapl: Support multi-die/package (David Arcari) [1616309]
- [x86] perf/x86/intel/uncore: Support multi-die/package (David Arcari) [1616309]
- [topology] topology: Create core_cpus and die_cpus sysfs attributes (David Arcari) [1616309]
- [topology] topology: Create package_cpus sysfs attribute (David Arcari) [1616309]
- [hwmon] hwmon/coretemp: Support multi-die/package (David Arcari) [1616309]
- [powercap] powercap/intel_rapl: Update RAPL domain name and debug messages (David Arcari) [1616309]
- [thermal] thermal/x86_pkg_temp_thermal: Support multi-die/package (David Arcari) [1616309]
- [powercap] powercap/intel_rapl: Support multi-die/package (David Arcari) [1616309]
- [powercap] powercap/intel_rapl: Simplify rapl_find_package() (David Arcari) [1616309]
- [x86] x86/topology: Define topology_logical_die_id() (David Arcari) [1616309]
- [x86] x86/topology: Define topology_die_id() (David Arcari) [1616309]
- [topology] cpu/topology: Export die_id (David Arcari) [1616309]
- [x86] x86/topology: Create topology_max_die_per_package() (David Arcari) [1616309]
- [x86] x86/topology: Add CPUID.1F multi-die/package support (David Arcari) [1616309]
- [x86] x86/smpboot: Rename match_die() to match_pkg() (David Arcari) [1616309]
- [documentation] topology: Simplify cputopology.txt formatting and wording (David Arcari) [1616309]
- [documentation] x86/topology: Fix documentation typo (David Arcari) [1616309]
- [mm] mm: remove stale comment from page struct (Rafael Aquini) [1737065]
- [mm] mm/slab.c: fix an infinite loop in leaks_show() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: update the comment about slab frozen (Rafael Aquini) [1737065]
- [mm] mm/slab.c: remove unneed check in cpuup_canceled (Rafael Aquini) [1737065]
- [mm] slub: remove useless kmem_cache_debug() before remove_full() (Rafael Aquini) [1737065]
- [mm] slab: use slab_list instead of lru (Rafael Aquini) [1737065]
- [mm] slub: use slab_list instead of lru (Rafael Aquini) [1737065]
- [mm] slob: use slab_list instead of lru (Rafael Aquini) [1737065]
- [mm] slob: respect list_head abstraction layer (Rafael Aquini) [1737065]
- [mm] slab: fix a crash by reading /proc/slab_allocators (Rafael Aquini) [1737065]
- [mm] mm: add support for kmem caches in DMA32 zone (Rafael Aquini) [1737065]
- [mm] mm, slub: make the comment of put_cpu_partial() complete (Rafael Aquini) [1737065]
- [mm] mm/slub.c: remove an unused addr argument (Rafael Aquini) [1737065]
- [mm] mm/slab.c: kmemleak no scan alien caches (Rafael Aquini) [1737065]
- [mm] mm/slub.c: freelist is ensured to be NULL when new_slab() fails (Rafael Aquini) [1737065]
- [mm] slab: alien caches must not be initialized if the allocation of the alien cache failed (Rafael Aquini) [1737065]
- [mm] include/linux/slab.h: fix sparse warning in kmalloc_type() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: record final state of slub action in deactivate_slab() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: page is always non-NULL in node_match() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: remove validation on cpu_slab in __flush_cpu_slab() (Rafael Aquini) [1737065]
- [mm] mm, slab: remove unnecessary unlikely() (Rafael Aquini) [1737065]
- [mm] mm: move obj_to_index to include/linux/slab_def.h (Rafael Aquini) [1737065]
- [mm] slab: make kmem_cache_create{_usercopy} description proper kernel-doc (Rafael Aquini) [1737065]
- [mm] slub: extend slub debug to handle multiple slabs (Rafael Aquini) [1737065]
- [mm] mm/slub.c: switch to bitmap_zalloc() (Rafael Aquini) [1737065]
- [fs] io_uring: add need_resched() check in inner poll loop (Jeff Moyer) [1706143]
- [fs] io_uring: don't enter poll loop if we have CQEs pending (Jeff Moyer) [1706143]
- [fs] io_uring: fix potential hang with polled IO (Jeff Moyer) [1706143]
- [fs] io_uring: fix an issue when IOSQE_IO_LINK is inserted into defer list (Jeff Moyer) [1706143]
- [fs] io_uring: fix manual setup of iov_iter for fixed buffers (Jeff Moyer) [1706143]
- [fs] io_uring: fix KASAN use after free in io_sq_wq_submit_work (Jeff Moyer) [1706143]
- [fs] io_uring: ensure ->list is initialized for poll commands (Jeff Moyer) [1706143]
- [fs] io_uring: track io length in async_list based on bytes (Jeff Moyer) [1706143]
- [fs] io_uring: don't use iov_iter_advance() for fixed buffers (Jeff Moyer) [1706143]
- [fs] io_uring: add a memory barrier before atomic_read (Jeff Moyer) [1706143]
- [fs] io_uring: fix counter inc/dec mismatch in async_list (Jeff Moyer) [1706143]
- [fs] io_uring: fix the sequence comparison in io_sequence_defer (Jeff Moyer) [1706143]
- [fs] io_uring: fix io_sq_thread_stop running in front of io_sq_thread (Jeff Moyer) [1706143]
- [include] io_uring: add support for recvmsg() (Jeff Moyer) [1706143]
- [include] io_uring: add support for sendmsg() (Jeff Moyer) [1706143]
- [fs] signal: remove the wrong signal_pending() check in restore_user_sigmask() (Jeff Moyer) [1706143]
- [fs] io_uring: add support for sqe links (Jeff Moyer) [1706143]
- [fs] io_uring: ensure req->file is cleared on allocation (Jeff Moyer) [1706143]
- [fs] io_uring: fix memory leak of UNIX domain socket inode (Jeff Moyer) [1706143]
- [fs] io_uring: punt short reads to async context (Jeff Moyer) [1706143]
- [fs] uio: make import_iovec()/compat_import_iovec() return bytes on success (Jeff Moyer) [1706143]
- [fs] io_uring: Fix __io_uring_register() false success (Jeff Moyer) [1706143]
- [tools] tools/io_uring: sync with liburing (Jeff Moyer) [1706143]
- [tools] tools/io_uring: fix Makefile for pthread library link (Jeff Moyer) [1706143]
- [fs] io_uring: use wait_event_interruptible for cq_wait conditional wait (Jeff Moyer) [1706143]
- [fs] io_uring: adjust smp_rmb inside io_cqring_events (Jeff Moyer) [1706143]
- [fs] io_uring: fix infinite wait in khread_park() on io_finish_async() (Jeff Moyer) [1706143]
- [fs] io_uring: remove 'ev_flags' argument (Jeff Moyer) [1706143]
- [fs] io_uring: fix failure to verify SQ_AFF cpu (Jeff Moyer) [1706143]
- [fs] io_uring: fix race condition reading SQE data (Jeff Moyer) [1706143]
- [fs] io_uring: use cpu_online() to check p->sq_thread_cpu instead of cpu_possible() (Jeff Moyer) [1706143]
- [fs] io_uring: fix shadowed variable ret return code being not checked (Jeff Moyer) [1706143]
- [fs] req->error only used for iopoll (Jeff Moyer) [1706143]
- [fs] io_uring: add support for eventfd notifications (Jeff Moyer) [1706143]
- [fs] io_uring: add support for IORING_OP_SYNC_FILE_RANGE (Jeff Moyer) [1706143]
- [fs] fs: add sync_file_range() helper (Jeff Moyer) [1706143]
- [fs] io_uring: add support for marking commands as draining (Jeff Moyer) [1706143]
- [fs] io_uring: avoid page allocation warnings (Jeff Moyer) [1706143]
- [include] iov_iter: fix iov_iter_type (Jeff Moyer) [1706143]
- [fs] block: fix handling for BIO_NO_PAGE_REF (Jeff Moyer) [1706143]
- [fs] io_uring: drop req submit reference always in async punt (Jeff Moyer) [1706143]
- [fs] io_uring: free allocated io_memory once (Jeff Moyer) [1706143]
- [fs] io_uring: fix SQPOLL cpu validation (Jeff Moyer) [1706143]
- [fs] io_uring: have submission side sqe errors post a cqe (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier after unsetting IORING_SQ_NEED_WAKEUP (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier after incrementing dropped counter (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier before reading SQ tail (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier after updating SQ head (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier before reading cq head (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier before wq_has_sleeper (Jeff Moyer) [1706143]
- [fs] io_uring: fix notes on barriers (Jeff Moyer) [1706143]
- [fs] io_uring: fix handling SQEs requesting NOWAIT (Jeff Moyer) [1706143]
- [fs] io_uring: remove 'state' argument from io_{read,write} path (Jeff Moyer) [1706143]
- [fs] io_uring: fix poll full SQ detection (Jeff Moyer) [1706143]
- [fs] io_uring: fix race condition when sq threads goes sleeping (Jeff Moyer) [1706143]
- [fs] io_uring: fix race condition reading SQ entries (Jeff Moyer) [1706143]
- [fs] io_uring: fail io_uring_register(2) on a dying io_uring instance (Jeff Moyer) [1706143]
- [fs] io_uring: fix CQ overflow condition (Jeff Moyer) [1706143]
- [fs] io_uring: fix possible deadlock between io_uring_{enter,register} (Jeff Moyer) [1706143]
- [powerpc] arch: add pidfd and io_uring syscalls everywhere (Jeff Moyer) [1706143]
- [fs] io_uring: drop io_file_put() 'file' argument (Jeff Moyer) [1706143]
- [fs] io_uring: only test SQPOLL cpu after we've verified it (Jeff Moyer) [1706143]
- [fs] io_uring: park SQPOLL thread if it's percpu (Jeff Moyer) [1706143]
- [fs] io_uring: restrict IORING_SETUP_SQPOLL to root (Jeff Moyer) [1706143]
- [tools] tools/io_uring: remove IOCQE_FLAG_CACHEHIT (Jeff Moyer) [1706143]
- [fs] io_uring: fix double free in case of fileset regitration failure (Jeff Moyer) [1706143]
- [fs] io_uring: offload write to async worker in case of -EAGAIN (Jeff Moyer) [1706143]
- [fs] io_uring: fix big-endian compat signal mask handling (Jeff Moyer) [1706143]
- [fs] block: add BIO_NO_PAGE_REF flag (Jeff Moyer) [1706143]
- [fs] iov_iter: add ITER_BVEC_FLAG_NO_REF flag (Jeff Moyer) [1706143]
- [maintainers] io_uring: mark me as the maintainer (Jeff Moyer) [1706143]
- [fs] io_uring: retry bulk slab allocs as single allocs (Jeff Moyer) [1706143]
- [fs] io_uring: fix poll races (Jeff Moyer) [1706143]
- [fs] io_uring: fix fget/fput handling (Jeff Moyer) [1706143]
- [fs] io_uring: add prepped flag (Jeff Moyer) [1706143]
- [fs] io_uring: make io_read/write return an integer (Jeff Moyer) [1706143]
- [fs] io_uring: use regular request ref counts (Jeff Moyer) [1706143]
- [fs] mm: refactor readahead defines in mm.h (Jeff Moyer) [1706143]
- [tools] io_uring: add a few test tools (Jeff Moyer) [1706143]
- [fs] io_uring: allow workqueue item to handle multiple buffered requests (Jeff Moyer) [1706143]
- [fs] io_uring: add support for IORING_OP_POLL (Jeff Moyer) [1706143]
- [fs] io_uring: add io_kiocb ref count (Jeff Moyer) [1706143]
- [fs] io_uring: add submission polling (Jeff Moyer) [1706143]
- [fs] io_uring: add file set registration (Jeff Moyer) [1706143]
- [net] net: split out functions related to registering inflight socket files (Jeff Moyer) [1706143]
- [include] io_uring: add support for pre-mapped user IO buffers (Jeff Moyer) [1706143]
- [block] block: implement bio helper to add iter bvec pages to bio (Jeff Moyer) [1706143]
- [fs] io_uring: batch io_kiocb allocation (Jeff Moyer) [1706143]
- [fs] io_uring: use fget/fput_many() for file references (Jeff Moyer) [1706143]
- [fs] fs: add fget_many() and fput_many() (Jeff Moyer) [1706143]
- [fs] io_uring: support for IO polling (Jeff Moyer) [1706143]
- [fs] io_uring: add fsync support (Jeff Moyer) [1706143]
- [include] Add io_uring IO interface (Jeff Moyer) [1706143]
- [fs] iomap: wire up the iopoll method (Jeff Moyer) [1706143]
- [fs] block: add bio_set_polled() helper (Jeff Moyer) [1706143]
- [fs] block: wire up block device iopoll method (Jeff Moyer) [1706143]
- [fs] signal: Add restore_user_sigmask() (Jeff Moyer) [1706143]
- [fs] signal: Add set_user_sigmask() (Jeff Moyer) [1706143]
- [net] iov_iter: Fix 9p virtio breakage (Benjamin Coddington) [1734762]
- [lib] iov_iter: Add I/O discard iterator (Benjamin Coddington) [1734762]
- [fs] iov_iter: Separate type from direction and use accessor functions (Benjamin Coddington) [1734762]
- [fs] iov_iter: Use accessor function (Benjamin Coddington) [1734762]

* Wed Oct 02 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.3.el8]
- [kernel] ftrace/x86: Anotate text_mutex split between ftrace_arch_code_modify_post_process() and ftrace_arch_code_modify_prepare() (Joe Lawrence) [1696461]
- [kernel] ftrace/x86: Remove possible deadlock between register_kprobe() and ftrace_run_update_code() (Joe Lawrence) [1696461]
- [kernel] Revert "livepatch: Remove reliable stacktrace check in klp_try_switch_task()" (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: push and pop dynamic debug config (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: add test skip handling (Joe Lawrence) [1696461]
- [kernel] module: Fix livepatch/ftrace module text permissions race (Joe Lawrence) [1696461]
- [kernel] kprobes: Mark ftrace mcount handler functions nokprobe (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: Add functions.sh to TEST_PROGS_EXTENDED (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: use TEST_PROGS for test scripts (Joe Lawrence) [1696461]
- [kernel] livepatch/selftests: use "$@" to preserve argument list (Joe Lawrence) [1696461]
- [kernel] livepatch: Module coming and going callbacks can proceed with all listed patches (Joe Lawrence) [1696461]
- [kernel] livepatch: Proper error handling in the shadow variables selftest (Joe Lawrence) [1696461]
- [kernel] livepatch: return -ENOMEM on ptr_id() allocation failure (Joe Lawrence) [1696461]
- [kernel] livepatch: Introduce klp_for_each_patch macro (Joe Lawrence) [1696461]
- [kernel] livepatch: core: Return EOPNOTSUPP instead of ENOSYS (Joe Lawrence) [1696461]
- [kernel] livepatch: samples: non static warnings fix (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove signal sysfs attribute (Joe Lawrence) [1696461]
- [kernel] livepatch: Send a fake signal periodically (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: introduce tests (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove ordering (stacking) of the livepatches (Joe Lawrence) [1696461]
- [kernel] livepatch: Atomic replace and cumulative patches documentation (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove Nop structures when unused (Joe Lawrence) [1696461]
- [kernel] livepatch: Add atomic replace (Joe Lawrence) [1696461]
- [kernel] livepatch: Use lists to manage patches, objects and functions (Joe Lawrence) [1696461]
- [kernel] livepatch: Simplify API by removing registration step (Joe Lawrence) [1696461]
- [kernel] livepatch: Don't block the removal of patches loaded after a forced transition (Joe Lawrence) [1696461]
- [kernel] livepatch: Consolidate klp_free functions (Joe Lawrence) [1696461]
- [kernel] livepatch: Shuffle klp_enable_patch()/klp_disable_patch() code (Joe Lawrence) [1696461]
- [kernel] livepatch: Change unsigned long old_addr -> void *old_func in struct klp_func (Joe Lawrence) [1696461]
- [kernel] livepatch: check kzalloc return values (Joe Lawrence) [1696461]
- [kernel] livepatch: Replace synchronize_sched() with synchronize_rcu() (Joe Lawrence) [1696461]
- [kernel] livepatch: Validate module/old func name length (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove reliable stacktrace check in klp_try_switch_task() (Joe Lawrence) [1696461]
- [pci] PCI/LINK: Add Kconfig option (default off) (Myron Stowe) [1748141]
- [pci] PCI/portdrv: Use shared MSI/MSI-X vector for Bandwidth Management (Myron Stowe) [1748141]
- [pci] PCI: Fix issue with "pci=disable_acs_redir" parameter being ignored (Myron Stowe) [1748141]
- [pci] PCI: Add function 1 DMA alias quirk for Marvell 9170 SATA controller (Myron Stowe) [1748141]
- [pci] PCI/LINK: Deduplicate bandwidth reports for multi-function devices (Myron Stowe) [1748141]
- [pci] PCI/LINK: Clear bandwidth notification interrupt before enabling it (Myron Stowe) [1748141]
- [pci] PCI/LINK: Supply IRQ handler so level-triggered IRQs are acked (Myron Stowe) [1748141]
- [pci] PCI/LINK: Report degraded links via link bandwidth notification (Myron Stowe) [1748141]
- [pci] PCI/portdrv: Support PCIe services on subtractive decode bridges (Myron Stowe) [1748141]
- [pci] PCI/portdrv: Use conventional Device ID table formatting (Myron Stowe) [1748141]
- [pci] PCI: Update PCIEPORTBUS Kconfig help text (Myron Stowe) [1748141]
- [pci] PCI: Clean up usage of __u32 type (Myron Stowe) [1748141]
- [pci] PCI: Move Rohm Vendor ID to generic list (Myron Stowe) [1748141]
- [pci] PCI: pciehp: Add HXT quirk for Command Completed errata (Myron Stowe) [1748141]
- [pci] PCI: Add ACS quirk for HXT SD4800 (Myron Stowe) [1748141]
- [pci] PCI: Add HXT vendor ID (Myron Stowe) [1748141]
- [pci] PCI: Use of_node_name_eq() for node name comparisons (Myron Stowe) [1748141]
- [pci] PCI: Mark expected switch fall-through (Myron Stowe) [1748141]
- [pci] PCI: ibmphp: Turn semaphores into completions or mutexes (Myron Stowe) [1748141]
- [pci] x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub (Myron Stowe) [1748141]
- [pci] PCI: Rely on config space header type, not class code (Myron Stowe) [1748141]
- [pci] PCI: Make pci_size() return real BAR size (Myron Stowe) [1748141]
- [pci] PCI/DPC: Fix print AER status in DPC event handling (Myron Stowe) [1748141]
- [pci] PCI/ASPM: Save LTR Capability for suspend/resume (Myron Stowe) [1748141]
- [pci] PCI/ASPM: Use LTR if already enabled by platform (Myron Stowe) [1748141]
- [pci] PCI: Enable SERR# forwarding for all bridges (Myron Stowe) [1748141]
- [pci] PCI/AER: Use match_string() helper to simplify the code (Myron Stowe) [1748141]
- [fs] gfs2: Use async glocks for rename (Robert S Peterson) [1737561]
- [fs] gfs2: create function gfs2_glock_update_hold_time (Robert S Peterson) [1737561]
- [fs] gfs2: separate holder for rgrps in gfs2_rename (Robert S Peterson) [1737561]
- [netdrv] net: aquantia: reapply vlan filters on up (Igor Russkikh) [1740500]
- [s390] s390/setup: Fix kernel lock down for s390 (Philipp Rudo) [1748343]
- [powerpc] kvm: ppc: book3s hv: Fix XICS-on-XIVE H_IPI when priority = 0 (David Gibson) [1725800]
- [s390] vfio-ap: fix irq registration (Thomas Huth) [1660910]
- [s390] ap: kvm: Enable PQAP/AQIC facility for the guest (Thomas Huth) [1660910]
- [s390] ap: implement PAPQ AQIC interception in kernel (Thomas Huth) [1660910]
- [s390] vfio: ap: register IOMMU VFIO notifier (Thomas Huth) [1660910]
- [s390] ap: kvm: add PQAP interception for AQIC (Thomas Huth) [1660910]
- [s390] kvm: s390: Do not leak kernel stack data in the KVM_S390_INTERRUPT ioctl (Thomas Huth) [1749503]
- [s390] kvm: s390: vsie: Return correct values for Invalid CRYCB format (Thomas Huth) [1749503]
- [s390] kvm: s390: vsie: Do not shadow CRYCB when no AP and no keys (Thomas Huth) [1749503]
- [s390] kvm: s390: change default halt poll time to 50us (Thomas Huth) [1749503]
- [s390] kvm: s390: fix typo in parameter description (Thomas Huth) [1749503]
- [s390] kvm: s390: provide kvm_arch_no_poll function (Thomas Huth) [1749503]
- [kernel] kvm: polling: add architecture backend to disable polling (Thomas Huth) [1749503]
- [s390] vtime: steal time exponential moving average (Thomas Huth) [1749503]
- [tools] kvm: selftests: fix ucall on x86 (Thomas Huth) [1730412]
- [tools] kvm: selftests: Test invalid bits in kvm_valid_regs and kvm_dirty_regs on s390x (Thomas Huth) [1730412]
- [s390] kvm: s390: Disallow invalid bits in kvm_valid_regs and kvm_dirty_regs (Thomas Huth) [1730412]
- [tools] kvm: selftests: Add a test for the KVM_S390_MEM_OP ioctl (Thomas Huth) [1730412]
- [s390] kvm: s390: Test for bad access register and size at the start of S390_MEM_OP (Thomas Huth) [1730412]
- [tools] kvm: selftests: Enable dirty_log_test on s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Implement ucall() for s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Split ucall.c into architecture specific files (Thomas Huth) [1730412]
- [tools] kvm: selftests: ucall improvements (Thomas Huth) [1730412]
- [tools] kvm: selftests: aarch64: dirty_log_test: fix unaligned memslot size (Thomas Huth) [1730412]
- [tools] kvm: selftests: Compile code with warnings enabled (Thomas Huth) [1730412]
- [tools] kvm: selftests: enable pgste option for the linker on s390 (Thomas Huth) [1730412]
- [tools] kvm: selftests: Move kvm_create_max_vcpus test to generic code (Thomas Huth) [1730412]
- [virt] kvm: s390: Do not report unusabled IDs via KVM_CAP_MAX_VCPU_ID (Thomas Huth) [1730412]
- [documentation] kvm: move KVM_CAP_NR_MEMSLOTS to common code (Thomas Huth) [1730412]
- [tools] kvm: selftests: Add the sync_regs test for s390x (Thomas Huth) [1730412]
- [s390] kvm: s390: fix memory slot handling for KVM_SET_USER_MEMORY_REGION (Thomas Huth) [1730412]
- [tools] kvm: selftests: Add processor code for s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Align memory region addresses to 1M on s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Introduce a VM_MODE_DEFAULT macro for the default bits (Thomas Huth) [1730412]
- [tools] kvm: selftests: aarch64: fix default vm mode (Thomas Huth) [1730412]
- [tools] kvm: selftests: Guard struct kvm_vcpu_events with __KVM_HAVE_VCPU_EVENTS (Thomas Huth) [1730412]
- [tools] kvm: selftests: Wrap vcpu_nested_state_get/set functions with x86 guard (Thomas Huth) [1730412]

* Fri Sep 27 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.2.el8]
- [fs] xfs: fix missing ILOCK unlock when xfs_setattr_nonsize fails due to EDQUOT (Bill O'Donnell) [1739607]
- [fs] xfs: fix reflink source file racing with directio writes (Bill O'Donnell) [1739607]
- [fs] xfs: implement cgroup aware writeback (Bill O'Donnell) [1274406]
- [fs] xfs: simplify xfs_chain_bio (Bill O'Donnell) [1274406]
- [fs] xfs: inode btree scrubber should calculate im_boffset correctly (Bill O'Donnell) [1739607]
- [fs] xfs: fix broken log reservation debugging (Bill O'Donnell) [1739607]
- [fs] xfs: don't reserve per-AG space for an internal log (Bill O'Donnell) [1739607]
- [fs] xfs: change some error-less functions to void types (Bill O'Donnell) [1739607]
- [fs] xfs: add online scrub for superblock counters (Bill O'Donnell) [1739607]
- [fs] xfs: don't parse the mtpt mount option (Bill O'Donnell) [1739607]
- [fs] xfs: scrub should check incore counters against ondisk headers (Bill O'Donnell) [1739607]
- [fs] xfs: allow scrubbers to pause background reclaim (Bill O'Donnell) [1739607]
- [fs] xfs: rename the speculative block allocation reclaim toggle functions (Bill O'Donnell) [1739607]
- [fs] xfs: track delayed allocation reservations across the filesystem (Bill O'Donnell) [1739607]
- [fs] xfs: fix broken bhold behavior in xrep_roll_ag_trans (Bill O'Donnell) [1739607]
- [fs] xfs: unlock inode when xfs_ioctl_setattr_get_trans can't get transaction (Bill O'Donnell) [1739607]
- [fs] xfs: kill the xfs_dqtrx_t typedef (Bill O'Donnell) [1739607]
- [fs] xfs: widen inode delalloc block counter to 64-bits (Bill O'Donnell) [1739607]
- [fs] xfs: widen quota block counters to 64-bit integers (Bill O'Donnell) [1739607]
- [fs] xfs: assert that we don't enter agfl freeing with a non-permanent transaction (Bill O'Donnell) [1739607]
- [fs] xfs: make tr_growdata a permanent transaction (Bill O'Donnell) [1739607]
- [fs] xfs: merge adjacent io completions of the same type (Bill O'Donnell) [1739607]
- [fs] xfs: remove unused m_data_workqueue (Bill O'Donnell) [1739607]
- [fs] xfs: implement per-inode writeback completion queues (Bill O'Donnell) [1739607]
- [fs] xfs: scrub should only cross-reference with healthy btrees (Bill O'Donnell) [1739607]
- [fs] xfs: scrub/repair should update filesystem metadata health (Bill O'Donnell) [1739607]
- [fs] xfs: hoist the already_fixed variable to the scrub context (Bill O'Donnell) [1739607]
- [fs] xfs: collapse scrub bool state flags into a single unsigned int (Bill O'Donnell) [1739607]
- [fs] xfs: refactor scrub context initialization (Bill O'Donnell) [1739607]
- [fs] xfs: report inode health via bulkstat (Bill O'Donnell) [1739607]
- [fs] xfs: report AG health via AG geometry ioctl (Bill O'Donnell) [1739607]
- [fs] xfs: report fs and rt health via geometry structure (Bill O'Donnell) [1739607]
- [fs] xfs: add a new ioctl to describe allocation group geometry (Bill O'Donnell) [1739607]
- [fs] xfs: bump XFS_IOC_FSGEOMETRY to v5 structures (Bill O'Donnell) [1739607]
- [fs] xfs: clear BAD_SUMMARY if unmounting an unhealthy filesystem (Bill O'Donnell) [1739607]
- [fs] xfs: replace the BAD_SUMMARY mount flag with the equivalent health code (Bill O'Donnell) [1739607]
- [fs] xfs: track metadata health status (Bill O'Donnell) [1739607]
- [fs] xfs,fstrim: fix to return correct minlen (Bill O'Donnell) [1739607]
- [fs] xfs: shutdown after buf release in iflush cluster abort path (Bill O'Donnell) [1739607]
- [fs] xfs: wake commit waiters on CIL abort before log item abort (Bill O'Donnell) [1739607]
- [fs] xfs: fix btree scrub checking with regards to root-in-inode (Bill O'Donnell) [1739607]
- [fs] xfs: dabtree scrub needs to range-check level (Bill O'Donnell) [1739607]
- [fs] xfs: clean up xfs_dir2_leaf_addname (Bill O'Donnell) [1739607]
- [fs] xfs: zero initialize highstale and lowstale in xfs_dir2_leaf_addname (Bill O'Donnell) [1739607]
- [fs] xfs: clean up xfs_dir2_leafn_add (Bill O'Donnell) [1739607]
- [fs] xfs: Zero initialize highstale and lowstale in xfs_dir2_leafn_add (Bill O'Donnell) [1739607]
- [fs] xfs: fix backwards endian conversion in scrub (Bill O'Donnell) [1739607]
- [fs] xfs: fix uninitialized error variables (Bill O'Donnell) [1739607]
- [fs] xfs: rework breaking of shared extents in xfs_file_iomap_begin (Bill O'Donnell) [1739607]
- [fs] xfs: don't pass iomap flags to xfs_reflink_allocate_cow (Bill O'Donnell) [1739607]
- [fs] xfs: fix uninitialized error variable (Bill O'Donnell) [1739607]
- [fs] xfs: introduce an always_cow mode (Bill O'Donnell) [1739607]
- [fs] xfs: report IOMAP_F_SHARED from xfs_file_iomap_begin_delay (Bill O'Donnell) [1739607]
- [fs] xfs: make COW fork unwritten extent conversions more robust (Bill O'Donnell) [1739607]
- [fs] xfs: merge COW handling into xfs_file_iomap_begin_delay (Bill O'Donnell) [1739607]
- [fs] xfs: also truncate holes covered by COW blocks (Bill O'Donnell) [1739607]
- [fs] xfs: don't use delalloc extents for COW on files with extsize hints (Bill O'Donnell) [1739607]
- [fs] xfs: fix SEEK_DATA for speculative COW fork preallocation (Bill O'Donnell) [1739607]
- [fs] xfs: make xfs_bmbt_to_iomap more useful (Bill O'Donnell) [1739607]
- [fs] xfs: fix xfs_buf magic number endian checks (Bill O'Donnell) [1739607]
- [fs] xfs: retry COW fork delalloc conversion when no extent was found (Bill O'Donnell) [1739607]
- [fs] xfs: remove the truncate short cut in xfs_map_blocks (Bill O'Donnell) [1739607]
- [fs] xfs: move xfs_iomap_write_allocate to xfs_aops.c (Bill O'Donnell) [1739607]
- [fs] xfs: move stat accounting to xfs_bmapi_convert_delalloc (Bill O'Donnell) [1739607]
- [fs] xfs: move transaction handling to xfs_bmapi_convert_delalloc (Bill O'Donnell) [1739607]
- [fs] xfs: split XFS_BMAPI_DELALLOC handling from xfs_bmapi_write (Bill O'Donnell) [1739607]
- [fs] xfs: factor out two helpers from xfs_bmapi_write (Bill O'Donnell) [1739607]
- [fs] xfs: simplify the xfs_bmap_btree_to_extents calling conventions (Bill O'Donnell) [1739607]
- [fs] xfs: remove the s_maxbytes checks in xfs_map_blocks (Bill O'Donnell) [1739607]
- [fs] xfs: remove the io_type field from the writeback context and ioend (Bill O'Donnell) [1739607]
- [fs] xfs: compile time offset checks for common v4/v5 metadata (Bill O'Donnell) [1739607]
- [fs] xfs: use buf ops magic to detect btree block type (Bill O'Donnell) [1739607]
- [fs] xfs: add magic numbers to dquot buffer ops (Bill O'Donnell) [1739607]
- [fs] xfs: add inode magic to inode verifier (Bill O'Donnell) [1739607]
- [fs] xfs: factor xfs_da3_blkinfo verification into common helper (Bill O'Donnell) [1739607]
- [fs] xfs: miscellaneous verifier magic value fixups (Bill O'Donnell) [1739607]
- [fs] xfs: use verifier magic field in dir2 leaf verifiers (Bill O'Donnell) [1739607]
- [fs] xfs: distinguish between bnobt and cntbt magic values (Bill O'Donnell) [1739607]
- [fs] xfs: split up allocation btree verifier (Bill O'Donnell) [1739607]
- [fs] xfs: distinguish between inobt and finobt magic values (Bill O'Donnell) [1739607]
- [fs] xfs: create a separate finobt verifier (Bill O'Donnell) [1739607]
- [fs] xfs: always check magic values in on-disk byte order (Bill O'Donnell) [1739607]
- [fs] xfs: clarify documentation for the function to reverify buffers (Bill O'Donnell) [1739607]
- [fs] xfs: cache unlinked pointers in an rhashtable (Bill O'Donnell) [1739607]
- [fs] xfs: add tracepoints for high level iunlink operations (Bill O'Donnell) [1739607]
- [fs] xfs: refactor inode update in iunlink_remove (Bill O'Donnell) [1739607]
- [fs] xfs: refactor unlinked list search and mapping to a separate function (Bill O'Donnell) [1739607]
- [fs] xfs: refactor inode unlinked pointer update functions (Bill O'Donnell) [1739607]
- [fs] xfs: strengthen AGI unlinked inode bucket pointer checks (Bill O'Donnell) [1739607]
- [fs] xfs: refactor AGI unlinked bucket updates (Bill O'Donnell) [1739607]
- [fs] xfs: add xfs_verify_agino_or_null helper (Bill O'Donnell) [1739607]
- [fs] xfs: clean up iunlink functions (Bill O'Donnell) [1739607]
- [fs] xfs: Introduce XFS_PTAG_VERIFIER_ERROR panic mask (Bill O'Donnell) [1739607]
- [fs] xfs: remove duplicated xfs_defer.h (Bill O'Donnell) [1739607]
- [fs] xfs: check attribute name validity (Bill O'Donnell) [1739607]
- [fs] xfs: check directory name validity (Bill O'Donnell) [1739607]
- [fs] xfs: fix off-by-one error in rtbitmap cross-reference (Bill O'Donnell) [1739607]
- [fs] xfs: scrub should flag dir/attr offsets that aren't mappable with xfs_dablk_t (Bill O'Donnell) [1739607]
- [fs] xfs: abort xattr scrub if fatal signals are pending (Bill O'Donnell) [1739607]
- [fs] xfs: consolidate scrub dinode mapping code into a single function (Bill O'Donnell) [1739607]
- [fs] xfs: scrub big block inode btrees correctly (Bill O'Donnell) [1739607]
- [fs] xfs: clean up the inode cluster checking in the inobt scrub (Bill O'Donnell) [1739607]
- [fs] xfs: hoist inode cluster checks out of loop (Bill O'Donnell) [1739607]
- [fs] xfs: check inobt record alignment on big block filesystems (Bill O'Donnell) [1739607]
- [fs] xfs: check the ir_startino alignment directly (Bill O'Donnell) [1739607]
- [fs] xfs: never try to scrub more than 64 inodes per inobt record (Bill O'Donnell) [1739607]
- [powerpc] powerpc: Allow flush_(inval_)dcache_range to work across ranges >4GB (Steve Best) [1744062]
- [scsi] scsi: lpfc: Fix port relogin failure due to GID_FT interaction (Dick Kennedy) [1733217]
- [rpmspec] redhat: Fix error messages during build of zfcpdump kernel (Philipp Rudo) [1745652]
- [s390] s390/protvirt: avoid memory sharing for diag 308 set/store (Philipp Rudo) [1745614]
- [infiniband] IB/hfi1: Remove extra brackets from an if (Petr Oros) [1737066]
- [documentation] docs/memory-barriers.txt: Update I/O section to be clearer about CPU vs thread (Petr Oros) [1737066]
- [documentation] docs/memory-barriers.txt: Fix style, spacing and grammar in I/O section (Petr Oros) [1737066]
- [powerpc] arch: Remove dummy mmiowb() definitions from arch code (Petr Oros) [1737066]
- [netdrv] net/ethernet/silan/sc92031: Remove stale comment about mmiowb() (Petr Oros) [1737066]
- [infiniband] i40iw: Redefine i40iw_mmiowb() to do nothing (Petr Oros) [1737066]
- [scsi] scsi/qla1280: Remove stale comment about mmiowb() (Petr Oros) [1737066]
- [netdrv] drivers: Remove explicit invocations of mmiowb() (Petr Oros) [1737066]
- [infiniband] drivers: Remove useless trailing comments from mmiowb() invocations (Petr Oros) [1737066]
- [documentation] Documentation: Kill all references to mmiowb() (Petr Oros) [1737066]
- [riscv] riscv/mmiowb: Hook up mmwiob() implementation to asm-generic code (Petr Oros) [1737066]
- [powerpc] powerpc/mmiowb: Hook up mmwiob() implementation to asm-generic code (Petr Oros) [1737066]
- [nds32] nds32/io: Remove useless definition of mmiowb() (Petr Oros) [1737066]
- [x86] x86/io: Remove useless definition of mmiowb() (Petr Oros) [1737066]
- [arm64] arm64/io: Remove useless definition of mmiowb() (Petr Oros) [1737066]
- [include] mmiowb: Hook up mmiowb helpers to spinlocks and generic I/O accessors (Petr Oros) [1737066]
- [arm64] arch: Use asm-generic header for asm/mmiowb.h (Petr Oros) [1737066]
- [kernel] asm-generic/mmiowb: Add generic implementation of mmiowb() tracking (Petr Oros) [1737066]
- [documentation] docs/memory-barriers.txt: Rewrite "KERNEL I/O BARRIER EFFECTS" section (Petr Oros) [1737066]
- [s390] s390/cpum_sf: save TOD clock base in SDBs for time conversion (Philipp Rudo) [1743504]
- [net] netns: provide pure entropy for net_hash_mix() (Paolo Abeni) [1737439] {CVE-2019-10639}
- [net] netns: get more entropy from net_hash_mix() (Paolo Abeni) [1737439] {CVE-2019-10639}
- [netdrv] net: phy: improve pause handling (Petr Oros) [1735763]
- [netdrv] net: phy: fix reading fixed phy status (Petr Oros) [1735763]
- [netdrv] net: phy: allow a PHY driver to define neither features nor get_features (Petr Oros) [1735763]
- [netdrv] net: phy: Add support for asking the PHY its abilities (Petr Oros) [1735763]
- [netdrv] net: phy: use genphy_read_abilities in genphy driver (Petr Oros) [1735763]
- [netdrv] net: phy: add genphy_read_abilities (Petr Oros) [1735763]
- [netdrv] net: phy: let genphy_c45_read_abilities also check aneg capability (Petr Oros) [1735763]
- [netdrv] net: phy: Add generic support for 2.5GBaseT and 5GBaseT (Petr Oros) [1735763]
- [netdrv] net: phy: Extract genphy_c45_pma_read_abilities from marvell10g (Petr Oros) [1735763]
- [netdrv] net: phy: Move of_set_phy_eee_broken to phy-core.c (Petr Oros) [1735763]
- [netdrv] net: phy: Mask-out non-compatible modes when setting the max-speed (Petr Oros) [1735763]
- [netdrv] net: phy: don't allow __set_phy_supported to add unsupported modes (Petr Oros) [1735763]
- [netdrv] net: phy: remove unneeded masking of PHY register read results (Petr Oros) [1735763]
- [netdrv] net: phy: probe the PHY before determining the supported features (Petr Oros) [1735763]
- [rpmspec] fix package summary and description for some kernel subpackages ("Herton R. Krzesinski") [1656863]
- [fs] mm/huge_memory: fix vmf_insert_pfn_{pmd, pud}() crash, handle unaligned addresses (Jeff Moyer) [1743159]
- [mm] mm/huge_memory.c: fix modifying of page protection by insert_pfn_pmd() (Jeff Moyer) [1743159]
- [arm64] arm64: disable improved unwind tables (Mark Langsdorf) [1684694]
- [arm64] arm64/stacktrace: Export save_stack_trace_regs() (Mark Langsdorf) [1684694]
- [fs] nfs4: flex_file: ignore synthetic uid/gid for tightly coupled DSes (Steve Dickson) [1655712]
- [include] futex: Update comments and docs about return values of arch futex code (Waiman Long) [1737058]
- [arm64] arm64: futex: Avoid copying out uninitialised stack in failed cmpxchg() (Waiman Long) [1737058]
- [arm64] arm64: futex: Bound number of LDXR/STXR loops in FUTEX_WAKE_OP (Waiman Long) [1737058]
- [kernel] locking/futex: Allow low-level atomic operations to return -EAGAIN (Waiman Long) [1737058]
- [arm64] arm64: futex: Fix FUTEX_WAKE_OP atomic ops with non-zero result value (Waiman Long) [1737058]
- [kernel] futex: Ensure that futex address is aligned in handle_futex_death() (Waiman Long) [1737058]
- [kernel] futex: Convert futex_pi_state.refcount to refcount_t (Waiman Long) [1737058]
- [kernel] sched/wake_q: Reduce reference counting for special users (Waiman Long) [1737058]
- [kernel] sched/wake_q: Add branch prediction hint to wake_q_add() cmpxchg (Waiman Long) [1737058]
- [kernel] futex: No need to check return value of debugfs_create functions (Waiman Long) [1737058]
- [kernel] futex: Handle early deadlock return correctly (Waiman Long) [1737058]
- [kernel] futex: Fix barrier comment (Waiman Long) [1737058]
- [kernel] futex: Cure exit race (Waiman Long) [1737058]
- [kernel] futex: Replace spin_is_locked() with lockdep (Waiman Long) [1737058]
- [kernel] futex: Mark expected switch fall-throughs (Waiman Long) [1737058]
- [kernel] sched/deadline: Correctly handle active 0-lag timers (Phil Auld) [1735907]
- [include] build_bug.h: add wrapper for _Static_assert (Ivan Vecera) [1735752]
- [include] build_bug.h: remove most of dummy BUILD_BUG_ON stubs for Sparse (Ivan Vecera) [1735752]
- [include] build_bug.h: remove negative-array fallback for BUILD_BUG_ON() (Ivan Vecera) [1735752]
- [mm] percpu: remove spurious lock dependency between percpu and sched (Rafael Aquini) [1731180]
- [mm] percpu: use chunk scan_hint to skip some scanning (Rafael Aquini) [1731180]
- [mm] percpu: convert chunk hints to be based on pcpu_block_md (Rafael Aquini) [1731180]
- [mm] percpu: make pcpu_block_md generic (Rafael Aquini) [1731180]
- [mm] percpu: use block scan_hint to only scan forward (Rafael Aquini) [1731180]
- [mm] percpu: remember largest area skipped during allocation (Rafael Aquini) [1731180]
- [mm] percpu: add block level scan_hint (Rafael Aquini) [1731180]
- [mm] percpu: set PCPU_BITMAP_BLOCK_SIZE to PAGE_SIZE (Rafael Aquini) [1731180]
- [mm] percpu: relegate chunks unusable when failing small allocations (Rafael Aquini) [1731180]
- [mm] percpu: manage chunks based on contig_bits instead of free_bytes (Rafael Aquini) [1731180]
- [mm] percpu: introduce helper to determine if two regions overlap (Rafael Aquini) [1731180]
- [mm] percpu: do not search past bitmap when allocating an area (Rafael Aquini) [1731180]
- [mm] percpu: update free path with correct new free region (Rafael Aquini) [1731180]
- [mm] mm/percpu: add checks for the return value of memblock_alloc*() (Rafael Aquini) [1731180]
- [mm] percpu: km: no need to consider pcpu_group_offsets[0] (Rafael Aquini) [1731180]
- [mm] percpu: use nr_groups as check condition (Rafael Aquini) [1731180]
- [mm] percpu: convert spin_lock_irq to spin_lock_irqsave. (Rafael Aquini) [1731180]
- [mm] mm: percpu: remove unnecessary unlikely() (Rafael Aquini) [1731180]
- [fs] /proc/meminfo: add percpu populated pages count (Rafael Aquini) [1731180]
- [netdrv] tg3: Use napi_alloc_frag() (Jonathan Toppins) [1724774]
- [fs] fuse: fix copy_file_range() in the writeback case (Miklos Szeredi) [1650518]
- [fs] fuse: add support for copy_file_range() (Miklos Szeredi) [1650518]

* Thu Sep 26 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.1.el8]
- [x86] perf/x86/intel: Fix spurious NMI on fixed counter (Michael Petlan) [1755110]
- [x86] perf/x86/intel: Fix race in intel_pmu_disable_event() (Michael Petlan) [1755110]
- [netdrv] drivers: tap.c: fix wrong backport causing WARN_ON_ONCE(1) in skb_flow_dissect() (Davide Caratti) [1750711]
- [virt] KVM: coalesced_mmio: add bounds checking (Bandan Das) [1746804] {CVE-2019-14821}

* Wed Sep 25 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-146.1.el8]
- [fs] gfs2: clear buf_in_tr when ending a transaction in sweep_bh_for_rgrps (Robert S Peterson) [1750939]
- [s390] kvm: s390: kvm_s390_vm_start_migration: check dirty_bitmap before using it as target for memset() (Thomas Huth) [1753260]
- [fs] cifs: fix credits leak for SMB1 oplock breaks (Leif Sahlberg) [1752243]

* Tue Sep 24 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-145.1.el8]
- Revert "[redhat] switch secureboot kernel image signing to release keys" (Phillip Lougher)
- [iommu] iommu/amd: Add support for X2APIC IOMMU interrupts (Suravee Suthikulpanit) [1734842]
- [vhost] vhost: make sure log_num < in_num (Eugenio Perez) [1750882] {CVE-2019-14835}

* Thu Sep 19 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-144.1.el8]
- [kernel] open the RHEL 8.2 development (Phillip Lougher)
- [md] Revert "[md] dm: eliminate 'split_discard_bios' flag from DM target interface" (Mike Snitzer) [1749929]
- [md] Revert "[md] dm: make sure to obey max_io_len_target_boundary" (Mike Snitzer) [1749929]
- [pci] PCI: Restore Resizable BAR size bits correctly for 1MB BARs (Myron Stowe) [1717760]
- [net] netfilter: nft_fib_netdev: Terminate rule eval if protocol=IPv6 and ipv6 module is disabled (Phil Sutter) [1743945]
- [net] netfilter: bridge: Drops IPv6 packets if IPv6 module is not loaded (Phil Sutter) [1743945]
- [drm] drm/qxl: get vga ioports (Gerd Hoffmann) [1728936]
- [drm] drm/i915: Call dma_set_max_seg_size() in i915_driver_hw_probe() (Lyude Paul) [1724363]

* Thu Sep 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-144.el8]
- [md] Revert "[md] dm: eliminate 'split_discard_bios' flag from DM target interface" (Mike Snitzer) [1749929]
- [md] Revert "[md] dm: make sure to obey max_io_len_target_boundary" (Mike Snitzer) [1749929]
- [pci] PCI: Restore Resizable BAR size bits correctly for 1MB BARs (Myron Stowe) [1717760]
- [net] netfilter: nft_fib_netdev: Terminate rule eval if protocol=IPv6 and ipv6 module is disabled (Phil Sutter) [1743945]
- [net] netfilter: bridge: Drops IPv6 packets if IPv6 module is not loaded (Phil Sutter) [1743945]
- [drm] drm/qxl: get vga ioports (Gerd Hoffmann) [1728936]
- [drm] drm/i915: Call dma_set_max_seg_size() in i915_driver_hw_probe() (Lyude Paul) [1724363]

* Mon Sep 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-143.el8]
- [net] netfilter: nft_set: fix allocation size overflow in privsize callback. (Florian Westphal) [1746338]
- [net] net: route dump netlink NLM_F_MULTI flag missing (Stefano Brivio) [1745971]
- [net] sched: pfifo_fast: fix wrong dereference in pfifo_fast_enqueue (Davide Caratti) [1745390]
- [net] sched: pfifo_fast: fix wrong dereference when qdisc is reset (Davide Caratti) [1745387]
- [scsi] scsi: vmw_pscsi: Fix use-after-free in pvscsi_queue_lck() (David Milburn) [1746597]

* Fri Sep 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-142.el8]
- [drm] drm/virtio: use virtio_max_dma_size (Gerd Hoffmann) [1739291]
- [mm] hwpoison, memory_hotplug: allow hwpoisoned pages to be offlined (Rafael Aquini) [1706088]
- [powerpc] kvm: ppc: book3s: Enable XIVE native capability only if OPAL has required functions [BZ1744884] (David Gibson) [1744884]
- [scsi] scsi: lpfc: Fix oops when fewer hdwqs than cpus (Dick Kennedy) [1745731]
- [scsi] scsi: lpfc: Limit xri count for kdump environment (Dick Kennedy) [1745731]
- [scsi] scsi: lpfc: Mitigate high memory pre-allocation by SCSI-MQ (Dick Kennedy) [1745731]
- [scsi] scsi: qla2xxx: Fix hardirq-unsafe locking (Himanshu Madhani) [1719941]
- [x86] Revert "[x86] x86/kexec/64: Prevent kexec from 5-level paging to a 4-level only kernel" (Baoquan He) [1669088]
- [x86] Revert "[x86] x86/boot: Add xloadflags bits to check for 5-level paging support" (Baoquan He) [1669088]

* Fri Aug 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-141.el8]
- [wireless] mwifiex: fix 802.11n/WPA detection (Jarod Wilson) [1714476] {CVE-2019-3846}

* Thu Aug 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-140.el8]
- [x86] x86/kdump: Reserve extra memory when SME or SEV is active (Kairui Song) [1728519]
- [scsi] scsi: qla2xxx: Fix hardlockup in abort command during driver remove (Himanshu Madhani) [1690041]
- [scsi] qla2xxx: Update driver version to 10.01.00.15.08.1-k1 (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix panic from use after free in qla2x00_async_tm_cmd (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: cleanup trace buffer initialization (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: qla2x00_alloc_fw_dump: set ha->eft (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Use mutex protection during qla2x00_sysfs_read_fw_dump() (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: move IO flush to the front of NVME rport unregistration (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix NVME cmd and LS cmd timeout race condition (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Complain loudly about reference count underflow (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix race conditions in the code for aborting SCSI commands (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Use an on-stack completion in qla24xx_control_vp() (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Change abort wait_loop from msleep to wait_event_timeout (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Set the SCSI command result before calling the command done (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: on session delete, return nvme cmd (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix kernel crash after disconnecting NVMe devices (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Remove the fcport test from qla_nvme_abort_work() (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix driver unload when FC-NVMe LUNs are connected (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Set remote port devloss timeout to 0 (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix panic in qla_dfs_tgt_counters_show (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix fw dump corruption (Himanshu Madhani) [1690041]
- [x86] kvm: disable nested virt on pre-haswell processors (Paolo Bonzini) [1739739]
- [x86] kvm: taint kernel for tech-preview when using nested virtualization (Paolo Bonzini) [1739739]
- [x86] kvm: x86: hyper-v: don't crash on KVM_GET_SUPPORTED_HV_CPUID when kvm_intel.nested is disabled (Vitaly Kuznetsov) [1746100]

* Tue Aug 27 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-139.el8]
- [char] ipmi: move message error checking to avoid deadlock (Tony Camuso) [1731388 1718699]
- [crypto] crypto: testmgr - mark crc32 checksum as FIPS allowed (Neil Horman) [1738887]
- [include] dma-mapping: use dma_get_mask in dma_addressing_limited (Don Dutile) [1738631]
- [kernel] dma-direct: correct the physical addr in dma_direct_sync_sg_for_cpu/device (Don Dutile) [1738631]
- [kernel] dma-direct: only limit the mapping size if swiotlb could be used (Don Dutile) [1738631]
- [include] dma-mapping: add a dma_addressing_limited helper (Don Dutile) [1738631]
- [kernel] dma-direct: Force unencrypted DMA under SME for certain DMA masks (Don Dutile) [1738631]
- [lib] lib/genalloc: introduce chunk owners (Don Dutile) [1738631]
- [lib] lib/genalloc: add gen_pool_dma_zalloc() for zeroed DMA allocations (Don Dutile) [1738631]
- [lib] lib/genalloc.c: fix allocation of aligned buffer from non-aligned chunk (Don Dutile) [1738631]
- [include] dma-mapping: remove dma_max_pfn (Don Dutile) [1738631]
- [mmc] mmc: core: let the dma map ops handle bouncing (Don Dutile) [1738631]
- [mmc] mmc: core: align max segment size with logical block size (Don Dutile) [1738631]
- [kernel] swiotlb: no need to check return value of debugfs_create functions (Don Dutile) [1738631]
- [xen] swiotlb: fix phys_addr_t overflow warning (Don Dutile) [1738631]
- [kernel] swiotlb: Return consistent SWIOTLB segments/nr_tbl (Don Dutile) [1738631]
- [kernel] swiotlb: Group identical cleanup in swiotlb_cleanup() (Don Dutile) [1738631]
- [kernel] swiotlb: save io_tlb_used to local variable before leaving critical section (Don Dutile) [1738631]
- [kernel] swiotlb: dump used and total slots when swiotlb buffer is full (Don Dutile) [1738631]
- [kernel] swiotlb: add checks for the return value of memblock_alloc*() (Don Dutile) [1738631]
- [kernel] swiotlb: add debugfs to track swiotlb buffer usage (Don Dutile) [1738631]
- [kernel] dma-direct: fix DMA_ATTR_NO_KERNEL_MAPPING (Don Dutile) [1738631]
- [kernel] dma-direct: handle DMA_ATTR_NO_KERNEL_MAPPING in common code (Don Dutile) [1738631]
- [kernel] dma-direct: fix DMA_ATTR_NO_KERNEL_MAPPING for remapped allocations (Don Dutile) [1738631]
- [kernel] dma-mapping: remove a pointless memset in dma_atomic_pool_init (Don Dutile) [1738631]
- [kernel] dma-mapping: fix lack of DMA address assignment in generic remap allocator (Don Dutile) [1738631]
- [kernel] dma-remap: support DMA_ATTR_NO_KERNEL_MAPPING (Don Dutile) [1738631]
- [kernel] dma-mapping: support highmem in the generic remap allocator (Don Dutile) [1738631]
- [kernel] dma-direct: handle DMA_ATTR_NON_CONSISTENT in common code (Don Dutile) [1738631]
- [kernel] dma-mapping: add a dma_alloc_need_uncached helper (Don Dutile) [1738631]
- [kernel] dma-mapping: truncate dma masks to what dma_addr_t can hold (Don Dutile) [1738631]
- [kernel] dma-remap: Avoid de-referencing NULL atomic_pool (Don Dutile) [1738631]
- [include] dma-buf: add DMA_BUF_SET_NAME ioctls (Don Dutile) [1738631]
- [include] dma-buf: give each buffer a full-fledged inode (Don Dutile) [1738631]
- [fs] new wrapper: alloc_file_pseudo() (Don Dutile) [1738631]
- [kernel] dma-direct: provide generic support for uncached kernel segments (Don Dutile) [1738631]
- [include] dma-contiguous: fix !CONFIG_DMA_CMA version of dma_{alloc, free}_contiguous() (Don Dutile) [1738631]
- [kernel] dma-contiguous: use fallback alloc_pages for single pages (Don Dutile) [1738631]
- [kernel] dma-contiguous: add dma_{alloc,free}_contiguous() helpers (Don Dutile) [1738631]
- [iommu] iommu/dma: Fix condition check in iommu_dma_unmap_sg (Don Dutile) [1738631]
- [iommu] iommu/dma: move the arm64 wrappers to common code (Don Dutile) [1738631]
- [iommu] iommu/dma-iommu.c: convert to use vm_map_pages() (Don Dutile) [1738631]
- [mm] mm: introduce new vm_map_pages() and vm_map_pages_zero() API (Don Dutile) [1738631]
- [mm] arm64/iommu: handle non-remapped addresses in ->mmap and ->get_sgtable (Don Dutile) [1738631]
- [arm64] arm64/mm: wire up CONFIG_ARCH_HAS_SET_DIRECT_MAP (Don Dutile) [1738631]
- [kernel] mm/hibernation: Make hibernation handle unmapped pages (Don Dutile) [1738631]
- [mm] page_poison: play nicely with KASAN (Don Dutile) [1738631]
- [mm] mm/vmalloc: Avoid rare case of flushing TLB with weird arguments (Don Dutile) [1738631]
- [mm] mm/vmalloc: Fix calculation of direct map addr range (Don Dutile) [1738631]
- [mm] mm/vmalloc: Add flag for freeing of special permsissions (Don Dutile) [1738631]
- [x86] x86/mm/cpa: Add set_direct_map_*() functions (Don Dutile) [1738631]
- [arm64] dma-mapping: add a kconfig symbol for arch_setup_dma_ops availability (Don Dutile) [1738631]
- [iommu] iommu/dma: Remove the flush_page callback (Don Dutile) [1738631]
- [include] iommu/dma: Cleanup dma-iommu.h (Don Dutile) [1738631]
- [dma] dmaengine: Add matching device node validation in __dma_request_channel() (Don Dutile) [1738631]
- [dma] dmaengine: dma_request_chan_by_mask() to handle deferred probing (Don Dutile) [1738631]
- [include] dma-buf: start caching of sg_table objects v2 (Don Dutile) [1738631]
- [kernel] dma-mapping: add a Kconfig symbol to indicate arch_dma_prep_coherent presence (Don Dutile) [1738631]
- [iommu] iommu/dma-iommu: Remove iommu_dma_map_msi_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/ls-scfg-msi: Don't map the MSI page in ls_scfg_msi_compose_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gic-v3-mbi: Don't map the MSI page in mbi_compose_m{b, s}i_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gicv2m: Don't map the MSI page in gicv2m_compose_msi_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gic-v3-its: Don't map the MSI page in its_irq_compose_msi_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gic-v3-its: Align PCI Multi-MSI allocation on their size (Don Dutile) [1738631]
- [iommu] iommu/dma-iommu: Split iommu_dma_map_msi_msg() in two parts (Don Dutile) [1738631]
- [iommu] iommu/dma: Remove unused variable (Don Dutile) [1738631]
- [iommu] iommu/dma: Use NUMA aware memory allocations in __iommu_dma_alloc_pages() (Don Dutile) [1738631]
- [kernel] genirq/msi: Add a new field in msi_desc to store an IOMMU cookie (Don Dutile) [1738631]
- [pci] PCI/MSI: Remove unused mask_msi_irq() and unmask_msi_irq() (Don Dutile) [1738631]
- [include] PCI/MSI: Remove unused __write_msi_msg() and write_msi_msg() (Don Dutile) [1738631]
- [include] genirq/msi: Clean up usage of __u8/__u16 types (Don Dutile) [1738631]
- [base] platform-msi: Free descriptors in platform_msi_domain_free() (Don Dutile) [1738631]
- [base] genirq/msi: Allow creation of a tree-based irqdomain for platform-msi (Don Dutile) [1738631]
- [kernel] dma-debug: only skip one stackframe entry (Don Dutile) [1738631]
- [dma] dmaengine: idma64: Move driver name to the header (Don Dutile) [1738631]
- [kernel] dma-mapping: remove an unnecessary NULL check (Don Dutile) [1738631]
- [include] dma-buf: Update [un]map documentation to match the other functions (Don Dutile) [1738631]
- [include] dma-buf: Remove leftover [un]map_atomic comments (Don Dutile) [1738631]
- [x86] x86/dma: Remove the x86_dma_fallback_dev hack (Don Dutile) [1738631]
- [kernel] dma-mapping: remove leftover NULL device support (Don Dutile) [1738631]
- [kernel] dma: select GENERIC_ALLOCATOR for DMA_REMAP (Don Dutile) [1738631]
- [crypto] crypto: ccp - Ignore unconfigured CCP device on suspend/resume (Gary Hook) [1743999]
- [md] dm snapshot: fix oversights in optional discard support (Mike Snitzer) [1744291]
- [md] dm snapshot: add optional discard support features (Mike Snitzer) [1744291]
- [md] dm snapshot: Use fine-grained locking scheme (Mike Snitzer) [1744291]
- [md] dm snapshot: Make exception tables scalable (Mike Snitzer) [1744291]
- [md] dm snapshot: Replace mutex with rw semaphore (Mike Snitzer) [1744291]
- [md] dm snapshot: Don't sleep holding the snapshot lock (Mike Snitzer) [1744291]
- [include] list_bl: Add hlist_bl_add_before/behind helpers (Mike Snitzer) [1744291]
- [powerpc] powerpc/rtas: use device model APIs and serialization during LPM (Steve Best) [1741643]
- [firmware] firmware/efi: Add NULL pointer checks in efivars API functions (Jarod Wilson) [1741949]
- [fs] ovl: fix wrong flags check in FS_IOC_FS[SG]ETXATTR ioctls (Miklos Szeredi) [1724518]
- [include] mm: page_cache_add_speculative(): refactor out some code duplication (Michael Petlan) [1738331]
- [netdrv] ibmvnic: Unmap DMA address of TX descriptor buffers after use (Steve Best) [1743155]
- [fs] NFSv4.1 don't free interrupted slot on open (Steve Dickson) [1708345]
- [fs] NFSv4.1: Avoid false retries when RPC calls are interrupted (Steve Dickson) [1708345]
- [net] ipv6: Fix return value of ipv6_mc_may_pull() for malformed packets (Stefano Brivio) [1743203]
- [net] inet: frags: re-introduce skb coalescing for local delivery (Guillaume Nault) [1719418]

* Mon Aug 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-138.el8]
- [net] xfrm: fix sa selector validation (Sabrina Dubroca) [1738871]
- [net] xfrm: Fix xfrm sel prefix length validation (Sabrina Dubroca) [1738871]
- [kernel] locking/rwsem: Prevent decrement of reader count before increment (Waiman Long) [1740338]
- [include] include/list: Backport list_cut_before() (Waiman Long) [1740338]
- [vhost] vhost: vsock: add weight support (Jason Wang) [1738494]
- [vhost] vhost_net: fix possible infinite loop (Jason Wang) [1738494]
- [vhost] vhost: introduce vhost_exceeds_weight() (Jason Wang) [1738494]
- [vhost] vhost: reject zero size iova range (Jason Wang) [1738494]
- [vhost] vhost: silence an unused-variable warning (Jason Wang) [1738494]
- [vhost] vhost: correctly check the return value of translate_desc() in log_used() (Jason Wang) [1738494]
- [vhost] vhost: return EINVAL if iovecs size does not match the message size (Jason Wang) [1738494]
- [vhost] Revert "net: vhost: lock the vqs one by one" (Jason Wang) [1738494]
- [vhost] vhost_net: switch to use mutex_trylock() in vhost_net_busy_poll() (Jason Wang) [1738494]
- [vhost] vhost: make sure used idx is seen before log in vhost_add_used_n() (Jason Wang) [1738494]
- [vhost] vhost: fix IOTLB locking (Jason Wang) [1738494]
- [netdrv] tun: wake up waitqueues after IFF_UP is set (Jason Wang) [1738494]
- [netdrv] tuntap: synchronize through tfiles array instead of tun->numqueues (Jason Wang) [1738494]
- [netdrv] tuntap: fix dividing by zero in ebpf queue selection (Jason Wang) [1738494]
- [netdrv] tun: Remove unused first parameter of tun_get_iff() (Jason Wang) [1738494]
- [netdrv] tun: Add ioctl() TUNGETDEVNETNS cmd to allow obtaining real net ns of tun device (Jason Wang) [1738494]
- [netdrv] tun: add a missing rcu_read_unlock() in error path (Jason Wang) [1738494]
- [netdrv] tun: properly test for IFF_UP (Jason Wang) [1738494]
- [netdrv] tun: remove unnecessary memory barrier (Jason Wang) [1738494]
- [netdrv] tun: fix blocking read (Jason Wang) [1738494]
- [netdrv] tun: move the call to tun_set_real_num_queues (Jason Wang) [1738494]
- [netdrv] tun: publish tfile after it's fully initialized (Jason Wang) [1738494]
- [netdrv] tun: replace get_cpu_ptr with this_cpu_ptr when bh disabled (Jason Wang) [1738494]
- [netdrv] tun: remove skb access after netif_receive_skb (Jason Wang) [1738494]
- [netdrv] tun: remove unnecessary check in tun_flow_update (Jason Wang) [1738494]
- [netdrv] tuntap: fix multiqueue rx (Jason Wang) [1738494]
- [netdrv] tun: Adjust on-stack tun_page initialization. (Jason Wang) [1738494]
- [netdrv] tuntap: free XDP dropped packets in a batch (Jason Wang) [1738494]
- [vhost] vhost_net: mitigate page reference counting during page frag refill (Jason Wang) [1738494]
- [vhost] net: vhost: remove bad code line (Jason Wang) [1738494]
- [vhost] net: vhost: add rx busy polling in tx path (Jason Wang) [1738494]
- [vhost] net: vhost: factor out busy polling logic to vhost_net_busy_poll() (Jason Wang) [1738494]
- [vhost] net: vhost: replace magic number of lock annotation (Jason Wang) [1738494]
- [vhost] net: vhost: lock the vqs one by one (Jason Wang) [1738494]
- [vhost] vhost_net: add a missing error return (Jason Wang) [1738494]
- [netdrv] net: tun: remove useless codes of tun_automq_select_queue (Jason Wang) [1738494]
- [vhost] vhost_net: batch submitting XDP buffers to underlayer sockets (Jason Wang) [1738494]
- [netdrv] tap: accept an array of XDP buffs through sendmsg() (Jason Wang) [1738494]
- [netdrv] tuntap: accept an array of XDP buffs through sendmsg() (Jason Wang) [1738494]
- [netdrv] tun: switch to new type of msg_control (Jason Wang) [1738494]
- [netdrv] tuntap: move XDP flushing out of tun_do_xdp() (Jason Wang) [1738494]
- [netdrv] tuntap: split out XDP logic (Jason Wang) [1738494]
- [netdrv] tuntap: tweak on the path of skb XDP case in tun_build_skb() (Jason Wang) [1738494]
- [netdrv] tuntap: simplify error handling in tun_build_skb() (Jason Wang) [1738494]
- [netdrv] tuntap: enable bh early during processing XDP (Jason Wang) [1738494]
- [netdrv] tuntap: switch to use XDP_PACKET_HEADROOM (Jason Wang) [1738494]
- [netdrv] net: sock: introduce SOCK_XDP (Jason Wang) [1738494]
- [vhost] vhost: correctly check the iova range when waking virtqueue (Jason Wang) [1738494]
- [vhost] vhost: switch to use new message format (Jason Wang) [1738494]
- [vhost] vhost_net: batch update used ring for datacopy TX (Jason Wang) [1738494]
- [vhost] vhost_net: rename VHOST_RX_BATCH to VHOST_NET_BATCH (Jason Wang) [1738494]
- [vhost] vhost_net: rename vhost_rx_signal_used() to vhost_net_signal_used() (Jason Wang) [1738494]
- [vhost] vhost_net: split out datacopy logic (Jason Wang) [1738494]
- [vhost] vhost_net: introduce tx_can_batch() (Jason Wang) [1738494]
- [vhost] vhost_net: introduce get_tx_bufs() (Jason Wang) [1738494]
- [vhost] vhost_net: introduce vhost_exceeds_weight() (Jason Wang) [1738494]
- [vhost] vhost_net: introduce helper to initialize tx iov iter (Jason Wang) [1738494]
- [vhost] vhost_net: drop unnecessary parameter (Jason Wang) [1738494]
- [vhost] vhost_net: Avoid rx vring kicks during busyloop (Jason Wang) [1738494]
- [vhost] vhost_net: Avoid rx queue wake-ups during busypoll (Jason Wang) [1738494]
- [vhost] vhost_net: Avoid tx vring kicks during busyloop (Jason Wang) [1738494]
- [vhost] vhost_net: Rename local variables in vhost_net_rx_peek_head_len (Jason Wang) [1738494]
- [mm] x86/mm/fault: Allow stack access below rsp (Waiman Long) [1739341]
- [mm] x86/mm: Clarify hardware vs. software "error_code" (Waiman Long) [1739341]
- [net] libceph: handle an empty authorize reply (Ilya Dryomov) [1720582]

* Thu Aug 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-137.el8]
- [drm] drm: Don't retry infinitely when receiving no data on i2c over AUX (Lyude Paul) [1672361]
- [scsi] scsi: hpsa: update revision to RH3 (Joseph Szczypek) [1739615]
- [scsi] scsi: hpsa: remove printing internal cdb on tag collision (Joseph Szczypek) [1739615]
- [scsi] scsi: hpsa: correct scsi command status issue after reset (Joseph Szczypek) [1739615]
- [scsi] hpsa: docs: fix broken doc references due to renames (Joseph Szczypek) [1739615]
- [scsi] hpsa: docs: pci: fix broken links due to conversion from pci.txt to pci.rst (Joseph Szczypek) [1739615]

* Tue Aug 20 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-136.el8]
- [drm] drm/nouveau: Only recalculate PBN/VCPI on mode/connector changes (Lyude Paul) [1734452 1734444]
- [drm] drm/nouveau: Only release VCPI slots on mode changes (Lyude Paul) [1734452 1734444]
- [infiniband] RDMA/srp: turn off 'use_imm_data' by default (Honggang Li) [1725158]
- [gpu] vga_switcheroo: Fix missing gpu_bound call at audio client registration (Lyude Paul) [1739727]
- [net] Bluetooth: Fix faulty expression for minimum encryption key size check (Gopal Tiwari) [1743076] {CVE-2019-9506}
- [net] Bluetooth: Fix regression with minimum encryption key size alignment (Gopal Tiwari) [1743076] {CVE-2019-9506}
- [net] Bluetooth: Align minimum encryption key size for LE and BR/EDR connections (Gopal Tiwari) [1743076] {CVE-2019-9506}

* Fri Aug 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-135.el8]
- [rpmspec] perf: package tips.txt (Michael Petlan) [1663816]
- [mm] mm/memblock.c: skip kmemleak for kasan_init() (Mark Langsdorf) [1722741]
- [kernel] mm/resource: Return real error codes from walk failures (Kairui Song) [1740443]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64 (Michael Petlan) [1733231]
- [tools] selftests/powerpc: Fix Makefiles for headers_install change (Steve Best) [1740127]
- [tools] selftests/powerpc: Add more version checks to alignment_handler test (Steve Best) [1740127]
- [tools] selftests/powerpc: Skip earlier in alignment_handler test (Steve Best) [1740127]
- [tools] selftests/powerpc: Consolidate copy/paste test logic (Steve Best) [1740127]
- [s390] s390/bpf: use 32-bit index for tail calls (Yauheni Kaliuta) [1719377]
- [s390] s390/bpf: fix lcgr instruction encoding (Yauheni Kaliuta) [1719377]
- [tools] selftests/bpf: fix "alu with different scalars 1" on s390 (Yauheni Kaliuta) [1719377]
- [net] bpf: fix use after free in bpf_evict_inode (Yauheni Kaliuta) [1719377]
- [arm64] bpf, arm64: remove prefetch insn in xadd mapping (Yauheni Kaliuta) [1719377]
- [scsi] scsi: lpfc: Fix crash when cpu count is 1 and null irq affinity mask (Dick Kennedy) [1720905]
- [md] md: add bitmap_abort label in md_run (Nigel Croxon) [1721944]
- [md] md-bitmap: create and destroy wb_info_pool with the change of bitmap (Nigel Croxon) [1721944]
- [md] md-bitmap: create and destroy wb_info_pool with the change of backlog (Nigel Croxon) [1721944]
- [md] md: introduce mddev_create/destroy_wb_pool for the change of member device (Nigel Croxon) [1721944]
- [md] md/raid1: fix potential data inconsistency issue with write behind device (Nigel Croxon) [1721944]
- [md] md: fix for divide error in status_resync (Nigel Croxon) [1721944]
- [md] md/raid10: read balance chooses idlest disk for SSD (Nigel Croxon) [1721944]
- [md] md: raid1-10: Unify r{1,10}bio_pool_free (Nigel Croxon) [1721944]
- [md] md: raid10: Use struct_size() in kmalloc() (Nigel Croxon) [1721944]
- [md] md/raid1: get rid of extra blank line and space (Nigel Croxon) [1721944]
- [md] md: fix spelling typo and add necessary space (Nigel Croxon) [1721944]
- [md] md: md.c: Return -ENODEV when mddev is NULL in rdev_attr_show (Nigel Croxon) [1721944]
- [md] raid5-cache: Need to do start() part job after adding journal device (Nigel Croxon) [1721944]
- [md] drivers: md: Unify common definitions of raid1 and raid10 (Nigel Croxon) [1721944]
- [kernel] userfaultfd: use RCU to free the task struct when fork fails (Andrea Arcangeli) [1718498]

* Thu Aug 15 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-134.el8]
- [efi] efi/arm: Revert "Defer persistent reservations until after paging_init()" (Mark Salter) [1699961]
- [s390] s390/ipl: Fix detection of has_secure attribute (Philipp Rudo) [1740653]
- [fs] xfs: don't crash on null attr fork xfs_bmapi_read (Bill O'Donnell) [1719094]
- [powerpc] powerpc/mm: Don't report PUDs as memory leaks when using kmemleak (Desnes Augusto Nunes do Rosario) [1716952]
- [x86] kvm: x86: introduce is_pae_paging (Vitaly Kuznetsov) [1720556]
- [s390] s390/kasan: Fix recursion loop when triggering kdump (Philipp Rudo) [1740249]
- [s390] s390/dasd: fix endless loop after read unit address configuration (Philipp Rudo) [1740251]
- [tools] selftests/powerpc: Give some tests longer to run (Steve Best) [1740420]
- [nvme] nvme-rdma: use dynamic dma mapping per command (David Milburn) [1738252]
- [nvme] nvme-rdma: remove redundant reference between ib_device and tagset (David Milburn) [1738252]
- [x86] kvm: svm/avic: Do not send AVIC doorbell to self (Janakarajan Natarajan) [1720981]
- [net] tipc: initialise addr_trial_end when setting node addresses (Jon Maloy) [1740317]
- [net] tipc: ensure head->lock is initialised (Jon Maloy) [1740317]
- [net] netfilter: nf_tables: fix oops during rule dump (Stefano Brivio) [1739734]
- [include] netfilter: nf_tables: correct NFT_LOGLEVEL_MAX value (Stefano Brivio) [1739734]
- [net] netfilter: nft_compat: do not dump private area (Stefano Brivio) [1739734]
- [net] netfilter: nf_tables: fix register ordering (Stefano Brivio) [1739734]
- [net] ipvs: defer hook registration to avoid leaks (Stefano Brivio) [1739734]
- [net] ipvs: Fix use-after-free in ip_vs_in (Stefano Brivio) [1739734]
- [net] netfilter: nf_conntrack_h323: restore boundary check correctness (Stefano Brivio) [1739734]
- [net] netfilter: fix nf_l4proto_log_invalid to log invalid packets (Stefano Brivio) [1739734]
- [net] netfilter: nf_tables: prevent shift wrap in nft_chain_parse_hook() (Stefano Brivio) [1739734]
- [net] netfilter: nft_set_rbtree: check for inactive element after flag mismatch (Stefano Brivio) [1739734]
- [net] netfilter: nft_compat: use-after-free when deleting targets (Stefano Brivio) [1739734]
- [net] netfilter: nf_tables: fix leaking object reference count (Stefano Brivio) [1739734]
- [net] ip6_gre: reload ipv6h in prepare_ip6gre_xmit_ipv6 (Stefano Brivio) [1739640]
- [net] ipv6: Unlink sibling route in case of failure (Stefano Brivio) [1739640]
- [net] ipv6: Default fib6_type to RTN_UNICAST when not set (Stefano Brivio) [1739640]
- [net] inet: frags: call inet_frags_fini() after unregister_pernet_subsys() (Stefano Brivio) [1739640]
- [net] ipv6: flowlabel: fl6_sock_lookup() must use atomic_inc_not_zero (Stefano Brivio) [1739640]
- [net] netfilter: ipset: Fix rename concurrency with listing (Stefano Brivio) [1739578]
- [net] netfilter: ipset: Fix error path in set_target_v3_checkentry() (Stefano Brivio) [1739578]
- [net] netfilter: ipset: Fix the last missing check of nla_parse_deprecated() (Stefano Brivio) [1739578]
- [net] netfilter: ipset: fix a missing check of nla_parse (Stefano Brivio) [1739578]
- [netdrv] ipvlan, l3mdev: fix broken l3s mode wrt local routes (Guillaume Nault) [1738329]
- [net] sched: use temporary variable for actions indexes (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [net] sched: cbs: Fix error path of cbs_module_init (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [net] netem: fix use after free and double free with packet corruption (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [net] netem: fix backlog accounting for corrupted GSO frames (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [netdrv] macsec: fix checksumming after decryption (Sabrina Dubroca) [1738237]
- [netdrv] macsec: fix use-after-free of skb during RX (Sabrina Dubroca) [1738237]
- [net] xfrm interface: fix memory leak on creation (Sabrina Dubroca) [1738267]
- [net] tls: fix socket wmem accounting on fallback with netem (Sabrina Dubroca) [1739260]
- [net] tls: fix poll ignoring partially copied records (Sabrina Dubroca) [1739260]
- [net] tls: make sure offload also gets the keys wiped (Sabrina Dubroca) [1739260]
- [net] tls: reject offload of TLS 1.3 (Sabrina Dubroca) [1739260]
- [net] tls: fix page double free on TX cleanup (Sabrina Dubroca) [1739260]
- [net] tls, correctly account for copied bytes with multiple sk_msgs (Sabrina Dubroca) [1739260]
- [net] tcp: fix tcp_set_congestion_control() use from bpf hook (Guillaume Nault) [1738272]
- [net] tcp: Reset bytes_acked and bytes_received when disconnecting (Guillaume Nault) [1738272]
- [net] tcp: Ensure DCTCP reacts to losses (Guillaume Nault) [1738272]
- [net] tcp: tcp_v4_err() should be more careful (Guillaume Nault) [1738272]
- [net] tcp: avoid resetting ACK timer upon receiving packet with ECN CWR flag (Guillaume Nault) [1738272]
- [net] tcp: always ACK immediately on hole repairs (Guillaume Nault) [1738272]
- [net] tcp: avoid resetting ACK timer in DCTCP (Guillaume Nault) [1738272]
- [net] tcp: mandate a one-time immediate ACK (Guillaume Nault) [1738272]
- [net] tipc: fix unitilized skb list crash (Xin Long) [1734298]
- [net] tipc: compat: allow tipc commands without arguments (Xin Long) [1738397]
- [net] sctp: factor out sctp_connect_add_peer (Xin Long) [1738393]
- [net] sctp: factor out sctp_connect_new_asoc (Xin Long) [1738393]
- [net] sctp: clean up __sctp_connect (Xin Long) [1738393]
- [net] sctp: check addr_size with sa_family_t size in __sctp_setsockopt_connectx (Xin Long) [1738393]
- [net] sctp: only copy the available addr data in sctp_transport_init (Xin Long) [1738393]
- [net] sctp: drop unneeded likely() call around IS_ERR() (Xin Long) [1738393]
- [net] sctp: fix warning "NULL check before some freeing functions is not needed" (Xin Long) [1738393]
- [net] sctp: remove rcu_read_lock from sctp_bind_addr_state (Xin Long) [1738393]
- [net] sctp: rename sp strm_interleave to ep intl_enable (Xin Long) [1738393]
- [net] sctp: rename asoc intl_enable to asoc peer.intl_capable (Xin Long) [1738393]
- [net] sctp: remove prsctp_enable from asoc (Xin Long) [1738393]
- [net] sctp: remove reconf_enable from asoc (Xin Long) [1738393]
- [net] sctp: count data bundling sack chunk for outctrlchunks (Xin Long) [1738393]
- [net] sctp: fix error handling on stream scheduler initialization (Xin Long) [1738393]
- [net] sctp: not bind the socket in sctp_connect (Xin Long) [1738393]
- [net] sctp: change to hold sk after auth shkey is created successfully (Xin Long) [1738393]
- [net] sctp: Free cookie before we memdup a new one (Xin Long) [1738393]
- [net] Fix memory leak in sctp_process_init (Xin Long) [1738393]
- [net] sctp: deduplicate identical skb_checksum_ops (Xin Long) [1738393]
- [net] sctp: Check address length before reading address family (Xin Long) [1738393]
- [net] sctp: Pass sk_buff_head explicitly to sctp_ulpq_tail_event(). (Xin Long) [1738393]
- [net] sctp: Make sctp_enqueue_event tak an skb list. (Xin Long) [1738393]
- [net] sctp: Use helper for sctp_ulpq_tail_event() when hooked up to ->enqueue_event (Xin Long) [1738393]
- [net] sctp: Always pass skbs on a list to sctp_ulpq_tail_event(). (Xin Long) [1738393]
- [net] sctp: Remove superfluous test in sctp_ulpq_reasm_drain(). (Xin Long) [1738393]
- [netdrv] ppp: Remove direct skb_queue_head list pointer access. (Xin Long) [1738393]
- [net] ipv6: fix neighbour resolution with raw socket (Stefano Brivio) [1728320]
- [net] ipv6: constify rt6_nexthop() (Stefano Brivio) [1728320]
- [net] openvswitch: fix csum updates for MPLS actions (Marcelo Leitner) [1738654]
- [net] udp_gso: Allow TX timestamp with UDP GSO (Paolo Abeni) [1738585]
- [net] bpf: udp: ipv6: Avoid running reuseport's bpf_prog from __udp6_lib_err (Paolo Abeni) [1738585]
- [net] fix ifindex collision during namespace removal (Paolo Abeni) [1738492]
- [net] rtnl: return early from rtnl_unregister_all when protocol isn't registered (Paolo Abeni) [1738492]
- [net] neigh: fix use-after-free read in pneigh_get_next (Paolo Abeni) [1738492]
- [net] socket: set sock->sk to NULL after calling proto_ops::release() (Paolo Abeni) [1738492]
- [net] socket: make bond ioctls go through compat_ifreq_ioctl() (Paolo Abeni) [1738492]
- [net] socket: fix SIOCGIFNAME in compat (Paolo Abeni) [1738492]
- [net] Revert "kill dev_ifsioc()" (Paolo Abeni) [1738492]
- [net] revert "socket: fix struct ifreq size in compat ioctl" (Paolo Abeni) [1738492]
- [net] ip6_tunnel: fix possible use-after-free on xmit (Guillaume Nault) [1737105]
- [net] genetlink: Fix a memory leak on error path (Guillaume Nault) [1737821]
- [net] netfilter: ipset: Copy the right MAC address in bitmap:ip, mac and hash:ip, mac sets (Stefano Brivio) [1723605]
- [net] netfilter: ipset: Actually allow destination MAC address for hash:ip, mac sets too (Stefano Brivio) [1723605]
- [net] igmp: fix memory leak in igmpv3_del_delrec() (Hangbin Liu) [1736816]
- [net] don't clear sock->sk early to avoid trouble in strparser (Hangbin Liu) [1736816]
- [net] ipv4/igmp: fix build error if !CONFIG_IP_MULTICAST (Hangbin Liu) [1736816]
- [net] ipv4/igmp: fix another memory leak in igmpv3_del_delrec() (Hangbin Liu) [1736816]
- [net] route: set the deleted fnhe fnhe_daddr to 0 in ip_del_fnhe to fix a race (Hangbin Liu) [1736816]
- [net] netlabel: fix out-of-bounds memory accesses (Hangbin Liu) [1736816]
- [net] ipv4: Fix memory leak in network namespace dismantle (Hangbin Liu) [1736816]
- [net] bridge: delete local fdb on device init failure (Hangbin Liu) [1736824]
- [net] bridge: stp: don't cache eth dest pointer before skb pull (Hangbin Liu) [1736824]
- [net] bridge: don't cache ether dest pointer on input (Hangbin Liu) [1736824]
- [net] bridge: mcast: fix stale ipv6 hdr pointer when handling v6 query (Hangbin Liu) [1736824]
- [net] bridge: mcast: fix stale nsrcs pointer in igmp3/mld2 report handling (Hangbin Liu) [1736824]
- [net] bridge: fix per-port af_packet sockets (Hangbin Liu) [1736824]
- [include] ip: fix ip_mc_may_pull() return value (Hangbin Liu) [1736824]
- [net] bridge: use struct_size() helper (Hangbin Liu) [1736824]
- [net] bridge: simplify ip_mc_check_igmp() and ipv6_mc_check_mld() calls (Hangbin Liu) [1736824]
- [net] net/bridge/br_multicast: remove redundant variable "err" (Hangbin Liu) [1736824]
- [x86] x86/kdump/64: Restrict kdump kernel reservation to <64TB (Baoquan He) [1669090]
- [x86] x86/kexec/64: Prevent kexec from 5-level paging to a 4-level only kernel (Baoquan He) [1669088]
- [x86] x86/boot: Add xloadflags bits to check for 5-level paging support (Baoquan He) [1669088]
- [tools] perf header: Fix wrong node write in NUMA_TOPOLOGY feature (Michael Petlan) [1722044]
- [tools] perf c2c: Fix c2c report for empty numa node (Michael Petlan) [1722044]
- [x86] kvm: svm/avic: fix off-by-one in checking host APIC ID (Janakarajan Natarajan) [1720983]

* Wed Aug 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-133.el8]
- [fs] gfs2: gfs2_walk_metadata fix (Andreas Grunbacher) [1724361]
- [netdrv] mlx4/en_netdev: allow offloading VXLAN over VLAN (Paolo Abeni) [1733532]
- [fs] xfs: always rejoin held resources during defer roll (Bill O'Donnell) [1706588]
- [bluetooth] Bluetooth: hci_uart: check for missing tty operations (Gopal Tiwari) [1734239] {CVE-2019-10207}

* Tue Aug 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-132.el8]
- [documentation] Documentation: Add swapgs description to the Spectre v1 documentation (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [documentation] Documentation: Add section about CPU vulnerabilities for Spectre (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/speculation/swapgs: Exclude ATOMs from speculation through SWAPGS (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/entry/64: Use JMP instead of JMPQ (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/speculation: Enable Spectre v1 swapgs mitigations (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/speculation: Prepare entry code for Spectre v1 swapgs mitigations (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/cpufeatures: Combine word 11 and 12 into a new scattered features word (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/cpufeatures: Carve out CQM features retrieval (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [netdrv] ibmveth: fix DMA unmap error in ibmveth_xmit_start error path (Steve Best) [1739431]
- [rpmspec] rpmspec: use make macro to do headers_install with rpm CFLAGS/LDFLAGS ("Herton R. Krzesinski") [1738659]
- [rpmspec] rpmspec: use tools_make for building tools ("Herton R. Krzesinski") [1738659]
- [tools] tools gpio: Allow overriding CFLAGS ("Herton R. Krzesinski") [1738659]
- [tools] tools thermal tmon: Allow overriding CFLAGS assignments ("Herton R. Krzesinski") [1738659]
- [tools] tools iio: Override CFLAGS assignments ("Herton R. Krzesinski") [1738659]
- [fs] NFS: Fix dentry revalidation on NFSv4 lookup (Steve Dickson) [1667774]
- [fs] pNFS: Avoid read/modify/write when it is not necessary (Benjamin Coddington) [1680649]
- [fs] pNFS: Fix potential corruption of page being written (Benjamin Coddington) [1680649]
- [fs] gfs2: Inode dirtying fix (Andreas Grunbacher) [1724361]
- [net] sunrpc: make visible processing error in bc_svc_process() ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: remove unused xpo_prep_reply_hdr callback ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: remove svc_tcp_bc_class ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: replace svc_serv->sv_bc_xprt by boolean flag ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: use-after-free in svc_process_common() ("J. Bruce Fields") [1660823] {CVE-2018-16884}

* Mon Aug 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-131.el8]
- [scsi] scsi: implement .cleanup_rq callback (Ming Lei) [1696256]
- [md] blk-mq: add callback of .cleanup_rq (Ming Lei) [1696256]
- [block] blk-mq: insert rq with DONTPREP to hctx dispatch list when requeue (Ming Lei) [1696256]
- [scsi] scsi: core: Fix race on creating sense cache (Ming Lei) [1696256]
- [block] blk-mq: balance mapping between present CPUs and queues (Ming Lei) [1733040]
- [block] blk-mq: Fix spelling in a source code comment (Ming Lei) [1733040]
- [drm] drm/i915: Don't dereference request if it may have been retired when printing (Lyude Paul) [1715997]
- [drm] drm/i915/icl: whitelist PS_(DEPTH|INVOCATION)_COUNT (Lyude Paul) [1715997]
- [drm] drm/i915: whitelist PS_(DEPTH|INVOCATION)_COUNT (Lyude Paul) [1715997]
- [drm] drm/i915: Support flags in whitlist WAs (Lyude Paul) [1715997]
- [drm] drm/i915: Disable SAMPLER_STATE prefetching on all Gen11 steppings. (Lyude Paul) [1715997]
- [drm] drm/i915/userptr: Acquire the page lock around set_page_dirty() (Lyude Paul) [1715997]
- [drm] drm/i915/perf: fix ICL perf register offsets (Lyude Paul) [1715997]
- [drm] drm/virtio: Add memory barriers for capset cache. (Lyude Paul) [1715997]
- [drm] drm/amd/display: Always allocate initial connector state state (Lyude Paul) [1715997]
- [drm] drm/vkms: Forward timer right after drm_crtc_handle_vblank (Lyude Paul) [1715997]
- [drm] drm/crc-debugfs: Also sprinkle irqrestore over early exits (Lyude Paul) [1715997]
- [drm] drm/crc-debugfs: User irqsafe spinlock in drm_crtc_add_crc_entry (Lyude Paul) [1715997]
- [drm] drm/amd/display: Increase Backlight Gain Step Size (Lyude Paul) [1715997]
- [drm] drm/amd/display: CS_TFM_1D only applied post EOTF (Lyude Paul) [1715997]
- [drm] drm/edid: Fix a missing-check bug in drm_load_edid_firmware() (Lyude Paul) [1715997]
- [drm] drm/amdkfd: Fix sdma queue map issue (Lyude Paul) [1715997]
- [drm] drm/amdkfd: Fix a potential memory leak (Lyude Paul) [1715997]
- [drm] drm/amd/display: Disable ABM before destroy ABM struct (Lyude Paul) [1715997]
- [drm] drm/amdgpu/sriov: Need to initialize the HDP_NONSURFACE_BAStE (Lyude Paul) [1715997]
- [drm] drm/amdgpu: Reserve shared fence for eviction fence (Lyude Paul) [1715997]
- [drm] drm/amd/display: Disable cursor when offscreen in negative direction (Lyude Paul) [1715997]
- [drm] drm/amd/display: Fill prescale_params->scale for RGB565 (Lyude Paul) [1715997]
- [drm] drm/virtio: set seqno for dma-fence (Lyude Paul) [1715997]
- [drivers] dma-buf: Discard old fence_excl on retrying get_fences_rcu for realloc (Lyude Paul) [1715997]
- [drivers] dma-buf: balance refcount inbalance (Lyude Paul) [1715997]
- [drm] drm/edid: parse CEA blocks embedded in DisplayID (Lyude Paul) [1715997]
- [drm] drm/nouveau/i2c: Enable i2c pads & busses during preinit (Lyude Paul) [1715997]
- [drm] drm: return -EFAULT if copy_to_user() fails (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: fix a warning due to missing dma_parms (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Honor the sg list segment size limitation (Lyude Paul) [1715997]
- [drm] drm/virtio: move drm_connector_update_edid_property() call (Lyude Paul) [1715997]
- [drm] drm/amdgpu/gfx9: use reset default for PA_SC_FIFO_SIZE (Lyude Paul) [1715997]
- [drm] drm/amdgpu: Don't skip display settings in hwmgr_resume() (Lyude Paul) [1717138 1715997]
- [drm] drm/amd/powerplay: use hardware fan control if no powerplay fan table (Lyude Paul) [1715997]
- [drm] drm/i915/ringbuffer: EMIT_INVALIDATE *before* switch context (Lyude Paul) [1715997]
- [drm] drm/i915: Skip modeset for cdclk changes if possible (Lyude Paul) [1715997]
- [drm] drm/i915: Remove redundant store of logical CDCLK state (Lyude Paul) [1715997]
- [drm] drm/i915: Save the old CDCLK atomic state (Lyude Paul) [1715997]
- [drm] drm/i915: Force 2*96 MHz cdclk on glk/cnl when audio power is enabled (Lyude Paul) [1715997]
- [drm] drm/i915: Don't clobber M/N values during fastset check (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Use the backdoor port if the HB port is not available (Lyude Paul) [1715997]
- [drm] drm: add fallback override/firmware EDID modes workaround (Lyude Paul) [1715997]
- [drm] drm/edid: abstract override/firmware EDID retrieval (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: NULL pointer dereference from vmw_cmd_dx_view_define() (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: integer underflow in vmw_cmd_dx_set_shader() leading to an invalid read (Lyude Paul) [1715997]
- [drm] drm/amdgpu: keep stolen memory on picasso (Lyude Paul) [1715997]
- [drm] drm/i915/dmc: protect against reading random memory (Lyude Paul) [1715997]
- [drm] drm/i915: Fix per-pixel alpha with CCS (Lyude Paul) [1715997]
- [drm] drm/i915/dsi: Use a fuzzy check for burst mode clock check (Lyude Paul) [1715997]
- [drm] drm/i915/sdvo: Implement proper HDMI audio support for SDVO (Lyude Paul) [1715997]
- [drm] drm/amdgpu/{uvd,vcn}: fetch ring's read_ptr after alloc (Lyude Paul) [1715997]
- [drm] drm/amd/display: Use plane->color_space for dpp if specified (Lyude Paul) [1715997]
- [drm] drm/amd/display: disable link before changing link settings (Lyude Paul) [1715997]
- [drm] Revert "drm: allow render capable master with DRM_AUTH ioctls" (Lyude Paul) [1715997]
- [drm] drm/amd: fix fb references in async update (Lyude Paul) [1715997]
- [drm] drm/i915/gvt: Initialize intel_gvt_gtt_entry in stack (Lyude Paul) [1715997]
- [drm] drm: don't block fb changes for async plane updates (Lyude Paul) [1715997]
- [drm] drm/i915/gvt: emit init breadcrumb for gvt request (Lyude Paul) [1715997]
- [drm] drm/amdgpu: fix ring test failure issue during s3 in vce 3.0 (V2) (Lyude Paul) [1715997]
- [drm] drm/amd/display: Add ASICREV_IS_PICASSO (Lyude Paul) [1715997]
- [drm] drm/amdgpu/soc15: skip reset on init (Lyude Paul) [1715997]
- [include] drm/i915: Fix I915_EXEC_RING_MASK (Lyude Paul) [1715997]
- [drm] drm/amdgpu: remove ATPX_DGPU_REQ_POWER_FOR_DISPLAYS check when hotplug-in (Lyude Paul) [1715997]
- [drm] drm/radeon: prefer lower reference dividers (Lyude Paul) [1715997]
- [drm] drm/amdgpu/psp: move psp version specific function pointers to early_init (Lyude Paul) [1715997]
- [drm] drm: add non-desktop quirks to Sensics and OSVR headsets. (Lyude Paul) [1715997]
- [drm] drm: add non-desktop quirk for Valve HMDs (Lyude Paul) [1715997]
- [drm] drm/cma-helper: Fix drm_gem_cma_free_object() (Lyude Paul) [1715997]
- [drm] drm/lease: Make sure implicit planes are leased (Lyude Paul) [1715997]
- [drm] drm: Expose "FB_DAMAGE_CLIPS" property to atomic aware user-space only (Lyude Paul) [1715997]
- [drm] drm/atomic: Wire file_priv through for property changes (Lyude Paul) [1715997]
- [drm] drm/fb-helper: generic: Call drm_client_add() after setup is done (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Don't send drm sysfs hotplug events on initial master set (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Fix compat mode shader operation (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Fix user space handle equal to zero (Lyude Paul) [1715997]
- [drm] drm: Wake up next in drm_read() chain if we are forced to putback the event (Lyude Paul) [1715997]
- [drm] drm/drv: Hold ref on parent device during drm_device lifetime (Lyude Paul) [1715997]
- [drm] drm/amd/display: Reset planes that were disabled in init_pipes (Lyude Paul) [1715997]
- [drm] drm/amd/display: Fix exception from AUX acquire failure (Lyude Paul) [1715997]
- [drm] drm: writeback: Fix leak of writeback job (Lyude Paul) [1715997]
- [drm] drm/amd/display: Set stream->mode_changed when connectors change (Lyude Paul) [1715997]
- [drm] drm/amd/display: half bandwidth for YCbCr420 during validation (Lyude Paul) [1715997]
- [drm] drm/amd/display: Re-add custom degamma support (Lyude Paul) [1715997]
- [drm] drm/amd/display: Fix Divide by 0 in memory calculations (Lyude Paul) [1715997]
- [drm] drm/amd/display: add pipe lock during stream update (Lyude Paul) [1715997]
- [drm] drm/amd/display: Reset alpha state for planes to the correct values (Lyude Paul) [1715997]
- [drm] drm/amd/display: Update ABM crtc state on non-modeset (Lyude Paul) [1715997]
- [drm] drm/amd/display: Link train only when link is DP and backend is enabled (Lyude Paul) [1715997]
- [drm] drm/amd/display: fix releasing planes when exiting odm (Lyude Paul) [1715997]
- [drm] drm/amd/display: Prevent cursor hotspot overflow for RV overlay planes (Lyude Paul) [1715997]
- [drm] drm/amd/display: use proper formula to calculate bandwidth from timing (Lyude Paul) [1715997]
- [drm] drm/amdgpu: fix old fence check in amdgpu_fence_emit (Lyude Paul) [1715997]
- [drm] drm/nouveau/bar/nv50: ensure BAR is mapped (Lyude Paul) [1715997]
- [pci] PCI: Mark AMD Stoney Radeon R7 GPU ATS as broken (Lyude Paul) [1715997]
- [kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath exit when queue is empty (Waiman Long) [1737089]
- [tools] perf vendor events power9: Added missing event descriptions (Michael Petlan) [1581405]
- [crypto] crypto: skcipher - fix crash flushing dcache in error path (David Gibson) [1724370]
- [netdrv] bnx2x: Prevent load reordering in tx completion processing (Manish Chopra) [1729599]
- [x86] x86/boot/KASLR: Always return a value from process_mem_region (Baoquan He) [1564822]
- [x86] x86/kexec: Add the ACPI NVS region to the ident map (Baoquan He) [1564822]
- [x86] x86/boot: Call get_rsdp_addr() after console_init() (Baoquan He) [1564822]
- [x86] x86/boot: Use efi_setup_data for searching RSDP on kexec-ed kernels (Baoquan He) [1564822]
- [x86] x86/kexec: Add the EFI system tables and ACPI tables to the ident map (Baoquan He) [1564822]
- [x86] x86/boot: Fix incorrect ifdeffery scope (Baoquan He) [1564822]
- [x86] x86/boot: Correct RSDP parsing with 32-bit EFI (Baoquan He) [1564822]
- [x86] x86/boot: Fix randconfig build error due to MEMORY_HOTREMOVE (Baoquan He) [1564822]
- [x86] x86/boot: Fix cmdline_find_option() prototype visibility (Baoquan He) [1564822]
- [x86] x86/boot/KASLR: Limit KASLR to extract the kernel in immovable memory only (Baoquan He) [1564822]
- [x86] x86/boot: Parse SRAT table and count immovable memory regions (Baoquan He) [1564822]
- [x86] x86/boot: Early parse RSDP and save it in boot_params (Baoquan He) [1564822]
- [x86] x86/boot: Search for RSDP in memory (Baoquan He) [1564822]
- [x86] x86/boot: Search for RSDP in the EFI tables (Baoquan He) [1564822]
- [x86] x86/boot: Add "acpi_rsdp=" early parsing (Baoquan He) [1564822]
- [x86] x86/boot: Copy kstrtoull() to boot/string.c (Baoquan He) [1564822]
- [x86] x86/boot: Use CC_SET()/CC_OUT() instead of open coding it (Baoquan He) [1564822]
- [x86] x86/boot: Build the command line parsing code unconditionally (Baoquan He) [1564822]
- [x86] x86/boot: Clear RSDP address in boot_params for broken loaders (Baoquan He) [1564822]
- [x86] x86/acpi, x86/boot: Take RSDP address from boot params if available (Baoquan He) [1564822]
- [x86] x86/boot: Mostly revert commit ae7e1238e68f2a ("Add ACPI RSDP address to setup_header") (Baoquan He) [1564822]
- [x86] x86/acpi, x86/boot: Take RSDP address for boot params if available (Baoquan He) [1564822]
- [x86] x86/boot: Add ACPI RSDP address to setup_header (Baoquan He) [1564822]
- [x86] x86/xen: Fix boot loader version reported for PVH guests (Baoquan He) [1564822]
- [x86] x86/boot: Add missing va_end() to die() (Baoquan He) [1564822]
- [x86] x86/boot/KASLR: Remove return value from handle_mem_options() (Baoquan He) [1564822]
- [x86] x86/boot/KASLR: Make local variable mem_limit static (Baoquan He) [1564822]
- [crypto] crypto: user - prevent operating on larval algorithms (Herbert Xu) [1728835]

* Thu Aug 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-130.el8]
- [scsi] scsi: mpt3sas: Use 63-bit DMA addressing on SAS35 HBA (Tomas Henzl) [1734769]
- [netdrv] bonding: Force slave speed check after link state recovery for 802.3ad (Jarod Wilson) [1732820]
- [pci] PCI: hv: Add pci_destroy_slot() in pci_devices_present_work(), if necessary (Mohammed Gamal) [1733302]
- [pci] PCI: hv: Add hv_pci_remove_slots() when we unload the driver (Mohammed Gamal) [1733302]
- [pci] PCI: hv: Fix a use-after-free bug in hv_eject_device_work() (Mohammed Gamal) [1733302]
- [pci] PCI: hv: Fix a memory leak in hv_eject_device_work() (Mohammed Gamal) [1733302]
- [nvme] nvmet: fix setting ns queue's segment boundary (Ming Lei) [1734458]

* Wed Aug 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-129.el8]
- [tools] perf script python: Remove explicit shebang from setup.py (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Remove explicit shebang from tests/attr.c (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Remove explicit shebang from Python scripts (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Use PyBytes for attr in trace-event-python (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Add trace_context extension module to sys.modules (Michael Petlan) [1663814 1664768]
- [tools] perf scripts python: exported-sql-viewer.py: Fix python3 support (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to export-to-sqlite.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to export-to-postgresql.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to exported-sql-viewer.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to intel-pt-events.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to event_analyzing_sample.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: add Python3 support to check-perf-trace.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to futex-contention.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Remove mixed indentation (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to syscall-counts-by-pid.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to syscall-counts.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to stackcollapse.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to sctop.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to powerpc-hcalls.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to net_dropmonitor.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to mem-phys-addr.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to failed-syscalls-by-pid.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to netdev-times.py (Michael Petlan) [1663814 1664768]
- [powerpc] mm_iommu: Allow pinning large regions (David Gibson) [1629531]
- [powerpc] mm_iommu: Fix potential deadlock (David Gibson) [1629531]
- [powerpc] mm/iommu: allow large IOMMU page size only for hugetlb backing (David Gibson) [1629531]
- [powerpc] mm/iommu: allow migration of cma allocated pages during mm_iommu_do_alloc (David Gibson) [1629531]
- [mm] update get_user_pages_longterm to migrate pages allocated from CMA region (David Gibson) [1629531]
- [kernel] mm/cma: add PF flag to force non cma alloc (David Gibson) [1629531]
- [net] tcp: be more careful in tcp_fragment() (Marcelo Leitner) [1732103]
- [net] tipc: initialize 'validated' field of received packets (Jon Maloy) [1730574]
- [documentation] networking: fix default_ttl typo in mpls-sysctl (Hangbin Liu) [1724882]

* Fri Aug 02 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-128.el8]
- [powerpc] powerpc/mm: Limit rma_size to 1TB when running without HV mode (Suraj Jitindar Singh) [1723297]
- [x86] kvm: nvmx: Set cached_vmcs12 and cached_shadow_vmcs12 NULL after free (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: do not use dangling shadow VMCS after guest reset (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Clear pending KVM_REQ_GET_VMCS12_PAGES when leaving nested (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Change KVM_STATE_NESTED_EVMCS to signal vmcs12 is copied from eVMCS (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Allow restore nested-state to enable eVMCS when vCPU in SMM (Paolo Bonzini) [1732096]
- [tools] kvm: nvmx: reorganize initial steps of vmx_set_nested_state (Paolo Bonzini) [1732096]
- [x86] kvm: x86: Modify struct kvm_nested_state to have explicit fields for data (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Clear nested_run_pending if setting nested state fails (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: really fix the size checks on KVM_SET_NESTED_STATE (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Set nested_run_pending in vmx_set_nested_state after checks complete (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: KVM_SET_NESTED_STATE - Tear down old EVMCS state before setting new state (Paolo Bonzini) [1732096]
- [tools] kvm: selftests: avoid type punning (Paolo Bonzini) [1732096]
- [tools] tests: kvm: Add tests for KVM_SET_NESTED_STATE (Paolo Bonzini) [1732096]
- [x86] kvm: x86/mmu: Allocate PAE root array when using SVM's 32-bit NPT (Paolo Bonzini) [1732096]
- [x86] kvm: lapic: Fix pending interrupt in IRR blocked by software disable LAPIC (Paolo Bonzini) [1732096]
- [x86] kvm: x86: Dynamically allocate user_fpu (Paolo Bonzini) [1732096]
- [x86] revert "kvm: x86: Use task structs fpu field for user" (Paolo Bonzini) [1732096]
- [x86] hyperv: suppress "pci: fatal: No config space access function found" (Raghavendra Rao) [1734265]
- [powerpc] [kvm] kvm: ppc: book3s hv: Save and restore guest visible PSSCR bits on pseries (Suraj Jitindar Singh) [1710726]
- [powerpc] pmu: Set pmcregs_in_use in paca when running as LPAR (Suraj Jitindar Singh) [1710726]
- [powerpc] [kvm] kvm: ppc: book3s hv: Always save guest pmu for guest capable of nesting (Suraj Jitindar Singh) [1710726]
- [powerpc] kvm: ppc: book3s hv: xive: fix rollback when kvmppc_xive_create fails (David Gibson) [1731900]
- [powerpc] powerpc/pseries: Fix xive=off command line (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: don't use string functions from lib/ (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc: remove CONFIG_CMDLINE #ifdef mess (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc: Move `path` variable inside DEBUG_PROM (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Generate "phandle" instead of "linux, phandle" (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Move a few remaining statics to appropriate sections (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Move prom_radix_disable to __prombss (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Remove support for OPAL v2 (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Replace __initdata with __prombss when applicable (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Make of_workarounds static (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/powernv/idle: Restore AMR/UAMOR/AMOR after idle (David Gibson) [1730183]
- [powerpc] powerpc/powernv/idle: Restore IAMR after idle (David Gibson) [1730183]

* Thu Aug 01 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-127.el8]
- [kernel] fork: report pid exhaustion correctly (Don Dutile) [1726448]
- [lib] idr: Fix idr_get_next race with idr_remove (Don Dutile) [1726448]
- [kernel] Fix failure path in alloc_pid() (Don Dutile) [1726448]
- [target] scsi: iscsi: set auth_protocol back to NULL if CHAP_A value is not supported (Maurizio Lombardi) [1733498]

* Wed Jul 31 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-126.el8]
- [infiniband] IB/umem: Add missing down_read on umem_rwsem (Alaa Hleihel) [1733188]
- [fs] gfs2: Fix rounding error in gfs2_iomap_page_prepare (Andreas Grunbacher) [1733621]
- [s390] s390/qeth: cancel cmd on early error (Philipp Rudo) [1731430]
- [s390] s390/qeth: simplify reply object handling (Philipp Rudo) [1731430]
- [s390] s390/qeth: release cmd buffer in error paths (Philipp Rudo) [1731430]
- [mm] mm: hugetlb: soft-offline: dissolve_free_huge_page() return zero on !PageHuge (Rafael Aquini) [1706088]
- [mm] mm: soft-offline: return -EBUSY if set_hwpoison_free_buddy_page() fails (Rafael Aquini) [1706088]
- [mm] mm: soft-offline: close the race against page allocation (Rafael Aquini) [1706088]
- [mm] mm: fix race on soft-offlining free huge pages (Rafael Aquini) [1706088]
- [pci] PCI: Probe bridge window attributes once at enumeration-time (Myron Stowe) [1730763]
- [mm] swap_readpage(): avoid blk_wake_io_task() if !synchronous (Ming Lei) [1724016]
- [mm] mm/page_io.c: fix polled swap page in (Ming Lei) [1724016]
- [include] fs: fix kABI for struct pipe_buf_operations (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [fs] fs: prevent page refcount overflow in pipe_buf_get (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [mm] mm: prevent get_user_pages() from overflowing page refcount (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [include] mm: add 'try_get_page()' helper function (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [include] mm: make page ref count overflow check tighter and more explicit (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [fs] fuse: call pipe_buf_release() under pipe lock (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [kernel] trace: Fix preempt_enable_no_resched() abuse (Phil Auld) [1705550]
- [kernel] sched/numa: Fix a possible divide-by-zero (Phil Auld) [1705550]
- [kernel] sched/core: Fix buffer overflow in cgroup2 property cpu.max (Phil Auld) [1705550]
- [kernel] sched/fair: Remove unused 'sd' parameter from select_idle_smt() (Phil Auld) [1705550]
- [kernel] sched/topology: Remove the ::smt_gain field from 'struct sched_domain' cleanups (Phil Auld) [1705550]
- [kernel] sched/numa: Remove unused code from update_numa_stats() (Phil Auld) [1705550]

* Tue Jul 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-125.el8]
- [s390] virtio/s390: fix race on airq_areas[] (Cornelia Huck) [1733499]
- [powerpc] powerpc: ignore __GFP_DMA/DMA32 if we left an empty ZONE_DMA/DMA32 enabled for kABI purposes (David Gibson) [1728314]
- [netdrv] bnx2x: Disable multi-cos feature. (Manish Chopra) [1679024]
- [char] tpm: tpm_ibm_vtpm: Fix unallocated banks (Jerry Snitselaar) [1726126]
- [scsi] scsi: ibmvfc: fix WARN_ON during event pool release (Steve Best) [1731133]
- [tools] perf vendor events power9: General metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power9: Branch_prediction, instruction_stats, latency, lsu_rejects, memory, prefetch & translation metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power9: Dl1_reloads, instruction_misses, l[23]_stats & pteg_reloads metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power9: Cpi_breakdown & estimated_dcache_miss_cpi metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Translaton & general metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Branch_prediction, latency, bus_stats, instruction_mix & instruction_stats metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Dl1_reload, instruction_misses, l2_stats, lsu_rejects, memory & pteg_reloads metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Cpi_breakdown & estimated_dcache_miss_cpi metrics (Michael Petlan) [1694638]
- [powerpc] powerpc/tm: Fix oops on sigreturn on systems without TM (Steve Best) [1732753]
- [net] net/mlx5e: Add ndo_set_feature for uplink representor (Alaa Hleihel) [1727708]
- [misc] VMCI: Fix integer overflow in VMCI handle arrays (Cathy Avery) [1729587]
- [tools] perf version: Fix segfault due to missing OPT_END() (Michael Petlan) [1732065]
- [sound] ALSA: hda/realtek - Headphone Mic can't record after S3 (Jaroslav Kysela) [1727676]
- [char] random: fix CRNG initialization when random.trust_cpu=1 (Oleksandr Natalenko) [1728583]
- [char] random: move rand_initialize() earlier (Oleksandr Natalenko) [1728583]
- [char] random: make CPU trust a boot parameter (Oleksandr Natalenko) [1728583]
- [char] random: add a config option to trust the CPU's hwrng (Oleksandr Natalenko) [1728583]
- [fs] blockdev: Fix livelocks on loop device (Ming Lei) [1683593]
- [block] nbd: Use set_blocksize() to set device blocksize (Ming Lei) [1683593]
- [kernel] ptrace: Fix ->ptracer_cred handling for PTRACE_TRACEME (Aristeu Rozanski) [1730959] {CVE-2019-13272}

* Mon Jul 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-124.el8]
- [include] linux/printk.h: use DYNAMIC_DEBUG_BRANCH in pr_debug_ratelimited (Mike Snitzer) [1729301]
- [include] dm: use printk ratelimiting functions (Mike Snitzer) [1729301]
- [md] dm crypt: move detailed message into debug level (Mike Snitzer) [1729301]
- [powerpc] powerpc/xive: Fix loop exit-condition in xive_find_target_in_mask() (Steve Best) [1731838]
- [s390] s390/qeth: be drop monitor friendly (Philipp Rudo) [1731200]
- [s390] s390/cpumf: Add extended counter set definitions for model 8561 and 8562 (Philipp Rudo) [1731195]
- [s390] s390/qdio: handle PENDING state for QEBSM devices (Philipp Rudo) [1731194]
- [net] net/af_iucv: build proper skbs for HiperTransport (Philipp Rudo) [1731193]
- [net] net/af_iucv: remove GFP_DMA restriction for HiperTransport (Philipp Rudo) [1731193]
- [wireless] iwlwifi: mvm: disable TX-AMSDU on older NICs (Jarod Wilson) [1728992]
- [wireless] carl9170: fix misuse of device driver API (Jarod Wilson) [1728992]
- [wireless] p54: fix crash during initialization (Jarod Wilson) [1728992]
- [wireless] p54usb: Fix race between disconnect and firmware loading (Jarod Wilson) [1728992]
- [wireless] mwifiex: Don't abort on small, spec-compliant vendor IEs (Jarod Wilson) [1728992]
- [wireless] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 507 (Jarod Wilson) [1728992]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 505 (Jarod Wilson) [1728992]
- [wireless] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 501 (Jarod Wilson) [1728992]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jarod Wilson) [1728992]
- [wireless] brcmfmac: sdio: Don't tune while the card is off (Jarod Wilson) [1728992]
- [wireless] brcmfmac: sdio: Disable auto-tuning around commands expected to fail (Jarod Wilson) [1728992]
- [mmc] mmc: core: Add sdio_retune_hold_now() and sdio_retune_release() (Jarod Wilson) [1728992]
- [mmc] mmc: core: API to temporarily disable retuning for SDIO CRC errors (Jarod Wilson) [1728992]
- [wireless] Revert "brcmfmac: disable command decode in sdio_aos" (Jarod Wilson) [1728992]
- [net] cfg80211: report measurement start TSF correctly (Jarod Wilson) [1728992]
- [net] cfg80211: fix memory leak of wiphy device name (Jarod Wilson) [1728992]
- [net] cfg80211: util: fix bit count off by one (Jarod Wilson) [1728992]
- [net] mac80211: do not start any work during reconfigure flow (Jarod Wilson) [1728992]
- [net] cfg80211: use BIT_ULL in cfg80211_parse_mbssid_data() (Jarod Wilson) [1728992]
- [net] mac80211: only warn once on chanctx_conf being NULL (Jarod Wilson) [1728992]
- [net] mac80211: drop robust management frames from unknown TA (Jarod Wilson) [1728992]
- [wireless] mwifiex: Fix heap overflow in mwifiex_uap_parse_tail_ies() (Jarod Wilson) [1728992 1721749] {CVE-2019-10126}
- [wireless] iwlwifi: mvm: change TLC config cmd sent by rs to be async (Jarod Wilson) [1728992]
- [wireless] iwlwifi: Fix double-free problems in iwl_req_fw_callback() (Jarod Wilson) [1728992]
- [wireless] iwlwifi: fix AX201 killer sku loading firmware issue (Jarod Wilson) [1728992]
- [wireless] iwlwifi: print fseq info upon fw assert (Jarod Wilson) [1728992]
- [wireless] iwlwifi: clear persistence bit according to device family (Jarod Wilson) [1728992]
- [wireless] iwlwifi: fix load in rfkill flow for unified firmware (Jarod Wilson) [1728992]
- [wireless] iwlwifi: mvm: remove d3_sram debugfs file (Jarod Wilson) [1728992]
- [wireless] mwifiex: Abort at too short BSS descriptor element (Jarod Wilson) [1728992 1714476] {CVE-2019-3846}
- [wireless] mwifiex: Fix possible buffer overflows at parsing bss descriptor (Jarod Wilson) [1728992 1714476] {CVE-2019-3846}
- [net] mac80211: free peer keys before vif down in mesh (Jarod Wilson) [1728992]
- [wireless] rtw88: Make some symbols static (Jarod Wilson) [1728992]
- [wireless] rtw88: avoid circular locking between local->iflist_mtx and rtwdev->mutex (Jarod Wilson) [1728992]
- [wireless] rtw88: fix unassigned rssi_level in rtw_sta_info (Jarod Wilson) [1728992]
- [wireless] rtw88: fix subscript above array bounds compiler warning (Jarod Wilson) [1728992]
- [net] mac80211: mesh: fix RCU warning (Jarod Wilson) [1728992]
- [net] nl80211: fix station_info pertid memory leak (Jarod Wilson) [1728992]
- [net] mac80211: Do not use stack memory with scatterlist for GMAC (Jarod Wilson) [1728992]
- [net] {nl,mac}80211: allow 4addr AP operation on crypto controlled devices (Jarod Wilson) [1728992]
- [wireless] mac80211_hwsim: mark expected switch fall-through (Jarod Wilson) [1728992]
- [net] mac80211: fix rate reporting inside cfg80211_calculate_bitrate_he() (Jarod Wilson) [1728992]
- [net] mac80211: remove set but not used variable 'old' (Jarod Wilson) [1728992]
- [net] mac80211: handle deauthentication/disassociation from TDLS peer (Jarod Wilson) [1728992]
- [net] wireless: Skip directory when generating certificates (Jarod Wilson) [1728992]
- [netdrv] i40e: Check and set the PF driver state first in i40e_ndo_set_vf_mac (Stefan Assmann) [1719538]
- [fs] cifs: fix crash in smb2_compound_op()/smb2_set_next_command() (Leif Sahlberg) [1722704]
- [firmware] efi/arm: Show SMBIOS bank/device location in CPER and GHES error logs (Robert Richter) [1721386]

* Thu Jul 25 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-123.el8]
- [x86] x86/speculation: Allow guests to use SSBD even if host does not (Waiman Long) [1728341]
- [block] block: kill BLK_MQ_F_SG_MERGE (Ming Lei) [1716595]
- [block] block: kill QUEUE_FLAG_NO_SG_MERGE (Ming Lei) [1716595]

* Wed Jul 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-122.el8]
- [x86] x86/insn-eval: Fix use-after-free access to LDT entry (Rafael Aquini) [1728561] {CVE-2019-13233}
- [arm64] arm64/mm: Correct the cache line size warning with non coherent device (Mark Salter) [1715061]
- [arm64] arm64: cacheinfo: Update cache_line_size detected from DT or PPTT (Mark Salter) [1715061]
- [base] drivers: base: cacheinfo: Add variable to record max cache line size (Mark Salter) [1715061]
- [arm64] arm64: cpufeature: Trap CTR_EL0 access only where it is necessary (Mark Salter) [1715061]
- [arm64] arm64: cpufeature: Fix handling of CTR_EL0.IDC field (Mark Salter) [1715061]
- [arm64] arm64: cpufeature: ctr: Fix cpu capability check for late CPUs (Mark Salter) [1715061]
- [arm64] arm64: cpu_errata: Remove ARM64_MISMATCHED_CACHE_LINE_SIZE (Mark Salter) [1715061]
- [fs] gfs2: Clean up freeing struct gfs2_sbd (Robert S Peterson) [1683698]
- [target] scsi: target/iblock: Fix overrun in WRITE SAME emulation (Maurizio Lombardi) [1729503]
- [x86] kvm/nvmx: fix VMCLEAR when Enlightened VMCS is in use (Vitaly Kuznetsov) [1717785]
- [x86] kvm/nvmx: don't use clean fields data on enlightened VMLAUNCH (Vitaly Kuznetsov) [1717785]
- [x86] kvm: nvmx: use correct clean fields when copying from eVMCS (Vitaly Kuznetsov) [1717785]
- [fs] NFS4: Only set creation opendata if O_CREAT (Benjamin Coddington) [1708471]
- [tools] perf test: Fix failure of 'evsel-tp-sched' test on s390 (Michael Petlan) [1729213]
- [fs] PNFS fallback to MDS if no deviceid found (Benjamin Coddington) [1708386]
- [mm] mm, memcg: add a memcg_slabinfo debugfs file (Waiman Long) [1699202]
- [mm] mm: memcg/slab: reparent memcg kmem_caches on cgroup removal (Waiman Long) [1699202]
- [mm] mm: memcg/slab: stop setting page->mem_cgroup pointer for slab pages (Waiman Long) [1699202]
- [mm] mm: memcg/slab: rework non-root kmem_cache lifecycle management (Waiman Long) [1699202]
- [mm] mm: memcg/slab: synchronize access to kmem_cache dying flag using a spinlock (Waiman Long) [1699202]
- [mm] mm: memcg/slab: don't check the dying flag on kmem_cache creation (Waiman Long) [1699202]
- [mm] mm: memcg/slab: unify SLAB and SLUB page accounting (Waiman Long) [1699202]
- [mm] mm: memcg/slab: introduce __memcg_kmem_uncharge_memcg() (Waiman Long) [1699202]
- [mm] mm: memcg/slab: generalize postponed non-root kmem_cache deactivation (Waiman Long) [1699202]
- [mm] mm: memcg/slab: rename slab delayed deactivation functions and fields (Waiman Long) [1699202]
- [mm] mm: memcg/slab: postpone kmem_cache memcg pointer initialization to memcg_link_cache() (Waiman Long) [1699202]
- [mm] slub: add comments to endif pre-processor macros (Waiman Long) [1699202]
- [mm] mm, slab: shorten kmalloc cache names for large sizes (Waiman Long) [1699202]
- [base] mm, proc: add KReclaimable to /proc/meminfo (Waiman Long) [1699202]
- [mm] mm: rename and change semantics of nr_indirectly_reclaimable_bytes (Waiman Long) [1699202]
- [fs] dcache: allocate external names from reclaimable kmalloc caches (Waiman Long) [1699202]
- [mm] mm, slab/slub: introduce kmalloc-reclaimable caches (Waiman Long) [1699202]
- [mm] mm, slab: combine kmalloc_caches and kmalloc_dma_caches (Waiman Long) [1699202]
- [mm] mm: don't warn about large allocations for slab (Waiman Long) [1699202]
- [mm] slab: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1699202]
- [acpi] ACPI / PM: LPIT: Register sysfs attributes based on FADT (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc_core: Quirk to ignore XTAL shutdown (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc_core: Add Package cstates residency info (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc_core: Add ICL platform support (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc: Sort headers alphabetically (Lenny Szubowicz) [1493461]
- [net] Revert "[net] net: openvswitch: Add a new action check_pkt_len" ("Herton R. Krzesinski")

* Tue Jul 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-121.el8]
- [nvme] nvme-rdma: use nr_phys_segments when map rq to sgl (David Milburn) [1729113]
- [nvme] nvme-loop: kill timeout handler (Ming Lei) [1692744]
- [netdrv] bnxt_en: Suppress error messages when querying DSCP DCB capabilities. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Cap the returned MSIX vectors to the RDMA driver. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix statistics context reservation logic for RDMA driver. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix ethtool selftest crash under error conditions. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Disable bus master during PCI shutdown and driver unload. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Reduce memory usage when running in kdump kernel. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix possible BUG() condition when calling pci_disable_msix(). (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix aggregation buffer leak under OOM condition. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Improve NQ reservations. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix uninitialized variable usage in bnxt_rx_pkt(). (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix statistics context reservation logic. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Pass correct extended TX port statistics size to firmware. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix possible crash in bnxt_hwrm_ring_free() under error conditions. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Free short FW command HWRM memory in error path in bnxt_init_one() (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Improve multicast address setup logic. (Selvin Xavier) [1727972]
- [net] net: openvswitch: Add a new action check_pkt_len (Numan Siddique) [1700733]

* Fri Jul 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-120.el8]
- [crypto] crypto: vmx - ghash: do nosimd fallback manually (Desnes Augusto Nunes do Rosario) [1729532]
- [crypto] crypto: vmx - CTR: always increment IV as quadword (Desnes Augusto Nunes do Rosario) [1729532]
- [net] vsock/virtio: fix flush of works during the .remove() (Stefano Garzarella) [1700312]
- [net] vsock/virtio: stop workers during the .remove() (Stefano Garzarella) [1700312]
- [net] vsock/virtio: use RCU to avoid use-after-free on the_virtio_vsock (Stefano Garzarella) [1700312]
- [net] vsock/virtio: Initialize core virtio vsock before registering the driver (Stefano Garzarella) [1700312]
- [nvme] nvme-fabrics: document the poll function argument (David Milburn) [1727784 1725132]
- [nvme] nvme-rdma: fix queue mapping when queue count is limited (David Milburn) [1727784 1725132]
- [nvme] nvme-rdma: rework queue maps handling (David Milburn) [1727784 1725132]
- [nvme] nvme-rdma: implement polling queue map (David Milburn) [1727784 1725132]
- [nvme] nvme-fabrics: allow nvmf_connect_io_queue to poll (David Milburn) [1727784 1725132]
- [hid] HID: multitouch: Add pointstick support for ALPS Touchpad (Benjamin Tissoires) [1672423]

* Thu Jul 18 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-119.el8]
- [tools] perf header: Assign proper ff->ph in perf_event__synthesize_features() (Michael Petlan) [1667983]
- [pci] PCI/IOV: Assume SR-IOV VFs support extended config space. (Myron Stowe) [1714978]
- [pci] Revert "PCI/IOV: Use VF0 cached config space size for other VFs" (Myron Stowe) [1714978]
- [x86] x86/crash: Add e820 reserved ranges to kdump kernel's e820 table (Lianbo Jiang) [1630108]
- [mm] x86/mm: Rework ioremap resource mapping determination (Lianbo Jiang) [1630108]
- [x86] x86/e820, ioport: Add a new I/O resource descriptor IORES_DESC_RESERVED (Lianbo Jiang) [1630108]
- [kernel] resource: Fix find_next_iomem_res() iteration issue (Lianbo Jiang) [1630108]
- [kernel] resource: Include resource end in walk_*() interfaces (Lianbo Jiang) [1630108]
- [x86] x86/kexec: Correct KEXEC_BACKUP_SRC_END off-by-one error (Lianbo Jiang) [1630108]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.3 (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix kernel warnings related to smp_processor_id() (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix BFS crash with DIX enabled (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix FDMI fc4type for nvme support (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix fcp_rsp_len checking on lun reset (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix poor use of hardware queues if fewer irq vectors (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix oops when driver is loaded with 1 interrupt vector (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix incorrect logical link speed on trunks when links down (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix memory leak in abnormal exit path from lpfc_eq_create (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Rework misleading nvme not supported in firmware message (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix hardlockup in scsi_cmd_iocb_cmpl (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Cancel queued work for an IO when processing a received ABTS (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Prevent 'use after free' memory overwrite in nvmet LS handling (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix PT2PT PLOGI collison stopping discovery (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Revert message logging on unsupported topology (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix nvmet handling of received ABTS for unmapped frames (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Separate CQ processing for nvmet_fc upcalls (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Revise message when stuck due to unresponsive adapter (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Correct nvmet buffer free race condition (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix nvmet target abort cmd matching (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix alloc context on oas lun creations (Dick Kennedy) [1717027]

* Wed Jul 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-118.el8]
- [virt] kvm: fix guest initialization code mismerge (Marcelo Tosatti) [1726487]
- [powerpc] powerpc/watchpoint: Restore NV GPRs while returning from exception (Steve Best) [1728557]
- [fs] fs/proc/vmcore: Enable dumping of encrypted memory when SEV was active (Lianbo Jiang) [1646810]
- [x86] x86/kexec: Set the C-bit in the identity map page table when SEV is active (Lianbo Jiang) [1646810]
- [x86] x86/kexec: Do not map kexec area as decrypted when SEV is active (Lianbo Jiang) [1646810]
- [mm] x86/mm: Do not use set_{pud, pmd}_safe() when splitting a large page (Lianbo Jiang) [1646810]

* Tue Jul 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-117.el8]
- [net] sched: protect against stack overflow in TC act_mirred (Ivan Vecera) [1726399]
- [net] sched: refactor reinsert action (Ivan Vecera) [1726399]
- [net] mpls: Fix 6PE forwarding (Hangbin Liu) [1726533]
- [net] make skb_dst_force return true when dst is refcounted (Florian Westphal) [1704809]
- [net] ipv4: Fix off-by-one in route dump counter without netlink strict checking (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv6: fix suspicious RCU usage in rt6_dump_route() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4: fix suspicious RCU usage in fib_dump_info_fnhe() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ip6_fib: Don't discard nodes with valid routing information in fib6_locate_1() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv6: Dump route exceptions if requested (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv6/route: Change return code of rt6_dump_route() for partial node dumps (Stefano Brivio) [1725383 1725381 1574290]
- [net] revert "net/ipv6: Bail early if user only wants cloned entries" (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4: Dump route exceptions if requested (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4/route: Allow NULL flowinfo in rt_fill_info() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4/fib_frontend: Allow RTM_F_CLONED flag to be used for filtering (Stefano Brivio) [1725383 1725381 1574290]
- [net] fib_frontend, ip6_fib: Select routes or exceptions dump from RTM_F_CLONED (Stefano Brivio) [1725383 1725381 1574290]
- [tools] selftests: bpf: disable test_lwt_seg6local (Jiri Benc) [1716346]
- [netdrv] ipvlan: Fix ipvlan device tso disabled while NETIF_F_IP_CSUM is set (Matteo Croce) [1725125]
- [netdrv] ipvlan: disallow userns cap_net_admin to change global mode/flags (Matteo Croce) [1725124]
- [net] netfilter: nft_fib: Fix existence check support (Phil Sutter) [1680578]
- [net] ipset: Fix memory accounting for hash types on resize (Stefano Brivio) [1714111]
- [tools] selftests: pmtu: Make list_flush_ipv6_exception test more demanding (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce list_flush_ipv4_exception test case (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce list_flush_ipv6_exception test case (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Add support for routing via nexthop objects (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Move route installs to a new function (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Move running of test into a new function (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Fix encapsulating device in pmtu_vti6_link_change_mtu (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Simplify cleanup and namespace names (Stefano Brivio) [1725384]
- [tools] selftests: pmtu.sh: Remove quotes around commands in setup_xfrm (Stefano Brivio) [1725384]
- [tools] selftests: Add debugging options to pmtu.sh (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: add explicit tests for PMTU exceptions cleanup (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: disable DAD in all namespaces (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce FoU and GUE PMTU exceptions tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce tests for IPv4/IPv6 over GENEVE over IPv4/IPv6 (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce tests for IPv4/IPv6 over VXLAN over IPv4/IPv6 (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Add optional traffic captures for single tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Allow selection of single tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: add basic IPv4 and IPv6 PMTU tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: extend MTU parsing helper to locked MTU (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce check_pmtu_value() (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: properly redirect stderr to /dev/null (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: detect correct binary to ping ipv6 addresses (Stefano Brivio) [1725384]
- [net] ipv6: icmp: Updating pmtu for link local route (Guillaume Nault) [1721961]
- [net] bridge: Mark FDB entries that were added by user as such (Ivan Vecera) [1724400]
- [net] tipc: change to use register_pernet_device (Xin Long) [1719136]
- [net] sched: cls_flower: fix infinite loop in fl_walk() (Davide Caratti) [1712739]

* Fri Jul 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-116.el8]
- [rpmspec] redhat: fix vmlinux debuginfo on ppc64le (Jan Stancek) [1727638]
- [powerpc] powerpc/rtas: retry when cpu offline races with suspend/migration (Steve Best) [1727051]
- [kernel] arm64/crashkernel: Reduce crashkernel size to 448M by default (Bhupesh Sharma) [1564422]

* Thu Jul 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-115.el8]
- [scsi] scsi: libiscsi: Fix race between iscsi_xmit_task and iscsi_complete_task (Chris Leech) [1718875]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.2 (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: add check for loss of ndlp when sending RRQ (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: correct rcu unlock issue in lpfc_nvme_info_show (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: resolve lockdep warnings (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Make lpfc_sli4_oas_verify static (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Fix a recently introduced compiler warning (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Fix missing wakeups on abort threads (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Change smp_processor_id() into raw_smp_processor_id() (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Remove unused functions (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Remove set-but-not-used variables (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Move trunk_errmsg[] from a header file into a .c file (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Annotate switch/case fall-through (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Fix indentation and balance braces (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Declare local functions static (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: avoid uninitialized variable warning (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: change snprintf to scnprintf for possible overflow (Dick Kennedy) [1714795]
- [net] Bluetooth: hidp: fix buffer overflow (Gopal Tiwari) [1723654] {CVE-2019-11884}
- [s390] virtio/s390: make airq summary indicators DMA (Philipp Rudo) [1651752]
- [s390] virtio/s390: use DMA memory for ccw I/O and classic notifiers (Philipp Rudo) [1651752]
- [s390] virtio/s390: add indirection to indicators access (Philipp Rudo) [1651752]
- [s390] virtio/s390: use cacheline aligned airq bit vectors (Philipp Rudo) [1651752]
- [s390] s390/airq: use DMA memory for adapter interrupts (Philipp Rudo) [1651752]
- [s390] s390/cio: add basic protected virtualization support (Philipp Rudo) [1651752]
- [s390] s390/cio: introduce DMA pools to cio (Philipp Rudo) [1651752]
- [s390] s390/mm: force swiotlb for protected virtualization (Philipp Rudo) [1651752]
- [s390] virtio/s390: DMA support for virtio-ccw (Philipp Rudo) [1651752]
- [s390] virtio/s390: use vring_create_virtqueue (Philipp Rudo) [1651752]
- [block] virtio-blk: Consider virtio_max_dma_size() for maximum segment size (Philipp Rudo) [1651752]
- [virtio] virtio: Introduce virtio_max_dma_size() (Philipp Rudo) [1651752]
- [kernel] dma: Introduce dma_max_mapping_size() (Philipp Rudo) [1651752]
- [kernel] swiotlb: Add is_swiotlb_active() function (Philipp Rudo) [1651752]
- [kernel] swiotlb: Introduce swiotlb_max_mapping_size() (Philipp Rudo) [1651752]
- [mm] x86/mm: Create a workarea in the kernel for SME early encryption (Lianbo Jiang) [1564427]
- [x86] x86/mm: Identify the end of the kernel area to be reserved (Lianbo Jiang) [1564427]
- [x86] x86/kdump: Export the SME mask to vmcoreinfo (Lianbo Jiang) [1564427]
- [fs] proc/vmcore: Fix i386 build error of missing copy_oldmem_page_encrypted() (Lianbo Jiang) [1564427]
- [fs] kdump, proc/vmcore: Enable kdumping encrypted memory with SME enabled (Lianbo Jiang) [1564427]
- [iommu] iommu/amd: Remap the IOMMU device table with the memory encryption mask for kdump (Lianbo Jiang) [1564427]
- [kernel] kexec: Allocate decrypted control pages for kdump if SME is enabled (Lianbo Jiang) [1564427]
- [mm] x86/ioremap: Add an ioremap_encrypted() helper (Lianbo Jiang) [1564427]
- [documentation] Documentation: Add ARM64 to kernel-parameters.rst (Jeremy Linton) [1640855]
- [arm64] arm64/speculation: Support 'mitigations=' cmdline option (Jeremy Linton) [1640855]
- [arm64] arm64: ssbs: Don't treat CPUs with SSBS as unaffected by SSB (Jeremy Linton) [1640855]
- [arm64] arm64: enable generic CPU vulnerabilites support (Jeremy Linton) [1640855]
- [arm64] arm64: add sysfs vulnerability show for speculative store bypass (Jeremy Linton) [1640855]
- [arm64] arm64: Always enable ssb vulnerability detection (Jeremy Linton) [1640855]
- [arm64] arm64: add sysfs vulnerability show for spectre-v2 (Jeremy Linton) [1640855]
- [arm64] arm64: Always enable spectre-v2 vulnerability detection (Jeremy Linton) [1640855]
- [arm64] arm64: Use firmware to detect CPUs that are not affected by Spectre-v2 (Jeremy Linton) [1640855]
- [arm64] arm64: Advertise mitigation of Spectre-v2, or lack thereof (Jeremy Linton) [1640855]
- [arm64] arm64: add sysfs vulnerability show for meltdown (Jeremy Linton) [1640855]
- [arm64] arm64: Add sysfs vulnerability show for spectre-v1 (Jeremy Linton) [1640855]
- [arm64] arm64: Provide a command line to disable spectre_v2 mitigation (Jeremy Linton) [1640855]
- [documentation] powerpc/fsl: Add FSL_PPC_BOOK3E as supported arch for nospectre_v2 boot arg (Jeremy Linton) [1640855]
- [documentation] Documentation: Document arm64 kpti control (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Whitelist HiSilicon Taishan v110 CPUs (Jeremy Linton) [1640855]
- [arm64] arm64: Add MIDR encoding for HiSilicon Taishan CPUs (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Whitelist Cortex-A CPUs that don't implement the CSV3 field (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Update arm64_kernel_use_ng_mappings() when forced on (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Avoid rewriting early page tables when KASLR is enabled (Jeremy Linton) [1640855]
- [arm64] arm64: capabilities: Merge duplicate Cavium erratum entries (Jeremy Linton) [1640855]
- [arm64] arm64: capabilities: Merge entries for ARM64_WORKAROUND_CLEAN_CACHE (Jeremy Linton) [1640855]
- [arm64] arm64: Use a raw spinlock in __install_bp_hardening_cb() (Jeremy Linton) [1640855]
- [arm64] arm64: KVM: Guests can skip __install_bp_hardening_cb()s HYP work (Jeremy Linton) [1640855]
- [arm64] arm64: fix SSBS sanitization (Jeremy Linton) [1640855]
- [arm64] arm64: don't zero DIT on signal return (Jeremy Linton) [1640855]
- [kvm] KVM: arm64: Set SCTLR_EL2.DSSBS if SSBD is forcefully disabled and !vhe (Jeremy Linton) [1640855]
- [arm64] arm64: ssbd: Add support for PSTATE.SSBS rather than trapping to EL3 (Jeremy Linton) [1640855]
- [arm64] arm64: ssbd: Drop #ifdefs for PR_SPEC_STORE_BYPASS (Jeremy Linton) [1640855]
- [arm64] arm64: cpufeature: Detect SSBS and advertise to userspace (Jeremy Linton) [1640855]
- [arm64] arm64: move SCTLR_EL{1,2} assertions to <asm/sysreg.h> (Jeremy Linton) [1640855]

* Wed Jul 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-114.el8]
- [powerpc] powerpc/mm/64s/hash: Reallocate context ids on fork (Steve Best) [1723808]
- [powerpc] powerpc/perf: Use cpumask_last() to determine the designated cpu for nest/core units. (Steve Best) [1725746]
- [fs] iomap: fix page_done callback for short writes (Andreas Grunbacher) [1724361]
- [fs] fs: fold __generic_write_end back into generic_write_end (Andreas Grunbacher) [1724361]
- [fs] iomap: don't mark the inode dirty in iomap_write_end (Andreas Grunbacher) [1724361]
- [fs] gfs2: Fix iomap write page reclaim deadlock (Andreas Grunbacher) [1724361]
- [fs] iomap: Add a page_prepare callback (Andreas Grunbacher) [1724361]
- [fs] iomap: Fix use-after-free error in page_done callback (Andreas Grunbacher) [1724361]
- [fs] fs: Turn __generic_write_end into a void function (Andreas Grunbacher) [1724361]
- [fs] iomap: Clean up __generic_write_end calling (Andreas Grunbacher) [1724361]
- [kvm] KVM: PPC: Book3S HV: Clear pending decrementer exceptions on nested guest entry (Suraj Jitindar Singh) [1718822]
- [kvm] KVM: PPC: Book3S HV: Signed extend decrementer value if not using large decrementer (Suraj Jitindar Singh) [1718822]

* Tue Jul 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-113.el8]
- [hid] HID: chicony: add another quirk for PixArt mouse (Oleksandr Natalenko) [1724967]
- [scsi] scsi: smartpqi: properly set both the DMA mask and the coherent DMA mask (Don Brace) [1712272]
- [tools] perf beauty waitid options: Fix up prefix showing logic (Michael Petlan) [1715507]
- [include] redhat: perf kABI-check failure fix (Michael Petlan) [1715507]
- [tools] perf script python: Add Python3 support to tests/attr.py (Michael Petlan) [1715507]
- [tools] perf trace: Support multiple "vfs_getname" probes (Michael Petlan) [1715507]
- [tools] perf symbols: Filter out hidden symbols from labels (Michael Petlan) [1715507]
- [tools] perf symbols: Add fallback definitions for GELF_ST_VISIBILITY() (Michael Petlan) [1715507]
- [tools] perf clang: Do not use 'return std::move(something)' (Michael Petlan) [1715507]
- [tools] perf tests evsel-tp-sched: Fix bitwise operator (Michael Petlan) [1715507]
- [tools] perf script: Fix crash when processing recorded stat data (Michael Petlan) [1715507]
- [tools] perf top: Fix wrong hottest instruction highlighted (Michael Petlan) [1715507]
- [tools] perf tools: Handle TOPOLOGY headers with no CPU (Michael Petlan) [1715507]
- [tools] perf python: Remove -fstack-clash-protection when building with some clang versions (Michael Petlan) [1715507]
- [tools] perf script: Fix crash with printing mixed trace point and other events (Michael Petlan) [1715507]
- [tools] perf ordered_events: Fix crash in ordered_events__free (Michael Petlan) [1715507]
- [tools] tools headers powerpc: Remove unistd.h (Michael Petlan) [1715507]
- [tools] perf powerpc: Rework syscall table generation (Michael Petlan) [1715507]
- [tools] perf symbols: Add 'arch_cpu_idle' to the list of kernel idle symbols (Michael Petlan) [1715507]
- [tools] perf beauty: Switch from using uapi/linux/fs.h to uapi/linux/mount.h (Michael Petlan) [1715507]
- [tools] tools include uapi: Grab a copy of linux/mount.h (Michael Petlan) [1715507]
- [tools] perf top: Lift restriction on using callchains without "sym" in --sort (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Remove tep_data_event_from_type() API (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Rename tep_is_file_bigendian() to tep_file_bigendian() (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Changed return logic of tep_register_event_handler() API (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Changed return logic of trace_seq_printf() and trace_seq_vprintf() APIs (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Rename struct cmdline to struct tep_cmdline (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Initialize host_bigendian at tep_handle allocation (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Introduce new libtracevent API: tep_override_comm() (Michael Petlan) [1715507]
- [tools] perf tests: Add a test for the ARM 32-bitpage (Michael Petlan) [1715507]
- [tools] perf tools: Make find_vdso_map() more modular (Michael Petlan) [1715507]
- [tools] perf trace: Fix alignment forlines (Michael Petlan) [1715507]
- [tools] perf trace: Fix ')' placement in "interrupted" syscall lines (Michael Petlan) [1715507]
- [tools] perf test shell: Use a fallback to get the pathname in vfs_getname (Michael Petlan) [1715507]
- [tools] perf python: Make sure the python binding output directory is in place (Michael Petlan) [1715507]
- [tools] perf strbuf: Remove redundant va_end() in strbuf_addv() (Michael Petlan) [1715507]
- [tools] perf annotate: Pass filename to objdump via execl (Michael Petlan) [1715507]
- [tools] perf report: Fix wrong iteration count in --branch-history (Michael Petlan) [1715507]
- [tools] tools headers uapi: Sync copy of asm-generic/unistd.h with the kernel sources (Michael Petlan) [1715507]
- [tools] tools beauty: Make the prctl option table generator catch all PR_ options (Michael Petlan) [1715507]
- [tools] perf stat: Fix endless wait for child process (Michael Petlan) [1715507]
- [tools] perf session: Add comment for perf_session__register_idle_thread() (Michael Petlan) [1715507]
- [tools] perf thread-stack: Fix thread stack processing for the idle task (Michael Petlan) [1715507]
- [tools] perf thread-stack: Allocate an array of thread stacks (Michael Petlan) [1715507]
- [tools] perf thread-stack: Factor out thread_stack__init() (Michael Petlan) [1715507]
- [tools] perf thread-stack: Allow for a thread stack array (Michael Petlan) [1715507]
- [tools] perf thread-stack: Avoid direct reference to the thread's stack (Michael Petlan) [1715507]
- [tools] perf thread-stack: Tidy thread_stack__bottom() usage (Michael Petlan) [1715507]
- [tools] perf thread-stack: Simplify some code in thread_stack__process() (Michael Petlan) [1715507]
- [tools] perf c2c: Increase the HITM ratio limit for displayed cachelines (Michael Petlan) [1715507]
- [tools] perf c2c: Change the default coalesce setup (Michael Petlan) [1715507]
- [tools] perf trace beauty ioctl: Beautify USBDEVFS_ commands (Michael Petlan) [1715507]
- [tools] perf trace beauty: Export function to get the files for a thread (Michael Petlan) [1715507]
- [tools] perf trace: Wire up ioctl's USBDEBFS_ cmd table generator (Michael Petlan) [1715507]
- [tools] perf beauty ioctl: Add generator for USBDEVFS_ ioctl commands (Michael Petlan) [1715507]
- [tools] tools headers uapi: Grab a copy of usbdevice_fs.h (Michael Petlan) [1715507]
- [tools] perf trace: Store the major number for a file when storing its pathname (Michael Petlan) [1715507]
- [tools] perf trace: Move the files table resizing to outside set_pathname() (Michael Petlan) [1715507]
- [tools] perf trace: Rename thread_thread->paths to thread_trace->files (Michael Petlan) [1715507]
- [tools] perf script: Fix LBR skid dump problems in brstackinsn (Michael Petlan) [1715507]
- [tools] perf trace: Use correct SECCOMP prefix spelling, "SECOMP_*" -> "SECCOMP_*" (Michael Petlan) [1715507]
- [tools] perf trace: Do not hardcode the size of the tracepoint common_ fields (Michael Petlan) [1715507]
- [tools] perf build: Don't unconditionally link the libbfd feature test to -liberty and -lz (Michael Petlan) [1715507]
- [tools] perf beauty mmap: PROT_WRITE should come before PROT_EXEC (Michael Petlan) [1715507]
- [tools] perf trace: Check if the raw_syscalls:sys_{enter, exit} are setup before setting tp filter (Michael Petlan) [1715507]
- [tools] perf symbols: Relax checks on perf-PID.map ownership (Michael Petlan) [1715507]
- [tools] perf trace: Wire up the fadvise 'advice' table generator (Michael Petlan) [1715507]
- [tools] perf beauty: Add generator for fadvise64's 'advice' arg constants (Michael Petlan) [1715507]
- [tools] tools headers uapi: Grab a copy of fadvise.h (Michael Petlan) [1715507]
- [tools] perf beauty mmap: Print mmap's 'offset' arg in hexadecimal (Michael Petlan) [1715507]
- [tools] perf beauty mmap: Print PROT_READ before PROT_EXEC to match strace output (Michael Petlan) [1715507]
- [tools] perf trace beauty: Beautify arch_prctl()'s arguments (Michael Petlan) [1715507]
- [tools] perf trace: When showing string prefixes show prefix + ??? for unknown entries (Michael Petlan) [1715507]
- [tools] perf trace: Move strarrays to beauty.h for further reuse (Michael Petlan) [1715507]
- [tools] perf beauty: Wire up the x86_arch prctl code table generator (Michael Petlan) [1715507]
- [tools] perf beauty: Add a string table generator for x86's 'arch_prctl' codes (Michael Petlan) [1715507]
- [tools] tools include arch: Grab a copy of x86's prctl.h (Michael Petlan) [1715507]
- [tools] perf trace: Show NULL when syscall pointer args are 0 (Michael Petlan) [1715507]
- [tools] perf trace: Enclose the errno strings with () (Michael Petlan) [1715507]
- [tools] perf augmented_raw_syscalls: Copy 'access' arg as well (Michael Petlan) [1715507]
- [tools] perf trace: Add alignment spaces after the closing parens (Michael Petlan) [1715507]
- [tools] perf trace beauty: Print O_RDONLY when (flags & O_ACCMODE) == 0 (Michael Petlan) [1715507]
- [tools] perf trace: Allow asking for not suppressing common string prefixes (Michael Petlan) [1715507]
- [tools] perf trace: Add a prefix member to the strarray class (Michael Petlan) [1715507]
- [tools] perf trace: Enclose strings with double quotes (Michael Petlan) [1715507]
- [tools] perf trace: Make the alignment of the syscall args be configurable (Michael Petlan) [1715507]
- [tools] perf trace: Allow suppressing the syscall argument names (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring if the syscall start timestamp should be printed (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring default for perf_event_attr.inherit (Michael Petlan) [1715507]
- [tools] perf config: Show the configuration when no arguments are provided (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring if the syscall duration should be printed (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring if zeroed syscall args should be printed (Michael Petlan) [1715507]
- [tools] perf trace: Allow specifying a set of events to add in perfconfig (Michael Petlan) [1715507]
- [tools] perf augmented_raw_syscalls: Do not include stdio.h (Michael Petlan) [1715507]
- [tools] perf cs-etm: Generate branch sample for exception packet (Michael Petlan) [1715507]
- [tools] perf cs-etm: Treat EO_TRACE element as trace discontinuity (Michael Petlan) [1715507]
- [tools] perf cs-etm: Treat NO_SYNC element as trace discontinuity (Michael Petlan) [1715507]
- [tools] perf cs-etm: Rename CS_ETM_TRACE_ON to CS_ETM_DISCONTINUITY (Michael Petlan) [1715507]
- [tools] perf cs-etm: Refactor enumeration cs_etm_sample_type (Michael Petlan) [1715507]
- [tools] perf cs-etm: Remove unused 'trace_on' in cs_etm_decoder (Michael Petlan) [1715507]
- [tools] perf cs-etm: Avoid stale branch samples when flush packet (Michael Petlan) [1715507]
- [tools] perf cs-etm: Correct packets swapping in cs_etm__flush() (Michael Petlan) [1715507]
- [tools] perf trace: Switch to using a struct for the aumented_raw_syscalls syscalls map values (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Switch to using a struct for the syscalls map values (Michael Petlan) [1715507]
- [tools] perf bpf: Move perf_event_output() from stdio.h to bpf.h (Michael Petlan) [1715507]
- [tools] perf trace: Implement syscall filtering in augmented_syscalls (Michael Petlan) [1715507]
- [tools] perf trace: Avoid using raw_syscalls in duplicity with eBPF augmentation (Michael Petlan) [1715507]
- [tools] perf trace: Rename set_ev_qualifier_filter to clarify its a tracepoint filter (Michael Petlan) [1715507]
- [tools] perf tools: Cast off_t to s64 to avoid warning on bionic libc (Michael Petlan) [1715507]
- [tools] perf tools: Add missing open_memstream() prototype for systems lacking it (Michael Petlan) [1715507]
- [tools] perf header: Fix up argument to ctime() (Michael Petlan) [1715507]
- [tools] perf tools: Add missing sigqueue() prototype for systems lacking it (Michael Petlan) [1715507]
- [tools] tools lib subcmd: Don't add the kernel sources to the include path (Michael Petlan) [1715507]
- [tools] perf trace beauty: renameat's newdirfd may also be AT_FDCWD (Michael Petlan) [1715507]
- [tools] perf trace: Beautify renameat2's flags argument (Michael Petlan) [1715507]
- [tools] perf beauty: Wire up the renameat flags table generator to the Makefile (Michael Petlan) [1715507]
- [tools] perf beauty: Add a string table generator for renameat2's flags constants (Michael Petlan) [1715507]
- [tools] perf trace beauty: Beautify renameat2's fd arg wrt AT_FDCWD (Michael Petlan) [1715507]
- [tools] perf trace: Allow selecting use the use of the ordered_events code (Michael Petlan) [1715507]
- [tools] perf trace: Rename delivery functions to ease making ordered_events selectable (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Fix processing of dereferenced args in bprintk events (Michael Petlan) [1715507]
- [tools] perf stat: Avoid segfaults caused by negated options (Michael Petlan) [1715507]
- [tools] perf auxtrace: Alter addr_filter__entire_dso() to work if there are no symbols (Michael Petlan) [1715507]
- [tools] perf dso: Export data_file_size() method there are no symbols (Michael Petlan) [1715507]
- [tools] perf trace: Add ordered processing (Michael Petlan) [1715507]
- [tools] perf ordered_events: Add first_time() method (Michael Petlan) [1715507]
- [tools] perf trace: Move event delivery to a new deliver_event() function (Michael Petlan) [1715507]
- [tools] perf ordered_events: Add ordered_events__flush_time interface (Michael Petlan) [1715507]
- [tools] perf annotate: Introduce basic support for ARC (Michael Petlan) [1715507]
- [tools] perf config: Modify size factor of snprintf (Michael Petlan) [1715507]
- [tools] perf record: Fix memory leak on AIO objects deallocation (Michael Petlan) [1715507]
- [tools] perf vendor events intel: Fix Load_Miss_Real_Latency on SKL/SKX (Michael Petlan) [1715507]
- [tools] perf parse-events: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf probe: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf ui helpline: Use strlcpy() as a shorter form of strncpy() + explicit set nul (Michael Petlan) [1715507]
- [tools] perf svghelper: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf help: Remove needless use of strncpy() (Michael Petlan) [1715507]
- [tools] perf header: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf header: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf dso: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf cs-etm: Add support for PTMv1.1 decoding (Michael Petlan) [1715507]
- [tools] perf cs-etm: Add support for ETMv3 trace decoding (Michael Petlan) [1715507]
- [tools] perf cs-etm: Add configuration for ETMv3 trace protocol (Michael Petlan) [1715507]
- [tools] perf top: Move perf_top__reset_sample_counters() to after counts display (Michael Petlan) [1715507]
- [tools] perf top: Display slow reader warning when droping samples (Michael Petlan) [1715507]
- [tools] perf top: Save and display the drop count stats (Michael Petlan) [1715507]
- [tools] perf top: Drop samples which are behind the refresh rate (Michael Petlan) [1715507]
- [tools] perf top: Set the 'session_done' volatile variable when exiting (Michael Petlan) [1715507]
- [tools] perf top: Use cond variable instead of a lock (Michael Petlan) [1715507]
- [tools] perf top: Add processing thread (Michael Petlan) [1715507]
- [tools] perf top: Move lost events warning to helpline (Michael Petlan) [1715507]
- [tools] perf top: Save and display the lost count stats (Michael Petlan) [1715507]
- [tools] perf ordered_events: Add private data member (Michael Petlan) [1715507]
- [tools] perf ordered_events: Rework show_progress for __ordered_events__flush (Michael Petlan) [1715507]
- [tools] perf tools: Support 'srccode' output (Michael Petlan) [1715507]
- [tools] perf trace: We need to consider "nr" if "__syscall_nr" is not there (Michael Petlan) [1715507]
- [tools] perf tools: Allow specifying proc-map-timeout in config file (Michael Petlan) [1715507]
- [tools] tools lib subcmd: Fix a few source code comment typos (Michael Petlan) [1715507]
- [tools] perf tools: Fix diverse comment typos (Michael Petlan) [1715507]
- [tools] perf bpf-loader: Fix debugging message typo (Michael Petlan) [1715507]
- [tools] perf tools Documentation: Fix diverse typos (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Fix diverse typos in comments (Michael Petlan) [1715507]
- [tools] perf vendor events intel: Fix diverse typos (Michael Petlan) [1715507]
- [tools] perf tests ARM: Disable breakpoint tests 32-bit (Michael Petlan) [1715507]
- [tools] perf cs-etm: Support for ARM A32/T32 instruction sets in CoreSight trace (Michael Petlan) [1715507]
- [tools] perf beauty mmap_flags: Fixed syntax error Fixed missing ']' error (Michael Petlan) [1715507]
- [tools] tools lib traceevent: traceevent API cleanup (Michael Petlan) [1715507]
- [tools] perf tools: traceevent API cleanup, remove __tep_data2host*() (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Rename tep_free_format() to tep_free_event() (Michael Petlan) [1715507]
- [tools] tools lib traceevent, perf tools: Rename 'struct tep_event_format' to 'struct tep_event' (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Install trace-seq.h API header file (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Added support for pkg-config (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Implement new API tep_get_ref() (Michael Petlan) [1715507]
- [tools] perf report: Documentation average IPC and IPC coverage (Michael Petlan) [1715507]
- [tools] perf report: Display average IPC and IPC coverage per symbol (Michael Petlan) [1715507]
- [tools] perf annotate: Create a annotate2 flag in struct symbol (Michael Petlan) [1715507]
- [tools] perf annotate: Compute average IPC and IPC coverage per symbol (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Add sanity check to is_timestamp_in_us() (Michael Petlan) [1715507]
- [tools] perf beauty mmap_flags: Check if the arch has a mmap.h file (Michael Petlan) [1715507]
- [tools] perf record: Extend trace writing to multi AIO (Michael Petlan) [1715507]
- [tools] perf record: Enable asynchronous trace writing (Michael Petlan) [1715507]
- [tools] perf mmap: Map data buffer for preserving collected data (Michael Petlan) [1715507]
- [tools] tools build feature: Check if libaio is available (Michael Petlan) [1715507]
- [tools] perf intel-pt: Fix error with config term "pt=0" (Michael Petlan) [1715507]
- [tools] perf top: Allow passing a kallsyms file (Michael Petlan) [1715507]
- [tools] perf bpf: Use ERR_CAST instead of ERR_PTR(PTR_ERR()) (Michael Petlan) [1715507]
- [tools] tools include: Adopt ERR_CAST() from the kernel err.h header (Michael Petlan) [1715507]
- [tools] perf tests record: Allow for 'sleep' being 'coreutils' (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Fix compile warnings in tools/lib/traceevent/event-parse.c (Michael Petlan) [1715507]
- [tools] perf script: Use fallbacks for branch stacks (Michael Petlan) [1715507]
- [tools] perf tools: Use fallback for sample_addr_correlates_sym() cases (Michael Petlan) [1715507]
- [tools] perf thread: Add fallback functions for cases where cpumode is insufficient (Michael Petlan) [1715507]
- [tools] perf machine: Record if a arch has a single user/kernel address space (Michael Petlan) [1715507]
- [tools] perf env: Also consider env->arch == NULL as local operation (Michael Petlan) [1715507]
- [tools] perf map: Remove extra indirection from map__find() (Michael Petlan) [1715507]
- [tools] perf stat: Fix CSV mode column output for non-cgroup events (Michael Petlan) [1715507]
- [tools] perf stat: Fix shadow stats for clock events (Michael Petlan) [1715507]
- [tools] perf build: Give better hint about devel package for libssl (Michael Petlan) [1715507]
- [tools] perf pmu: Move *_cpuid_str() weak functions to header.c (Michael Petlan) [1715507]
- [tools] perf symbols: Fix slowness due to -ffunction-section (Michael Petlan) [1715507]
- [tools] perf jvmti: Separate jvmti cmlr check (Michael Petlan) [1715507]
- [tools] perf vendor events: Add JSON metrics for Cascadelake server (Michael Petlan) [1715507]
- [tools] perf vendor events: Add stepping in CPUID string for x86 (Michael Petlan) [1715507]
- [tools] perf stat: Use perf_evsel__is_clocki() for clock events (Michael Petlan) [1715507]
- [tools] perf pmu: Suppress potential format-truncation warning (Michael Petlan) [1715507]
- [tools] perf tools: Add Hygon Dhyana support (Michael Petlan) [1715507]
- [tools] perf bench: Add epoll_ctl(2) benchmark (Michael Petlan) [1715507]
- [tools] perf bench: Add epoll parallel epoll_wait benchmark (Michael Petlan) [1715507]
- [tools] tools build feature: Check if eventfd() is available (Michael Petlan) [1715507]
- [tools] perf bench: Move HAVE_PTHREAD_ATTR_SETAFFINITY_NP into bench.h (Michael Petlan) [1715507]
- [tools] perf script: Share code and output format for uregs and iregs output (Michael Petlan) [1715507]
- [tools] perf bpf: Reduce the hardcoded .max_entries for pid_maps (Michael Petlan) [1715507]
- [tools] perf script: Add newline after uregs output (Michael Petlan) [1715507]
- [tools] Revert "perf augmented_syscalls: Drop 'write', 'poll' for testing without self pid filter" (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Remove example hardcoded set of filtered pids (Michael Petlan) [1715507]
- [tools] perf trace: Fill in BPF "filtered_pids" map when present (Michael Petlan) [1715507]
- [tools] perf trace: See if there is a map named "filtered_pids" (Michael Petlan) [1715507]
- [tools] perf trace: Add "_from_option" suffix to trace__set_filter() (Michael Petlan) [1715507]
- [tools] perf evlist: Rename perf_evlist__set_filter* to perf_evlist__set_tp_filter* (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Use pid_filter (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Drop 'write', 'poll' for testing without self pid filter (Michael Petlan) [1715507]
- [tools] perf bpf: Add simple pid_filter class accessible to BPF proggies (Michael Petlan) [1715507]
- [tools] perf bpf: Add defines for map insertion/lookup (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Remove needless linux/socket.h include (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Filter on a hard coded pid (Michael Petlan) [1715507]
- [tools] perf bpf: Add unistd.h to the headers accessible to bpf proggies (Michael Petlan) [1715507]
- [kernel] perf/core: Fix impossible ring-buffer sizes warning (Michael Petlan) [1715507]
- [x86] perf/x86: Add check_period PMU callback (Michael Petlan) [1715507]
- [kernel] perf/core: Don't WARN() for impossible ring-buffer sizes (Michael Petlan) [1715507]
- [x86] perf/x86/intel/uncore: Add Node ID mask (Michael Petlan) [1715507]
- [kernel] perf core: Fix perf_proc_update_handler() bug (Michael Petlan) [1715507]
- [tools] powerpc/perf: Update perf_regs structure to include MMCRA (Michael Petlan) [1715507]
- [powerpc] powerpc/perf: Update perf_regs structure to include SIER (Michael Petlan) [1715507]
- [include] perf/core: Declare the __percpu attribute on non-deref types (Michael Petlan) [1715507]
- [kernel] perf: Fix typos in comments (Michael Petlan) [1715507]
- [arm64] arm64: perf: Add support for Armv8.1 PMCEID register format (Michael Petlan) [1715507]

* Fri Jul 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-112.el8]
- [fs] xfs: abort unaligned nowait directio early (Brian Foster) [1690458]
- [fs] xfs: serialize unaligned dio writes against all other dio writes (Brian Foster) [1690458]
- [sound] ALSA: hda/hdmi: consider eld_valid also in sync_eld_via_acomp() (Jaroslav Kysela) [1708555]
- [fs] Fix error code in nfs_lookup_verify_inode() (Scott Mayhew) [1722315]
- [md] dm table: don't copy from a NULL pointer in realloc_argv() (Jerome Marchand) [1571628]
- [net] netfilter: ipset: replace a strncpy() with strscpy() (Jerome Marchand) [1571628]
- [lib] lib/ubsan.c: don't mark __ubsan_handle_builtin_unreachable as noreturn (Jerome Marchand) [1571628]
- [include] netfilter: avoid erronous array bounds warning (Jerome Marchand) [1571628]
- [x86] x86/mm/KASLR: Compute the size of the vmemmap section properly (Baoquan He) [1669076]
- [security] selinux: fix empty write to keycreate file (Ondrej Mosnacek) [1719067]
- [netdrv] net: aquantia: fix vlans not working over bridged network (Igor Russkikh) [1718716]
- [s390] s390/jump_label: replace stop_machine with smp_call_function (Philipp Rudo) [1722161]
- [s390] s390/dumpstack: print psw mask and address again (Philipp Rudo) [1722157]
- [s390] s390/crypto: fix gcm-aes-s390 selftest failures (Philipp Rudo) [1722156]
- [wireless] Backport mt76 drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1709867 1709828]
- [wireless] Add rtw88 driver from linux-5.2-rc5 (Stanislaw Gruszka) [1487086 1709828]
- [wireless] Backport mt7601u driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport mwifiex driver from linux-5.2-rc2 (Stanislaw Gruszka) [1709828]
- [wireless] Backport rtl8xxxu driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport rtlwifi drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport ath9k driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport ath10k driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport brcm80211 drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport iwlwifi drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1696052 1662020 1662015 1650016 1650015 1650014 1650013 1622445 1494008 1494001 1709828]
- [net] Backport mac80211 from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [net] Backport core wireless code from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [include] netlink: add nl_set_extack_cookie_u64() (Stanislaw Gruszka) [1709828]
- [netdrv] r8152: Fix an error on RTL8153-BD MAC Address Passthrough support (Torez Smith) [1683883 1683882]
- [netdrv] r8152: Add support for MAC address pass through on RTL8153-BD (Torez Smith) [1683883 1683882]
- [netdrv] nfp: abm: fix spelling mistake "offseting" -> "offsetting" (Pablo Cascon) [1713258]
- [netdrv] nfp: flower: remove vlan CFI bit from push vlan action (Pablo Cascon) [1713258]
- [netdrv] nfp: flower: replace CFI with vlan present (Pablo Cascon) [1713258]
- [netdrv] nfp: flower: remove double new line (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: fix ALU32 high bits clearance bug (Pablo Cascon) [1713258]
- [netdrv] bpf: do not pass netdev to translate() and prepare() offload callbacks (Pablo Cascon) [1713258]
- [netdrv] bpf: pass prog instead of env to bpf_prog_offload_verifier_prep() (Pablo Cascon) [1713258]
- [netdrv] bpf: pass destroy() as a callback and remove its ndo_bpf subcommand (Pablo Cascon) [1713258]
- [netdrv] bpf: pass translate() as a callback and remove its ndo_bpf subcommand (Pablo Cascon) [1713258]
- [netdrv] bpf: call verifier_prep from its callback in struct bpf_offload_dev (Pablo Cascon) [1713258]
- [netdrv] bpf: pass a struct with offload callbacks to bpf_offload_dev_create() (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: move nfp_bpf_analyzer_ops from verifier.c to offload.c (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: relax prog rejection through max_pkt_offset (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: double check vNIC capabilities after object sharing (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: optimise save/restore for R6~R9 based on register usage (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: fix return address from register-saving subroutine to callee (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: update fixup function for BPF-to-BPF calls support (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: account for additional stack usage when checking stack limit (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: add main logics for BPF-to-BPF calls support in nfp driver (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: copy eBPF subprograms information from kernel verifier (Pablo Cascon) [1713258]
- [netdrv] bpf: add verifier callback to get stack usage info for offloaded progs (Pablo Cascon) [1713258]

* Wed Jul 03 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-111.el8]
- [rpmspec] Enable kernel signing for ppc64le (Gustavo Duarte) [1504169]
- [nvme] nvme: fix memory leak for power latency tolerance (David Milburn) [1724793]
- [rpmspec] redhat: fix missing files for mlxsw specific self-tests (Ivan Vecera) [1724735]
- [rpmspec] redhat: Package the signing key for s390 (Philipp Rudo) [1714194]
- [rpmspec] redhat: Enable kernel signing for s390 (Philipp Rudo) [1714194]
- [rpmspec] redhat: Rename secure boot sources (Philipp Rudo) [1714194]
- [powerpc] powerpc: fix max_zone_pfns initialization (Laurent Vivier) [1706560]
- [crypto] crypto: dh - update test for public key verification (Herbert Xu) [1722692]
- [hid] HID: i2c-hid: Don't reset device upon system resume (Perry Yuan) [1715385]
- [rpmspec] correct the ghost initramfs attributes (Rafael Aquini) [1678881]
- [s390] s390/mm: fix address space detection in exception handling (Philipp Rudo) [1722160]
- [s390] s390/zcrypt: Fix wrong dispatching for control domain CPRBs (Philipp Rudo) [1722158]
- [virt] kvm: arm/arm64: Fix emulated ptimer irq injection (Andrew Jones) [1716383]
- [x86] kvm/nested: mark as TechPreview on first VM creation (Vitaly Kuznetsov) [1723447]
- [powerpc] bpf: powerpc64: add JIT support for bpf line info (Yauheni Kaliuta) [1722423]
- [fs] cifs: add spinlock for the openFileList to cifsInodeInfo (Leif Sahlberg) [1712197]
- [fs] cifs: fix GlobalMid_Lock bug in cifs_reconnect (Leif Sahlberg) [1716743]
- [mm] powerpc/numa: document topology_updates_enabled, disable by default (Desnes Augusto Nunes do Rosario) [1705465]
- [mm] powerpc/numa: improve control of topology updates (Desnes Augusto Nunes do Rosario) [1705465]
- [kernel] bpf: decouple the lifetime of cgroup_bpf from cgroup itself (Jiri Olsa) [1656432]
- [netdrv] USB: hso: Fix OOB memory access in hso_probe/hso_get_config_data (Torez Smith) [1689308 1666662] {CVE-2018-19985}
- [usb] USB: check usb_get_extra_descriptor for proper size (Torez Smith) [1689308 1666662] {CVE-2018-20169}
- [kvm] KVM: PPC: Book3S HV: Restore SPRG3 in kvmhv_p9_guest_entry() (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Fix lockdep warning when entering guest on POWER9 (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Fix page offset when clearing ESB pages (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Take the srcu read lock when accessing memslots (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Do not clear IRQ data of passthrough interrupts (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Introduce a new mutex for the XIVE device (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Fix the enforced limit on the vCPU identifier (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Do not test the EQ flag validity when resetting (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Clear file mapping when device is released (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Don't take kvm->lock around kvm_for_each_vcpu (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S: Use new mutex to synchronize access to rtas token list (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Use new mutex to synchronize MMU setup (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Avoid touching arch.mmu_ready in XIVE release functions (David Gibson) [1719524]
- [mm] mm, oom: don't kill global init via memory.oom.group (Waiman Long) [1711604]
- [mm] mm, oom: remove 'prefer children over parent' heuristic (Waiman Long) [1711604]
- [mm] mm, oom: fix use-after-free in oom_kill_process (Waiman Long) [1711604]
- [kernel] fork, memcg: fix crash in free_thread_stack on memcg charge fail (Waiman Long) [1711604]
- [mm] memcg: localize memcg_kmem_enabled() check (Waiman Long) [1711604]
- [mm] memcg, oom: notify on oom killer invocation from the charge path (Waiman Long) [1711604]
- [mm] mm: handle no memcg case in memcg_kmem_charge() properly (Waiman Long) [1711604]
- [kernel] mm: rework memcg kernel stack accounting (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: convert mem_cgroup_id::ref to refcount_t type (Waiman Long) [1711604]
- [mm] memcg: remove memcg_kmem_skip_account (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: fix memory.stat item ordering (Waiman Long) [1711604]
- [mm] mm: drain memcg stocks on css offlining (Waiman Long) [1711604]
- [mm] mm: memcontrol: print proper OOM header when no eligible victim left (Waiman Long) [1711604]
- [mm] mm, oom: introduce memory.oom.group (Waiman Long) [1711604]
- [mm] mm, oom: refactor oom_kill_process() (Waiman Long) [1711604]
- [mm] memcg: reduce memcg tree traversals for stats collection (Waiman Long) [1711604]
- [mm] mm/vmscan.c: clear shrinker bit if there are no objects related to memcg (Waiman Long) [1711604]
- [mm] mm: add SHRINK_EMPTY shrinker methods return value (Waiman Long) [1711604]
- [mm] mm/vmscan.c: generalize shrink_slab() calls in shrink_node() (Waiman Long) [1711604]
- [mm] mm/vmscan.c: iterate only over charged shrinkers during memcg shrink_slab() (Waiman Long) [1711604]
- [mm] mm/list_lru.c: set bit in memcg shrinker bitmap on first list_lru item appearance (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: export mem_cgroup_is_root() (Waiman Long) [1711604]
- [mm] mm/list_lru.c: pass lru argument to memcg_drain_list_lru_node() (Waiman Long) [1711604]
- [mm] mm/list_lru: pass dst_memcg argument to memcg_drain_list_lru_node() (Waiman Long) [1711604]
- [mm] mm/list_lru.c: add memcg argument to list_lru_from_kmem() (Waiman Long) [1711604]
- [mm] fs: propagate shrinker::id to list_lru (Waiman Long) [1711604]
- [fs] fs: Don't need to put list_lru into its own cacheline (Waiman Long) [1711604]
- [fs] fs/super.c: refactor alloc_super() (Waiman Long) [1711604]
- [mm] mm/workingset.c: refactor workingset_init() (Waiman Long) [1711604]
- [mm] mm, memcg: assign memcg-aware shrinkers bitmap to memcg (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: move up for_each_mem_cgroup{, _tree} defines (Waiman Long) [1711604]
- [mm] mm: assign id to every memcg-aware shrinker (Waiman Long) [1711604]
- [mm] mm: introduce CONFIG_MEMCG_KMEM as combination of CONFIG_MEMCG && !CONFIG_SLOB (Waiman Long) [1711604]
- [mm] mm/list_lru.c: combine code under the same define (Waiman Long) [1711604]
- [mm] memcg, oom: move out_of_memory back to the charge path (Waiman Long) [1711604]
- [fs] fs, mm: account buffer_head to kmemcg (Waiman Long) [1711604]
- [fs] fs: fsnotify: account fsnotify metadata to kmemcg (Waiman Long) [1711604]
- [include] mm: introduce mem_cgroup_put() helper (Waiman Long) [1711604]
- [net] tcp: refine memory limit test in tcp_fragment() (Florian Westphal) [1724584]
- [net] tcp: enforce tcp_min_snd_mss in tcp_mtu_probing() (Florian Westphal) [1719923] {CVE-2019-11479}
- [net] tcp: add tcp_min_snd_mss sysctl (Florian Westphal) [1719923] {CVE-2019-11479}
- [net] tipc: pass tunnel dev as NULL to udp_tunnel(6)_xmit_skb (Xin Long) [1722751]
- [include] ip6_tunnel: allow not to count pkts on tstats by passing dev as NULL (Xin Long) [1722751]
- [net] ip_tunnel: allow not to count pkts on tstats by setting skb's dev to NULL (Xin Long) [1722751]
- [net] netfilter: ipv6: nf_defrag: accept duplicate fragments again (Guillaume Nault) [1717106]
- [net] netfilter: ipv6: nf_defrag: fix leakage of unqueued fragments (Guillaume Nault) [1717106]
- [net] ethtool: fix potential userspace buffer overflow (Paolo Abeni) [1718393]
- [net] net-gro: fix use-after-free read in napi_gro_frags() (Paolo Abeni) [1718393]
- [net] ethtool: Check for vlan etype or vlan tci when parsing flow_rule (Paolo Abeni) [1718393]
- [include] test nouarg before dereferencing zerocopy pointers (Paolo Abeni) [1718393]
- [net] avoid weird emergency message (Paolo Abeni) [1718393]
- [net] net-gro: Fix GRO flush when receiving a GSO packet. (Paolo Abeni) [1718393]
- [net] sock_diag: fix autoloading of the raw_diag module (Paolo Abeni) [1718393]
- [net] make skb_partial_csum_set() more robust against overflows (Paolo Abeni) [1718393]
- [net] packets: Always register packet sk in the same order (Paolo Abeni) [1718393]
- [net] net-sysfs: call dev_hold if kobject_init_and_add success (Paolo Abeni) [1718393]
- [net] gro_cells: make sure device is up in gro_cells_receive() (Paolo Abeni) [1718393]
- [net] net-sysfs: Fix mem leak in netdev_register_kobject (Paolo Abeni) [1718393]
- [include] avoid false positives in untrusted gso validation (Paolo Abeni) [1718393]
- [include] net: validate untrusted gso packets without csum offload (Paolo Abeni) [1718393]
- [net] Do not allocate page fragments that are not skb aligned (Paolo Abeni) [1718393]
- [net] set default network namespace in init_dummy_netdev() (Paolo Abeni) [1718393]
- [net] Fix usage of pskb_trim_rcsum (Paolo Abeni) [1718393]
- [net] call sk_dst_reset when set SO_DONTROUTE (Paolo Abeni) [1718393]
- [net] net, skbuff: do not prefer skb allocation fails early (Paolo Abeni) [1718393]
- [net] ethtool: check the return value of get_regs_len (Paolo Abeni) [1718393]
- [net] packet: copy user buffers before orphan or clone (Paolo Abeni) [1718393]
- [net] don't keep lonely packets forever in the gro hash (Paolo Abeni) [1718393]
- [net] net-gro: reset skb->pkt_type in napi_reuse_skb() (Paolo Abeni) [1718393]
- [net] flow_dissector: do not dissect l4 ports for fragments (Paolo Abeni) [1718393]
- [net] net-ethtool: ETHTOOL_GUFO did not and should not require CAP_NET_ADMIN (Paolo Abeni) [1718393]
- [net] tipc: fix modprobe tipc failed after switch order of device registration (Jon Maloy) [1718064]
- [net] tipc: switch order of device registration to fix a crash (Jon Maloy) [1718064]
- [net] tipc: fix hanging clients using poll with EPOLLOUT flag (Jon Maloy) [1718064]
- [net] tipc: fix missing Name entries due to half-failover (Jon Maloy) [1718064]
- [net] tipc: remove rcu_read_unlock() left in tipc_udp_recv() (Jon Maloy) [1718064]
- [net] tipc: tipc_udp_recv() cleanup vs rcu verbs (Jon Maloy) [1718064]
- [net] tipc: introduce new socket option TIPC_SOCK_RECVQ_USED (Jon Maloy) [1718064]
- [net] tipc: set sysctl_tipc_rmem and named_timeout right range (Jon Maloy) [1718064]
- [net] tipc: fix link established but not in session (Jon Maloy) [1718064]
- [net] tipc: use standard write_lock & unlock functions when creating node (Jon Maloy) [1718064]
- [net] tipc: missing entries in name table of publications (Jon Maloy) [1718064]
- [net] tipc: adapt link failover for new Gap-ACK algorithm (Jon Maloy) [1718064]
- [net] tipc: reduce duplicate packets for unicast traffic (Jon Maloy) [1718064]
- [net] tipc: improve TIPC throughput by Gap ACK blocks (Jon Maloy) [1718064]
- [net] tipc: add NULL pointer check (Jon Maloy) [1718064]
- [net] tipc: fix return value check in tipc_mcast_send_sync() (Jon Maloy) [1718064]
- [net] tipc: fix a null pointer deref (Jon Maloy) [1718064]
- [net] tipc: fix use-after-free in tipc_sk_filter_rcv (Jon Maloy) [1718064]
- [net] tipc: smooth change between replicast and broadcast (Jon Maloy) [1718064]
- [net] tipc: introduce new capability flag for cluster (Jon Maloy) [1718064]
- [net] tipc: support broadcast/replicast configurable for bc-link (Jon Maloy) [1718064]
- [net] sched: avoid double free on matchall reoffload (Ivan Vecera) [1688236 1687456]
- [net] taprio: add null check on sched_nest to avoid potential null pointer dereference (Ivan Vecera) [1688236 1687456]
- [net] nfp: flower: remove unused index from nfp_fl_pedit() (Ivan Vecera) [1688236 1687456]
- [net] mlx5e: Fix calling wrong function to get inner vlan key and mask (Ivan Vecera) [1688236 1687456]
- [net] flow_offload: support CVLAN match (Ivan Vecera) [1688236 1687456]
- [net] nfp: flower: fix masks for tcp and ip flags fields (Ivan Vecera) [1688236 1687456]
- [net] sched: use the hardware intermediate representation for matchall (Ivan Vecera) [1688236 1687456]
- [net] sched: add sample action to the hardware intermediate representation (Ivan Vecera) [1688236 1687456]
- [net] cls_cgroup: avoid panic when receiving a packet before filter set (Ivan Vecera) [1688236 1687456]
- [net] cls_matchall: avoid panic when receiving a packet before filter set (Ivan Vecera) [1688236 1687456]
- [net] add a generic tracepoint for TX queue timeout (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: use struct_size() helper (Ivan Vecera) [1688236 1687456]
- [net] taprio: Add support for cycle-time-extension (Ivan Vecera) [1688236 1687456]
- [net] taprio: Add support for setting the cycle-time manually (Ivan Vecera) [1688236 1687456]
- [net] taprio: Add support adding an admin schedule (Ivan Vecera) [1688236 1687456]
- [net] taprio: Fix potencial use of invalid memory during dequeue() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Fix taprio_dequeue() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Fix taprio_peek() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Remove should_restart_cycle() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Refactor taprio_get_start_time() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Remove pointless variable assigment (Ivan Vecera) [1688236 1687456]
- [net] tc_act: drop include of module.h from tc_ife.h (Ivan Vecera) [1688236 1687456]
- [net] fib: drop include of module.h from fib_notifier.h (Ivan Vecera) [1688236 1687456]
- [net] ife: drop include of module.h from net/ife.h (Ivan Vecera) [1688236 1687456]
- [net] psample: drop include of module.h from psample.h (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: fix build without 64bit div (Ivan Vecera) [1688236 1687456]
- [net] revert: "net: sched: put back q.qlen into a single location" (Ivan Vecera) [1688236 1687456]
- [net] sched: when clearing NOLOCK, clear TCQ_F_CPUSTATS, too (Ivan Vecera) [1688236 1687456]
- [net] sched: always do stats accounting according to TCQ_F_CPUSTATS (Ivan Vecera) [1688236 1687456]
- [net] sched: prefer qdisc_is_empty() over direct qlen access (Ivan Vecera) [1688236 1687456]
- [net] caif: avoid using qdisc_qlen() (Ivan Vecera) [1688236 1687456]
- [net] sched: cbs: fix port_rate miscalculation (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: fix picos_per_byte miscalculation (Ivan Vecera) [1688236 1687456]
- [net] selftests: add a tc matchall test case (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Make sure we can write the IP header before changing DSCP bits (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Use tc_skb_protocol() helper for getting packet protocol (Ivan Vecera) [1688236 1687456]
- [net] sched: act_sample: fix divide by zero in the traffic path (Ivan Vecera) [1688236 1687456]
- [net] sched: don't set tunnel for decap action (Ivan Vecera) [1688236 1687456]
- [net] sched: introduce and use qdisc tree flush/purge helpers (Ivan Vecera) [1688236 1687456]
- [net] sched: introduce and use qstats read helpers (Ivan Vecera) [1688236 1687456]
- [net] sched: fix ->get helper of the matchall cls (Ivan Vecera) [1688236 1687456]
- [net] sched: Kconfig: update reference link for PIE (Ivan Vecera) [1688236 1687456]
- [net] dev: introduce support for sch BYPASS for lockless qdisc (Ivan Vecera) [1688236 1687456]
- [net] sched: add empty status flag for NOLOCK qdisc (Ivan Vecera) [1688236 1687456]
- [net] sched: fix cleanup NULL pointer exception in act_mirr (Ivan Vecera) [1688236 1687456]
- [net] sched: let actions use RCU to access 'goto_chain' (Ivan Vecera) [1688236 1687456]
- [net] sched: don't dereference a->goto_chain to read the chain index (Ivan Vecera) [1688236 1687456]
- [net] sched: act_vlan: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_skbmod: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_skbedit: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_simple: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_sample: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_police: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_pedit: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_nat: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_connmark: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_mirred: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_ife: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_gact: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_csum: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_bpf: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: prepare TC actions to properly validate the control action (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Interpret fwmark parameter as a bitmask (Ivan Vecera) [1688236 1687456]
- [net] net_sched: return correct value for *notify* functions (Ivan Vecera) [1688236 1687456]
- [net] sched: fix potential use-after-free in __tcf_chain_put() (Ivan Vecera) [1688236 1687456]
- [net] sched: flower: insert new filter to idr after setting its mask (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: Fix double free dst_cache (Ivan Vecera) [1688236 1687456]
- [net] sched: avoid unused-label warning (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Simplify logic in cake_select_tin() (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Permit use of connmarks as tin classifiers (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Make the dual modes fairer (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Allow test cases to be skipped (Ivan Vecera) [1688236 1687456]
- [net] sched: put back q.qlen into a single location (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: avoid slow division in drop probability decay (Ivan Vecera) [1688236 1687456]
- [net] netem: fix skb length BUG_ON in __skb_to_sgvec (Ivan Vecera) [1688236 1687456]
- [net] revert "net: sched: fw: don't set arg->stop in fw_walk() when empty" (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: fix 64-bit division (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: gitignore, ignore local tdc config file (Ivan Vecera) [1688236 1687456]
- [net] sched: fix typo in walker_check_empty() (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: fix mistake in reference link (Ivan Vecera) [1688236 1687456]
- [net] sched: act_csum: Fix csum calc for tagged packets (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: update references (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: add derandomization mechanism (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: add more cases to auto-tune alpha and beta (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change initial value of pie_vars->burst_time (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change default value of pie_params->tupdate (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change default value of pie_params->target (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change value of QUEUE_THRESHOLD (Ivan Vecera) [1688236 1687456]
- [net] sched: don't release block->lock when dumping chains (Ivan Vecera) [1688236 1687456]
- [net] sched: set dedicated tcf_walker flag when tp is empty (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: fix metadata handling (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: fix NULL pointer dereference during init (Ivan Vecera) [1688236 1687456]
- [net] Use RCU_POINTER_INITIALIZER() to init static variable (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel replace/delete (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel add/delete (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify concurrent delete (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify concurrent replace (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel rules replace (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel rules deletion (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel rules insertion (Ivan Vecera) [1688236 1687456]
- [net] selftests: tdc_batch.py: add options needed for concurrency tests (Ivan Vecera) [1688236 1687456]
- [net] sched: act_skbedit: fix refcount leak when replace fails (Ivan Vecera) [1688236 1687456]
- [net] sched: act_ipt: fix refcount leak when replace fails (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: Add dst_cache support (Ivan Vecera) [1688236 1687456]
- [net] net_sched: initialize net pointer inside tcf_exts_init() (Ivan Vecera) [1687456 1688236]
- [net] sched: potential NULL dereference in tcf_block_find() (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix a memory leak in cls_tcindex (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix a race condition in tcindex_destroy() (Ivan Vecera) [1688236 1687456]
- [net] sched: using kfree_rcu() to simplify the code (Ivan Vecera) [1688236 1687456]
- [net] sched: route: don't set arg->stop in route4_walk() when empty (Ivan Vecera) [1688236 1687456]
- [net] sched: fw: don't set arg->stop in fw_walk() when empty (Ivan Vecera) [1688236 1687456]
- [net] sched: cgroup: verify that filter is not NULL during walk (Ivan Vecera) [1688236 1687456]
- [net] sched: matchall: verify that filter is not NULL in mall_walk() (Ivan Vecera) [1688236 1687456]
- [net] sched: remove duplicated include from cls_api.c (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix two more memory leaks in cls_tcindex (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix a memory leak in cls_tcindex (Ivan Vecera) [1688236 1687456]
- [net] sched: unlock rules update API (Ivan Vecera) [1688236 1687456]
- [net] sched: refactor tcf_block_find() into standalone functions (Ivan Vecera) [1688236 1687456]
- [net] sched: add flags to Qdisc class ops struct (Ivan Vecera) [1688236 1687456]
- [net] sched: extend proto ops to support unlocked classifiers (Ivan Vecera) [1688236 1687456]
- [net] sched: extend proto ops with 'put' callback (Ivan Vecera) [1688236 1687456]
- [net] sched: track rtnl lock status when validating extensions (Ivan Vecera) [1688236 1687456]
- [net] sched: prevent insertion of new classifiers during chain flush (Ivan Vecera) [1688236 1687456]
- [net] sched: refactor tp insert/delete for concurrent execution (Ivan Vecera) [1688236 1687456]
- [net] sched: traverse classifiers in chain with tcf_get_next_proto() (Ivan Vecera) [1688236 1687456]
- [net] sched: introduce reference counting for tcf_proto (Ivan Vecera) [1688236 1687456]
- [net] sched: protect filter_chain list with filter_chain_lock mutex (Ivan Vecera) [1688236 1687456]
- [net] sched: protect chain template accesses with block lock (Ivan Vecera) [1688236 1687456]
- [net] sched: traverse chains in block with tcf_get_next_chain() (Ivan Vecera) [1688236 1687456]
- [net] sched: protect block->chain0 with block->lock (Ivan Vecera) [1688236 1687456]
- [net] sched: refactor tc_ctl_chain() to use block->lock (Ivan Vecera) [1688236 1687456]
- [net] sched: protect chain->explicitly_created with block->lock (Ivan Vecera) [1688236 1687456]
- [net] sched: protect block state with mutex (Ivan Vecera) [1688236 1687456]
- [net] Change TCA_ACT_* to TCA_ID_* to match that of TCA_ID_POLICE (Ivan Vecera) [1688236 1687456]
- [net] Move all TC actions identifiers to one place (Ivan Vecera) [1688236 1687456]
- [net] sched: use struct_size() helper (Ivan Vecera) [1688236 1687456]
- [net] documentation: bring operstate documentation up-to-date (Ivan Vecera) [1688236 1687456]
- [net] cls_flower: Remove filter from mask before freeing it (Ivan Vecera) [1688236 1687456]
- [net] cls_flower: don't expose TC actions to drivers anymore (Ivan Vecera) [1688236 1687456]
- [net] drivers: net: use flow action infrastructure (Ivan Vecera) [1688236 1687456]
- [net] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1688236 1687456]
- [net] net_sched: add performance counters for basic filter (Ivan Vecera) [1688236 1687456]
- [net] net_sched: add hit counter for matchall (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: allocate mask dynamically in fl_change() (Ivan Vecera) [1688236 1687456]
- [net] selftests: tc-testing: fix parsing of ife type (Ivan Vecera) [1688236 1687456]
- [net] net_sched: refetch skb protocol for each filter (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: fix memory leak in case of action replace (Ivan Vecera) [1688236 1687456]
- [net] sch_api: Change signature of qdisc_tree_reduce_backlog() to use ints (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Correctly update parent qlen when splitting GSO packets (Ivan Vecera) [1688236 1687456]
- [net] sched: Fix detection of empty queues in child qdiscs (Ivan Vecera) [1688236 1687456]
- [net] sched: Avoid dereferencing skb pointer after child enqueue (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: Remove old entries from rhashtable (Ivan Vecera) [1688236 1687456]
- [net] sched: simplify the qdisc_leaf code (Ivan Vecera) [1688236 1687456]
- [net] selftests: Fix test errors related to lib.mk khdr target (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fold tcf_block_cb_call() into tc_setup_cb_call() (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: Reject duplicated rules also under skip_sw (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: gitignore, ignore generated test results (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Implement the TdcResults module in tdc (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Add new TdcResults module (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Add command timeout feature to tdc (Ivan Vecera) [1688236 1687456]
- [net] netem: use a list in addition to rbtree (Ivan Vecera) [1688236 1687456]
- [net] Prevent invalid access to skb->prev in __qdisc_drop_all (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: tdc.py: Guard against lack of returncode in executed command (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: tdc.py: ignore errors when decoding stdout/stderr (Ivan Vecera) [1688236 1687456]
- [net] etf: Drop all expired packets (Ivan Vecera) [1688236 1687456]
- [net] etf: Split timersortedlist_erase() (Ivan Vecera) [1688236 1687456]
- [net] etf: Use cached rb_root (Ivan Vecera) [1688236 1687456]
- [net] etf: Cancel timer if there are no pending skbs (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: Classify packets using port ranges (Ivan Vecera) [1688236 1687456]
- [net] act_mirred: clear skb->tstamp on redirect (Ivan Vecera) [1688236 1687456]
- [net] core: use __vlan_hwaccel helpers (Ivan Vecera) [1688236 1687456]
- [net] sched: Replace call_rcu_bh() and rcu_barrier_bh() (Ivan Vecera) [1688236 1687456]
- [net] sched: Remove egdev mechanism (Ivan Vecera) [1688236 1687456]
- [net] sched: avoid writing on noop_qdisc (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: simplify the hell out u32_delete() emptiness check (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: keep track of knodes count in tc_u_common (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of tp_c (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: the tp_c argument of u32_set_parms() is always tp->data (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: pass tc_u_common to u32_set_parms() instead of tc_u_hnode (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: clean tc_u_common hashtable (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of tc_u_common ->rcu (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of tc_u_knode ->tp (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of unused argument of u32_destroy_key() (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: make sure that divisor is a power of 2 (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: disallow linking to root hnode (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: mark root hnode explicitly (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: fix coding style issues (Ivan Vecera) [1688236 1687456]
- [net] treewide: Replace more open-coded allocation size multiplications (Ivan Vecera) [1688236 1687456]
- [net] sched: remove unused helpers (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: use a plugin to build eBPF program (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: fix build of eBPF programs (Ivan Vecera) [1688236 1687456]
- [net] tc: Add support for configuring the taprio scheduler (Ivan Vecera) [1688236 1687456]
- [documentation] KVM: arm64: Clarify access behaviour for out-of-range SVE register slice IDs (Andrew Jones) [1550499]
- [documentation] KVM: Clarify KVM_{SET,GET}_ONE_REG error code documentation (Andrew Jones) [1550499]
- [documentation] KVM: Clarify capability requirements for KVM_ARM_VCPU_FINALIZE (Andrew Jones) [1550499]
- [kvm] KVM: arm/arm64: Clean up vcpu finalization function parameter naming (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Explain validity checks in set_sve_vls() (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Simplify KVM_REG_ARM64_SVE_VLS array sizing (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: WARN when avoiding divide-by-zero in sve_reg_to_region() (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Make register ioctl access errors more consistent (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Miscellaneous tidyups in guest.c (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Clean up UAPI register ID definitions (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: sys_regs: Demote redundant vcpu_has_sve() checks to WARNs (Andrew Jones) [1550499]
- [virt] KVM: arm/arm64: Demote kvm_arm_init_arch_resources() to just set up SVE (Andrew Jones) [1550499]
- [arm64] arm64/sve: Clarify vq map semantics (Andrew Jones) [1550499]
- [kvm] arm64: KVM: Fix system register enumeration (Andrew Jones) [1550499]
- [documentation] KVM: arm64/sve: Document KVM API extensions for SVE (Andrew Jones) [1550499]
- [documentation] KVM: Document errors for KVM_GET_ONE_REG and KVM_SET_ONE_REG (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Add a capability to advertise SVE support (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Allow userspace to enable SVE for vcpus (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Add pseudo-register for the guest's vector lengths (Andrew Jones) [1550499]
- [virt] KVM: arm/arm64: Add KVM_ARM_VCPU_FINALIZE ioctl (Andrew Jones) [1550499]
- [virt] KVM: arm/arm64: Add hook for arch-specific KVM initialisation (Andrew Jones) [1550499]
- [arm64] arm64/sve: In-kernel vector length availability query interface (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Enumerate SVE register indices for KVM_GET_REG_LIST (Andrew Jones) [1550499]
- [arm64] KVM: arm64/sve: Add SVE support to register access ioctl interface (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Reject ioctl access to FPSIMD V-regs on SVE vcpus (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Factor out core register ID enumeration (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Add missing #include of <linux/string.h> in guest.c (Andrew Jones) [1550499]
- [include] KVM: Allow 2048-bit register access via ioctl interface (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Context switch the SVE registers (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: System register context switch and access support (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Support runtime sysreg visibility filtering (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Propagate vcpu into read_id_reg() (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Add a vcpu flag to control SVE visibility for the guest (Andrew Jones) [1550499]
- [arm64] arm64/sve: Enable SVE state tracking for non-task contexts (Andrew Jones) [1550499]
- [arm64] arm64/sve: Check SVE virtualisability (Andrew Jones) [1550499]
- [arm64] arm64/sve: Clarify role of the VQ map maintenance functions (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Add missing #includes to kvm_host.h (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Refactor kvm_arm_num_regs() for easier maintenance (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Delete orphaned declaration for __fpsimd_enabled() (Andrew Jones) [1550499]
- [arm64] arm64: fpsimd: Always set TIF_FOREIGN_FPSTATE on task state flush (Andrew Jones) [1550499]
- [documentation] KVM: Documentation: Document arm64 core registers in detail (Andrew Jones) [1550499]
- [arm64] arm64/sve: Disentangle <uapi/asm/ptrace.h> from <uapi/asm/sigcontext.h> (Andrew Jones) [1550499]
- [arm64] arm64/sve: ptrace: Fix SVE_PT_REGS_OFFSET definition (Andrew Jones) [1550499]

* Fri Jun 28 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-110.el8]
- [fs] xfs: fix reporting supported extra file attributes for statx() (Bill O'Donnell) [1721034]
- [scsi] scsi: hpsa: correct ioaccel2 chaining (Joseph Szczypek) [1706121]
- [powerpc] powerpc/pseries/mobility: rebuild cacheinfo hierarchy post-migration (Steve Best) [1720929]
- [powerpc] powerpc/pseries/mobility: prevent cpu hotplug during DT update (Steve Best) [1720929]
- [powerpc] powerpc/cacheinfo: add cacheinfo_teardown, cacheinfo_rebuild (Steve Best) [1720929]
- [kernel] cpuset: restore sanity to cpuset_cpus_allowed_fallback() (Joel Savitz) [1677311]

* Wed Jun 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-109.el8]
- [scripts] scripts: override locale from environment when running recordmcount.pl (Prarit Bhargava) [1721515]
- [netdrv] net: aquantia: fix wol configuration not applied sometimes (Igor Russkikh) [1662198]
- [x86] x86/resctrl: Prevent NULL pointer dereference when local MBM is disabled (Prarit Bhargava) [1721208]
- [fs] inotify: Fix fsnotify_mark refcount leak in inotify_update_existing_watch() (Miklos Szeredi) [1451863]
- [fs] inotify: Fix fd refcount leak in inotify_add_watch(). (Miklos Szeredi) [1451863]
- [fs] fanotify: Use inode_is_open_for_write (Miklos Szeredi) [1451863]
- [fs] fanotify: Make sure to check event_len when copying (Miklos Szeredi) [1451863]
- [fs] fsnotify/fdinfo: include fdinfo.h for inotify_show_fdinfo() (Miklos Szeredi) [1451863]
- [include] fanotify: introduce new event mask FAN_OPEN_EXEC_PERM (Miklos Szeredi) [1451863]
- [include] fsnotify: refactor fsnotify_parent()/fsnotify() paired calls when event is on path (Miklos Szeredi) [1451863]
- [include] fanotify: introduce new event mask FAN_OPEN_EXEC (Miklos Szeredi) [1451863]
- [fs] fanotify: return only user requested event types in event mask (Miklos Szeredi) [1451863]
- [fs] fanotify: support reporting thread id instead of process id (Miklos Szeredi) [1451863]
- [fs] fanotify: add BUILD_BUG_ON() to count the bits of fanotify constants (Miklos Szeredi) [1451863]
- [fs] fsnotify: convert runtime BUG_ON() to BUILD_BUG_ON() (Miklos Szeredi) [1451863]
- [fs] fanotify: deprecate uapi FAN_ALL_* constants (Miklos Szeredi) [1451863]
- [fs] fanotify: simplify handling of FAN_ONDIR (Miklos Szeredi) [1451863]
- [include] fanotify: fix collision of internal and uapi mark flags (Miklos Szeredi) [1451863]
- [fs] fanotify: store fanotify_init() flags in group's fanotify_data (Miklos Szeredi) [1451863]
- [fs] fanotify: clean up handling of "mark type" (Miklos Szeredi) [1451863]
- [fs] fsnotify: fix false positive warning on inode delete (Miklos Szeredi) [1451863]
- [include] inotify: Add flag IN_MASK_CREATE for inotify_add_watch() (Miklos Szeredi) [1451863]
- [fs] fanotify: factor out helpers to add/remove mark (Miklos Szeredi) [1451863]
- [fs] fsnotify: add helper to get mask from connector (Miklos Szeredi) [1451863]
- [fs] fsnotify: let connector point to an abstract object (Miklos Szeredi) [1451863]
- [fs] fsnotify: pass connp and object type to fsnotify_add_mark() (Miklos Szeredi) [1451863]
- [fs] fsnotify: use typedef fsnotify_connp_t for brevity (Miklos Szeredi) [1451863]
- [powerpc] powerpc/pseries: Fix oops in hotplug memory notifier (Steve Best) [1720932]
- [netdrv] net: aquantia: tcp checksum 0xffff being handled incorrectly (Igor Russkikh) [1719176]
- [netdrv] net: aquantia: fix LRO with FCS error (Igor Russkikh) [1719176]
- [netdrv] net: aquantia: check rx csum for all packets in LRO session (Igor Russkikh) [1719176]
- [netdrv] net: aquantia: tx clean budget logic error (Igor Russkikh) [1719176]
- [security] selinux: log raw contexts as untrusted strings (Ondrej Mosnacek) [1719666]
- [kernel] audit: add saddr_fam filter field (Richard Guy Briggs) [1715679]
- [kernel] audit: re-structure audit field valid checks (Richard Guy Briggs) [1715679]
- [kernel] audit: rename FILTER_TYPE to FILTER_EXCLUDE (Richard Guy Briggs) [1715679]
- [kernel] audit: allow other filter list types for AUDIT_EXE (Richard Guy Briggs) [1715679]
- [documentation] ovl: doc: add non-standard corner cases (Miklos Szeredi) [1718370]
- [fs] ovl: support the FS_IOC_FSETXATTR ioctls (Miklos Szeredi) [1718370]
- [fs] ovl: relax WARN_ON() for overlapping layers use case (Miklos Szeredi) [1718370]
- [fs] ovl: check the capability before cred overridden (Miklos Szeredi) [1718370]
- [fs] ovl: do not generate duplicate fsnotify events for "fake" path (Miklos Szeredi) [1718370]
- [fs] ovl: support stacked SEEK_HOLE/SEEK_DATA (Miklos Szeredi) [1718370]
- [fs] ovl: fix missing upper fs freeze protection on copy up for ioctl (Miklos Szeredi) [1718370]
- [fs] fuse: fallocate: fix return with locked inode (Miklos Szeredi) [1717457]
- [fs] fuse: honor RLIMIT_FSIZE in fuse_file_fallocate (Miklos Szeredi) [1717457]
- [fs] fuse: decrement NR_WRITEBACK_TEMP on the right page (Miklos Szeredi) [1717457]
- [fs] fuse: handle zero sized retrieve correctly (Miklos Szeredi) [1717457]
- [fs] fuse: continue to send FUSE_RELEASEDIR when FUSE_OPEN returns ENOSYS (Miklos Szeredi) [1717457]

* Mon Jun 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-108.el8]
- [mm] mm/mincore.c: make mincore() more conservative (Rafael Aquini) [1664203] {CVE-2019-5489}
- [x86] x86/umip: Make the UMIP activated message generic (David Arcari) [1720014]
- [x86] x86/umip: Print UMIP line only once (David Arcari) [1720014]
- [crypto] crypto: vmac - separate tfm and request context (Desnes Augusto Nunes do Rosario) [1702702]
- [crypto] crypto: ccp - Update driver messages to remove some confusion (David Arcari) [1719026]
- [block] blk-mq: fix hang caused by freeze/unfreeze sequence (Ming Lei) [1719835]
- [block] blk-mq: remove WARN_ON(!q->elevator) from blk_mq_sched_free_requests (Ming Lei) [1719835]
- [block] block: free sched's request pool in blk_cleanup_queue (Ming Lei) [1719835]
- [block] block: don't protect generic_make_request_checks with blk_queue_enter (Ming Lei) [1719835]
- [block] block: move blk_exit_queue into __blk_release_queue (Ming Lei) [1719835]
- [block] block: print offending values when cloned rq limits are exceeded (Ming Lei) [1719816]
- [block] block: fix page leak when merging to same page (Ming Lei) [1662864]
- [x86] RHEL: fix build of spec_ctrl.h for older assemblers (Jeff Moyer) [1719406]
- [drm] drm/amd/display: Initialize stream_update with memset (Jeff Moyer) [1719406]
- [mm] mm/gup: finish consolidating error handling (Jeff Moyer) [1641506]
- [mm] mm/gup: cache dev_pagemap while pinning pages (Jeff Moyer) [1641506]
- [rpmspec] kernel packaging: Fix extra namespace collision (Prarit Bhargava) [1699868]
- [rpmspec] redhat: kernel-selftests-internal: add dependencies (Jiri Benc) [1717943]
- [kernel] kernel/module.c: Only return -EEXIST for modules that have finished loading (Prarit Bhargava) [1666939]
- [input] Input: elantech - remove P52 and P72 from SMBus blacklist (Benjamin Tissoires) [1703157]
- [input] Input: elan_i2c - handle physical middle button (Benjamin Tissoires) [1703157]
- [input] Input: elantech/SMBus - export all capabilities from the PS/2 node (Benjamin Tissoires) [1703157]
- [input] Input: elan_i2c - do not query the info if they are provided (Benjamin Tissoires) [1703157]
- [input] Input: elantech - detect middle button based on firmware version (Benjamin Tissoires) [1703157]
- [input] Input: elantech - add helper function elantech_is_buttonpad() (Benjamin Tissoires) [1703157]
- [input] Input: elantech - query the min/max information beforehand too (Benjamin Tissoires) [1703157]
- [input] Input: elantech - enable middle button support on 2 ThinkPads (Benjamin Tissoires) [1703157]
- [input] Input: elan_i2c - increment wakeup count if wake source (Benjamin Tissoires) [1703157]
- [kernel] timekeeping: Update multiplier when NTP frequency is set directly (Prarit Bhargava) [1714164]
- [fs] xfs: fix use after free in buf log item unlock assert (Brian Foster) [1666150]
- [fs] xfs: add missing error check in xfs_prepare_shift() (Brian Foster) [1699214]
- [documentation] Documentation: Fix grammatical error in sysctl/fs.txt & clarify negative dentry (Waiman Long) [1673955]
- [fs] fs/dcache: Track & report number of negative dentries (Waiman Long) [1673955]
- [fs] fs/dcache: Fix incorrect nr_dentry_unused accounting in shrink_dcache_sb() (Waiman Long) [1673955]
- [net] tcp: tcp_fragment() should apply sane memory limits (Florian Westphal) [1719858] {CVE-2019-11478}
- [net] tcp: limit payload size of sacked skbs (Florian Westphal) [1719603] {CVE-2019-11477}

* Fri Jun 14 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-107.el8]
- [tools] kvm: selftests: make hyperv_cpuid test pass on AMD (Vitaly Kuznetsov) [1718501]
- [scsi] vmw_pvscsi: Fixed to work with SG_CHAIN (Ewan Milne) [1717278]
- [x86] mark AMD Rome processors supported (David Arcari) [1520002]
- [fs] ext4: zero out the unused memory region in the extent tree block (Lukas Czerner) [1715276] {CVE-2019-11833}
- [s390] s390/smp: Fix calling smp_call_ipl_cpu() from ipl CPU (David Hildenbrand) [1715041]
- [vfio] vfio/type1: Limit DMA mappings per container (Alex Williamson) [1695592] {CVE-2019-3882}
- [tools] selftests/powerpc: Remove Power9 paste tests (Diego Domingos) [1662374]
- [tools] selftests/powerpc: Remove Power9 copy_unaligned test (Diego Domingos) [1662374]
- [tools] selftests/powerpc: Fix ptrace tm failure (Diego Domingos) [1662374]
- [netdrv] mlxsw: core: Prevent reading unsupported slave address from SFP EEPROM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Prevent QSFP module initialization for old hardware (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix autoneg status in ethtool (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Reincrease PCI reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Put MC TCs into DWRR mode (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Add a multicast pool for Spectrum-2 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test VRF MAC vetoing (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not check VRF MAC address (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw ordered workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for EMAD workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add MDB entries in prepare phase (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: mlxsw: core: avoid -Wint-in-bool-context warning (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Initialize base_mac (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Prevent duplication during QSFP module initialization (Ivan Vecera) [1680241]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Extend initialization by querying resources data (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Extend input parameters list of command API (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Modify input parameter name in initialization API (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Fix comment misspelling (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Move resource query API to common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Add ethtool support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Make structures and variables names shorter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Move ethtool module callbacks to a common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Make mlxsw_sp_acl_tcam_vregion_rehash() return void (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remember where to continue rehash migration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Allow to interrupt/continue rehash work (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Do rollback as another call to mlxsw_sp_acl_tcam_vchunk_migrate_all() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Put vchunk migrate start/end code into separate functions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Put this_is_rollback to rehash context struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Rename variables in mlxsw_sp_acl_tcam_ventry_migrate() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: assign vchunk->chunk by the newly created chunk (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: assign vregion->region by the newly created region (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push code start/end from mlxsw_sp_acl_tcam_vregion_migrate() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push rehash start/end code into separate functions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce new rehash context struct and save hint_priv there (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't migrate already migrated entry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push rehash dw struct into rehash sub-struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Handle SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: remove set but not used variable 'autoneg_status' (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add massive delta rehash test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Check migrate end trace (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add vregion migration end tracepoint (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add IPv6 variant of simple delta rehash test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't take mutex in mlxsw_sp_acl_tcam_vregion_rehash_work() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove RTNL lock assertions from ERP code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't take rtnl lock during vregion_rehash_intrvl_set() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce a mutex to guard objagg instance manipulation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Enable vregion rehash per-profile (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce mutex to guard Bloom Filter updates (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce vregion mutex (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Refactor vregion association code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce a mutex to guard region list updates (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split TCAM group structure into two (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove unused ops field from group structure (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 ASIC support for new port types and speeds (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 ASIC port type-speed operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add new port type-speed fields for PTYS register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: 80 columns wrapping change (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Rename p_eth_proto_adm to full name p_eth_proto_admin (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add port type-speed operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Rename port type-speed functions to ASIC specific (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Query port connector type from firmware (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove unsupported eth_proto_lp_advertise field in PTYS (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove duplicate port link mode entry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Avoid -Wformat-truncation warnings (Ivan Vecera) [1680241]
- [netdrv] net: Remove SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS_SUPPORT (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Reject overlarge headroom size requests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Update port headroom configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Add Spectrum-2 shared buffer configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_mm in sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_cm in sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_prs in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_pms in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep pool descriptors in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allocate prs & pms dynamically (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add struct mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change IP2ME CPU policer rate and burst size values (Ivan Vecera) [1680241]
- [netdrv] mlxsw: __mlxsw_sp_port_headroom_set(): Fix a use of local variable (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add some missing configuration symbols (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: fix spelling mistake "temprature" -> "temperature" (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend thermal module with per QSFP module thermal zones (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Allow thermal zone binding to an external cooling device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Add QSFP module temperature label attribute to hwmon (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend hwmon interface with QSFP module temperature attributes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend hwmon interface with fan fault attribute (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Rename cooling device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Replace thermal temperature trips with defines (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Modify thermal zone definition (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Set different thermal polling time based on bus frequency capability (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Add API for QSFP module temperature thresholds reading (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Fan Out of Range Event Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Management Temperature Bulk Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Move QSFP EEPROM definitions to common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Remove unused variables (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: avoid double sourcing of lib.sh (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Fix VLAN modify action support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Drop unnecessary WARN_ON_ONCE() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set LAG port collector only when active (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Remove getting PORT_BRIDGE_FLAGS (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add simple delta rehash test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add couple of vregion rehash tracepoints (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: add "acl_region_rehash_interval" devlink param (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement region migration according to hints (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add multi field to PAGT register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Pass hints priv all the way to ERP code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement basic ERP rehash hits creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split entry struct into entry and ventry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split chunk struct into chunk and vchunk (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split region struct into region and vregion (Ivan Vecera) [1680241]
- [netdrv] lib: objagg: implement optimization hints assembly and use hints for object creation (Ivan Vecera) [1680241]
- [netdrv] devlink: publish params only after driver init is done (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for blackhole routes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Offload blackhole routes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Implement ndo_get_port_parent_id() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Trace EMAD errors (Ivan Vecera) [1680241]
- [netdrv] drivers: net: use flow action infrastructure (Ivan Vecera) [1680241]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_flower: Fix test result handling (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Ignore ARP (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Enable forwarding (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Flush neighbors (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Fix roaming test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Wait for tardy mirrored packets (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_changes: Fix TTL test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Update ping limits (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Update ping limits (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Make ping timeout configurable (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Add delta two masks one key test (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Fix multiple_masks_test (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Extend and move trace helpers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add C-TCAM spill tracepoint (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Include delta bits into hashtable key (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Use OK instead of PASS in test output (Ivan Vecera) [1680241]
- [tools] selftests: net: forwarding: change devlink resource support checking (Ivan Vecera) [1680241]
- [documentation] Documentation: add devlink param file for mlxsw driver (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add more extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Fix rul/rule typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Move mr_ruleset and mr_rule structs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove unnecessary arg on action_replace call path (Ivan Vecera) [1680241]
- [netdrv] mlxfw: Replace license text with SPDX identifiers and adjust copyrights (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Enable VXLAN on Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add support for VXLAN on Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Breakout common code to a common function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose functions to create and destroy underlay RIF (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for ARP suppression (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VXLAN symmetric routing (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for ARP decapsulation (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VXLAN asymmetric routing (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology with keys test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology with key test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology with keys test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology with key test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP tunneling lib (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add GRE tunnel support for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Update tunnel decap properties (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Support RIF without device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Change mlxsw_sp_ipip_lb_ul_vr_id() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add underlay RIF ID support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Mark RIF index as taken before creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Adjust loopback RIF configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set RIF ops per ASIC type (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Split RIF ops array for Spectrum-2 support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add underlay egress RIF field in RTDP register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add fields to RITR - Router Interface Table Register (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for externally learned FDB entries (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test FDB offload indication (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not treat static FDB entries as sticky (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Update dummy FID index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Return error on PCI reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Increase PCI SW reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Ring CQ's doorbell before RDQ's (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test veto of unsupported VXLAN FDBs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add extack messages to VXLAN FDB rejection (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Add extack to mlxsw_sp_nve_ops.fdb_replay (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl_bloom_filter: use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VLAN deletion (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Set PVID correctly during VLAN deletion (Ivan Vecera) [1680241]
- [net] net: bridge: Fix VLANs memory leak (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test case for VLAN addition error flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Replace error code with EINVAL (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Avoid returning errors in commit phase (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add VXLAN dependency for spectrum (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Disable lag port TX before removing it (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove ASSERT_RTNL()s in module removal flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add cleanup after C-TCAM update error condition (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: drop useless LIST_HEAD (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add router test with VID 1 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Adjust test regarding VID 1 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove limitation regarding VID 1 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Switch to VID 4095 as default VID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add an helper function to cleanup VLAN entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Store pointer to default port VLAN in port struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Allow controlling destruction of default port VLAN (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set PVID during port initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Replace hard-coded default VID with a define (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test case for L3 VNI (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not force specific configuration order (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add rtnetlink tests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Hold a reference on RIF's netdev (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Make RIF deletion more robust (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Propagate 'struct mlxsw_sp' further (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Properly cleanup LAG uppers when removing port from LAG (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove reference count from VLAN entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Handle VLAN device unlinking (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Remove unused function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not destroy RIFs based on FID's reference count (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Sanitize VLAN interface's uppers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Fix memory leak upon driver reload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add trap for decapsulated ARP packets (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Increase timeout during firmware flash process (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Update the supported firmware to version 13.1910.622 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom delta test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom filter complex test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom filter simple test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Activate Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Set master RP index on transition to eRP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Update Bloom filter on eRP transitions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Set A-TCAM rules in Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Bloom filter update (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Bloom filter handling (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 Bloom filter resource (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy Engine Algorithmic Bloom Filter Entries Register (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test FID RIF MAC vetoing (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test RIF MAC vetoing (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Veto unsupported RIF MAC addresses (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp.mac_mask (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Generalize mlxsw_sp_netdevice_router_port_event() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: extack: Test VLAN add on a port device (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: extack: Test VLAN add on a VXLAN device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack on port VLAN events (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack on VXLAN VLAN events (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add multicast routing test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add Multicast routing support for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Limit priority value (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Support rule creation without action creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add replace rule action operation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add multicast router profile operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Spectrum-2 keys (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change stage of ACL initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy Engine Multicast Router Binding Table Register (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add PVID test case for VXLAN with VLAN-aware bridges (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: vxlan: Test FDB un/marking on VXLAN join/leave (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Un/offload FDB on nve_fid_disable/enable (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp_fid_ops.fdb_clear_offload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add mlxsw_sp_nve_ops.fdb_clear_offload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add mlxsw_sp_nve_ops.fdb_replay (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Publish mlxsw_sp_switchdev_notifier (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Track NVE type at FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Fix VLAN device deletion via ioctl (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Relax GRE decap matching check (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Avoid leaking FID's reference count (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Remove easily triggerable warnings (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a new test extack.sh (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add one-armed router test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Mirror loopbacked packets instead of trapping them (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Load firmware version based on devlink parameter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Reset firmware after flash during driver initialization (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add VxLAN test with a VLAN-aware bridge (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN configuration with a VLAN-aware bridge (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Consider VLAN-aware bridges as valid (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable VxLAN enslavement to VLAN-aware bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Prepare function for VLAN-aware bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Unify VxLAN leave function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Add API to lookup 802.1Q FIDs without creating them (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Flip driver to use emulated 802.1Q FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Introduce emulated VLAN RIFs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Introduce emulated 802.1Q FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Make flood index calculation more robust (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not set field when it is reserved (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Consider VxLAN learning enabled as valid (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Allow VxLAN learning (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Allow deletion of learned FDB entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Process learned VxLAN FDB entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add API to resolve learned IP addresses (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Allow FID lookup by its index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Store ifindex of NVE device in FID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add definition of unicast tunnel record for SFN register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend cooling device with cooling levels (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN flooding (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose discard counters via ethtool (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add simple delta test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Implement delta for ERP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Push code related to num_ctcam_erps inc/dec into separate helpers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Remove mlxsw_afk_encode() block range args and key/mask check (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Don't encode the key again in mlxsw_sp_acl_atcam_12kb_lkey_id_get() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl: Change order of args of ops->encode_block() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Pass key pointer to master_mask_set/clear (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl_erp: Convert to use objagg for tracking ERPs (Ivan Vecera) [1680241]
- [tools] selftests: Adjust spectrum-2 ctcam_two_atcam_masks_test (Ivan Vecera) [1680241]
- [tools] selftests: Adjust spectrum-2 two_mask_test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix IP2ME CPU policer configuration (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Add a test for UC awareness (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Tweak for min shaper (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set minimum shaper on MC TCs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: QEEC: Add minimum shaper fields (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Fix devlink unregister flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Don't ignore deletions of learned MACs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add support for VxLAN encapsulation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable VxLAN enslavement to bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Configure matching local routes for NVE decap (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Clear NVE configuration when destroying 802.1D FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Implement VxLAN operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Implement common NVE core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Allow querying VR ID based on table ID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Enable local routes promotion to perform NVE decap (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Add APIs to lookup FID without creating it (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Allow setting and clearing NVE properties on FID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Fix use-after-free when flashing firmware during init (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add NVE packet traps (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add NVE resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Monitoring Parsing State Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add definition of unicast tunnel record for SFD register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE QoS Default Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE QoS Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Decapsulation ECN Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Encapsulation ECN Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Underlay Multicast Table Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunnel Port Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE General Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Seed LAG hash function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Extend FDB flush types for NVE (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add a new type of KVD linear record (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Move L3 protocol and address definitions to global header file (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not assume notifier information type (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Check notification relevance based on upper device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Prepare for VxLAN FDB notifications (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove misuses of private header file (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Make executable (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Have lldpad_app_wait_set() wait for unknown, too (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Fix a typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Delete RIF when VLAN device is removed (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Derive event type from event queue number (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Make MLXSW_SP1_FWREV_MINOR a hard requirement (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Bump required firmware version (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for UC behavior under MC flood (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add mtu_set(), mtu_restore() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add ethtool_stats_get() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Tweak SBMM configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Configure MC pool (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow configuration of static pools (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Pass SBPM min_size in cells (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow an infinite maximum for per-TC pool limit (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow pools of infinite size (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep shared buffer size in mlxsw_sp_sb (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Split TC_COUNT into ingress and egress (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Use devlink pool indices throughout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Init shaper for TCs 8..15 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Set up a dedicated pool for BUM traffic (Ivan Vecera) [1680241]
- [netdrv] mlxsw: remove unused arrays mlxsw_i2c_driver_name and mlxsw_pci_driver_name (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: remove unnecessary function mlxsw_core_driver_put (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose counter for all 16 TCs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Include RFC-2819 counters in stats length (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Replace license text with SPDX identifiers and adjust copyrights (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add TC flower test for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Reset FW after flash (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Update the supported firmware to version 13.1702.6 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Disallow usage of vlan_id key on egress (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: use PTR_ERR_OR_ZERO() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: gre_multipath: Update next-hop statistics match criteria (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Configure MC-aware mode on mlxsw ports (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix a typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Switch Traffic Class Table is Multicast-Aware Register (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add test for ip_forward_update_priority (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Move DSCP capture to lib.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Move lldpad waiting to lib.sh (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Handle sysctl_ip_fwd_update_priority (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Extract work-scheduling into a new function (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL team LACP (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL team (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Introduce $ARPING (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Support team devices (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add require_command() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_dscp_bridge: Fix (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add test for trust-DSCP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Support ieee_setapp, ieee_delapp (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Priority to DSCP Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS ReWrite Enable Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Priority Trust State Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Port DSCP to Priority Mapping Register (Ivan Vecera) [1680241]
- [tools] selftests: add a selftest for directed broadcast forwarding (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: add tests for TC chain get and dump operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Start using A-TCAM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM rule insertion and deletion (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Pass C-TCAM region and entry to insert function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM region initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Make global TCAM resources available to regions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Encapsulate C-TCAM region in A-TCAM region (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Allow encoding a partial key (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Extend Spectrum-2 region struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add support for C-TCAM eRPs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Enable C-TCAM only mode in eRP core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement common eRP core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 eRP resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 maximum large key ID resource (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine eRP Table Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine TCAM Entry Register Version 3 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Prepare PERERP register for A-TCAM usage (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Propagate extack pointer (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: gre_multipath: Drop IPv6 tests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Implement chain template hinting (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Extend to support Spectrum-2 ASIC (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add initial Spectrum-2 ACL implementation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add region association callback (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add support for Spectrum-2 block encoding (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Prepare for Spectrum-2 block encoding (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine General Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region eRP Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region Association Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: acl: Introduce activity get operation for action block/set (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add support for activity information from PEFA register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Introduce flex key blocks for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 variant of flex actions ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_mr_tcam: Add Spectrum-2 stubs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add KVDL manager implementation for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Infrastructure Entry Delete Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose counters for various packet sizes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Optimize processing of VRRP MACs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add VRRP traps (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Direct macvlans' MACs to router (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable macvlan upper devices (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_nh: Unset rp_filter on host VRF (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_span: Change LAG lower selection (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add couple of Spectrum-2 KVD resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Prepare for multiple FW versions for Spectrum and Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement priority setting for rules inserted to TCAM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add priority field for PTCEV2 register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Move block items encoding into Spectrum op (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Convert mlxsw_afk_create args to ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add tcam init/fini ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split TCAM handling 3 ways (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_mr_tcam: Push Spectrum-specific operations into a separate file (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Pass entry_count to free function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Pass entry type to alloc/free (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Push out KVD linear management into ops (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Tighten up VLAN capture (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Fix helper to get the first KVD linear index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Allow the first set to be dummy (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Put pointer to flex action ops to mlxsw_sp (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_keys: Change SRC_SYS_PORT flex key element size (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_keys: Split MAC and IP address flex key elements (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Ignore always-zeroed bits in tp->prio (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Introduce Flex2 key type for PTAR register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change name of mlxsw_sp_afk_blocks to mlxsw_sp1_afk_blocks (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: avoid uninitialized variable access (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add mlxsw-specific test for mirror to gretap (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Allow importing dependent libraries (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: test for bridge port isolation (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL 802.1q (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL 802.1d (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add scale test for resources (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for mirror-to-gretap test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add scale test for mirror-to-gretap (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for tc flower test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add tc flower scale test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for router test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add router test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add devlink KVD resource test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add devlink_lib_spectrum.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add devlink_lib.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Parameterize NUM_NETIFS in two functions (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add check_err_fail() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Allow lib.sh sourcing from other directories (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_changes: Fix waiting for neighbor (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Split out setup_wait_dev() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test multipath tunneling (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Unset rp_filter (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test routed bridge interface (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Ban PVID change if bridge has a RIF (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add mlxsw_sp_rif_fid() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Publish mlxsw_sp_rif_find_by_dev() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Allocate FID according to PVID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Propagate extack to .fid_get() (Ivan Vecera) [1680241]
- [netdrv] net: phy: realtek: Dummy IRQ calls for RTL8366RB (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add generic Realtek PHY driver (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: use new PHYID matching macros (Corinna Vinschen) [1680528]
- [include] net: phy: add macros for PHYID matching (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: load driver for all PHYs with a Realtek OUI (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: fix RTL8201F sysfs name (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: Support RTL8366RB variant (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add missing entry for RTL8211C to mdio_device_id table (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add support for RTL8211C (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add missing entry for RTL8211 to mdio_device_id table (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add support for RTL8211 (Corinna Vinschen) [1680528]
- [netdrv] r8169: change irq handler to always trigger NAPI polling (Corinna Vinschen) [1680528]
- [netdrv] r8169: create function pointer array for chip hw init functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: create function pointer array for PHY init functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable ASPM again (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable tx interrupt coalescing on RTL8168 (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: use netif_receive_skb_list batching" (Corinna Vinschen) [1680528]
- [netdrv] r8169: use netif_receive_skb_list batching (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable default rx interrupt coalescing on RTL8168 (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix cable re-plugging issue (Corinna Vinschen) [1680528]
- [netdrv] r8169: use netif_start_queue instead of netif_wake_qeueue in rtl8169_start_xmit (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't read interrupt mask register in interrupt handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded mmiowb barriers (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: make use of xmit_more and __netdev_sent_queue" (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: remove unneeded mmiowb barriers" (Corinna Vinschen) [1680528]
- [netdrv] r8169: Avoid pointer aliasing (Corinna Vinschen) [1680528]
- [netdrv] r8169: Load MAC address from device tree if present (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl_wol_pll_power_down (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve WoL handling (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable EEE per default on RTL8168f (Corinna Vinschen) [1680528]
- [netdrv] r8169: add EEE support for RTL8168f (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable EEE per default on chip versions from RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: add general EEE support for chip versions from RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out PHY init sequence adjusting 10M and ALDPS (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out disabling ALDPS (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve firmware handling (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove PCI DAC support (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rx buffer allocation (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out getting ether_clk (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace mii_bus member with phy_device member in struct rtl8169_private (Corinna Vinschen) [1680528]
- [netdrv] r8169: reset chip synchronously in __rtl8169_resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: add helpers for locking / unlocking the config registers (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rtl_pcie_state_l2l3_enable (Corinna Vinschen) [1680528]
- [netdrv] r8169: initialize task workqueue only once (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded call in pcierr (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl_get_events (Corinna Vinschen) [1680528]
- [netdrv] r8169: load Realtek PHY driver module before r8169 (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't try to read counters if chip is in a PCI power-save state (Corinna Vinschen) [1680528]
- [netdrv] r8169: Add support for new Realtek Ethernet (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix WoL device wakeup enable (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve spurious interrupt detection (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix crash if CONFIG_DEBUG_SHIRQ is enabled (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded mmiowb barriers (Corinna Vinschen) [1680528]
- [netdrv] ethernet/realtek: Replace synchronize_sched() with synchronize_rcu() (Corinna Vinschen) [1680528]
- [netdrv] r8169: make use of xmit_more and __netdev_sent_queue (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace macro TX_FRAGS_READY_FOR with a function (Corinna Vinschen) [1680528]
- [netdrv] r8169: use napi_consume_skb where possible (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify detecting chip versions with same XID (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove default chip versions (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove ancient GCC bug workaround in a second place (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve chip version identification (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify ocp functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove workaround for ancient gcc bug (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove manual padding in struct ring_info (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove "not PCI Express" message (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove print_mac_version (Corinna Vinschen) [1680528]
- [netdrv] r8169: use PCI_VDEVICE macro (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace event_slow with irq_mask (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unused interrupt sources (Corinna Vinschen) [1680528]
- [netdrv] r8169: use dev_get_drvdata where possible (Corinna Vinschen) [1680528]
- [netdrv] r8169: merge rtl_irq_enable and rtl_irq_enable_all (Corinna Vinschen) [1680528]
- [pci] PCI: add USR vendor id and use it in r8169 and w6692 driver (Corinna Vinschen) [1680528]
- [netdrv] net: ethernet: Convert phydev advertize and supported from u32 to link mode (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix broken Wake-on-LAN from S5 (poweroff) (Corinna Vinschen) [1680528]
- [netdrv] r8169: add support for Byte Queue Limits (Corinna Vinschen) [1680528]
- [netdrv] r8169: handle all interrupt events in the hard irq handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix NAPI handling under high load (Corinna Vinschen) [1680528]
- [netdrv] r8169: re-enable MSI-X on RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded call to netif_stop_queue in rtl8169_net_suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify rtl8169_set_magic_reg (Corinna Vinschen) [1680528]
- [netdrv] r8169: Enable MSI-X on RTL8106e (Corinna Vinschen) [1680528]
- [netdrv] r8169: set RX_MULTI_EN bit in RxConfig for 8168F-family chips (Corinna Vinschen) [1680528]
- [netdrv] r8169: always autoneg on resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix network stalls due to missing bit TXCFG_AUTO_FIFO (Corinna Vinschen) [1680528]
- [netdrv] r8169: Disable clk during suspend / resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve a check in rtl_init_one (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rtl8169_irq_mask_and_ack (Corinna Vinschen) [1680528]
- [netdrv] r8169: use default watchdog timeout (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix autoneg issue on resume with RTL8168E (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove duplicated RTL8169s PHY initialization steps (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify RTL8169 PHY initialization (Corinna Vinschen) [1680528]
- [netdrv] r8169: Get and enable optional ether_clk clock (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable ASPM on RTL8106E (Corinna Vinschen) [1680528]
- [netdrv] r8169: Align ASPM/CLKREQ setting function with vendor driver (Corinna Vinschen) [1680528]
- [netdrv] r8169: Clear RTL_FLAG_TASK_*_PENDING when clearing RTL_FLAG_TASK_ENABLED (Corinna Vinschen) [1680528]
- [netdrv] r8169: set TxConfig register after TX / RX is enabled, just like RxConfig (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't configure max jumbo frame size per chip version (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't configure csum function per chip version (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify interrupt handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't include asm headers directly (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove version info (Corinna Vinschen) [1680528]
- [netdrv] r8169: restore previous behavior to accept BIOS WoL settings (Corinna Vinschen) [1680528]
- [netdrv] r8169: power down chip in probe (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't read chip phy status register (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove mii_if_info member from struct rtl8169_private (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl8169_set_speed_xmii (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_speed_down / phy_speed_up (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_mii_ioctl (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_ethtool_nway_reset (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_ethtool_(g|s)et_link_ksettings (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace open-coded PHY soft reset with genphy_soft_reset (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_resume/phy_suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: add basic phylib support (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix runtime suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove old PHY reset hack (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove TBI 1000BaseX support (Corinna Vinschen) [1680528]
- [netdrv] r8169: use standard debug output functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: reject unsupported WoL options (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't check WoL when powering down PHY and interface is down (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve saved_wolopts handling (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: restore previous behavior to accept BIOS WoL settings" (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve phy initialization when resuming (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable ASPM on RTL8168E-VL (Corinna Vinschen) [1680528]
- [netdrv] r8169: align ASPM entry latency setting with vendor driver (Corinna Vinschen) [1680528]
- [netdrv] r8169: Reinstate ASPM Support (Corinna Vinschen) [1680528]
- [netdrv] r8169: Don't disable ASPM in the driver (Corinna Vinschen) [1680528]
- [kernel] kernel/sched/psi.c: expose pressure metrics on root cgroup (Waiman Long) [1678388]
- [kernel] psi: introduce psi monitor (Waiman Long) [1678388]
- [spi] include/: refactor headers to allow kthread.h inclusion in psi_types.h (Waiman Long) [1678388]
- [kernel] psi: track changed states (Waiman Long) [1678388]
- [kernel] psi: split update_stats into parts (Waiman Long) [1678388]
- [kernel] psi: rename psi fields in preparation for psi trigger addition (Waiman Long) [1678388]
- [kernel] psi: make psi_enable static (Waiman Long) [1678388]
- [kernel] psi: introduce state_mask to represent stalled psi states (Waiman Long) [1678388]
- [kernel] kernel: cgroup: add poll file operation (Waiman Long) [1678388]
- [fs] fs: kernfs: add poll file operation (Waiman Long) [1678388]
- [documentation] psi: clarify the units used in pressure files (Waiman Long) [1678388]
- [kernel] psi: avoid divide-by-zero crash inside virtual machines (Waiman Long) [1678388]
- [init] psi: clarify the Kconfig text for the default-disable option (Waiman Long) [1678388]
- [kernel] psi: fix aggregation idle shut-off (Waiman Long) [1678388]
- [init] psi: fix reference to kernel commandline enable (Waiman Long) [1678388]
- [kernel] psi: make disabling/enabling easier for vendor kernels (Waiman Long) [1678388]
- [kernel] kernel/sched/psi.c: simplify cgroup_move_task() (Waiman Long) [1678388]
- [kernel] psi: cgroup support (Waiman Long) [1678388]
- [kernel] psi: pressure stall information for CPU, memory, and IO (Waiman Long) [1678388]
- [kernel] sched: introduce this_rq_lock_irq() (Waiman Long) [1678388]
- [kernel] sched: sched.h: make rq locking and clock functions available in stats.h (Waiman Long) [1678388]
- [kernel] sched: loadavg: make calc_load_n() public (Waiman Long) [1678388]
- [kernel] sched: loadavg: consolidate LOAD_INT, LOAD_FRAC, CALC_LOAD (Waiman Long) [1678388]
- [kernel] delayacct: track delays from thrashing cache pages (Waiman Long) [1678388]
- [mm] mm: workingset: tell cache transitions from workingset thrashing (Waiman Long) [1678388]
- [mm] mm: workingset: don't drop refault information prematurely (Waiman Long) [1678388]
- [scsi] scsi: ibmvfc: Add failed PRLI to cmd_status lookup array (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Byte swap status and error codes when logging (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Remove "failed" from logged errors (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Clean up transport events (Diego Domingos) [1665716]
- [scsi] scsi: ibmvscsi: Don't use rc uninitialized in ibmvscsi_do_work (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: fix tripping of blk_mq_run_hw_queue WARN_ON (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: redo driver work thread to use enum action states (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: Wire up host_reset() in the driver's scsi_host_template (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: change strncpy+truncation to strlcpy (Gustavo Duarte) [1665715]
- [fs] ext4: avoid panic during forced reboot due to aborted journal (Lukas Czerner) [1717831]
- [fs] ext4: fix use-after-free in dx_release() (Lukas Czerner) [1717831]
- [fs] ext4: fix data corruption caused by overlapping unaligned and aligned IO (Lukas Czerner) [1717831]
- [fs] ext4: avoid drop reference to iloc.bh twice (Lukas Czerner) [1717831]
- [nvme] nvme-tcp: mark NVMe/TCP as a technical preview (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix possible null deref on a timed out io queue connect (Chris Leech) [1696451]
- [nvme] nvme-tcp: rename function to have nvme_tcp prefix (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix a NULL deref when an admin connect times out (Chris Leech) [1696451]
- [nvme] nvmet-tcp: don't fail maxr2t greater than 1 (Chris Leech) [1696451]
- [nvme] nvmet-tcp: implement C2HData SUCCESS optimization (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix an endianess miss-annotation (Chris Leech) [1696451]
- [nvme] nvme-tcp: support C2HData with SUCCESS flag (Chris Leech) [1696451]
- [nvme] nvme-tcp: use older iov_iter API to fix panic (Chris Leech) [1696451]
- [nvme] nvmet: fix building bvec from sg list (Ming Lei) [1690287]
- [nvme] nvmet: set loop queue's segment boundary mask as PAGE_SIZE - 1 (Ming Lei) [1690287]
- [x86] x86/qspinlock: Fix compile error (Waiman Long) [1709451]
- [kernel] locking/rwsem: Prevent unneeded warning during locking selftest (Waiman Long) [1709451]
- [kernel] locking/rwsem: Enable lock event counting (Waiman Long) [1709451]
- [kernel] locking/lock_events: Don't show pvqspinlock events on bare metal (Waiman Long) [1709451]
- [kernel] locking/lock_events: Make lock_events available for all archs & other locks (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Introduce generic lockevent_*() counting APIs (Waiman Long) [1709451]
- [kernel] locking/rwsem: Enhance DEBUG_RWSEMS_WARN_ON() macro (Waiman Long) [1709451]
- [kernel] locking/rwsem: Add debug check for __down_read*() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Micro-optimize rwsem_try_read_lock_unqueued() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Move rwsem internal function declarations to rwsem-xadd.h (Waiman Long) [1709451]
- [kernel] locking/rwsem: Move owner setting code from rwsem.c to rwsem.h (Waiman Long) [1709451]
- [kernel] locking/rwsem: Relocate rwsem_down_read_failed() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Optimize down_read_trylock() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Remove rwsem-spinlock.c & use rwsem-xadd.c for all archs (Waiman Long) [1709451]
- [x86] locking/rwsem: Remove arch specific rwsem files (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Remove unnecessary BUG_ON() call (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Track the no MCS node available case (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Handle > 4 slowpath nesting levels (Waiman Long) [1709451]
- [kernel] locking/pvqspinlock: Extend node size when pvqspinlock is configured (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Count instances of nested lock slowpaths (Waiman Long) [1709451]
- [kernel] locking/qspinlock, x86: Provide liveness guarantee (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Rework some comments (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Re-order code (Waiman Long) [1709451]
- [x86] x86/headers: Fix -Wmissing-prototypes warning (Waiman Long) [1709451]
- [x86] Revert "x86/refcount: Work around GCC inlining bug" (Waiman Long) [1709451]
- [x86] x86/asm: 'Simplify' GEN_*_RMWcc() macros (Waiman Long) [1709451]
- [x86] x86/refcount: Work around GCC inlining bug (Waiman Long) [1709451]
- [lib] locking/refcounts: Include fewer headers in <linux/refcount.h> (Waiman Long) [1709451]
- [media] media: stk1160: Set the vb2_queue lock before calling vb2_queue_init (Torez Smith) [1697664]
- [usb] USB: typec: fsusb302: Drop empty set_current_limit implementation (Torez Smith) [1697664]
- [usb] USB: mark expected switch fall-throughs (Torez Smith) [1697664]
- [usb] USB: musb: mark expected switch fall-throughs (Torez Smith) [1697664]
- [usb] usb: wusbcore: security: cast sizeof to int for comparison (Torez Smith) [1697664]
- [usb] usb: typec: tcpm: Support for Alternate Modes (Torez Smith) [1697664]
- [usb] usb: typec: pi3usb30532: Start using generic state values (Torez Smith) [1697664]
- [usb] usb: typec: Add driver for DisplayPort alternate mode (Torez Smith) [1697664]
- [usb] usb: typec: Bus type for alternate modes (Torez Smith) [1697664]
- [usb] usb: typec: Register a device for every mode (Torez Smith) [1697664]
- [usb] usb: typec: mux: Get the mux identifier from function parameter (Torez Smith) [1697664]
- [usb] usb: update for tcpci drivers moving out of staging (Torez Smith) [1697664]
- [netdrv] net: usb: Mark expected switch fall-throughs (Torez Smith) [1697664]
- [media] media: tm6000: add error handling for dvb_register_adapter (Torez Smith) [1697664]
- [usb] usb: typec: function for checking cable plug orientation (Torez Smith) [1697664]
- [include] usb: pd: include kernel.h (Torez Smith) [1697664]
- [staging] staging: typec: tcpci: move tcpci drivers out of staging (Torez Smith) [1697664]
- [usb] typec: tcpm: add starting value for drp toggling (Torez Smith) [1697664]
- [usb] usb: typec: tcpm: support get typec and pd config from device properties (Torez Smith) [1697664]
- [usb] usb: typec: add API to get typec basic port power and data config (Torez Smith) [1697664]
- [staging] usb: typec: add fwnode to tcpc (Torez Smith) [1697664]
- [documentation] dt-bindings: usb: add documentation for typec port controller(TCPCI) (Torez Smith) [1697664]
- [documentation] dt-bindings: connector: add properties for typec (Torez Smith) [1697664]
- [usb] usb: typec: tps6598x: Remove VLA usage (Torez Smith) [1697664]
- [usb] usb: cdc-wdm: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: cdc-wdm: don't enable interrupts in USB-giveback (Torez Smith) [1697664]
- [usb] usb: legousbtower: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: ldusb: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: iowarrior: remove intr_idx_lock (Torez Smith) [1697664]
- [usb] usb: adutux: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: wusbcore: remove excessive irqsave (Torez Smith) [1697664]
- [usb] usb: usb-skeleton: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: usblp: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: usbfs: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: core: use irqsave() in sg_complete() complete callback (Torez Smith) [1697664]
- [usb] usb: cdc-acm: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: host: ehci-npcm7xx: Fix some error codes in probe (Torez Smith) [1697664]
- [media] media: cx231xx: fix RC_CORE dependency (Torez Smith) [1697664]
- [usb] USB: serial: digi_acceleport: rename tty flag variable (Torez Smith) [1697664]
- [usb] USB: serial: usb_wwan: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: ti_usb_3410_5052: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: symbolserial: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: sierra: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: sierra: fix potential deadlock at close (Torez Smith) [1697664]
- [usb] USB: serial: quatech2: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: mos7840: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: mos7720: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: io_ti: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: io_edgeport: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: digi_acceleport: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: cyberjack: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: chipidea: tegra: Use aligned DMA on Tegra114/124 (Torez Smith) [1697664]
- [documentation] dt-bindings: usb: new ehci-npcm7xx dt (Torez Smith) [1697664]
- [usb] USB host: Add USB ehci support for nuvoton npcm7xx platform (Torez Smith) [1697664]
- [usb] usb: cdc-acm: Decrement tty port's refcount if probe() fail (Torez Smith) [1697664]
- [usb] USB: mon: use ktime_get_real_ts64 instead of getnstimeofday64 (Torez Smith) [1697664]
- [usb] USB: xhci-hcd: Add get_resuming_ports method (Torez Smith) [1697664]
- [usb] USB: ehci-hcd: Add get_resuming_ports method (Torez Smith) [1697664]
- [usb] USB: Report wakeup events on root-hub ports (Torez Smith) [1697664]
- [usb] USB: serial: cast sizeof() to int when comparing with error code (Torez Smith) [1697664]
- [netdrv] net: drivers/net: Convert random_ether_addr to eth_random_addr (Torez Smith) [1697664]
- [netdrv] net: usb: rtl8150: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: r8152: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: kaweth: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: hso: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: cdc-phonet: use irqsave() in USB's complete callback (Torez Smith) [1697664]

* Thu Jun 13 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-106.el8]
- [net] selftests/tls: add test for sleeping even though there is data (Sabrina Dubroca) [1711821]
- [net] tls: fix no wakeup on partial reads (Sabrina Dubroca) [1711821]
- [net] selftests/tls: test for lowat overshoot with multiple records (Sabrina Dubroca) [1711821]
- [net] tls: fix lowat calculation if some data came from previous record (Sabrina Dubroca) [1711821]
- [net] tls: don't ignore netdev notifications if no TLS features (Sabrina Dubroca) [1711821]
- [net] tls: fix state removal with feature flags off (Sabrina Dubroca) [1711821]
- [net] tls: handle errors from padding_length() (Sabrina Dubroca) [1711821]
- [net] tls: avoid NULL pointer deref on nskb->sk in fallback (Sabrina Dubroca) [1711821]
- [net] tls: byte swap device req TCP seq no upon setting (Sabrina Dubroca) [1711821]
- [net] tls: remove old exports of sk_destruct functions (Sabrina Dubroca) [1711821]
- [net] tls: don't log errors every time offload can't proceed (Sabrina Dubroca) [1711821]
- [net] tls: fix refcount adjustment in fallback (Sabrina Dubroca) [1711821]
- [net] strparser: make it explicitly non-modular (Sabrina Dubroca) [1711821]
- [net] strparser: partially revert "strparser: Call skb_unclone conditionally" (Sabrina Dubroca) [1711821]
- [net] tls: fix the IV leaks (Sabrina Dubroca) [1711821]
- [net] strparser: fix comment (Sabrina Dubroca) [1711821]
- [net] tls: prevent false connection termination with offload (Sabrina Dubroca) [1711821]
- [net] tls: Replace kfree_skb() with consume_skb() (Sabrina Dubroca) [1711821]
- [net] strparser: fix a missing check for create_singlethread_workqueue (Sabrina Dubroca) [1711821]
- [net] tls: Fix tls_device receive (Sabrina Dubroca) [1711821]
- [net] tls: Fix mixing between async capable and async (Sabrina Dubroca) [1711821]
- [net] tls: Return type of non-data records retrieved using MSG_PEEK in recvmsg (Sabrina Dubroca) [1711821]
- [net] selftest/tls: Add test to verify received 'type' of non-data record (Sabrina Dubroca) [1711821]
- [net] tls: Move protocol constants from cipher context to tls context (Sabrina Dubroca) [1711821]
- [net] tls: Do not use async crypto for non-data records (Sabrina Dubroca) [1711821]
- [net] tls: Disable async decrytion for tls1.3 (Sabrina Dubroca) [1711821]
- [net] tls: Set async_capable for tls zerocopy only if we see EINPROGRESS (Sabrina Dubroca) [1711821]
- [net] tls: Add tests for TLS 1.3 (Sabrina Dubroca) [1711821]
- [net] tls: Add tls 1.3 support (Sabrina Dubroca) [1711821]
- [net] tls: Refactor control message handling on recv (Sabrina Dubroca) [1711821]
- [net] tls: Refactor tls aad space size calculation (Sabrina Dubroca) [1711821]
- [net] tls: Support 256 bit keys (Sabrina Dubroca) [1711821]
- [net] tls: free ctx in sock destruct (Sabrina Dubroca) [1711821]
- [net] tls: build_protos moved to common routine (Sabrina Dubroca) [1711821]
- [net] tls: Fix recvmsg() to be able to peek across multiple records (Sabrina Dubroca) [1711821]
- [net] tls: Make function tls_sw_do_sendpage static (Sabrina Dubroca) [1711821]
- [net] tls: remove unused function tls_sw_sendpage_locked (Sabrina Dubroca) [1711821]
- [net] Optimize sk_msg_clone() by data merge to end dst sg entry (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Fix recv partial/large_buff test cases (Sabrina Dubroca) [1711821]
- [net] tls: allocate tls context using GFP_ATOMIC (Sabrina Dubroca) [1711821]
- [net] tls: Init routines in create_ctx (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Fix recv(MSG_PEEK) & splice() test cases (Sabrina Dubroca) [1711821]
- [net] tls: fix currently broken MSG_PEEK behavior (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Add MSG_WAITALL in recv() syscall (Sabrina Dubroca) [1711821]
- [net] tls: async support causes out-of-bounds access in crypto APIs (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Add test for recv(PEEK) spanning across multiple records (Sabrina Dubroca) [1711821]
- [net] tls: Add support for async decryption of tls records (Sabrina Dubroca) [1711821]
- [net] tls: Calculate nsg for zerocopy path without skb_cow_data (Sabrina Dubroca) [1711821]
- [net] strparser: remove redundant variable 'rd_desc' (Sabrina Dubroca) [1711821]
- [net] tls: Use kmemdup to simplify the code (Sabrina Dubroca) [1711821]
- [net] tls: Use socket data_ready callback on record availability (Sabrina Dubroca) [1711821]
- [net] selftests: tls: add selftests for TLS sockets (Sabrina Dubroca) [1711821]
- [net] strparser: Call skb_unclone conditionally (Sabrina Dubroca) [1711821]
- [net] tls: Remove VLA usage on nonce (Sabrina Dubroca) [1711821]
- [net] tls: Removed unused variable (Sabrina Dubroca) [1711821]
- [netdrv] veth: use generic helper to report timestamping info (Jiri Benc) [1718938]
- [netdrv] veth: Fix -Wformat-truncation (Jiri Benc) [1718938]
- [netdrv] veth: Mark expected switch fall-throughs (Jiri Benc) [1718938]
- [net] Add extack argument to rtnl_create_link (Jiri Benc) [1718938]
- [netdrv] veth: Add ethtool statistics support for XDP (Jiri Benc) [1718938]
- [netdrv] veth: Account for XDP packet statistics on rx side (Jiri Benc) [1718938]
- [netdrv] veth: Account for packet drops in ndo_xdp_xmit (Jiri Benc) [1718938]
- [netdrv] veth: rename pcpu_vstats as pcpu_lstats (Jiri Benc) [1718938]
- [netdrv] net: move definition of pcpu_lstats to header file (Jiri Benc) [1718938]
- [netdrv] veth: add software timestamping (Jiri Benc) [1718938]
- [net] tcp: tcp_grow_window() needs to respect tcp_space() (Marcelo Leitner) [1718344]
- [net] tcp: fix a potential NULL pointer dereference in tcp_sk_exit (Marcelo Leitner) [1718344]
- [net] tcp: do not use ipv6 header for ipv4 flow (Marcelo Leitner) [1718344]
- [net] tcp: Don't access TCP_SKB_CB before initializing it (Marcelo Leitner) [1718344]
- [net] tcp: do not report TCP_CM_INQ of 0 for closed connections (Marcelo Leitner) [1718344]
- [net] tcp: clear icsk_backoff in tcp_write_queue_purge() (Marcelo Leitner) [1718344]
- [net] tcp: allow MSG_ZEROCOPY transmission also in CLOSE_WAIT state (Marcelo Leitner) [1718344]
- [net] tcp: change txhash on SYN-data timeout (Marcelo Leitner) [1718344]
- [net] tcp: lack of available data can also cause TSO defer (Marcelo Leitner) [1718344]
- [net] tcp: fix NULL ref in tail loss probe (Marcelo Leitner) [1718344]
- [net] tcp: Do not underestimate rwnd_limited (Marcelo Leitner) [1718344]
- [net] tcp: defer SACK compression after DupThresh (Marcelo Leitner) [1718344]
- [net] tcp: do not release socket ownership in tcp_close() (Marcelo Leitner) [1718344]
- [net] tcp: Fix SOF_TIMESTAMPING_RX_HARDWARE to use the latest timestamp during TCP coalescing (Marcelo Leitner) [1718344]
- [net] inet: make sure to grab rcu_read_lock before using ireq->ireq_opt (Marcelo Leitner) [1718344]
- [net] tcp/dccp: fix lockdep issue when SYN is backlogged (Marcelo Leitner) [1718344]
- [net] xfrm4: Fix uninitialized memory read in _decode_session4 (Sabrina Dubroca) [1718812]
- [net] esp4: add length check for UDP encapsulation (Sabrina Dubroca) [1718812]
- [net] xfrm: clean up xfrm protocol checks (Sabrina Dubroca) [1718812]
- [net] xfrm6_tunnel: Fix potential panic when unloading xfrm6_tunnel module (Sabrina Dubroca) [1718812]
- [net] xfrm: Reset secpath in xfrm failure (Sabrina Dubroca) [1718812]
- [net] xfrm: policy: Fix out-of-bound array accesses in __xfrm_policy_unlink (Sabrina Dubroca) [1718812]
- [net] xfrm: destroy xfrm_state synchronously on net exit path (Sabrina Dubroca) [1718812]
- [net] esp: Skip TX bytes accounting when sending from a request socket (Sabrina Dubroca) [1718812]
- [net] xfrm: refine validation of template and selector families (Sabrina Dubroca) [1718812]
- [net] xfrm: policy: increment xfrm_hash_generation on hash rebuild (Sabrina Dubroca) [1718812]
- [net] xfrm6_tunnel: Fix spi check in __xfrm6_tunnel_alloc_spi (Sabrina Dubroca) [1718812]
- [net] xfrm_user: fix freeing of xfrm states on acquire (Sabrina Dubroca) [1718812]
- [net] xfrm: Fix NULL pointer dereference in xfrm_input when skb_dst_force clears the dst_entry (Sabrina Dubroca) [1718812]
- [net] xfrm: Fix error return code in xfrm_output_one() (Sabrina Dubroca) [1718812]
- [net] vti4: eliminated some duplicate code (Guillaume Nault) [1718443]
- [net] vti4: removed duplicate log message (Guillaume Nault) [1718443]
- [net] vti4: ipip tunnel deregistration fixes (Guillaume Nault) [1718443]
- [net] vti4: Fix a ipip packet processing bug in 'IPCOMP' virtual tunnel (Guillaume Nault) [1718443]
- [net] fou: do not use guehdr after iptunnel_pull_offloads in gue_udp_recv (Guillaume Nault) [1718443]
- [netdrv] vxlan: test dev->flags & IFF_UP before calling gro_cells_receive() (Guillaume Nault) [1718443]
- [netdrv] vxlan: test dev->flags & IFF_UP before calling netif_rx() (Guillaume Nault) [1718443]
- [net] devlink: turn devlink into a built-in (Petr Oros) [1717458]
- [net] ipv6: fix EFAULT on sendto with icmpv6 and hdrincl (Stefano Brivio) [1718503]
- [net] ipv6: use READ_ONCE() for inet->hdrincl as in ipv4 (Stefano Brivio) [1718503]
- [net] ipv6: Fix redirect with VRF (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a raw socket to an address (Stefano Brivio) [1718503]
- [net] ipv6: prevent possible fib6 leaks (Stefano Brivio) [1718503]
- [net] vrf: sit mtu should not be updated when vrf netdev is the link (Stefano Brivio) [1718503]
- [net] ipv6: A few fixes on dereferencing rt->from (Stefano Brivio) [1718503]
- [tools] selftests: fib_rule_tests: Fix icmp proto with ipv6 (Stefano Brivio) [1718503]
- [net] ipv6: fix races in ip6_dst_destroy() (Stefano Brivio) [1718503]
- [net] ipv6/flowlabel: wait rcu grace period before put_pid() (Stefano Brivio) [1718503]
- [net] ipv6: invert flowlabel sharing check in process and user mode (Stefano Brivio) [1718503]
- [net] route: Avoid crash from dereferencing NULL rt->from (Stefano Brivio) [1718503]
- [net] udpv6: Check address length before reading address family (Stefano Brivio) [1718503]
- [net] ip6_gre: fix possible use-after-free in ip6erspan_rcv (Stefano Brivio) [1718503]
- [net] ip6_gre: remove gre_hdr_len from ip6erspan_rcv (Stefano Brivio) [1718503]
- [net] ipv6: Fix dangling pointer when ipv6 fragment (Stefano Brivio) [1718503]
- [net] ip6_tunnel: Match to ARPHRD_TUNNEL6 for dev type (Stefano Brivio) [1718503]
- [net] inet: switch IP ID generator to siphash (Stefano Brivio) [1718503]
- [net] sit: fix UBSAN Undefined behaviour in check_6rd (Stefano Brivio) [1718503]
- [net] ip6mr: Do not call __IP6_INC_STATS() from preemptible context (Stefano Brivio) [1718503]
- [net] sit: fix memory leak in sit_init_net() (Stefano Brivio) [1718503]
- [net] ipv4: Add ICMPv6 support when parse route ipproto (Stefano Brivio) [1718503]
- [net] ipv6: Return error for RTA_VIA attribute (Stefano Brivio) [1718503]
- [net] Set rtm_table to RT_TABLE_COMPAT for ipv6 for tables > 255 (Stefano Brivio) [1718503]
- [net] ip6_gre: do not report erspan_ver for ip6gre or ip6gretap (Stefano Brivio) [1718503]
- [net] ipv6: route: enforce RCU protection in rt6_update_exception_stamp_rt() (Stefano Brivio) [1718503]
- [net] ipv6: route: enforce RCU protection in ip6_route_check_nh_onlink() (Stefano Brivio) [1718503]
- [net] ipv6: propagate genlmsg_reply return code (Stefano Brivio) [1718503]
- [net] fix IPv6 prefix route residue (Stefano Brivio) [1718503]
- [net] ip6mr: Fix notifiers call on mroute_clean_tables() (Stefano Brivio) [1718503]
- [net] af_packet: fix raw sockets over 6in4 tunnel (Stefano Brivio) [1718503]
- [net] ip6_gre: fix tunnel list corruption for x-netns (Stefano Brivio) [1718503]
- [net] ipv6: fix kernel-infoleak in ipv6_local_error() (Stefano Brivio) [1718503]
- [net] ip: on queued skb use skb_header_pointer instead of pskb_may_pull (Stefano Brivio) [1718503]
- [net] ipv4: fix use-after-free in ip_cmsg_recv_dstaddr() (Stefano Brivio) [1718503]
- [net] ipv6: Take rcu_read_lock in __inet6_bind for mapped addresses (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a socket to a v4 mapped address (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a socket to an address (Stefano Brivio) [1718503]
- [net] ip: validate header length on virtual device xmit (Stefano Brivio) [1718503]
- [net] ipv6: Fix a test against 'ipv6_find_idev()' return value (Stefano Brivio) [1718503]
- [net] ipv6: tunnels: fix two use-after-free (Stefano Brivio) [1718503]
- [net] ipv6: add missing tx timestamping on IPPROTO_RAW (Stefano Brivio) [1718503]
- [net] clear skb->tstamp in forwarding paths (Stefano Brivio) [1718503]
- [net] ipv6: sr: properly initialize flowi6 prior passing to ip6_route_output (Stefano Brivio) [1718503]
- [net] always initialize pagedlen (Stefano Brivio) [1718503]
- [net] ipv6: Fix PMTU updates for UDP/raw sockets in presence of VRF (Stefano Brivio) [1718503]
- [net] ipv6: gro: do not use slow memcmp() in ipv6_gro_receive() (Stefano Brivio) [1718503]
- [net] xfrm: fix out-of-bounds packet access (Stefano Brivio) [1718503]
- [net] ipv6: take rcu lock in rawv6_send_hdrinc() (Stefano Brivio) [1718503]
- [net] ip6_tunnel: be careful when accessing the inner header (Stefano Brivio) [1718503]
- [net] revert "ipv6: fix double refcount of fib6_metrics" (Stefano Brivio) [1718503]
- [net] ipv6: fix memory leak on dst->_metrics (Stefano Brivio) [1718503]
- [net] ipv6: fix cleanup ordering for ip6_mr failure (Stefano Brivio) [1718503]
- [net] ipv6: fix cleanup ordering for pingv6 registration (Stefano Brivio) [1718503]
- [net] ip6_tunnel: collect_md xmit: Use ip_tunnel_key's provided src address (Stefano Brivio) [1718503]
- [net] ipv6: fix addrconf_sysctl_addr_gen_mode (Stefano Brivio) [1718503]
- [net] ipv6: don't reinitialize ndev->cnf.addr_gen_mode on new inet6_dev (Stefano Brivio) [1718503]
- [net] ipv6: reserve room for IFLA_INET6_ADDR_GEN_MODE (Stefano Brivio) [1718503]
- [net] ipv6: propagate net.ipv6.conf.all.addr_gen_mode to devices (Stefano Brivio) [1718503]
- [net] openvswitch: check for null pointer return from nla_nest_start_noflag (Stefano Brivio) [1718408]
- [net] openvswitch: add seqadj extension when NAT is used (Stefano Brivio) [1718408]
- [net] netfilter: Replace spin_is_locked() with lockdep (Stefano Brivio) [1718392]
- [net] netfilter: ipset: do not call ipset_nest_end after nla_nest_cancel (Stefano Brivio) [1718392]
- [net] netfilter: ipset: Fix calling ip_set() macro at dumping (Stefano Brivio) [1718392]
- [include] netfilter: ipset: Correct rcu_dereference() call in ip_set_put_comment() (Stefano Brivio) [1718392]
- [net] netfilter: ipset: fix ip_set_list allocation failure (Stefano Brivio) [1718392]
- [net] netfilter: ipset: Make invalid MAC address checks consistent (Stefano Brivio) [1649087]
- [net] netfilter: ipset: Allow matching on destination MAC address for mac and ipmac sets (Stefano Brivio) [1649087]
- [netdrv] rocker: Handle SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1717892]
- [net] switchdev: Add SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1717892]
- [netdrv] rocker: Add missing break for PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [net] bridge: Stop calling switchdev_port_attr_get() (Ivan Vecera) [1717892]
- [netdrv] rocker: Check Handle PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [netdrv] mlxsw: spectrum: Handle PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [include] net: switchdev: Add PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [netdrv] rocker: Remove port_attr_bridge_flags_get assignment (Ivan Vecera) [1717892]
- [netdrv] rocker: Remove getting PORT_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [net] pktgen: do not sleep with the thread lock held (Paolo Abeni) [1715575]
- [include] ipv6: fix the check before getting the cookie in rt6_get_cookie (Xin Long) [1709166]
- [net] ipv4: not do cache for local delivery if bc_forwarding is enabled (Xin Long) [1712657]
- [net] sctp: avoid running the sctp state machine recursively (Xin Long) [1717316]
- [netdrv] netdevsim: use skb_sec_path helper (Hangbin Liu) [1711810]
- [netdrv] netdevsim: convert to DEFINE_SHOW_ATTRIBUTE (Hangbin Liu) [1711810]
- [netdrv] netdevsim: make debug dirs' dentries static (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: use internal netns switch for ip commands (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: add testcases for vxlan flag sets (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: Add a test case for multipath route get (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink.sh: add testcase for neigh get (Hangbin Liu) [1711810]
- [tools] selftests: net: rtnetlink.sh: add fdb get test (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink.sh explicitly requires bash (Hangbin Liu) [1711810]
- [net] udp: with udp_segment release on error path (Paolo Abeni) [1718079]
- [net] ipv6: explicitly initialize udp6_addr in udp_sock_create6() (Paolo Abeni) [1718079]
- [netdrv] geneve: Don't assume linear buffers in vxlan_err_lookup() (Stefano Brivio) [1652222]
- [netdrv] vxlan: Don't assume linear buffers in vxlan_err_lookup() (Stefano Brivio) [1652222]
- [netdrv] geneve: Initialize addr6 with memset (Stefano Brivio) [1652222]
- [net] ip_tunnel: don't force DF when MTU is locked (Stefano Brivio) [1652222]
- [netdrv] geneve: ICMP error lookup handler (Stefano Brivio) [1652222]
- [netdrv] vxlan: ICMP error lookup handler (Stefano Brivio) [1652222]
- [net] udp: Handle ICMP errors for tunnels with same destination port on both endpoints (Stefano Brivio) [1652222]
- [net] udp: gro behind static key (Stefano Brivio) [1652222]
- [net] bpf: in __bpf_redirect_no_mac pull mac only if present (Jiri Benc) [1687471]
- [net] lwt_bpf: remove unnecessary rcu_read_lock in run_lwt_bpf (Jiri Benc) [1687471]
- [net] bpf: add End.DT6 action to bpf_lwt_seg6_action helper (Jiri Benc) [1687471]
- [net] bpf: fix out-of-bounds read in __bpf_skc_lookup (Jiri Benc) [1687459]
- [net] bpf: Check sk_fullsock() before returning from bpf_sk_lookup() (Jiri Benc) [1687459]
- [net] flow_dissector: disable preemption around BPF calls (Jiri Benc) [1687459]
- [net] bpf: sockmap, only stop/flush strp if it was enabled at some point (Jiri Benc) [1687459]
- [net] bpf: Stop the psock parser before canceling its work (Jiri Benc) [1687459]
- [net] bpf: only test gso type on gso packets (Jiri Benc) [1687459]
- [tools] selftests: add dummy xdp test helper (Jiri Benc) [1687459]
- [net] filter: mark expected switch fall-through (Jiri Benc) [1687459]
- [documentation] Update references to netdev-FAQ (Jiri Benc) [1687459]
- [net] bpfilter: remove trailing newline (Jiri Benc) [1687459]
- [net] core: filter: mark expected switch fall-through (Jiri Benc) [1687459]
- [net] revert "xsk: simplify AF_XDP socket teardown" (Jiri Benc) [1687459]
- [net] bpf/test_run: fix unkillable BPF_PROG_TEST_RUN (Jiri Benc) [1687459]
- [net] xsk: share the mmap_sem for page pinning (Jiri Benc) [1687459]
- [net] xsk: add missing smp_rmb() in xsk_mmap (Jiri Benc) [1687459]
- [net] bpf: only adjust gso_size on bytestream protocols (Jiri Benc) [1687459]
- [net] sk_msg: Always cancel strp work before freeing the psock (Jiri Benc) [1687459]
- [net] bpf: sock recvbuff must be limited by rmem_max in bpf_setsockopt() (Jiri Benc) [1687459]
- [net] bpf: fix SO_MAX_PACING_RATE to support TCP internal pacing (Jiri Benc) [1687459]
- [net] bpf: bpf_setsockopt: reset sock dst on SO_MARK changes (Jiri Benc) [1687459]
- [net] bpf: correctly set initial window on active Fast Open sender (Jiri Benc) [1687459]
- [net] xsk: simplify AF_XDP socket teardown (Jiri Benc) [1687459]
- [net] bpf: fix doc of bpf_skb_adjust_room() in uapi (Jiri Benc) [1687459]
- [net] bpf: do not blindly change rlimit in reuseport net selftest (Jiri Benc) [1687459]
- [net] xsk: proper AF_XDP socket teardown ordering (Jiri Benc) [1687459]
- [net] bpf: typo fix in Documentation/networking/af_xdp.rst (Jiri Benc) [1687459]
- [net] xdp: split code for map vs non-map redirect (Jiri Benc) [1687459]
- [net] xdp: explicit inline __xdp_map_lookup_elem (Jiri Benc) [1687459]
- [net] xdp: unlikely instrumentation for xdp map redirect (Jiri Benc) [1687459]
- [net] xdp: remove redundant variable 'headroom' (Jiri Benc) [1687459]
- [net] xsk: include XDP meta data in AF_XDP frames (Jiri Benc) [1687459]
- [net] bpf: Enable BPF_PROG_TYPE_SK_REUSEPORT bpf prog in reuseport selection (Jiri Benc) [1687459]
- [net] revert "xdp: add NULL pointer check in __xdp_return()" (Jiri Benc) [1687459]
- [lib] test_rhashtable: Make test_insert_dup() allocate its hash table dynamically (Jiri Benc) [1717066]
- [lib] test_rhashtable: remove semaphore usage (Jiri Benc) [1717066]
- [lib] rhashtable: detect when object movement between tables might have invalidated a lookup (Jiri Benc) [1717066]
- [lib] rhashtable: remove duplicated include from rhashtable.c (Jiri Benc) [1717066]
- [lib] rhashtable: clean up dereference of ->future_tbl (Jiri Benc) [1717066]
- [lib] rhashtable: use cmpxchg() to protect ->future_tbl (Jiri Benc) [1717066]
- [lib] rhashtable: simplify nested_table_alloc() and rht_bucket_nested_insert() (Jiri Benc) [1717066]
- [lib] rhashtable: simplify INIT_RHT_NULLS_HEAD() (Jiri Benc) [1717066]
- [lib] rhashtable: remove nulls_base and related code (Jiri Benc) [1717066]
- [lib] rhashtable: split rhashtable.h (Jiri Benc) [1717066]
- [lib] rhashtable: silence RCU warning in rhashtable_test (Jiri Benc) [1717066]
- [net] devlink: publish params only after driver init is done (Ivan Vecera) [1715929]
- [net] iptunnel: NULL pointer deref for ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_gre: Refactor collect metatdata mode tunnel xmit to ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Fix route fl4 init in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Add tnl_update_pmtu in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Add ip tunnel dst_cache in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] vlan: Mark expected switch fall-through (Hangbin Liu) [1664359]
- [net] vlan: disable SIOCSHWTSTAMP in container (Hangbin Liu) [1664359]
- [netdrv] macvlan: Mark expected switch fall-through (Hangbin Liu) [1664359]
- [netdrv] macvlan: disable SIOCSHWTSTAMP in container (Hangbin Liu) [1664359]
- [netdrv] macvlan: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to real device (Hangbin Liu) [1664359]
- [net] ethtool: add compat for flash update (Petr Oros) [1708339]
- [net] devlink: add flash update command (Petr Oros) [1708339]
- [net] devlink: Fix list access without lock while reading region (Petr Oros) [1708339]
- [net] devlink: Return right error code in case of errors for region read (Petr Oros) [1708339]
- [net] devlink: use direct return of genlmsg_reply (Petr Oros) [1708339]
- [net] devlink: Rename devlink health attributes (Petr Oros) [1709874]
- [net] devlink: Modify reply of DEVLINK_CMD_HEALTH_REPORTER_GET (Petr Oros) [1709874]
- [net] devlink: Update reporter state to error even if recover aborted (Petr Oros) [1709874]
- [documentation] devlink: Add Documentation/networking/devlink-health.txt (Petr Oros) [1709874]
- [net] devlink: Add health dump {get, clear} commands (Petr Oros) [1709874]
- [net] devlink: Add health diagnose command (Petr Oros) [1709874]
- [net] devlink: Add health recover command (Petr Oros) [1709874]
- [net] devlink: Add health set command (Petr Oros) [1709874]
- [net] devlink: Add health get command (Petr Oros) [1709874]
- [net] devlink: Add health report functionality (Petr Oros) [1709874]
- [net] devlink: Add health reporter create/destroy functionality (Petr Oros) [1709874]
- [net] devlink: Add devlink formatted message (fmsg) API (Petr Oros) [1709874]
- [net] devlink: add hardware errors tracing facility (Petr Oros) [1709874]
- [net] cnb: devlink: report cell size of shared buffers (Petr Oros) [1708348]
- [net] devlink: skip info_get op call if it is not defined in dumpit (Petr Oros) [1708342]
- [include] devlink: add a generic board.manufacture version name (Petr Oros) [1708342]
- [net] devlink: don't allocate attrs on the stack (Petr Oros) [1708342]
- [net] devlink: fix condition for compat device info (Petr Oros) [1708342]
- [net] ethtool: add compat for devlink info (Petr Oros) [1708342]
- [include] devlink: add generic info version names (Petr Oros) [1708342]
- [net] devlink: add version reporting to devlink info API (Petr Oros) [1708342]
- [net] devlink: add device information API (Petr Oros) [1708342]
- [net] devlink: Add devlink notifications support for port params (Petr Oros) [1710228]
- [net] devlink: Add support for driverinit set value for devlink_port (Petr Oros) [1710228]
- [net] devlink: Add support for driverinit get value for devlink_port (Petr Oros) [1710228]
- [net] devlink: Add port param set command (Petr Oros) [1710228]
- [net] devlink: Add port param get command (Petr Oros) [1710228]
- [net] devlink: Add devlink_param for port register and unregister (Petr Oros) [1710228]
- [net] ipv6: properly check return value in inet6_dump_all() (Petr Oros) [1714656]
- [net] Don't return invalid table id error when dumping all families (Petr Oros) [1714656]
- [net] ipmr_base: Do not reset index in mr_table_dump (Petr Oros) [1714656]
- [net] ipv6: Fix dump of specific table with strict checking (Petr Oros) [1714656]
- [net] ipv4: avoid compile error in fib_info_nh_uses_dev (Petr Oros) [1714656]
- [net] ipv4: Bail early if user only wants prefix entries (Petr Oros) [1714656]
- [net] ipv6: Bail early if user only wants cloned entries (Petr Oros) [1714656]
- [net] mpls: Handle kernel side filtering of route dumps (Petr Oros) [1714656]
- [net] Enable kernel side filtering of route dumps (Petr Oros) [1714656]
- [net] Plumb support for filtering ipv4 and ipv6 multicast route dumps (Petr Oros) [1714656]
- [net] ipmr: Refactor mr_rtm_dumproute (Petr Oros) [1714656]
- [net] mpls: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] ipv6: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] netfilter: nft_fib: Convert nft_fib4_eval to new dev helper (Petr Oros) [1714656]
- [net] netfilter: rpfilter: Convert rpfilter_lookup_reverse to new dev helper (Petr Oros) [1714656]
- [net] ipv4: Move device validation to helper (Petr Oros) [1714656]
- [net] ipv4: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] Add struct for fib dump filter (Petr Oros) [1714656]
- [lib] iov_iter: Fix build error without CONFIG_CRYPTO (Ivan Vecera) [1714213]
- [net] datagram: introduce skb_copy_and_hash_datagram_iter helper (Ivan Vecera) [1714213]
- [lib] iov_iter: introduce hash_and_copy_to_iter helper (Ivan Vecera) [1714213]
- [net] datagram: consolidate datagram copy to iter helpers (Ivan Vecera) [1714213]
- [lib] iov_iter: pass void csum pointer to csum_and_copy_to_iter (Ivan Vecera) [1714213]
- [net] datagram: open-code copy_page_to_iter (Ivan Vecera) [1714213]
- [include] net: enable mpls_ptr in net_device (Hangbin Liu) [1350011]
- [net] netfilter: ipset: actually allow allowable CIDR 0 in hash:net, port, net (Stefano Brivio) [1680512]
- [net] netfilter: ipset: fix ip_set_byindex function (Stefano Brivio) [1680512]
- [net] netfilter: ipset: Introduction of new commands and protocol version 7 (Stefano Brivio) [1680512]
- [net] ipv6: don't return positive numbers when nothing was dumped (Petr Oros) [1700306]
- [net] rtnetlink: restore handling of dumpit return value in rtnl_dump_all() (Petr Oros) [1700306]
- [net] netlink: fixup regression in RTM_GETADDR (Petr Oros) [1700306]
- [net] {ipv4, ipv6}: Do not put target net if input nsid is invalid (Petr Oros) [1700306]
- [net] rtnl_dump_all needs to propagate error from dumpit function (Petr Oros) [1700306]
- [net] rtnetlink: Move ifm in valid_fdb_dump_legacy to closer to use (Petr Oros) [1700306]
- [net] neighbor: NTF_PROXY is a valid ndm_flag for a dump request (Petr Oros) [1700306]
- [net] mpls: Implement handler for strict data checking on dumps (Petr Oros) [1700306]
- [net] rtnetlink: Update comment in rtnl_stats_dump regarding strict data checking (Petr Oros) [1700306]
- [net] ipv6: Put target net when address dump fails due to bad attributes (Petr Oros) [1700306]
- [net] ipv4: Put target net when address dump fails due to bad attributes (Petr Oros) [1700306]
- [tools] headers uapi: Update linux/netlink.h header copy (Petr Oros) [1700306]
- [net] neigh: fix NULL deref in pneigh_dump_table() (Petr Oros) [1700306]
- [net] ipv6: Add support for dumping addresses for a specific device (Petr Oros) [1700306]
- [net] ipv4: Add support for dumping addresses for a specific device (Petr Oros) [1700306]
- [net] ipv6: Remove ip_idx arg to in6_dump_addrs (Petr Oros) [1700306]
- [net] ipv4: Move loop over addresses on a device into in_dev_dump_addr (Petr Oros) [1700306]
- [net] netlink: Add answer_flags to netlink_callback (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_fdb_dump for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Move input checking for rtnl_fdb_dump to helper (Petr Oros) [1700306]
- [net] bridge: Update br_mdb_dump for strict data checking (Petr Oros) [1700306]
- [net] Update netconf dump handlers for strict data checking (Petr Oros) [1700306]
- [net] ipv6: Update ip6addrlbl_dump for strict data checking (Petr Oros) [1700306]
- [net] fib_rules: Update fib_nl_dumprule for strict data checking (Petr Oros) [1700306]
- [net] namespace: Update rtnl_net_dumpid for strict data checking (Petr Oros) [1700306]
- [net] neighbor: Update neightbl_dump_info for strict data checking (Petr Oros) [1700306]
- [net] neighbor: Update neigh_dump_info for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update fib dumps for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update ipmr_rtm_dumplink for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update inet6_dump_ifinfo for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_stats_dump for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_bridge_getlink for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_dump_ifinfo for strict data checking (Petr Oros) [1700306]
- [net] ipv6: Update inet6_dump_addr for strict data checking (Petr Oros) [1700306]
- [net] ipv4: Update inet_dump_ifaddr for strict data checking (Petr Oros) [1700306]
- [net] netlink: Add new socket option to enable strict checking on dumps (Petr Oros) [1700306]
- [net] ipv6: Refactor address dump to push inet6_fill_args to in6_dump_addrs (Petr Oros) [1700306]
- [lib] netlink: Add strict version of nlmsg_parse and nla_parse (Petr Oros) [1700306]
- [net] Add extack to nlmsg_parse (Petr Oros) [1700306]
- [include] netlink: Add extack message to nlmsg_parse for invalid header length (Petr Oros) [1700306]
- [net] netlink: Pass extack to dump handlers (Petr Oros) [1700306]
- [net] neigh: Extend dump filter to proxy neighbor dumps (Petr Oros) [1700306]
- [lib] netlink: add nested array policy validation (Petr Oros) [1700306]
- [lib] netlink: allow NLA_NESTED to specify nested policy to validate (Petr Oros) [1700306]
- [lib] netlink: move extack setting into validate_nla() (Petr Oros) [1700306]
- [lib] netlink: make validation_data const (Petr Oros) [1700306]
- [lib] netlink: remove NLA_NESTED_COMPAT (Petr Oros) [1700306]
- [lib] netlink: add ethernet address policy types (Petr Oros) [1700306]
- [net] sched: cls_u32: add res to offload information (Ivan Vecera) [1711377]
- [net] sched: gred: support reporting stats from offloads (Ivan Vecera) [1711377]
- [net] sched: gred: add basic Qdisc offload (Ivan Vecera) [1711377]
- [net] sched: gred: allow manipulating per-DP RED flags (Ivan Vecera) [1711377]
- [net] sched: gred: store red flags per virtual queue (Ivan Vecera) [1711377]
- [net] sched: gred: provide a better structured dump and expose stats (Ivan Vecera) [1711377]
- [net] sched: gred: store bytesin as a 64 bit value (Ivan Vecera) [1711377]
- [net] sched: gred: use extack to provide more details on configuration errors (Ivan Vecera) [1711377]
- [net] sched: gred: pass extack to nla_parse_nested() (Ivan Vecera) [1711377]
- [net] sched: gred: separate error and non-error path in gred_change() (Ivan Vecera) [1711377]
- [net] netlink: add NLA_REJECT policy type (Ivan Vecera) [1711377]
- [lib] netlink: Return extack message if attribute validation fails (Ivan Vecera) [1711377]
- [net] sched: red: notify drivers about RED's limit parameter (Ivan Vecera) [1711039]
- [net] sched: mq: offload a graft notification (Ivan Vecera) [1711039]
- [net] sched: red: offload a graft notification (Ivan Vecera) [1711039]
- [net] sched: provide notification for graft on root (Ivan Vecera) [1711039]
- [net] sched: prio: delay destroying child qdiscs on change (Ivan Vecera) [1711039]
- [net] sched: red: delay destroying child qdisc on replace (Ivan Vecera) [1711039]
- [net] sched: refactor grafting Qdiscs with a parent (Ivan Vecera) [1711039]
- [net] sched: add an offload graft helper (Ivan Vecera) [1711039]
- [net] sched: set TCQ_F_OFFLOADED flag for MQ (Ivan Vecera) [1711039]
- [net] sched: red: remove unnecessary red_dump_offload_stats parameter (Ivan Vecera) [1711039]
- [net] sched: add an offload dump helper (Ivan Vecera) [1711039]
- [netdrv] netdevsim: Implement ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [netdrv] rocker: Implement ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [net] Introduce ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [net] use indirect calls helpers at early demux stage (Paolo Abeni) [1700747]
- [net] use indirect calls helpers for L3 handler hooks (Paolo Abeni) [1700747]
- [net] use indirect calls helpers at the socket layer (Paolo Abeni) [1700747]
- [net] use indirect calls helpers for ptype hook (Paolo Abeni) [1700747]
- [net] add documentation to socket.c (Paolo Abeni) [1700747]
- [net] udp: use indirect call wrappers for GRO socket lookup (Paolo Abeni) [1700747]
- [net] use indirect call wrappers at GRO transport layer (Paolo Abeni) [1700747]
- [net] use indirect call wrappers at GRO network layer (Paolo Abeni) [1700747]
- [net] indirect call wrappers: helpers to speed-up indirect calls of builtin (Paolo Abeni) [1700747]
- [powerpc] powerpc: bpf: Fix generation of load/store DW instructions (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: propagate liveness on all frames (Yauheni Kaliuta) [1700846]
- [net] bpf: do not restore dst_reg when cur_state is freed (Yauheni Kaliuta) [1700846]
- [tools] tools lib bpf: Fix the build by adding a missing stdarg.h include (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: fix version info and add it to shared object (Yauheni Kaliuta) [1700846]
- [tools] btf: fix bug with resolving STRUCT/UNION into corresponding FWD (Yauheni Kaliuta) [1700846]
- [tools] tools/libbpf: signedness bug in btf_dedup_ref_type() (Yauheni Kaliuta) [1700846]
- [tools] libbpf: fix libbpf_print (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: simplify libbpf API function libbpf_set_print() (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: move set_max_rlimit() before __bpf_object__open_xattr() (Yauheni Kaliuta) [1700846]
- [include] bpf: promote bpf_perf_event.h to mandatory UAPI header (Yauheni Kaliuta) [1700846]
- [net] bpf: Avoid unnecessary instruction in convert_bpf_ld_abs() (Yauheni Kaliuta) [1700846]
- [kernel] bpf: fix check of allowed specifiers in bpf_trace_printk (Yauheni Kaliuta) [1700846]
- [documentation] bpf, doc: Document Jump X addressing mode (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: fix license for a compat header file (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Capitalise document heading (Yauheni Kaliuta) [1700846]
- [documentation] docs: Add bpf/index to top level index (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Add toctree to index (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Rename README.rst to index.rst (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip verifier tests for unsupported map types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip verifier tests for unsupported program types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip sockmap in test_maps if kernel doesn't have support (Yauheni Kaliuta) [1700846]
- [rpmspec] rpmspec: pack bpf-helpers, bpftool-net, bpftool-feature manpages (Yauheni Kaliuta) [1700846]
- [net] bpf, tcp: correctly handle DONT_WAIT flags and timeo == 0 (Yauheni Kaliuta) [1700846]
- [kernel] bpf: mark bpf_event_notify and bpf_event_init as static (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap fix msg->sg.size account on ingress skb (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap remove duplicate queue free (Yauheni Kaliuta) [1700846]
- [net] net/tls: remove set but not used variables (Yauheni Kaliuta) [1700846]
- [media] bpf: add map helper functions push, pop, peek in more BPF programs (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix infinite loop in map create (Yauheni Kaliuta) [1700846]
- [net] net/tls: fix build without CONFIG_TLS_DEVICE (Yauheni Kaliuta) [1700846]
- [net] net/tls: don't leak partially sent record in device mode (Yauheni Kaliuta) [1700846]
- [net] xdp: fix cpumap redirect SKB creation bug (Yauheni Kaliuta) [1700846]
- [net] net/core: Document reuseport_add_sock() bind_inany argument (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: clarify bump in libbpf version info (Yauheni Kaliuta) [1700846]
- [net] net/tls: Inform user space about send buffer availability (Yauheni Kaliuta) [1700846]
- [tools] libbpf: handle BTF parsing and loading properly (Yauheni Kaliuta) [1700846]
- [net] bpf: fix warning about using plain integer as NULL (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: fixing leak when kernel does not support btf (Yauheni Kaliuta) [1700846]
- [net] tls: Fix write space handling (Yauheni Kaliuta) [1700846]
- [net] tls: Fix tls_device handling of partial records (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, fix documentation for attach types (Yauheni Kaliuta) [1700846]
- [tools] btf: separate btf creation and loading (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix a selftest test_btf failure (Yauheni Kaliuta) [1700846]
- [tools] selftests/btf: add initial BTF dedup tests (Yauheni Kaliuta) [1700846]
- [tools] btf: add BTF types deduplication algorithm (Yauheni Kaliuta) [1700846]
- [tools] btf: extract BTF type size calculation (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: silence a libbpf unnecessary warning (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: implement libbpf btf__get_map_kv_tids() API function (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: expose functions btf_ext__* as API functions (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add a support for getting xdp prog id on ifindex (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add a helper for retrieving a map fd for a given name (Yauheni Kaliuta) [1700846]
- [tools] libbpf: introduce bpf_map_lookup_elem_flags() (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add bash completion for bpftool probes (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for a network device (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add C-style "#define" output for probes (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF helper functions (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF map types (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF program types (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for kernel configuration options (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for /proc/ eBPF parameters (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add basic probe capability, probe syscall availability (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: print out btf log at LIBBPF_WARN level (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: move libbpf pr_* debug print functions to headers (Yauheni Kaliuta) [1700846]
- [net] net: tls: Fix deadlock in free_resources tx (Yauheni Kaliuta) [1700846]
- [net] net: tls: Save iv in tls_rec for async crypto requests (Yauheni Kaliuta) [1700846]
- [tools] bpf: pull in pkt_sched.h header for tooling to fix bpftool build (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: change section name of bpfilter UMH blob (Yauheni Kaliuta) [1700846]
- [netdrv] tap: call skb_probe_transport_header after setting skb->dev (Yauheni Kaliuta) [1700846]
- [net] Prevent overflow of sk_msg in sk_msg_clone() (Yauheni Kaliuta) [1700846]
- [net] tls: Do not call sk_memcopy_from_iter with zero length (Yauheni Kaliuta) [1700846]
- [net] net: ipv4: Set skb->dev for output route resolution (Yauheni Kaliuta) [1700846]
- [net] bpf: refactor bpf_test_run() to separate own failures and test program result (Yauheni Kaliuta) [1700846]
- [include] bpf: fix pointer offsets in context for 32 bit (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: copy a few net uapi headers to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: tcp_bpf_recvmsg should return EAGAIN when nonblocking and no data (Yauheni Kaliuta) [1700846]
- [net] bpf: skmsg, fix psock create on existing kcm/tls port (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: remove socket lock assertion on ULP cleanup (Yauheni Kaliuta) [1700846]
- [lib] bpf: test_bpf: add init_net to dev for flow_dissector (Yauheni Kaliuta) [1700846]
- [net] flow_dissector: lookup netns by skb->sk if skb->dev is NULL (Yauheni Kaliuta) [1700846]
- [net] tls: Fixed uninitialised vars warning (Yauheni Kaliuta) [1700846]
- [include] cgroup: Simplify cgroup_ancestor (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Orphan skb before GRO (Yauheni Kaliuta) [1700846]
- [net] net/core/filter: fix unused-variable warning (Yauheni Kaliuta) [1700846]
- [net] bpf: fix build error with clang (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Free queues on link delete (Yauheni Kaliuta) [1700846]
- [net] bpf: fix sanitation rewrite in case of non-pointers (Yauheni Kaliuta) [1700846]
- [net] bpf: drop refcount if bpf_map_new_fd() fails in map_create() (Yauheni Kaliuta) [1700846]
- [net] bpf: decrease usercnt if bpf_map_new_fd() fails in bpf_map_get_fd_by_id() (Yauheni Kaliuta) [1700846]
- [net] bpf, lpm: fix lookup bug in map_delete_elem (Yauheni Kaliuta) [1700846]
- [net] bpf: fix lockdep false positive in stackmap (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix narrow load on a bpf_sock returned from sk_lookup() (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix syscall's stackmap lookup potential deadlock (Yauheni Kaliuta) [1700846]
- [kernel] bpf: fix potential deadlock in bpf_prog_register (Yauheni Kaliuta) [1700846]
- [net] bpf: fix lockdep false positive in percpu_freelist (Yauheni Kaliuta) [1700846]
- [net] bpf: run bpf programs with preemption disabled (Yauheni Kaliuta) [1700846]
- [tools] bpf, selftests: fix handling of sparse CPU allocations (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix test_btf for typedef func_proto case (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: allow typedef func_proto (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix crash with un-owned prog arrays (Yauheni Kaliuta) [1700846]
- [tools] bpftool: fix percpu maps updating (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: Cleanup license mess (Yauheni Kaliuta) [1700846]
- [net] bpf: Annotate implicit fall through in cgroup_dev_func_proto (Yauheni Kaliuta) [1700846]
- [net] bpf: Make function btf_name_offset_valid static (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: retry tests that expect build-id (Yauheni Kaliuta) [1700846]
- [net] bpf: zero out build_id for BPF_STACK_BUILD_ID_IP (Yauheni Kaliuta) [1700846]
- [net] bpf: don't assume build-id length is always 20 bytes (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: properly account for libbfd variations (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: retry loading program on EAGAIN (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: workaround clang asm goto compilation errors (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: install with_tunnels.sh for test_flow_dissector.sh (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: disallow to remove bpfilter module while being used (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: Fix type cast and pointer warnings (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: restart bpfilter_umh when error occurred (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: use cleanup callback to release umh_info (Yauheni Kaliuta) [1700846]
- [kernel] umh: add exit routine for UMH process (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: Set user mode helper's command line (Yauheni Kaliuta) [1700846]
- [kernel] umh: Add command line to user mode helpers (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: use get_pid_task instead of pid_task (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix bpftool map dump with bitfields (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: test btf bitfield with >=256 struct member offset (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpffs bitfield pretty print (Yauheni Kaliuta) [1700846]
- [net] bpf: fix panic in stack_map_get_build_id() on i386 and arm32 (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: install files tcp_(server|client)*.py (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: user proper argument index (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [tools] bpf, doc: add note for libbpf's stand-alone build (Yauheni Kaliuta) [1700846]
- [documentation] bpf, doc: update design qa to reflect kern_version requirement (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix incorrect users of create_and_get_cgroup (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases for alu op on mixed dst register types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test [::] -> [::1] rewrite in sys_sendmsg in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix [::] -> [::1] rewrite in sys_sendmsg (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases to selftests (Yauheni Kaliuta) [1700846]
- [net] bpf: fix check_map_access smin_value test when pointer contains offset (Yauheni Kaliuta) [1700846]
- [net] bpf: restrict stack pointer arithmetic for unprivileged (Yauheni Kaliuta) [1700846]
- [net] bpf: restrict map value pointer arithmetic for unprivileged (Yauheni Kaliuta) [1700846]
- [net] bpf: enable access to ax register also from verifier rewrite (Yauheni Kaliuta) [1700846]
- [net] bpf: move tmp variable into ax register in interpreter (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix error printing in test_devmap() (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix segfault in test_verifier selftest (Yauheni Kaliuta) [1700846]
- [net] bpf: tls_sw, init TLS ULP removes BPF proto hooks (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, sock{map|hash} redirect through ULP (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, zap ingress queue on psock down (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, fix socket data_ready events (Yauheni Kaliuta) [1700846]
- [net] bpf: skb_verdict, support SK_PASS on RX BPF path (Yauheni Kaliuta) [1700846]
- [net] bpf: skmsg, replace comments with BUILD bug (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, improve offset chk in _is_valid_access (Yauheni Kaliuta) [1700846]
- [tools] bpf: sk_msg, fix sk_msg_md access past end test (Yauheni Kaliuta) [1700846]
- [net] bpf/cpumap: make sure frame_size for build_skb is aligned if headroom isn't (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: reorder stack size check with dead code sanitization (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: verifier: add tests for JSET interpretation (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: teach the verifier to reason about the BPF_JSET instruction (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add trivial JSET tests (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_LD_IMM64 to the line_info test (Yauheni Kaliuta) [1700846]
- [net] bpf: Ensure line_info.insn_off cannot point to insn with zero code (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: do not force gcc as CC (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix up uapi helper description and sync bpf header with tools (Yauheni Kaliuta) [1700846]
- [net] bpf: log struct/union attribute for forward type (Yauheni Kaliuta) [1700846]
- [tools] bpf: sk_msg, add tests for size field (Yauheni Kaliuta) [1700846]
- [tools] bpf: add tools lib/include support sk_msg_md size field (Yauheni Kaliuta) [1700846]
- [include] bpf: sockmap, metadata support for reporting size of msg (Yauheni Kaliuta) [1700846]
- [net] bpf: correct slot_type marking logic to allow more stack slot sharing (Yauheni Kaliuta) [1700846]
- [kernel] bpf: support raw tracepoints in modules (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add an option to prevent auto-mount of bpffs, tracefs (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: attempt to mount tracefs if required for tracelog cmd (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: check precise {func, line, jited_line}_info_rec_size in test_btf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: fix memleak by freeing line_info (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: support pretty print with kind_flag set (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: refactor btf_dumper_int_bits() (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: test kernel bpffs map pretty print with struct kind_flag (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add test_btf unit tests for kind_flag (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync btf.h header from kernel to tools (Yauheni Kaliuta) [1700846]
- [net] bpf: enable cgroup local storage map pretty print with kind_flag (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: fix struct/union/fwd types with kind_flag (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: refactor btf_int_bits_seq_show() (Yauheni Kaliuta) [1700846]
- [net] bpf: remove useless version check for prog load (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix -Wmissing declaration warnings (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix warning on struct bpf_prog_linfo definition (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add a prog array map update example to documentation (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix examples in documentation for bpftool prog (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add doc for -m option to bpftool-prog.rst (Yauheni Kaliuta) [1700846]
- [net] bpf: add self-check logic to liveness analysis (Yauheni Kaliuta) [1700846]
- [net] bpf: improve stacksafe state comparison (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: check insn processed in test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: speed up stacksafe check (Yauheni Kaliuta) [1700846]
- [net] bpf: verbose log bpf_line_info in verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Create a new btf_name_by_offset() for non type name use case (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix sk lookup usage in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: remove obsolete prog->aux sanitation in bpf_insn_prepare_dump (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: make sure callees don't prune with caller differences (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync tools/include/uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [net] bpf: include sub program tags in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [tools] bpf: Remove !func_info and !line_info check from test_btf and bpftool (Yauheni Kaliuta) [1700846]
- [net] bpf: Remove bpf_dump_raw_ok() check for func_info and line_info (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: dual license all files (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: replace Netronome boilerplate with SPDX license headers (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix SPDX format in headers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add btf annotations for cgroup_local_storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for cgroup local storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: pass struct btf pointer to the map_check_btf() callback (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: use __bpf_constant_htons in test_prog.c (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpf_jit_limit knob for PAGE_SIZE >= 64K (Yauheni Kaliuta) [1700846]
- [arm64] bpf: arm64: Enable arm64 jit to provide bpf_line_info (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: use proper type when passing prog_type (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: rename *_info_cnt to nr_*_info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync kernel uapi bpf.h to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: rename *_info_cnt to nr_*_info in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [net] bpf: clean up bpf_prog_get_info_by_fd() (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool: Fix newline and p_err issue (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing pointer dereference for map stacktrace fixup (Yauheni Kaliuta) [1700846]
- [net] bpf: relax verifier restriction on BPF_MOV | BPF_ALU (Yauheni Kaliuta) [1700846]
- [tools] media: bpf: add bpf function to report mouse movement (Yauheni Kaliuta) [1700846]
- [include] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: bpftool: Print bpf_line_info during prog dump (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Add btf_line_info support to libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Refactor and bug fix on the bpf_func_info loading logic (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add unit tests for bpf_line_info (Yauheni Kaliuta) [1700846]
- [tools] bpf: Refactor and bug fix in test_func_type in test_btf.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: tools: Sync uapi bpf.h (Yauheni Kaliuta) [1700846]
- [include] bpf: Add bpf_line_info support (Yauheni Kaliuta) [1700846]
- [net] net/flow_dissector: correctly cap nhoff and thoff in case of BPF (Yauheni Kaliuta) [1700846]
- [net] selftests/bpf: use thoff instead of nhoff in BPF flow dissector (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: update testcases for BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier remove the rejection on BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [net] bpf: interpreter support BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [s390] s390: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Yauheni Kaliuta) [1700846]
- [powerpc] ppc: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Yauheni Kaliuta) [1700846]
- [tools] bpf: Expect !info.func_info and insn_off name changes in test_btf/libbpf/bpftool (Yauheni Kaliuta) [1700846]
- [tools] bpf: tools: Sync uapi bpf.h for the name changes in bpf_func_info (Yauheni Kaliuta) [1700846]
- [net] bpf: Change insn_offset to insn_off in bpf_func_info (Yauheni Kaliuta) [1700846]
- [net] bpf: Improve the info.func_info and info.func_info_rec_size behavior (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add a command to dump the trace pipe (Yauheni Kaliuta) [1700846]
- [arm64] arm64/bpf: don't allocate BPF JIT programs in module memory (Yauheni Kaliuta) [1700846]
- [net] bpf: add __weak hook for allocating executable memory (Yauheni Kaliuta) [1700846]
- [net] bpf: add per-insn complexity limit (Yauheni Kaliuta) [1700846]
- [net] bpf: improve verifier branch analysis (Yauheni Kaliuta) [1700846]
- [net] bpf: check pending signals while verifying programs (Yauheni Kaliuta) [1700846]
- [tools] selftests: add a test for bpf_prog_test_run_xattr (Yauheni Kaliuta) [1700846]
- [tools] libbpf: add bpf_prog_test_run_xattr (Yauheni Kaliuta) [1700846]
- [tools] tools: sync uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [net] bpf: respect size hint to BPF_PROG_TEST_RUN if present (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: fix: seg fault with NULL pointer arg (Yauheni Kaliuta) [1700846]
- [powerpc] bpf: powerpc64: optimize JIT passes for bpf function calls (Yauheni Kaliuta) [1700846]
- [tools] bpf: allow BPF read access to qdisc pkt_len (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Fix license in README.rst (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix memleak in aux->func_info and aux->btf (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: get ifindex from ifname (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: improve xdp1 example (Yauheni Kaliuta) [1700846]
- [tools] bpf: Apply F_NEEDS_EFFICIENT_UNALIGNED_ACCESS to more ACCEPT test cases (Yauheni Kaliuta) [1700846]
- [tools] bpf: Make more use of 'any' alignment in test_verifier.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: Adjust F_NEEDS_EFFICIENT_UNALIGNED_ACCESS handling in test_verifier.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_F_ANY_ALIGNMENT (Yauheni Kaliuta) [1700846]
- [tools] bpf: Improve socket lookup reuseport documentation (Yauheni Kaliuta) [1700846]
- [tools] bpf: Support sk lookup in netns with id 0 (Yauheni Kaliuta) [1700846]
- [tools] bpf: Fix verifier log string check for bad alignment (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add owner_prog_type and owner_jited to bpftool output (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: mark offloaded programs more explicitly in plain output (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix bash completion for new map types (queue and stack) (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix bash completion for bpftool prog (attach|detach) (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: use "/proc/self/" i.o. crafting links with getpid() (Yauheni Kaliuta) [1700846]
- [arm64] arm64/bpf: use movn/movk/movk sequence to generate kernel addresses (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: make libbpf _GNU_SOURCE friendly (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix a bitfield pretty print issue (Yauheni Kaliuta) [1700846]
- [tools] bpf: Fix various lib and testsuite build failures on 32-bit (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add addition type tests to test_btf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix two test_btf unit test cases (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: check name validity for various types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add config fragment CONFIG_FTRACE_SYSCALLS (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_sockmap, add options for msg_pop_data() helper (Yauheni Kaliuta) [1700846]
- [tools] bpf: add msg_pop_data helper to tools (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Document API and ABI conventions (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Verify versioned symbols (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add version script for DSO (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Name changing for btf_get_from_id (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: change selftest test_btf for both jit and non-jit (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: support proper non-jit func info (Yauheni Kaliuta) [1700846]
- [arm64] bpf, arm64: fix getting subprog addr from aux for calls (Yauheni Kaliuta) [1700846]
- [net] bpf, ppc64: generalize fetching subprog into bpf_jit_get_func_addr (Yauheni Kaliuta) [1700846]
- [tools] bpf: align map type names formatting (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: fix spelling mistake "Memmber" -> "Member" (Yauheni Kaliuta) [1700846]
- [net] bpf, tags: Fix DEFINE_PER_CPU expansion (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_MAP_TYPE_QUEUE and BPF_MAP_TYPE_STACK to bpftool-map (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: fix: error handling regarding kprobe_events (Yauheni Kaliuta) [1700846]
- [tools] libbpf: make bpf_object__open default to UNSPEC (Yauheni Kaliuta) [1700846]
- [tools] bpf: add skb->tstamp r/w access from tc clsact and cg skb progs (Yauheni Kaliuta) [1700846]
- [net] bpf: fix integer overflow in queue_stack_map (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix spelling mistake "memeory" -> "memory" (Yauheni Kaliuta) [1700846]
- [net] bpf, lpm: make longest_prefix_match() faster (Yauheni Kaliuta) [1700846]
- [tools] bpf: adding tests for map_in_map helpber in libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: adding support for map in map in libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: don't specify prog name if kernel doesn't support it (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: remove map name retry from bpf_create_map_xattr (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: introduce bpf_object__probe_caps to test BPF capabilities (Yauheni Kaliuta) [1700846]
- [tools] libbpf: make sure bpf headers are c++ include-able (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix a libbpf loader issue (Yauheni Kaliuta) [1700846]
- [include] bpf: fix a compilation error when CONFIG_BPF_SYSCALL is not defined (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add support for func types (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: enhance test_btf file testing to test func info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: refactor to implement btf_get_from_id() in lib/bpf (Yauheni Kaliuta) [1700846]
- [samples] tools/bpf: do not use pahole if clang/llvm can generate BTF sections (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add support to read .BTF.ext sections (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: extends test_btf to test load/retrieve func_type info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add new fields for program load in lib/bpf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync kernel uapi bpf.h header to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce bpf_func_info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: Add tests for BTF_KIND_FUNC_PROTO and BTF_KIND_FUNC (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: Sync kernel btf.h header (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Add BTF_KIND_FUNC and BTF_KIND_FUNC_PROTO (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Break up btf_type_is_void() (Yauheni Kaliuta) [1700846]
- [tools] tools: add selftest for BPF_F_ZERO_SEED (Yauheni Kaliuta) [1700846]
- [tools] tools: sync linux/bpf.h (Yauheni Kaliuta) [1700846]
- [include] bpf: move BPF_F_QUERY_EFFECTIVE after map flags (Yauheni Kaliuta) [1700846]
- [net] bpf: allow zero-initializing hash map seed (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: retry map creation without the name (Yauheni Kaliuta) [1700846]
- [net] bpf: allocate local storage buffers using GFP_ATOMIC (Yauheni Kaliuta) [1700846]
- [net] bpf: fix off-by-one error in adjust_subprog_starts (Yauheni Kaliuta) [1700846]
- [net] bpf: fix null pointer dereference on pointer offload (Yauheni Kaliuta) [1700846]
- [tools] bpftool: make libbfd optional (Yauheni Kaliuta) [1700846]
- [net] net/bpf: split VLAN_PRESENT bit handling from VLAN_TCI (Yauheni Kaliuta) [1700846]
- [powerpc] net/bpf_jit: PPC: split VLAN_PRESENT bit handling from VLAN_TCI (Yauheni Kaliuta) [1700846]
- [net] net/skbuff: add macros for VLAN_PRESENT bit (Yauheni Kaliuta) [1700846]
- [tools] selftest/bpf: Use bpf_sk_lookup_{tcp, udp} in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: Support socket lookup in CGROUP_SOCK_ADDR progs (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix IPv6 dport byte order in bpf_sk_lookup_udp (Yauheni Kaliuta) [1700846]
- [net] bpf: Extend the sk_lookup() helper to XDP hookpoint (Yauheni Kaliuta) [1700846]
- [net] bpf: helper to pop data from messages (Yauheni Kaliuta) [1700846]
- [net] bpf: fix wrong helper enablement in cgroup local storage (Yauheni Kaliuta) [1700846]
- [include] bpf: sk_msg program helper bpf_msg_push_data (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix IPv6 dport byte-order in bpf_sk_lookup (Yauheni Kaliuta) [1700846]
- [net] bpf: Allow sk_lookup with IPv6 module (Yauheni Kaliuta) [1700846]
- [net] net: core: Fix build with CONFIG_IPV6=m (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix dev pointer dereference from sk_skb (Yauheni Kaliuta) [1700846]
- [net] bpf: fix building without CONFIG_INET (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Fix bpf_program__next() API (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix uninitialized duration warning (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test narrow loads with off > 0 for bpf_sock_addr (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test narrow loads with off > 0 in test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Allow narrow loads with offset > 0 (Yauheni Kaliuta) [1700846]
- [tools] bpftool: support loading flow dissector (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add pinmaps argument to the load/loadall (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add loadall command (Yauheni Kaliuta) [1700846]
- [tools] libbpf: add internal pin_name (Yauheni Kaliuta) [1700846]
- [tools] libbpf: bpf_program__pin: add special case for instances.nr == 1 (Yauheni Kaliuta) [1700846]
- [tools] libbpf: cleanup after partial failure in bpf_object__pin (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: rename flow dissector section to flow_dissector (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: do not pass netdev to translate() and prepare() offload callbacks (Yauheni Kaliuta) [1700846]
- [net] bpf: pass prog instead of env to bpf_prog_offload_verifier_prep() (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: pass destroy() as a callback and remove its ndo_bpf subcommand (Yauheni Kaliuta) [1700846]
- [include] bpf: pass translate() as a callback and remove its ndo_bpf subcommand (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: call verifier_prep from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [net] bpf: call finalize() from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [net] bpf: call verify_insn from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: pass a struct with offload callbacks to bpf_offload_dev_create() (Yauheni Kaliuta) [1700846]
- [tools] kselftests/bpf: use ping6 as the default ipv6 ping binary when it exists (Yauheni Kaliuta) [1700846]
- [tools] bpftool: Improve handling of ENOENT on map dumps (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add a test case for sock_ops perf-event notification (Yauheni Kaliuta) [1700846]
- [net] bpf: add perf event notificaton support for sock_ops (Yauheni Kaliuta) [1700846]
- [net] bpf: let verifier to calculate and record max_pkt_offset (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: update references to other man pages in documentation (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: pass an argument to silence open_obj_pinned() (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix plain output and doc for --bpffs option (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: prevent infinite loop in get_fdinfo() (Yauheni Kaliuta) [1700846]
- [samples] bpf_load: add map name to load_maps error message (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: adjust rlimit RLIMIT_MEMLOCK when loading programs, maps (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: enable (uncomment) all tests in test_libbpf.sh (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpf_prog_get_info_by_fd to return 0 func_lens for unpriv (Yauheni Kaliuta) [1700846]
- [net] bpf: show main program address and length in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [net] bpf: show real jited address in bpf_prog_info->jited_ksyms (Yauheni Kaliuta) [1700846]
- [net] bpf: show real jited prog address in /proc/kallsyms (Yauheni Kaliuta) [1700846]
- [tools] bpf: test make sure to run unpriv test cases in test_verifier (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases to test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: don't set id on after map lookup with ptr_to_map_val return (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Fix compile error in libbpf_attach_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] kselftests/bpf: use ping6 as the default ipv6 ping binary if it exists (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add unlimited rlimit for flow_dissector_load (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpf_jit_limit knob to restrict unpriv allocations (Yauheni Kaliuta) [1700846]
- [net] bpf: make direct packet write unclone more robust (Yauheni Kaliuta) [1700846]
- [net] bpf: fix leaking uninitialized memory on pop/peek helpers (Yauheni Kaliuta) [1700846]
- [net] bpf: fix direct packet write into pop/peek helpers (Yauheni Kaliuta) [1700846]
- [net] bpf: fix cg_skb types to hint access type in may_access_direct_pkt_data (Yauheni Kaliuta) [1700846]
- [net] bpf: fix direct packet access for flow dissector progs (Yauheni Kaliuta) [1700846]
- [net] bpf: disallow direct packet access for unpriv in cg_skb (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix test suite to enable all unpriv program types (Yauheni Kaliuta) [1700846]
- [net] bpf, btf: fix a missing check bug in btf_parse (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add config fragments BPF_STREAM_PARSER and XDP_SOCKETS (Yauheni Kaliuta) [1700846]
- [net] bpf: devmap: fix wrong interface selection in notifier_call (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix completion for "bpftool map update" (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: print nb of cmds to stdout (not stderr) for batch mode (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: document restriction on '.' in names to pin in bpffs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix return value comparison for tests in test_libbpf.sh (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: simplify and cleanup perf ring buffer walk (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: avoid retpoline for map push/pop/peek operation (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: remove unneeded flow key in check_helper_mem_access (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: reject xadd on flow key memory (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: fix register type dump in xadd and st (Yauheni Kaliuta) [1700846]
- [net] ulp: remove uid and user_visible members (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_sockmap add options to use msg_push_data (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf support for msg_push_data (Yauheni Kaliuta) [1700846]
- [tools] Sync uapi/bpf.h to tools/include (Yauheni Kaliuta) [1700846]
- [net] bpf: add tests for direct packet access from CGROUP_SKB (Yauheni Kaliuta) [1700846]
- [net] bpf: add cg_skb_is_valid_access for BPF_PROG_TYPE_CGROUP_SKB (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: use correct barriers in perf ring buffer walk (Yauheni Kaliuta) [1700846]
- [tools] tools, perf: add and use optimized ring_buffer_{read_head, write_tail} helpers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add test cases for queue and stack maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add MAP_LOOKUP_AND_DELETE_ELEM syscall (Yauheni Kaliuta) [1700846]
- [net] bpf: add queue and stack maps (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: add ARG_PTR_TO_UNINIT_MAP_VALUE (Yauheni Kaliuta) [1700846]
- [net] bpf/syscall: allow key to be null in map functions (Yauheni Kaliuta) [1700846]
- [net] bpf: rename stack trace map operations (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: use 4 context mode for the NFP disasm (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix file resource leak in load_kallsyms (Yauheni Kaliuta) [1700846]
- [tools] bpf: sockmap, add msg_peek tests to test_sockmap (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, support for msg_peek in sk_msg with redirect ingress (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, fix skmsg recvmsg handler to track size correctly (Yauheni Kaliuta) [1700846]
- [include] bpf: skmsg, improve sk_msg_used_element to work in cork context (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Per-symbol visibility for DSO (Yauheni Kaliuta) [1700846]
- [tools] bpf, tls: add tls header to tools infrastructure (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add map create command (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, add flag to allow non-compat map definitions (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, add support for attaching programs to maps (Yauheni Kaliuta) [1700846]
- [maintainers] bpf, doc: add maintainers entry to related files (Yauheni Kaliuta) [1700846]
- [tools] bpf: add tls support for testing in test_sockmap (Yauheni Kaliuta) [1700846]
- [net] tls: add bpf support to sk_msg handling (Yauheni Kaliuta) [1700846]
- [net] tls: replace poll implementation with read hook (Yauheni Kaliuta) [1700846]
- [net] tls: convert to generic sk_msg interface (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: convert to generic sk_msg interface (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: remove ulp bits from sockmap (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: enforce sock_owned_by_me upon ulp init and cleanup (Yauheni Kaliuta) [1700846]
- [net] net/tls: Make function get_rec() static (Yauheni Kaliuta) [1700846]
- [net] net/tls: Mark the end in scatterlist table (Yauheni Kaliuta) [1700846]
- [net] tls: Fixed a memory leak during socket close (Yauheni Kaliuta) [1700846]
- [net] net/tls: Removed redundant checks for non-NULL (Yauheni Kaliuta) [1700846]
- [net] tls: Add support for inplace records encryption (Yauheni Kaliuta) [1700846]
- [net] tls: Remove redundant vars from tls record structure (Yauheni Kaliuta) [1700846]
- [net] net/tls: Fixed race condition in async encryption (Yauheni Kaliuta) [1700846]
- [net] tls: Fix socket mem accounting error under async encryption (Yauheni Kaliuta) [1700846]
- [net] net/tls: Add support for async encryption of records for performance (Yauheni Kaliuta) [1700846]
- [net] tls: Remove dead code in tls_sw_sendmsg (Yauheni Kaliuta) [1700846]
- [net] net/tls: Fixed return value when tls_complete_pending_work() fails (Yauheni Kaliuta) [1700846]
- [net] bpf: wait for running BPF programs when updating map-in-map (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: install script with_addr.sh (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add config fragment LWTUNNEL (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: use proper type and uapi perf_event.h header for libbpf (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add XDP selftests for modifying and popping VLAN headers (Yauheni Kaliuta) [1700846]
- [tools] bpf: make TC vlan bpf_helpers avail to selftests (Yauheni Kaliuta) [1700846]
- [net] net: fix generic XDP to handle if eth header was mangled (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test_verifier, check bpf_map_lookup_elem access in bpf prog (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test_verifier, change names of fixup maps (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, print strerror when map lookup error occurs (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, split the function do_dump() (Yauheni Kaliuta) [1700846]
- [net] bpf: return EOPNOTSUPP when map lookup isn't supported (Yauheni Kaliuta) [1700846]
- [net] bpf: error handling when map_lookup_elem isn't supported (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Fix a missing check bug (Yauheni Kaliuta) [1700846]
- [net] bpf: allow offload of programs with BPF-to-BPF function calls (Yauheni Kaliuta) [1700846]
- [net] bpf: add verifier callback to get stack usage info for offloaded progs (Yauheni Kaliuta) [1700846]
- [tools] libbpf: relicense libbpf as LGPL-2.1 OR BSD-2-Clause (Yauheni Kaliuta) [1700846]
- [samples] bpf, tracex3_user: erase "ARRAY_SIZE" redefined (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Use __u32 instead of u32 in bpf_program__load (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Make include guards consistent (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in str_error.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in nlattr.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in libbpf.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Move __dump_nlmsg_t from API to implementation (Yauheni Kaliuta) [1700846]
- [documentation] Documentation: Describe bpf reference tracking (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add C tests for reference tracking (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support loading individual progs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add tests for reference tracking (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Generalize dummy program types (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add helper to retrieve socket in BPF (Yauheni Kaliuta) [1700846]
- [include] bpf: Introduce bpf_skb_ancestor_cgroup_id helper (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync include/uapi/linux/bpf.h to tools/include/uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync bpf.h uapi with tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h uapi to tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Add reference tracking to verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Macrofy stack state copy (Yauheni Kaliuta) [1700846]
- [include] bpf: Add PTR_TO_SOCKET verifier type (Yauheni Kaliuta) [1700846]
- [net] bpf: Generalize ptr_or_null regs check (Yauheni Kaliuta) [1700846]
- [net] bpf: Reuse canonical string formatter for ctx errs (Yauheni Kaliuta) [1700846]
- [net] bpf: Add iterator for spilled registers (Yauheni Kaliuta) [1700846]
- [net] bpf: don't accept cgroup local storage with zero value size (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: cgroup local storage-based network counters (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: extend test_cgrp2_attach2 test to use per-cpu cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: extend the storage test to test per-cpu cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add verifier per-cpu cgroup storage tests (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for PERCPU_CGROUP_STORAGE maps (Yauheni Kaliuta) [1700846]
- [net] bpf: don't allow create maps of per-cpu cgroup local storages (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce per-cpu cgroup local storage (Yauheni Kaliuta) [1700846]
- [net] bpf: rework cgroup storage pointer passing (Yauheni Kaliuta) [1700846]
- [net] bpf: extend cgroup bpf core to allow multiple cgroup storage types (Yauheni Kaliuta) [1700846]
- [net] bpf/test_run: support cgroup local storage (Yauheni Kaliuta) [1700846]
- [net] bpf: harden flags check in cgroup_storage_update_elem() (Yauheni Kaliuta) [1700846]
- [net] bpf: permit CGROUP_DEVICE programs accessing helper bpf_get_current_cgroup_id() (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test libbpf_{prog,attach}_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Use libbpf_attach_type_by_name in test_socket_cookie (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support sk_skb/stream_{parser, verdict} section names (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support cgroup_skb/{e,in}gress section names (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Introduce libbpf_attach_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] bpftool: Fix bpftool net output (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for BPF_MAP_TYPE_REUSEPORT_SOCKARRAY maps (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_maps, only support ESTABLISHED socks (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, fix transition through disconnect without close (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap only allow ESTABLISHED sock state (Yauheni Kaliuta) [1700846]
- [net] bpf: remove redundant null pointer check before consume_skb (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: fix compilation failure (Yauheni Kaliuta) [1700846]
- [net] flow_dissector: fix build failure without CONFIG_NET (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: fix a compilation failure (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: remove duplicated includes (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: improve output format for bpftool net (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix bpf_flow.c build (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test bpf flow dissection (Yauheni Kaliuta) [1700846]
- [tools] flow_dissector: implements eBPF parser (Yauheni Kaliuta) [1700846]
- [tools] bpf: support flow dissector in libbpf and bpftool (Yauheni Kaliuta) [1700846]
- [include] flow_dissector: implements flow dissector BPF hook (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Fix end boundary calculation for type section (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix a netlink recv issue (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: support prog array map and map of maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for program array map (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add net support (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add more netlink functionalities in lib/bpf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: move bpf/lib netlink related functions into a new file (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf/test_progs: do not check errno == 0 (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: fix verifier instability (Yauheni Kaliuta) [1700846]
- [net] bpf: avoid misuse of psock when TCP_ULP_BPF collides with another ULP (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, add xskmap in map types (Yauheni Kaliuta) [1700846]
- [tools] bpf: add selftest for bpf's (set|get)_sockopt for SAVE_SYN (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: xdpsock, minor fixes (Yauheni Kaliuta) [1700846]
- [samples] bpf: add TCP_SAVE_SYN/TCP_SAVED_SYN sample program (Yauheni Kaliuta) [1700846]
- [net] bpf: add TCP_SAVE_SYN/TCP_SAVED_SYN options for bpf_(set|get)sockopt (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add btf percpu map formated dump (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add bpffs percpu map pretty print tests in test_btf (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for percpu arraymap/hash/lru_hash (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: display non-spill stack slot types in print_verifier_state (Yauheni Kaliuta) [1700846]
- [tools] bpf: use --cgroup in test_suite if supplied (Yauheni Kaliuta) [1700846]
- [tools] bpf: sockmap test remove shutdown() calls (Yauheni Kaliuta) [1700846]
- [net] bpf: remove duplicated include from syscall.c (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, decrement copied count correctly in redirect error case (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix psock refcount leak in bpf_tcp_recvmsg (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix potential use after free in bpf_tcp_close (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: return from do_event_pipe() on bad arguments (Yauheni Kaliuta) [1700846]
- [net] bpf: use per htab salt for bucket hash (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap: write_space events need to be passed to TCP handler (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock hash count in alloc_sock_hash_elem (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock_hash_alloc and reject zero-sized keys (Yauheni Kaliuta) [1700846]
- [net] bpf: fix redirect to map under tail calls (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Support per queue XDP ring (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add XDP TX and REDIRECT (Yauheni Kaliuta) [1700846]
- [net] xdp: Helpers for disabling napi_direct of xdp_return_frame (Yauheni Kaliuta) [1700846]
- [net] bpf: Make redirect_info accessible from modules (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add ndo_xdp_xmit (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Handle xdp_frames in xdp napi ring (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Avoid drops by oversized packets when XDP is enabled (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add driver XDP (Yauheni Kaliuta) [1700846]
- [net] net: Export skb_headers_offset_update (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix bpf selftest test_cgroup_storage failure (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock_map_ctx_update_elem race with exist/noexist (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix map elem deletion race with smap_stop_sock (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix leakage of smap_psock_map_entry (Yauheni Kaliuta) [1700846]
- [net] bpf: fix a rcu usage warning in bpf_prog_array_copy_core() (Yauheni Kaliuta) [1700846]
- [tools] bpf: test: fix spelling mistake "REUSEEPORT" -> "REUSEPORT" (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Selftest for bpf_skb_ancestor_cgroup_id (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add cgroup id helpers to bpf_helpers.h (Yauheni Kaliuta) [1700846]
- [net] bpf: decouple btf from seq bpf fs dump and enable more maps (Yauheni Kaliuta) [1700846]
- [tools] bpf: Test BPF_PROG_TYPE_SK_REUSEPORT (Yauheni Kaliuta) [1700846]
- [tools] bpf: test BPF_MAP_TYPE_REUSEPORT_SOCKARRAY (Yauheni Kaliuta) [1700846]
- [tools] bpf: Refactor ARRAY_SIZE macro to bpf_util.h (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce BPF_PROG_TYPE_SK_REUSEPORT (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce BPF_MAP_TYPE_REUSEPORT_SOCKARRAY (Yauheni Kaliuta) [1700846]
- [net] net: Add ID (if needed) to sock_reuseport and expose reuseport_lock (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add bpffs pretty print btf test for hash/lru_hash maps (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: add pretty print for hash/lru_hash maps (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpffs non-array map seq_show issue (Yauheni Kaliuta) [1700846]
- [powerpc] powerpc/Makefiles: Convert ifeq to ifdef where possible (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce update_effective_progs() (Yauheni Kaliuta) [1700846]
- [s390] s390: fix br_r1_trampoline for machines without exrl (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix a typo in map in map test (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: fix BTF code added twice to different trees (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: extend test_cgrp2_attach2 test to use cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add a cgroup storage test (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add verifier cgroup storage tests (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for CGROUP_STORAGE maps (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce the bpf_get_local_storage() helper function (Yauheni Kaliuta) [1700846]
- [net] bpf: don't allow create maps of cgroup local storages (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: introduce BPF_PTR_TO_MAP_VALUE (Yauheni Kaliuta) [1700846]
- [net] bpf: extend bpf_prog_array to store pointers to the cgroup storage (Yauheni Kaliuta) [1700846]
- [net] bpf: allocate cgroup storage entries on attaching bpf programs (Yauheni Kaliuta) [1700846]
- [net] bpf: pass a pointer to a cgroup storage using pcpu variable (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce cgroup storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add ability to charge bpf maps memory dynamically (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: MOV64 don't mark dst reg unbounded (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test for get_socket_cookie (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add bpf_get_socket_cookie to bpf_helpers.h (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Support bpf_get_socket_cookie in more prog types (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: convert xdpsock_user.c to libbpf (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: convert xdp_fwd_user.c to libbpf (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: add bpf_object__find_program_by_title() (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: handle NULL program gracefully in bpf_program__nth_fd() (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: Add BTF build flags to Makefile (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: ignore build products (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add Python 3 support to selftests scripts for bpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: fix inconsistent IS_ERR and PTR_ERR (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap: remove redundant pointer sg (Yauheni Kaliuta) [1700846]
- [net] bpf: bpf_prog_array_alloc() should return a generic non-rcu pointer (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: don't pass FEATURES_DUMP to libbpf (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: remove libelf-getphdrnum feature detection (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: test_cgrp2_sock2: fix an off by one (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: ensure that we don't load over MAX_PROGS programs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test case for BPF_SOCK_OPS_TCP_LISTEN_CB (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Better verification in test_tcpbpf (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Switch test_tcpbpf_user to cgroup_helpers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix const'ness in cgroup_helpers (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Add BPF_SOCK_OPS_TCP_LISTEN_CB (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: print map dump and lookup with btf info (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: add btf print functionality (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: export btf types and name by offset from lib (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: build and install man page for eBPF helpers from bpftool/ (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1700846]
- [include] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add bash completion for cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] bpftool: document cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] bpftool: introduce cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test sys_connect BPF hooks with TFO (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: Add xdp_sample_pkts example (Yauheni Kaliuta) [1700846]
- [tools] trace_helpers.c: Add helpers to poll multiple perf FDs for events (Yauheni Kaliuta) [1700846]
- [net] bpf: deal with kABI breakage in cgroups (Yauheni Kaliuta) [1700846]
- [netdrv] nfp: bpf: fix static check error through tightening shift amount adjustment (Pablo Cascon) [1663986]
- [netdrv] nfp: disable netpoll on representors (Pablo Cascon) [1663986]
- [netdrv] nfp: validate the return code from dev_queue_xmit() (Pablo Cascon) [1663986]
- [netdrv] nfp: fix simple vNIC mailbox length (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: set higher timeout for flash bundle (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: allow the use of DMA buffer (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: move default buffer handling into its own function (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: use fractional size of the buffer (Pablo Cascon) [1663986]
- [netdrv] nfp: report RJ45 connector in ethtool (Pablo Cascon) [1663986]
- [netdrv] nfp: remove ethtool flashing fallback (Pablo Cascon) [1663986]
- [netdrv] nfp: Remove switchdev.h inclusion (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: fix code-gen bug on BPF_ALU | BPF_XOR | BPF_K (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: allow flashing the device via devlink (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: include vendor/product info in serial number (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: use the generic manufacture identifier instead of vendor (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: cmsg: use struct_size() helper (Pablo Cascon) [1663986]
- [netdrv] nfp: Implement ndo_get_port_parent_id() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: complete ALU32 logic shift supports (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: correct the behavior for shifts by zero (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report the running and flashed versions (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: add support for versions command (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report fixed versions (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report driver name and serial number (Pablo Cascon) [1663986]
- [netdrv] nfp: use struct_size() in kzalloc() (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: enable MAC address sharing for offloadable devs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure MAC cleanup on address change (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: add infastructure for non-repr priv data (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure deletion of old offloaded MACs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove list infastructure from MAC offload (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ignore offload of VF and PF repr MAC addresses (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: tidy tunnel related private data (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: support multiple memory units for filter offloads (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: increase cmesg reply timeout (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: optimize codegen for JSET with a constant (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: remove the trivial JSET optimization (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: fix cb_ident duplicate in indirect block register (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: allow to opt-out of RED offload (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure TCP flags can be placed in IPv6 frame (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Pablo Cascon) [1663986]
- [netdrv] nfp: convert to DEFINE_SHOW_ATTRIBUTE (Pablo Cascon) [1663986]
- [netdrv] nfp: report more info when reconfiguration fails (Pablo Cascon) [1663986]
- [netdrv] nfp: add offset to all TLV parsing errors (Pablo Cascon) [1663986]
- [netdrv] nfp: add offloads on representors (Pablo Cascon) [1663986]
- [netdrv] nfp: add locking around representor changes (Pablo Cascon) [1663986]
- [netdrv] nfp: run don't require Qdiscs on representor netdevs (Pablo Cascon) [1663986]
- [netdrv] nfp: run representor TX locklessly (Pablo Cascon) [1663986]
- [netdrv] nfp: avoid oversized TSO headers with metadata prepend (Pablo Cascon) [1663986]
- [netdrv] nfp: correct descriptor offsets in presence of metadata (Pablo Cascon) [1663986]
- [netdrv] nfp: move queue variable init (Pablo Cascon) [1663986]
- [netdrv] nfp: move temporary variables in nfp_net_tx_complete() (Pablo Cascon) [1663986]
- [netdrv] nfp: copy only the relevant part of the TX descriptor for frags (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: prevent offload if rhashtable insert fails (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: release metadata on offload failure (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add support for more threshold actions (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add cls_u32 offload for simple band classification (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add functions to update DSCP -> virtual queue map (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: calculate PRIO map len and check mailbox size (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add GRED offload (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: wrap RED parameters in bands (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add up bands for sto/non-sto stats (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: switch to extended stats for reading packet/byte counts (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: size threshold table to account for bands (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: pass band parameter to functions (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: map per-band symbols (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: restructure Qdisc handling (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: save RED's parameters (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: reset RED's child based on limit (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: build full Qdisc hierarchy based on graft notifications (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: allocate Qdisc child table (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: remember which Qdisc is root (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: track all offload-enabled qdiscs (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: keep track of all RED thresholds (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: rename qdiscs -> red_qdiscs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove unnecessary code in flow lookup (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove TC egdev offloads (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: offload tunnel decap rules via indirect TC blocks (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: increase scope of netdev checking functions (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: allow non repr netdev offload (Pablo Cascon) [1663986]
- [netdrv] nfp: use the new __netdev_tx_sent_queue() BQL optimisation (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: refuse RED offload with harddrop set (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: don't set negative threshold (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: provide more precise info about offload parameter validation (Pablo Cascon) [1663986]
- [netdrv] nfp: parse vNIC TLV capabilities at alloc time (Pablo Cascon) [1663986]
- [netdrv] nfp: pass ctrl_bar pointer to nfp_net_alloc (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: split qdisc offload code into a separate file (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: include geneve as supported offload tunnel type (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: use geneve and vxlan helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: use the common netdev notifier (Pablo Cascon) [1663986]
- [netdrv] nfp: register a notifier handler in a central location for the device (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: make nfp_fl_lag_changels_event() void (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: don't try to nack device unregister events (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove unnecessary iteration over devices (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: protect against mis-initializing atomic counters (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink port split support for 1x100G CXP NIC (Pablo Cascon) [1663986]
- [netdrv] nfp: replace long license headers with SPDX (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support pointers to other stack frames for BPF-to-BPF calls (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: account for BPF-to-BPF calls when preparing nfp JIT (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: ignore helper-related checks for BPF calls in nfp verifier (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: rename nfp_prog->stack_depth as nfp_prog->stack_frame_depth (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow control message sizing for map ops (Pablo Cascon) [1663986]
- [netdrv] nfp: allow apps to request larger MTU on control vNIC (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: parse global BPF ABI version capability (Pablo Cascon) [1663986]
- [netdrv] nfp: warn on experimental TLV types (Pablo Cascon) [1663986]
- [netdrv] nfp: remove ndo_poll_controller (Pablo Cascon) [1663986]
- [netdrv] nfp: replace spin_lock_bh with spin_lock in tasklet callback (Pablo Cascon) [1663986]
- [netdrv] nfp: separate VXLAN and GRE feature handling (Pablo Cascon) [1663986]
- [netdrv] nfp: validate rtsym accesses fall within the symbol (Pablo Cascon) [1663986]
- [netdrv] nfp: prefix rtsym error messages with symbol name (Pablo Cascon) [1663986]
- [netdrv] nfp: fix readq on absolute RTsyms (Pablo Cascon) [1663986]
- [netdrv] nfp: make RTsym users handle absolute symbols correctly (Pablo Cascon) [1663986]
- [netdrv] nfp: support access to absolute RTsyms (Pablo Cascon) [1663986]
- [netdrv] nfp: convert all RTsym users to use new read/write helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: convert existing RTsym helpers to full target decoding (Pablo Cascon) [1663986]
- [netdrv] nfp: pass cpp_id to nfp_cpp_map_area() (Pablo Cascon) [1663986]
- [netdrv] nfp: add RTsym access helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: add basic errors messages to target logic (Pablo Cascon) [1663986]
- [netdrv] nfp: save the MU locality field offset (Pablo Cascon) [1663986]
- [netdrv] nfp: refactor the per-chip PCIe config (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for NFP5000 (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: look up MAC addresses via management FW (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for indirect HWinfo lookup (Pablo Cascon) [1663986]
- [netdrv] nfp: interpret extended FW load result codes (Pablo Cascon) [1663986]
- [netdrv] nfp: attempt FW load from flash (Pablo Cascon) [1663986]
- [netdrv] nfp: encapsulate NSP command arguments into structs (Pablo Cascon) [1663986]
- [netdrv] nfp: clean up return types in kdoc comments (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: allow matching on ipv4 UDP tunnel tos and ttl (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: xdp_adjust_tail support (Pablo Cascon) [1663986]
- [netdrv] nfp: fix variable dereferenced before check in nfp_app_ctrl_rx_raw() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: improve map offload info messages (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: remember maps by ID (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow receiving perf events on data queues (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: pass raw data buffer to nfp_bpf_event_output() (Pablo Cascon) [1663986]
- [netdrv] nfp: allow control message reception on data queues (Pablo Cascon) [1663986]
- [netdrv] nfp: move repr handling on RX path (Pablo Cascon) [1663986]
- [netdrv] nfp: protect from theoretical size overflows on HW descriptor ring (Pablo Cascon) [1663986]
- [netdrv] nfp: restore correct ordering of fields in rx ring structure (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow program sharing within ASIC (Pablo Cascon) [1663986]
- [netdrv] nfp: add .ndo_init() and .ndo_uninit() callbacks (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for simultaneous driver and hw XDP (Pablo Cascon) [1663986]
- [netdrv] nfp: avoid using getnstimeofday64() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: migrate to advanced reciprocal divide in reciprocal_div.h (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support u32 divide using reciprocal_div.h (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support u16 and u32 multiplications (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: copy range info for all operands of all ALU operations (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: rename umin/umax to umin_src/umax_src (Pablo Cascon) [1663986]
- [netdrv] nfp: make use of napi_consume_skb() (Pablo Cascon) [1663986]
- [netdrv] nfp: implement netpoll ndo (thus enabling netconsole) (Pablo Cascon) [1663986]
- [netdrv] nfp: fail probe if serial or interface id is missing (Pablo Cascon) [1663986]
- [netdrv] nfp: expose ring stats of inactive rings via ethtool (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow source ptr type be map ptr in memcpy optimization (Pablo Cascon) [1663986]
- [netdrv] bpf: offload: keep the offload state per-ASIC (Pablo Cascon) [1663986]
- [netdrv] bpf: offload: aggregate offloads per-device (Pablo Cascon) [1663986]
- [tools] selftests/bpf: add test for sharing objects between netdevs (Ivan Vecera) [1708399]
- [netdrv] netdevsim: allow program sharing between devices (Ivan Vecera) [1708399]
- [net] bpf: offload: allow program and map sharing per-ASIC (Ivan Vecera) [1708399]
- [netdrv] bpf: offload: keep the offload state per-ASIC (Ivan Vecera) [1708399]
- [netdrv] bpf: offload: aggregate offloads per-device (Ivan Vecera) [1708399]
- [net] bpf: offload: rename bpf_offload_dev_match() to bpf_offload_prog_map_match() (Ivan Vecera) [1708399]
- [netdrv] netdevsim: associate bound programs with shared dev (Ivan Vecera) [1708399]
- [netdrv] netdevsim: add shared netdevsim devices (Ivan Vecera) [1708399]
- [netdrv] netdevsim: add switch_id attribute (Ivan Vecera) [1708399]

* Wed Jun 12 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-105.el8]
- [infiniband] IB/mlx5: Remove set but not used variable (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: WQE dump jumps over first 16 bytes (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix false compilation warning (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Remove redundant assignment (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix compilation warning in en_tc.c (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix compilation warning in eq.c (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix the max MTU check in case of XDP (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix use-after-free after xdp_return_frame (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix scatter to CQE in DCT QP creation (Alaa Hleihel) [1691238]
- [netdrv] Revert "net/mlx5e: Enable reporting checksum unnecessary also for L3 packets" (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Rx, Check ip headers sanity (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: FPGA, tls, idr remove on flow delete (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: FPGA, tls, hold rcu read lock a bit longer (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Consider tunnel type for encap contexts (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: E-Switch, Fix esw manager vport indication for more vport commands (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Correctly use the namespace type when allocating pedit action (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: ethtool, Allow legacy link-modes configuration via non-extended ptys (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: ethtool, Fix type analysis of advertised link-mode (Alaa Hleihel) [1691238]
- [netdrv] net: mlx5: Add a missing check on idr_find, free buf (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Allow IPv4 ttl & IPv6 hop_limit rewrite for all L4 protocols (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Use mlx5 core to create/destroy a DEVX DCT (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix DCT creation bad flow (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix bad flow upon DEVX mkey creation (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Add support for ODP for DEVX indirection mkey (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Manage indirection mkey upon DEVX flow for ODP (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: DEVX handling for indirection MKEY (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix access to non-existing receive queue (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Properly get the PF number phys port name ndo (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Consolidate update FTE for all removal changes (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Add a locked flag to node removal functions (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Add modify FTE helper function (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix multiple updates of steering rules in parallel (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Validate correct PD before prefetch MR (Alaa Hleihel) [1691238]
- [infiniband] RDMA/mlx5: Introduce and reuse helper to identify ODP MR (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Protect against prefetch of invalid MR (Alaa Hleihel) [1691238]
- [infiniband] net/mlx5: Make mlx5_cmd_exec_cb() a safe API (Alaa Hleihel) [1691238]
- [infiniband] RDMA: Clean structures from CONFIG_INFINIBAND_ON_DEMAND_PAGING (Alaa Hleihel) [1691238]
- [infiniband] RDMA/mlx5: Embed into the code flow the ODP config option (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Add missing static function annotation (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Do not use hw_access_flags for be and CPU data (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix code style issue in mlx driver (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix the locking of SRQ objects in ODP events (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Make mlx5_ib_stage_odp_cleanup() static (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Declare local functions 'static' (Alaa Hleihel) [1691238]
- [netdrv] RDMA/mlx5: Delete declaration of already removed function (Alaa Hleihel) [1691238]
- [netdrv] mlx5-core: Mark ConnectX-6 Dx as unsupported device (Alaa Hleihel) [1691236 1687434]
- [netdrv] net/mlx5: Update the list of the PCI supported devices (Alaa Hleihel) [1691236 1687434]
- [infiniband] IB/mlx5: Fix mapping of link-mode to IB width and speed (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: ethtool, Add ethtool support for 50Gbps per lane link modes (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Add support for 50Gbps per lane link modes (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5: Add support to ext_* fields introduced in Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [include] net/mlx5: Add new fields to Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5: Refactor queries to speed fields in Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5e: Set peer flow needed also for multipath (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Update check for merged eswitch device (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Use hint to resolve route when in HW multipath mode (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Always query offloaded tc peer rule counter (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Re-attempt to offload flows on multipath port affinity events (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Emit port affinity event for multipath offloads (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Allow one failure when offloading tc encap rules under multipath (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Don't inherit flow flags on peer flow creation (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Activate HW multipath and handle port affinity based on FIB events (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Add multipath mode (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Use own workqueue for lag netdev events processing (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Expose lag operations in header file (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Use unsigned int bit instead of bool as a struct member (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Don't make internal use of errno to denote missing neigh (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Cleanup attach encap function (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Remove 'parse_attr' argument in mlx5e_tc_add_fdb_flow() (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Introduce mlx5e_flow_esw_attr_init() helper (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Return the allocated flow directly from __mlx5e_add_fdb_flow (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix GRE key by controlling port tunnel entropy calculation (Alaa Hleihel) [1691236 1663240]
- [include] net/mlx5: Introduce tunnel entropy control in PCMR register (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Use read-modify-write when changing PCMR register values (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Remove wrong and superfluous tc pedit header type check (Alaa Hleihel) [1691236]
- [netdrv] drivers: net: use flow action infrastructure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: support for two independent packet edit actions (Alaa Hleihel) [1691236]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, fix redirect resources availability check (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix a compilation warning in events.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: No command allowed when command interface is not ready (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix NULL pointer derefernce in set channels error flow (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Don't overwrite pedit action when multiple pedit used (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Update hw flows when encap source mac changed (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use the inner headers to determine tc/pedit offload limitation on decap flows (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Properly set steering match levels for offloaded TC decap rules (Alaa Hleihel) [1691236 1663207]
- [netdrv] net/mlx5e: Unblock setting vid 0 for VFs through the uplink rep (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move to use common phys port names for vport representors (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Allow MAC invalidation while spoofchk is ON (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Take lock with IRQs disabled to avoid deadlock (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong private flag usage causing checksum disable (Alaa Hleihel) [1691236]
- [netdrv] Revert "net/mlx5e: E-Switch, Initialize eswitch only if eswitch manager" (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Fix flow creation on representors (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix how advise_mr() launches async work (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Fix check for supported user flags when creating a QP (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix cb_ident duplicate in indirect block register (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong (zero) TX drop counter indication for representor (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong error code return on FEC query failure (Alaa Hleihel) [1691236]
- [infiniband] Revert "IB/mlx5: Fix long EEH recover time with NVMe offloads" (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow XRC INI usage via verbs in DEVX context (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: drop useless LIST_HEAD (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: fix semicolon.cocci warnings (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Signedness bug in UVERBS_HANDLER() (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allocate the per-port Q counter shared when DEVX is supported (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Add user control for XDP TX MPWQE feature (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Support Enhanced Multi-Packet TX WQE (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Add array for WQE info descriptors (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Maintain a FIFO structure for xdp_info instances (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Replace boolean doorbell indication with segment pointer (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Warn upon polling an error CQE (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Change the XDP SQ redirect indication (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Precede XDP-related operations in RQ poll by a loaded program check (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: TX, Print opcode in error CQE warning (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix wrong error unwind (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix long EEH recover time with NVMe offloads (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Simplify netdev unbinding (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use the correct commands for UMEM and UCTX allocation (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use uid as part of alloc/dealloc transport domain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix LAG requirement when CONFIG_MLX5_ESWITCH is off (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix query_nic_sys_image_guid() error during init (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Support tunnel encap over tagged Ethernet (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Support VLAN encap ETH header generation (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Re-order route and encap header memory allocation (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Tunnel encap ETH header helper function (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Fail attempt to offload e-switch TC encap flows with vlan on underlay (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Tunnel routing output devs helper function (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Fail attempt to offload e-switch TC flows with egress upper devices (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Allow vlans on e-switch uplink reps (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Increase VF representors' SQ size to 128 (Alaa Hleihel) [1691236]
- [netdrv] mlx5: extend PTP gettime function to read system clock (Alaa Hleihel) [1691236]
- [netdrv] mlx5: update timecounter at least twice per counter overflow (Alaa Hleihel) [1691236]
- [include] IB/mlx5: Introduce uid as part of alloc/dealloc transport domain (Alaa Hleihel) [1691236]
- [netdrv] drivers: net: ethernet: mellanox: use skb_sec_path helper (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix compile issue when ODP disabled (Alaa Hleihel) [1691236]
- [include] net/mlx5: Add shared Q counter bits (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add advise_mr() support (Alaa Hleihel) [1691236 1663248]
- [infiniband] IB/uverbs: Add helper to get array size from ptr attribute (Alaa Hleihel) [1691236 1663248]
- [infiniband] RDMA/mlx5: Fix function name typo 'fileds' -> 'fields' (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Delete unreachable handle_atomic code by simplifying SW completion (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Continue driver initialization despite debugfs failure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Add some ethtool port control entries to the uplink rep netdev (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Expose ethtool pause and link functions to mlx5e callers (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Add sriov and udp tunnel ndo support for the uplink rep (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Handle port mtu/link, dcb and lag for uplink reps (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Uninstantiate esw manager vport netdev on switchdev mode (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Remove leftover code from the PF netdev being uplink rep (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Use dedicated uplink vport netdev representor (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Use single argument for the esw representor build params helper (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5: E-Switch, Remove redundant reloading of the IB interface (Alaa Hleihel) [1691236 1663256 1663207]
- [netdrv] net/mlx5: Handle LAG FW commands failure gracefully (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Make RoCE and SR-IOV LAG modes explicit (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Rename mlx5_lag_is_bonded() to __mlx5_lag_is_active() (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Allow co-enablement of uplink LAG and SRIOV (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Allow/disallow LAG according to pre-req only (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Adjustments for the activate LAG logic to run under sriov (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Duplicate offloaded TC eswitch rules under uplink LAG (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Offload TC e-switch rules with egress LAG device (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: In case of LAG, one switch parent id is used for all representors (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Enhance flow counter scheme for offloaded TC eswitch rules (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Infrastructure for duplicated offloading of TC flows (Alaa Hleihel) [1691236 1663230 1663207]
- [netdrv] net/mlx5e: E-Switch, Add peer miss rules (Alaa Hleihel) [1691236 1663230 1663207]
- [netdrv] net/mlx5: Introduce inter-device communication mechanism (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Fold the modify lag code into function (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Add lag affinity info to log (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Split the activate lag function into two routines (Alaa Hleihel) [1691236 1663230]
- [include] net/mlx5: E-Switch, Introduce flow counter affinity (Alaa Hleihel) [1691236 1663230]
- [infiniband] IB/mlx5: Unify e-switch representors load approach between uplink and VFs (Alaa Hleihel) [1691236]
- [include] net/mlx5: Use lowercase 'X' for hex values (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove set but not used variable 'upriv' (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove duplicated include from eswitch.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use monitor counters for update stats (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Monitor counters commands support (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Avoid query PPCNT register if not supported by the device (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use CQE padding for Ethernet CQs (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Support multiple encapsulations for a TC flow (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Allow association of a flow to multiple encaps (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Change parse attr struct to accommodate multiple tunnel infos (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Support header rewrite actions with remote port mirroring (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Replace the split logic with extended destination (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Annul encap action ordering requirement (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Move flow attr reformat action bit to per dest flags (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Refactor eswitch flow attr for destination specific properties (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5: E-Switch, Rename esw attr mirror count field (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5: Consider encapsulation properties when comparing destinations (Alaa Hleihel) [1691236 1663239]
- [infiniband] RDMA/mlx5: Fail early if user tries to create flows on IB representors (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Remove duplicated include from mlx5_ib.h (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add 2X width support to query_port (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Add HDR speed support to query port (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Report CapabilityMask2 in ib_query_port (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5e: Add GRE protocol offloading (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Move TC tunnel offloading code to separate source file (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Branch according to classified tunnel type (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Refactor VXLAN tunnel decap offloading code (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Refactor VXLAN tunnel encap offloading code (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Replace egdev with indirect block notifications (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Propagate the filter's net device to mlx5e structures (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Provide the TC filter netdev as parameter to flower callbacks (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Support TC indirect block notifications for eswitch uplink reprs (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Store eswitch uplink representor state on a dedicated struct (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Remove the get protocol device interface entry (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Support extended destination format in flow steering command (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5: E-Switch, Change vhca id valid bool field to bit flag (Alaa Hleihel) [1691236 1663239 1663207]
- [include] net/mlx5: Introduce extended destination fields (Alaa Hleihel) [1691236 1663239]
- [infiniband] net/mlx5: Revise gre and nvgre key formats (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Add monitor commands layout and event data (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Add support for plugged-disabled cable status in PME (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Add support for PCIe power slot exceeded error in PME (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Rework handling of port module events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Move flow counters data structures from flow steering header (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use helper to get CQE opcode (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Use helper to get CQE opcode (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: When fetching CQEs return CQE instead of void pointer (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Report packet based credit mode device capability (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add packet based credit mode support (Alaa Hleihel) [1691236]
- [include] net/mlx5: Expose packet based credit mode (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enable TX on a DEVX flow table (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Improve ethtool private-flags code structure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: ethtool, Support user configuration for RX hash fields (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move RSS params to a dedicated struct (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Refactor TIR configuration function (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move modify tirs hash functionality (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Cleanup unused defines (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove trailing space of tx_pause ethtool counter name (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow XRC usage via verbs in DEVX context (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Update the supported DEVX commands (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enforce DEVX privilege by firmware (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enable modify and query verbs objects via DEVX (Alaa Hleihel) [1691236]
- [include] net/mlx5: Update mlx5_ifc with DEVX UCTX capabilities bits (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Unfold modify RMP function (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Unfold create RMP function (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Initialize SRQ tables on mlx5_ib (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Update SRQ functions signatures to mlx5_ib format (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Use stages for callback to setup and release DEVX (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Remove SRQ signature global flag (Alaa Hleihel) [1691236]
- [infiniband] net/mlx5: Move SRQ functions to RDMA part (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove references to local mlx5_core functions (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove not-used lib/eq.h header file (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove dead transobj code (Alaa Hleihel) [1691236]
- [infiniband] net/mlx5: Align SRQ licenses and copyright information (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Debug print for forwarded async events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward SRQ resource events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward QP/WorkQueues resource events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove all deprecated software versions of FW events (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Handle raw delay drop general event (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Allow forwarding event type general event as is (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Handle raw port change event rather than the software version (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove unused events callback and logic (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use the new mlx5 core notifier API (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward all mlx5 events to mlx5 notifiers chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use the new mlx5 core notifier API (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Allow port change event to be forwarded to driver notifiers chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Driver events notifier API (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use fragmented QP's buffer for in-kernel users (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use fragmented SRQ's buffer for in-kernel users (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Attach a DEVX counter via raw flow creation (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Improve core device events handling (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Device events, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: CQ ERR, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Resource tables, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: CmdIF, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FWPage, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: E-Switch, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Clock, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FPGA, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FWTrace, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Introduce atomic notifier chain subscription API (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Use the uapi disablement APIs instead of code (Alaa Hleihel) [1691236]
- [infiniband] RDMA/uverbs: Use a linear list to describe the compiled-in uapi (Alaa Hleihel) [1691236]
- [netdrv] mlx5: use skb_vlan_tag_get_prio() (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow modify AV in DCI QP to RTR (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Make EQE access methods inline (Alaa Hleihel) [1691236]
- [netdrv] {net, IB}/mlx5: Move Page fault EQ and ODP logic to RDMA (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Generic EQ (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Different EQ types (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Privatize eq_table and friends (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, irq_info and rmap belong to eq_table (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Create all EQs in one place (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Move all EQ logic to eq.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Remove redundant completion EQ list lock (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, No need to store eq index as a field (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Remove unused fields and structures (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Use the right place to store/read IRQ affinity hint (Alaa Hleihel) [1691236]
- [include] net/mlx5: Fix offsets of ifc reserved fields (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove the false indication of software timestamping support (Alaa Hleihel) [1691234 1647734]
- [netdrv] net/mlx5: Typo fix in del_sw_hw_rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: RX, Fix wrong early return in receive queue poll (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Cancel DIM work on close SQ (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Remove unused UDP GSO remaining counter (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid encap flows deletion attempt the 1st time a neigh is resolved (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Properly initialize flow attributes for slow path eswitch rule deletion (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid overriding the user provided priority for offloaded tc rules (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Err if asked to mirror a goto chain tc eswitch rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix default amount of channels for VF representors (Alaa Hleihel) [1691234]
- [include] net/mlx5: E-Switch, Fix fdb cap bits swap (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Block DEVX umem from the non applicable cases (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Fix XRC QP support after introducing extended atomic (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix failing ethtool query on FEC query error (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix wrong field name in FEC related functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix a bug in turning off FEC policy in unsupported speeds (Alaa Hleihel) [1691234]
- [include] net/mlx5: Fix XRC SRQ umem valid bits (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Allocate enough space for the FDB sub-namespaces (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Added 'raw_errors_laneX' fields to ethtool statistics (Alaa Hleihel) [1691234]
- [include] net/mlx5: Added "per_lane_error_counters" cap bit to PCAM (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Ethtool driver callback for query/set FEC policy (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add port FEC get/set functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add FEC fields to Port Phy Link Mode (PPLM) reg (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Remove counter from idr after removing it from list (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Take fs_counters dellist before addlist (Alaa Hleihel) [1691234]
- [infiniband] net/mlx5: Refactor fragmented buffer struct fields and init flow (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Support offloading tc priorities and chains for eswitch flows (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Use a slow path rule instead if vxlan neighbour isn't available (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Enable setting goto slow path chain action (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid duplicated code for tc offloads add/del fdb rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: For TC offloads, always add new flow instead of appending the actions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add a no-append flow insertion mode (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Add chains and priorities (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Have explicit API to delete fwd rules (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Split FDB fast path prio to multiple namespaces (Alaa Hleihel) [1691234]
- [include] net/mlx5: Add cap bits for multi fdb encap (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Split TC add rule path for nic vs e-switch (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Change return type of tc add flow functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Use flow counter IDs and not the wrapping cache object (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Get counters for offloaded flows from callers (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Add support for extended atomic operations (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Allow scatter to CQE without global signaled WRs (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Verify that driver supports user flags (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Support scatter to CQE for DC transport type (Alaa Hleihel) [1691234]
- [include] net/mlx5: Expose DC scatter to CQE capability bit (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Add support for flow tag to raw create flow (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Verify DEVX object type (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add new counter for aRFS rule insertion failures (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add extack messages for TC offload failures (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: E-Switch, Add extack messages to devlink callbacks (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Allow reporting of checksum unnecessary (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable reporting checksum unnecessary also for L3 packets (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add ethtool control of ring params to VF representors (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable multi-queue and RSS for VF representors (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Expose ethtool rss key size / indirection table functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Expose function for building RSS params (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Provide explicit directive if to create inner indirect tirs (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Provide flow dest when creating vport rx rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Extract creation of rep's default flow rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable stateless offloads for VF representor netdevs (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Change VF representors' RQ type (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Ethtool steering, Support masks for l3/l4 filters (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Enable DEVX on IB (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Enable DEVX white list commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Manage device uid for DEVX white list commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Expose RAW QP device handles to user space (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set valid umem bit on DEVX (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TD commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of XRCD commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of CQ creation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid upon PD allocation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of RQT commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TIS commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TIR commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of MCG commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of DCT commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of SRQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of SQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of RQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of QP creation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Use uid as part of PD commands (Alaa Hleihel) [1691234]
- [include] net/mlx5: Update mlx5_ifc with DEVX UID bits (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of DCT commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of SRQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of SQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of RQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of QP commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of CQ commands (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Enable vport loopback when user context or QP mandate (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Allow creating RAW ethernet QP with loopback support (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Refactor transport domain bookkeeping logic (Alaa Hleihel) [1691234]
- [infiniband] net/mlx5: Rename incorrect naming in IFC file (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Use rdma_user_mmap_io (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Allow creating a matcher for a NIC TX flow table (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add NIC TX namespace when getting a flow table (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add flow actions support to raw create flow (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Refactor raw flow creation (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Don't overwrite action if already set (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Refactor flow action parsing to be more generic (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching packet reformat action to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable reformat on NIC RX if supported (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching DECAP action to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable decap and packet reformat on flow tables (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching modify header to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add NIC TX steering support (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5e: Replace PTP clock lock from RW lock to seq lock (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Move Q counters allocation and drop RQ to init_rx (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add flow counters idr (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Store flow counters in a list (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add new list to store deleted flow counters (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Change flow counters addlist type to single linked list (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Extend packet reformat verbs (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add new flow action verb - packet reformat (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/uverbs: Add generic function to fill in flow action object (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add a new flow action verb - modify header (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Export packet reformat alloc/dealloc functions (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Pass a namespace for packet reformat ID allocation (Alaa Hleihel) [1691234 1663215]
- [include] net/mlx5: Expose new packet reformat capabilities (Alaa Hleihel) [1691234 1663215]
- [netdrv] {net, RDMA}/mlx5: Rename encap to reformat packet (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Move header encap type to IFC header file (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Break encap/decap into two separated flow table creation flags (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Add support for more namespaces when allocating modify header (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Export modify header alloc/dealloc functions (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Add proper NIC TX steering flow tables support (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Cleanup flow namespace getter switch logic (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Change TX affinity assignment in RoCE LAG mode (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add memic command opcode to command checker (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Destroy the DEVX object upon error flow (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, Read capabilities only when it is safe (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, fix udp source port value (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Improve argument name for add flow API (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, l4 proto support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, ip6 support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering flow parsing refactoring (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering flow validation refactoring (Alaa Hleihel) [1691231]
- [infiniband] IB/uverbs: Use uverbs_alloc for allocations (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Unexport functions that need not be exported (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Remove unused mlx5_query_vport_admin_state (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: E-Switch, Remove unused argument when creating legacy FDB (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Rename modify/query_vport state related enums (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Mark expected switch fall-throughs (Alaa Hleihel) [1691231]
- [netdrv] mellanox: fix the dport endianness in call of __inet6_lookup_established() (Alaa Hleihel) [1691231]
- [netdrv] mlx5: handle DMA mapping error case for XDP redirect (Alaa Hleihel) [1691231]
- [infiniband] IB/uverbs: Add UVERBS_ATTR_FLAGS_IN to the specs language (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Issue direct lookup on vxlan ports by vport representors (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TX, Use function to access sq_dma object in fifo (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TX, Move DB fields in TXQ-SQ struct (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Add support for XDP_REDIRECT in device-out side (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Re-order fields of struct mlx5e_xdpsq (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Refactor XDP counters (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Make XDP xmit functions more generic (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Add counter for XDP redirect in RX (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Enable driver uapi commands for flow steering (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Add support for a flow table destination for driver flow steering (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Support adding flow steering rule by raw description (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Introduce driver create and destroy flow methods (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Introduce flow steering matcher uapi object (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add support for flow table destination number (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add forward compatible support for the FTE match data (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Support offloading double vlan push/pop tc actions (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5e: Refactor tc vlan push/pop actions offloading (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5e: Support offloading tc double vlan headers match (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5: FW tracer, Add debug prints (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, Enable tracing (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, parse traces and kernel tracing support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, events handling (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, register log buffer memory key (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, create trace buffer and copy strings database (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, implement tracer logic (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Remove set but not used variables (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add XRQ commands definitions (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add core support for double vlan push/pop steering action (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5: Expose MPEGC (Management PCIe General Configuration) structures (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, add hardware structures (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: fix an unused-function warning (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: IPsec, fix byte count in CQE (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Accel, add common metadata functions (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, build TLS netdev from capabilities (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add software statistics (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add Innova TLS rx data path (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add innova rx support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Accel, add TLS rx offload routines (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, refactor variable names (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Check that supplied blue flame index doesn't overflow (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Melt consecutive calls to alloc_bfreg() in one call (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Use 2-factor allocator calls (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Remove unused port number parameter (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Expose dump and fill memory key (Alaa Hleihel) [1691231]
- [include] net/mlx5: Add hardware definitions for dump_fill_mkey (Alaa Hleihel) [1691231]
- [infiniband] net/mlx5: Limit scope of dump_fill_mkey function (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Add support for drain SQ & RQ (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Support RoCE ICRC encapsulated error counter (Alaa Hleihel) [1691231 1663195]
- [include] net/mlx5: Add RoCE RX ICRC encapsulated counter (Alaa Hleihel) [1691231 1663195]
- [infiniband] RDMA/mlx5: Refactor transport domain checks (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Expose DEVX tree (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX query EQN support (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX support for memory registration (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add support for DEVX query UAR (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX support for modify and query commands (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add obj create and destroy functionality (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add support for DEVX general command (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Introduce DEVX (Alaa Hleihel) [1691231 1663190]
- [netdrv] net/mlx5: Expose DEVX specification (Alaa Hleihel) [1691231]

* Tue Jun 11 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-104.el8]
- [virt] kvm: arm/arm64: Don't emulate virtual timers on userspace ioctls (Andrew Jones) [1716066]
- [virt] kvm: arm/arm64: Remove unused timer variable (Andrew Jones) [1716066]
- [virt] kvm: arm/arm64: Rework the timer code to use a timer_map (Andrew Jones) [1716066]
- [powerpc] powernv: Fix compile without CONFIG_TRACEPOINTS (David Gibson) [1524674]
- [virt] kvm: ppc: book3s: Remove useless checks in 'release' method of KVM device (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Clear escalation interrupt pointers on device close (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Prevent races when releasing device (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Replace the 'destroy' method by a 'release' method (David Gibson) [1524674]
- [virt] kvm: Introduce a 'release' method for KVM devices (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Activate XIVE exploitation mode (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add passthrough support (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a mapping for the source ESB pages (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a TIMA mapping (David Gibson) [1524674]
- [virt] kvm: Introduce a 'mmap' method for KVM devices (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add get/set accessors for the VP XIVE state (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to dirty the XIVE EQ pages (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to sync the sources (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a global reset control (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add controls for the EQ configuration (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to configure a source (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: add a control to initialize a source (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Introduce a new capability KVM_CAP_PPC_IRQ_XIVE (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: Add a new KVM device for the XIVE native exploitation mode (David Gibson) [1524674]
- [powerpc] xive: add OPAL extensions for the XIVE native exploitation support (David Gibson) [1524674]
- [powerpc] powernv: move OPAL call wrapper tracing and interrupt handling to C (David Gibson) [1524674]
- [thermal] thermal/intel_powerclamp: fix truncated kthread name (Lihong Yang) [1716810]
- [kernel] kernel/signal.c: trace_signal_deliver when signal_group_exit (Waiman Long) [1548279]
- [kernel] signal: unconditionally leave the frozen state in ptrace_stop() (Waiman Long) [1548279]
- [kernel] cgroup: never call do_group_exit() with task->frozen bit set (Waiman Long) [1548279]
- [kernel] kernel: cgroup: fix misuse of x (Waiman Long) [1548279]
- [kernel] cgroup: get rid of cgroup_freezer_frozen_exit() (Waiman Long) [1548279]
- [kernel] cgroup: prevent spurious transition into non-frozen state (Waiman Long) [1548279]
- [kernel] cgroup: Remove unused cgrp variable (Waiman Long) [1548279]
- [documentation] cgroup: document cgroup v2 freezer interface (Waiman Long) [1548279]
- [kernel] cgroup: add tracing points for cgroup v2 freezer (Waiman Long) [1548279]
- [kernel] cgroup: make TRACE_CGROUP_PATH irq-safe (Waiman Long) [1548279]
- [tools] kselftests: cgroup: don't fail on cg_kill_all() error in cg_destroy() (Waiman Long) [1548279]
- [kernel] cgroup: cgroup v2 freezer (Waiman Long) [1548279]
- [kernel] cgroup: protect cgroup->nr_(dying_)descendants by css_set_lock (Waiman Long) [1548279]
- [kernel] cgroup: implement __cgroup_task_count() helper (Waiman Long) [1548279]
- [kernel] cgroup: rename freezer.c into legacy_freezer.c (Waiman Long) [1548279]
- [kernel] cgroup: remove extra cgroup_migrate_finish() call (Waiman Long) [1548279]
- [kernel] cgroup/cpuset: Update stale generate_sched_domains() comments (Waiman Long) [1548279]
- [kernel] cgroup: saner refcounting for cgroup_root (Waiman Long) [1548279]
- [fs] fix cgroup_do_mount() handling of failure exits (Waiman Long) [1548279]
- [kernel] cgroup: Add named hierarchy disabling to cgroup_no_v1 boot param (Waiman Long) [1548279]
- [kernel] cgroup: fix parsing empty mount option string (Waiman Long) [1548279]
- [kernel] cgroup: fix CSS_TASK_ITER_PROCS (Waiman Long) [1548279]
- [kernel] cgroup: Fix dom_cgrp propagation when enabling threaded mode (Waiman Long) [1548279]
- [lib] lib: objagg: fix handling of object with 0 users when assembling hints (Ivan Vecera) [1704850]
- [lib] test_objagg: Uninitialized variable in error handling (Ivan Vecera) [1704850]
- [lib] test_objagg: Test the correct variable (Ivan Vecera) [1704850]
- [lib] lib: objagg: Fix an error code in objagg_hints_get() (Ivan Vecera) [1704850]
- [lib] lib: objagg: add root count to stats (Ivan Vecera) [1704850]
- [lib] lib: objagg: implement optimization hints assembly and use hints for object creation (Ivan Vecera) [1704850]
- [lib] lib: objagg: fix typo in objagg_stats_put() docstring (Ivan Vecera) [1704850]
- [lib] lib: introduce initial implementation of object aggregation manager (Ivan Vecera) [1704850]
- [netdrv] ibmvnic: Fix unchecked return codes of memory allocations (Steve Best) [1718919]
- [netdrv] ibmvnic: Refresh device multicast list after reset (Steve Best) [1718919]
- [netdrv] ibmvnic: Do not close unopened driver during reset (Steve Best) [1718919]
- [target] scsi: target: tcmu: Switch to bitmap_zalloc() (Maurizio Lombardi) [1712917]
- [target] scsi: target: tcmu: wait for nl reply only if there are listeners or during an add (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Simplify iscsit_handle_text_cmd() (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Simplify iscsit_dump_data_payload() (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Avoid iscsit_release_commands_from_conn() deadlock (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Rename a function and a function pointer (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Fix spelling of "unsolicited" (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Convert comments about locking into runtime checks (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Remove an incorrect comment (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Add target_send_busy() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Inline transport_lun_remove_cmd() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify the LUN RESET implementation (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove several state tests from the TMF code (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove the write_pending_status() callback function (Maurizio Lombardi) [1712917]
- [target] scsi: target: make the pi_prot_format ConfigFS path readable (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: fix use after free (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: avoid cmd/qfull timers updated whenever a new cmd comes (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: fix error msg typo when create lio_qr_cache failed (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use kmem_cache_free() instead of kfree() (Maurizio Lombardi) [1712917]
- [target] scsi: target: perform t10_wwn ID initialisation in target_alloc_device() (Maurizio Lombardi) [1712917]
- [target] scsi: target: remove hardcoded T10 Vendor ID in INQUIRY response (Maurizio Lombardi) [1712917]
- [target] scsi: target: add device vendor_id configfs attribute (Maurizio Lombardi) [1712917]
- [target] scsi: target: consistently null-terminate t10_wwn strings (Maurizio Lombardi) [1712917]
- [target] scsi: target: use consistent left-aligned ASCII INQUIRY data (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Reduce the amount of code executed with a spinlock held (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make ABORT and LUN RESET handling synchronous (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Fix TAS handling for aborted commands (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify the code for aborting SCSI commands (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make it possible to wait from more than one context for command completion (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use system workqueues for TMF (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make sure that target_wait_for_sess_cmds() waits long enough (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fix target_wait_for_sess_cmds breakage with active signals (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify transport_clear_lun_ref() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use kvcalloc() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: target/tcmu: Fix queue_cmd_ring() declaration (Maurizio Lombardi) [1712917]
- [target] scsi: target: replace fabric_ops.name with fabric_alias (Maurizio Lombardi) [1712917]
- [target] scsi: target: drop unnecessary get_fabric_name() accessor from fabric_ops (Maurizio Lombardi) [1712917]
- [target] scsi: target: drop unused pi_prot_format attribute storage (Maurizio Lombardi) [1712917]
- [target] scsi: target: add emulate_pr backstore attr to toggle PR support (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Avoid that a kernel oops is triggered when COMPARE AND WRITE fails (Maurizio Lombardi) [1712917]
- [target] scsi: target: Don't request modules that aren't even built (Maurizio Lombardi) [1712917]
- [target] scsi: target: Set response length for REPORT TARGET PORT GROUPS (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Always call transport_complete_callback() upon failure (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use sg_alloc_table() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use the SECTOR_SHIFT constant (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove the SCF_COMPARE_AND_WRITE_POST flag (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove an unused data member from struct xcopy_pt_cmd (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Fix spelling in two source code comments (Maurizio Lombardi) [1712917]
- [target] scsi: target: stash sess_err_stats on Data-Out timeout (Maurizio Lombardi) [1712917]
- [target] scsi: target: split out helper for cxn timeout error stashing (Maurizio Lombardi) [1712917]
- [target] scsi: target: log NOP ping timeouts as errors (Maurizio Lombardi) [1712917]
- [target] scsi: target: log Data-Out timeouts as errors (Maurizio Lombardi) [1712917]
- [include] scsi: target: use ISCSI_IQN_LEN in iscsi_target_stat (Maurizio Lombardi) [1712917]
- [target] scsi: target: iblock: split T10 PI SGL across command bios (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: fix spelling mistake "entires" -> "entries" (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: Fix conn_ops double free (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: Set conn->sess to NULL when iscsi_login_set_conn_values fails (Maurizio Lombardi) [1712917]
- [target] scsi: target: loop, usb, vhost, xen: use target_remove_session (Maurizio Lombardi) [1712917]
- [target] scsi: tcm_fc: use target_remove_session (Maurizio Lombardi) [1712917]
- [target] scsi: target: make transport_init_session_tags static (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi target: have iscsit_start_nopin_timer call __iscsit_start_nopin_timer (Maurizio Lombardi) [1712917]
- [target] scsi: target: fix __transport_register_session locking (Maurizio Lombardi) [1712917]
- [target] Revert "scsi: target/iscsi: Reduce number of __iscsit_free_cmd() callers" (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use u64 for dev_size (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use match_int for dev params (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: do not set max_blocks if data_bitmap has been setup (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: unmap if dev is configured (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: check if dev is configured before block/reset (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use lio core se_device configuration helper (Maurizio Lombardi) [1712917]
- [target] scsi: target: add helper to check if dev is configured (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: initialize list head (Maurizio Lombardi) [1712917]
- [target] scsi: target_core_user: fix double unlock (Maurizio Lombardi) [1712917]
- [target] scsi: target: Remove se_dev_entry.ua_count (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fix handling of removed LUNs (Maurizio Lombardi) [1712917]
- [target] scsi: target: Send unit attention condition even if the sense buffer is too small (Maurizio Lombardi) [1712917]
- [target] scsi: target: Do not duplicate the code that marks that a command has sense data (Maurizio Lombardi) [1712917]
- [target] scsi: target/tcm_loop: Avoid that static checkers warn about dead code (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Reduce number of __iscsit_free_cmd() callers (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify the code for waiting for command completion (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify transport_generic_free_cmd() (2/2) (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify transport_generic_free_cmd() (1/2) (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fold core_tmr_handle_tas_abort() into transport_cmd_finish_abort() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify core_tmr_handle_tas_abort() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Document when CMD_T_STOP and CMD_T_COMPLETE are set (Maurizio Lombardi) [1712917]
- [target] scsi: target: Make the session shutdown code also wait for commands that are being aborted (Maurizio Lombardi) [1712917]
- [target] scsi: target: Introduce transport_init_session() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Rename transport_init_session() into transport_alloc_session() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Move a list_del_init() statement (Maurizio Lombardi) [1712917]
- [target] scsi: target: Avoid that EXTENDED COPY commands trigger lock inversion (Maurizio Lombardi) [1712917]
- [target] scsi: target: Use config_item_name() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: Don't pass KERN_ERR to pr_err (Maurizio Lombardi) [1712917]
- [target] scsi: target: remove target_find_device (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: add module wide block/reset_netlink support (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: misc nl code cleanup (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: simplify nl interface (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: track nl commands (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: delete unused __wait (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: remove useless code and clean up the code style (Maurizio Lombardi) [1712917]

* Sat Jun 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-103.el8]
- [ipc] ipc: do cyclic id allocation for the ipc object. (Waiman Long) [1710480]
- [ipc] ipc: conserve sequence numbers in ipcmni_extend mode (Waiman Long) [1710480]
- [ipc] ipc: allow boot time extension of IPCMNI from 32k to 16M (Waiman Long) [1710480]
- [ipc] ipc/mqueue: optimize msg_get() (Waiman Long) [1710480]
- [ipc] ipc/mqueue: remove redundant wq task assignment (Waiman Long) [1710480]
- [ipc] ipc: prevent lockup on alloc_msg and free_msg (Waiman Long) [1710480]
- [ipc] ipc: IPCMNI limit check for semmni (Waiman Long) [1710480]
- [ipc] ipc: IPCMNI limit check for msgmni and shmmni (Waiman Long) [1710480]
- [ipc] ipc/shm.c: use ERR_CAST() for shm_lock() error return (Waiman Long) [1710480]
- [ipc] ipc/shm: properly return EIDRM in shm_lock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: update return value of ipc_getref from int to bool (Waiman Long) [1710480]
- [ipc] ipc/util.c: further variable name cleanups (Waiman Long) [1710480]
- [ipc] ipc: simplify ipc initialization (Waiman Long) [1710480]
- [ipc] ipc: get rid of ids->tables_initialized hack (Waiman Long) [1710480]
- [lib] lib/rhashtable: guarantee initial hashtable allocation (Waiman Long) [1710480]
- [lib] lib/rhashtable: simplify bucket_table_alloc() (Waiman Long) [1710480]
- [ipc] ipc: drop ipc_lock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: correct comment in ipc_obtain_object_check (Waiman Long) [1710480]
- [ipc] ipc: rename ipcctl_pre_down_nolock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: use ipc_rcu_putref() for failues in ipc_addid() (Waiman Long) [1710480]
- [ipc] ipc: reorganize initialization of kern_ipc_perm.seq (Waiman Long) [1710480]
- [ipc] ipc: compute kern_ipc_perm.id under the ipc lock (Waiman Long) [1710480]
- [x86] x86/speculation/mds: Improve CPU buffer clear documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Revert CPU buffer clear on double fault exit (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add 'mitigations=' support for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [s390] s390/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [powerpc] powerpc/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [mm] x86/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kernel] cpu/speculation: Add 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Fix documentation typo (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] Documentation: Correct the possible MDS sysfs values (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/mds: Add MDSUM variant to the MDS documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Print SMT vulnerable on MSBDS with mitigations off (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Fix comment (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add SMT warning message (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Move arch_smt_update() call to after mitigation decisions (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Add mds=full,nosmt cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] Documentation: Add MDS vulnerability documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] documentation: Move L1TF to separate directory (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add mitigation mode VMWERV (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [base] x86/speculation/mds: Add sysfs reporting for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add mitigation control for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Conditionally clear CPU buffers on idle entry (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kvm] x86/kvm/vmx: Add MDS protection when L1D Flush is not active (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Clear CPU buffers on exit to user (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Add mds_clear_cpu_buffers() (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kvm] x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add BUG_MSBDS_ONLY (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add basic bug infrastructure for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Consolidate CPU whitelists (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [tools] x86/msr-index: Cleanup bit defines (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/l1tf: Drop the swap storage limit restriction when l1tf=off (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Cast ~SPEC_CTRL_STIBP atomic value to int (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [tools] tools power x86_energy_perf_policy: Override CFLAGS assignments and add LDFLAGS to build command (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [scsi] scsi: qla2xxx: Fix read offset in qla24xx_load_risc_flash() (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Simplify conditional check again (Himanshu Madhani) [1665555]
- [scsi] qla2xxx: Update driver version to 10.01.00.15.08.1-k (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Secure flash update support for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add 28xx flash primary/secondary status/image mechanism (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Simplification of register address used in qla_tmpl.c (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Correction and improvement to fwdt processing (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Update flash read/write routine (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add support for multiple fwdump templates/segments (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Cleanups for NVRAM/Flash read/write path (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Correctly report max/min supported speeds (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add Serdes support for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add Device ID for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Fix routine qla27xx_dump_{mpi|ram}() (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Remove FW default template (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add fw_attr and port_no SysFS node (Himanshu Madhani) [1665555]
- [netdrv] e1000e: Disable runtime PM on CNP+ (David Arcari) [1659179]
- [netdrv] intel: correct return from set features callback (David Arcari) [1659179]
- [netdrv] e1000e: Fix -Wformat-truncation warnings (David Arcari) [1659179]
- [netdrv] e1000e: fix cyclic resets at link up with active tx (David Arcari) [1659179]
- [netdrv] e1000e: fix a missing check for return value (David Arcari) [1659179]
- [netdrv] e1000e: Exclude device from suspend direct complete optimization (David Arcari) [1659179]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (David Arcari) [1659179]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (David Arcari) [1659179]
- [netdrv] e1000e: extend PTP gettime function to read system clock (David Arcari) [1659179]
- [netdrv] e1000e: allow non-monotonic SYSTIM readings (David Arcari) [1659179]
- [netdrv] intel-ethernet: use correct module license (David Arcari) [1659179]
- [kernel] sched/cpufreq: Fix kobject memleak (Phil Auld) [1714719]
- [kernel] sched/core: Check quota and period overflow at usec to nsec conversion (Phil Auld) [1714719]
- [kernel] sched/core: Handle overflow in cpu_shares_write_u64 (Phil Auld) [1714719]
- [kernel] sched/rt: Check integer overflow at usec to nsec conversion (Phil Auld) [1714719]
- [base] arch_topology: Make cpu_capacity sysfs node as read-only (Phil Auld) [1714719]
- [x86] sched/x86: Save [ER]FLAGS on context switch (Phil Auld) [1714719]
- [kernel] sched/fair: Remove setting task's se->runnable_weight during PELT update (Phil Auld) [1714719]
- [kernel] sched/fair: Disable LB_BIAS by default (Phil Auld) [1714719]
- [arm64] sched/topology, arch/arm64: Rebuild the sched_domain hierarchy when the CPU capacity changes (Phil Auld) [1714719]
- [base] sched/topology, drivers/base/arch_topology: Rebuild the sched_domain hierarchy when capacities change (Phil Auld) [1714719]
- [kernel] sched/topology: Add SD_ASYM_CPUCAPACITY flag detection (Phil Auld) [1714719]
- [kernel] sched/fair: Fix load_balance redo for !imbalance (Phil Auld) [1714719]
- [tools] cpupower : frequency-set -r option misses the last cpu in related cpu list (Steve Best) [1717841]
- [kernel] Uprobes: Fix kernel oops with delayed_uprobe_remove() (Gustavo Duarte) [1608798]
- [kernel] trace_uprobe/sdt: Prevent multiple reference counter for same uprobe (Gustavo Duarte) [1608798]
- [kernel] uprobes/sdt: Prevent multiple reference counter for same uprobe (Gustavo Duarte) [1608798]
- [kernel] uprobes: Support SDT markers having reference count (semaphore) (Gustavo Duarte) [1608798]
- [kernel] Uprobe: Additional argument arch_uprobe to uprobe_write_opcode() (Gustavo Duarte) [1608798]
- [kernel] Uprobes: Simplify uprobe_register() body (Gustavo Duarte) [1608798]
- [pci] PCI: Rework pcie_retrain_link() wait loop (Myron Stowe) [1707902]
- [pci] PCI: Work around Pericom PCIe-to-PCI bridge Retrain Link erratum (Myron Stowe) [1707902]
- [pci] PCI: Factor out pcie_retrain_link() function (Myron Stowe) [1707902]
- [tools] selftests/powerpc: Fix strncpy usage (Diego Domingos) [1662372]
- [tools] selftests: Fix test errors related to lib.mk khdr target (Diego Domingos) [1662372]
- [nvme] nvme-fc: use separate work queue to avoid warning (Ewan Milne) [1715135]
- [scsi] scsi: scsi_transport_fc: nvme: display FC-NVMe port roles (Ewan Milne) [1715135]
- [nvme] nvme-fc: correct csn initialization and increments on error (Ewan Milne) [1715135]
- [nvme] nvme-multipath: avoid crash on invalid subsystem cntlid enumeration (Ewan Milne) [1715135]
- [nvme] nvme-multipath: don't print ANA group state by default (Ewan Milne) [1715135]
- [nvme] nvme-multipath: split bios with the ns_head bio_set before submitting (Ewan Milne) [1715135]
- [nvme] nvme-multipath: relax ANA state check (Ewan Milne) [1715135]
- [drm] drm/i915: Bump gen7+ fb size limits to 16kx16k (Lyude Paul) [1664969]
- [drm] drm/i915: Bump fb stride limit to 128KiB for gen4+ and 256KiB for gen7+ (Lyude Paul) [1664969]
- [drm] drm/i915: Align dumb buffer stride to 4k to allow for gtt remapping (Lyude Paul) [1664969]
- [drm] drm/i915: Overcome display engine stride limits via GTT remapping (Lyude Paul) [1664969]
- [drm] drm/i915: Shuffle stride checking code around (Lyude Paul) [1664969]
- [drm] drm/i915/selftests: Add live vma selftest (Lyude Paul) [1664969]
- [drm] drm/i915/selftests: Add mock selftest for remapped vmas (Lyude Paul) [1664969]
- [drm] drm/i915: Add a new "remapped" gtt_view (Lyude Paul) [1664969]
- [md] dax: Arrange for dax_supported check to span multiple devices (Jeff Moyer) [1665364]
- [mm] mm/memory_hotplug.c: drop memory device reference after find_memory_block() (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Retain security state after overwrite (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/pmem: fix a possible OOB access when read and write pmem (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] libnvdimm/security, acpi/nfit: unify zero-key for all security commands (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/security: provide fix for secure-erase to use zero-key (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [mm] mm/memory.c: fix modifying of page protection by insert_pfn() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Fix a kmemdup failure check (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/namespace: Fix a potential NULL pointer dereference (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Always dump _DSM output payload (Jeff Moyer) [1665367 1665364 1665362]
- [fs] fs/dax: Deposit pagetable even when installing zero page (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/namespace: Clean up holder_class_store() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/of_pmem: Fix platform_no_drv_owner.cocci warnings (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Update NFIT flags error message (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Fix LBA masking during 'free list' population (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Remove unnecessary code in btt_freelist_init (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pfn: Remove dax_label_reserve (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] dax: Check the end of the block-device capacity with dax_direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Avoid stale ARS results (Jeff Moyer) [1697175 1665367 1665364 1665362]
- [acpi] nfit/ars: Allow root to busy-poll the ARS state machine (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Introduce scrub_flags (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Remove ars_start_flags (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Attempt short-ARS even in the no_init_ars case (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Attempt a short-ARS whenever the ARS state is idle at boot (Jeff Moyer) [1697194 1665367 1665364 1665362]
- [fs] fs/dax: NIT fix comment regarding start/end vs range (Jeff Moyer) [1665367 1665364 1665362]
- [fs] fs/dax: Convert to use vmf_error() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Require opt-in for read-only label configurations (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pmem: Honor force_raw for legacy pmem regions (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pfn: Account for PAGE_SIZE > info-block-size in nd_pfn_init() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: Fix altmap reservation size calculation (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pfn: Fix over-trim in trim_pfn_device() (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [nvdimm] libnvdimm/dimm: Add a no-BLK quirk based on NVDIMM family (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: Add Hyper-V NVDIMM DSM command set to white list (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: acpi_nfit_ctl(): Check out_obj->type in the right place (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: Fix nfit_intel_shutdown_status() command submission (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [nvdimm] libnvdimm/security: Require nvdimm_security_setup_events() to succeed (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] nfit_test: fix security state pull for nvdimm security nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/security: Fix nvdimm_security_state() state request selection (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/label: Clear 'updating' flag after label-set update (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Remove duplicate set nd_set in acpi_nfit_init_interleave_set() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Fix race accessing memdev in nfit_get_smbios_id() (Jeff Moyer) [1665367 1665364 1665362]
- [include] libnvdimm/dimm: Fix security capability detection for non-Intel NVDIMMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] nfit: Mark some functions as __maybe_unused (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] ACPI/nfit: delete the function to_acpi_nfit_desc (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] ACPI/nfit: delete the redundant header file (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: add MEMORY_DEVICE_PRIVATE support (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] mm, devm_memremap_pages: fix shutdown handling (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: kill mapping "System RAM" support (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: mark devm_memremap_pages() EXPORT_SYMBOL_GPL (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/security: Quiet security operations (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [documentation] libnvdimm/security: Add documentation for nvdimm security support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: add Intel DSM 1.8 support for nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: Add overwrite support for nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: Add test support for Intel nvdimm security DSMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm/security: add Intel DSM 1.8 master passphrase support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm/security: Add security DSM overwrite support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add support for issue secure erase DSM to Intel nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add enable/update passphrase support for Intel nvdimms (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add disable passphrase support to Intel nvdimm. (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add unlock of nvdimm support for Intel DIMMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add freeze security support to Intel nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] acpi/nfit, libnvdimm: Introduce nvdimm_security_ops (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [security] keys-encrypted: add nvdimm key format type to encrypted keys (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [security] keys: Export lookup_user_key to external users (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] acpi/nfit, libnvdimm: Store dimm id as a member to struct nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm, namespace: Replace kmemdup() with kstrndup() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, label: Switch to bitmap_zalloc() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] ACPI/nfit: Adjust annotation for why return 0 if fail to find NFIT at start (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, bus: Check id immediately following ida_simple_get (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Fix user-initiated ARS to be "ARS-long" rather than "ARS-short" (Jeff Moyer) [1665367 1665364 1665362 1662224 1641487]
- [nvdimm] libnvdimm, pfn: Pad pfn namespaces relative to other regions (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [tools] tools/testing/nvdimm: Align test resources to 128M (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [acpi] acpi/nfit: Add support for Intel DSM 1.8 commands (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] Revert "acpi, nfit: Further restrict userspace ARS start requests" (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Fix ARS overflow continuation (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Fix the array size for dimm devices. (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [mm] mm: Fix warning in insert_pfn() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Further restrict userspace ARS start requests (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Fix Address Range Scrub completion tracking (Jeff Moyer) [1665367 1665364 1665362 1662224 1641487]
- [tools] tools/testing/nvdimm: Populate dirty shutdown data (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [acpi] acpi, nfit: Collect shutdown status (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [acpi] acpi, nfit: Introduce nfit_mem flags (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [nvdimm] libnvdimm, label: Fix sparse warning (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, namespace: Drop the repeat assignment for variable dev->parent (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, region: Fail badblocks listing for inactive regions (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pfn: during init, clear errors in the metadata area (Jeff Moyer) [1665367 1665364 1665362 1641565]
- [nvdimm] libnvdimm: Set device node in nd_device_register (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: Hold reference on parent while scheduling async init (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: remove duplicate include (Jeff Moyer) [1665367 1665364 1665362]
- [fs] filesystem-dax: Fix use of zero page (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pmem: Restore page attributes when clearing errors (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] device-dax: avoid hang on error before devm_memremap_pages() (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: improve emulation of smart injection (Jeff Moyer) [1685043 1665367 1665364 1665362]
- [fs] filesystem-dax: Do not request kaddr and pfn when not required (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] dax/super: Do not request a pointer kaddr when not required (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: kaddr and pfn can be NULL to ->direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pmem: kaddr and pfn can be NULL to ->direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: queue issuing of ars when an uc error notification comes in (Jeff Moyer) [1665367 1665364 1665362 1641487]
- [kernel] mm, dev_pagemap: Do not clear ->mapping on final put (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Fix support for emulating controller temperature (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Make DSM failure code injection an override (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [acpi] acpi, nfit: Prefer _DSM over _LSR for namespace label reads (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [nvdimm] libnvdimm: Introduce locked DIMM capacity support (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [drm] drm/nouveau: fix duplication of nv50_head_atom struct (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/disp/dp: respect sink limits when selecting failsafe link configuration (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/core: initial support for boards with TU117 chipset (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/core: allow detected chipset to be overridden (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/gf119-gp10x: push HeadSetControlOutputResource() mthd when encoders change (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/nv50-: fix bug preventing non-vsync'd page flips (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/gv100-: fix spurious window immediate interlocks (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/nouveau: forward error generated while resuming objects tree (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/i2c: Disable i2c bus access after ->fini() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add WaDisableBankHangMode (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/fbc: disable framebuffer compression on GeminiLake (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix setting 10 bit deep color mode (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add missing combo PHY lane power setup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Factor out combo PHY lane power setup helper (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Corrupt DSI picture fix for GeminiLake (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix clockgating issue when using scalers (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Suppress spurious combo PHY B warning (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Disable read only ppgtt support for gen11 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use Engine1 instance for gen11 pm interrupts (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Disable video turbo mode for rp control (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable media sampler powergate (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: introduce REG_BIT() and REG_GENMASK() to define register contents (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1664615 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Apply a recommended rc6 threshold (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use dedicated rc6 enabling sequence for gen11 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Don't warn on spurious interrupts (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Handle rps interrupts without irq lock (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sure we have enough memory bandwidth on ICL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sandybridge_pcode_read() deal with the second data register (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix ONLY icl+ max plane width (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix MG_DP_MODE() register programming (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Really calculate the cursor ddb based on the highest enabled wm level (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Inline skl_update_pipe_wm() into its only caller (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Don't pass pipe_wm around so much (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Move some variables to tighter scope (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Keep plane watermarks enabled more aggressively (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sure cursor has enough ddb for the selected wm level (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Allocate enough DDB for the cursor (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract skl_compute_wm_params() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Don't pass plane state to skl_compute_plane_wm() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Accept alloc_size == blocks (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/cml: Introduce Comet Lake PCH (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/cml: Add CML PCI IDS (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix PSR2 selective update corruption after PSR1 setup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off the CUS when turning off a HDR plane (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix legacy gamma mode for ICL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Refactor icl_is_hdr_plane (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] drm/i915: Add new ICL PCI ID (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix CRC mismatch error for DP link layer compliance (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Prevent incorrect DBuf enabling (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Read out memory type (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract DIMM info on cnl+ (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Clean up intel_get_dram_info() a bit (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i914: s/l_info/dimm_l/ etc. (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Generalize intel_is_dram_symmetric() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use dram_dimm_info more (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract DIMM info on GLK too (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix DRAM size reporting for BXT (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract BXT DIMM helpers (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Polish skl_is_16gb_dimm() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract functions to derive SKL+ DIMM info (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Store DIMM rank information as a number (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Default to Thread Group preemption for compute workloads (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix the state checker for ICL Y planes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: move MG pll hw_state readout (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Finalize Wa_1408961008:icl (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Call MG_DP_MODE() macro with the right parameters order (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Drop redundant gamma mode mask (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Implement new w/a for underruns with wm1+ disabled (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Include "ignore lines" in skl+ wm state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] Revert "drm/i915: W/A for underruns with WM1+ disabled on icl" (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make MG PHY macros semantically consistent (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make combo PHY DDI macro definitions consistent for ICL and CNL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add degamma and gamma lut size to gen11 caps (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable pipe output csc (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable ICL Pipe CSC block (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add icl pipe degamma and gamma support (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/glk: Fix degamma lut programming (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Dump skl+ watermark changes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Update DSPCNTR gamma/csc bits during crtc_enable() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Disable pipe gamma when C8 pixel format is used (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off pipe CSC when it's not needed (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off pipe gamma when it's not needed (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Track pipe csc enable in crtc state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Track pipe gamma enable/disable in crtc state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Populate gamma_mode for all platforms (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: Main backport to rebase from 4.18 to 5.1 (Lyude Paul) [1713573 1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286] {CVE-2019-11085}
- [include] list: Backport list_is_first() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] lib/scatterlist: Provide a DMA page iterator (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [acpi] ACPI / PMIC: Add support for executing PMIC MIPI sequence elements (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] vfio: add edid api for display (vgpu) devices. (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [mm] mm: don't miss the last page because of round-off error (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [base] PM-runtime: Add new interface to get accounted time (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: move i915_kick_out_vgacon to vgaarb (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [scripts] tracing: Avoid calling cc-option -mrecord-mcount for every Makefile (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/fb_helper: Allow leaking fbdev smem_start (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/fb: Stop leaking physical address (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [video] fbdev: Add FBINFO_HIDE_SMEM_START flag (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] vt: Remove vc_panic_force_write (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] fbdev: Drop FBINFO_CAN_FORCE_OUTPUT flag (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [video] fbdev: fix kerneldoc (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] fbdev: add remove_conflicting_pci_framebuffers() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [media] media: cec-notifier: Get notifier by device and connector name (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [base] driver core: Add device_link_remove function (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] include: Move ascii85 functions from i915 to linux/ascii85.h (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [mm] mm, drm/i915: mark pinned shmemfs pages as unevictable (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] list: introduce list_bulk_move_tail helper (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [fs] sysfs: constify sysfs create/remove files harder (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/selftests: Remove unused dmabuf->kmap routines, fix the build (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] dma-buf: remove kmap_atomic interface (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] include/linux/bitops.h: introduce BITS_PER_TYPE (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] dma_buf: remove device parameter from attach callback v2 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [pci] PCI: Export pcie_get_speed_cap and pcie_get_width_cap (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: Add support for pps and compression mode command packet (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking/mutex: Fix mutex debug call and ww_mutex documentation (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking: Implement an algorithm choice for Wound-Wait mutexes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking: WW mutex cleanup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]

* Fri Jun 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-102.el8]
- [netdrv] igb: Fix WARN_ONCE on runtime suspend (Corinna Vinschen) [1659168]
- [netdrv] igb: use struct_size() helper (Corinna Vinschen) [1659168]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Corinna Vinschen) [1659168]
- [netdrv] igb: Bump version number (Corinna Vinschen) [1659168]
- [netdrv] Revert "igb: reduce CPU0 latency when updating statistics" (Corinna Vinschen) [1659168]
- [netdrv] igb: Fix an issue that PME is not enabled during runtime suspend (Corinna Vinschen) [1659168]
- [netdrv] igb: Change RXPBSIZE size when setting Qav mode (Corinna Vinschen) [1659168]
- [netdrv] igb: reduce CPU0 latency when updating statistics (Corinna Vinschen) [1659168]
- [netdrv] igb: fix uninitialized variables (Corinna Vinschen) [1659168]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Corinna Vinschen) [1659168]
- [netdrv] igb: Fix format with line continuation whitespace (Corinna Vinschen) [1659168]
- [netdrv] igb: extend PTP gettime function to read system clock (Corinna Vinschen) [1659168]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Corinna Vinschen) [1659168]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Corinna Vinschen) [1659168]
- [netdrv] igb: remove ndo_poll_controller (Corinna Vinschen) [1659168]
- [netdrv] intel-ethernet: use correct module license (Corinna Vinschen) [1659168]
- [netdrv] igb: Replace mdelay() with msleep() in igb_integrated_phy_loopback() (Corinna Vinschen) [1659168]
- [netdrv] igb: Replace GFP_ATOMIC with GFP_KERNEL in igb_sw_init() (Corinna Vinschen) [1659168]
- [netdrv] igb: Use an advanced ctx descriptor for launchtime (Corinna Vinschen) [1659168]
- [netdrv] igb: e1000_phy: Mark expected switch fall-through (Corinna Vinschen) [1659168]
- [netdrv] igb: e1000_82575: Mark expected switch fall-through (Corinna Vinschen) [1659168]
- [netdrv] igb_main: Mark expected switch fall-throughs (Corinna Vinschen) [1659168]
- [netdrv] igb: Use dma_wmb() instead of wmb() before doorbell writes (Corinna Vinschen) [1659168]
- [netdrv] igb: Add support for ETF offload (Corinna Vinschen) [1659168]
- [netdrv] igb: Only call skb_tx_timestamp after descriptors are ready (Corinna Vinschen) [1659168]
- [netdrv] igb: Refactor igb_offload_cbs() (Corinna Vinschen) [1659168]
- [netdrv] igb: Only change Tx arbitration when CBS is on (Corinna Vinschen) [1659168]
- [netdrv] igb: Refactor igb_configure_cbs() (Corinna Vinschen) [1659168]
- [fs] Revert "[fs] ext4: protect journal inode's blocks using block_validity" (Lukas Czerner) [1716549]
- [fs] xfs: don't trip over uninitialized buffer on extent read of corrupted inode (Bill O'Donnell) [1715942]
- [fs] xfs: always init bma in xfs_bmapi_write (Bill O'Donnell) [1715942]
- [lib] rhashtable: Still do rehash when we get EEXIST (Vladis Dronov) [1712457]
- [fs] vmcore: Add a kernel parameter novmcoredd (Kairui Song) [1705864]
- [powerpc] powerpc/eeh: Correct retries in eeh_pe_reset_full() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Improve recovery of passed-through devices (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Add include_passed to eeh_clear_pe_frozen_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Add include_passed to eeh_pe_state_clear() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: remove sw_state from eeh_unfreeze_pe() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_pe_clear_frozen_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup control flow in eeh_handle_normal_event() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_ops.wait_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_pe_state_mark() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup unnecessary eeh_pe_state_mark_with_cfg() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_enabled() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup logic in eeh_rmv_from_parent_pe() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup field names in eeh_rmv_data (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup list_head field names (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_add_virt_device() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup unused field in eeh_dev (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup EEH_POSTPONED_PROBE (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Avoid misleading message "EEH: no capable adapters found" (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix use of EEH_PE_KEEP on wrong field (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix null deref for devices removed during EEH (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix possible null deref in eeh_dump_dev_log() (Sam Bobroff) [1352405]
- [edac] x86/MCE/AMD, EDAC/mce_amd: Add new error descriptions for some SMCA bank types (Janakarajan Natarajan) [1688469]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new McaTypes for CS, PSP, and SMU units (Janakarajan Natarajan) [1688469]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new MP5, NBIO, and PCIE SMCA bank types (Janakarajan Natarajan) [1688469]
- [scsi] megaraid_sas: remove tech preview from Aero series (Tomas Henzl) [1668409]
- [scsi] megaraid_sas: sync with mainline (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: fix spelling mistake "oustanding" -> "outstanding" (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Make megasas_host_device_list_query() static (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: reduce module load time (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove a bunch of set but not used variables (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: return error when create DMA pool failed (Tomas Henzl) [1668409] {CVE-2019-11810}
- [scsi] scsi: megaraid_sas: driver version update (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Update structures for HOST_DEVICE_LIST DCMD (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add support for DEVICE_LIST DCMD in driver (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rework device add code in AEN path (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rework code to get PD and LD list (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: correct an info message (Tomas Henzl) [1668409]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid: fix out-of-bound array accesses (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: changes to function prototypes (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: NULL check before some freeing functions is not needed (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas_fusion: Mark expected switch fall-through (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid: megaraid_sas_base: Mark expected switch fall-through (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: modify max supported lds related print (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: remove unused macro (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: increase timeout for IOC INIT to 180seconds (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove double endian conversion (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Re-use max_mfi_cmds to calculate queue sizes (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rename scratch_pad registers (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove spin lock for dpc operation (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: optimize raid context access in IO path (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fail init if heartbeat timer fails (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: For SRIOV, do not set STOP_ADP bit (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix combined reply queue mode detection (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix module parameter description (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix goto labels in error handling (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Update copyright information (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add check for reset adapter bit (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix msleep granularity (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add support for FW snap dump (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add watchdog thread to detect Firmware fault (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: switch to generic DMA API (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: fix a missing-check bug (Tomas Henzl) [1668409]
- [kernel] get_maintainer.pl: Add default .get_maintainer.conf file for RHEL (Prarit Bhargava) [1714630]
- [scripts] get_maintainer: allow option --mpath <directory> to read all files in <directory> (Prarit Bhargava) [1714630]
- [scripts] get_maintainer.pl: add -mpath=<path or file> for MAINTAINERS file location (Prarit Bhargava) [1714630]
- [scripts] get_maintainer: allow usage outside of kernel tree (Prarit Bhargava) [1714630]
- [scripts] Revert "[scripts] get_maintainer.pl: Add optional .get_maintainer.MAINTAINERS override" (Prarit Bhargava) [1714630]
- [include] signal: Make siginmask safe when passed a signal of 0 (Waiman Long) [1714351]
- [fs] signal: Don't send signals to tasks that don't exist (Waiman Long) [1714351]
- [kernel] signal: Restore the stop PTRACE_EVENT_EXIT (Waiman Long) [1714351]
- [kernel] signal: Better detection of synchronous signals (Waiman Long) [1714351]
- [kernel] signal: Always notice exiting tasks (Waiman Long) [1714351]
- [kernel] signal: Always attempt to allocate siginfo for SIGSTOP (Waiman Long) [1714351]
- [kernel] signal: Guard against negative signal numbers in copy_siginfo_from_user32 (Waiman Long) [1714351]
- [kernel] signal: Guard against negative signal numbers in copy_siginfo_from_user (Waiman Long) [1714351]
- [kernel] signal: In sigqueueinfo prefer sig not si_signo (Waiman Long) [1714351]
- [include] signal: Use a smaller struct siginfo in the kernel (Waiman Long) [1714351]
- [include] signal: Distinguish between kernel_siginfo and siginfo (Waiman Long) [1714351]
- [kernel] signal: Introduce copy_siginfo_from_user and use it's return value (Waiman Long) [1714351]
- [arm64] signal: Remove the need for __ARCH_SI_PREABLE_SIZE and SI_PAD_SIZE (Waiman Long) [1714351]
- [kernel] signal: Fail sigqueueinfo if si_signo != sig (Waiman Long) [1714351]
- [kernel] signal/sparc: Move EMT_TAGOVF into the generic siginfo.h (Waiman Long) [1714351]
- [mm] signal/arm: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Use send_sig_fault where appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_ptrace_errno_trap (Waiman Long) [1714351]
- [arm64] signal/arm64: In ptrace_hbptriggered name the signal description string (Waiman Long) [1714351]
- [arm64] signal/arm64: Remove arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_mceerr as appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_fault where appropriate (Waiman Long) [1714351]
- [mm] signal/arm64: Only call set_thread_esr once in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Only perform one esr_to_fault_info call in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Expand __do_user_fault and remove it (Waiman Long) [1714351]
- [mm] signal/arm64: For clarity separate the 3 signal sending cases in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Consolidate the two hwpoison cases in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Factor set_thread_esr out of __do_user_fault (Waiman Long) [1714351]
- [arm64] signal/arm64: Factor out arm64_show_signal from arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Remove unneeded tsk parameter from arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Push siginfo generation into arm64_notify_die (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Simplify _exception_pkey by using force_sig_pkuerr (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Specialize _exception_pkey for handling pkey exceptions (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Call force_sig_fault from _exception (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Factor the common exception code into exception_common (Waiman Long) [1714351]
- [powerpc] powerpc/traps: Print unhandled signals in a separate function (Waiman Long) [1714351]
- [mm] signal/powerpc: Remove pkey parameter from __bad_area_nosemaphore (Waiman Long) [1714351]
- [mm] signal/powerpc: Call _exception_pkey directly from bad_key_fault_exception (Waiman Long) [1714351]
- [mm] signal/powerpc: Remove pkey parameter from __bad_area (Waiman Long) [1714351]
- [mm] signal/powerpc: Use force_sig_mceerr as appropriate (Waiman Long) [1714351]
- [x86] signal/x86: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [mm] signal/x86: Pass pkey by value (Waiman Long) [1714351]
- [mm] signal/x86: Replace force_sig_info_fault with force_sig_fault (Waiman Long) [1714351]
- [mm] signal/x86: Call force_sig_pkuerr from __bad_area_nosemaphore (Waiman Long) [1714351]
- [mm] signal/x86: Pass pkey not vma into __bad_area (Waiman Long) [1714351]
- [mm] signal/x86: Don't compute pkey in __do_page_fault (Waiman Long) [1714351]
- [mm] signal/x86: Remove pkey parameter from mm_fault_error (Waiman Long) [1714351]
- [mm] signal/x86: Remove the pkey parameter from do_sigbus (Waiman Long) [1714351]
- [mm] signal/x86: Remove pkey parameter from bad_area_nosemaphore (Waiman Long) [1714351]
- [x86] signal/x86/traps: Simplify trap generation (Waiman Long) [1714351]
- [x86] signal/x86/traps: Use force_sig instead of open coding it. (Waiman Long) [1714351]
- [x86] signal/x86/traps: Use force_sig_bnderr (Waiman Long) [1714351]
- [x86] signal/x86/traps: Move more code into do_trap_no_signal so it can be reused (Waiman Long) [1714351]
- [x86] signal/x86/traps: Factor out show_signal (Waiman Long) [1714351]
- [x86] signal/x86: Move mpx siginfo generation into do_bounds (Waiman Long) [1714351]
- [x86] signal/x86: In trace_mpx_bounds_register_exception add __user annotations (Waiman Long) [1714351]
- [mm] signal/x86: Move MCE error reporting out of force_sig_info_fault (Waiman Long) [1714351]
- [x86] signal/x86: Inline fill_sigtrap_info in it's only caller send_sigtrap (Waiman Long) [1714351]
- [powerpc] signal: Simplify tracehook_report_syscall_exit (Waiman Long) [1714351]
- [kernel] signal: Pair exports with their functions (Waiman Long) [1714351]
- [kernel] signal: Remove specific_send_sig_info (Waiman Long) [1714351]
- [kernel] signal: Use group_send_sig_info to kill all processes in a pid namespace (Waiman Long) [1714351]
- [tty] tty_io: Use group_send_sig_info in __do_SACK to note it is a session being killed (Waiman Long) [1714351]
- [misc] signal/GenWQE: Fix sending of SIGKILL (Waiman Long) [1714351]
- [include] signal: Remove SEND_SIG_FORCED (Waiman Long) [1714351]
- [kernel] signal: Use SEND_SIG_PRIV not SEND_SIG_FORCED with SIGKILL and SIGSTOP (Waiman Long) [1714351]
- [kernel] signal: Never allocate siginfo for SIGKILL or SIGSTOP (Waiman Long) [1714351]
- [usb] signal: Don't send siginfo to kthreads. (Waiman Long) [1714351]
- [usb] signal: Remove the siginfo paramater from kernel_dqueue_signal (Waiman Long) [1714351]
- [tty] signal: send_sig_all no longer needs SEND_SIG_FORCED (Waiman Long) [1714351]
- [kernel] signal: Always deliver the kernel's SIGKILL and SIGSTOP to a pid namespace init (Waiman Long) [1714351]
- [x86] signal: Properly deliver SIGSEGV from x86 uprobes (Waiman Long) [1714351]
- [kernel] signal: Properly deliver SIGILL from uprobes (Waiman Long) [1714351]
- [kernel] signal: Always ignore SIGKILL and SIGSTOP sent to the global init (Waiman Long) [1714351]
- [iommu] mm: convert return type of handle_mm_fault() caller to vm_fault_t (Waiman Long) [1714351]
- [kernel] signal: make get_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make sigkill_pending() return bool (Waiman Long) [1714351]
- [kernel] signal: make legacy_queue() return bool (Waiman Long) [1714351]
- [kernel] signal: make wants_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make flush_sigqueue_mask() void (Waiman Long) [1714351]
- [kernel] signal: make unhandled_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make recalc_sigpending_tsk() return bool (Waiman Long) [1714351]
- [kernel] signal: make has_pending_signals() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_task_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_handler_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make kill_ok_by_cred() return bool (Waiman Long) [1714351]
- [kernel] signal: simplify rt_sigaction() (Waiman Long) [1714351]
- [kernel] signal: make do_sigpending() void (Waiman Long) [1714351]
- [kernel] signal: make may_ptrace_stop() return bool (Waiman Long) [1714351]
- [kernel] signal: make kill_as_cred_perm() return bool (Waiman Long) [1714351]
- [kernel] signal: make force_sigsegv() void (Waiman Long) [1714351]
- [kernel] signal: Don't restart fork when signals come in. (Waiman Long) [1714351]
- [kernel] fork: Have new threads join on-going signal group stops (Waiman Long) [1714351]
- [include] fork: Skip setting TIF_SIGPENDING in ptrace_init_task (Waiman Long) [1714351]
- [kernel] signal: Add calculate_sigpending() (Waiman Long) [1714351]
- [kernel] fork: Unconditionally exit if a fatal signal is pending (Waiman Long) [1714351]
- [kernel] fork: Move and describe why the code examines PIDNS_ADDING (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into complete_signal. (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into __send_signal (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into send_signal (Waiman Long) [1714351]
- [tty] signal: Pass pid type into do_send_sig_info (Waiman Long) [1714351]
- [fs] signal: Pass pid type into send_sigio_to_task & send_sigurg_to_task (Waiman Long) [1714351]
- [kernel] signal: Pass pid type into group_send_sig_info (Waiman Long) [1714351]
- [kernel] signal: Pass pid and pid type into send_sigqueue (Waiman Long) [1714351]
- [kernel] posix-timers: Noralize good_sigevent (Waiman Long) [1714351]
- [fs] signal: Use PIDTYPE_TGID to clearly store where file signals will be sent (Waiman Long) [1714351]
- [kernel] pid: Implement PIDTYPE_TGID (Waiman Long) [1714351]
- [include] pids: Move the pgrp and session pid pointers from task_struct to signal_struct (Waiman Long) [1714351]
- [fs] pids: Compute task_tgid using signal->leader_pid (Waiman Long) [1714351]
- [kernel] pids: Move task_pid_type into sched/signal.h (Waiman Long) [1714351]
- [init] pids: Initialize leader_pid in init_task (Waiman Long) [1714351]

* Thu Jun 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-101.el8]
- [s390] s390: enable processes for mio instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: add parameter to disable usage of MIO instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: provide support for MIO instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: improve bar check (Philipp Rudo) [1651734]
- [s390] s390/ism: move oddities of device IO to wrapper function (Philipp Rudo) [1651734]
- [s390] s390/pci: move io address mapping code to pci_insn.c (Philipp Rudo) [1651734]
- [s390] s390/pci: add parameter to force floating irqs (Philipp Rudo) [1651735]
- [s390] s390/pci: gather statistics for floating vs directed irqs (Philipp Rudo) [1651735]
- [s390] s390: show statistics for MSI IRQs (Philipp Rudo) [1651735]
- [s390] s390/pci: provide support for CPU directed interrupts (Philipp Rudo) [1651735]
- [s390] s390/airq: provide cacheline aligned ivs (Philipp Rudo) [1651735]
- [s390] s390/pci: clarify interrupt vector usage (Philipp Rudo) [1651735]
- [s390] s390/airq: recognize directed interrupts (Philipp Rudo) [1651735]
- [s390] s390/sclp: detect DIRQ facility (Philipp Rudo) [1651735]
- [s390] s390/pci: move everything irq related to pci_irq.c (Philipp Rudo) [1651735]
- [s390] s390/pci: remove stale rc (Philipp Rudo) [1651735]
- [s390] s390/pci: remove unused define (Philipp Rudo) [1651735]
- [s390] s390/pci: mark command line parser data __initdata (Philipp Rudo) [1651735]
- [cpufreq] cpufreq: intel_pstate: Ignore turbo active ratio in HWP (David Arcari) [1711970]
- [scsi] mpt3sas: remove tech preview from Aero series (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix indentation issue (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Update mpt3sas driver version to 28.100.00.00 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Improve the threshold value and introduce module param (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Load balance to improve performance and avoid soft lockups (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Irq poll to avoid CPU hard lockups (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: simplify interrupt handler (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix typo in request_desript_type (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add missing breaks in switch statements (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Update driver version to 27.102.00.00 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add support for ATLAS PCIe switch (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add support for NVMe Switch Adapter (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Rename mpi endpoint device ID macro. (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: mpt3sas_scsih: Mark expected switch fall-through (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix memory ordering on 64bit writes (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix spelling mistake "manufaucturing" -> "manufacturing" (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix driver modifying persistent data in Manufacturing page11 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Don't modify EEDPTagMode field setting on SAS3.5 HBA devices (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix Sync cache command failure during driver unload (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Call sas_remove_host before removing the target devices (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Refactor mpt3sas_wait_for_ioc function (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Separate out mpt3sas_wait_for_ioc (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Added new #define variable IOC_OPERATIONAL_WAIT_COUNT (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: switch to generic DMA API (Tomas Henzl) [1684444]
- [tools] perf tools beauty ioctl: Support new ISO7816 commands (Michael Petlan) [1709243]
- [tools] perf tools: Restore proper cwd on return from mnt namespace (Michael Petlan) [1709243]
- [tools] perf tools: Fix crash on synthesizing the unit (Michael Petlan) [1709243]
- [tools] perf tools: Do not zero sample_id_all for group members (Michael Petlan) [1709243]
- [tools] perf beauty: Use SRCARCH, ARCH=x86_64 must map to "x86" to find the headers (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add MTC and CYC timestamps to debug log (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add more event information to debug log (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Fix table find when table re-ordered (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add help window (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add Selected branches report (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Fall back to /usr/local/lib/libxed.so (Michael Petlan) [1709243]
- [tools] perf top: Display the LBR stats in callchain entry (Michael Petlan) [1709243]
- [tools] perf stat: Handle different PMU names with common prefix (Michael Petlan) [1709243]
- [tools] perf record: Support weak groups (Michael Petlan) [1709243]
- [tools] perf evlist: Move perf_evsel__reset_weak_group into evlist (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Start collecting pathnames in the BPF program (Michael Petlan) [1709243]
- [tools] perf trace: Fix setting of augmented payload when using eBPF + raw_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: When augmenting raw_syscalls plug raw_syscalls:sys_exit too (Michael Petlan) [1709243]
- [tools] perf examples bpf: Start augmenting raw_syscalls:sys_{start,exit} (Michael Petlan) [1709243]
- [tools] perf intel-pt/bts: Calculate cpumode for synthesized samples (Michael Petlan) [1709243]
- [tools] perf intel-pt: Insert callchain context into synthesized callchains (Michael Petlan) [1709243]
- [tools] perf top: Start display thread earlier (Michael Petlan) [1709243]
- [tools] perf trace beauty: Use the mmap flags table generated from headers (Michael Petlan) [1709243]
- [tools] perf beauty: Wire up the mmap flags table generator to the Makefile (Michael Petlan) [1709243]
- [tools] perf beauty: Add a generator for MAP_ mmap's flag constants (Michael Petlan) [1709243]
- [tools] perf callchain: Honour the ordering of PERF_CONTEXT_{USER,KERNEL,etc} (Michael Petlan) [1709243]
- [tools] perf cs-etm: Correct CPU mode for samples (Michael Petlan) [1709243]
- [tools] perf unwind: Take pgoff into account when reporting elf to libdwfl (Michael Petlan) [1709243]
- [tools] perf top: Do not use overwrite mode by default (Michael Petlan) [1709243]
- [tools] perf trace: Beautify mount's first pathname arg (Michael Petlan) [1709243]
- [tools] perf trace: Beautify the umount's 'name' argument (Michael Petlan) [1709243]
- [tools] perf trace: Consider syscall aliases too (Michael Petlan) [1709243]
- [tools] perf trace beauty: Beautify mount/umount's 'flags' argument (Michael Petlan) [1709243]
- [tools] perf trace beauty: Allow syscalls to mask an argument before considering it (Michael Petlan) [1709243]
- [tools] perf beauty: Introduce strarray__scnprintf_flags() (Michael Petlan) [1709243]
- [tools] perf beauty: Switch from GPL v2.0 to LGPL v2.1 (Michael Petlan) [1709243]
- [tools] perf beauty: Add a generator for MS_ mount/umount's flag constants (Michael Petlan) [1709243]
- [tools] tools include uapi: Grab a copy of linux/fs.h (Michael Petlan) [1709243]
- [tools] perf script: Support total cycles count (Michael Petlan) [1709243]
- [tools] perf script: Make itrace script default to all calls (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add All branches report (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to display all the database tables (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to shrink / enlarge font (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to find symbols in the call-graph (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add support for multiple sub-windows (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Rename to exported-sql-viewer.py (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Refactor TreeItem class (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Add data helper functions (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Factor out CallGraphModel from TreeModel (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Remove use of setObjectName() (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Add a class for global data (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Separate the database details into a class (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Make a "Main" function (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Change icon (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Set a minimum window size (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Provide better default column sizes (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Use SPDX license identifier (Michael Petlan) [1709243]
- [tools] perf trace: Introduce per-event maximum number of events property (Michael Petlan) [1709243]
- [tools] perf script: Flush output stream after events in verbose mode (Michael Petlan) [1709243]
- [tools] perf script: Allow extended console debug output (Michael Petlan) [1709243]
- [tools] perf stat: Poll for monitored tasks being alive (Michael Petlan) [1709243]
- [tools] perf trace: Drop thread refcount in trace__event_handler() (Michael Petlan) [1709243]
- [tools] perf trace: Drop addr_location refcounts (Michael Petlan) [1709243]
- [tools] perf evsel: Mark a evsel as disabled when asking the kernel do disable it (Michael Petlan) [1709243]
- [tools] perf evsel: Introduce per event max_events property (Michael Petlan) [1709243]
- [tools] tools lib subcmd: Introduce OPTION_ULONG (Michael Petlan) [1709243]
- [tools] perf arm64: Fix generate system call table failed with /tmp mounted with noexec (Michael Petlan) [1709243]
- [tools] perf symbols: Set PLT entry/header sizes properly on Sparc (Michael Petlan) [1709243]
- [tools] perf jitdump: Add Sparc support. (Michael Petlan) [1709243]
- [tools] perf annotate: Add Sparc support (Michael Petlan) [1709243]
- [tools] perf record: Encode -k clockid frequency into Perf trace (Michael Petlan) [1709243]
- [tools] perf probe: Support SDT markers having reference counter (semaphore) (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Move struct tep_handler definition in a local header file (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Separate out tep_strerror() for strerror_r() issues (Michael Petlan) [1709243]
- [tools] perf python: More portable way to make CFLAGS work with clang (Michael Petlan) [1709243]
- [tools] perf python: Make clang_has_option() work on Python 3 (Michael Petlan) [1709243]
- [tools] perf tools: Free temporary 'sys' string in read_event_files() (Michael Petlan) [1709243]
- [tools] perf tools: Avoid double free in read_event_file() (Michael Petlan) [1709243]
- [tools] perf tools: Free 'printk' string in parse_ftrace_printk() (Michael Petlan) [1709243]
- [tools] perf tools: Cleanup trace-event-info 'tdata' leak (Michael Petlan) [1709243]
- [tools] perf strbuf: Match va_{add,copy} with va_end (Michael Petlan) [1709243]
- [tools] perf test: S390 does not support watchpoints in test 22 (Michael Petlan) [1709243]
- [tools] perf auxtrace: Include missing asm/bitsperlong.h to get BITS_PER_LONG (Michael Petlan) [1709243]
- [tools] tools include: Adopt linux/bits.h (Michael Petlan) [1709243]
- [tools] perf intel-pt: Implement decoder flags for trace begin / end (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add decoder flags for trace begin / end (Michael Petlan) [1709243]
- [tools] perf tools: Improve thread_stack__process() for trace begin / end (Michael Petlan) [1709243]
- [tools] perf tools: Improve thread_stack__event() for trace begin / end (Michael Petlan) [1709243]
- [tools] perf db-export: Add trace begin / end branch type variants (Michael Petlan) [1709243]
- [tools] perf script: Enhance sample flags for trace begin / end (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enum filter_trivial_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename data2host*() APIs (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename struct plugin_list to struct tep_plugin_list (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to structs filter_type and event_filter (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to various structs filter_arg_*. (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to struct filter_{arg,value_type} (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enums filter_{exp,arg}_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enums filter_{boolean,op,cmp}_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename enum print_arg_type to enum tep_print_arg_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Add prefix tep_ to all print_* structures (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix TEP_ to all EVENT_FL_* flags (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename enum event_{sort_}type to enum tep_event_{sort_}type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename enum format_flags to enum tep_format_flags (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename struct format{_field} to struct tep_format{_field} (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename struct event_format to struct tep_event_format (Michael Petlan) [1709243]
- [tools] perf script: Print DSO for callindent (Michael Petlan) [1709243]
- [tools] perf script: Allow sym and dso without ip, addr (Michael Petlan) [1709243]
- [tools] tools lib subcmd: Support overwriting the pager (Michael Petlan) [1709243]
- [tools] perf tools: Report itrace options in help (Michael Petlan) [1709243]
- [tools] perf help: Add missing subcommand `version` (Michael Petlan) [1709243]
- [tools] perf tools: Initialize perf_data_file fd field (Michael Petlan) [1709243]
- [tools] perf util: Make copyfile_offset() global (Michael Petlan) [1709243]
- [tools] perf tools: Add 'struct perf_mmap' arg to record__write() (Michael Petlan) [1709243]
- [tools] perf auxtrace: Pass struct perf_mmap into mmap__read* functions (Michael Petlan) [1709243]
- [tools] perf tools: Remove perf_tool from event_op3 (Michael Petlan) [1709243]
- [tools] perf tools: Remove perf_tool from event_op2 (Michael Petlan) [1709243]
- [tools] perf bpf-loader: use PTR_ERR_OR_ZERO inetead of return code (Michael Petlan) [1709243]
- [tools] tools include: Adopt PTR_ERR_OR_ZERO from the kernel err.h header (Michael Petlan) [1709243]
- [tools] perf ordered_events: Prevent crossing max_alloc_size (Michael Petlan) [1709243]
- [tools] perf ordered_events: Add 'struct ordered_events_buffer' layer (Michael Petlan) [1709243]
- [tools] perf test: Add watchpoint test (Michael Petlan) [1709243]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh without ping's debuginfo (Michael Petlan) [1709243]
- [tools] perf map: Turn some pr_warning() to pr_debug() (Michael Petlan) [1709243]
- [tools] perf trace: Use the raw_syscalls:sys_enter for the augmented syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Setup augmented_args in the raw_syscalls:sys_enter handler (Michael Petlan) [1709243]
- [tools] perf trace: Introduce syscall__augmented_args() method (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Avoid optimization to pass older BPF validators (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Check probe_read_str() return separately (Michael Petlan) [1709243]
- [tools] perf annotate: Handle arm64 move instructions (Michael Petlan) [1709243]
- [tools] perf trace beauty: Alias 'umount' to 'umount2' (Michael Petlan) [1709243]
- [tools] perf stat: Move the display functions to stat-display.c (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_events' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'walltime_*' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Propagate 'struct target' arg to sort_aggr_thread() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'no_merge' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'big_num' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Do not use the global 'evsel_list' in print functions (Michael Petlan) [1709243]
- [tools] perf stat: Move *_aggr_* data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move ru_* data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'print_mixed_hw_group_error' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'print_free_counters_hint' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'null_run' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Add 'walltime_nsecs_stats' pointer to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'evlist' to aggr_update_shadow() (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'struct perf_stat_config' to first_shadow_cpu() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_only_len' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'run_count' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use 'evsel->evlist' instead of 'evsel_list' in collect_all_aliases() (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'evlist' argument to print functions (Michael Petlan) [1709243]
- [tools] perf stat: Add 'target' argument to perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'unit_width' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_only' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'interval_clear' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move csv_* to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Pass a 'struct perf_stat_config' argument to global print functions (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'struct perf_stat_config' argument to local print functions (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_stat_config' argument to perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move STAT_RECORD out of perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Introduce perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move perf_stat_synthesize_config() to stat.c (Michael Petlan) [1709243]
- [tools] perf stat: Add 'perf_event__handler_t' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_evlist' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_tool' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_stat_config' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Rename 'is_pipe' argument to 'attrs' in perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Move create_perf_stat_counter() to stat.c (Michael Petlan) [1709243]
- [tools] perf evsel: Introduce perf_evsel__store_ids() (Michael Petlan) [1709243]
- [tools] perf tools: Switch 'session' argument to 'evlist' in perf_event__synthesize_attrs() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'identifier' flag to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use local config arg for scale in create_perf_stat_counter() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'no_inherit' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'initial_delay' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use evsel->threads in create_perf_stat_counter() (Michael Petlan) [1709243]
- [tools] perf trace: Show comm and tid for tracepoint events (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Hook into syscalls:sys_exit_SYSCALL too (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Rename augmented_*_syscall__enter to just *_syscall (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Update the header comments (Michael Petlan) [1709243]
- [tools] perf bpf: Add syscall_exit() helper (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Split trace-seq related APIs in a separate header file (Michael Petlan) [1709243]
- [tools] perf report: Create auxiliary trace data files for s390 (Michael Petlan) [1709243]
- [tools] perf trace beauty: Reorganize 'struct sockaddr *' beautifier (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment sendto's 'addr' arg (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment bind's 'myaddr' sockaddr arg (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Add augmented_sockaddr_syscall_enter() (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment connect's 'sockaddr' arg (Michael Petlan) [1709243]
- [tools] perf bpf: Add linux/socket.h to the headers accessible to bpf proggies (Michael Petlan) [1709243]
- [tools] perf bpf: Give precedence to bpf header dir (Michael Petlan) [1709243]
- [tools] perf trace: Add a etcsnoop.c augmented syscalls eBPF utility (Michael Petlan) [1709243]
- [tools] perf trace: Augment 'newstat' (aka 'stat') filename ptr (Michael Petlan) [1709243]
- [tools] perf trace: Introduce augmented_filename_syscall_enter() declarator (Michael Petlan) [1709243]
- [tools] perf trace: Augment inotify_add_watch pathname syscall arg (Michael Petlan) [1709243]
- [tools] perf trace: Augment the 'open' syscall 'filename' arg (Michael Petlan) [1709243]
- [tools] perf trace: Use the augmented filename, expanding syscall enter pointers (Michael Petlan) [1709243]
- [tools] perf trace: Show comm/tid for augmented_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Extract the comm/tid printing for syscall enter (Michael Petlan) [1709243]
- [tools] perf trace: Print the syscall name for augmented_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Make the augmented_syscalls filter out the tracepoint event (Michael Petlan) [1709243]
- [tools] perf trace: Pass augmented args to the arg formatters when available (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Disallow precise_ip on BTS events (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Add generic branch tracing check to intel_pmu_has_bts() (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Move branch tracing setup to the Intel-specific source file (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Fix regression by default disabling perfmon v4 interrupt handling (Michael Petlan) [1709243]
- [x86] perf/x86/intel/uncore: Support CoffeeLake 8th CBOX (Michael Petlan) [1709243]
- [x86] perf/x86/intel/uncore: Add more IMC PCI IDs for KabyLake and CoffeeLake CPUs (Michael Petlan) [1709243]
- [tools] perf tools: Don't clone maps from parent when synthesizing forks (Michael Petlan) [1709243]
- [tools] perf top: Allow disabling the overwrite mode (Michael Petlan) [1709243]
- [kernel] perf/core: Clean up inconsisent indentation (Michael Petlan) [1709243]
- [tools] perf script: Implement --graph-function (Michael Petlan) [1709243]
- [tools] tools script: Add --call-trace and --call-ret-trace (Michael Petlan) [1709243]
- [tools] perf script: Add --insn-trace for instruction decoding (Michael Petlan) [1709243]
- [tools] perf trace: Introduce --max-events (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Add quirk for Goldmont Plus (Michael Petlan) [1709243]
- [kernel] perf: Suppress AUX/OVERWRITE records (Michael Petlan) [1709243]
- [x86] perf/x86/intel/pt: Annotate 'pt_cap_group' with __ro_after_init (Michael Petlan) [1709243]
- [x86] perf/x86: Add __ro_after_init annotations (Michael Petlan) [1709243]
- [x86] x86/mm/mem_encrypt: Disable all instrumentation for early SME setup (Janakarajan Natarajan) [1679265]
- [fs] cifs: fix copy_file_range to allow write on the same file (Leif Sahlberg) [1689100]
- [infiniband] Revert "[infiniband] IB/usnic: Remove stub functions" (Jonathan Toppins) [1713753]
- [x86] Update stepping values for Whiskey Lake U/Y (David Arcari) [1704801]
- [powerpc] powerpc/perf: Trace imc PMU functions (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Trace imc events detection and cpuhotplug (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Declare static identifier a such (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Add privileged access check for thread_imc (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Rearrange setting of ldbar for thread-imc (Jiri Olsa) [1608796]
- [powerpc] powerpc/include: Add data structures and macros for IMC trace mode (Jiri Olsa) [1608796]
- [scsi] hpsa: correct-static-checker-issue-in-reset-handler (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: update driver version (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct device resets (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: do-not-complete-cmds-for-deleted-devices (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: wait longer for ptraid commands (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: check for tag collision (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: use local workqueues instead of system workqueues (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct simple mode (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: bump driver version (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct device id issues (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: check for lv removal (Joseph Szczypek) [1713772]
- [mm] mm, slub: restore the original intention of prefetch_freepointer() (Rafael Aquini) [1714671]
- [fs] Revert "add KABI padding to dentry structure" (Waiman Long) [1714253]
- [crypto] crypto: drbg - add FIPS 140-2 CTRNG for noise source (Herbert Xu) [1687905]
- [infiniband] RDMA/qedr: Fix incorrect device rate. (Manish Chopra) [1713580]
- [scsi] scsi: bnx2fc: remove unneeded variable (Nilesh Javali) [1665308]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Nilesh Javali) [1665308]
- [char] ipmi:ssif: compare block number correctly for multi-part return messages (Tony Camuso) [1712159]
- [kernel] kernel/sysctl.c: define minmax conv functions in terms of non-minmax versions (Alex Gladkov) [1683922]
- [kernel] kernel/sysctl.c: add missing range check in do_proc_dointvec_minmax_conv (Alex Gladkov) [1683922]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: add tests for >32-bit values written to 32-bit integers (Alex Gladkov) [1683922]
- [kernel] sched/nohz: Run NOHZ idle load balancer on HK_FLAG_MISC CPUs (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] nohz_full: Allow the boot CPU to be nohz_full (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/isolation: Require a present CPU in housekeeping mask (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] kernel/cpu: Allow non-zero CPU to be primary for suspend / kexec freeze (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] power/suspend: Add function to disable secondaries for suspend (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/core: Allow the remote scheduler tick to be started on CPU0 (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/fair: Use non-atomic cpumask_{set,clear}_cpu() (Desnes Augusto Nunes do Rosario) [1666614]
- [lib] lib: reciprocal_div: implement the improved algorithm on the paper mentioned (Petr Oros) [1706982]
- [kernel] kernel/sysctl.c: fix proc_do_large_bitmap for large input buffers (Eric Sandeen) [1667092]
- [kernel] tools/testing/selftests/sysctl/sysctl.sh: add proc_do_large_bitmap() test case (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: allow graceful use on older kernels (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: ignore diff output on verify_diff_w() (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: load module before testing for it (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: remove superfluous test_reqs() (Eric Sandeen) [1667092]
- [kernel] kernel/sysctl.c: fix out-of-bounds access when setting file-max (Eric Sandeen) [1694160]
- [kernel] sysctl: handle overflow for file-max (Eric Sandeen) [1694160]
- [kernel] sysctl: handle overflow in proc_get_long (Eric Sandeen) [1694160]
- [s390] kvm: s390: Fix potential spectre warnings (Thomas Huth) [1702344]
- [powerpc] mm: move warning from resize_hpt_for_hotplug() (Laurent Vivier) [1660737]
- [powerpc] pseries: Use pr_xxx() in lpar.c (Laurent Vivier) [1660737]
- [infiniband] RDMA/iw_cxgb4: Always disconnect when QP is transitioning to TERMINATE state (Arjun Vynipadath) [1664673]
- [infiniband] cxgb4: kfree mhp after the debug print (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxbg: Use correct sizing on buffers holding page DMA addresses (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Make function read_tcb() static (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Remove kref accounting for sync operation (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: cq/qp mask depends on bar2 pages in a host page (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: fix srqidx leak during connection abort (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: complete the cached SRQ buffers (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Remove a set-but-not-used variable (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use tos when finding ipv6 routes (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use tos when importing the endpoint (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use listening ep tos when accepting new connections (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb*: kzalloc the iwcm verbs struct (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/iw_cxgb4: Drop __GFP_NOFAIL (Arjun Vynipadath) [1664673]
- [infiniband] infiniband: cxgb4: no need to check return value of debugfs_create functions (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/iw_cxgb4: Fix the unchecked ep dereference (Arjun Vynipadath) [1664673]
- [infiniband] RDMA: Introduce and use rdma_device_to_ibdev() (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Check for send WR also while posting write with completion WR (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: only reconnect with MPAv1 if the peer aborts (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Use proper enumerated type in c4iw_bar2_addrs (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: remove redundant null pointer check before kfree_skb (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Remove pci_unmap_addr() wrappers for DMA API (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Declare ib_post_send() and ib_post_recv() arguments const (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Simplify a structure initialization (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Fix SRQ endianness annotations (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Add support for kernel mode SRQ's (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Add support for srq functions & structs (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Restore the dropped uninitialized_var (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Make c4iw_poll_cq_one() easier to analyze (Arjun Vynipadath) [1664673]
- [fs] gfs2: clean_journal improperly set sd_log_flush_head (Robert S Peterson) [1693660]

* Fri May 31 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-100.el8]
- [netdrv] bonding/802.3ad: fix slave link initialization transition states (Jarod Wilson) [1714387]
- [iommu] iommu/vt-d: Disable ATS support on untrusted devices (Jerry Snitselaar) [1649210 1692246]
- [documentation] thunderbolt: Export IOMMU based DMA protection support to userspace (Jerry Snitselaar) [1649210 1692246]
- [iommu] iommu/vt-d: Do not enable ATS for untrusted devices (Jerry Snitselaar) [1649210 1692246]
- [iommu] iommu/vt-d: Force IOMMU on for platform opt in hint (Jerry Snitselaar) [1649210 1692246]
- [arm64] arm64: makefile fix build of .i file in external module case (Jerome Marchand) [1713052]
- [s390] s390/protvirt: block kernel command line alteration (Philipp Rudo) [1651711]
- [s390] s390/protvirt: add memory sharing for diag 308 set/store (Philipp Rudo) [1651711]
- [s390] s390/uv: introduce guest side ultravisor code (Philipp Rudo) [1651711]
- [netdrv] net: aquantia: fix undefined devm_hwmon_device_register_with_info reference (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Make aq_ndev_driver_name static (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: remove outdated device ids (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixups on 64bit dma counters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: get total counters from DMA block (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fetch up to date statistics on ethtool request (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: extract timer cb into work job (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: introduce fwreq mutex (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: user correct MSI irq type (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: use macros for better visibility (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: improve ifup link detection (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: link status irq handling (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: create global service workqueue (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: link interrupt handling function (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add link interrupt fields (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: implement hwmon api for chip temperature (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add infrastructure to readout chip temperature (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: enable driver build for arm64 or compile_test (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: improve LRO configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Increase rx ring default size from 1K to 2K (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Make RX default frame size 2K (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Introduce rx refill threshold value (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: optimize rx performance by page reuse strategy (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: optimize rx path using larger preallocated skb len (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix rx checksum offload for UDP/TCP over IPv6 (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: use better wrappers for state registers (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: replace AQ_HW_WAIT_FOR with readx_poll_timeout_atomic (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed instack structure overflow (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed buffer overflow (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: added newline at end of file (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed memcpy size (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: regression on cpus with high cores: set mode with 8 queues (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of RSS configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix initialization of RSS table (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: increase max number of hw queues (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix RSS table and key sizes (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix rx checksum offload bits (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: return 'err' if set MPI_DEINIT state fails (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix spelling mistake "specfield" -> "specified" (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: cleanup err handing in hw_atl_utils_fw_rpc_wait (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of rx-vlan-filter offload (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add ethertype and PCP to rx flow filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add vlan id to rx flow filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of L3/L4 ntuple filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add infrastructure for ntuple rules (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add rx-flow filter definitions (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: allow rx checksum offload configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: invalid checksumm offload implementation (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed enable unicast on 32 macvlan (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix potential IOMMU fault after driver unbind (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: synchronized flow control between mac/phy (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: make function aq_fw2x_update_stats static (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: remove some redundant variable initializations (Igor Russkikh) [1706905]
- [netdrv] bnxt_en: Add device IDs 0x1806 and 0x1752 for 57500 devices. (Selvin Xavier) [1672208]
- [scsi] scsi: fnic: Remove set but not used variable 'vdev' (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: no need to check return value of debugfs_create functions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Update fnic driver version to 1.6.0.47 (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Enable fnic devcmd2 interface (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Adding devcmd2 init and posting interfaces (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Add devcmd2 initialization helpers (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic devcmd2 controller definitions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic devcmd2 interface definitions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Impose upper limit on max. # of CQs processed per intr (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: RQ enable and then post descriptors (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: delaying vnic dev enable till after req intr (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Warn when calling done for IO not issued to fw (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic stats for max CQs processed and ISR time (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Add port speed stat to fnic debug stats (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: use fnic_lock to guard fnic->state_flags (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: vnic_rq_clean change BUG_ON to WARN_ON (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: change fnic queue depth to 256 (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: support to display 20G port speed (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Use vzalloc (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: switch to generic DMA API (Govindarajulu Varadarajan) [1656236]
- [pci] PCI/PME: Fix possible use-after-free on remove (Myron Stowe) [1701834]
- [pci] PCI/PME: Fix hotplug/sysfs remove deadlock in pcie_pme_remove() (Myron Stowe) [1701834]
- [pci] PCI: Blacklist power management of Gigabyte X299 DESIGNARE EX PCIe ports (Myron Stowe) [1701834]
- [tools] perf arm64: Fix mksyscalltbl when system kernel headers are ahead of the kernel (Michael Petlan) [1709242]
- [rpmspec] perf: remove bpf examples (Michael Petlan) [1709242]
- [tools] perf tools: Stop fallbacking to kallsyms for vdso symbols lookup (Michael Petlan) [1709242]
- [tools] perf report: Don't crash on invalid inline debug information (Michael Petlan) [1709242]
- [tools] perf cpu_map: Align cpu map synthesized events properly. (Michael Petlan) [1709242]
- [tools] perf tools: Fix tracing_path_mount proper path (Michael Petlan) [1709242]
- [tools] perf evsel: Store ids for events with their own cpus perf_event__synthesize_event_update_cpus (Michael Petlan) [1709242]
- [tools] perf vendor events intel: Fix wrong filter_band* values for uncore events (Michael Petlan) [1709242]
- [tools] Revert "perf tools: Fix PMU term format max value calculation" (Michael Petlan) [1709242]
- [tools] tools headers uapi: Sync kvm.h copy (Michael Petlan) [1709242]
- [tools] perf record: Use unmapped IP for inline callchain cursors (Michael Petlan) [1709242]
- [tools] perf python: Use -Wno-redundant-decls to build with PYTHON=python3 (Michael Petlan) [1709242]
- [tools] perf report: Don't try to map ip to invalid map (Michael Petlan) [1709242]
- [tools] perf script python: Fix export-to-sqlite.py sample columns (Michael Petlan) [1709242]
- [tools] perf script python: Fix export-to-postgresql.py occasional failure (Michael Petlan) [1709242]
- [tools] perf Documentation: Fix out-of-tree asciidoctor man page generation (Michael Petlan) [1709242]
- [tools] perf tools: Fix maps__find_symbol_by_name() (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/if_link.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/vhost.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copies of kvm headers (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of drm/drm.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of asm-generic/unistd.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/perf_event.h (Michael Petlan) [1709242]
- [tools] perf annotate: Fix parsing aarch64 branch instructions after objdump update (Michael Petlan) [1709242]
- [tools] perf probe powerpc: Ignore SyS symbols irrespective of endianness (Michael Petlan) [1709242]
- [tools] perf event-parse: Use fixed size string for comms (Michael Petlan) [1709242]
- [tools] perf util: Fix bad memory access in trace info. (Michael Petlan) [1709242]
- [tools] perf tools: Streamline bpf examples and headers installation (Michael Petlan) [1709242]
- [tools] perf evsel: Fix potential null pointer dereference in perf_evsel__new_idx() (Michael Petlan) [1709242]
- [tools] perf arm64: Fix include path for asm-generic/unistd.h (Michael Petlan) [1709242]
- [tools] perf tests: Add breakpoint modify tests (Michael Petlan) [1709242]
- [tools] perf annotate: Properly interpret indirect call (Michael Petlan) [1709242]
- [tools] tools/lib/lockdep: Add dummy task_struct state member (Michael Petlan) [1709242]
- [tools] tools/lib/lockdep: Add empty nmi.h (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Change to SPDX License format (Michael Petlan) [1709242]
- [tools] perf llvm: Allow passing options to llc in addition to clang (Michael Petlan) [1709242]
- [tools] perf parser: Improve error message for PMU address filters (Michael Petlan) [1709242]
- [tools] perf tools: Disable parallelism for 'make clean' (Michael Petlan) [1709242]
- [tools] perf auxtrace: Fix queue resize (Michael Petlan) [1709242]
- [tools] perf python: Remove -mcet and -fcf-protection when building with clang (Michael Petlan) [1709242]
- [tools] perf arm spe: Fix uninitialized record error variable (Michael Petlan) [1709242]
- [tools] perf tools: Move syscall_64.tbl check into check-headers.sh (Michael Petlan) [1709242]
- [tools] perf tools: Make check-headers.sh check based on kernel dir (Michael Petlan) [1709242]
- [tools] perf tools: Fix check-headers.sh AND list path of execution (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename static variables and functions in event-parse.c (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename various pevent APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename internal parser related APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename various pevent get/set/is APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_find_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent field APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_data_ APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_register / unregister APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_filter* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent,  perf tools: Rename traceevent_plugin_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_function* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, tools lib lockdep: Rename 'enum pevent_errno' to 'enum tep_errno' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename 'enum pevent_flag' to 'enum tep_flag' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename traceevent_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_set_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_register_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_read_number_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent print APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent parse APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent find APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent alloc / free APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent plugin related APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename 'struct pevent_record' to 'struct tep_record' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename struct pevent to struct tep_handle (Michael Petlan) [1709242]
- [tools] perf probe powerpc: Fix trace event post-processing (Michael Petlan) [1709242]
- [tools] perf map: Optimize maps__fixup_overlappings() (Michael Petlan) [1709242]
- [tools] perf map: Synthesize maps only for thread group leader (Michael Petlan) [1709242]
- [tools] perf trace: Wire up the augmented syscalls with the syscalls:sys_enter_FOO beautifier (Michael Petlan) [1709242]
- [tools] perf trace: Setup the augmented syscalls bpf-output event fields (Michael Petlan) [1709242]
- [tools] perf bpf: Make bpf__setup_output_event() return the bpf-output event (Michael Petlan) [1709242]
- [tools] perf trace: Handle "bpf-output" events associated with "__augmented_syscalls__" BPF map (Michael Petlan) [1709242]
- [tools] perf bpf: Add wrappers to BPF_FUNC_probe_read(_str) functions (Michael Petlan) [1709242]
- [tools] perf bpf: Add bpf__setup_output_event() strerror() counterpart (Michael Petlan) [1709242]
- [tools] perf bpf: Generalize bpf__setup_stdout() (Michael Petlan) [1709242]
- [tools] perf bpf: Make bpf__for_each_stdout_map() generic (Michael Petlan) [1709242]
- [tools] perf bpf: Add bpf/stdio.h wrapper to bpf_perf_event_output function (Michael Petlan) [1709242]
- [tools] perf bpf: Add struct bpf_map struct (Michael Petlan) [1709242]
- [tools] perf report: Add --percent-type option (Michael Petlan) [1709242]
- [tools] perf annotate: Add --percent-type option (Michael Petlan) [1709242]
- [tools] perf annotate: Display percent type in stdio output (Michael Petlan) [1709242]
- [tools] perf annotate: Make local period the default percent type (Michael Petlan) [1709242]
- [tools] perf annotate: Add support to toggle percent type (Michael Petlan) [1709242]
- [tools] perf annotate: Pass browser percent_type in annotate_browser__calc_percent() (Michael Petlan) [1709242]
- [tools] perf annotate: Pass 'struct annotation_options' to map_symbol__annotation_dump() (Michael Petlan) [1709242]
- [tools] perf annotate: Pass struct annotation_options to symbol__calc_lines() (Michael Petlan) [1709242]
- [tools] perf annotate: Add percent_type to struct annotation_options (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_PERIOD_GLOBAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_PERIOD_LOCAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_HITS_GLOBAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Switch struct annotation_data::percent to array (Michael Petlan) [1709242]
- [tools] perf annotate: Loop group events directly in annotation__calc_percent() (Michael Petlan) [1709242]
- [tools] perf annotate: Rename hist to sym_hist in annotation__calc_percent (Michael Petlan) [1709242]
- [tools] perf annotate: Rename local sample variables to data (Michael Petlan) [1709242]
- [tools] perf annotate: Rename struct annotation_line::samples* to data* (Michael Petlan) [1709242]
- [tools] perf annotate: Get rid of annotation__scnprintf_samples_period() (Michael Petlan) [1709242]
- [tools] perf annotate: Make annotation_line__max_percent static (Michael Petlan) [1709242]
- [tools] perf annotate: Make symbol__annotate_fprintf2() local (Michael Petlan) [1709242]
- [tools] perf bpf: Add 'syscall_enter' probe helper for syscall enter tracepoints (Michael Petlan) [1709242]
- [tools] perf tools: Drop unneeded bitmap_zero() calls (Michael Petlan) [1709242]
- [tools] perf vendor events arm64: Enable JSON events for eMAG (Michael Petlan) [1709242]
- [tools] perf report: Add GUI report support for s390 auxiliary trace (Michael Petlan) [1709242]
- [tools] perf report: Add raw report support for s390 auxiliary trace (Michael Petlan) [1709242]
- [tools] perf auxtrace: Support for perf report -D for s390 (Michael Petlan) [1709242]
- [tools] perf trace: Use perf_evsel__sc_tp_{uint,ptr} for "id"/"args" handling syscalls:* events (Michael Petlan) [1709242]
- [tools] perf trace: Setup struct syscall_tp for syscalls:sys_{enter,exit}_NAME events (Michael Petlan) [1709242]
- [tools] perf trace: Allow setting up a syscall_tp struct without a format_field (Michael Petlan) [1709242]
- [tools] perf trace: Rename some syscall_tp methods to raw_syscall (Michael Petlan) [1709242]
- [tools] perf trace: Use beautifiers on syscalls:sys_enter_ handlers (Michael Petlan) [1709242]
- [tools] perf trace: Associate vfs_getname()'ed pathname with fd returned from 'openat' (Michael Petlan) [1709242]
- [tools] perf trace: Do not require --no-syscalls to suppress strace like output (Michael Petlan) [1709242]
- [tools] perf bpf: Include uapi/linux/bpf.h from the 'perf trace' script's bpf.h (Michael Petlan) [1709242]
- [tools] perf tools: Allow overriding MAX_NR_CPUS at compile time (Michael Petlan) [1709242]
- [tools] perf bpf: Show better message when failing to load an object (Michael Petlan) [1709242]
- [tools] perf list: Unify metric group description format with PMU event description (Michael Petlan) [1709242]
- [tools] perf cs-etm: Generate branch sample for CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Generate branch sample when receiving a CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Support dummy address value for CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Fix start tracing packet handling (Michael Petlan) [1709242]
- [tools] perf build: Fix installation directory for eBPF (Michael Petlan) [1709242]
- [tools] perf c2c report: Fix crash for empty browser (Michael Petlan) [1709242]
- [tools] perf tests: Fix indexing when invoking subtests (Michael Petlan) [1709242]
- [tools] perf trace: Beautify the AF_INET & AF_INET6 'socket' syscall 'protocol' args (Michael Petlan) [1709242]
- [tools] perf trace beauty: Add beautifiers for 'socket''s 'protocol' arg (Michael Petlan) [1709242]
- [tools] perf trace beauty: Do not print NULL strarray entries (Michael Petlan) [1709242]
- [tools] perf beauty: Add a generator for IPPROTO_ socket's protocol constants (Michael Petlan) [1709242]
- [tools] tools include uapi: Grab a copy of linux/in.h (Michael Petlan) [1709242]
- [tools] perf tests: Fix complex event name parsing (Michael Petlan) [1709242]
- [tools] perf evlist: Fix error out while applying initial delay and LBR (Michael Petlan) [1709242]
- [tools] perf trace beauty: Default header_dir to cwd to work without parms (Michael Petlan) [1709242]
- [tools] perf test: Fix subtest number when showing results (Michael Petlan) [1709242]
- [tools] perf stat: Get rid of extra clock display function (Michael Petlan) [1709242]
- [tools] perf tools: Use perf_evsel__match instead of open coded equivalent (Michael Petlan) [1709242]
- [tools] perf tools: Fix struct comm_str removal crash (Michael Petlan) [1709242]
- [tools] perf machine: Use last_match threads cache only in single thread mode (Michael Petlan) [1709242]
- [tools] perf machine: Add threads__set_last_match function (Michael Petlan) [1709242]
- [tools] perf machine: Add threads__get_last_match function (Michael Petlan) [1709242]
- [tools] perf tools: Synthesize GROUP_DESC feature in pipe mode (Michael Petlan) [1709242]
- [tools] perf script: Show correct offsets for DWARF-based unwinding (Michael Petlan) [1709242]
- [tools] perf trace arm64: Use generated syscall table (Michael Petlan) [1709242]
- [tools] perf arm64: Generate system call table from asm/unistd.h (Michael Petlan) [1709242]
- [tools] tools include: Grab copies of arm64 dependent unistd.h files (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh when event exists (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh to ensure cleanups (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64 (Michael Petlan) [1709242]
- [tools] perf powerpc: Fix callchain ip filtering when return address is in a register (Michael Petlan) [1709242]
- [tools] perf powerpc: Fix callchain ip filtering (Michael Petlan) [1709242]
- [tools] perf list: Add missing documentation for --desc and --debug options (Michael Petlan) [1709242]
- [tools] perf stat: Add transaction flag (-T) support for s390 (Michael Petlan) [1709242]
- [tools] perf json: Add s390 transaction counter definition (Michael Petlan) [1709242]
- [tools] perf list: Add s390 support for detailed PMU event description (Michael Petlan) [1709242]
- [tools] Revert "perf list: Add s390 support for detailed/verbose PMU event description" (Michael Petlan) [1709242]
- [tools] perf cs-etm: Bail out immediately for instruction sample failure (Michael Petlan) [1709242]
- [tools] perf cs-etm: Introduce invalid address macro (Michael Petlan) [1709242]
- [tools] perf hists: Clarify callchain disabling when available (Michael Petlan) [1709242]
- [tools] perf tests: Check that complex event name is parsed correctly (Michael Petlan) [1709242]
- [arm64] arm64: perf: Reject stand-alone CHAIN events for PMUv3 (Michael Petlan) [1709242]
- [x86] perf/x86/amd/uncore: Set ThreadMask and SliceMask for L3 Cache perf events (Michael Petlan) [1709242]
- [x86] perf/x86/intel/uncore: Fix PCI BDF address of M3UPI on SKX (Michael Petlan) [1709242]
- [kernel] perf/ring_buffer: Prevent concurent ring buffer access (Michael Petlan) [1709242]
- [x86] perf/x86/intel/uncore: Use boot_cpu_data.phys_proc_id instead of hardcorded physical package ID 0 (Michael Petlan) [1709242]
- [kernel] perf/core: Fix perf_pmu_unregister() locking (Michael Petlan) [1709242]
- [kernel] perf/core: Add sanity check to deal with pinned event failure (Michael Petlan) [1709242]
- [kernel] perf/core: Force USER_DS when recording user stack data (Michael Petlan) [1709242]
- [include] perf/UAPI: Clearly mark __PERF_SAMPLE_CALLCHAIN_EARLY as internal use (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Add support/quirk for the MISPREDICT bit on Knights Landing CPUs (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Simplify breakpoint enable in perf_event_modify_breakpoint (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Enable breakpoint in modify_user_hw_breakpoint (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Remove superfluous bp->attr.disabled = 0 (Michael Petlan) [1709242]
- [kernel] arm64: perf: Add cap_user_time aarch64 (Michael Petlan) [1709242]
- [include] arm_pmu: Add support for 64bit event counters (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Support Extended PEBS for Goldmont Plus (Michael Petlan) [1709242]
- [x86] perf/x86/intel/ds: Handle PEBS overflow for fixed counters (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Support PEBS on fixed counters (Michael Petlan) [1709242]
- [kernel] perf, tools: Use correct articles in comments (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Clean up and consolidate modify_user_hw_breakpoint_check() (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Pass new breakpoint type to modify_breakpoint_slot() (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Remove default hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [arm64] perf/arch/arm64: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [powerpc] perf/arch/powerpc: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [x86] perf/arch/x86: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [arm64] perf/hw_breakpoint: Pass arch breakpoint struct to arch_check_bp_in_kernelspace() (Michael Petlan) [1709242]
- [kernel] perf/core: Change perf_mmap_fault() return type to 'vm_fault_t' (Michael Petlan) [1709242]
- [x86] perf/x86/intel/lbr: Optimize context switches for the LBR call stack (Michael Petlan) [1709242]
- [netdrv] cnic: Refactor code and mark expected switch fall-through (Nilesh Javali) [1665302]
- [netdrv] cnic: remove use of VLAN_TAG_PRESENT (Nilesh Javali) [1665302]
- [netdrv] cnic: use kvzalloc to allocate memory for csk_tbl (Nilesh Javali) [1665302]
- [netdrv] cnic: remove redundant pointer req and variable func (Nilesh Javali) [1665302]
- [scsi] drivers: Remove useless trailing comments from mmiowb() invocations (Nilesh Javali) [1665307]
- [scsi] scsi: qedf: remove set but not used variables (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Update the driver version to 8.37.25.20 (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add return value to log message if scsi_add_host fails (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Print fcport information on wait for upload timeout (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check the return value of start_xmit (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Log message if scsi_add_host fails (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for fcoe_libfc_config failure (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add comment to display logging levels (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add port_id for fcport into initiate_cleanup debug message (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add LBA to underrun debug messages (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Print scsi_cmd backpointer in good completion path if the command is still being used (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add driver state to 'driver_stats' debugfs node (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Change MSI-X load error message (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: remove memset/memcpy to nfunc and use func instead (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Remove set but not used variable 'fr_len' (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Update the driver version to 8.37.25.19 (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Fix lport may be used uninitialized warning (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correctly handle refcounting of rdata (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Cleanup rrq_work after QEDF_CMD_OUTSTANDING is cleared (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for tm_flags instead of cmd_type during cleanup (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add a flag to help debugging io_req which could not be cleaned (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Don't send ABTS for under run scenario (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Don't queue anything if upload is in progress (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check both the FCF and fabric ID before servicing clear virtual link (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fc_rport_priv reference counting fixes (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing return in qedf_scsi_done() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Wait for upload and link down processing during soft ctx reset (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add additional checks for io_req->sc_cmd validity (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fixup bit operations (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fixup locking in qedf_restart_rport() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: missing kref_put in qedf_xmit() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for link state before processing LL2 packets and send fipvlan retries (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing fc_disc_init call after allocating lport (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correct the memory barriers in qedf_ring_doorbell (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Use a separate completion for cleanup commands (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Modify abort and tmf handler to handle edge condition and flush (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Modify flush routine to handle all I/Os and TMF (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Simplify s/g list mapping (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing return in qedf_post_io_req() in the fcport offload check (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correct xid range overlap between offloaded requests and libfc requests (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Do not retry ELS request if qedf_alloc_cmd fails (Nilesh Javali) [1665301]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Nilesh Javali) [1665301]
- [scsi] scsi: stop setting up request->special (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: no need to check return value of debugfs_create functions (Nilesh Javali) [1665301]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: NULL check before some freeing functions is not needed (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fully convert to the generic DMA API (Nilesh Javali) [1665301]
- [scsi] scsi: qedi: Adjust termination and offload ramrod timers (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Abort ep termination if offload not scheduled (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: fix spelling mistake "oflload" -> "offload" (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: remove declaration of nvm_image from stack (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Remove set but not used variable 'cls_sess' (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Add ep_state for login completion on un-reachable targets (Nilesh Javali) [1665300]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Update driver version to 8.33.0.21 (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Move LL2 producer index processing in BH. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: add module param to set ping packet size (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Add packet filter in light L2 Rx path. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Check for session online before getting iSCSI TLV data. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Replace PAGE_SIZE with QEDI_PAGE_SIZE (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Fix spelling mistake "OUSTANDING" -> "OUTSTANDING" (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Cleanup redundant QEDI_PAGE_SIZE macro definition (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: fully convert to the generic DMA API (Nilesh Javali) [1665300]
- [x86] x86/kdump: Fall back to reserve high crashkernel memory (Pingfan Liu) [1682984]
- [x86] x86/kdump: Have crashkernel=X reserve under 4G by default (Pingfan Liu) [1682984]
- [x86] Revert "[x86] x86/kdump: make the behavior of crashkernel=X consistent with kaslr" (Pingfan Liu) [1682984]
- [scsi] scsi: core: avoid pre-allocating big SGL for data (Ewan Milne) [1698297]
- [scsi] scsi: core: avoid pre-allocating big SGL for protection information (Ewan Milne) [1698297]
- [nvme] scsi: lib/sg_pool.c: improve APIs for allocating sg pool (Ewan Milne) [1698297]
- [kvm] KVM: PPC: Book3S HV: Save/restore vrsave register in kvmhv_p9_guest_entry() (Suraj Jitindar Singh) [1700272]
- [fs] ext4: avoid kernel warning when writing the superblock to a dead device (Lukas Czerner) [1695021]
- [fs] ext4: cond_resched in work-heavy group loops (Lukas Czerner) [1698815]
- [fs] ext4: ignore e_value_offs for xattrs with value-in-ea-inode (Lukas Czerner) [1698815]
- [fs] ext4: protect journal inode's blocks using block_validity (Lukas Czerner) [1698815]
- [fs] ext4: use BUG() instead of BUG_ON(1) (Lukas Czerner) [1698815]
- [fs] jbd2: check superblock mapped prior to committing (Lukas Czerner) [1698815]
- [fs] ext4: remove incorrect comment for NEXT_ORPHAN() (Lukas Czerner) [1698815]
- [fs] ext4: make sanity check in mballoc more strict (Lukas Czerner) [1698815]
- [fs] ext4: fix use-after-free race with debug_want_extra_isize (Lukas Czerner) [1698815]
- [fs] ext4: fix ext4_show_options for file systems w/o journal (Lukas Czerner) [1698815]
- [fs] ext4: actually request zeroing of inode table after grow (Lukas Czerner) [1698815]
- [fs] Revert "ext4: use ext4_write_inode() when fsyncing w/o a journal" (Lukas Czerner) [1698815]
- [fs] ext4: fix some error pointer dereferences (Lukas Czerner) [1698815]
- [fs] ext4: fix special inode number checks in __ext4_iget() (Lukas Czerner) [1698815]
- [fs] ext4: prohibit fstrim in norecovery mode (Lukas Czerner) [1698815]
- [fs] ext4: cleanup bh release code in ext4_ind_remove_space() (Lukas Czerner) [1698815]
- [fs] ext4: brelse all indirect buffer in ext4_ind_remove_space() (Lukas Czerner) [1698815]
- [fs] ext4: report real fs size after failed resize (Lukas Czerner) [1698815]
- [fs] ext4: add missing brelse() in add_new_gdb_meta_bg() (Lukas Czerner) [1698815]
- [fs] ext4: remove useless ext4_pin_inode() (Lukas Czerner) [1698815]
- [fs] ext4: avoid panic during forced reboot (Lukas Czerner) [1698815]
- [fs] ext4: fix data corruption caused by unaligned direct AIO (Lukas Czerner) [1698815]
- [fs] ext4: fix NULL pointer dereference while journal is aborted (Lukas Czerner) [1698815]
- [fs] jbd2: jbd2_get_transaction does not need to return a value (Lukas Czerner) [1698815]
- [fs] jbd2: fix invalid descriptor block checksum (Lukas Czerner) [1698815]
- [fs] ext4: fix bigalloc cluster freeing when hole punching under load (Lukas Czerner) [1698815]
- [fs] ext4: add sysfs attr /sys/fs/ext4/<disk>/journal_task (Lukas Czerner) [1698815]
- [fs] ext4: Change debugging support help prefix from EXT4 to Ext4 (Lukas Czerner) [1698815]
- [fs] ext4: fix compile error when using BUFFER_TRACE (Lukas Czerner) [1698815]
- [fs] jbd2: fix compile warning when using JBUFFER_TRACE (Lukas Czerner) [1698815]
- [fs] ext4: annotate more implicit fall throughs (Lukas Czerner) [1698815]
- [fs] ext4: annotate implicit fall throughs (Lukas Czerner) [1698815]
- [fs] ext4: don't update s_rev_level if not required (Lukas Czerner) [1698815]
- [fs] jbd2: fold jbd2_superblock_csum_{verify,set} into their callers (Lukas Czerner) [1698815]
- [fs] jbd2: fix race when writing superblock (Lukas Czerner) [1698815]
- [fs] ext4: fix crash during online resizing (Lukas Czerner) [1698815]
- [fs] ext4: disallow files with EXT4_JOURNAL_DATA_FL from EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1698815]
- [fs] ext4: add mask of ext4 flags to swap (Lukas Czerner) [1698815]
- [fs] ext4: update quota information while swapping boot loader inode (Lukas Czerner) [1698815]
- [fs] ext4: cleanup pagecache before swap i_data (Lukas Czerner) [1698815]
- [fs] ext4: fix check of inode in swap_inode_boot_loader (Lukas Czerner) [1698815]
- [fs] ext4: unlock unused_pages timely when doing writeback (Lukas Czerner) [1698815]
- [fs] ext4: cleanup clean_bdev_aliases() calls (Lukas Czerner) [1698815]
- [fs] jbd2: discard dirty data when forgetting an un-journalled buffer (Lukas Czerner) [1698815]
- [fs] jbd2: clear dirty flag when revoking a buffer from an older transaction (Lukas Czerner) [1698815]
- [fs] ext4: replace opencoded i_writecount usage with inode_is_open_for_write() (Lukas Czerner) [1698815]
- [fs] jbd2: fix deadlock while checkpoint thread waits commit thread to finish (Lukas Czerner) [1698815]
- [fs] ext4: use IS_ENCRYPTED() to check encryption status (Lukas Czerner) [1698815]
- [fs] ext4: track writeback errors using the generic tracking infrastructure (Lukas Czerner) [1698815]
- [fs] ext4: use ext4_write_inode() when fsyncing w/o a journal (Lukas Czerner) [1698815]
- [fs] ext4: fix a potential fiemap/page fault deadlock w/ inline_data (Lukas Czerner) [1698815]
- [fs] ext4: make sure enough credits are reserved for dioread_nolock writes (Lukas Czerner) [1698815]
- [fs] ext4: check for shutdown and r/o file system in ext4_write_inode() (Lukas Czerner) [1698815]
- [fs] ext4: force inode writes when nfsd calls commit_metadata() (Lukas Czerner) [1698815]
- [fs] ext4: avoid declaring fs inconsistent due to invalid file handles (Lukas Czerner) [1698815]
- [fs] ext4: include terminating u32 in size of xattr entries when expanding inodes (Lukas Czerner) [1698815]
- [fs] ext4: compare old and new mode before setting update_mode flag (Lukas Czerner) [1698815]
- [fs] ext4: fix EXT4_IOC_GROUP_ADD ioctl (Lukas Czerner) [1698815]
- [fs] ext4: hard fail dax mount on unsupported devices (Lukas Czerner) [1698815]
- [fs] ext4: remove redundant condition check (Lukas Czerner) [1698815]
- [fs] jbd2: clean up indentation issue, replace spaces with tab (Lukas Czerner) [1698815]
- [fs] ext4: clean up indentation issues, remove extraneous tabs (Lukas Czerner) [1698815]
- [fs] ext4: missing unlock/put_page() in ext4_try_to_write_inline_data() (Lukas Czerner) [1698815]
- [fs] ext4: fix possible use after free in ext4_quota_enable (Lukas Czerner) [1698815]
- [fs] jbd2: avoid long hold times of j_state_lock while committing a transaction (Lukas Czerner) [1698815]
- [fs] ext4: add ext4_sb_bread() to disambiguate ENOMEM cases (Lukas Czerner) [1698815]
- [fs] ext4: remove unneeded brelse call in ext4_xattr_inode_update_ref() (Lukas Czerner) [1698815]
- [fs] ext4: fix use-after-free race in ext4_remount()'s error path (Lukas Czerner) [1698815]
- [fs] ext4: don't open-code ERR_CAST (Lukas Czerner) [1698815]
- [fs] ext4: cache NULL when both default_acl and acl are NULL (Lukas Czerner) [1698815]
- [fs] ext4: propagate error from dquot_initialize() in EXT4_IOC_FSSETXATTR (Lukas Czerner) [1698815]
- [fs] ext4: fix setattr project check in fssetxattr ioctl (Lukas Czerner) [1698815]
- [fs] ext4: convert fault handler to use vm_fault_t type (Lukas Czerner) [1698815]
- [fs] ext4: fix EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1698815]
- [fs] ext4: fix argument checking in EXT4_IOC_MOVE_EXT (Lukas Czerner) [1698815]
- [fs] ext4: fix reserved cluster accounting at page invalidation time (Lukas Czerner) [1698815]
- [fs] ext4: adjust reserved cluster count when removing extents (Lukas Czerner) [1698815]
- [fs] ext4: reduce reserved cluster count by number of allocated clusters (Lukas Czerner) [1698815]
- [fs] ext4: fix reserved cluster accounting at delayed write time (Lukas Czerner) [1698815]
- [fs] ext4: add new pending reservation mechanism (Lukas Czerner) [1698815]
- [fs] ext4: generalize extents status tree search functions (Lukas Czerner) [1698815]
- [fs] ext4: readpages() should submit IO as read-ahead (Lukas Czerner) [1698815]
- [fs] ext4: improve code readability in ext4_iget() (Lukas Czerner) [1698815]
- [fs] ext4: use swap macro in mext_page_double_lock (Lukas Czerner) [1698815]
- [fs] ext4: fix warning message in ext4_enable_quotas() (Lukas Czerner) [1698815]
- [fs] ext4: super: extend timestamps to 40 bits (Lukas Czerner) [1698815]
- [fs] jbd2: replace current_kernel_time64 with ktime equivalent (Lukas Czerner) [1698815]
- [fs] ext4: use timespec64 for all inode times (Lukas Czerner) [1698815]
- [fs] ext4: use ktime_get_real_seconds for i_dtime (Lukas Czerner) [1698815]
- [fs] ext4: use 64-bit timestamps for mmp_time (Lukas Czerner) [1698815]
- [scsi] scsi: smartpqi: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Don Brace) [1665565]
- [scsi] scsi: smartpqi: bump driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add spdx (Don Brace) [1665565]
- [scsi] scsi: smartpqi: update copyright (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add H3C controller IDs (Don Brace) [1665565]
- [scsi] scsi: smartpqi: increase LUN reset timeout (Don Brace) [1665565]
- [scsi] scsi: smartpqi: Reporting 'logical unit failure' (Don Brace) [1665565]
- [scsi] scsi: smartpqi_init: fix boolean expression in pqi_device_remove_start (Don Brace) [1665565]
- [scsi] scsi: smartpqi: call pqi_free_interrupts() in pqi_shutdown() (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fix build warnings (Don Brace) [1665565]
- [scsi] scsi: smartpqi: update driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add ofa support (Don Brace) [1665565]
- [scsi] scsi: smartpqi: increase fw status register read timeout (Don Brace) [1665565]
- [scsi] scsi: smartpqi: bump driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add smp_utils support (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct lun reset issues (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct volume status (Don Brace) [1665565]
- [scsi] scsi: smartpqi: do not offline disks for transient did no connect conditions (Don Brace) [1665565]
- [scsi] scsi: smartpqi: allow for larger raid maps (Don Brace) [1665565]
- [scsi] scsi: smartpqi: check for null device pointers (Don Brace) [1665565]
- [scsi] scsi: smartpqi: enhance numa node detection (Don Brace) [1665565]
- [scsi] scsi: smartpqi: wake up drives after os resumes from suspend (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fix disk name mount point (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add h3c ssid (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add sysfs attributes (Don Brace) [1665565]
- [scsi] scsi: smartpqi: refactor sending controller raid requests (Don Brace) [1665565]
- [scsi] scsi: smartpqi: turn off lun data caching for ptraid (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct host serial num for ssa (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add no_write_same for logical volumes (Don Brace) [1665565]
- [scsi] scsi: smartpqi: Add retries for device reset (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add support for PQI Config Table handshake (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fully convert to the generic DMA API (Don Brace) [1665565]
- [net] rtnetlink: always put IFLA_LINK for links with a link-netnsid (Sabrina Dubroca) [1711933]
- [net] ipv6: add inet6_fill_args (Ivan Vecera) [1711956]
- [net] ipv4: add inet_fill_args (Ivan Vecera) [1711956]
- [net] rtnetlink: s/IFLA_IF_NETNSID/IFLA_TARGET_NETNSID/g (Ivan Vecera) [1711956]
- [include] if_link: add IFLA_TARGET_NETNSID alias (Ivan Vecera) [1711956]
- [net] rtnetlink: move type calculation out of loop (Ivan Vecera) [1711956]
- [net] ipv6: enable IFA_TARGET_NETNSID for RTM_GETADDR (Ivan Vecera) [1711956]
- [net] ipv4: enable IFA_TARGET_NETNSID for RTM_GETADDR (Ivan Vecera) [1711956]
- [include] if_addr: add IFA_TARGET_NETNSID (Ivan Vecera) [1711956]
- [net] rtnetlink: add rtnl_get_net_ns_capable() (Ivan Vecera) [1711956]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Fix untagged test (Hangbin Liu) [1710283]
- [tools] selftests: forwarding: Tweak tc filters for mirror-to-gretap tests (Hangbin Liu) [1710283]
- [tools] selftests: forwarding: lib: Avoid trapping soft devices (Hangbin Liu) [1710283]
- [tools] selftests: pmtu: maximum MTU for vti4 is 2^16-1-20 (Hangbin Liu) [1704659]
- [net] sched: red: inform offloads about harddrop setting (Ivan Vecera) [1710999]
- [net] tls: fix copy to fragments in reencrypt (Ivan Vecera) [1710366]
- [net] tls: don't copy negative amounts of data in reencrypt (Ivan Vecera) [1710366]
- [net] tls: don't leak IV and record seq when offload fails (Ivan Vecera) [1710366]
- [net] tls: avoid potential deadlock in tls_set_device_offload_rx() (Ivan Vecera) [1710366]
- [net] tls: prevent bad memory access in tls_is_sk_tx_device_offloaded() (Ivan Vecera) [1710366]
- [net] tls: Combined memory allocation for decryption request (Ivan Vecera) [1710366]
- [net] tls: Skip zerocopy path for ITER_KVEC (Ivan Vecera) [1710366]
- [net] tls: Fix copy-paste error in tls_device_reencrypt (Ivan Vecera) [1710366]
- [net] tls: Add rx inline crypto offload (Ivan Vecera) [1710366]
- [net] tls: Fill software context without allocation (Ivan Vecera) [1710366]
- [net] tls: Split tls_sw_release_resources_rx (Ivan Vecera) [1710366]
- [net] tls: Split decrypt_skb to two functions (Ivan Vecera) [1710366]
- [net] tcp: Don't coalesce decrypted and encrypted SKBs (Ivan Vecera) [1710366]
- [include] Add TLS rx resync NDO (Ivan Vecera) [1710366]
- [net] Add TLS RX offload feature (Ivan Vecera) [1710366]
- [net] Add decrypted field to skb (Ivan Vecera) [1710366]
- [net] tls: Use aead_request_alloc/free for request alloc/free (Ivan Vecera) [1710366]
- [net] tls: Refactor tls_offload variable names (Ivan Vecera) [1703389]

* Thu May 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-99.el8]
- [netdrv] qede: use ethtool_rx_flow_rule() to remove duplicated parser code (Manish Chopra) [1663274]
- [netdrv] qede: place ethtool_rx_flow_spec after code after TC flower codebase (Manish Chopra) [1663274]
- [netdrv] drivers: net: use flow action infrastructure (Manish Chopra) [1663274]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Manish Chopra) [1663274]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Manish Chopra) [1663274]
- [netdrv] qede: Populate mbi version in ethtool driver query data. (Manish Chopra) [1663274]
- [netdrv] qed: Define new MF bit for no_vlan config (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "faspath" -> "fastpath" (Manish Chopra) [1663274]
- [netdrv] qed: Fix the DORQ's attentions handling (Manish Chopra) [1663274]
- [netdrv] qed: Fix missing DORQ attentions (Manish Chopra) [1663274]
- [netdrv] qed: Fix the doorbell address sanity check (Manish Chopra) [1663274]
- [netdrv] qed: Delete redundant doorbell recovery types (Manish Chopra) [1663274]
- [netdrv] qede: fix write to free'd pointer error and double free of ptp (Manish Chopra) [1663274]
- [netdrv] qede: Fix internal loopback failure with jumbo mtu configuration (Manish Chopra) [1663274]
- [netdrv] qed: Read device port count from the shmem (Manish Chopra) [1663274]
- [netdrv] qed: Fix iWARP syn packet mac address validation. (Manish Chopra) [1663274]
- [netdrv] qed: Fix iWARP buffer size provided for syn packet processing. (Manish Chopra) [1663274]
- [netdrv] qed: fix indentation issue with statements in an if-block (Manish Chopra) [1663274]
- [netdrv] qede: Add ethtool interface for SmartAN query. (Manish Chopra) [1663274]
- [netdrv] qed: Add API for SmartAN query. (Manish Chopra) [1663274]
- [netdrv] qed*: Advance drivers version to 8.37.0.20 (Manish Chopra) [1663274]
- [netdrv] qed: Change verbosity for coalescing message. (Manish Chopra) [1663274]
- [netdrv] qede: Fix system crash on configuring channels. (Manish Chopra) [1663274]
- [netdrv] qed: Consider TX tcs while deriving the max num_queues for PF. (Manish Chopra) [1663274]
- [netdrv] qed: Assign UFP TC value to vlan priority in UFP mode. (Manish Chopra) [1663274]
- [netdrv] qed: Fix EQ full firmware assert. (Manish Chopra) [1663274]
- [netdrv] qed: Fix stack out of bounds bug (Manish Chopra) [1663274]
- [netdrv] qed: Fix system crash in ll2 xmit (Manish Chopra) [1663274]
- [netdrv] qed: Fix VF probe failure while FLR (Manish Chopra) [1663274]
- [netdrv] qed: Fix LACP pdu drops for VFs (Manish Chopra) [1663274]
- [netdrv] qed: Fix bug in tx promiscuous mode settings (Manish Chopra) [1663274]
- [netdrv] qede: Error recovery process (Manish Chopra) [1663274]
- [netdrv] qed: Add infrastructure for error detection and recovery (Manish Chopra) [1663274]
- [netdrv] qed: Revise load sequence to avoid PCI errors (Manish Chopra) [1663274]
- [netdrv] qed: Mark expected switch fall-through (Manish Chopra) [1663274]
- [include] qed: remove duplicated include from qed_if.h (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: Fix out of bounds index check in query pkey (Manish Chopra) [1663274]
- [netdrv] qed: Fix qed_ll2_post_rx_buffer_notify_fw() by adding a write memory barrier (Manish Chopra) [1663274]
- [include] qed: Fix qed_chain_set_prod() for PBL chains with non power of 2 page count (Manish Chopra) [1663274]
- [infiniband] infiniband/qedr: Potential null ptr dereference of qp (Manish Chopra) [1663274]
- [netdrv] qed: Fix an error code qed_ll2_start_xmit() (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "Dispalying" -> "Displaying" (Manish Chopra) [1663274]
- [netdrv] qede: Register l2 queues with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Expose the doorbell overflow recovery mechanism to the protocol drivers (Manish Chopra) [1663274]
- [netdrv] qed: Register light L2 queues with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Register slowpath queue doorbell with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Use the doorbell overflow recovery mechanism in case of doorbell overflow (Manish Chopra) [1663274]
- [netdrv] qed: Add doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qede - Add a statistic for a case where driver drops tx packet due to memory allocation failure. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "attnetion" -> "attention" (Manish Chopra) [1663274]
- [netdrv] qed: Add support for MBI upgrade over MFW. (Manish Chopra) [1663274]
- [netdrv] qede: Update link status only when interface is ready. (Manish Chopra) [1663274]
- [netdrv] qede: Simplify the usage of qede-flags. (Manish Chopra) [1663274]
- [netdrv] qed: Display port_id in the UFP debug messages. (Manish Chopra) [1663274]
- [netdrv] qed: Fix QM getters to always return a valid pq (Manish Chopra) [1663274]
- [netdrv] qed: Fix bitmap_weight() check (Manish Chopra) [1663274]
- [netdrv] drivers/net/ethernet/qlogic/qed/qed_rdma.h: fix typo (Manish Chopra) [1663274]
- [netdrv] qed: Fix reading wrong value in loop condition (Manish Chopra) [1663274]
- [netdrv] qed: Fix rdma_info structure allocation (Manish Chopra) [1663274]
- [netdrv] qed: Fix overriding offload_tc by protocols without APP TLV (Manish Chopra) [1663274]
- [netdrv] qed: Fix PTT leak in qed_drain() (Manish Chopra) [1663274]
- [netdrv] qed: Fix potential memory corruption (Manish Chopra) [1663274]
- [netdrv] qed: Fix SPQ entries not returned to pool in error flows (Manish Chopra) [1663274]
- [netdrv] qed: Fix blocking/unlimited SPQ entries leak (Manish Chopra) [1663274]
- [netdrv] qed: Fix memory/entry leak in qed_init_sp_request() (Manish Chopra) [1663274]
- [netdrv] qed: fix link config error handling (Manish Chopra) [1663274]
- [netdrv] qed: Fix static checker warning (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "transcevier" -> "transceiver" (Manish Chopra) [1663274]
- [netdrv] qed: Prevent link getting down in case of autoneg-off. (Manish Chopra) [1663274]
- [netdrv] qede: Check available link modes before link set from ethtool. (Manish Chopra) [1663274]
- [netdrv] qed: Add supported link and advertise link to display in ethtool. (Manish Chopra) [1663274]
- [netdrv] qed: Added supported transceiver modes, speed capability and board config to HSI. (Manish Chopra) [1663274]
- [netdrv] qed: Align local and global PTT to propagate through the APIs. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "Ireelevant" -> "Irrelevant" (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_ooo_submit_tx_buffers (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: Remove enumerated type qed_roce_ll2_tx_dest (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "b_cb_registred" -> "b_cb_registered" (Manish Chopra) [1663274]
- [netdrv] qed: Remove set but not used variable 'p_archipelago' (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_iwarp_parse_rx_pkt (Manish Chopra) [1663274]
- [netdrv] qed: Avoid constant logical operation warning in qed_vf_pf_acquire (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_roce_mode_to_flavor (Manish Chopra) [1663274]
- [netdrv] qed: Fix mask parameter in qed_vf_prep_tunn_req_tlv (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_set_tunn_cls_info (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "toogle" -> "toggle" (Manish Chopra) [1663274]
- [netdrv] net: qed: list usage cleanup (Manish Chopra) [1663274]
- [netdrv] net: qede: Use FIELD_SIZEOF directly instead of reimplementing its function (Manish Chopra) [1663274]
- [netdrv] qed: remove duplicated include from qed_cxt.c (Manish Chopra) [1663274]
- [netdrv] qed*: Utilize FW 8.37.7.0 (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: remove set but not used variable 'ctx' (Manish Chopra) [1663274]
- [netdrv] qed: Lower the severity of a dcbx log message. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "comparsion" -> "comparison" (Manish Chopra) [1663274]
- [netdrv] net_sched: remove list_head from tc_action (Manish Chopra) [1663274]
- [infiniband] qedr: Add user space support for SRQ (Manish Chopra) [1663274]
- [infiniband] qedr: Add support for kernel mode SRQ's (Manish Chopra) [1663274]
- [infiniband] qedr: Add wrapping generic structure for qpidr and adjust idr routines. (Manish Chopra) [1663274]
- [netdrv] qed/qede: qede_setup_tc() can be static (Manish Chopra) [1663274]
- [netdrv] qede: Ingress tc flower offload (drop action) support. (Manish Chopra) [1663274]
- [netdrv] qede: Add destination ip based flow profile. (Manish Chopra) [1663274]
- [netdrv] qed/qede: Multi CoS support. (Manish Chopra) [1663274]
- [netdrv] qede: qede_fp: Mark expected switch fall-through (Manish Chopra) [1663274]
- [netdrv] qed: qed_dev: Mark expected switch fall-throughs (Manish Chopra) [1663274]
- [netdrv] qed: Add Multi-TC RoCE support (Manish Chopra) [1663274]
- [netdrv] qed: Add DCBX API - qed_dcbx_get_priority_tc() (Manish Chopra) [1663274]
- [netdrv] qed: Make some functions static (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant functions qed_get_cm_pq_idx_rl (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant functions qed_set_gft_event_id_cm_hdr (Manish Chopra) [1663274]
- [netdrv] qede: Add driver callbacks for eeprom module query. (Manish Chopra) [1663274]
- [netdrv] qed: Add qed APIs for PHY module query. (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant pointer 'name' (Manish Chopra) [1663274]
- [iommu] iommu: Don't print warning when IOMMU driver only supports unmanaged domains (Jerry Snitselaar) [1707616 1694210 1689183]
- [iommu] iommu/vt-d: Check capability before disabling protected memory (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: fix sg->dma_address for sg->offset bigger than PAGE_SIZE (Jerry Snitselaar) [1694210 1694029]
- [iommu] iommu/amd: Fix NULL dereference bug in match_hid_uid (Jerry Snitselaar) [1677737 1694210]
- [iommu] iommu/vt-d: Fix NULL pointer reference in intel_svm_bind_mm() (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Remove unnecessary WARN_ON() (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Check identity map for hot-added devices (Jerry Snitselaar) [1694210]
- [iommu] iommu/dmar: Fix buffer overflow during PCI bus notification (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Fix memory leak in intel_iommu_put_resv_regions() (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: Fix amd_iommu=force_isolation (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Handle domain agaw being less than iommu agaw (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Use memunmap to free memremap (Jerry Snitselaar) [1694210]
- [iommu] amd/iommu: Fix Guest Virtual APIC Log Tail Address Register (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Fix NULL pointer dereference in prq_event_thread() (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: Return devid as alias for ACPI HID devices (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Free irqs in shutdown handler (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Move irq request past pm_runtime_enable (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Handle errors returned from PM framework (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: make sure TLB to be flushed before IOVA freed (Jerry Snitselaar) [1694210]
- [idle] intel_idle: Get rid of custom ICPU() macro (Alexander Beregalov) [1710976]
- [security] selinux: do not report error on connect(AF_UNSPEC) (Ondrej Mosnacek) [1707828]
- [security] selinux: Check address length before reading address family (Ondrej Mosnacek) [1707828]
- [scsi] scsi: core: add new RDAC LENOVO/DE_Series device (Maurizio Lombardi) [1700912]
- [infiniband] i40iw: Avoid panic when handling the inetdev event (Stefan Assmann) [1659180]
- [infiniband] cross-tree: phase out dma_zalloc_coherent() (Stefan Assmann) [1659180]
- [infiniband] infiniband: prefix header search paths with $(srctree)/ (Stefan Assmann) [1659180]
- [infiniband] i40iw: remove use of VLAN_TAG_PRESENT (Stefan Assmann) [1659180]
- [infiniband] RDMA/i40iw: Fix incorrect iterator type (Stefan Assmann) [1659180]
- [infiniband] infiniband: i40iw, nes: don't use wall time for TCP sequence numbers (Stefan Assmann) [1659180]
- [infiniband] i40iw: Reorganize acquire/release of locks in i40iw_manage_apbvt (Stefan Assmann) [1659180]
- [netdrv] i40e: Changed maximum supported FW API version to 1.8 (Stefan Assmann) [1659174]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Stefan Assmann) [1659174]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Stefan Assmann) [1659174]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Stefan Assmann) [1659174]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Stefan Assmann) [1659174]
- [netdrv] i40e: Memory leak in i40e_config_iwarp_qvlist (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix of memory leak and integer truncation in i40e_virtchnl.c (Stefan Assmann) [1659162]
- [netdrv] i40e: Use struct_size() in kzalloc() (Stefan Assmann) [1659162]
- [netdrv] i40e: Revert ShadowRAM checksum calculation change (Stefan Assmann) [1659162]
- [netdrv] i40e: missing input validation on VF message handling by the PF (Stefan Assmann) [1659162]
- [netdrv] i40e: Add support for X710 B/P & SFP+ cards (Stefan Assmann) [1659162]
- [netdrv] i40e: Wrong truncation from u16 to u8 (Stefan Assmann) [1659162]
- [netdrv] i40e: add num_vectors checker in iwarp handler (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix the typo in adding 40GE KR4 mode (Stefan Assmann) [1659162]
- [netdrv] i40e: Setting VF to VLAN 0 requires restart (Stefan Assmann) [1659162]
- [netdrv] i40e: add new pci id for X710/XXV710 N3000 cards (Stefan Assmann) [1659162]
- [netdrv] i40e: VF's promiscuous attribute is not kept (Stefan Assmann) [1659162]
- [netdrv] i40e: Introduce recovery mode support (Stefan Assmann) [1659162]
- [netdrv] i40e: print PCI vendor and device ID during probe (Stefan Assmann) [1659162]
- [netdrv] i40e: fix misleading message about promisc setting on un-trusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: update version number (Stefan Assmann) [1659162]
- [netdrv] i40e: remove out-of-range comparisons in i40e_validate_cloud_filter (Stefan Assmann) [1659162]
- [netdrv] i40e: Further implementation of LLDP (Stefan Assmann) [1659162]
- [netdrv] i40e: Report advertised link modes on 40GBase_LR4, CR4 and fibre (Stefan Assmann) [1659162]
- [netdrv] i40e: ShadowRAM checksum calculation change (Stefan Assmann) [1659162]
- [netdrv] i40e: remove error msg when vf with port vlan tries to remove vlan 0 (Stefan Assmann) [1659162]
- [netdrv] i40e: change behavior on PF in response to MDD event (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix for allowing too many MDD events on VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix misleading error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Able to add up to 16 MAC filters on an untrusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Report advertised link modes on 40GBASE_SR4 (Stefan Assmann) [1659162]
- [netdrv] i40e: The driver now prints the API version in error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Changed maximum supported FW API version to 1.8 (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove misleading messages for untrusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Update i40e_init_dcb to return correct error (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix for 10G ports LED not blinking (Stefan Assmann) [1659162]
- [netdrv] i40e: save PTP time before a device reset (Stefan Assmann) [1659162]
- [netdrv] i40e: don't allow changes to HW VLAN stripping on active port VLANs (Stefan Assmann) [1659162]
- [netdrv] i40e: Implement DDP support in i40e driver (Stefan Assmann) [1659162]
- [netdrv] i40e: Queues are reserved despite "Invalid argument" error (Stefan Assmann) [1659162]
- [netdrv] i40e: add tracking of AF_XDP ZC state for each queue pair (Stefan Assmann) [1659162]
- [netdrv] i40e: move i40e_xsk_umem function (Stefan Assmann) [1659162]
- [netdrv] i40e: fix WoL support check (Stefan Assmann) [1659162]
- [netdrv] i40e: fix i40e_ptp_adjtime when given a negative delta (Stefan Assmann) [1659162]
- [netdrv] i40e: fix XDP_REDIRECT/XDP xmit ring cleanup race (Stefan Assmann) [1659162]
- [netdrv] i40e: fix potential RX buffer starvation for AF_XDP (Stefan Assmann) [1659162]
- [netdrv] net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Stefan Assmann) [1659162]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Stefan Assmann) [1659162]
- [netdrv] i40e: clean up several indentation issues (Stefan Assmann) [1659162]
- [netdrv] i40e: increase indentation (Stefan Assmann) [1659162]
- [netdrv] i40e: update version number (Stefan Assmann) [1659162]
- [netdrv] i40e: remove debugfs tx_timeout support (Stefan Assmann) [1659162]
- [netdrv] i40e: check queue pairs num in config queues handler (Stefan Assmann) [1659162]
- [netdrv] i40e: Change unmatched function types (Stefan Assmann) [1659162]
- [netdrv] i40e: Add support FEC configuration for Fortville 25G (Stefan Assmann) [1659162]
- [netdrv] i40e: Limiting RSS queues to CPUs (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove umem from VSI (Stefan Assmann) [1659162]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Stefan Assmann) [1659162]
- [netdrv] i40e: extend PTP gettime function to read system clock (Stefan Assmann) [1659162]
- [netdrv] i40e: DRY rx_ptype handling code (Stefan Assmann) [1659162]
- [netdrv] i40e: fix kerneldoc for xsk methods (Stefan Assmann) [1659162]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Stefan Assmann) [1659162]
- [netdrv] i40e: suppress bogus error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Allow disabling FW LLDP on X722 devices (Stefan Assmann) [1659162]
- [netdrv] i40e: update driver version (Stefan Assmann) [1659162]
- [netdrv] i40e: Protect access to VF control methods (Stefan Assmann) [1659162]
- [netdrv] i40e: Replace strncpy with strlcpy to ensure null termination (Stefan Assmann) [1659162]
- [netdrv] i40e: Add capability flag for stopping FW LLDP (Stefan Assmann) [1659162]
- [netdrv] i40e: Use a local variable for readability (Stefan Assmann) [1659162]
- [netdrv] i40e: Replace spin_is_locked() with lockdep (Stefan Assmann) [1659162]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Stefan Assmann) [1659162]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Stefan Assmann) [1659162]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove unnecessary print statement (Stefan Assmann) [1659162]
- [netdrv] i40e: Use proper enum in i40e_ndo_set_vf_link_state (Stefan Assmann) [1659162]
- [nvme] nvmet: ignore EOPNOTSUPP for discard (Ewan Milne) [1696369]
- [tools] tools: bpftool: fix potential NULL pointer dereference in do_load (Ivan Vecera) [1708560]
- [tools] tools lib bpf: Provide wrapper for strerror_r to build in !_GNU_SOURCE systems (Ivan Vecera) [1708560]
- [tools] libbpf: Remove the duplicate checking of function storage (Ivan Vecera) [1708560]
- [tools] bpf: fix build error in libbpf with EXTRA_CFLAGS="-Wp, -D_FORTIFY_SOURCE=2 -O2" (Ivan Vecera) [1708560]
- [tools] tools: include reallocarray feature test in FEATURE_TESTS_BASIC (Ivan Vecera) [1708560]
- [tools] tools: bpftool: allow reuse of maps with bpftool prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: allow map reuse (Ivan Vecera) [1708560]
- [tools] tools: bpf: make use of reallocarray (Ivan Vecera) [1708560]
- [tools] tools: libbpf: move library error code into a separate file (Ivan Vecera) [1708560]
- [tools] tools: bpftool: reimplement bpf_prog_load() for prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: add extended attributes version of bpf_object__open() (Ivan Vecera) [1708560]
- [tools] tools: libbpf: recognize offload neutral maps (Ivan Vecera) [1708560]
- [tools] tools: bpftool: allow users to specify program type for prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: expose the prog type guessing from section name logic (Ivan Vecera) [1708560]
- [tools] tools: bpftool: add support for loading programs for offload (Ivan Vecera) [1708560]
- [tools] tools: bpftool: refactor argument parsing for prog load (Ivan Vecera) [1708560]
- [tools] selftests/bpf: add Error: prefix in check_extack helper (Ivan Vecera) [1708560]
- [tools] selftests/bpf: remove duplicated word from test offloads (Ivan Vecera) [1708560]
- [tools] tools: bpftool: deal with options upfront (Ivan Vecera) [1708560]
- [tools] tools: bpftool: add missing --bpffs to completions (Ivan Vecera) [1708560]
- [tools] tools: bpftool: drop unnecessary Author comments (Ivan Vecera) [1708560]
- [tools] tools: libbpf: don't return '.text' as a program for multi-function programs (Ivan Vecera) [1708560]
- [tools] tools: libbpf: restore the ability to load programs from .text section (Ivan Vecera) [1708560]
- [tools] tools: libbpf: allow setting ifindex for programs and maps (Ivan Vecera) [1708560]
- [tools] tools: libbpf: add section names for missing program types (Ivan Vecera) [1708560]
- [tools] tools: bpftool: use correct make variable type to improve compilation time (Ivan Vecera) [1708560]
- [scsi] scsi: lpfc: nvme: avoid hang / use-after-free when destroying localport (Dick Kennedy) [1588024]

* Thu May 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-98.el8]
- [xen] ALSA: xen: Introduce shared buffer helpers for page directory... (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Initialize completion for defer messages (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Remove duplicate assignment (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Fix uninitialized adev deref (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Add pre/post bank switch ops (Jaroslav Kysela) [1683051]
- [include] ALSA: soundwire: keep track of Masters in a stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Add support for multi link bank switch (Jaroslav Kysela) [1683051]
- [include] ALSA: soundwire: Handle multiple master instances in a stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Add support to lock across bus instances (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix acquiring bus lock twice during master release (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix incorrect exit after configuring stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix duplicate stream state assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix for Lenovo B50-70 inverted internal microphone bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix race between creating and refreshing sysfs entries (Jaroslav Kysela) [1683051]
- [include] ALSA: ASoC: uapi: fix sound/skl-tplg-interface.h userspace compilation errors (Jaroslav Kysela) [1683051]
- [include] ALSA: uapi: #include <time.h> in asound.h (Jaroslav Kysela) [1683051]
- [include] ALSA: timer: fix wrong comment to refer to 'SNDRV_TIMER_PSFLG_*' (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86/cpu: Sanitize FAM6_ATOM naming (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: don't select DPCM via simple-audio-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: don't select DPCM via audio-graph-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Corrected fixup for System76 Gazelle (gaze14) (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Avoid superfluous COEF EAPD setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixup headphone noise via runtime suspend (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Fix unused variable warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: toneport: Fix broken usage of timer for delayed execution (Jaroslav Kysela) [1683051]
- [sound] ALSA: aica: Fix a long-time build breakage (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support low power consumption for ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: update pcm hardware constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codec: hdac_hdmi: no checking monitor in hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: save PGA for mixer control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: save output volume for mixer controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: initialize setting when ramping volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: core: fix undefined nocodec reference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: xtensa: fix undefined references (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Propagate sof_get_ctrl_copy_params() error properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdea/realtek - Headset fixup for System76 Gazelle (gaze14) (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: add CometLake PCI IDs (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support low power consumption for ALC295 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: Fix an uninitialized variable compile warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Fix a compile warning with CONFIG_PCI=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Fix a compile warning at CONFIG_COMMON_CLK=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sound/soc/sof/: fix kconfig dependency warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: change trace level on iec control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: update pcm hardware constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98090: Fix restore of DAPM Muxes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: RT5677-SPI: Disable 16Bit SPI Transfers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Consider eld_valid when reporting jack event (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Read the pin sense from register when repolling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add reserved DMA memory support (Jaroslav Kysela) [1683051]
- [sound] ALSA: synth: emux: soundfont.c: divide by zero in calc_gus_envelope_time() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: Map BTN_0 to KEY_PLAYPAUSE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: add sof-rt5682 machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic:refine code style (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic: add DMIC support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: APL: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: IPC: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: intel: hda: add hw_params_upon_resume flag for hda stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: handle real stream interrupts only (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: store stream capabilities (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: simplify handling of IPC IRQ (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: ipc: use snd_sof_pcm_period_elapsed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: use snd_sof_pcm_period_elapsed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: PCM: add period_elapsed work to fix race condition in interrupt context (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-pcm: remove useless dependency on hdac_ext (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: set bus->idx as 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: set I2S slave before enabling DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: add SSP info to the chip info struct (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: add the SSP Host Device memory space (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: cnl: add pointer ops to use DPIB position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: topology: add support for stricter ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASOC: SOF: ipc: add support for stricter ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: add Kconfig option for strict ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: avoid Oops if DMA setup fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: stream is already locked in hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: remove redundant null checks of dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: skip hw_free on codec dai for which the stream is invalid (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix valid stream condition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: unlock the device on startup errors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Update the support rate list (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Use clk_round_rate to handle enabled bclk/wclk case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: Headphone Jack sense inverts on the LattePanda board (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Fix missing break in switch statement (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct region base typo in wm_halo_setup_algs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: fix spelling mistake "incompatble" -> "incompatible" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Use DSP ops pointers to stop watchdog in error handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix to use list_for_each_entry_safe() when delete items (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix return value check in sprd_mcdt_probe() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7213: fix DAI_CLK_EN register bit overwrite (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix kcontrols for effect widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: cache pdev->dev pointer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix potential uninitialized variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: add I2S2 control path from UL2 and UL3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: change supported formats of DL2 and UL1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: remove "model" attribute (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmix: fix object reference leaks in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs43130: fix a NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: fix a NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add Geminilake Realtek+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Make boards more available for compile test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_dma: Fix invalid license ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_i2s: Fix invalid license ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: tse850: Make some functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx: fix fiq dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: acp3x: Make acp3x_dai_i2s_ops static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Remove set but not used variable 'mclk_rate' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_micfil: Remove set but not used variable 'osr' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: Enable TDM support for DSP_A/B modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Configure wclk and bclk of master codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix build err while CONFIG_I2C set to module (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix spelling mistake "plalform" -> "platform" (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply the fixup for ASUS Q325UAR (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Register irq handler after the chip initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: usx2y: fix a double free bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: overwrite hdev type to HDA_DEV_ASOC (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix unregister device twice on ASoC driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: use dynamic buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix a memory leak bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: fix misuse of x (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - EAPD turn on later (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed Dell AIO speaker noise (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: select relevant machine drivers for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Make sure BDW based machine drivers build for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Build support for SOF core and Intel drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Kconfig: expose common option between SST and SOF drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add platform differentiation for APL and CNL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: add SKL+ platform DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add support for HDAudio codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA trace operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA stream operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add hda-bus support and initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA PCM operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA firmware loader (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PCI device support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add ACPI device support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA IPC mechanisms. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA DSP HW operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add HDA controller for Intel DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add APL/CNL HW DSP support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add legacy IPC support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add BDW HW DSP support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add BYT, CHT and BSW DSP HW support. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add utils (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add xtensa support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Nocodec machine driver support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PM support (Jaroslav Kysela) [1683051]
- [include] ALSA: ASoC: SOF: Add userspace ABI support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add firmware loader support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add DSP HW abstraction operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add DSP firmware logger support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add support for loading topologies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PCM operations support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add support for IPC IO between DSP and Host (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add driver debug support. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Sound Open Firmware KControl support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Sound Open Firmware driver core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: simplify dai driver initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Read pin switches conf from devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Add missing return 0 in remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: add asoc_simple_parse_pin_switches() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd fix irq mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: align quirk override handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: align quirk override handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: fix compilation warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Add support for runtime pm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Update is_slave_mode with correct value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum multi-channel data transfer support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: rt5682: initialize mutex before using (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: return the get_irq error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup 6ch settings to 8ch (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Handle the error from snd_usb_mixer_apply_create_quirk() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add new Dell platform for headset mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codec: hdac_hdmi add device_link to card device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: Remove set but not used variable 'stage_type' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: save fixed-up hw_params of BE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: tobermory: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: speyside: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: spdif: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: snow: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_wm8994*: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_wm8580: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_spdif: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smartq_wm8987: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx_uda134x: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec*: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c2412-i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: rx1950_uda1380: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx-i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c-i2s-v2: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: pcm: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: lowland: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: littlemill: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: jive_wm8750: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: idma: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: h1940_uda1380: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: dmaengine: Convert to SPDX License Indentifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: bells: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: arndale: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ps3: Remove set but not used variables 'start_vaddr' and 'pcm_index' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - add two more pin configuration sets to quirk table (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Don't refer to snd_cards array directly (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Drop superfluous id-uniquification behavior (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Fix card races between register and disconnect (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Fix racy addition/deletion of nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Correct unlock sequence at snd_seq_client_ioctl_unlock() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add quirk for Focusrite Scarlett Solo (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Initialize ext-bus-specific fields in snd_hdac_bus_init(), too (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Initialize power_state field properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Protect racy pool manipulation from OSS sequencer (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Simplify snd_seq_kernel_client_enqueue() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Cover unsubscribe_port() in list_mutex (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ALSA: seq: Protect in-kernel ioctl calls with mutex" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix missing regmap requirement (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix racy display power access (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: fix error handling when try_module_get() fails. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix master clock management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl: fix wrong number of channels (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Coding style fixes (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Simplify error path in snd_timer_open() (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix race of get-subscription call vs port-delete ioctls (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Protect in-kernel ioctl calls with mutex (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Remove superfluous irqsave flags (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Align temporary re-locking with irqsave version (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Use kvmalloc() for cell pools (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Revert active callback sync check at close (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add two more machines to the power_save_blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix spacing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: remove headset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: update module refcount if module_get_upon_open is set (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: conditionally increase module refcount on component open (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for the Teclast X98+ II (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for inverted jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm1133-ev1: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: phycore-ac97: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm030-audio-fabric: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: p1022_rdk: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: p1022_ds: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mx27vis-aic32x4: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc8610_hpcd: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_i2s: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_ac97: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_dma: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-ssi: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-spdif: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-pcm-fiq: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-mc13783: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-es8328: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmux: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-dma: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eukrea-tlv320: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-pcm: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: fix sai driver name initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Use the correct dobj to free enum control values and texts (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix OOB-reads from strlcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: change mic bias DAPM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Support synchronous mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix big-endian check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix endianness issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdmout: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: rework quirks settings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-frddr: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-toddr: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-fifo: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: remove link components before cleaning up card resources (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: add remove() callback for component driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l35: Disable regulators on driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add adc volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add support of master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add reset management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add regulator management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Avoid calling snd_compr_stop_error from WDT expiry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98357a: add missing supported rates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Add Playback PowerTune Controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Add Switch for Setting Common Mode Voltage (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Do not use stream buffer size before it is set (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: Mark RXFIFO_DATA as volatile and precious (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix spelling mistake "faied" -> "failed" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: Correct PDM_CTRL0 reg value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: adjust waterlevel in frame unit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: add compatible for rk1808 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: fixup pdm fractional div (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: optimize clear logic (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: add default regs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: using left justified store mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: change dma burst to 8 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: fix regmap_ops hang issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Update copyright and use SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix the smatch warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Change author's name (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add quirk for Tuxedo XC 1509 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Move to ACT_INIT state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix modular build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: Enable codec clock once and keep it enabled (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix build error in mt8183_da7219_max98357_dev_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: TS3A227: fix build error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Make use of local variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Remove redundant NULL check in wm_adsp_buffer_free (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: aic31xx_set_jack() can be static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Check for buffer in trigger stop (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer TravelMate B114-21 with ALC233 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eukrea-tlv320: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_utils: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Align tplg pointer increment across all kcontrols (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: support driver alias names for FE topology overrides (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum audio compress offload support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix SND_SOC_LOCHNAGAR_SC kconfig warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: set power_check callback for widgets that shouldnt be always on (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add button press detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add headphone/headset detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: skip missing substream while applying symmetry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [acpi] ALSA: ACPI / utils: Introduce acpi_dev_get_first_match_dev() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: remove set but not used variable 'dai_name' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add support for inverted jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Fix typo in comment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: fix spelling mistake: "missign" -> "missing" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Add machine driver with DA7219 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Add machine driver with TS3A227 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677-spi: Add ACPI ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add multi endpoint support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix Common Pins (Jaroslav Kysela) [1683051]
- [sound] ALSA: us122l: Use alloc_pages_exact() (Jaroslav Kysela) [1683051]
- [sound] ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers, take#2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Make snd_timer_close() really kill pending actions (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Check ack_list emptiness instead of bit flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Make sure to clear pending ack list (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Unify timer callback process code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: Fix kbuild failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: emux: Add support of loading GUS-patch (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix speakers on Acer Predator Helios 500 Ryzen laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Add Audio Mixer machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Add Audio Mixer CPU DAI driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: enable S24_LE format support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Only enable with common clock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Allow 192000 Sample Rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Remove mclk references (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Restructure set_dai_sysclk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Dynamically Determine Clocking (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Move aosr and dosr setting to separate functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Control clock gating with CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model BDIV divider in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model DAC/ADC dividers in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model CODEC_CLKIN in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model PLL in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Initialize private_value in snd_soc_dapm_new_dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: aloop: Support S24 sample formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Don't suspend stream in unrecoverable PCM state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix NULL pointer dereference in snd_soc_dapm_free_kcontrol (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sirf-audio: Remove redundant of_match_node call (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix incorrect extern (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the issue of 64 bits division (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Fix crash at suspend/resume after failed codec registration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Simplify alt firmware loading code (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix possible OOB access in PCM oss plugins (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of ASUS X430UN and X512DK with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset mic of ASUS P5440FF with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable ASUS X441MB and X705FD headset MIC with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: test memory allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: lochnagar: Add driver to support Lochnagar 2 sound card (Jaroslav Kysela) [1683051]
- [mfd] ALSA: mfd: lochnagar: Add support for the Cirrus Logic Lochnagar (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Properly Set Processing Blocks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mchp-i2s-mcc: add driver for I2SC Multi-Channel Controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: rename asoc_simple_card_xxx() to asoc_simple_() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: separate asoc_simple_card_parse_dai() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_card_init_priv() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_be_hw_params_fixup() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_dai_init() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_hw_param() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_shutdown() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_startup() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: share common priv for simple-card/audio-graph (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: add asoc_simple_debug_info() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Update DA7219 DAI clock name to align with codec updates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Expose BCLK and WCLK control through CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: fix channel swap issue when stream starts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_asrc: add constraint for the asrc of older version (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4270: Set auto-increment bit for register writes (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support for Acer Aspire E5-523G/ES1-432 headset mic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer Aspire Z24-890 with ALC286 (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: oss: Fix Spectre v1 vulnerability (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer AIO with ALC286 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: add mmap support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: fix debugfs warnings on entry creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: manage multiple prepare (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct some minor issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Don't use register read to determine slave/master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Break out clock setting into separate function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: jz4740: Depend on MIPS instead of MACH_JZ4740 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add WDT expiry IRQ handling support for Halo core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add HALO MPU fault logging (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add support for new Halo core DSPs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Reduce repititive code on mtk_regmap_update_bits. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Fix UBSAN warning. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out DSP specific operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out parsing of firmware ID header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Refactor firmware status reading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Move wm_adsp2_set_dspclk to CODEC drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Don't export wm_adsp2_lock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Shutdown any compressed streams on DSP watchdog timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add locking to wm_adsp2_bus_error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct handling of compressed streams that restart (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free link string in error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free stream_name of dai_drv (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Enforces runtime_resume after S3 and S4 for each codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Don't trigger jackpoll_work in azx_resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph: add graph_parse_mclk_fs() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph: rename graph_get_conversion() to graph_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add simple_parse_mclk_fs() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: rename simple_get_conversion() to simple_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: recording has no sound after booting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: fix jack type detection issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Check JD status when system resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: skip for i2s5 in mck_disable (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: use 8 byte header for IR context to get isochronous cycle (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add support MOTU 8pre FireWire (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: fix mismatch between snd_opl3_drum_switch definition and declaration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - add Lenovo IdeaCentre B550 to the power_save_blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_JD_NOT_INV quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add support for active-high jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: Make gpio property optional (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: dt-bindings: add regulator property to simple amplifier (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: simple-amplifier: remame dio2125 documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: use 'version' field of unit directory to identify model (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: add a check for request_region (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: add a check for ioremap_nocache (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: create tlv before soc_tplg_init_kcontrol (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support headset mode for New DELL WYSE NB (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support headset mode for DELL WYSE AIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: merge alc_fixup_headset_jack to alc295_fixup_chromebook (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: hdmi - add Icelake support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: automatic selecting BCLK in I2S master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the typo of function name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Fix clock configuration for 44100 sample rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the issue of widget with prefixed name (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - add more quirks for HP Z2 G4 and HP Z240 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed Headset Mic JD not stable (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer TravelMate X514-51T with ALC255 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: avoid build error without CONFIG_PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: usx2y: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Avoid NULL pointer dereference at snd_hdac_stream_start() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: axi-i2s: let both capture and playback be optional (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: src: Avoid a potential deadlock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix registers declaration in regmap (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: fix the issue of the widget with prefix name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: prevent snd_soc_dpcm use after free (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:intel:skl:fix a simultaneous playback & capture issue on hda platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:hdac_hda:use correct format to setup hda codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:soc-pcm:fix a codec fixup issue in TDM case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: fix davinci_mcasp_probe dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ams-delta: remove duplicate 'const' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: remove compat dma probing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: use default dai name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: improve channel capabilities handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: change trigger traces (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: add i2c dependency for SND_SOC_SDM845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Fix clang warning without CONFIG_PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: src: fix compiler warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix DAPM routes for capture stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: Fix probe deferral following prelink failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: avoid limiting params->msbits in hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix set_sync service (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix oversampling mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix race condition in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix exposed capabilities in spdif mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix iec958 controls indexation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ab8500: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix S/PDIF DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add quirk for MOTU MicroBook II (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd add loopback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic3x: fix reset gpio reference counting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: skip useless write in slave mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix race condition in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: remove useless callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix dma configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix stream count management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix 16 bit format support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix IRQ clearing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: fix dependency for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add Maxim98373 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: gen: fix SSI9 4/5/6/7 busif related register address (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: fix construction of PCM frame for capture direction (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use more identical mod_alias for Saffire Pro 10 I/O against Liquid Saffire 56 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Extend i915 component bind timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Improve logging messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add support for multiple compressed buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Refactor compress stream initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Reorder some functions for improved clarity (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out stripping padding from ADSP data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Fix an IS_ERR() vs NULL checking bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: sound card name from device tree (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX362FA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Prevent uninitialized variable use (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix of-node refcount unbalance in qcom_snd_parse_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix of-node refcount unbalance in apq8016_sbc_parse_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Fix of_node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Reduce click noise on Dell Precision 5820 headphone (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix of-node refcount unbalance in DAI-link parser (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Fix of-node refcount unbalance in fsl_ssi_probe_from_dt() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Allow compressed buffers in any memory region (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Update cached error state on trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: pcm186x: Fix energysense SLEEP bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: pcm186x: fix wrong usage of DECLARE_TLV_DB_SCALE() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix multiple "IIS multi" devices initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix secondary platform device unregistration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk: Add DAI links for Multi-Playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Add Geminilake Dialog Maxim machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Headset button support in broxton machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Rename hpvcc regulator supply to cpvdd (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau1977: Add support for setting MICBIAS via DT (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Potential small memory leak in dapm_cnew_widget() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Add missing DAPM routes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Make function 'wm8741_mute' static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: fix register setting issue in RIGHT_J mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: SoC: imx-sgtl5000: add missing put_device() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix missing of_node_put() at simple_dai_link_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix refcount underflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Ensure proper sample rate on pri/sec PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: remove set but not used variables 'mask, cr1' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free created components in tplg load error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Make some symbols static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: select dmic for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: fix sysclk_df type (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: fix TXCLK_DF mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Add support to disable on-chip PLL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Add runtime support for DSP_A and I2S modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Fix frame polarity for DSP_A format (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Set constraint to always have 32 sample bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Remove capture support for codecs without ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: fix spelling mistake "doens't" -> "doesn't" (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Expose sample resolution through proc interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Prevent potential NULL platform data dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Remove unused SND_DMAENGINE_PCM_FLAG_CUSTOM_CHANNEL_NAME flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Update TDM usage to be more flexible (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add support for master mode BCLK rate adjustment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to SPDX License Indentifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Comments clean up (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Change indentation in SAMSUNG_I2S_FMTS definition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Simplify pri_dai, sec_dai pointers usage (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add missing put_device() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: Specify DMA channel names through custom DMA config (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Add support for secondary CPU DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Get rid of a static spinlock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move quirks data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move IP variant data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Drop spinlock pointer from i2s_dai data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move SFR pointer to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: es1688: Remove set but not used variable 'hw' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Disable PC beep in passthrough on alc285 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Headset microphone and internal speaker support for System76 oryp5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cros_ec_codec: Make symbol 'cros_ec_dai' static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: make some functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Remove unused including <linux/version.h> (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move registers cache to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move opclk data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move core clk to the driver common data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Add widgets and routes for DPCM support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move clk supplier data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Restore support for the secondary PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Comment why read blocks when PCM is not running (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: remove new_mach_data field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: cnl-match.c: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: icl-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: hsw-bdw-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: glk-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: cht-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: byt-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: bxt-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: icl-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hsw-bdw-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hda-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cnl-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: byt-match.c: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to single component with multiple DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: dmaengine: Allow to specify custom DMA device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Extend use of chan_names provided in custom DMA config (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Improve of_node test in dmaengine_pcm_request_chan_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix prescaler setting for the secondary DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Use __printf markup to silence compiler (Jaroslav Kysela) [1683051]
- [sound] ALSA: tlv320aic32x4: delay i2c access by 1 ms after hardware reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd fix rx stream assign (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Set OSR mode in hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Add digital mute callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: PCM: check if ops are defined before suspending PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: use devm_kzalloc for all structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: use pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add clock select (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add soft reset on probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: set .ignore_module_refcount field in component (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: don't increase component module refcount unconditionally (Jaroslav Kysela) [1683051]
- [sound] ALSA: gpiolib: acpi: Introduce ACPI_GPIO_QUIRK_ONLY_GPIOIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: convert license header to SPDX (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-analog: add missing license information (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: regulator notifier registration should be managed (Jaroslav Kysela) [1683051]
- [sound] ALSA: i915/snd_hdac: I915 subcomponent for the snd_hdac (Jaroslav Kysela) [1683051]
- [base] ALSA: components: multiple components for a device (Jaroslav Kysela) [1683051]
- [documentation] ALSA: component: Add documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Revert capture stream behavior change in blocking mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix function name in kernel-doc comment (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Define snd_pcm_lib_preallocate_*() as returning void (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: fix up for snd_pcm_lib_preallocate_pages_for_all() API change (Jaroslav Kysela) [1683051]
- [sound] ALSA: SoC: stm32: i2s: manage clock power (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: Remove unnecessary const qualifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Add support for Cirrus CS35L36 Amplifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix implicit fb endpoint setup by quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add quirk for HP EliteBook 840 G5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: Use C++ style comments in header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: Kconfig: Show knob, and depend on MIPS || COMPILE_TEST (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4740: Add support for devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4740: Use SPDX license notifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: Prevent clk_get_rate() calls in atomic context (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Line Playback Volume, Line Boost Volume, Line Right, Line Left, Line Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add FM Playback Volume, FM Left, FM Right, FM Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic1 Playback Switch, Mic2 Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Merge sun4i_codec_left_mixer_controls and sun4i_codec_right_mixer_controls into sun4i_codec_mixer_controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic1 Boost Volume, Mic2 Boost Volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add sun7i_codec_controls, sun7i_codec_codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic Playback Volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add MIC2 Pre-Amplifier, Mic2 input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: fix spelling mistake "Deemphatize" -> "Deemphasize" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: fix semicolon.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: correct shift bit for ssiu9 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: Add jz4725b-codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup rsnd_ssi_master_clk_start() user count check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: harden use of lookup tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xtensa: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: txx9: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dwc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix out-of-bounds accesses to DAPM lookup tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Clean up proc file creations (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Move card id proc creation into info.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Minor optimization (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Drop unused snd_info_entry.card field (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcmcia: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Add standard helpers for card proc file entries (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: emux: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl4: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssm2602: switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: Add helper functions for component trigger/set_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: Clarify the intent of current compressed ops handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: remove some unnecessary NULL checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssm2602: Fix ADC powerup sequencing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Check for NULL widget in dapm_update_dai_unlocked (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: spi: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: sh: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: parisc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: atmel: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix build error without CONFIG_PCI (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Fix stop handling on compressed capture streams (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for new T+A USB DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Always register entries recursively (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Don't allow NULL device for memory allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4118: fix missing header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd: fix spelling mistake "offest" -> "offset" (Jaroslav Kysela) [1683051]
- [sound] ALSA: arm: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: unload physical dai link in remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: add SND_SOC_DOBJ_GRAPH type for dapm routes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: clear platform pointers on error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-asoc-card: fix object reference leaks in fsl_asoc_card_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add warnings for widget overwrite when adding route (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Only power up active channels from a DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix oops/use-after-free case with dai driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix use-after-free issue with dailink sname (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: add btcvsd driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: Add channel numbers to AIFs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup TDM Split mode check for CTU (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: synchronize connection check for simple-card/audio-graph (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup MIX kctrl registration (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: pass struct device to DMA API functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hal2: pass struct device to DMA API functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Serialize codec registrations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use a common helper for hp pin reference (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix lose hp_pins for disable auto mute (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Headset microphone support for System76 darp5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: remove a superfluous function declaration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum audio DMA platfrom driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: modify dapm route loading routine and add dapm route unloading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix memory leak in soc_tplg_dapm_widget_create (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Fix memory leak from soc_tplg_denum_create_texts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Remove widgets from dobj list (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Reduce number of dereferences when accessing dobj (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Use standard device registration for beep (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply ALC294 hp init also for S4 resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Record the current power state before suspend/resume calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: remove useless test (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed hp_pin no value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cros_ec_codec: Add codec driver for Cros EC (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: Documentation: Add google, cros-ec-codec (Jaroslav Kysela) [1683051]
- [maintainers] ALSA: MAINTAINERS: add maintainers for ChromeOS EC sub-drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix missing slimbus dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Cleanup DSD whitelist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: add slim support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add audio routings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add capture dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add playback dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add basic controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add support to wcd9335 codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt_rt298: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt_da7219_max98357a: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: broadwell: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: haswell: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add helper to change platform name for all dailinks (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: add support for Solid State Logic Duende Classic/Mini (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Variable "ret" in function rt5651_i2c_probe() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: add static inline fallbacks when CONFIG_ACPI=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Fix clocking calculations when not using the PLL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Implement the set_bclk_ratio interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use for_each_link_codecs() for dai_link codecs V2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Fixup build error for mt6358 (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix tight loop of OSS capture stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add Opus #3 to quirks for native DSD support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: add codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: add platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Allow soc_find_component lookups to match parent of_node (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use the common error path in __snd_pcm_lib_xfer() (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: Off by one in latter_handle_midi_msg() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: make const arrays static, reduces object code size (Jaroslav Kysela) [1683051]
- [sound] ALSA: proc: Avoid possible leaks of snd_info_entry objects (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Simplify proc file destruction (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Drop unused snd_pcm_substream.file field (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: comment cleanup about destination address of async transactions for MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Cleanup snd_pcm_stream_lock() & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Remove down_write() hack for snd_pcm_link_rwsem (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: More fine-grained PCM link locking (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Fix multi-CODEC setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: support rx MIDI functionality for Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-specific operation to fill transaction buffer with MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add model-dependent parameter for address to receive async transaction for MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: support tx MIDI functionality of Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add model-dependent parameter for address range to receive async transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: change prototype of handler for async transaction with MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Correct the setting while select ASRC clk for AD/DA filter (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: add driver flag for runtime PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: implement runtime suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: remove redundant clock enable API (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: add runtime PM callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: get clock handles early in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: runtime power management support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: rename to asoc_simple_card_canonicalize_platform() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use for_each_link_codecs() for dai_link codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add soc_cleanup_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: reduce if/else nest on soc_probe_link_dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: merge card resources cleanup method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add new snd_soc_flush_all_delayed_work() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add .num_platform for dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Avoid confusing loop in snd_pcm_unlink() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Make PCM linked list consistent while re-grouping (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Unify snd_pcm_group initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Call snd_card_unref() inside in_pcm_file() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add mute LED support for HP ProBook 470 G5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to parse of clock configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring for dump of sync status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to get clock status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to switch mode to fetch PCM frame (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to dump status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: obsolete proc node to leave one node (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: unify protocol layer for FF400/FF800 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: rename protocol layer for former models (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc.h: add explanation of legacy/modern style of dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Remove expensive print in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove error due to probe deferral (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-spdif: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: lower log level for potential probe deferral cases (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: put of nodes if finding codec fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix oops on re-probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add default pdata for i2s mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Set DAI format for dmic codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: select max98927 for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmux: change snprintf to scnprintf for possible overflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514-spi: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: change snprintf to scnprintf for possible overflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix PLL source register definitions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Don't defer probe on optional, NULL components (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Make snd_pcm_suspend() local static (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcmcia: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: arm: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: Move PCM suspend/resume code into trigger callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Suspend streams globally via device type PM ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Make snd_soc_find_component() more robust (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: fix init platform memory handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: parse AES audio parameters (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: Select REGMAP_MMIO to fix build error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: remove few unused variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4341: fix waring unused-function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: program stripe control for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: program stripe bits for controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add verbs for stripe control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add register offset for stripe control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add api to program stripe control bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skl: Fix display power regression (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix typo for ALC225 model (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: Hold client_mutex around soc_init_dai_link() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: use correct drvdata in snd_byt_cht_es8316_mc_remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: move the codec PLL configuration to _init (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: SND_SOC_DAPM_MICBIAS is deprecated (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add recalc_rate function to return DAI clock rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: MCLK should be enabled before DAI clocks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: defer card probe until all component is added to list (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Remove set but not used variable 'first_ch_bits' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix a mask wrong issue in snd_hdac_stream_start() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix mismatches for register mask and value in hdac controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Disable headset Mic VREF for headset mode of ALC225 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add unplug function into unplug state of Headset Mode for ALC225 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: fix CM6206 register definitions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: Variable "buf" in function rt274_jack_detect() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ADAU7002: Add optional delay before start of capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Potential NULL dereference in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirk for PoV TAB-P1006W-232 (v1.0) tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add support for jack-detect using an external GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirks module parameter (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Revert "Fix DMIC map headsetmic mapping" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add support for jack detect using an external GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add ACPI ID 10EC5640 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add quirk for PoV P1006W tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: update BSDSR/BSDISR handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sgtl5000: Allow SCLK pad drive strength to be changed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atom: fix a missing check of snd_pcm_lib_malloc_pages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable SPDIF driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: add SPDIF audio driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Kernel OOPS while entering DAPM standby mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Add MICFIL SoC Digital Audio Interface driver. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eliminate left-over from Raumfeld machine driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt298: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rl6437a: use __be32 for a __be32 buf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: store eq kcontrol byte in __be (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: use logical AND (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: fix endianness issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mt6351: remove unneeded variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tscs42xx.c: fix boolean test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: fix boolean assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98927: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5640: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rt286: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4271: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98383: fix boolean assignments to true/false (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5670: remove unused mux/mixer define (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: remove unused mux define (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: fix kernel doc descriptions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: remove unused constant variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98090: remove unused constant variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: declare trigger function as static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4458: Add support for AK4497 (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: fix a missing check of snd_ctl_add (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: fix check on snd_card_register (Jaroslav Kysela) [1683051]
- [sound] ALSA: ice1712: fix a missing check of snd_i2c_sendbytes (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: add a check of the status of snd_ctl_add (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxygen: initialize spdif_playback_enable to 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: virtuoso: add de-emphasis control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support Dell headset mode for New AIO platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix an out-of-bound read in create_composite_quirks (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Always check descriptor sizes in parser code (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Check mixer unit descriptors more strictly (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Avoid access before bLength check in build_audio_procunit() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Add support for GPIO mode of the pins (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Move context save/restore to runtime_pm callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: No need for IS_MODULE/BUILTIN check for pcm driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirks for ASUS MeMO Pad 7 (ME176C) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: sst: Fallback to BYT-CR if IRQ 5 is missing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: sst: Simplify is_byt_cr() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Add ACPI match table entry for ES8316 codec on BYTCR platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Set card long_name based on quirks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add input-map support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add external speaker mux support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add jack-detect support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add support for SSP0 (BYTCR) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Minor refactoring (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Sort includes alphabetically (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator: fixed: Let core handle GPIO descriptor (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator/gpio: Allow nonexclusive GPIO access (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator: fixed: Default enable high on DT regulators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add DAC mono mix switch mixer control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add jack-detect support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Variable "val" in function rt274_i2c_probe() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: fix error handling in xlnx_formatter_pcm_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add workaround for silence of rk3288 ACODEC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: support ACODEC for rk3328 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: reduce naming prefix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: cleanup DAI link loop method - step2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: cleanup DAI link loop method - step1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add link_info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add 1 CPU : 1 Codec support again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add asoc_simple_card_get_conversion() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: reduce naming prefix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: cleanup DAI link loop method - step2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: cleanup DAI link loop method - step1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add link_info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add 1 CPU : 1 Codec support again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable audio formatter driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: add pcm formatter platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: remove simple-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove audio-graph-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add asoc_graph_card_get_conversion() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: check "reg" property on asoc_simple_card_get_dai_id() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: boards: use snd_mask_set_format in all machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: simplify boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Baytrail: simplify boolean test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Baytrail: remove unneeded variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: assign booleans to true/false (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: remove unneeded semicolon (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: simplify boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: remove useless cast (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: enable MCLK in STANDBY (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: save model id directly in of_device_id.data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: make the driver visible in Kconfig (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4341: Add driver for CS4341 DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix recording no sound issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: atom: Make PCI dependency explicit (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: prevent potential divide by zero bugs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Fix a small memory leak (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Fix a NULL vs IS_ERR() bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Off by one in of_q6asm_parse_dai_data() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Fix a double unlock in pcm512x_digital_mute() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: change license header format style (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell/Broadwell: fix setting for .dynamic field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: Grammar s/the the/the/ (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dma-sh7760: cleanup a debug printk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: set jack only for a specific backend (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Revert DSP detection on legacy HD-audio driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: clear pending irq handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable the headset mic auto detection for ASUS laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: HD-Audio: SKL+: force HDaudio legacy or SKL+ driver selection (Jaroslav Kysela) [1683051]
- [sound] ALSA: HD-Audio: SKL+: abort probe if DSP is present and Skylake driver selected (Jaroslav Kysela) [1683051]
- [sound] ALSA: HDA: export process_unsol_events() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX391UA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: fix model-id of unit for Apogee Ensemble (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Use Xen common shared buffer implementation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: Kconfig: Remove the deprecated options (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: Merge davinci and omap directories (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add mute LED support for HP EliteBook 840 G4 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to handle model-specific registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for packet streaming on Fireface 800 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: allocate isochronous resources in mode-specific implementation (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to handle multiplier mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share helper function to switch fetching mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix for state to fetch PCM frames (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: use the same print format for 'without_header' tracepoints (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix wrong assignment for 'out_packet_without_header' tracepoint (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix wrong handling payload_length as payload_quadlet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add display_port_rx port routing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add support to Display port RX dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: qdafe: add support for display_port_rx (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Add support to compress offload (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: add support to MP3 format (Jaroslav Kysela) [1683051]
- [sound] ALSA: soc-compress: add support to snd_compr_set_runtime_buffer() (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: make use of runtime buffer for copy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add more platform granularity (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup prefix for snd_soc_codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup convert_rate/channel method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup mclk-fs method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: merge simple-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup prefix for snd_soc_codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup convert_rate/channel method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup mclk-fs method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: merge audio-graph-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fixup asoc_simple_card_get_dai_id() ID method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Invoke pcm_new() for all DAI-link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Implement the digital_mute interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: fix do_div warning in spdifin (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: add error logs on probe, remove dependency on NHLT (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: remove useless tests on HDaudio capabilities (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: stop probe if HDaudio capabilities don't exist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Harden DSP detection with PCI class/subclass info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add CFL-S support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add powersaving widgets for DAC and ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable i2s driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: Add i2s driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_rt5660: Add a new machine driver for kbl with rt5660 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg spdif input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-toddr: add support for spdifin backend (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Dereference pointer for memcpy sizeof in asoc_simple_card_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Fix SND_SOC_EUKREA_TLV320 build error on i.MX8M (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add support for Huawei WMI micmute LED (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix front speakers on Huawei MBXP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove RSND_REG_ from rsnd_reg (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for Fireface 800 with MIDI functionality only (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: localize a handler for MIDI messages on tx transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add driver data for register for MIDI high address (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share register for async transaction of MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for second optical interface for ADAT stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share helper function to get current sampling rate and clock source (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share status and configuration dump (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share some registers for status of clock synchronization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: care multi DPCM codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup "convert-rate/channels" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: care link / dai count (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: add dai-link support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - make pci_iounmap() call conditional (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi: Always set display_power_control for Intel HSW+ codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: Add missing display power-off at driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Make snd_hdac_display_power() void function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Properly free the display power at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Drop superfluous AZX_DCAPS_I915_POWERWELL checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Refactor display power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup asoc_simple_card_parse_daifmt() timing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: use cpu/codec pointer on simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fix build warning without CONFIG_OF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: add rt5663 codec select (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: fix the audio jack button remapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Point of View Mobii TAB-P1005W-232 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Prowise PT301 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX433FN/UX333FA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX533FD with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: ALC294 mic and headset-mode fixups for ASUS X542UN (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Refactoring PM code (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix reference to wrong register for clock configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix the mute LED regresion on Lenovo X1 Carbon (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Add copyright and module author (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add configuration for headset codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add TDM configuration for speaker (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix signal paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Calculate LRCLK divider (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Remove useless assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Enable headset button support for new codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add jack button support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add jack pointer and unsolicited event bits to callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed headphone issue for ALC700 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5660: Add a new ACPI match ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ak4104: move to GPIO consumer API (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: cs4270: move to GPIO consumer API (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: use dma_ops of parent device for acp_audio_dma (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: use DMA addr rather than CPU pa for acp_audio_dma (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for Chromebook Gnawty (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Remove direct OF name and type accesses (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4860G/Z6860G (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4660G (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support for Acer Aspire C24-860 headset mic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: ALC286 mic and headset-mode fixups for Acer Aspire U27-880 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added max98373_reset for stable amp reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: care multi DPCM codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: care link / dai count (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fixup asoc_simple_card_get_dai_id() counting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add missing TDM Split mode support for simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup mod ID for CTU regmap read/write (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: indicates Channel and Mode for debug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Add Tegra186 and Tegra194 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra - Probe up to 8 codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for Chromebook Clapper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove raumfeld machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix UAF decrement if card has no live interfaces in card.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for ICL (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix speaker output regression on Thinkpad T570 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: au8540: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add support for AMD Stoney Ridge (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add SMSL D1 to quirks for native DSD support (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix starvation on down_write_nonblock() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Call snd_pcm_unlink() conditionally at closing (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: compatible string as shortname (Jaroslav Kysela) [1683051]
- [platform] ALSA: platform/x86: thinkpad_acpi: Add audio mute LED classdev support (Jaroslav Kysela) [1683051]
- [platform] ALSA: platform/x86: dell-laptop: Add micmute LED trigger support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Support led audio trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: Don't disable pcm3168a when CONFIG_PM defined (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: introduce module_param wakeup_delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: introduce mode switch delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: sdm845: Create and setup jack in init callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: sdm845: Add board specific dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Implement configurable dismod handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Update PDIR (pin direction) register handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Clear TXSTAT register before activating serializers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add FW reply for MCLK/SCLK IPC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Make DSP replies more human readable (Jaroslav Kysela) [1683051]
- [drivers] ALSA: leds: trigger: Introduce audio mute LED trigger (Jaroslav Kysela) [1683051]
- [drivers] ALSA: leds: core: Introduce LED pattern trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup registering method for rsnd_kctrl_new() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support ALC300 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add auto-mute quirk for HP Spectre x360 laptop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix whitespace (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc.h: makes snd_soc_of_parse_audio_prefix() inline (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fix a NULL vs IS_ERR() check in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - fix the pop noise on headphone for lenovo laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: fix spelling mistake "Frequence" -> "Frequency" (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers" (Jaroslav Kysela) [1683051]
- [sound] ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: control: Consolidate helpers for adding and replacing ctl elements (Jaroslav Kysela) [1683051]
- [sound] ALSA: control: Fix race between adding and removing a user element (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Fix invalid snd_free_pages() at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: wss: Fix invalid snd_free_pages() at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - fix headset mic detection for MSI MS-B171 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add ASRock N68C-S UCC the power_save blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: Fix incorrect bit shift at AC97-SPSA control write (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: notify events of change of state for userspace applications (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: apply small refactoring to handle several type of event for hwdep interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: queue events for change of control surface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: add new hwdep ioctl command to get state image (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: pick up data of state from tx isochronous pakcets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-dmic: Add pm_qos handling to avoid overruns with CPU_IDLE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcpdm: Add pm_qos handling to avoid under/overruns with CPU_IDLE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Fix latency value calculation for pm_qos (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup define position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup typo SND_AUDIO_GRAPH_CARD (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup asoc_simple_card_parse_daifmt() timing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup "convert-rate/channels" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup "prefix" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup "prefix" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add snd_soc_of_parse_node_prefix() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: add VCC regulator widget (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Add support for cpvdd regulator supply (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: remove "option" from asoc_simple_card_of_parse_routing() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: tidyup asoc_simple_card_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: accept NULL parameter on asoc_simple_card_xxx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: remove asoc_simple_card_clk_register() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: makes rsnd_ssi_is_dma_mode() static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup rsnd_parse_connect_ssiu_compatible() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add support for Secondary MI2S interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Update slot_width for Quaternary TDM port (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use platform_data for machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: fix interface for Chromebook machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: acpi: define common interface for machine driver configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: acpi: fix: continue searching when machine is ignored (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: fix Kconfigs, make HDaudio codec optional (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic3x: Add support for CBM_CFS and CBS_CFM clocking modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Use device_type helpers to access the node type (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - fix AE-5 pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add new ZxR quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: clean up indentation, replace spaces with tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Fix error handling of regulator_set_load (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: fix spelling mistake "Inavlid" -> "Invalid" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: fix indentation issue with return statement (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320dac33: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: asihpi: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Convert a few more users to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Add regulator support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4118: Add support for AK4118 S/PDIF transceiver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Fix device reset-registers trigger value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: remove set but not used variable 'dma_buffer' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fixed build errors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Recalculate audio map forcely when card instantiated (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-abe-twl6040: Fix missing audio card caused by deferred probing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: fix memory leak of i2s_data on error return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add DT property for single-ended output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Rename output widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Set dai_link id to each dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: add missing route for ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: enable acp3x drivers build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x system resume pm op (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x runtime pm ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x tdm mode support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x i2s ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x pcm driver dma ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Interrupt handler changes for ACP3x DMA driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add ACP3x PCM platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: create ACP3x PCM platform device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: add ACP3.0 PCI driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: add ACP 3.x IP register header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Power down links before turning off display audio power (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: add Icelake support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out common init code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Fix dma-unsafe read of scratch registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add missing slave_config setting for I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: No need to initialize max_xx_thres when it is not used (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Remove redundant check for mcbsp->pdata (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Re-arrange files for core McBSP and Sidetone function split (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Move out the FIFO check from set_threshold and get_delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Simplify the mcbsp_start/_stop function parameters (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Clean up the interrupt handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Skip dma_data.maxburst initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Clean up dma_data addr initialization code (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: add support for APOGEE duet FireWire (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Call pci_iounmap() instead of iounmap() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add quirk entry for HP Pavilion 15 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Optimize for non-PCI configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use ring buffer for rsnd_mod_name() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: fix crash on module removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: oss: Use kvzalloc() for local buffer allocations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_ssi: Change to use DEFINE_SHOW_ATTRIBUTE macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add TDM Split mode support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add SSIU BUSIF support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: handle DPCM converted rate/chan under core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: move HDMI information from ssi.c to core.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use defined io_playback/io_capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: rename rsnd_runtime_is_ssi_xxx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove error check which never happen (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add quirk for APL RVP boards (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add SOF information for APL RVP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: remove GFP_ATOMIC, use GFP_KERNEL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: boards: fix Skylake typo (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use standard interface for Atom machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use standard interface for Hdaudio machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: change ac97 dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap: Remove unused machine driver for AM3517-evm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: remove read-only status register from snd_kcontrol_new (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak5558: Remove redundant snd_soc_component_read32 calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Fix the dai widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Only add routing once. (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Define registers for CM6206 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix incorrect clearance of thinkpad_acpi hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: Fix wrong MI2S SD line mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add quirk for boards using pmc_plt_clk_0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: rsnd_mod_name() handles both name and ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add .get_id/.get_id_sub (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: move .get_status under rsnd_mod_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: cleanup hw_constraint for LEFT_J/I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: On OMAP1 and OMAP2420 only 16bit format is supported (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: constify regulator_desc structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8825: remove unnecessary unlikely() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: mrfld: fix uninitialized variable access (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm97xx: fix uninitialized regmap pointer problem (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: constify snd_soc_ops structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix less than zero comparison on unsigned int (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: rename SND_SUNXI_ADDA_PR_REGMAP to SND_SUN8I_ADDA_PR_REGMAP (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Rip out the lpe audio runtime suspend/resume hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Fix runtime PM for hdmi-lpe-audio (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup clock start checker (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix oops w/ for_each_rtd_codec_dai_rollback() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix insufficient PCM rule for period/buffer size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ca0106: Disable IZD on SB0570 DAC to fix audio pops (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: fix to wait for releases of all ALSA character devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix noderef.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix master clock naming (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: add clock dependency for sai (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Actually fix microphone issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-i2s: move code from startup/shutdown hooks into pm_runtime hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm2000: Remove wm2000_read helper function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: fix mclk support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Log addresses as 8 digits in wm_adsp_buffer_populate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Rename memory fields in wm_adsp_buffer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add mclk support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: set sai as mclk clock provider (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: fix trivial checkpatch issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add support for hw_free on CODEC to CODEC links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: minor white space clean up (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c/cs8427: Fix int to char conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup SSICR::SWSP for TDM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: enable TDM settings for SSI parent (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add hw constraint for capture channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sta32x: Add support for XTI clock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: new codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra_sgtl5000: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: allow the sun8i-codec driver to be built on ARM64 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: Add new driver for Allwinner A64 codec's analog path controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec-analog: split regmap code into separate driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: Don't hardcode BCLK / LRCK ratio (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-i2s: Add compatibility with A64 codec I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: don't pass GFP_DMA32 to dma_alloc_coherent (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add 2 more models to the power_save blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add Kabylake Dialog+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add KBL Dialog Maxim I2S machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add SND_JACK_LINEOUT jack type (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: don't pass GFP_DMA32 to dma_alloc_coherent (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add I2S/Left_J TDM support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add hw constraint for channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add HW constraint for non RIGHT_J (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sta32x: set ->component pointer in private struct (Jaroslav Kysela) [1683051]
- [sound] ALSA: au88xx: Add fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti92xx-ad1848: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: oss: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: caiaq: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add missing entries to Kconfig (Jaroslav Kysela) [1683051]
- [sound] ALSA: isight: fix leak of reference to firewire unit in error path of .probe callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add mic quirk for the Lenovo G50-30 (17aa:3905) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort DHT Rot Pnt Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort max98373_bde_gain_tlv in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort BDE Limiter Thresh Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort Digital Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: enable mclk-fs on codec node (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use 32bit TDM width as default (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98988: add I2C dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: simplify cleanup process when failing to register sound card (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob/fireworks: simplify handling of local device entry table (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: release reference count of firewire unit in .remove callback of bus driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: block .remove callback of bus driver till all of ALSA character devices are released (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix the problem of the front MIC on the Lenovo M715 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix headphone pin config for ASUS G751 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix input effect controls for desktop cards (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add error checking in ca0132_build_controls() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up patch_ca0132() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix microphone inconsistency issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98988: make it selectable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98088: Add master clock handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8782: add support for regulators (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add ASUS G751 quirk model entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add quirk for ASUS G751 laptop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Use the standard fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: Add fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau1761: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add custom mixer status quirks for RME CC devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: update quirk for B&W PX to remove microphone (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/sigmatel - Disable automute for Elo VuPoint (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: A lightweight function to discard pending bytes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add fault detect recovery property to DT bindings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: enable and disable extclk if given (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: checking NULL vs IS_ERR() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: Add missing break in skl_tplg_get_token() (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: use managed-resource to maintain cache of stream formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: use managed-resource to maintain model-specific data (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireworks: use managed-resource to maintain response buffer (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use managed-resource to maintain data specific to M-Audio FW-1814/ProjectMix I/O (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: use managed-resource of fw unit device for private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Cannot adjust speaker's volume on Dell XPS 27 7760 (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: add PCM rules to obsolete PCM constraints based on LCM of SYT_INTERVAL (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR exit commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR 600 ohm gain control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Remove input select enum for ZxR (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR input/output select commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR DSP post-download commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR init commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DBpro hda_codec_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR quirks + new quirk check function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix surround sound with output effects (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix AE-5 control type (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix mismatch for register mask and value in ext controller. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: qdsp6: remove duplicated include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9712: fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: add SND_SOC_I2C_AND_SPI dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: avoid AC97_BUS build warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils: Rename dummy_dma_ops to snd_dummy_dma_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98088: add OF support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add a MIC pre. route (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_component_dais() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_component() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup SSI clock during suspend/resume modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: qdsp6: remove duplicated include from q6adm.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tidyup for_each_card_prelinks() dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Remove the boost volume in the beginning of playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_dpcm_be() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_dpcm_fe() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_comp_order() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_components() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_rtds() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_links() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_prelinks() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rename for_each_rtd_codec_dai_reverse to rollback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: convert for_each_rtd_codec_dai() for missing part (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 exit function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 specific controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add input selection commands for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add output set commands for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_alt_out_select (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DSP setup functions for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Merge post-dsp functions + cleanup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change firmware name and usage (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 regular init setup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 pre-init and ca0113 functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change ca0132_mmio_init for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Set AE-5 bools and select mixer (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add pincfg for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add quirk for Sound BlasterX AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Define new verbs and control params (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Refine indentations and constify snd_pcm_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix the audio-component completion timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677-spi: Drop unused GPIO include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Minor code modification (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix capture unstable in beginning for some runs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix the boost volume at the begining of playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Update calibration function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Remove HP volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Improve HP performance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: remove redundant include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514-spi: Get the period_bytes in the copy work to make sure the value correctly (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add snd_soc_is_matching_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: manage platform name under snd_soc_init_platform() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: remove duplicated include from q6asm-dai.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hisilicon: fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8328: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireworks: fix memory leak of response buffer at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak of discovered stream formats at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak for model-dependent data at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: fix memory leak for M-Audio FW1814 and ProjectMix I/O at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Enable runtime PM only for discrete GPU (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-digi00x: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0m: Register irq handler after register initializations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix implicit definition of pci_iomap() on SH (Jaroslav Kysela) [1683051]
- [sound] ALSA: don't call skl_init_chip() to reset intel skl soc (Jaroslav Kysela) [1683051]
- [sound] ALSA: enable interrupt after dma buffer initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ASoC: Intel: Skylake: Acquire irq after RIRB allocation" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove dai->driver NULL check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to card rebind (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: remove unneeded static set .owner field in platform_driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add missing INTERLEAVED PCM attribute (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove unused num_dai_links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: avoid nested code on soc_remove_dai() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5668: remove empty rt5668_i2c_remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Fix UBSAN warning at snd_soc_get/put_volsw_sx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: switch to new ac97 bus support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix simultaneous playback and capture on different channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: fix possible info leak to userspace on SNDRV_EMU10K1_IOCTL_INFO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add missing return value check for snd_soc_dapm_new_dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: skl-topology: Use kmemdup to replace kzalloc + memcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: q6core: Use kmemdup to replace kzalloc + memcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: txx9: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nuc900: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tscs454: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5668: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: bcm: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel_ssc_dai: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Ensure reset bit is cleared before configuring (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: clean up a return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix a couple uninitialized ret variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix memory leak in ff400_switch_fetching_mode() (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use address returned by kmalloc() instead of kernel stack for streaming DMA mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Update hardware pointer before start capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: usleep_range() needs include/delay.h (Jaroslav Kysela) [1683051]
- [sound] ALSA: regmap: split up regmap_config.use_single_rw (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: Limit sampling rates at dai creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Avoid uninitialised variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sgtl5000: avoid division by zero if lo_vag is zero (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: don't use p for dev_dbg() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: don't fallback to PIO mode when -EPROBE_DEFER (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: adg: care clock-frequency size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: gen: use tab instead of white-space (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: remove redundant check for !port condition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move CODEC to CODEC params from the widget to the runtime (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add support for multi-CODEC CODEC to CODEC links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move connection of CODEC to CODEC DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Cosmetic tidy up of snd_soc_dapm_new_control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move error handling to snd_soc_dapm_new_control_unlocked (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_link_codecs() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add overflow detection support (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: Cleanup indirect PCM helper usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: rme32: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix several mismatch for register mask and value (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Convert to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Don't schedule DAPM work if already in target state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Add driver for PROTO Audio CODEC (with a WM8731) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: merge .nolock_start and .prepare (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: Support to init different BUSIF instance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: Support BUSIF other than BUSIF0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rsnd: dma: Calculate PDMACHCRE with consider of BUSIF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rsnd: dma: Calculate dma address with consider of BUSIF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssi: Check runtime channel number rather than hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssi: Fix issue in dma data address assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove is_play parameter from hw_rule function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for 8 bit S8 format (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for the DSP_A/DSP_B formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for 16/24 bit slot widths (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add warning message to rsnd_kctrl_accept_runtime() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup not to call clk_get/set under non-atomic (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Initialize allocated buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add short circuit detection support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix soc-core.c kernel-doc warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: q6routing: initialize data correctly (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Add channel fault reporting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Save last fault register even when clear (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Print full register name in error message (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: remove dai_link compatible code for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use snd_soc_dai_link_component for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: remove dai_link compatible code for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: use simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: use simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add a S/PDIF enable switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add native 32bit I2S transport (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: SOC_SINGLE register value error fix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: tas5720: add TAS5722 TDM slot width setting support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: tas5720: add TAS5722 specific volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Add support for FIFO usage caused delay reporting (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix cancel_work_sync() stall from jackpoll work (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Clean up jackpoll_ms option handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg pdm input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: add DT module alias (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: add Kconfig prompt for the generic dmic codec. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau17x1: Unused exported functions changed to internal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Improve legibility of if-statements (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Improve stylistics of file comments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: tse850: switch to SPDX license identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Change MCLK to 48Mhz (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Set constraints for DMIC and MAX98357a codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht-bsw-rt5672: Add key-mappings for the headset buttons (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add quirk for Thinkpad 8 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5670: Add quirk for Thinkpad 8 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau17x1: Implemented safeload support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sigmadsp: safeload should not have lower byte limit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: add asoc extension for legacy HDA codec drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: use hda_bus instead of hdac_bus (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: add HDA BE DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: use HDAudio if ACPI enumeration fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Machine driver for SKL+ w/ HDAudio codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add table for HDA-based platforms (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: move hda_codec.h to include/sound (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8804: Add ACPI support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Update calibration function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Change DAC/ADC volume scale (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added 10ms sleep after amp software reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdm: restrict formats depending on slot width (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-fifo: report interrupt request failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: imply clock and reset controllers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: Properly initialise hw->rate_max (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Don't fail creating new DAPM control on NULL pinctrl (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Remove clock framework ifdefs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Convert to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel_hdmi: Use the new non-cached allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Use the new non-cached allocation for 440MX workaround (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Remove substream allocation/free ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Use new non-cached allocation for non-snoop mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Check the non-cached stream buffers more explicitly (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Add non-cached buffer type (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Simplify snd_malloc_dev_pages() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Don't align the size to power-of-two (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Do error checks at creating system ports (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: add error check in snd_seq_system_client_init() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: signedness bug in snd_pcm_plug_alloc() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdspm: fix spelling mistake "Initializeing" -> "Initializing" (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Return 0 when size < start_threshold in capture (Jaroslav Kysela) [1683051]
- [kvm] ALSA: treewide: correct "differenciate" and "instanciate" typos (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix HP Headset Mic can't record (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix unbalanced pm_runtime_enable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix check of pm_runtime_get_sync failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix device initialization in the compat layer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514: Fix the issue of the delay volume applied again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added speaker FS gain cotnrol register to volatile. (Jaroslav Kysela) [1683051]
- [sound] ALSA: update dell-wmi mic-mute registration to new world order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix NULL pointer deference on CODEC to CODEC DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Fix discarding the unsubscribed output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Acquire irq after RIRB allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9712: fix replace codec to component (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirks for 2 more devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adav80x: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add delays to capture path to remove DC offset noise (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add exit commands for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change mixer controls for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D input and output select commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DSP setup defaults for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D startup functions and setup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add bool variable to enable/disable pci region2 mmio (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add quirk ID and enum for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add alt_functions unsolicited response (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_init function. (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Create mmio gpio function to make code clearer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Make DSP name configurable by codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Declare firmware controls from codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added software reset register to readable registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct DSP pointer for preloader control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677: Fix initialization of rt5677_of_match.data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: make BE and FE order inline with dpcm (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel_hdmi: remove redundant variable cfg_val (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Set delay value for the capture case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Modified DMA pointer for capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Make ACP->SYSMEM DMA non circular (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8994: Fix missing break in switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add SLIM tx AIF_IN dapm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: remove unused header files from common.h (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: remove unused header files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: remove unused header files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: make common.c as proper module (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8903: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da9055: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm5100-tables: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7213: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: twl6040: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8996: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4270: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8990: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tda7419: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5631: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9850: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: fix wrong copy to rx parameters for Alesis iO26 (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add mute LED quirk for HP Spectre x360 (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq_oss: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-dmic: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcpdm: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-i2s: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: fix memory leak (Jaroslav Kysela) [1683051]
- [sound] ALSA: synth: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: fix spelling mistake "acumulator" -> "accumulator" (Jaroslav Kysela) [1683051]
- [sound] ALSA: es18xx: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti9xx: mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti92x: mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: galaxy: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt: Use refcap device for mono recording (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: remove support for card rebind using component framework (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: remove auto rebinding (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: remove auto rebinding (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix unmet dependency warning for SND_SOC_SDM845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8994: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9081: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8995: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8962: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8996: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8960: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8955: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5640: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8961: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix a typo (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix invalid use of sizeof in parse_uac_endpoint_attributes() (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Drop unused 64bit division macros (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Use no intrruptible mutex_lock (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix leftovers at probe error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Remove dead codes (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Minor cleanup of MIDI event parser helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm: Use delay set in component pointer function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix build due to CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: remove redundant pointer 'urb' (Jaroslav Kysela) [1683051]
- [sound] ALSA: sonicvibes: remove redundant pointer 'dir' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ens137x: remove redundant array pcm_devs (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: remove redundant variable attn (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs5535audio: remove redundant pointer 'dma' (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: remove redundant variable max_streams (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: remove redundant pointers 'priv' and 'rtd' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8540: remove redundant variable osrate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: add sdm845 sound card support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Add support to parse common audio device nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add support to wcd9335 codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Operate UAC3 Power Domains in PCM callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add UAC3 Power Domains to suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: AudioStreaming Power Domain parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Initial Power Domain support (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Use READ_ONCE/WRITE_ONCE() macros (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Offload the output event processing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: change functions to static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: add support for multichannel output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sirf: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra_alc5632: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Kconfig: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4613: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7210: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4554: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4642: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8988: fix typo in rate constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: i2s: Fix typo/broken macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi: Use single mutex unlock in error paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Turn CX8200 into D3 as well upon reboot (Jaroslav Kysela) [1683051]
- [sound] ALSA: ctxfi: cthw20k2: Replace mdelay() with msleep() and usleep_range() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ALSA:: ctxfi: cthw20k1: Replace mdelay() with msleep() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: quirks: Replace mdelay() with msleep() and usleep_range() (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp_modem: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: bt87x: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: maestro3: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0m: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: lola: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: riptide: Properly endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Proper endian notations for BDL pointers (Jaroslav Kysela) [1683051]
- [sound] ALSA: trident: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ymfpci: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen: Use standard pcm_format_to_bits() for ALSA format bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix PCM format bit calculation (Jaroslav Kysela) [1683051]
- [sound] ALSA: wss: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: Fix PCM format notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: au88x0: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: ad1816a: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: riptide: Fix PCM format type conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix implicit PCM format type conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: virmidi: Fix too long output trigger loop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Use standard pcm_format_to_bits() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Declare PCM format with snd_pcm_format_t (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Use snd_mask_set_format() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix interval evaluation with openmin/max (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Add snd_mask_set_format() helper for standard usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Fix snd_pcm_format_t handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Use int for format bit position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Fix missing __user prefix in copy_user callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: zte: Fix incorrect PCM format bit usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: align axg card driver with DT bindings documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: use IRQ_RETVAL in the fifo irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix build warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add a fix voltage regulator for DA7219 and ADAU7002 (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Fix missing PAGE_SIZE definition (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: declare snd_sgbuf_aligned_pages() unconditionally (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Fix missing __force annotation for user/kernel pointer cast (Jaroslav Kysela) [1683051]
- [sound] ALSA: korg1212: Add __force annotation to cast in user-copy callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use standard lower_32_bits() and upper_32_bits() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Declare the common variable in header file (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: Declare common variables properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix a sparse warning about snd_ctl_elem_iface_t (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Use NULL instead of 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Use NULL instead of 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Fix the default sample sizes (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Add missing __iomem annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix multiple definitions in AU0828_DEVICE() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for Encore mDSD USB DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs5535audio: Fix invalid endian conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: vxpocket: Fix invalid endian conversions (Jaroslav Kysela) [1683051]
- [sound] ALSA: vx222: Fix invalid endian conversions (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix poll() error return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: fix widget handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: fix inversion between __iowrite32 and __ioread32 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: simplify iomem address and casts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: make sst_dma functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: BDL definitions should be __le32 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: fix endianness handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5631: add Volume to the name of volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_utils: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_asrc: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-asoc-card: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to snd_soc_dai_get_channel_map() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514: Fix the issue of the delay volume applied (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-spdifout: select SND_PCM_IEC958 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/i915: Allow delayed i915 audio component binding (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Generic DSD detection for Thesycon-based implementations (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Don't exceed over the requested size (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: catch invalid timer object creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove clock divider and pll setup from zylonite and magician (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg sound card support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: export snd_soc_of_get_slot_mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm input driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm output driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm interface driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm formatter base driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: improve goto error label (Jaroslav Kysela) [1683051]
- [usb] ALSA: powerpc/ps3: Set driver coherent_dma_mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the "Connect Tablet 9" tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirk table entries for various devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add mono speaker quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add IN2 input mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Set OVCD limit for VIOS LTH17 to 2000uA (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix using the wrong GPIO for the ext-amp on some boards (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add IN3 Boost volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Parse HOST_BUFFER controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Allow up to 8 channels for voice control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Take prefix into account in control name length (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct algorithm list allocation size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Ensure DSP boot work complete before preloader_put return (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Allow changing from a bad sample rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg spdif output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg toddr driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg frddr driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg fifo base driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: Add documentation for power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: remove component fw related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to card re-bind using component framework (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Add __force to cast in snd_pcm_lib_read/write() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Nuke snd_pcm_lib_mmap_vmalloc() (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Use kvmalloc() for buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Minor code refactoring (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Simplify error paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Tidy up coding styles (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Make audio component support more generic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/i915: Associate audio component with devres (Jaroslav Kysela) [1683051]
- [sound] ALSA: drm/i915: Split audio component to a generic type (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu8000: Use swap macro in snd_emu8000_sample_new (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1_patch: Use swap macro in snd_emu10k1_sample_new (Jaroslav Kysela) [1683051]
- [gpu] ALSA: vga_switcheroo: set audio client id according to bound GPU id (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: use PCI_BASE_CLASS_DISPLAY to replace PCI_CLASS_DISPLAY_VGA (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Tidy up logic for Processing Unit min/max values (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Unify virtual type units type to UAC3 values (Jaroslav Kysela) [1683051]
- [include] ALSA: usb-audio: Add support for Processing Units in UAC3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Processing Unit controls parsing in UAC2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for Selector Units in UAC3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: For capture have interrupts on I2S->ACP channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Send correct channel for configuring DMA descriptors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add GLK Realtek Maxim I2S machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix routing (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: remove redundant pointer 'ins' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ali5451: remove redundant pointer 'codec' (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: remove redundant pointer runtime (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: remove redundant pointer private_data (Jaroslav Kysela) [1683051]
- [sound] ALSA: es1688: remove redundant pointer chip (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: remove redundant pointer opl3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: off by one in routing_hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: fix a range check in of_q6afe_parse_dai_data() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: allow soc-core to pick up name prefixes from component nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: add rate merge to the BE stream merge (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: rework runtime stream merge (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix snd_interval_refine first/last with open min/max (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Reporting button presses (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Disable jack-detect over suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add button press support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Allow disabling jack-detect by calling set_jack(NULL) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Fix workqueue cancel vs irq free race on remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add support for externar amplifier enable GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Move getting of codec_dev into probe() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove is_valleyview helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Lenovo Miix2 8 tablet (Jaroslav Kysela) [1683051]
- [dma] ALSA: dmaengine: add support for reporting pause and resume separately (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau171x1: Connect playback DAI to the DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: make SND_PXA_SOC_SSP depend on PLAT_PXA (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: replace "p" with "pK" (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Allow drivers to set R/W wait time. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: add support for an external clock in devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: cmd: Add missing newline to debug message (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: Use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Do not overwrite slim dai num_channels (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add slim rx routings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add support to slim tx dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: Add missing slimbus capture ports (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sti: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8825: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: do not close port if its not opened (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: do not close port if its not opened (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use snd_pcm_stop_xrun() for xrun injection (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: trace XRUN event at injection, too (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Allow topology to override machine driver FE DAI link config. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel-i2s: Remove unnecessary audio PLL clock (aclk) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: add support for the es7154 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: correct required power supplies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Simplify trigger handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Reset bytescount when starting transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Do not generate interrups for every captured sample (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix Capture DMA channel names (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Always subtract bytescount (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Always stop ch2 first (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7241: add es7241 codec support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add button detection mode control (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-midi: use irqsave() in USB's complete callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: caiaq: audio: use irqsave() in USB's complete callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: Add VDD and AVDD power supplies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: check if mclk rate is valid (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: remove 64kHz rate from the supported rates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: remove .set_pll() and .set_clkdiv() callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: select SND_PXA2XX_LIB for drivers that depend on it (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ac97: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-generic-dmaengine-pcm: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-compress: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-topology: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dapm: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-devres.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-jack.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dpcm.h: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-ops.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dai.h: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-io.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: snd-aoa: add of_node_put() in error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mt6797: sub dai use list_head (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: sub dai use list_head (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: make SND_PXA2XX_SOC_I2S selectable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove bindings from pxa2xx-pcm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: provide PCM ops for ssp, i2s and ac97 components (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa2xx-pcm-lib: fix indenting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: move some functions to pxa2xx-lib (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: clean up function names in pxa2xx-lib (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fold pxa2xx-pcm into its only user, pxa2xx-ac97 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove the dmaengine compat need (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Don't fall back to generic when i915 binding fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: don't merge format from invalid codec dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: extend channel merging to the backend cpu dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: qdafe: fix some off by one bugs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: improve runtime update predictability (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add AZX_DCAPS_PM_RUNTIME for AMD Raven Ridge (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: add extended ops in the hdac_bus (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: remove memory allocation from snd_hdac_ext_bus_device_init (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: split snd_hda_codec_new function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: ext: add wait for codec to respond after link reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_driver, use hdac_driver instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_bus and use hdac_bus instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_device and use hdac_device instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Move in_pm accessors to HDA core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas517x: add tas5707 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifer: add simple-amplifier compatible (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: rename dio2125 to simple-amplifer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Sort DMI table entries alphabetically (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_HP_LR_SWAPPED quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Simplify card long-name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix DMIC map headsetmic mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix IN1 map headsetmic mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove IN2 input mappings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix IN1_IN2_MAP quirk not being logged (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Change default input map from in2 to in1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_DEFAULT_QUIRKS define (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Kill snd_hda_codec_update_cache() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC882 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC262 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC268 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC259 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC662 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: Fix references to Documentation/.*/MultiSound (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: remove unused struct q6asm member (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add proper error check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: remove redundant owner assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6adm: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils: Fix unregistration order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cx20442: Don't ignore regulator_get() errors. (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply PRE_PROBE fixup after ALC269 codec variant setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Use standard verb containers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Simplify control management (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Rewrite with error goto (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/cirrus - Simplify creation of new controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/conexant - Clean up beep code (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common helper for creating beep controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common helper for creating ALC268 beep controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common GPIO mask for ALC660VD ASUS fixup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify Dell XPS13 GPIO handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Convert some manual GPIO setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify mute LED GPIO handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify alc885_fixup_macpro_gpio() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Consolidate gpio_data and gpio_led (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add GPIO data update helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Manage GPIO bits commonly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Allow skipping spec->init_amp detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: add codecs devicetree binding (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm: DPCM cares BE channel constraint (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Configure channel 1 or channel 0 for capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Change codec to channel link as per hardware redesign (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: remove redundant check of PLL ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt1305: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: fix missing rename from 'reef' to 'sof' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify alc269_fixup_hp_line1_mic1_led() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Sanity check of unexpected cap_sync_hook override (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/sigmatel - Use common helper for mic mute LED (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Allow multiple ADCs for mic mute LED controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/conexant - Use the mic-mute LED helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use the mic-mute LED helper for HP and others (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Use the common helper for thinkpad_acpi mic mute LED handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Move mic mute LED helper to the generic parser (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: rename 'reef' to 'sof' in ACPI matching table (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: Set compressed IRQ to a wake source (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Simplify handling of alg offset and length (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add support for Motu Traveler (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: cancel chunk alignment for protocol version 2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add a flag for AES/EBU on XLR interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add a flag for chunks for main 1/2 out (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: suppless consumption for unused element of array in stack (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: Tidy up open/hw_params handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: fix copy/paste issue with SOF/broadwell topology file (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add entries for SOF-based machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add firmware/topology information for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add Geminilake Dialog+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: move SKL+ codec ACPI tables to common directory (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: cleanup before moving ACPI tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: broxton: reduce machine name for bxt_da7219_max98357a (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: add fe_ops for kbl Audio Capture Port (Jaroslav Kysela) [1683051]
- [sound] ALSA: ARM: pxa: change SSP DMA channels allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: stop using get_seconds() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ctxfi: use enum type CT_SUM_CTL where appropriate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ice1724: remove unused array (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Fix Acer Iconia 8 over-current detect threshold (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Nuvison/TMax TM800W560 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: add devicetree support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: PCM1789: unconditionally flush work (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add rt5682 codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Add headphone auto switching (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Remove Playback/Capture in names (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Add mic bias boost control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4458: make structure soc_codec_dev_ak4458 static const (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak5558: make two structures static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: twl6040: make pointer dmic_codec_dev static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: set card as device drvdata (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add rsnd_daidrv_get() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add hp and mic detect gpios same as simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: move hp and mic detection to soc_card probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: move hp and mic detect gpios from simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Chuwi Vi10 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt1305: Use ULL suffixes for 64-bit constants (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add config for rockchip dmaengine pcm register (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: put device_node on remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add iec958 controls support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add NULL pointer check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: SSI parent cares SWSP bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: has .symmetric_rates if SSIs are sharing WS pin (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh7760-ac97: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dma-sh7760: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: migor: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: siu: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hac: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Add callback for DAPM route load/unload (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Give more data to clients via callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix potential DAI widget pointer deref when linking DAIs (Jaroslav Kysela) [1683051]
- [fs] gfs2: Fix loop in gfs2_rbm_find (v2) (Andreas Grunbacher) [1690483]
- [fs] gfs2: Rename bitmap.bi_{len => bytes} (Andreas Grunbacher) [1690483]

* Wed May 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-97.el8]
- [vfio] vfio/pci: Mask buggy SR-IOV VF INTx support (Myron Stowe) [1678076]
- [netdrv] net/ibmvnic: Update carrier state after link state change (Steve Best) [1711282]
- [netdrv] net/ibmvnic: Update MAC address settings after adapter reset (Steve Best) [1711282]
- [scsi] scsi: storvsc: Reduce default ring buffer size to 128 Kbytes (Cathy Avery) [1691370]
- [scsi] scsi: storvsc: Fix calculation of sub-channel count (Cathy Avery) [1691370]
- [powercap] powercap: RAPL: Get rid of custom RAPL_CPU() macro (Alexander Beregalov) [1706827]
- [tools] tools/power turbostat: Increase default buffer size (Prarit Bhargava) [1711260]
- [char] virtio_console: initialize vtermno value for ports (Pankaj Gupta) [1460636]
- [rpmspec] redhat: exclude kvm_stat from pathfix.py's tenure (Vitaly Kuznetsov) [1692804]
- [virt] kvm: arm: Skip stage2 huge mappings for unaligned ipa backed by THP (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Ensure vcpu target is unset on reset failure (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-v3: Retire pending interrupts on disabling LPIs (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Fix CNTP_TVAL calculation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move RSB stuffing to before the first RET after VM-Exit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Fix size checks in vmx_set_nested_state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Check for in-kernel LAPIC before deferencing apic pointer (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix KVM_CLEAR_DIRTY_LOG for memory slots of unaligned size (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: reset MMU context when 32-bit guest switches PAE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Whitelist port 0x7e for pre-incrementing rip (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Convert guest TSC to host time domain if necessary (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Allow user to disable adaptive tuning of timer advancement (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Track lapic timer advance per vCPU (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Disable timer advancement if adaptive tuning goes haywire (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyper-v: deal with buggy TLB flush requests from WS2012 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Consider LAPIC TSC-Deadline timer expired if deadline too short (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: avoid misreporting level-triggered irqs as edge-triggered in tracing (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix spectrev1 gadgets (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix warning Using plain integer as NULL pointer (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: add a selftest for SMM (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: fix for compilers that do not support -no-pie (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm/evmcs_test: complete I/O before migrating guest state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Always use 32-bit SMRAM save state for 32-bit kernels (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Don't clear EFER during SMM transitions for 32-bit vCPU (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: clear SMM flags before loading state while leaving SMM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Open code kvm_set_hflags (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Load SMRAM in a single shot when leaving SMM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Expose RDPMC-exiting only when guest supports PMU (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm: move kvm_load/put_guest_xcr0 into atomic context (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: svm: make sure NMI is injected after nmi_singlestep (Vitaly Kuznetsov) [1692804]
- [kvm] svm/avic: Fix invalidate logical APIC id entry (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "svm: Fix AVIC incomplete IPI emulation" (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: mmu: Fix overflow on kvm mmu page limit calculation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: always use early vmcs check when EPT is disabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: allow tests to use bad virtual-APIC page address (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Fix an inverted list_empty() check when zapping sptes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: fix x2APIC VTPR read intercept (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: close leak of L0's x2APIC MSRs (CVE-2019-3887) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: SVM: prevent DBG_DECRYPT and DBG_ENCRYPT overflow (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: fix potential get_num_contig_pages overflow (Vitaly Kuznetsov) [1692804]
- [documentation] Documentation: kvm: clarify KVM_SET_USER_MEMORY_REGION (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: complete IO before migrating guest state (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: disable stack protector for all KVM tests (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: explicitly disable PIE for tests (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: assert on exit reason in CR4/cpuid sync test (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: update rip after emulating IO (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: avoid spurious pending stimer on vCPU init (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86: Move MSR_IA32_ARCH_CAPABILITIES to array emulated_msrs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Emulate MSR_IA32_ARCH_CAPABILITIES on AMD hosts (Vitaly Kuznetsov) [1692804]
- [virt] kvm: don't redefine flags as something else (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: mmu: Used range based flushing in slot_handle_level_range (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Fix definition of HV_MAX_FLUSH_REP_COUNT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: remove check on nr_mmu_pages in kvm_arch_commit_memory_region() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: nVMX: Add a vmentry check for HOST_SYSENTER_ESP and HOST_SYSENTER_EIP fields (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: SVM: Workaround errata#1096 (insn_len maybe zero on SMAP violation) (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Reject device ioctls from processes other than the VM's creator (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: doc: Fix incorrect word ordering regarding supported use of APIs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix handling of role.cr4_pae and rename it to 'gpte_size' (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Do not inherit quadrant and invalid for the root shadow EPT (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Comments cleanup in mmu.c (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Make attribute accessors static (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Fix handling of stage2 huge mappings (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Enforce PTE mappings at stage2 when needed (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Take the srcu lock when parsing the memslots (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Take the srcu lock when writing to guest memory (Vitaly Kuznetsov) [1692804]
- [virt] arm64: KVM: Always set ICH_HCR_EL2.EN if GICv4 is enabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Reset the PMU in preemptible context (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: fix formatting of a comment (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: doc: Document the life cycle of a VM and its resources (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range()" (Vitaly Kuznetsov) [1692804]
- [documentation] virtio-ccw: diag 500 may return a negative cookie (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Add count cache flush parameters to kvmppc_get_cpu_char() (Vitaly Kuznetsov) [1692804]
- [virt] kvm: properly check debugfs dentry before using it (Vitaly Kuznetsov) [1692804]
- [powerpc] KVM: PPC: Fix compilation when KVM is not enabled (Vitaly Kuznetsov) [1692804]
- [powerpc] powerpc: Avoid circular header inclusion in mmu-hash.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: MMU: record maximum physical address width in kvm_mmu_extended_role (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Return LA57 feature based on hardware capability (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: fix switch between root and guest MMUs (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Minor cleanups for kvm_main.c (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Fix architecturally invalid reset value for FPEXC32_EL2 (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/kvm: Save and restore host AMR/IAMR/UAMOR (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Improve KVM reference counting (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Fix build failure without IOMMU support (Vitaly Kuznetsov) [1692804]
- [powerpc] powerpc/64s: Better printing of machine check info for guest MCEs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Simplify machine check handling (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Context switch AMR on Power9 (Vitaly Kuznetsov) [1692804]
- [virt] Revert "KVM: Eliminate extra function calls in kvm_get_dirty_log_protect()" (Vitaly Kuznetsov) [1692804]
- [x86] x86: kvmguest: use TSC clocksource if invariant TSC is exposed (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Never start grow vCPU halt_poll_ns from value below halt_poll_ns_grow_start (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Expose the initial start value in grow_halt_poll_ns() as a module parameter (Vitaly Kuznetsov) [1692804]
- [virt] KVM: grow_halt_poll_ns() should never shrink vCPU halt_poll_ns (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Consolidate kvm_mmu_zap_all() and kvm_mmu_zap_mmio_sptes() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: WARN if zapping a MMIO spte results in zapping children (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Differentiate between nr zapped and list unstable (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: fast invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Voluntarily reschedule as needed when zapping all sptes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: skip over invalid root pages when zapping all sptes (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: x86: use the fast way to invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: show mmu_valid_gen in shadow page related tracepoints" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: add tracepoint for kvm_mmu_invalidate_all_pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: zap pages in batch" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: collapse TLB flushes when zap all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: reclaim the zapped-obsolete page first" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Remove is_obsolete() call (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Voluntarily reschedule as needed when zapping MMIO sptes (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: drop kvm_mmu_zap_mmio_sptes" (Vitaly Kuznetsov) [1692804]
- [x86] Revert "KVM: MMU: document fast invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Zap only the relevant pages when removing a memslot (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Split remote_flush+zap case out of kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Move slot_level_*() helper functions up a few lines (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Move the memslot update in-progress flag to bit 63 (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Remove the hack to trigger memslot generation wraparound (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Refactor the MMIO SPTE generation handling (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Use a u64 when passing the MMIO gen around (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Explicitly define the "memslot update in-progress" bit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Do not cache MMIO accesses while memslots are in flux (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Detect MMIO generation wrap in any address space (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Call kvm_arch_memslots_updated() before updating memslots (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not start the preemption timer hrtimer unnecessarily (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Fix typos in vmentry/vmexit control setting (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: cleanup freeing of nested state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Sync the pending Posted-Interrupts (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: expose MOVDIR64B CPU feature into VM. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: expose MOVDIRI CPU feature into VM. (Vitaly Kuznetsov) [1692804]
- [kvm] kvm, x86, mmu: Use kernel generic dynamic physical address mask (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: remove useless is_protmode check (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Ignore limit checks on VMX instructions using flat segments (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Apply addr size mask to effective address for VMX instructions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Sign extend displacements of VMX instr's mem operands (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix improper check when deactivate AVIC (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: cull apicv code when userspace irqchip is requested (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix AVIC DFR and LDR handling (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Use struct_size() in kmalloc() (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: set offset for kvm unstable clock (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Reorder clearing of registers in the vCPU-run assembly flow (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Call vCPU-run asm sub-routine from C and remove clobbering (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Preserve callee-save registers in vCPU-run asm sub-routine (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Return VM-Fail from vCPU-run assembly via standard ABI reg (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass @launched to the vCPU-run asm via standard ABI regs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use RAX as the scratch register during vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Rename ____vmx_vcpu_run() to __vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Fold __vmx_vcpu_run() back into vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move vCPU-run code to a proper assembly routine (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Create a stack frame in vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use #defines in place of immediates in VM-Enter inline asm (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: Explicitly #define the VCPU_REGS_* indices (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Remove unused gpa_end variable (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Fix comment for KVM_PHYS_SHIFT (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: fix spelling mistake: "auxilary" -> "auxiliary" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Prefix header search paths with $(srctree)/ (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Fix TRACE_INCLUDE_PATH (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Mark physical interrupt active when a virtual interrupt is pending (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Describe data or unified caches as having 1 set and 1 way (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Expose sanitised cache type register to guest (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Move kvm_is_write_fault to header file (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Assign the phys timer on VHE systems (Vitaly Kuznetsov) [1692804]
- [include] clocksource/arm_arch_timer: Store physical timer IRQ number for KVM on VHE (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: timer: Rework data structures for multiple timers (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: consolidate arch timer trap handlers (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Reuse sys_reg() macro when searching the trap table (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Fix ICH_ELRSR_EL2 sysreg naming (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Simplify bg_timer programming (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm/arm64: Factor out VMID into struct kvm_vmid (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Statically configure the host's view of MPIDR (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Drop VHE-specific HYP call stub (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Allow for direct call of HYP functions when using VHE (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Introduce kvm_call_hyp_ret() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Release all hardware TCE tables attached to a group (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Optimise mmio emulation for devices on FAST_MMIO_BUS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Allow XICS emulation to work in nested hosts using XIVE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Replace kmalloc_node+memset with kzalloc_node (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Add emulation for slbfee. instruction (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Fix entry number check for add_atomic_switch_msr() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Recompute PID.ON when clearing PID.SN (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Restore a preemption timer consistency check (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: read from MSR_IA32_VMX_PROCBASED_CTLS2 only when it is available (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use vcpu->arch.regs directly when saving/loading guest state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Don't save guest registers after VM-Fail (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Invert the ordering of saving guest/host scratch reg at VM-Enter (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass "launched" directly to the vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Update VMCS.HOST_RSP via helper C function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Load/save guest CR2 via C code in __vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Cache host_rsp on a per-VMCS basis (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Let the compiler select the reg for holding HOST_RSP (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Reference vmx->loaded_vmcs->launched directly (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Capture VM-Fail via CC_{SET, OUT} in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Capture VM-Fail to a local var in nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Explicitly reference the scratch reg in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Drop STACK_FRAME_NON_STANDARD from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Remove a rogue "rax" clobber from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Let the compiler save/load RDX during vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Manually load RDX in vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Save RSI to an unused output in the vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Modify only RSP when creating a placeholder for guest's RCX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Zero out *all* general purpose registers after VM-Exit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Check a single byte for VMCS "launched" in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Compare only a single byte for VMCS' "launched" in vCPU-run (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: add selftest for releasing VM file descriptor while in L2 (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm/arm64: Add kvm_ras.h to collect kvm specific RAS plumbing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: work around leak of uninitialized stack contents (CVE-2019-7222) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Forbid kprobing of the VHE world-switch code (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Relax the restriction on using stage2 PUD huge mapping (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Always initialize the group of private IRQs (Vitaly Kuznetsov) [1692804]
- [kvm] arm/arm64: KVM: Don't panic on failure to properly reset system registers (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Allow a VCPU to fully reset itself (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Reset the VCPU without preemption and vcpu state loaded (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: fix possible null pointer dereference in pending_irqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: start using the GIB (Vitaly Kuznetsov) [1692804]
- [s390] KVM: s390: add gib_alert_irq_handler() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: kvm_s390_gisa_clear() now clears the IPM only (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add functions to (un)register GISC with GISA (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add kvm reference to struct sie_page2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add the GIB and its related life-cyle functions (Vitaly Kuznetsov) [1692804]
- [s390] s390/cio: add function chsc_sgib() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: introduce struct kvm_s390_gisa_interrupt (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: remove kvm_s390_ from gisa static inline functions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: use pending_irqs_no_gisa() where appropriate (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: coding style kvm_s390_gisa_init/clear() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: move bitmap idle_mask into arch struct top level (Vitaly Kuznetsov) [1692804]
- [virt] virt/kvm: Replace spin_is_locked() with lockdep (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Mark expected switch fall-throughs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix TRACE_INCLUDE_PATH and remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: check returned evmcs version range (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: nested_enable_evmcs() sets vmcs_version incorrectly (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move vmx_vcpu_run()'s VM-Enter asm blob to a helper function (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: Fix region overlap check in kvm_util (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: fix some -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nSVM: clear events pending from svm_complete_interrupts() when exiting to L1 (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix AVIC incomplete IPI emulation (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Add warning message for AVIC IPI invalid target (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: WARN_ONCE if sending a PV IPI returns a fatal error (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix PV IPIs for 32-bit KVM host (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: recommend using eVMCS only when it is enabled (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: don't recommend doing reset via synthetic MSR (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86/vmx: Use kzalloc for cached_vmcs12 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use the correct field var when clearing VM_ENTRY_LOAD_IA32_PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix single-step debugging (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: don't announce GUEST IDLE MSR support (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Don't generate UNDEF when LORegion feature is present (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_cpu->ap_list_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_dist->lpi_list_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_irq->irq_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: powerpc: remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [documentation] Documentation/virtual/kvm: Update URL for AMD SEV API specification (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Avoid return error when flush tlb successfully in the hv_remote_flush_tlb_with_range() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: sev: Fail KVM_SEV_INIT if already initialized (Vitaly Kuznetsov) [1692804]
- [virt] KVM: validate userspace input in kvm_clear_dirty_log_protect() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix bit shifting in update_intel_pt_cfg (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: radix: Fix uninitialized var build error (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: ucall: fix exit mmio address guessing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VM-Enter + VM-Exit handling to non-inline sub-routines (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Explicitly reference RCX as the vmx_vcpu pointer in asm blobs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use SVM assembly instruction mnemonics instead of .byte streams (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Flush tlb directly in kvm_set_pte_rmapp() (Vitaly Kuznetsov) [1692804]
- [virt] KVM/MMU: Move tlb flush in kvm_set_pte_rmapp() to kvm_mmu_notifier_change_pte() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: Make kvm_set_spte_hva() return int (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: Replace old tlb flush function with new one to flush a specified range. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Add tlb flush with range helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Add hv tlb range flush support (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Add HvFlushGuestAddressList hypercall support (Vitaly Kuznetsov) [1692804]
- [x86] KVM: Add tlb_remote_flush_with_range callback in kvm_x86_ops (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Disable Intel PT when VMXON in L1 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Set intercept for Intel PT MSRs read/write (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Implement Intel PT MSRs read/write emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Introduce a function to initialize the PT configuration (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel PT context switch for each vcpu (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel Processor Trace cpuid emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel PT virtualization work mode (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: add new capability for Intel PT (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Add new bit definitions for PT MSRs (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Introduce intel_pt_validate_cap() (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Export pt_cap_get() (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Move Intel PT MSRs bit defines to global header (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: aarch64: dirty_log_test: support greater than 40-bit IPAs (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add pa-48/va-48 VM modes (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: improve mode param management (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: reset guest test phys offset (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: always use -t (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: don't identity map the test mem (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: x86_64: dirty_log_test: fix -t (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix some typos (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: convert to SPDX identifiers (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Remove KF() macro placeholder (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Allow guest read access to IA32_TSC (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: nVMX: NMI-window and interrupt-window exiting should wake L2 from HLT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nSVM: Fix nested guest support for PAUSE filtering. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Remove duplicated include from vmx.c (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: report failed stage when exit reason is unexpected (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix size of x86_fpu_cache objects (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/fsl: Flush branch predictor when entering KVM (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/fsl: Emulate SPRN_BUCSR register (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nSVM: fix switch to guest mmu (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Add trapped system register access tracepoint (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Make vcpu const in vcpu_read_sys_reg (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Simplify kvm_timer_vcpu_terminate (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Remove arch timer workqueue (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix unregistering coalesced mmio zone from wrong bus (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Add support for creating PUD hugepages at stage 2 (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Update age handlers to support PUD hugepages (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Support handling access faults for PUD hugepages (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Support PUD hugepage in stage2_is_exec() (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Support dirty page tracking for PUD hugepages (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Introduce helpers to manipulate page table entries (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Re-factor setting the Stage 2 entry to exec on fault (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Share common code in user_mem_abort() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Log PSTATE for unhandled sysregs (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Consistently advance singlestep when emulating instructions (Vitaly Kuznetsov) [1692804]
- [virt] arm64: KVM: Skip MMIO insn after emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Allow passthrough of an emulated device to an L3 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Introduce new hcall H_COPY_TOFROM_GUEST to access quadrants 1 & 2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Allow passthrough of an emulated device to an L2 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Update kvmppc_st and kvmppc_ld to use quadrants (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Add load_from_eaddr and store_to_eaddr to the kvmppc_ops struct (Vitaly Kuznetsov) [1692804]
- [powerpc] KVM: PPC: Book3S HV: Implement functions to access quadrants 1 & 2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Add function kvmhv_vcpu_is_radix() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Only report KVM_CAP_SPAPR_TCE_VFIO on powernv machines (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: ucall: improve ucall placement in memory, fix unsigned comparison (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Dynamically allocate guest_fpu (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Use task structs fpu field for user (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for Guest Non-Register States to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for Host Control Registers and MSRs to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Entry Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Exit Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Remove param indirection from nested_vmx_check_msr_switch() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Execution Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Prepend "nested_vmx_" to check_vmentry_{pre, post}reqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Check ept_pointer before flushing ept tlb (Vitaly Kuznetsov) [1692804]
- [kvm] KVM nVMX: MSRs should not be stored if VM-entry fails during or after loading guest state (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Don't modify MSR_PLATFORM_INFO on vCPU reset (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: add cpu into VMX preemption timer bug list (Vitaly Kuznetsov) [1692804]
- [kvm] x86/hyper-v: Stop caring about EOI for direct stimers (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: avoid open-coding stimer_mark_pending() in kvm_hv_notify_acked_sint() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: direct mode for synthetic timers (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvm/hyper-v: use stimer config definition from hyperv-tlfs.h (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: Add hyperv_cpuid test (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: implement an unchecked version of vcpu_ioctl() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: Introduce KVM_GET_SUPPORTED_HV_CPUID (Vitaly Kuznetsov) [1692804]
- [kvm] x86/hyper-v: Do some housekeeping in hyperv-tlfs.h (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Mark TLFS structures packed (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: Introduce nested_get_evmcs_version() helper (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyperv: don't retry message delivery for periodic timers (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyperv: simplify SynIC message delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: remove unnecessary recalculate_apic_map (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: remove unused struct definition (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Skip all SYSCALL MSRs in setup_msrs() when !EFER.SCE (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Don't set hardware IA32_CSTAR MSR on VM-entry (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Document the need for MSR_STAR in i386 builds (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Set IA32_TSC_AUX for legacy mode guests (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move nested code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose nested_vmx_allowed() to nested VMX as a non-inline (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose various getters and setters to nested VMX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose misc variables needed for nested VMX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move "vmcs12 to shadow/evmcs sync" to helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Call nested_vmx_setup_ctls_msrs() iff @nested is true (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Set callbacks for nested functions during hardware setup (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move the hardware {un}setup functions to the bottom (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: Allow nested_enable_evmcs to be NULL (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move nested hardware/vcpu {un}setup to helper functions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMX instruction wrappers to a dedicated header file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move eVMCS code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Add vmx.h to hold VMX definitions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move vmcs12 code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMCS definitions to dedicated file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose various module param vars via capabilities.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move capabilities structs and helpers to dedicated file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass vmx_capability struct to setup_vmcs_config() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Properly handle dynamic VM Entry/Exit controls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move caching of MSR_IA32_XSS to hardware_setup() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Drop the "vmx" prefix from vmx_evmcs.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: rename vmx_shadow_fields.h to vmcs_shadow_fields.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMX specific files to a "vmx" subdirectory (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add requisite includes to hyperv.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add requisite includes to kvm_cache_regs.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Alphabetize the includes in vmx.c (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Allocate and configure VM{READ, WRITE} bitmaps iff enable_shadow_vmcs (Vitaly Kuznetsov) [1692804]
- [tools] kvm: introduce manual dirty log reprotect (Vitaly Kuznetsov) [1692804]
- [virt] kvm: rename last argument to kvm_get_dirty_log_protect (Vitaly Kuznetsov) [1692804]
- [virt] kvm: make KVM_CAP_ENABLE_CAP_VM architecture agnostic (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Set hflag to indicate that POWER9 supports 1T segments (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Change to use DEFINE_SHOW_ATTRIBUTE macro (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Don't trap host pointer auth use to EL2 (Vitaly Kuznetsov) [1692804]
- [kvm] arm64/kvm: hide ptrauth from guests (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: add pointer authentication register bits (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: add comments about EC exception levels (Vitaly Kuznetsov) [1692804]
- [arm64] arm64/kvm: consistently handle host HCR_EL2 flags (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Add configuration/documentation for Cortex-A76 erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Handle ARM erratum 1165522 in TLB invalidation (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Add synchronization on translation regime change for erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Force VHE for systems affected by erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Add TCR_EPD{0,1} definitions (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Rework detection of SVE, !VHE systems (Vitaly Kuznetsov) [1692804]
- [kvm] nVMX x86: Check VMX-preemption timer controls on vmentry of L2 guests (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/nVMX: Remove unneeded forward jump in nested_vmx_check_vmentry_hw asm (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Unrestricted guest mode requires EPT (Vitaly Kuznetsov) [1692804]
- [tools] tools/kvm_stat: switch to python3 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Trace changes to active TSC offset regardless if vCPU in guest-mode (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: vmcs12 revision_id is always VMCS12_REVISION even when copied from eVMCS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Verify eVMCS revision id match supported eVMCS version on eVMCS VMPTRLD (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/vmx: fix old-style function declaration (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix empty-body warnings (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Fix kernel info-leak when enabling KVM_CAP_HYPERV_ENLIGHTENED_VMCS more than once (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Replace spin_is_locked() with lockdep (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Move and undef TRACE_INCLUDE_PATH/FILE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Use exported tb_to_ns() function in decrementer emulation (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: Fix -Wformat warnings (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: fix spelling mistake "Insufficent" -> "Insufficient" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "kvm: x86: optimize dr6 restore" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Optimize clearing TCEs for sparse tables (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: tweak shadow fields (Vitaly Kuznetsov) [1692804]
- [tools] selftests/kvm: add missing executables to .gitignore (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Don't use streamlined entry path on early POWER9 chips (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Enable 32 bits kvm vcpu events support (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Rename function kvm_arch_dev_ioctl_check_extension() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: enable nested virtualization by default (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use 32bit xor to clear registers in svm.c (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Introduce KVM_CAP_EXCEPTION_PAYLOAD (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Defer setting of DR6 until #DB delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Defer setting of CR2 until #PF delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add payload operands to kvm_multiple_exception (Vitaly Kuznetsov) [1692804]
- [x86] kvm: x86: Add exception payload fields to kvm_vcpu_events (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add has_payload and payload to kvm_queued_exception (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: Documentation: Fix omission in struct kvm_vcpu_events (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: add Enlightened VMCS test (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: nested state migration for Enlightened VMCS (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: state_test: test bare VMXON migration (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyperv: don't clear VP assist pages on init (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: optimize prepare_vmcs02{, _full} for Enlightened VMCS case (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: implement enlightened VMPTRLD and VMCLEAR (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add enlightened VMCS state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add KVM_CAP_HYPERV_ENLIGHTENED_VMCS capability (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: refactor evmcs_sanitize_exec_ctrls() (Vitaly Kuznetsov) [1692804]
- [virt] KVM: refine the comment of function gfn_to_hva_memslot_prot() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: reintroduce pte_list_remove, but including mmu_spte_clear_track_bits (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: rename pte_list_remove to __pte_list_remove (Vitaly Kuznetsov) [1692804]
- [virt] kvm/x86 : add coalesced pio support (Vitaly Kuznetsov) [1692804]
- [documentation] kvm/x86 : add document for coalesced mmio (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86 : fix some typo (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Change hv flush logic when ept tables are mismatched. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use 32bit xor to clear register (Vitaly Kuznetsov) [1692804]
- [x86] KVM/x86: Use assembly instruction mnemonics instead of .byte streams (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Fix invvpid and invept register operand size in 64-bit mode (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: check if MMU reconfiguration is needed in init_kvm_nested_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: check if tdp/shadow MMU reconfiguration is needed (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: introduce source data cache for kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: make space for source data caching in struct kvm_mmu (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: get rid of redundant kvm_mmu_setup() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: introduce guest_mmu (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu.c: add kvm_mmu parameter to kvm_mmu_free_roots() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu.c: set get_pdptr hook in kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: make vcpu->mmu a pointer to the current MMU (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: optimize dr6 restore (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: optimize sparse VP set processing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: fix 'tlb_lush' typo (Vitaly Kuznetsov) [1692804]
- [virt] vgic: Add support for 52bit guest physical address (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: WARN if nested run hits VMFail with early consistency checks enabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add option to perform early consistency checks via H/W (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: write HOST_IA32_EFER in vmx_set_constant_host_state() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: call kvm_skip_emulated_instruction in nested_vmx_{fail, succeed} (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not call nested_vmx_succeed() for consistency check VMExit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not skip VMEnter instruction that succeeds (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do early preparation of vmcs02 before check_vmentry_postreqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: initialize vmcs02 constant exactly once (per VMCS) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: split pieces of prepare_vmcs02() to prepare_vmcs02_early() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: remove ASSERT() on vmx->pml_pg validity (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vVMX: rename label for post-enter_guest_mode consistency check (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: assimilate nested_vmx_entry_failure() into nested_vmx_enter_non_root_mode() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: rename enter_vmx_non_root_mode to nested_vmx_enter_non_root_mode (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: try to set EFER bits correctly when initializing controls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: do not unconditionally clear EFER switching (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: reset cache/shadows when switching loaded VMCS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: use vm_exit_controls_init() to write exit controls for vmcs02 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: move vmcs12 EPTP consistency check to check_vmentry_prereqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: move host EFER consistency checks to VMFail path (Vitaly Kuznetsov) [1692804]
- [virt] KVM: leverage change to adjust slots->used_slots in update_memslots() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: implement PV IPI send hypercalls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: optimize kvm_hv_flush_tlb() for vp_index == vcpu_idx case (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: valid_bank_mask should be 'u64' (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: keep track of mismatched VP indexes (Vitaly Kuznetsov) [1692804]
- [virt] KVM: x86: hyperv: optimize 'all cpus' case in kvm_hv_flush_tlb() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86: return meaningful value from KVM_SIGNAL_MSI (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: move definition PT_MAX_HUGEPAGE_LEVEL and KVM_NR_PAGE_SIZES together (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Remve unused function is_external_interrupt(). (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: return 0 in case kvm_mmu_memory_cache has min number of objects (Vitaly Kuznetsov) [1692804]
- [kvm] nVMX x86: Make nested_vmx_check_pml_controls() concise (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: adjust kvm_mmu_page member to save 8 bytes (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: support high GPAs in dirty_log_test (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: stop lying to aarch64 tests about PA-bits (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: also test 64K pages on aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: port dirty_log_test to aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: introduce new VM mode for 64K pages (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add vcpu support for aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add virt mem support for aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add vm_phy_pages_alloc (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: tidy up kvm_util (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add cscope make target (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: move arch-specific files to arch-specific locations (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: introduce ucall (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: vcpu_setup: set cr4.osfxsr (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: LAPIC: Tune lapic_timer_advance_ns automatically (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Do not flush TLB on L1<->L2 transitions if L1 uses VPID and EPT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Flush linear and combined mappings on VPID02 related flushes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Use correct VPID02 when emulating L1 INVVPID (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Flush TLB entries tagged by dest EPTP on L1<->L2 transitions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: rename KVM_GUEST_CR0_MASK tp KVM_VM_CR0_ALWAYS_OFF (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Remove redundand permission bits removal (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Propagate errors to the guest when failed instead of ignoring (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Provide mode where all vCPUs on a core must be the same VM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Exiting split hack mode needs to fixup both PC and LR (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Remove some extra semicolon in kvm_target_cpu (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Validate all tces before updating tables (Vitaly Kuznetsov) [1692804]
- [documentation] arm64: Add silicon-errata.txt entry for ARM erratum 1188873 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: arch_timer: Add workaround for ARM erratum 1188873 (Vitaly Kuznetsov) [1692804]
- [virt] signal/arm/kvm: Use send_sig_mceerr (Vitaly Kuznetsov) [1692804]
- [arm64] arm64/cpufeatures: Introduce ESR_ELx_SYS64_ISS_RT() (Vitaly Kuznetsov) [1692804]
- [kvm] signal/x86: Use send_sig_mceerr as apropriate (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvm: Use __bss_decrypted attribute in shared variables (Vitaly Kuznetsov) [1692804]
- [x86] x86/mm: Add .bss..decrypted section to hold shared variables (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: Inject #UD for SGX ENCLS instruction in guest (Vitaly Kuznetsov) [1692804]
- [x86] KVM: vmx: Add defines for SGX ENCLS exiting (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: Documentation: rename the capability of KVM_CAP_ARM_SET_SERROR_ESR (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Mark kvm_get_preset_lpj() as __init (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Don't open code task_pid in kvm_vcpu_ioctl (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Share the parts of get/set events useful to 32bit (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: export the capability to set guest SError syndrome (Vitaly Kuznetsov) [1692804]
- [kvm] arm/arm64: KVM: Add KVM_GET/SET_VCPU_EVENTS (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Switch kvmclock data to a PER_CPU variable (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Move kvmclock vsyscall param and init to kvmclock (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Mark variables __initdata and __ro_after_init (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Cleanup the code (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Decrapify kvm_register_clock() (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Remove page size requirement from wall_clock (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Remove memblock dependency (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/arm: use PSR_AA32 definitions (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Handle Set/Way CMOs as NOPs if FWB is present (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Add support for Stage-2 control of memory types and cacheability (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Handle mismatched cache type (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Fix mismatched cache line size detection (Vitaly Kuznetsov) [1692804]

* Mon May 27 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-96.el8]
- [lib] rhel-kabi: Add RH_KABI_FORCE_CHANGE() to radix-tree and idr functions (Don Dutile) [1692079]
- [lib] XArray: Fix xa_reserve for 2-byte aligned entries (Don Dutile) [1692079]
- [lib] XArray: Fix xa_erase of 2-byte aligned entries (Don Dutile) [1692079]
- [lib] XArray: Use xa_cmpxchg to implement xa_reserve (Don Dutile) [1692079]
- [lib] XArray: Fix xa_release in allocating arrays (Don Dutile) [1692079]
- [lib] XArray: Mark xa_insert and xa_reserve as must_check (Don Dutile) [1692079]
- [lib] XArray: Add cyclic allocation (Don Dutile) [1692079]
- [lib] XArray: Redesign xa_alloc API (Don Dutile) [1692079]
- [lib] XArray: Add support for 1s-based allocation (Don Dutile) [1692079]
- [lib] XArray: Change xa_insert to return -EBUSY (Don Dutile) [1692079]
- [lib] XArray: Update xa_erase family descriptions (Don Dutile) [1692079]
- [lib] XArray tests: RCU lock prohibits GFP_KERNEL (Don Dutile) [1692079]
- [include] XArray: Fix an arithmetic error in xa_is_err (Don Dutile) [1692079]
- [lib] XArray tests: Check mark 2 gets squashed (Don Dutile) [1692079]
- [include] XArray: Fix typo in comment (Don Dutile) [1692079]
- [lib] XArray: Honour reserved entries in xa_insert (Don Dutile) [1692079]
- [lib] XArray: Permit storing 2-byte-aligned pointers (Don Dutile) [1692079]
- [lib] XArray: Change xa_for_each iterator (Don Dutile) [1692079]
- [lib] XArray: Turn xa_init_flags into a static inline (Don Dutile) [1692079]
- [lib] XArray tests: Add RCU locking (Don Dutile) [1692079]
- [lib] XArray: Fix xa_alloc when id exceeds max (Don Dutile) [1692079]
- [lib] XArray tests: Check iterating over multiorder entries (Don Dutile) [1692079]
- [lib] XArray tests: Handle larger indices more elegantly (Don Dutile) [1692079]
- [include] XArray: Add xa_cmpxchg_irq and xa_cmpxchg_bh (Don Dutile) [1692079]
- [tools] radix tree: Don't return retry entries from lookup (Don Dutile) [1692079]
- [lib] XArray tests: Add missing locking (Don Dutile) [1692079]
- [lib] XArray tests: Correct some 64-bit assumptions (Don Dutile) [1692079]
- [lib] XArray: Correct xa_store_range (Don Dutile) [1692079]
- [lib] XArray: Fix Documentation (Don Dutile) [1692079]
- [lib] XArray: Handle NULL pointers differently for allocation (Don Dutile) [1692079]
- [lib] XArray: Unify xa_store and __xa_store (Don Dutile) [1692079]
- [include] XArray: Add xa_store_bh() and xa_store_irq() (Don Dutile) [1692079]
- [lib] XArray: Turn xa_erase into an exported function (Don Dutile) [1692079]
- [lib] XArray: Unify xa_cmpxchg and __xa_cmpxchg (Don Dutile) [1692079]
- [lib] XArray: Regularise xa_reserve (Don Dutile) [1692079]
- [lib] XArray: Export __xa_foo to non-GPL modules (Don Dutile) [1692079]
- [lib] XArray: Fix xa_for_each with a single element at 0 (Don Dutile) [1692079]
- [lib] xarray: Add range store functionality (Don Dutile) [1692079]
- [lib] xarray: Move multiorder_check to in-kernel tests (Don Dutile) [1692079]
- [lib] xarray: Move multiorder_shrink to kernel tests (Don Dutile) [1692079]
- [lib] xarray: Move multiorder account test in-kernel (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert iteration test to XArray (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert tag_tagged_items to XArray (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert regression1 to XArray (Don Dutile) [1692079]
- [lib] ida: Convert to XArray (Don Dutile) [1692079]
- [lib] xarray: Track free entries in an XArray (Don Dutile) [1692079]
- [lib] xarray: Add xa_reserve and xa_release (Don Dutile) [1692079]
- [lib] xarray: Add xas_create_range (Don Dutile) [1692079]
- [lib] xarray: Add xas_for_each_conflict (Don Dutile) [1692079]
- [lib] xarray: Step through an XArray (Don Dutile) [1692079]
- [lib] xarray: Destroy an XArray (Don Dutile) [1692079]
- [lib] xarray: Extract entries from an XArray (Don Dutile) [1692079]
- [lib] xarray: Add XArray iterators (Don Dutile) [1692079]
- [lib] xarray: Add XArray conditional store operations (Don Dutile) [1692079]
- [tools] xarray: Add XArray unconditional store operations (Don Dutile) [1692079]
- [tools] xarray: Add XArray marks (Don Dutile) [1692079]
- [tools] xarray: Add XArray load operation (Don Dutile) [1692079]
- [documentation] xarray: Add documentation (Don Dutile) [1692079]
- [include] xarray: Define struct xa_node (Don Dutile) [1692079]
- [tools] xarray: Add definition of struct xarray (Don Dutile) [1692079]
- [lib] test_ida: Fix lockdep warning (Don Dutile) [1692079]
- [lib] xarray: Change definition of sibling entries (Don Dutile) [1692079]
- [mm] xarray: Replace exceptional entries (Don Dutile) [1692079]
- [lib] idr: Permit any valid kernel pointer to be stored (Don Dutile) [1692079]
- [pci] Update email address (Don Dutile) [1692079]
- [lib] ida: Change ida_get_new_above to return the id (Don Dutile) [1692079]
- [lib] ida: Remove old API (Don Dutile) [1692079]
- [target] target/iscsi: Allocate session IDs from an IDA (Don Dutile) [1692079]
- [target] iscsi target: fix session creation failure handling (Don Dutile) [1692079]
- [drm] drm/vmwgfx: Return 0 when gmrid::get_node runs out of ID's (Don Dutile) [1692079]
- [drm] drm/vmwgfx: Convert to new IDA API (Don Dutile) [1692079]
- [dma] dmaengine: Convert to new IDA API (Don Dutile) [1692079]
- [powerpc] ppc: Convert vas ID allocation to new IDA API (Don Dutile) [1692079]
- [media] media: Convert entity ID allocation to new IDA API (Don Dutile) [1692079]
- [mm] ppc: Convert mmu context allocation to new IDA API (Don Dutile) [1692079]
- [net] Convert net_namespace to new IDA API (Don Dutile) [1692079]
- [misc] cb710: Convert to new IDA API (Don Dutile) [1692079]
- [block] rsxx: Convert to new IDA API (Don Dutile) [1692079]
- [scsi] osd: Convert to new IDA API (Don Dutile) [1692079]
- [scsi] sd: Convert to new IDA API (Don Dutile) [1692079]
- [fs] devpts: Convert to new IDA API (Don Dutile) [1692079]
- [fs] fs: Convert namespace IDAs to new API (Don Dutile) [1692079]
- [fs] fs: Convert unnamed_dev_ida to new API (Don Dutile) [1692079]
- [lib] test_ida: check_ida_destroy and check_ida_alloc (Don Dutile) [1692079]
- [lib] test_ida: Convert check_ida_conv to new API (Don Dutile) [1692079]
- [lib] test_ida: Move ida_check_max (Don Dutile) [1692079]
- [lib] test_ida: Move ida_check_leaf (Don Dutile) [1692079]
- [tools] idr-test: Convert ida_check_nomem to new API (Don Dutile) [1692079]
- [tools] ida: Start new test_ida module (Don Dutile) [1692079]
- [lib] ida: Lock the IDA in ida_destroy (Don Dutile) [1692079]
- [lib] radix-tree: Fix UBSAN warning (Don Dutile) [1692079]
- [include] rh_kabi: Indirect EXTEND macros so nesting of other macros will resolve. (Don Dutile) [1692079]
- [s390] s390/pkey: add one more argument space for debug feature entry (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: fix possible deadlock situation on ap queue remove (Philipp Rudo) [1710033]
- [s390] zcrypt: handle AP Info notification from CHSC SEI command (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: revisit ap device remove procedure (Philipp Rudo) [1710033]
- [s390] pkey: Indicate old mkvp only if old and current mkvp are different (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: use new state UNBOUND during queue driver rebind (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: fix specification exception on z196 during ap probe (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: rework ap scan bus code (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: make sysfs reset attribute trigger queue reset (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: improve special ap message cmd handling (Philipp Rudo) [1710033]
- [s390] s390: vfio-ap: include <asm/facility> for test_facility() (Philipp Rudo) [1710033]
- [fs] flexfiles: enforce per-mirror stateid only for v4 DSes (Scott Mayhew) [1709556]
- [fs] flexfiles: use per-mirror specified stateid for IO (Scott Mayhew) [1709556]
- [powerpc] powerpc/pseries: Fix build break due to pnv_npu2_init() (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/sriov: Register IOMMU groups for VFs (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/npu: Allocate enough memory in pnv_try_setup_npu_table_group() (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/npu: Fix oops in pnv_try_setup_npu_table_group() (Sam Bobroff) [1704567]
- [mm] mm: defer ZONE_DEVICE page initialization to the point where we init pgmap (Waiman Long) [1666538 1634343]
- [mm] mm: create non-atomic version of SetPageReserved for init use (Waiman Long) [1666538 1634343]
- [mm] mm: provide kernel parameter to allow disabling page init poisoning (Waiman Long) [1666538 1634343]
- [x86] x86/resctrl: Initialize a new resource group with default MBA values (David Arcari) [1688127]
- [x86] x86/resctrl: Move per RDT domain initialization to a separate function (David Arcari) [1688127]
- [x86] x86/resctrl: Do not repeat rdtgroup mode initialization (David Arcari) [1688127]
- [x86] x86/resctrl: Fix rdt_find_domain() return value and checks (David Arcari) [1688127]
- [x86] x86/resctrl: Use rdt_last_cmd_puts() where possible (David Arcari) [1688127]

* Fri May 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-95.el8]
- [s390] s390/pci: map IOV resources (Philipp Rudo) [1659411]
- [powerpc] powerpc/book3s/64: check for NULL pointer in pgd_alloc() (Steve Best) [1710310]
- [md] dm thin metadata: do not write metadata if no changes occurred (Mike Snitzer) [1710030]
- [md] dm thin metadata: add wrappers for managing write locking of metadata (Mike Snitzer) [1710030]
- [md] dm thin metadata: check __commit_transaction()'s return (Mike Snitzer) [1710030]
- [md] dm space map common: zero entire ll_disk (Mike Snitzer) [1710030]
- [powerpc] powerpc/tm: Fix stack pointer corruption (Desnes Augusto Nunes do Rosario) [1707635]
- [pci] PCI/MSI: Remove obsolete sanity checks for multiple interrupt sets (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Remove the leftovers of the original set support (Prarit Bhargava) [1686678]
- [nvme] nvme-pci: Simplify interrupt allocation (Prarit Bhargava) [1686678]
- [include] genirq/affinity: Add new callback for (re)calculating interrupt sets (Prarit Bhargava) [1686678]
- [nvme] genirq/affinity: Store interrupt sets size in struct irq_affinity (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Code consolidation (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Move allocation of 'node_to_cpumask' to irq_build_affinity_masks() (Prarit Bhargava) [1686678]
- [kernel] genirq/irqdesc: Fix double increment in alloc_descs() (Prarit Bhargava) [1686678]
- [include] genirq: Fix the kerneldoc comment for struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Add is_managed to struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/core: Introduce struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Remove excess indentation (Prarit Bhargava) [1686678]

* Thu May 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-94.el8]
- [md] dm: make sure to obey max_io_len_target_boundary (Mike Snitzer) [1712607]

* Wed May 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-93.el8]
- [mm] x86/dump_pagetables: Fix LDT remap address marker (Baoquan He) [1639560]
- [x86] x86/mm: Fix guard hole handling (Baoquan He) [1639560]
- [x86] x86/mm: Move LDT remap out of KASLR region on 5-level paging (Baoquan He) [1639560]
- [x86] x86/ldt: Define LDT_END_ADDR (Baoquan He) [1639560]
- [mm] x86/ldt: Reserve address-space range on 32 bit for the LDT (Baoquan He) [1639560]
- [documentation] x86/mm/doc: Enhance the x86-64 virtual memory layout descriptions (Baoquan He) [1639560]
- [documentation] x86/mm/doc: Clean up the x86-64 virtual memory layout descriptions (Baoquan He) [1639560]
- [fs] cifs: fix page reference leak with readv/writev (Leif Sahlberg) [1708033]
- [fs] cifs: do not attempt cifs operation on smb2+ rename error (Leif Sahlberg) [1708033]
- [fs] cifs: fix memory leak in SMB2_read (Leif Sahlberg) [1708033]
- [fs] CIFS: keep FileInfo handle live during oplock break (Leif Sahlberg) [1708033]
- [fs] cifs: fix handle leak in smb2_query_symlink() (Leif Sahlberg) [1708033]
- [fs] cifs: Fix lease buffer length error (Leif Sahlberg) [1708033]
- [fs] cifs: Fix use-after-free in SMB2_read (Leif Sahlberg) [1708033]
- [fs] cifs: Fix use-after-free in SMB2_write (Leif Sahlberg) [1708033]
- [fs] cifs: a smb2_validate_and_copy_iov failure does not mean the handle is invalid. (Leif Sahlberg) [1708033]
- [fs] SMB3: Allow persistent handle timeout to be configurable on mount (Leif Sahlberg) [1708033]
- [fs] smb3: Fix enumerating snapshots to Azure (Leif Sahlberg) [1708033]
- [fs] cifs: fix kref underflow in close_shroot() (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] SMB3: Fix SMB3.1.1 guest mounts to Samba (Leif Sahlberg) [1708033]
- [fs] cifs: Fix slab-out-of-bounds when tracing SMB tcon (Leif Sahlberg) [1708033]
- [fs] cifs: allow guest mounts to work for smb3.11 (Leif Sahlberg) [1708033]
- [fs] fix incorrect error code mapping for OBJECTID_NOT_FOUND (Leif Sahlberg) [1708033]
- [fs] cifs: fix that return -EINVAL when do dedupe operation (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix an issue with re-sending rdata when transport returning -EAGAIN (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix an issue with re-sending wdata when transport returning -EAGAIN (Leif Sahlberg) [1708033]
- [fs] CIFS: fix POSIX lock leak and invalid ptr deref (Leif Sahlberg) [1708033]
- [fs] SMB3: Allow SMB3 FSCTL queries to be sent to server from tools (Leif Sahlberg) [1708033]
- [fs] cifs: fix incorrect handling of smb2_set_sparse() return in smb3_simple_falloc (Leif Sahlberg) [1708033]
- [fs] smb2: fix typo in definition of a few error flags (Leif Sahlberg) [1708033]
- [fs] CIFS: make mknod() an smb_version_op (Leif Sahlberg) [1708033]
- [documentation] cifs: minor documentation updates (Leif Sahlberg) [1708033]
- [documentation] cifs: minor updates to documentation (Leif Sahlberg) [1708033]
- [fs] cifs: remove unused value pointed out by Coverity (Leif Sahlberg) [1708033]
- [fs] SMB3: passthru query info doesn't check for SMB3 FSCTL passthru (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic tracepoints for simple fallocate and zero range (Leif Sahlberg) [1708033]
- [fs] cifs: fix smb3_zero_range so it can expand the file-size when required (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_ioctl_init/free helpers to be used with compounding (Leif Sahlberg) [1708033]
- [fs] smb3: Add dynamic trace points for various compounded smb3 ops (Leif Sahlberg) [1708033]
- [fs] cifs: cache FILE_ALL_INFO for the shared root handle (Leif Sahlberg) [1708033]
- [fs] smb3: display volume serial number for shares in /proc/fs/cifs/DebugData (Leif Sahlberg) [1708033]
- [fs] cifs: simplify how we handle credits in compound_send_recv() (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic tracepoint for timeout waiting for credits (Leif Sahlberg) [1708033]
- [fs] smb3: display security information in /proc/fs/cifs/DebugData more accurately (Leif Sahlberg) [1708033]
- [fs] cifs: add a timeout argument to wait_for_free_credits (Leif Sahlberg) [1708033]
- [fs] cifs: prevent starvation in wait_for_free_credits for multi-credit requests (Leif Sahlberg) [1708033]
- [fs] cifs: wait_for_free_credits() make it possible to wait for >=1 credits (Leif Sahlberg) [1708033]
- [fs] cifs: pass flags down into wait_for_free_credits() (Leif Sahlberg) [1708033]
- [fs] cifs: change wait_for_free_request() to take flags as argument (Leif Sahlberg) [1708033]
- [fs] fs: cifs: Kconfig: pedantic formatting (Leif Sahlberg) [1708033]
- [fs] smb3: request more credits on normal (non-large read/write) ops (Leif Sahlberg) [1708033]
- [fs] CIFS: Return -EAGAIN instead of -ENOTSOCK (Leif Sahlberg) [1708033]
- [fs] CIFS: Only send SMB2_NEGOTIATE command on new TCP connections (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix read after write for files with read caching (Leif Sahlberg) [1708033]
- [fs] smb3: for kerberos mounts display the credential uid used (Leif Sahlberg) [1708033]
- [fs] cifs: use correct format characters (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic trace point for query_info_enter/done (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic trace point for smb3_cmd_enter (Leif Sahlberg) [1708033]
- [fs] smb3: improve dynamic tracing of open and posix mkdir (Leif Sahlberg) [1708033]
- [fs] smb3: add missing read completion trace point (Leif Sahlberg) [1708033]
- [fs] smb3: Add tracepoints for read, write and query_dir enter (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoints for query dir (Leif Sahlberg) [1708033]
- [fs] smb3: Update POSIX negotiate context with POSIX ctxt GUID (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: Try to acquire credits at once for compound requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Return error code when getting file handle for writeback (Leif Sahlberg) [1708033]
- [fs] CIFS: Move open file handling to writepages (Leif Sahlberg) [1708033]
- [fs] CIFS: Move unlocking pages from wdata_send_pages() (Leif Sahlberg) [1708033]
- [fs] CIFS: Find and reopen a file before get MTU credits in writepages (Leif Sahlberg) [1708033]
- [fs] CIFS: Reopen file before get SMB2 MTU credits for async IO (Leif Sahlberg) [1708033]
- [fs] CIFS: Remove custom credit adjustments for SMB2 async IO (Leif Sahlberg) [1708033]
- [fs] CIFS: Adjust MTU credits before reopening a file (Leif Sahlberg) [1708033]
- [fs] CIFS: Check for reconnects before sending compound requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Check for reconnects before sending async requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect reconnect in non-MTU credits calculations (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect reconnect in MTU credits calculations (Leif Sahlberg) [1708033]
- [fs] CIFS: Set reconnect instance to one initially (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect SMB2 hdr preamble size in read responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Count SMB3 credits for malformed pending responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not log credits when unmounting a share (Leif Sahlberg) [1708033]
- [fs] CIFS: Always reset read error to -EIO if no response (Leif Sahlberg) [1708033]
- [fs] cifs: Accept validate negotiate if server return NT_STATUS_NOT_SUPPORTED (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not skip SMB2 message IDs on send failures (Leif Sahlberg) [1708033]
- [fs] smb3: request more credits on tree connect (Leif Sahlberg) [1708033]
- [fs] smb3: make default i/o size for smb3 mounts larger (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not reset lease state to NONE on lease break (Leif Sahlberg) [1708033]
- [fs] smb3: fix bytes_read statistics (Leif Sahlberg) [1708033]
- [fs] cifs: return -ENODATA when deleting an xattr that does not exist (Leif Sahlberg) [1708033]
- [fs] cifs: add credits from unmatched responses/messages (Leif Sahlberg) [1708033]
- [fs] cifs: replace snprintf with scnprintf (Leif Sahlberg) [1708033]
- [fs] cifs: Fix NULL pointer dereference of devname (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix leaking locked VFS cache pages in writeback retry (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: fix use-after-free of the lease keys (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not consider -ENODATA as stat failure for reads (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not count -ENODATA as failure for query directory (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix trace command logging for SMB2 reads and writes (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix possible oops and memory leaks in async IO (Leif Sahlberg) [1708033]
- [fs] cifs: limit amount of data we request for xattrs to CIFSMaxBufSize (Leif Sahlberg) [1708033]
- [fs] cifs: fix computation for MAX_SMB2_HDR_SIZE (Leif Sahlberg) [1708033]
- [fs] cifs: print CIFSMaxBufSize as part of /proc/fs/cifs/DebugData (Leif Sahlberg) [1708033]
- [fs] smb3: add credits we receive from oplock/break PDUs (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix mounts if the client is low on credits (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not assume one credit for async responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit calculations in compound mid callback (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit calculation for encrypted reads with errors (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credits calculations for reads with errors (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not reconnect TCP session in add_credits() (Leif Sahlberg) [1708033]
- [fs] smb3: Cleanup license mess (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix possible hang during async MTU reads and writes (Leif Sahlberg) [1708033]
- [fs] cifs: fix memory leak of an allocated cifs_ntsd structure (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix error paths in writeback code (Leif Sahlberg) [1708033]
- [fs] CIFS: Move credit processing to mid callbacks for SMB3 (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credits calculation for cancelled requests (Leif Sahlberg) [1708033]
- [fs] cifs: Fix potential OOB access of lock element array (Leif Sahlberg) [1708033]
- [fs] cifs: Limit memory used by lock request calls to a page (Leif Sahlberg) [1708033]
- [fs] cifs: move large array from stack to heap (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not hide EINTR after sending network packets (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit computation for compounded requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not set credits to 1 if the server didn't grant anything (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix adjustment of credits for MTU requests (Leif Sahlberg) [1708033]
- [fs] cifs: Fix a tiny potential memory leak (Leif Sahlberg) [1708033]
- [fs] cifs: Fix a debug message (Leif Sahlberg) [1708033]
- [fs] smb3: add smb3.1.1 to default dialect list (Leif Sahlberg) [1708033]
- [fs] cifs: fix confusing warning message on reconnect (Leif Sahlberg) [1708033]
- [fs] smb3: fix large reads on encrypted connections (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] cifs: we can not use small padding iovs together with encryption (Leif Sahlberg) [1708033]
- [fs] cifs: Minor Kconfig clarification (Leif Sahlberg) [1708033]
- [fs] cifs: Always resolve hostname before reconnecting (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_reconnect_tcon() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in smb2_reconnect() (Leif Sahlberg) [1708033]
- [fs] cifs: Only free DFS target list if we actually got one (Leif Sahlberg) [1708033]
- [fs] cifs: start DFS cache refresher in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: Use GFP_ATOMIC when a lock is held in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_reconnect() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'sep' (Leif Sahlberg) [1708033]
- [fs] cifs: Make use of DFS cache to get new DFS referrals (Leif Sahlberg) [1708033]
- [fs] cifs: check kzalloc return (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'server' (Leif Sahlberg) [1708033]
- [fs] cifs: Use kzfree() to free password (Leif Sahlberg) [1708033]
- [fs] cifs: Fix to use kmem_cache_free() instead of kfree() (Leif Sahlberg) [1708033]
- [fs] cifs: update for current_kernel_time64() removal (Leif Sahlberg) [1708033]
- [fs] cifs: Add DFS cache routines (Leif Sahlberg) [1708033]
- [fs] cifs: Save TTL value when parsing DFS referrals (Leif Sahlberg) [1708033]
- [fs] cifs: auto disable 'serverino' in dfs mounts (Leif Sahlberg) [1708033]
- [fs] cifs: Make devname param optional in cifs_compose_mount_options() (Leif Sahlberg) [1708033]
- [fs] cifs: Skip any trailing backslashes from UNC (Leif Sahlberg) [1708033]
- [fs] cifs: Refactor out cifs_mount() (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix error mapping for SMB2_LOCK command which caused OFD lock problem (Leif Sahlberg) [1708033]
- [fs] CIFS: return correct errors when pinning memory failed for direct I/O (Leif Sahlberg) [1708033]
- [fs] CIFS: use the correct length when pinning memory for direct I/O for write (Leif Sahlberg) [1708033]
- [fs] cifs: check ntwrk_buf_start for NULL before dereferencing it (Leif Sahlberg) [1708033]
- [fs] cifs: remove coverity warning in calc_lanman_hash (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'smb_buf' (Leif Sahlberg) [1708033]
- [fs] cifs: suppress some implicit-fallthrough warnings (Leif Sahlberg) [1708033]
- [fs] cifs: change smb2_query_eas to use the compound query-info helper (Leif Sahlberg) [1708033]
- [fs] Add vers=3.0.2 as a valid option for SMBv3.0.2 (Leif Sahlberg) [1708033]
- [fs] cifs: create a helper function for compound query_info (Leif Sahlberg) [1708033]
- [fs] cifs: address trivial coverity warning (Leif Sahlberg) [1708033]
- [fs] cifs: smb2 commands can not be negative, remove confusing check (Leif Sahlberg) [1708033]
- [fs] cifs: use a compound for setting an xattr (Leif Sahlberg) [1708033]
- [fs] cifs: clean up indentation, replace spaces with tab (Leif Sahlberg) [1708033]
- [fs] smb3: Fix rmdir compounding regression to strict servers (Leif Sahlberg) [1708033]
- [fs] CIFS: Avoid returning EBUSY to upper layer VFS (Leif Sahlberg) [1708033]
- [fs] cifs: Fix separator when building path from dentry (Leif Sahlberg) [1708033]
- [fs] cifs: In Kconfig CONFIG_CIFS_POSIX needs depends on legacy (insecure cifs) (Leif Sahlberg) [1708033]
- [fs] cifs: fix signed/unsigned mismatch on aio_read patch (Leif Sahlberg) [1708033]
- [fs] cifs: don't dereference smb_file_target before null check (Leif Sahlberg) [1708033]
- [fs] CIFS: Add direct I/O functions to file_operations (Leif Sahlberg) [1708033]
- [fs] CIFS: Add support for direct I/O write (Leif Sahlberg) [1708033]
- [fs] CIFS: Add support for direct I/O read (Leif Sahlberg) [1708033]
- [fs] smb3: missing defines and structs for reparse point handling (Leif Sahlberg) [1708033]
- [fs] smb3: allow more detailed protocol info on open files for debugging (Leif Sahlberg) [1708033]
- [fs] smb3: on kerberos mount if server doesn't specify auth type use krb5 (Leif Sahlberg) [1708033]
- [fs] smb3: add trace point for tree connection (Leif Sahlberg) [1708033]
- [fs] cifs: fix spelling mistake, EACCESS -> EACCES (Leif Sahlberg) [1708033]
- [fs] cifs: fix return value for cifs_listxattr (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number for cifs.ko to 2.14 (Leif Sahlberg) [1708033]
- [fs] smb3: add debug for unexpected mid cancellation (Leif Sahlberg) [1708033]
- [fs] cifs: allow calling SMB2_xxx_free(NULL) (Leif Sahlberg) [1708033]
- [fs] smb3 - clean up debug output displaying network interfaces (Leif Sahlberg) [1708033]
- [fs] smb3: show number of current open files in /proc/fs/cifs/Stats (Leif Sahlberg) [1708033]
- [fs] cifs: add support for ioctl on directories (Leif Sahlberg) [1708033]
- [fs] cifs: fallback to older infolevels on findfirst queryinfo retry (Leif Sahlberg) [1708033]
- [fs] smb3: do not attempt cifs operation in smb3 query info error path (Leif Sahlberg) [1708033]
- [fs] smb3: send backup intent on compounded query info (Leif Sahlberg) [1708033]
- [fs] cifs: track writepages in vfs operation counters (Leif Sahlberg) [1708033]
- [fs] smb2: fix uninitialized variable bug in smb2_ioctl_query_info (Leif Sahlberg) [1708033]
- [fs] cifs: add IOCTL for QUERY_INFO passthrough to userspace (Leif Sahlberg) [1708033]
- [fs] cifs: minor clarification in comments (Leif Sahlberg) [1708033]
- [fs] CIFS: Print message when attempting a mount (Leif Sahlberg) [1708033]
- [fs] CIFS: Adds information-level logging function (Leif Sahlberg) [1708033]
- [fs] cifs: OFD locks do not conflict with eachothers (Leif Sahlberg) [1708033]
- [fs] CIFS: SMBD: Do not call ib_dereg_mr on invalidated memory registration (Leif Sahlberg) [1708033]
- [fs] CIFS: pass page offsets on SMB1 read/write (Leif Sahlberg) [1708033]
- [fs] fs/cifs: fix uninitialised variable warnings (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for sending lease break responses to server (Leif Sahlberg) [1708033]
- [fs] cifs: do not return atime less than mtime (Leif Sahlberg) [1708033]
- [fs] smb3: update default requested iosize to 4MB from 1MB for recent dialects (Leif Sahlberg) [1708033]
- [fs] smb3: Add debug message later in smb2/smb3 reconnect path (Leif Sahlberg) [1708033]
- [fs] CIFS: make 'nodfs' mount opt a superblock flag (Leif Sahlberg) [1708033]
- [fs] smb3: track the instance of each session for debugging (Leif Sahlberg) [1708033]
- [fs] smb3: minor missing defines relating to reparse points (Leif Sahlberg) [1708033]
- [fs] smb3: add way to control slow response threshold for logging and stats (Leif Sahlberg) [1708033]
- [fs] cifs: minor updates to module description for cifs.ko (Leif Sahlberg) [1708033]
- [fs] cifs: protect against server returning invalid file system block size (Leif Sahlberg) [1708033]
- [fs] smb3: allow stats which track session and share reconnects to be reset (Leif Sahlberg) [1708033]
- [fs] SMB3: Backup intent flag missing from compounded ops (Leif Sahlberg) [1708033]
- [fs] cifs: create a define for the max number of iov we need for a SMB2 set_info (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_RENAME and SMB2_OP_HARDLINK to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: remove the is_falloc argument to SMB2_set_eof (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_SET_INFO to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_SET_EOF to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: make rmdir() use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: create helpers for SMB2_set_info_init/free() (Leif Sahlberg) [1708033]
- [fs] cifs: change unlink to use a compound (Leif Sahlberg) [1708033]
- [fs] cifs: change mkdir to use a compound (Leif Sahlberg) [1708033]
- [fs] cifs: add a smb2_compound_op and change QUERY_INFO to use it (Leif Sahlberg) [1708033]
- [fs] cifs: fix a credits leak for compund commands (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint to catch cases where credit refund of failed op overlaps reconnect (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'cifs_sb' (Leif Sahlberg) [1708033]
- [fs] cifs: Use kmemdup rather than duplicating its implementation in smb311_posix_mkdir() (Leif Sahlberg) [1708033]
- [fs] smb3: do not display confusing message on mount to Azure servers (Leif Sahlberg) [1708033]
- [fs] smb3: fix lease break problem introduced by compounding (Leif Sahlberg) [1708033]
- [fs] cifs: only wake the thread for the very last PDU in a compound (Leif Sahlberg) [1708033]
- [fs] cifs: add a warning if we try to to dequeue a deleted mid (Leif Sahlberg) [1708033]
- [fs] smb2: fix missing files in root share directory listing (Leif Sahlberg) [1708033]
- [fs] cifs: read overflow in is_valid_oplock_break() (Leif Sahlberg) [1708033]
- [fs] cifs: integer overflow in in SMB2_ioctl() (Leif Sahlberg) [1708033]
- [fs] CIFS: fix wrapping bugs in num_entries() (Leif Sahlberg) [1708033]
- [fs] cifs: prevent integer overflow in nxt_dir_entry() (Leif Sahlberg) [1708033]
- [fs] fs/cifs: suppress a string overflow warning (Leif Sahlberg) [1708033]
- [fs] cifs: connect to servername instead of IP for IPC$ share (Leif Sahlberg) [1708033]
- [fs] smb3: check for and properly advertise directory lease support (Leif Sahlberg) [1708033]
- [fs] smb3: minor debugging clarifications in rfc1001 len processing (Leif Sahlberg) [1708033]
- [fs] SMB3: Backup intent flag missing for directory opens with backupuid mounts (Leif Sahlberg) [1708033]
- [fs] fs/cifs: don't translate SFM_SLASH (U+F026) to backslash (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number for cifs.ko to 2.12 (Leif Sahlberg) [1708033]
- [fs] cifs: check kmalloc before use (Leif Sahlberg) [1708033]
- [fs] cifs: check if SMB2 PDU size has been padded and suppress the warning (Leif Sahlberg) [1708033]
- [fs] cifs: create a define for how many iovs we need for an SMB2_open() (Leif Sahlberg) [1708033]
- [fs] smb3: create smb3 equivalent alias for cifs pseudo-xattrs (Leif Sahlberg) [1708033]
- [fs] smb3: allow previous versions to be mounted with snapshot= mount parm (Leif Sahlberg) [1708033]
- [fs] cifs: don't show domain= in mount output when domain is empty (Leif Sahlberg) [1708033]
- [fs] cifs: add missing support for ACLs in SMB 3.11 (Leif Sahlberg) [1708033]
- [fs] smb3: enumerating snapshots was leaving part of the data off end (Leif Sahlberg) [1708033]
- [fs] cifs: update smb2_queryfs() to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: update receive_encrypted_standard to handle compounded responses (Leif Sahlberg) [1708033]
- [fs] cifs: create SMB2_open_init()/SMB2_open_free() helpers. (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_query_info_[init|free]() (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_close_init()/SMB2_close_free() (Leif Sahlberg) [1708033]
- [fs] smb3: display stats counters for number of slow commands (Leif Sahlberg) [1708033]
- [fs] CIFS: fix uninitialized ptr deref in smb2 signing (Leif Sahlberg) [1708033]
- [fs] smb3: Do not send SMB3 SET_INFO if nothing changed (Leif Sahlberg) [1708033]
- [fs] smb3: fix minor debug output for CONFIG_CIFS_STATS (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for slow responses (Leif Sahlberg) [1708033]
- [fs] cifs: add compound_send_recv() (Leif Sahlberg) [1708033]
- [fs] cifs: make smb_send_rqst take an array of requests (Leif Sahlberg) [1708033]
- [fs] cifs: update init_sg, crypt_message to take an array of rqst (Leif Sahlberg) [1708033]
- [fs] smb3: fix reset of bytes read and written stats (Leif Sahlberg) [1708033]
- [fs] smb3: display bytes_read and bytes_written in smb3 stats (Leif Sahlberg) [1708033]
- [fs] cifs: simple stats should always be enabled (Leif Sahlberg) [1708033]
- [fs] cifs: use a refcount to protect open/closing the cached file handle (Leif Sahlberg) [1708033]
- [fs] smb3: add reconnect tracepoints (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for session expired or deleted (Leif Sahlberg) [1708033]
- [fs] cifs: remove unused stats (Leif Sahlberg) [1708033]
- [fs] smb3: don't request leases in symlink creation and query (Leif Sahlberg) [1708033]
- [fs] smb3: remove per-session operations from per-tree connection stats (Leif Sahlberg) [1708033]
- [fs] SMB3: Number of requests sent should be displayed for SMB3 not just CIFS (Leif Sahlberg) [1708033]
- [fs] smb3: snapshot mounts are read-only and make sure info is displayable about the mount (Leif Sahlberg) [1708033]
- [fs] smb3: remove noisy warning message on mount (Leif Sahlberg) [1708033]
- [fs] cifs: add missing debug entries for kconfig options (Leif Sahlberg) [1708033]
- [fs] smb3: fill in statfs fsid and correct namelen (Leif Sahlberg) [1708033]
- [fs] cifs: Make sure all data pages are signed correctly (Leif Sahlberg) [1708033]
- [fs] CIFS: fix memory leak and remove dead code (Leif Sahlberg) [1708033]
- [fs] cifs: use 64-bit timestamps for fscache (Leif Sahlberg) [1708033]
- [fs] cifs: use timespec64 internally (Leif Sahlberg) [1708033]
- [fs] cifs: Silence uninitialized variable warning (Leif Sahlberg) [1708033]
- [fs] fs/cifs: Simplify ib_post_(send|recv|srq_recv)() calls (Leif Sahlberg) [1708033]

* Mon May 20 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-92.el8]
- [edac] EDAC/amd64: Set maximum channel layer size depending on family (Gary Hook) [1690984]
- [edac] EDAC/amd64: Adjust printed chip select sizes when interleaved (Gary Hook) [1690984]
- [edac] EDAC/amd64: Recognize x16 symbol size (Gary Hook) [1690984]
- [edac] EDAC/amd64: Support more than two Unified Memory Controllers (Gary Hook) [1690984]
- [edac] EDAC/amd64: Use a macro for iterating over Unified Memory Controllers (Gary Hook) [1690984]
- [edac] EDAC, amd64: Add Family 17h, models 10h-2fh support (Gary Hook) [1670609 1690984]
- [md] dm mpath: fix missing call of path selector type->end_io (Mike Snitzer) [1686227]
- [rpmspec] redhat: do not generate debuginfo for self-tests and samples (Ivan Vecera) [1708375]
- [netdrv] broadcom: Mark expected switch fall-throughs (Kamal Heib) [1684380]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Kamal Heib) [1684380]
- [netdrv] broadcom: tg3: fix use of SPEED_UNKNOWN ethtool constant (Kamal Heib) [1684380]
- [netdrv] tg3: allow ethtool -p to work for NICs in down state (Kamal Heib) [1684380]
- [netdrv] tg3: optionally use eth_platform_get_mac_address() to get mac address (Kamal Heib) [1684380]
- [netdrv] tg3: extend PTP gettime function to read system clock (Kamal Heib) [1684380]
- [netdrv] tg3: Fix fall-through annotations (Kamal Heib) [1684380]
- [netdrv] tg3: Mark expected switch fall-throughs (Kamal Heib) [1684380]
- [mm] x86/mm/KASLR: Fix the size of the direct mapping section (Baoquan He) [1669075]
- [netdrv] net/mlx4_en: fix spelling mistake: "quiting" -> "quitting" (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix error handling when initializing CQ bufs in the driver (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Add masking for a few queries on HCA caps (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Fix using wrong function to destroy sqp AHs under SRIOV (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4: replace pci_{,un}map_sg with dma_{,un}map_sg (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4: Get rid of page operation after dma_alloc_coherent (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: drop useless LIST_HEAD (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Remove set but not used variable 'pd' (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Utilize macro to calculate SQ spare size (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_en: remove fallback after kzalloc_node() (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Remove unneeded NULL check (Alaa Hleihel) [1691235 1691228]
- [infiniband] mlx4: Use snprintf instead of complicated strcpy (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix several coding style errors (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix return codes of unsupported operations (Alaa Hleihel) [1691235 1691228]
- [netdrv] {net, IB}/mlx4: Initialize CQ buffers in the driver when possible (Alaa Hleihel) [1691235 1691228]
- [netdrv] mlx4: use __vlan_hwaccel helpers (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_en: Fix build break when CONFIG_INET is off (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_en: use __netdev_tx_sent_queue() (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_en: add a missing <net/ip.h> include (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Add port and TID to MAD debug print (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Enable debug print of SMPs (Alaa Hleihel) [1691233 1691228]
- [infiniband] RDMA: Fix dependencies for rdma_user_mmap_io (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Remove unnecessary parentheses (Alaa Hleihel) [1691233 1691228]
- [infiniband] RDMA/mlx4: Use rdma_user_mmap_io (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_core: Fix warnings during boot on driverinit param set failures (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Use devlink region_snapshot parameter (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Add Crdump FW snapshot support (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Add health buffer address capability (Alaa Hleihel) [1691228]
- [netdrv] mlx4: Add support for devlink reload and load driverinit values (Alaa Hleihel) [1691228 1663198]
- [netdrv] mlx4: Add mlx4 initial parameters table and register it (Alaa Hleihel) [1691228 1663198]
- [infiniband] IB/mlx4: Create slave AH's directly (Alaa Hleihel) [1691228]
- [infiniband] IB/mlx4: Add support for drain SQ & RQ (Alaa Hleihel) [1691228]
- [net] openvswitch: return an error instead of doing BUG_ON() (Eelco Chaudron) [1700468]
- [include] net: add netif_is_geneve() (Petr Oros) [1707002]
- [netdrv] team: fix possible recursive locking when add slaves (Hangbin Liu) [1700679]
- [netdrv] phy: Fix ioctl handler when modifing MII_ADVERTISE (Petr Oros) [1691676]
- [netdrv] mii: Add mii_lpa_mod_linkmode_lpa_t (Petr Oros) [1691676]
- [netdrv] phy: marvell: Rename mii_lpa_to_linkmode_lpa_t (Petr Oros) [1691676]
- [netdrv] mii: Rename mii_stat1000_to_linkmode_lpa_t (Petr Oros) [1691676]
- [include] mii: Fix autoneg in mii_lpa_to_linkmode_lpa_t() (Petr Oros) [1691676]
- [netdrv] phy: remove unused code in phy_probe (Petr Oros) [1691676]
- [netdrv] phy: check if advertising is zero using linkmode_empty (Petr Oros) [1691676]
- [netdrv] phy: marvell: remove set but not used variable 'pause' (Petr Oros) [1691676]
- [netdrv] phy: Add support for resolving 5G and 2.5G autoneg (Petr Oros) [1691676]
- [netdrv] phy: Add more link modes to the settings table (Petr Oros) [1691676]
- [netdrv] phy: Fixup kerneldoc markup. (Petr Oros) [1691676]
- [netdrv] phy: Convert u32 phydev->lp_advertising to linkmode (Petr Oros) [1691676]
- [netdrv] ethernet: Convert phydev advertize and supported from u32 to link mode (Petr Oros) [1691676]
- [netdrv] bonding: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [netdrv] bonding: Give bond_set_dev_addr() a return value (Ivan Vecera) [1705509]
- [netdrv] ipvlan: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] bridge: Handle NETDEV_PRE_CHANGEADDR from ports (Ivan Vecera) [1705509]
- [net] bridge: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Add NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Add extack argument to dev_set_mac_address() (Ivan Vecera) [1705509]
- [netdrv] phy: phy driver features are mandatory (Petr Oros) [1691720]
- [netdrv] phy: add missing phy driver features (Petr Oros) [1691720]
- [netdrv] phy: Add missing features to PHY drivers (Petr Oros) [1691720]
- [netdrv] phy: genphy_10g_driver: Avoid NULL pointer dereference (Petr Oros) [1691720]
- [netdrv] phy: phy_support_sym_pause: Clear Asym Pause (Petr Oros) [1691720]
- [netdrv] phy: Replace phy driver features u32 with link_mode bitmap (Petr Oros) [1691720]
- [netdrv] ethernet: xgbe: expand PHY_GBIT_FEAUTRES (Petr Oros) [1691720]
- [net] net: phy: Add limkmode equivalents to some of the MII ethtool helpers (Petr Oros) [1691720]
- [netdrv] phy: Add helper for advertise to lcl value (Petr Oros) [1691720]
- [net] phy: Add helper to convert MII ADV register to a linkmode (Petr Oros) [1691720]
- [netdrv] phy: Add phydev_info() (Petr Oros) [1691720]
- [netdrv] phy: Add phydev_warn() (Petr Oros) [1691720]
- [netdrv] phy: Move linkmode helpers to somewhere public (Petr Oros) [1691720]
- [netdrv] ethernet: dpaa: remove unused variables (Petr Oros) [1691720]
- [netdrv] ravb: Disable Pause Advertisement (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper to determine if pause configuration is supported (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for set_pauseparam for Pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for set_pauseparam for Asym Pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for MACs which support pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for MACs which support asym pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper to remove a supported link mode (Petr Oros) [1691720]
- [netdrv] ethernet: Fix up drivers masking pause support (Petr Oros) [1691720]
- [netdrv] bcmgenet: Fix speed selection for reverse MII (Petr Oros) [1691720]
- [netdrv] ethernet: Use phy_set_max_speed() to limit advertised speed (Petr Oros) [1691720]
- [netdrv] phy: bcm63xx: Allow to be built with COMPILE_TEST (Petr Oros) [1691720]
- [netdrv] phy: et1011c: Remove incorrect missing 1000 Half (Petr Oros) [1691720]
- [netdrv] phy: ste10Xp: Remove wrong SUPPORTED_Pause (Petr Oros) [1691720]
- [tools] selftests: net: ip_defrag: cover new IPv6 defrag behavior (Guillaume Nault) [1660282]
- [tools] selftests: net: fix/improve ip_defrag selftest (Guillaume Nault) [1660282]
- [tools] selftests: use posix-style redirection in ip_defrag.sh (Guillaume Nault) [1660282]
- [tools] selftests: net: Clean up an unused variable (Guillaume Nault) [1660282]
- [tools] selftests/net: add ipv6 tests to ip_defrag selftest (Guillaume Nault) [1660282]
- [tools] selftests/net: add ip_defrag selftest (Guillaume Nault) [1660282]
- [net] ip6: fix skb leak in ip6frag_expire_frag_queue() (Guillaume Nault) [1660282]
- [net] IP6 defrag: use rbtrees in nf_conntrack_reasm.c (Guillaume Nault) [1660282]
- [net] IP6 defrag: use rbtrees for IPv6 defrag (Guillaume Nault) [1660282]
- [net] IP defrag: encapsulate rbtree defrag code into callable functions (Guillaume Nault) [1660282]
- [net] ipv4: do not handle duplicate fragments as overlapping (Guillaume Nault) [1660282]
- [net] ipv4: ipv6: netfilter: Adjust the frag mem limit when truesize changes (Guillaume Nault) [1660282]
- [net] ipv6: remove dependency of nf_defrag_ipv6 on ipv6 module (Guillaume Nault) [1660282]
- [net] ipv6: fix typo in net/ipv6/reassembly.c (Guillaume Nault) [1660282]
- [net] core: dev: Attach extack to NETDEV_PRE_UP (Ivan Vecera) [1705501]
- [net] core: dev: Add call_netdevice_notifiers_extack() (Ivan Vecera) [1705501]
- [net] core: dev: Add extack argument to __dev_change_flags() (Ivan Vecera) [1705501]
- [net] core: dev: Add extack argument to dev_change_flags() (Ivan Vecera) [1705501]
- [netdrv] ipvlan: ipvlan_set_port_mode(): Add an extack argument (Ivan Vecera) [1705501]
- [netdrv] vrf: cycle_netdev(): Add an extack argument (Ivan Vecera) [1705501]
- [net] net: core: dev: Add extack argument to dev_open() (Ivan Vecera) [1705501]
- [net] vlan: conditional inclusion of FCoE hooks to match netdevice.h and bnx2x (Chris Leech) [1685894]
- [net] Do not route unicast IP packets twice (Ivan Vecera) [1704923]
- [net] skbuff: Rename 'offload_mr_fwd_mark' to 'offload_l3_fwd_mark' (Ivan Vecera) [1704923]
- [net] devlink: Add 'fw_load_policy' generic parameter (Ivan Vecera) [1704902]
- [net] bridge: Extend br_vlan_get_pvid() for bridge ports (Ivan Vecera) [1704863]
- [net] ipv4: Notify about changes to ip_forward_update_priority (Ivan Vecera) [1704697]
- [net] ipv4: Control SKB reprioritization after forwarding (Ivan Vecera) [1704697]
- [net] dcb: Add priority-to-DSCP map getters (Ivan Vecera) [1704639]
- [net] xsk: export xdp_get_umem_from_qid (Ivan Vecera) [1704606]
- [net] net: Add lag.h, net_lag_port_dev_txable() (Ivan Vecera) [1704297]
- [netdrv] team: Publish team_port_get_rcu() (Ivan Vecera) [1704297]
- [net] sched: sch_api: set an error msg when qdisc_alloc_handle() fails (Ivan Vecera) [1677094]
- [net] ethtool: Remove unnecessary null check in ethtool_rx_flow_rule_create (Ivan Vecera) [1691738]
- [net] flow_offload: fix block stats (Ivan Vecera) [1691738]
- [net] sched: flower: only return error from hw offload if skip_sw (Ivan Vecera) [1691738]
- [net] flow_offload: Fix flow action infrastructure (Ivan Vecera) [1691738]
- [net] ethtool: add ethtool_rx_flow_spec to flow_rule structure translator (Ivan Vecera) [1691738]
- [net] flow_offload: add wake-up-on-lan and queue to flow_action (Ivan Vecera) [1691738]
- [net] flow_offload: add statistics retrieval infrastructure and use it (Ivan Vecera) [1691738]
- [net] cls_api: add translator to flow_action representation (Ivan Vecera) [1691738]
- [net] flow_offload: add flow action infrastructure (Ivan Vecera) [1691738]
- [net] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1691738]
- [net] netfilter: ipv6: Don't preserve original oif for loopback address (Florian Westphal) [1702813]
- [net] netfilter: ipv6: Preserve link scope traffic original oif (Florian Westphal) [1702813]
- [net] sctp: implement memory accounting on rx path (Xin Long) [1665243] {CVE-2019-3874}
- [net] sctp: implement memory accounting on tx path (Xin Long) [1665243] {CVE-2019-3874}
- [net] openvswitch: fix flow actions reallocation (Eelco Chaudron) [1700468]
- [net] openvswitch: fix missing checks for nla_nest_start (Eelco Chaudron) [1700468]
- [net] openvswitch: fix a NULL pointer dereference (Eelco Chaudron) [1700468]
- [net] openvswitch: meter: Use struct_size() in kzalloc() (Eelco Chaudron) [1700468]
- [net] openvswitch: Fix IPv6 later frags parsing (Eelco Chaudron) [1700468]
- [net] openvswitch: fix spelling mistake "execeeds" -> "exceeds" (Eelco Chaudron) [1700468]
- [net] openvswitch: remove BUG_ON from get_dpdev (Eelco Chaudron) [1700468]
- [net] openvswitch: fix linking without CONFIG_NF_CONNTRACK_LABELS (Eelco Chaudron) [1700468]
- [net] revert "openvswitch: Fix template leak in error cases." (Eelco Chaudron) [1700468]
- [net] openvswitch: Use correct reply values in datapath and vport ops (Eelco Chaudron) [1700468]
- [net] ovs: fix return type of ndo_start_xmit function (Eelco Chaudron) [1700468]
- [net] openvswitch: Derive IP protocol number for IPv6 later frags (Eelco Chaudron) [1700468]
- [net] openvswitch: kernel datapath clone action (Eelco Chaudron) [1700468]
- [net] openvswitch: Avoid OOB read when parsing flow nlattrs (Eelco Chaudron) [1700468]
- [net] net/vlan: remove unused #define HAVE_VLAN_GET_TAG (Ivan Vecera) [1700369]
- [net] vlan: include the shift in skb_vlan_tag_get_prio() (Ivan Vecera) [1700369]
- [net] vlan: introduce __vlan_hwaccel_copy_tag() helper (Ivan Vecera) [1700369]
- [net] vlan: introduce __vlan_hwaccel_clear_tag() helper (Ivan Vecera) [1700369]
- [net] sctp: initialize _pad of sockaddr_in before copying to user memory (Xin Long) [1699076]
- [net] sctp: use memdup_user instead of vmemdup_user (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_STREAM_SCHEDULER sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_EVENT sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_ENABLE_STREAM_RESET sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_PRINFO sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_DEACTIVATE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_DELETE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_ACTIVE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_MAX_BURST sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_CONTEXT sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_SNDINFO sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DELAYED_SACK sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_SEND_PARAM sockopt (Xin Long) [1699076]
- [net] sctp: not copy sctp_sock pd_lobby in sctp_copy_descendant (Xin Long) [1699076]
- [net] sctp: get sctphdr by offset in sctp_compute_cksum (Xin Long) [1699076]
- [net] sctp: call sctp_auth_init_hmacs() in sctp_sock_migrate() (Xin Long) [1699076]
- [net] sctp: move up sctp_auth_init_hmacs() in sctp_endpoint_init() (Xin Long) [1699076]
- [net] sctp: sctp_sock_migrate() returns error if sctp_bind_addr_dup() fails (Xin Long) [1699076]
- [net] sctp: remove sched init from sctp_stream_init (Xin Long) [1699076]
- [net] sctp: call iov_iter_revert() after sending ABORT (Xin Long) [1699076]
- [net] ipvs: get sctphdr by sctphoff in sctp_csum_check (Xin Long) [1699076]
- [net] sctp: chunk.c: correct format string for size_t in printk (Xin Long) [1699076]
- [net] sctp: don't compare hb_timer expire date before starting it (Xin Long) [1699076]
- [net] doc: sctp: Merge and clean up rst files (Xin Long) [1699076]
- [net] sctp: set stream ext to NULL after freeing it in sctp_stream_outq_migrate (Xin Long) [1699076]
- [net] sctp: add SCTP_FUTURE_ASOC and SCTP_CURRENT_ASSOC for SCTP_STREAM_SCHEDULER sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_EVENT sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_ENABLE_STREAM_RESET sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_PRINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_DEACTIVATE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_DELETE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_ACTIVE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_MAX_BURST sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_CONTEXT sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_SNDINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_SEND_PARAM sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DELAYED_SACK sockopt (Xin Long) [1699076]
- [net] sctp: add SCTP_CURRENT_ASSOC for SCTP_STREAM_SCHEDULER_VALUE sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_INTERLEAVING_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_RECONFIG_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_PR_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: add SCTP_FUTURE_ASSOC for SCTP_PEER_ADDR_THLDS sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_LOCAL_AUTH_CHUNKS sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_MAXSEG sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_ASSOCINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_RTOINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_PEER_ADDR_PARAMS sockopt (Xin Long) [1699076]
- [net] sctp: introduce SCTP_FUTURE/CURRENT/ALL_ASSOC (Xin Long) [1699076]
- [net] sctp: set flow sport from saddr only when it's 0 (Xin Long) [1699076]
- [net] sctp: set chunk transport correctly when it's a new asoc (Xin Long) [1699076]
- [net] sctp: improve the events for sctp stream adding (Xin Long) [1699076]
- [net] sctp: improve the events for sctp stream reset (Xin Long) [1699076]
- [net] sctp: allocate sctp_sockaddr_entry with kzalloc (Xin Long) [1699076]
- [net] sctp: initialize sin6_flowinfo for ipv6 addrs in sctp_inet6addr_event (Xin Long) [1699076]
- [net] sctp: frag_point sanity check (Xin Long) [1699076]
- [net] sctp: kfree_rcu asoc (Xin Long) [1699076]
- [net] sctp: update frag_point when stream_interleave is set (Xin Long) [1699076]
- [net] sctp: add sockopt SCTP_EVENT (Xin Long) [1699076]
- [net] sctp: rename enum sctp_event to sctp_event_type (Xin Long) [1699076]
- [net] sctp: add subscribe per asoc (Xin Long) [1699076]
- [net] sctp: define subscribe in sctp_sock as __u16 (Xin Long) [1699076]
- [net] sctp: process sk_reuseport in sctp_get_port_local (Xin Long) [1699076]
- [net] sctp: add sock_reuseport for the sock in __sctp_hash_endpoint (Xin Long) [1699076]
- [net] sctp: do reuseport_select_sock in __sctp_rcv_lookup_endpoint (Xin Long) [1699076]
- [net] sctp: Fix SKB list traversal in sctp_intl_store_ordered(). (Xin Long) [1699076]
- [net] sctp: Fix SKB list traversal in sctp_intl_store_reasm(). (Xin Long) [1699076]
- [net] sctp: define SCTP_SS_DEFAULT for Stream schedulers (Xin Long) [1699076]
- [net] sctp: clear the transport of some out_chunk_list chunks in sctp_assoc_rm_peer (Xin Long) [1699076]
- [net] sctp: use sk_wmem_queued to check for writable space (Xin Long) [1699076]
- [net] sctp: count both sk and asoc sndbuf with skb truesize and sctp_chunk size (Xin Long) [1699076]
- [net] sctp: use the pmtu from the icmp packet to update transport pathmtu (Xin Long) [1699076]
- [net] sctp: fix fall-through annotation (Xin Long) [1699076]
- [net] sctp: Use skb_queue_is_first(). (Xin Long) [1699076]
- [net] sctp: not traverse asoc trans list if non-ipv6 trans exists for ipv6_flowlabel (Xin Long) [1699076]
- [net] sctp: fix invalid reference to the index variable of the iterator (Xin Long) [1699076]
- [net] sctp: remove useless start_fail from sctp_ht_iter in proc (Xin Long) [1699076]
- [net] sctp: Make wrappers for accessing in/out streams (Xin Long) [1699076]
- [net] sctp: whitespace fixes (Xin Long) [1699076]
- [net] sctp: check for ipv6_pinfo legal sndflow with flowlabel in sctp_v6_get_dst (Xin Long) [1699076]
- [net] sctp: add support for setting flowlabel when adding a transport (Xin Long) [1699076]
- [net] sctp: add spp_ipv6_flowlabel and spp_dscp for sctp_paddrparams (Xin Long) [1699076]
- [net] sctp: add support for dscp and flowlabel per transport (Xin Long) [1699076]
- [net] ipv4: add __ip_queue_xmit() that supports tos param (Xin Long) [1699076]
- [net] sctp: add support for SCTP_REUSE_PORT sockopt (Xin Long) [1699076]
- [netdrv] pptp: dst_release sk_dst_cache in pptp_sock_destruct (Xin Long) [1671606]
- [net] datagram: fix unbounded loop in __skb_try_recv_datagram() (Paolo Abeni) [1692379]
- [net] ipv6: route: purge exception on removal (Paolo Abeni) [1669049]
- [net] vsock: cope with memory allocation failure at socket creation time (Paolo Abeni) [1671619]
- [net] ptp: fix Spectre v1 vulnerability (Hangbin Liu) [1664624]

* Fri May 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-91.el8]
- [infiniband] RDMA/bnxt_re: fix or'ing of data into an uninitialized struct member (Selvin Xavier) [1664798]
- [netdrv] RDMA/bnxt_en: Enable RDMA driver support for 57500 chip (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Update kernel user abi to pass chip context (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add extended psn structure for 57500 adapters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Enable GSI QP support for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Skip backing store allocation for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add 64bit doorbells for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add chip context to identify 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: fix a size calculation (Selvin Xavier) [1664798]
- [infiniband] infiniband: bnxt_re: qplib: Check the return value of send_message (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Increase depth of control path command queue (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Query HWRM Interface version from FW (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Make use of destroy AH sleepable flag (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Make use of create AH sleepable flag (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid accessing the device structure after it is freed (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix system hang when registration with L2 driver fails (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid resource leak in case the NQ registration fails (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Wait for delayed work to finish before device removal (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Limit max_pkey to 16 bit value (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix qp async event reporting (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Report out of sequence hw counters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Expose rx discards and drop counters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Prevent driver crash due to NULL pointer in error message print (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Drop L2 async events silently (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid accessing nq->bar_reg_iomem in failure case (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid NULL check after accessing the pointer (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Remove the unnecessary version macro definition (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix recursive lock warning in debug kernel (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add missing spin lock initialization (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: QPLIB: Add and use #define dev_fmt(fmt) "QPLIB: " fmt (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Modify a fall-through annotation (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix a bunch of off by one bugs in qplib_fp.c (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix a couple off by one bugs (Selvin Xavier) [1664798]
- [powerpc] powerpc/fadump: Do not allow hot-remove memory from fadump reserved area. (Gustavo Duarte) [1524686]
- [powerpc] powerpc/fadump: Throw proper error message on fadump registration failure (Gustavo Duarte) [1524686]
- [powerpc] powerpc/fadump: Reservationless firmware assisted dump (Gustavo Duarte) [1524686]
- [infiniband] IB/hfi1: Fix WQ_MEM_RECLAIM warning (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Implement CCA for TID RDMA protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove WARN_ON when freeing expected receive groups (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Unify the software PSN check for TID RDMA READ/WRITE (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to read next expected psn from hardware flow (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Delay the release of destination mr for TID RDMA WRITE DATA (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Do not flush send queue in the TID RDMA second leg (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix the allocation of RSM table (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Eliminate opcode tests on mr deref (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Clear the IOWAIT pending bits when QP is put into error state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Failed to drain send queue when QP is put into error state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add missing break in switch statement (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix a build warning for TID RDMA READ (Alex Estrin) [1660618]
- [infiniband] RDMA/rdmavt: Adapt to handle non-uniform sizes on umem SGEs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prioritize the sending of ACK packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for TID RDMA WRITE protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Enable TID RDMA WRITE protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add interlock between TID RDMA WRITE and other requests (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA WRITE functionality into RDMA verbs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the dual leg code (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the TID second leg ACK packet builder (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the TID second leg send packet builder (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Resend the TID RDMA WRITE DATA packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA RESYNC packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA RESYNC packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA retry timer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA ACK packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA ACK packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA WRITE DATA packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA WRITE DATA packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA WRITE response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID resource timer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA WRITE response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA WRITE request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add an s_acked_ack_queue pointer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Allow for extra entries in QP's s_ack_queue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Build TID RDMA WRITE request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for TID RDMA READ protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Enable TID RDMA READ protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add interlock between a TID RDMA request and other requests (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Integrate TID RDMA READ protocol into RC protocol (Alex Estrin) [1660618]
- [include] IB/hfi1: Increment the retry timeout value for TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions for restarting TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA handlers (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA READ response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA READ response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Set PbcInsertHcrc for TID RDMA packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to build TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for flow and TID management functions (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the counter n_tidwait (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: TID RDMA RcvArray programming and TID allocation (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: TID RDMA flow allocation (Alex Estrin) [1660618]
- [infiniband] IB/hfi: Move RC functions into a header file (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for OPFN (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Integrate OPFN into RC transactions (Alex Estrin) [1660618]
- [infiniband] IB/hfi1, IB/rdmavt: Allow for extending of QP's s_ack_queue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: OPFN interface (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add OPFN helper functions for TID RDMA feature (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: OPFN support discovery (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1, qib, rvt} Cleanup open coded sge usage (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1,qib}: Cleanup open coded sge sizing (Alex Estrin) [1660618]
- [infiniband] RDMA/qib: Use GUP longterm for PSM page pining (Alex Estrin) [1660618]
- [infiniband] infiniband: qib: no need to check return value of debugfs_create functions (Alex Estrin) [1660618]
- [infiniband] infiniband: hfi1: no need to check return value of debugfs_create functions (Alex Estrin) [1660618]
- [infiniband] infiniband: hfi1: drop crazy DEBUGFS_SEQ_FILE_CREATE() macro (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1, qib}: Fix WC.byte_len calculation for UD_SEND_WITH_IMM (Alex Estrin) [1660618]
- [infiniband] IB/qib: Fix an error code in qib_sdma_verbs_send() (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Reduce lock contention on iowait_lock for sdma and pio (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Close VNIC sdma_progress sleep window (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Allow the driver to initialize QP priv struct (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add OPFN and TID RDMA capability bits (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Unreserve a reserved request when it is completed (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Consider LMC in 16B/bypass ingress packet check (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Limit VNIC use of SDMA engines to the available count (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Correctly process FECN and BECN in packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Ignore LNI errors before DC8051 transitions to Polling state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Dump pio info for non-user send contexts (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix a latency issue for small messages (Alex Estrin) [1660618]
- [infiniband] RDMA/qib: Remove all occurrences of BUG_ON() (Alex Estrin) [1660618]
- [infiniband] IB/qib: fix spelling mistake "colescing" -> "coalescing" (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Use VL15 for SM packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add mtu check for operational data VLs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for iowait (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prepare resource waits for dual leg (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Error path MAD response size is incorrect (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move UnsupportedVL bits definitions to the correct header (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: set_intr_bits uses incorrect source for register modification (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Missing return value in error path for user sdma (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Right size user_sdma sequence numbers and related variables (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move URGENT IRQ enable to hfi1_rcvctrl() (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rework the IRQ API to be more flexible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: PCIe bus width retry (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Make the MSIx resource allocation a bit more flexible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prepare for new HFI1 MSIx API (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Get the hfi1_devdata structure as early as possible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: tune_pcie_caps is arbitrarily placed, poorly (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove duplicated defines (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rework file list in Makefile (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove incorrect call to do_interrupt callback (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Set in_use_ctxts bits for user ctxts only (Alex Estrin) [1660618]
- [include] include/rdma/opa_addr.h: Fix an endianness issue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove INTx support and simplify MSIx usage (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Reorg ctxtdata and rightsize fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove caches of chip CSRs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove unused/writeonly devdata fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rightsize ctxt_eager_bufs fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvctrl from ctxtdata (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvhdrq_size (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvhdrsize (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move rhf_offset from devdata to ctxtdata (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move normal functions from hfi1_devdata to const array (Alex Estrin) [1660618]
- [infiniband] scsi: RDMA/srpt: Fix handling of TMF submission failure (Jonathan Toppins) [1685313]
- [infiniband] scsi: RDMA/srpt: Fix a credit leak for aborted commands (Jonathan Toppins) [1685313]
- [net] xprtrdma: Reduce the doorbell rate (Receive) (Jonathan Toppins) [1685313]
- [net] xprtrdma: Fix sparse warnings (Jonathan Toppins) [1685313]
- [net] xprtrdma: Fix helper that drains the transport (Jonathan Toppins) [1685313]
- [netdrv] enic: fix build warning without CONFIG_CPUMASK_OFFSTACK (Jonathan Toppins) [1685313]
- [infiniband] IB/usnic: Fix out of bounds index check in query pkey (Jonathan Toppins) [1685313]
- [infiniband] IB/usnic: Remove stub functions (Jonathan Toppins) [1685313]
- [infiniband] rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE use (Jonathan Toppins) [1685313]
- [infiniband] RDMA/ucontext: Fix regression with disassociate (Jonathan Toppins) [1685313]
- [infiniband] IB/iser: Fix dma_nents type definition (Jonathan Toppins) [1685313]
- [infiniband] IB/iser: Pass the correct number of entries for dma mapped SGL (Jonathan Toppins) [1685313]
- [infiniband] RDMA/rxe: Use for_each_sg_page iterator on umem SGL (Jonathan Toppins) [1685313]
- [infiniband] RDMA/vmw_pvrdma: Fix memory leak on pvrdma_pci_remove (Jonathan Toppins) [1685313]
- [infiniband] RDMA/vmw_pvrdma: Support upto 64-bit PFNs (Jonathan Toppins) [1683475]
- [include] IB/mlx5: Remove dead code (Jonathan Toppins) [1685313]
- [infiniband] IB/mlx5: Ranges in implicit ODP MR inherit its write access (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix frwr memory registration (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Add wc_flags and wc_immdata to cq entry trace (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix concurrency panics in QP post_send and modify to error (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix loopback send with invalidate ordering (Jonathan Toppins) [1685313]
- [infiniband] IB/hfi1: Add limit test for RC/UC send via loopback (Jonathan Toppins) [1685313]
- [infiniband] RDMA/iwcm: Fix string truncation error (Jonathan Toppins) [1685313]
- [infiniband] RDMA/iwcm: add tos_set bool to iw_cm struct (Jonathan Toppins) [1685313]
- [infiniband] RDMA/cma: listening device cm_ids should inherit tos (Jonathan Toppins) [1685313]
- [infiniband] RDMA/cma: Rollback source IP address if failing to acquire device (Jonathan Toppins) [1685313]
- [infiniband] RDMA/device: Call ib_cache_release_one() only from ib_device_release() (Jonathan Toppins) [1685313]
- [infiniband] RDMA/device: Ensure that security memory is always freed (Jonathan Toppins) [1685313]
- [infiniband] RDMA/uverbs: Fix an error flow in ib_uverbs_poll_cq (Jonathan Toppins) [1685313]
- [infiniband] IB/ipoib: Make ipoib_intercept_dev_id_attr() static (Jonathan Toppins) [1685313]
- [infiniband] RDMA: Provide safe ib_alloc_device() function (Jonathan Toppins) [1685313]
- [infiniband] IB/core, ipoib: Do not overreact to SM LID change event (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Abort page fault handler silently during owning process exit (Jonathan Toppins) [1685313]
- [infiniband] RDMA/core: Verify that memory window type is legal (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Don't register each MAD agent for LSM notifier (Jonathan Toppins) [1711086 1685313]
- [include] IB/core: Eliminate a hole in MAD agent struct (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Fix potential memory leak while creating MAD agents (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Unregister notifier before freeing MAD security (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Destroy QP if XRC QP fails (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Declare local functions 'static' (Jonathan Toppins) [1685313]
- [infiniband] RDMA/i40iw: Make sure to initialize ib_device_ops (Jonathan Toppins) [1685313]
- [rpmspec] Update the kernel rpm package description to mention backports/bug fixes ("Herton R. Krzesinski") [1701064]
- [netdrv] bonding: fix arp_validate toggling in active-backup mode (Jarod Wilson) [1654214]
- [scsi] scsi: bnx2i: fix indentation issue, remove a tab (Maurizio Lombardi) [1665626]
- [scsi] scsi: bnx2i: remove set but not used variable 'cid_num' (Maurizio Lombardi) [1665626]
- [scsi] scsi: bnx2i: add error handling for ioremap_nocache (Maurizio Lombardi) [1665626]
- [wireless] iwlwifi: mvm: Send LQ command as async when necessary (Stanislaw Gruszka) [1687265]
- [scsi] scsi: bnx2fc: Fix error handling in probe() (Maurizio Lombardi) [1665625]
- [scsi] scsi: bnx2fc: Fix NULL dereference in error handling (Maurizio Lombardi) [1665625]
- [scsi] scsi: bnx2fc: Remove set but not used variable 'oxid' (Maurizio Lombardi) [1665625]
- [scsi] bnx2fc_fcoe: Use skb_queue_walk_safe(). (Maurizio Lombardi) [1665625]
- [netdrv] hv_netvsc: Fix rndis_per_packet_info internal field initialization (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Add handler for LRO setting change (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Add support for LRO/RSC in the vSwitch (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix unwanted wakeup after tx_disable (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix IP header checksum for coalesced packets (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: fix typos in code comments (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix hash key value reset after other ops (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Refactor assignments of struct netvsc_device_info (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix ethtool change hash key error (Mohammed Gamal) [1691375]
- [netdrv] ice: Disable sniffing VF traffic on PF (Kamal Heib) [1659176]
- [netdrv] ice: Use more efficient structures (Kamal Heib) [1659176]
- [netdrv] ice: Use bitfields where possible (Kamal Heib) [1659176]
- [netdrv] ice: Add function to program ethertype based filter rule on VSIs (Kamal Heib) [1659176]
- [netdrv] ice: Separate if conditions for ice_set_features() (Kamal Heib) [1659176]
- [netdrv] ice: Remove __always_unused attribute (Kamal Heib) [1659176]
- [netdrv] ice: Suppress false-positive style issues reported by static analyzer (Kamal Heib) [1659176]
- [netdrv] ice: Refactor getting/setting coalesce (Kamal Heib) [1659176]
- [netdrv] ice: Always free/allocate q_vectors (Kamal Heib) [1659176]
- [netdrv] ice: Do not unnecessarily initialize local variable (Kamal Heib) [1659176]
- [netdrv] ice: Add more validation in ice_vc_cfg_irq_map_msg (Kamal Heib) [1659176]
- [netdrv] ice: Don't remove VLAN filters that were never programmed (Kamal Heib) [1659176]
- [netdrv] ice: Preserve VLAN Rx stripping settings (Kamal Heib) [1659176]
- [netdrv] ice: Fix for allowing too many MDD events on VF (Kamal Heib) [1659176]
- [netdrv] ice: Use pf instead of vsi-back (Kamal Heib) [1659176]
- [netdrv] ice: Use dev_err when ice_cfg_vsi_lan fails (Kamal Heib) [1659176]
- [netdrv] ice: Refactor link event flow (Kamal Heib) [1659176]
- [netdrv] ice: Add missing PHY type to link settings (Kamal Heib) [1659176]
- [netdrv] ice: Add reg_idx variable in ice_q_vector structure (Kamal Heib) [1659176]
- [netdrv] ice: Remove runtime change of PFINT_OICR_ENA register (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue when adding more than allowed VLANs (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary wait when disabling/enabling Rx queues (Kamal Heib) [1659176]
- [netdrv] ice: Add ability to update rx-usecs-high (Kamal Heib) [1659176]
- [netdrv] ice: Add 52 byte RSS hash key support (Kamal Heib) [1659176]
- [netdrv] ice: Use ice_for_each_q_vector macro where possible (Kamal Heib) [1659176]
- [netdrv] ice: Validate ring existence and its q_vector per VSI (Kamal Heib) [1659176]
- [netdrv] ice: Reduce scope of variable in ice_vsi_cfg_rxqs (Kamal Heib) [1659176]
- [netdrv] ice: Resolve static analysis reported issue (Kamal Heib) [1659176]
- [netdrv] ice: Return configuration error without queue to disable (Kamal Heib) [1659176]
- [netdrv] ice: Create framework for VSI queue context (Kamal Heib) [1659176]
- [netdrv] ice: Calculate ITR increment based on direct calculation (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Bump driver version (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to control FW LLDP and DCBX (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB rebuild (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to get DCB related statistics (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add priority information into VLAN header (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Update rings based on TC information (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to process LLDP MIB change events (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 4/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 3/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 2/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 1/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Bump version (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Fix incorrect use of abbreviations (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Fix typos in code comments (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Remove "2 BITS" comment (Kamal Heib) [1659176]
- [netdrv] ice: Update comment regarding the ITR_GRAN_S (Kamal Heib) [1659176]
- [netdrv] ice: Update function header for __ice_vsi_get_qs (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary braces (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused function prototype (Kamal Heib) [1659176]
- [netdrv] ice: Add missing case in print_link_msg for printing flow control (Kamal Heib) [1659176]
- [netdrv] ice: Audit hotpath structures with pahole (Kamal Heib) [1659176]
- [netdrv] ice: Do not bail out when filter already exists (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue with VF attempt to delete default MAC address (Kamal Heib) [1659176]
- [netdrv] ice: enable VF admin queue interrupts (Kamal Heib) [1659176]
- [netdrv] ice: Fix for adaptive interrupt moderation (Kamal Heib) [1659176]
- [netdrv] ice: Implement pci_error_handler ops (Kamal Heib) [1659176]
- [netdrv] ice: Put __ICE_PREPARED_FOR_RESET check in ice_prepare_for_reset (Kamal Heib) [1659176]
- [netdrv] ice: use virt channel status codes (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary newlines from log messages (Kamal Heib) [1659176]
- [netdrv] ice: Create a generic name for the ice_rx_flg64_bits structure (Kamal Heib) [1659176]
- [netdrv] ice: add and use new ice_for_each_traffic_class() macro (Kamal Heib) [1659176]
- [netdrv] ice: change VF VSI tc info along with num_queues (Kamal Heib) [1659176]
- [netdrv] ice: Prevent unintended multiple chain resets (Kamal Heib) [1659176]
- [netdrv] ice: map Rx buffer pages with DMA attributes (Kamal Heib) [1659176]
- [netdrv] ice: Limit the ice_add_rx_frag to frag addition (Kamal Heib) [1659176]
- [netdrv] ice: Gather the rx buf clean-up logic for better reuse (Kamal Heib) [1659176]
- [netdrv] ice: Introduce bulk update for page count (Kamal Heib) [1659176]
- [netdrv] ice: Get rid of ice_pull_tail (Kamal Heib) [1659176]
- [netdrv] ice: Pull out page reuse checks onto separate function (Kamal Heib) [1659176]
- [netdrv] ice: Retrieve rx_buf in separate function (Kamal Heib) [1659176]
- [netdrv] ice: Enable link events over the ARQ (Kamal Heib) [1659176]
- [netdrv] ice: use irq_num var in ice_vsi_req_irq_msix (Kamal Heib) [1659176]
- [netdrv] ice: Restore VLAN switch rule if port VLAN existed before (Kamal Heib) [1659176]
- [netdrv] ice: update VSI config dynamically (Kamal Heib) [1659176]
- [netdrv] ice: Get VF VSI instances directly via PF (Kamal Heib) [1659176]
- [netdrv] ice: Don't let VF know that it is untrusted (Kamal Heib) [1659176]
- [netdrv] ice: Set LAN_EN for all directional rules (Kamal Heib) [1659176]
- [netdrv] ice: Do not set LB_EN for prune switch rules (Kamal Heib) [1659176]
- [netdrv] ice: Enable LAN_EN for the right recipes (Kamal Heib) [1659176]
- [netdrv] ice: Add support for PF/VF promiscuous mode (Kamal Heib) [1659176]
- [netdrv] ice: code cleanup in ice_sched.c (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused vsi_id field (Kamal Heib) [1659176]
- [netdrv] ice: fix some function prototype and signature style issues (Kamal Heib) [1659176]
- [netdrv] ice: fix the divide by zero issue (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue reconfiguring VF queues (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused function prototype (Kamal Heib) [1659176]
- [netdrv] ice: fix static analysis warnings (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue reclaiming resources back to the pool after reset (Kamal Heib) [1659176]
- [netdrv] ice: Enable MAC anti-spoof by default (Kamal Heib) [1659176]
- [netdrv] ice: Determine descriptor count and ring size based on PAGE_SIZE (Kamal Heib) [1659176]
- [netdrv] ice: Reset all VFs with VFLR during SR-IOV init flow (Kamal Heib) [1659176]
- [netdrv] ice: Get resources per function (Kamal Heib) [1659176]
- [netdrv] ice: Implement flow to reset VFs with PFR and other resets (Kamal Heib) [1659176]
- [netdrv] ice: configure GLINT_ITR to always have an ITR gran of 2 (Kamal Heib) [1659176]
- [netdrv] ice: use ice_for_each_vsi macro when possible (Kamal Heib) [1659176]
- [netdrv] ice : Ensure only valid bits are set in ice_aq_set_phy_cfg (Kamal Heib) [1659176]
- [netdrv] ice: remove redundant variable and if condition (Kamal Heib) [1659176]
- [netdrv] ice: avoid multiple unnecessary de-references in probe (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue with VF reset and multiple VFs support on PFs (Kamal Heib) [1659176]
- [netdrv] ice: Fix broadcast traffic in port VLAN mode (Kamal Heib) [1659176]
- [netdrv] ice: fix overlong string, update stats output (Kamal Heib) [1659176]
- [netdrv] ice: Fix for FC get rx/tx pause params (Kamal Heib) [1659176]
- [netdrv] ice: use absolute vector ID for VFs (Kamal Heib) [1659176]
- [netdrv] ice: check for a leaf node presence (Kamal Heib) [1659176]
- [netdrv] ice: flush Tx pipe on disable queue timeout (Kamal Heib) [1659176]
- [netdrv] ice: clear VF ARQLEN register on reset (Kamal Heib) [1659176]
- [netdrv] ice: don't spam VFs with link messages (Kamal Heib) [1659176]
- [netdrv] ice: only use the VF for ICE_VSI_VF in ice_vsi_release (Kamal Heib) [1659176]
- [netdrv] ice: fix numeric overflow warning (Kamal Heib) [1659176]
- [netdrv] ice: fix issue where host reboots on unload when iommu=on (Kamal Heib) [1659176]
- [netdrv] ice: fix ice_remove_rule_internal vsi_list handling (Kamal Heib) [1659176]
- [netdrv] ice: fix stack hogs from struct ice_vsi_ctx structures (Kamal Heib) [1659176]
- [netdrv] ice: sizeof(<type>) should be avoided (Kamal Heib) [1659176]
- [netdrv] ice: Fix added in VSI supported nodes calc (Kamal Heib) [1659176]
- [netdrv] ice: Fix the calculation of ICE_MAX_MTU (Kamal Heib) [1659176]
- [netdrv] ice: Mark extack argument as __always_unused (Kamal Heib) [1659176]
- [netdrv] ice: add const qualifier to mac_addr parameter (Kamal Heib) [1659176]
- [netdrv] ice: Add support for new PHY types (Kamal Heib) [1659176]
- [netdrv] ice: Offload SCTP checksum (Kamal Heib) [1659176]
- [netdrv] ice: Allow for software timestamping (Kamal Heib) [1659176]
- [netdrv] ice: Implement getting and setting ethtool coalesce (Kamal Heib) [1659176]
- [netdrv] ice: Add support for adaptive interrupt moderation (Kamal Heib) [1659176]
- [netdrv] ice: Move aggregator list into ice_hw instance (Kamal Heib) [1659176]
- [netdrv] ice: Rework queue management code for reuse (Kamal Heib) [1659176]
- [netdrv] ice: Add ethtool private flag to make forcing link down optional (Kamal Heib) [1659176]
- [netdrv] ice: Set physical link up/down when an interface is set up/down (Kamal Heib) [1659176]
- [netdrv] ice: Implement support for normal get_eeprom[_len] ethtool ops (Kamal Heib) [1659176]
- [netdrv] ice: Add ethtool set_phys_id handler (Kamal Heib) [1659176]
- [netdrv] ice: Configure RSS LUT and HASH KEY in rebuild path (Kamal Heib) [1659176]
- [netdrv] ice: Refactor a few Tx scheduler functions (Kamal Heib) [1659176]
- [netdrv] ice: Fix unused variable build warning (Kamal Heib) [1659176]
- [netdrv] ice: Do not enable NAPI on q_vectors that have no rings (Kamal Heib) [1659176]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Kamal Heib) [1659176]
- [netdrv] ice: Fix possible NULL pointer de-reference (Kamal Heib) [1659176]
- [netdrv] ice: Use Tx|Rx in comments (Kamal Heib) [1659176]
- [netdrv] ice: Cosmetic formatting changes (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup short function signatures (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup ice_tx_timeout() (Kamal Heib) [1659176]
- [netdrv] ice: Fix return value from NAPI poll (Kamal Heib) [1659176]
- [netdrv] ice: Constify global structures that can/should be (Kamal Heib) [1659176]
- [netdrv] ice: Do not set LAN_EN for MAC-VLAN filters (Kamal Heib) [1659176]
- [netdrv] ice: Pass the return value of ice_init_def_sw_recp() (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup duplicate control queue code (Kamal Heib) [1659176]
- [netdrv] ice: Remove ICE_MAX_TXQ_PER_TXQG check when configuring Tx queue (Kamal Heib) [1659176]
- [netdrv] ice: Destroy scheduler tree in reset path (Kamal Heib) [1659176]
- [netdrv] ice: Fix to make VLAN priority tagged traffic to appear on all TCs (Kamal Heib) [1659176]
- [netdrv] ice: Call pci_disable_sriov before stopping queues for VF (Kamal Heib) [1659176]
- [netdrv] ice: Increase Rx queue disable timeout (Kamal Heib) [1659176]
- [netdrv] ice: Fix NVM mask defines (Kamal Heib) [1659176]
- [netdrv] ice: Avoid nested RTNL locking in ice_dis_vsi (Kamal Heib) [1659176]
- [netdrv] ice: Calculate guaranteed VSIs per function and use it (Kamal Heib) [1659176]
- [netdrv] ice: Remove node before releasing VSI (Kamal Heib) [1659176]
- [netdrv] ice: Check for q_vector when stopping rings (Kamal Heib) [1659176]
- [netdrv] ice: Fix debug print in ice_tx_timeout (Kamal Heib) [1659176]
- [netdrv] intel-ethernet: use correct module license (Kamal Heib) [1659176]
- [netdrv] bnx2x: Add support for detection of P2P event packets. (Manish Chopra) [1638306 1663271]
- [netdrv] bnx2x: Replace magic numbers with macro definitions. (Manish Chopra) [1638306 1663271]
- [netdrv] bnx2x: fix spelling mistake "dicline" -> "decline" (Manish Chopra) [1663271]
- [netdrv] bnx2x: Utilize FW 7.13.11.0. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Remove set but not used variable 'mfw_vn' (Manish Chopra) [1663271]
- [netdrv] bnx2x: Use struct_size() in kzalloc() (Manish Chopra) [1663271]
- [netdrv] broadcom: Mark expected switch fall-throughs (Manish Chopra) [1663271]
- [netdrv] bnx2x: Bump up driver version to 1.713.36 (Manish Chopra) [1663271]
- [netdrv] bnx2x: fix various indentation issues (Manish Chopra) [1663271]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() on headers (Manish Chopra) [1663271]
- [netdrv] bnx2x: Fix NULL pointer dereference in bnx2x_del_all_vlans() on some hw (Manish Chopra) [1663271]
- [netdrv] bnx2x: Send update-svid ramrod with retry/poll flags enabled (Manish Chopra) [1663271]
- [netdrv] bnx2x: Enable PTP only on the PF that initializes the port (Manish Chopra) [1663271]
- [netdrv] bnx2x: Remove configured vlans as part of unload sequence. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Clear fip MAC when fcoe offload support is disabled (Manish Chopra) [1663271]
- [netdrv] bnx2x: Add storm FW version to ethtool driver query output. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Add MBI version to ethtool driver query output. (Manish Chopra) [1663271]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Manish Chopra) [1663271]
- [netdrv] bnx2x: remove ndo_poll_controller (Manish Chopra) [1663271]
- [netdrv] bnx2x: Provide VF link status in ndo_get_vf_config (Manish Chopra) [1663271]
- [netdrv] bnx2x: Ignore bandwidth attention in single function mode (Manish Chopra) [1663271]
- [block] block: remove CONFIG_LBDAF (Ming Lei) [1708452]
- [kernel] sched/pelt: Fix warning and clean up IRQ PELT config (Phil Auld) [1637824]
- [kernel] sched/pelt: Fix update_blocked_averages() for RT and DL classes (Phil Auld) [1637824]
- [mm] mm, sched/numa: Remove remaining traces of NUMA rate-limiting (Phil Auld) [1637824]
- [kernel] sched/fair: Fix cpu_util_wake() for 'execl' type workloads (Phil Auld) [1637824]
- [kernel] sched/fair: Consider SD_NUMA when selecting the most idle group to schedule on (Phil Auld) [1637824]
- [kernel] sched/numa: Migrate pages to local nodes quicker early in the lifetime of a task (Phil Auld) [1637824]
- [mm] mm, sched/numa: Remove rate-limiting of automatic NUMA balancing migration (Phil Auld) [1637824]
- [kernel] sched/numa: Avoid task migration for small NUMA improvement (Phil Auld) [1637824]
- [mm] mm/migrate: Use spin_trylock() while resetting rate limit (Phil Auld) [1637824]
- [kernel] sched/numa: Limit the conditions where scan period is reset (Phil Auld) [1637824]
- [kernel] sched/numa: Reset scan rate whenever task moves across nodes (Phil Auld) [1637824]
- [kernel] sched/numa: Pass destination CPU as a parameter to migrate_task_rq (Phil Auld) [1637824]
- [kernel] sched/numa: Stop multiple tasks from moving to the CPU at the same time (Phil Auld) [1637824]
- [kernel] sched/fair: Fix scale_rt_capacity() for SMT (Phil Auld) [1637824]
- [kernel] sched/numa: Move task_numa_placement() closer to numa_migrate_preferred() (Phil Auld) [1637824]
- [kernel] sched/numa: Use group_weights to identify if migration degrades locality (Phil Auld) [1637824]
- [kernel] sched/numa: Update the scan period without holding the numa_group lock (Phil Auld) [1637824]
- [kernel] sched/numa: Remove numa_has_capacity() (Phil Auld) [1637824]
- [kernel] sched/numa: Modify migrate_swap() to accept additional parameters (Phil Auld) [1637824]
- [kernel] sched/numa: Remove unused task_capacity from 'struct numa_stats' (Phil Auld) [1637824]
- [kernel] sched/numa: Skip nodes that are at 'hoplimit' (Phil Auld) [1637824]
- [kernel] sched/debug: Reverse the order of printing faults (Phil Auld) [1637824]
- [kernel] sched/numa: Use task faults only if numa_group is not yet set up (Phil Auld) [1637824]
- [kernel] sched/numa: Set preferred_node based on best_cpu (Phil Auld) [1637824]
- [kernel] sched/numa: Simplify load_too_imbalanced() (Phil Auld) [1637824]
- [kernel] sched/numa: Evaluate move once per node (Phil Auld) [1637824]
- [kernel] sched/fair: Remove #ifdefs from scale_rt_capacity() (Phil Auld) [1637824]
- [kernel] sched/cpufreq: Clarify sugov_get_util() (Phil Auld) [1637824]
- [kernel] sched/sysctl: Remove unused sched_time_avg_ms sysctl (Phil Auld) [1637824]
- [kernel] sched/core: Remove the rt_avg code (Phil Auld) [1637824]
- [kernel] sched/core: Use PELT for scale_rt_capacity() (Phil Auld) [1637824]
- [kernel] sched/cpufreq: Remove sugov_aggregate_util() (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Take time spent in interrupts into account (Phil Auld) [1637824]
- [kernel] sched/irq: Add IRQ utilization tracking (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Use DL utilization tracking (Phil Auld) [1637824]
- [kernel] sched/dl: Add dl_rq utilization tracking (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Use RT utilization tracking (Phil Auld) [1637824]
- [kernel] sched/rt: Add rt_rq utilization tracking (Phil Auld) [1637824]
- [kernel] sched/pelt: Move PELT related code in a dedicated file (Phil Auld) [1637824]
- [char] ipmi_si: Potential array underflow in hotmod_handler() (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hacks for adding a dummy platform devices (Tony Camuso) [1665131]
- [char] ipmi_si: Consolidate scanning the platform bus (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hotmod devices on removal and exit (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hardcode IPMI devices by scanning the platform bus (Tony Camuso) [1665131]
- [char] ipmi_si: Switch hotmod to use a platform device (Tony Camuso) [1665131]
- [char] ipmi: Fix failure on SMBIOS specified devices (Tony Camuso) [1665131]
- [char] ipmi: Consolidate the adding of platform devices (Tony Camuso) [1665131]
- [char] ipmi_si: Rename addr_type to addr_space to match what it does (Tony Camuso) [1665131]
- [char] ipmi_si: Convert some types into unsigned (Tony Camuso) [1665131]
- [char] ipmi: ipmi_si_hardcode.c: init si_type array to fix a crash (Tony Camuso) [1665131]
- [char] ipmi_si: Fix crash when using hard-coded device (Tony Camuso) [1665131]
- [char] ipmi: Use dedicated API for copying a UUID (Tony Camuso) [1665131]
- [char] ipmi: Use defined constant for UUID representation (Tony Camuso) [1665131]
- [char] ipmi:ssif: Change some pr_xxx to dev_xxx calls (Tony Camuso) [1665131]
- [char] ipmi: kcs_bmc: handle devm_kasprintf() failure case (Tony Camuso) [1665131]
- [char] ipmi: Fix return value when a message is truncated (Tony Camuso) [1665131]
- [char] ipmi: clean an indentation issue, remove extraneous space (Tony Camuso) [1665131]
- [char] ipmi: Make the smi watcher be disabled immediately when not needed (Tony Camuso) [1665131]
- [char] ipmi: Fix how the lower layers are told to watch for messages (Tony Camuso) [1665131]
- [char] ipmi: Fix SSIF flag requests (Tony Camuso) [1665131]
- [char] ipmi_si: fix use-after-free of resource->name (Tony Camuso) [1665131]
- [char] ipmi: Don't initialize anything in the core until something uses it (Tony Camuso) [1665131]
- [char] ipmi:ssif: Fix handling of multi-part return messages (Tony Camuso) [1665131]
- [char] ipmi:dmi: Use pr_fmt in the IPMI DMI code (Tony Camuso) [1665131]
- [char] ipmi: Remove platform driver overrides and use the id_table (Tony Camuso) [1665131]
- [char] ipmi: msghandler: Add and use pr_fmt and dev_fmt, remove PFX (Tony Camuso) [1665131]
- [char] ipmi: Use more common logging styles (Tony Camuso) [1665131]
- [acpi] ACPI / glue: Split dev_is_platform() out of module for wide use (Tony Camuso) [1665131]

* Thu May 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-90.el8]
- [scsi] scsi: hpsa: bump driver version (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: remove timeout from TURs (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: clean up two indentation issues (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: mark expected switch fall-throughs (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: switch to generic DMA API (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: Use vmemdup_user to replace the open code (Joseph Szczypek) [1672669]
- [netdrv] ibmvnic: Add device identification to requested IRQs (Steve Best) [1665717]
- [crypto] crypto: authenc - fix parsing key with misaligned rta_len (Herbert Xu) [1707546]
- [block] block: don't drain in-progress dispatch in blk_cleanup_queue() (Ming Lei) [1694879]
- [block] blk-mq: move cancel of hctx->run_work into blk_mq_hw_sysfs_release (Ming Lei) [1694879]
- [include] blk-mq: always free hctx after request queue is freed (Ming Lei) [1694879]
- [block] blk-mq: split blk_mq_alloc_and_init_hctx into two parts (Ming Lei) [1694879]
- [block] blk-mq: free hw queue's resource in hctx's release handler (Ming Lei) [1694879]
- [block] blk-mq: move cancel of requeue_work into blk_mq_release (Ming Lei) [1694879]
- [block] blk-mq: grab .q_usage_counter when queuing request from plug code path (Ming Lei) [1694879]
- [block] block: fix use-after-free on gendisk (Ming Lei) [1694879]
- [netdrv] bonding: fix event handling for stacked bonds (Jarod Wilson) [1708390]
- [netdrv] bonding: show full hw address in sysfs for slave entries (Jarod Wilson) [1708390]
- [netdrv] bonding: fix PACKET_ORIGDEV regression (Jarod Wilson) [1708390]
- [netdrv] bonding: check slave set command firstly (Jarod Wilson) [1708390]
- [netdrv] bonding: count master 3ad stats separately (Jarod Wilson) [1708390]
- [netdrv] bonding: add support for xstats and export 3ad stats (Jarod Wilson) [1708390]
- [netdrv] bonding: add 3ad stats (Jarod Wilson) [1708390]
- [netdrv] bonding: 3ad: remove bond_3ad_rx_indication's length argument (Jarod Wilson) [1708390]
- [netdrv] bonding: adjust style of bond_3ad_rx_indication (Jarod Wilson) [1708390]
- [netdrv] bonding: update nest level on unlink (Jarod Wilson) [1708390]
- [netdrv] bonding: fix indentation issues, remove extra spaces (Jarod Wilson) [1708390]
- [netdrv] bonding: convert to DEFINE_SHOW_ATTRIBUTE (Jarod Wilson) [1708390]
- [netdrv] bonding: fix 802.3ad state sent to partner when unbinding slave (Jarod Wilson) [1708390]
- [netdrv] bonding: use netpoll_poll_dev() helper (Jarod Wilson) [1708390]
- [net] netpoll: do not test NAPI_STATE_SCHED in poll_one_napi() (Jarod Wilson) [1708390]
- [net] netpoll: make ndo_poll_controller() optional (Jarod Wilson) [1708390]
- [netdrv] bonding: don't cast const buf in sysfs store (Jarod Wilson) [1708390]
- [netdrv] netdevsim: fix sa_idx out of bounds check (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: add ipsec offload API test (Ivan Vecera) [1708373]
- [netdrv] netdevsim: add ipsec offload testing (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: use dummydev as a test device (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: clear the return code at start of ipsec test (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: use a local IP address for IPsec tests (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: hide complaint from terminated monitor (Ivan Vecera) [1708373]
- [powerpc] powerpc/watchdog: Use hrtimers for per-CPU heartbeat (Steve Best) [1708327]
- [netdrv] ixgbevf: Update driver version for RHEL-8.1.0 (Ken Cox) [1659166]
- [netdrv] drivers: net: intel: use secpath helpers in more places (Ken Cox) [1659166]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Ken Cox) [1659166]
- [netdrv] ixgbevf: add support for software timestamps (Ken Cox) [1659166]
- [netdrv] ixgbe/ixgbevf: fix XFRM_ALGO dependency (Ken Cox) [1659166]
- [netdrv] ixgbevf: off by one in ixgbevf_ipsec_tx() (Ken Cox) [1659166]
- [netdrv] ixgbevf: fix msglen for ipsec mbx messages (Ken Cox) [1659166]
- [netdrv] ixgbevf: remove ndo_poll_controller (Ken Cox) [1659166]
- [netdrv] intel-ethernet: use correct module license (Ken Cox) [1659166]
- [netdrv] ixgbevf: enable VF IPsec offload operations (Ken Cox) [1659166]
- [netdrv] ixgbevf: add VF IPsec offload code (Ken Cox) [1659166]
- [netdrv] ixgbevf: add defines for IPsec offload request (Ken Cox) [1659166]
- [netdrv] ixgbevf: VF2VF TCP RSS (Ken Cox) [1659166]
- [netdrv] ixgbe: Update driver version for RHEL-8.1.0 (Ken Cox) [1659164]
- [netdrv] intel: correct return from set features callback (Ken Cox) [1659164]
- [netdrv] ixgbe: don't do any AF_XDP zero-copy transmit if netif is not OK (Ken Cox) [1659164]
- [netdrv] ixgbe: fix potential RX buffer starvation for AF_XDP (Ken Cox) [1659164]
- [netdrv] ixgbe: fix older devices that do not support IXGBE_MRQC_L3L4TXSWEN (Ken Cox) [1659164]
- [netdrv] net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Ken Cox) [1659164]
- [netdrv] ixgbe: Use struct_size() helper (Ken Cox) [1659164]
- [netdrv] ixgbe: remove magic constant in ixgbe_reset_hw_82599() (Ken Cox) [1659164]
- [netdrv] ixgbe: use mii_bus to handle MII related ioctls (Ken Cox) [1659164]
- [netdrv] ixgbe: register a mdiobus (Ken Cox) [1659164]
- [netdrv] drivers: net: intel: use secpath helpers in more places (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix race when the VF driver does a reset (Ken Cox) [1659164]
- [netdrv] ixgbe: recognize 1000BaseLX SFP modules as 1Gbps (Ken Cox) [1659164]
- [netdrv] ixgbe: Replace synchronize_sched() with synchronize_rcu() (Ken Cox) [1659164]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Ken Cox) [1659164]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Ken Cox) [1659164]
- [netdrv] ixgbe: allow IPsec Tx offload in VEPA mode (Ken Cox) [1659164]
- [netdrv] ixgbe: don't clear_bit on xdp_ring->state if xdp_ring is null (Ken Cox) [1659164]
- [netdrv] ixgbe: fix MAC anti-spoofing filter after VFLR (Ken Cox) [1659164]
- [netdrv] ixgbe/ixgbevf: fix XFRM_ALGO dependency (Ken Cox) [1659164]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Ken Cox) [1659164]
- [netdrv] ixgbe: check return value of napi_complete_done() (Ken Cox) [1659164]
- [netdrv] ixgbe: add AF_XDP zero-copy Tx support (Ken Cox) [1659164]
- [netdrv] ixgbe: move common Tx functions to ixgbe_txrx_common.h (Ken Cox) [1659164]
- [netdrv] ixgbe: add AF_XDP zero-copy Rx support (Ken Cox) [1659164]
- [netdrv] ixgbe: move common Rx functions to ixgbe_txrx_common.h (Ken Cox) [1659164]
- [netdrv] ixgbe: added Rx/Tx ring disable/enable functions (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix crash with VFs and flow director on interface flap (Ken Cox) [1659164]
- [netdrv] ixgbe: remove redundant function ixgbe_fw_recovery_mode() (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix ixgbe TX hangs with XDP_TX beyond queue limit (Ken Cox) [1659164]
- [netdrv] ixgbe: remove ndo_poll_controller (Ken Cox) [1659164]
- [netdrv] intel-ethernet: use correct module license (Ken Cox) [1659164]
- [netdrv] ixgbe: fix the return value for unsupported VF offload (Ken Cox) [1659164]
- [netdrv] ixgbe: disallow IPsec Tx offload when in SR-IOV mode (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec offload request message handling (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec offload enable flag (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec management (Ken Cox) [1659164]
- [netdrv] ixgbe: prep IPsec constants for later use (Ken Cox) [1659164]
- [netdrv] ixgbe: reload IPsec IP table after sa tables (Ken Cox) [1659164]
- [netdrv] ixgbe: don't clear IPsec sa counters on HW clearing (Ken Cox) [1659164]
- [netdrv] ixgbe: firmware recovery mode (Ken Cox) [1659164]
- [netdrv] ixgbe: fix driver behaviour after issuing VFLR (Ken Cox) [1659164]
- [netdrv] ixgbe: Prevent unsupported configurations with XDP (Ken Cox) [1659164]
- [netdrv] ixgbe: Refactor queue disable logic to take completion time into account (Ken Cox) [1659164]
- [netdrv] ixgbe: Reorder Tx/Rx shutdown to reduce time needed to stop device (Ken Cox) [1659164]
- [netdrv] ixgbe: add ipsec security registers into ethtool register dump (Ken Cox) [1659164]
- [netdrv] ixgbe: Do not allow LRO or MTU change with XDP (Ken Cox) [1659164]
- [wireless] brcmfmac: add subtype check for event handling in data path (Stanislaw Gruszka) [1705386] {CVE-2019-9500}
- [wireless] brcmfmac: assure SSID length from firmware is limited (Stanislaw Gruszka) [1705386] {CVE-2019-9500}
- [base] driver core: Postpone DMA tear-down until after devres release (Maurizio Lombardi) [1698053]

* Wed May 15 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-89.el8]
- [of] of: Add missing exports of node name compare functions (Neil Horman) [1665660]
- [of] of: add node name compare helper functions (Neil Horman) [1665660]
- [include] gpio: Add API to explicitly name a consumer (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: fix SPI_CS_HIGH capability (Neil Horman) [1665660]
- [drivers] spi: use gpio[d]_set_value_cansleep for setting chipselect GPIO (Neil Horman) [1665660]
- [drivers] spi: gpio: Advertise support for SPI_CS_HIGH (Neil Horman) [1665660]
- [include] spi: support inter-word delay requirement for devices (Neil Horman) [1665660]
- [drivers] spi: dw: Fix default polarity of native chipselect (Neil Horman) [1665660]
- [drivers] spi: Support high CS when using descriptors (Neil Horman) [1665660]
- [include] spi: Go back to immediate teardown (Neil Horman) [1665660]
- [drivers] spi: dw: change snprintf to scnprintf for possible overflow (Neil Horman) [1665660]
- [drivers] spi: dw: fix warning unused variable 'ret' (Neil Horman) [1665660]
- [include] spi: core: avoid waking pump thread from spi_sync instead run teardown delayed (Neil Horman) [1665660]
- [drivers] spi: dw: Convert to use CS GPIO descriptors (Neil Horman) [1665660]
- [include] spi: Optionally use GPIO descriptors for CS GPIOs (Neil Horman) [1665660]
- [drivers] spi: dw: fix potential variable assignment error (Neil Horman) [1665660]
- [drivers] spi: Use of_node_name_eq for node name comparisons (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add ACPI support (Neil Horman) [1665660]
- [include] spi: add support for octal mode I/O data transfer (Neil Horman) [1665660]
- [drivers] spi: Fix formatting of header block (Neil Horman) [1665660]
- [drivers] spi: Fix core transfer waits after slave support (Neil Horman) [1665660]
- [drivers] spi: Deal with slaves that return from transfer_one() unfinished (Neil Horman) [1665660]
- [include] spi: gpio: Support 3WIRE high-impedance turn-around (Neil Horman) [1665660]
- [drivers] spi: Make GPIO CSs honour the SPI_NO_CS flag (Neil Horman) [1665660]
- [drivers] dw: spi: add support for Amazon's Alpine spi controller (Neil Horman) [1665660]
- [include] spi: Add driver_override SPI device attribute (Neil Horman) [1665660]
- [include] spi: make OF helper available for others (Neil Horman) [1665660]
- [include] spi: switch to SPDX license identifier (Neil Horman) [1665660]
- [drivers] spi: always use software fallback for SPI_CS_WORD when using cs_gio (Neil Horman) [1665660]
- [drivers] spi: add software implementation for SPI_CS_WORD (Neil Horman) [1665660]
- [include] spi: add new SPI_CS_WORD flag (Neil Horman) [1665660]
- [drivers] spi: gpio: No MISO does not imply no RX (Neil Horman) [1665660]
- [drivers] spi: dw: support 4-16 bits per word (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: Remove set but not used variable 'pdata' (Neil Horman) [1665660]
- [drivers] spi: Do not print a message if spi_controller_{suspend,resume}() fails (Neil Horman) [1665660]
- [drivers] spi: gpio: Fix copy-and-paste error (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: avoid hardcoded field mask (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add MSCC Jaguar2 support (Neil Horman) [1665660]
- [include] spi: Introduce one new field to set word delay (Neil Horman) [1665660]
- [drivers] spi: Fix double IDR allocation with DT aliases (Neil Horman) [1665660]
- [drivers] spi: fix IDR collision on systems with both fixed and dynamic SPI bus numbers (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: add SPI_3WIRE support (Neil Horman) [1665660]
- [drivers] spi: add flags parameter to txrx_word function pointers (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add MSCC Ocelot support (Neil Horman) [1665660]
- [drivers] spi: dw: export dw_spi_set_cs (Neil Horman) [1665660]
- [drivers] spi: dw: allow providing own set_cs callback (Neil Horman) [1665660]
- [drivers] spi: dw: fix possible race condition (Neil Horman) [1665660]
- [acpi] ACPI / APD: Add clock frequency for Hisilicon Hip08 SPI controller (Neil Horman) [1665660]
- [md] md/raid: raid5 preserve the writeback action after the parity check (Nigel Croxon) [1702309]
- [md] Revert "Don't jump to compute_result state from check_result state" (Nigel Croxon) [1702309]
- [md] md: return -ENODEV if rdev has no mddev assigned (Nigel Croxon) [1702309]
- [md] md: add __acquires/__releases annotations to handle_active_stripes (Nigel Croxon) [1702309]
- [md] md: add __acquires/__releases annotations to (un)lock_two_stripes (Nigel Croxon) [1702309]
- [md] md: mark md_cluster_mod static (Nigel Croxon) [1702309]
- [md] md: use correct type in super_1_sync (Nigel Croxon) [1702309]
- [md] md: use correct type in super_1_load (Nigel Croxon) [1702309]
- [md] md: use correct types in md_bitmap_print_sb (Nigel Croxon) [1702309]
- [md] md: add a missing endianness conversion in check_sb_changes (Nigel Croxon) [1702309]
- [md] md: add mddev->pers to avoid potential NULL pointer dereference (Nigel Croxon) [1702309]
- [md] md: batch flush requests. (Nigel Croxon) [1702309]
- [md] Revert "MD: fix lock contention for flush bios" (Nigel Croxon) [1702309]
- [md] Don't jump to compute_result state from check_result state (Nigel Croxon) [1702309]
- [netdrv] bnxt_en: Reset device on RX buffer errors. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Improve RX consumer index validity check. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Drop oversize TX packets to prevent errors. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Wait longer for the firmware message response to complete. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix typo in firmware message timeout logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Return relevant error code when offload fails (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for mdio read/write to external PHY (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Propagate trusted VF attribute to firmware. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for BCM957504 (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.47. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable interrupts when allocating CP rings or NQs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix context memory allocation. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix ring checking logic on 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust default RX coalescing ticks to 10 us. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Support for 64-bit flow handle. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Increase context memory allocations on 57500 chips for RDMA. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add Level 2 context memory paging support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Enhance bnxt_alloc_ring()/bnxt_free_ring(). (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for 2nd firmware message channel. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Introduce bnxt_get_hwrm_resp_addr & bnxt_get_hwrm_seq_id routines. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Avoid arithmetic on void * pointer. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use macros for firmware message doorbell offsets. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Set hwrm_intr_seq_id value to its inverted value. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.33. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix ethtool self-test loopback. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: query force speeds before disabling autoneg mode. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not free port statistics buffer when device is down. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Save ring statistics before reset. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Return linux standard errors in bnxt_ethtool.c (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Don't set ETS on unused TCs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add ethtool -S priority counters. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add SR-IOV support for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable MSIX before re-reserving NQs/CMPL rings. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Reserve 1 stat_ctx for RDMA driver. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not modify max_stat_ctxs after RDMA driver requests/frees stat_ctxs (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: get rid of num_stat_ctxs variable (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add bnxt_get_avail_cp_rings_for_en() helper function. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Store the maximum NQs available on the PF. (Selvin Xavier) [1664477]
- [netdrv] bnxt: remove printing of hwrm message (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix _bnxt_get_max_rings() for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix NQ/CP rings accounting on the new 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Keep track of reserved IRQs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix CNP CoS queue regression. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix filling time in bnxt_fill_coredump_record() (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add software "missed_irqs" counter. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Workaround occasional TX timeout on 57500 A0. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable RDMA support on the 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix rx_l4_csum_errors counter on 57500 devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix RSS context allocation. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Copy and paste bug in extended tx_stats (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add PCI ID for BCM57508 device. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new NAPI poll function for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Refactor bnxt_poll_work(). (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add coalescing setup for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use bnxt_cp_ring_info struct pointer as parameter for RX path. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add RSS support for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Increase RSS context array count and skip ring groups on 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Allocate/Free CP rings for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Modify bnxt_ring_alloc_send_msg() to support 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add helper functions to get firmware CP ring ID. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Allocate completion ring structures for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Modify the ring reservation functions for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust MSIX and ring groups for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Re-structure doorbells. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add 57500 new chip ID and basic structures. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Configure context memory on new devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Check context memory requirements from firmware. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new flags to setup new page table PTE bits on newer devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Refactor bnxt_ring_struct. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update interrupt coalescing logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add maximum extended request length fw message support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add additional extended port statistics. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.3. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Remove unnecessary unsigned integer comparison and initialize variable (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: get the reduced max_irqs by the ones used by RDMA (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: free hwrm resources, if driver probe fails. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix enables field in HWRM_QUEUE_COS2BW_CFG request (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix VNIC reservations on the PF. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add a driver specific gre_ver_check devlink parameter. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use msix_vec_per_pf_max and msix_vec_per_pf_min devlink params. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: return proper error when FW returns HWRM_ERR_CODE_RESOURCE_ACCESS_DENIED (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use ignore_ari devlink parameter (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix TX timeout during netpoll. (Selvin Xavier) [1664477]
- [netdrv] bnxt: remove ndo_poll_controller (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: don't try to offload VLAN 'modify' action (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove set but not used variable 'addr_type' (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove set but not used variable 'rx_stats' (Selvin Xavier) [1664477]
- [netdrv] net: bnxt: Fix a uninitialized variable warning. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: take coredump_record structure off stack (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: avoid string overflow for record->system_name (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix strcpy() warnings in bnxt_ethtool.c (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not use the CNP CoS queue for networking traffic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add DCBNL DSCP application protocol support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add hwmon sysfs support to read temperature (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Notify firmware about IF state changes. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Move firmware related flags to a new fw_cap field in struct bnxt. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add BNXT_NEW_RM() macro. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for ethtool get dump. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update RSS setup and GRO-HW logic according to the latest spec. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new VF resource allocation strategy mode. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add PHY retry logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add external loopback test to ethtool selftest. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust timer based on ethtool stats-block-usecs settings. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface version to 1.9.2.25. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: combine 'else if' and 'else' into single branch (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove redundant debug register dma mem allocation (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add bnxt_en initial params table and register it. (Selvin Xavier) [1664477]
- [netdrv] sfc: mcdi_port: Mark expected switch fall-through (Jarod Wilson) [1685478]
- [netdrv] sfc: ensure recovery after allocation failures (Jarod Wilson) [1685478]
- [netdrv] sfc: Replace dev_kfree_skb_any by dev_consume_skb_any (Jarod Wilson) [1685478]
- [netdrv] sfc: add bundle partition definitions to mtd (Jarod Wilson) [1685478]
- [netdrv] sfc: Replace spin_is_locked() with lockdep (Jarod Wilson) [1685478]
- [netdrv] sfc: remove ndo_poll_controller (Jarod Wilson) [1685478]
- [iommu] iommu/amd: Set exclusion range correctly (Jerry Snitselaar) [1702766]
- [iommu] iommu/amd: Reserve exclusion range in iova-domain (Jerry Snitselaar) [1694835]
- [scsi] scsi: mpt3sas: Fix kernel panic during expander reset (Tomas Henzl) [1677693]
- [mm] mm/vmstat.c: fix /proc/vmstat format for CONFIG_DEBUG_TLBFLUSH=y CONFIG_SMP=n (Waiman Long) [1705607]
- [mm] x86/mm: Drop usage of __flush_tlb_all() in kernel_physical_mapping_init() (Waiman Long) [1705607]
- [include] x86/mm: Validate kernel_physical_mapping_init() PTE population (Waiman Long) [1705607]
- [include] generic/pgtable: Introduce set_pte_safe() (Waiman Long) [1705607]
- [include] generic/pgtable: Introduce {p4d,pgd}_same() (Waiman Long) [1705607]
- [include] generic/pgtable: Make {pmd, pud}_same() unconditionally available (Waiman Long) [1705607]
- [mm] percpu: stop printing kernel addresses (Waiman Long) [1705607]
- [x86] x86/speculation: Prevent deadlock on ssb_state::lock (Waiman Long) [1705607]
- [fs] debugfs: fix use-after-free on symlink traversal (Waiman Long) [1705607]
- [lib] debugobjects: avoid recursive calls with kmemleak (Waiman Long) [1705607]
- [mm] mm/swapfile.c: use kvzalloc for swap_info_struct allocation (Waiman Long) [1705607]
- [mm] hugetlbfs: fix kernel BUG at fs/hugetlbfs/inode.c:444! (Waiman Long) [1705607]
- [include] watchdog/core: Add missing prototypes for weak functions (Waiman Long) [1705607]
- [mm] memory_hotplug: cond_resched in __remove_pages (Waiman Long) [1705607]
- [kernel] genirq: Fix race on spurious interrupt detection (Waiman Long) [1705607]
- [kernel] printk: Fix panic caused by passing log_buf_len to command line (Waiman Long) [1705607]
- [mm] mm/hmm: fix race between hmm_mirror_unregister() and mmu_notifier callback (Waiman Long) [1705607]
- [mm] mm/rmap: map_pte() was not handling private ZONE_DEVICE page properly (Waiman Long) [1705607]
- [mm] hugetlbfs: dirty pages as they are added to pagecache (Waiman Long) [1705607]
- [fs] mm: /proc/pid/smaps_rollup: fix NULL pointer deref in smaps_pte_range() (Waiman Long) [1705607]
- [kernel] sched/fair: Fix the min_vruntime update logic in dequeue_entity() (Waiman Long) [1705607]
- [mm] x86/mm/pat: Disable preemption around __flush_tlb_all() (Waiman Long) [1705607]
- [x86] x86/corruption-check: Fix panic in memory_corruption_check() when boot option without value is provided (Waiman Long) [1705607]
- [x86] x86/time: Correct the attribute on jiffies' definition (Waiman Long) [1705607]
- [x86] x86/percpu: Fix this_cpu_read() (Waiman Long) [1705607]
- [x86] x86/tsc: Force inlining of cyc2ns bits (Waiman Long) [1705607]
- [mm] mm/migrate.c: split only transparent huge pages when allocation fails (Waiman Long) [1705607]
- [mm] mm/thp: fix call to mmu_notifier in set_pmd_migration_entry() v2 (Waiman Long) [1705607]
- [mm] mm/mmap.c: don't clobber partially overlapping VMA with MAP_FIXED_NOREPLACE (Waiman Long) [1705607]
- [mm] percpu: stop leaking bitmap metadata blocks (Waiman Long) [1705607]
- [lib] vsprintf: Fix off-by-one bug in bstr_printf() processing dereferenced pointers (Waiman Long) [1705607]
- [mm] mm/vmstat.c: fix outdated vmstat_text (Waiman Long) [1705607]
- [base] PM / core: Clear the direct_complete flag on errors (Waiman Long) [1705607]
- [tools] x86/vdso: Fix vDSO syscall fallback asm constraint regression (Waiman Long) [1705607]
- [x86] x86/vdso: Only enable vDSO retpolines when enabled and supported (Waiman Long) [1705607]
- [tools] selftests/x86: Add clock_gettime() tests to test_vdso (Waiman Long) [1705607]
- [x86] x86/vdso: Fix asm constraints on vDSO syscall fallbacks (Waiman Long) [1705607]
- [drivers] clocksource/drivers/timer-atmel-pit: Properly handle error cases (Waiman Long) [1705607]
- [mm] mm/vmstat.c: skip NR_TLB_REMOTE_FLUSH* properly (Waiman Long) [1705607]
- [mm] mm, thp: fix mlocking THP page with migration enabled (Waiman Long) [1705607]
- [mm] mm: migration: fix migration of huge PMD shared pages (Waiman Long) [1705607]
- [net] net/smc: improve smc_conn_create reason codes (Philipp Rudo) [1703471]
- [net] net/smc: improve smc_listen_work reason codes (Philipp Rudo) [1703471]
- [net] net/smc: code cleanup smc_listen_work (Philipp Rudo) [1703471]
- [net] net/smc: cleanup of get vlan id (Philipp Rudo) [1703471]
- [net] net/smc: consolidate function parameters (Philipp Rudo) [1703471]
- [net] net/smc: check for ip prefix and subnet (Philipp Rudo) [1703471]
- [net] net/smc: fallback to TCP after connect problems (Philipp Rudo) [1703471]
- [net] net/smc: nonblocking connect rework (Philipp Rudo) [1703471]
- [net] net/smc: move unhash before release of clcsock (Philipp Rudo) [1703471]
- [net] net/smc: fix return code from FLUSH command (Philipp Rudo) [1703471]
- [net] net/smc: propagate file from SMC to TCP socket (Philipp Rudo) [1703471]
- [net] net/smc: fix a NULL pointer dereference (Philipp Rudo) [1703471]
- [net] net/smc: wait for pending work before clcsock release_sock (Philipp Rudo) [1703471]
- [net] net/smc: allow pnetid-less configuration (Philipp Rudo) [1700797]
- [net] net/smc: allow PCI IDs as ib device names in the pnet table (Philipp Rudo) [1700797]
- [net] net/smc: add pnet table namespace support (Philipp Rudo) [1700797]
- [net] net/smc: add smcd support to the pnet table (Philipp Rudo) [1700797]
- [net] net/smc: rework pnet table (Philipp Rudo) [1700797]
- [net] net/smc: cleanup for smcr_tx_sndbuf_nonempty (Philipp Rudo) [1700797]

* Tue May 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-88.el8]
- [tools] tools power turbostat: Override CFLAGS assignments and add LDFLAGS to build command (Steve Best) [1705959]
- [tools] tools/power turbostat: update version number (Steve Best) [1705959]
- [tools] tools/power turbostat: Add checks for failure of fgets() and fscanf() (Steve Best) [1705959]
- [tools] tools/power turbostat: Warn on bad ACPI LPIT data (Steve Best) [1705959]
- [tools] tools/power turbostat: Also read package power on AMD F17h (Zen) (Steve Best) [1705959]
- [tools] tools/power turbostat: Add support for AMD Fam 17h (Zen) RAPL (Steve Best) [1705959]
- [tools] tools/power turbostat: Do not display an error on systems without a cpufreq driver (Steve Best) [1705959]
- [tools] tools/power turbostat: Add Die column (Steve Best) [1705959]
- [tools] tools/power turbostat: Cleanup CNL-specific code (Steve Best) [1705959]
- [tools] tools/power turbostat: Cleanup CC3-skip code (Steve Best) [1705959]
- [tools] tools/power turbostat: Restore ability to execute in topology-order (Steve Best) [1705959]
- [tools] tools/power turbostat: fix goldmont C-state limit decoding (Steve Best) [1705959]
- [tools] tools/power turbostat: reduce debug output (Steve Best) [1705959]
- [tools] tools/power turbosat: fix AMD APIC-id output (Steve Best) [1705959]
- [mmc] mmc: sdhci-iproc: Add ACPI support (Mark Langsdorf) [1576966]
- [mmc] mmc: sdhci-pltfm: Convert DT properties to generic device properties (Mark Langsdorf) [1576966]
- [tty] serial: 8250_dw: Add ACPI support for uart on Broadcom SoC (Mark Langsdorf) [1576966]
- [watchdog] watchdog: sp805: Add clock-frequency property (Mark Langsdorf) [1576966]
- [watchdog] watchdog: sp805: set WDOG_HW_RUNNING when appropriate (Mark Langsdorf) [1576966]
- [thermal] thermal: broadcom: Add Stingray thermal driver (Mark Langsdorf) [1576966]
- [hv] hv: vmbus: Change server monitor_pages index to 0 (Mohammed Gamal) [1691383]
- [kernel] hv: vmbus: Expose counters for interrupts and full conditions (Mohammed Gamal) [1691383]
- [kernel] vmbus: Switch to use new generic UUID API (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Check for ring when getting debug info (Mohammed Gamal) [1691383]
- [x86] hyper-v: move synic/stimer control structures definitions to hyperv-tlfs.h (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Return -EINVAL for the sys files for unopened channels (Mohammed Gamal) [1691383]
- [hv] x86, hyperv: remove PCI dependency (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Offload the handling of channels to two workqueues (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: check the creation_status in vmbus_establish_gpadl() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove the useless API vmbus_get_outgoing_channel() (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Use u to print U32 (Mohammed Gamal) [1691383]
- [hv] hv_utils: update name in struct hv_driver util_drv (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Get rid of unnecessary state in hv_context (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix the recent regression caused by incorrect clean-up (Mohammed Gamal) [1691383]
- [hv] hv_balloon: Replace spin_is_locked() with lockdep (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Use cpumask_var_t for on-stack cpu mask (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix two "this statement may fall through" warnings (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix the indentation of some "break" statements (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the descriptions of some function parameters (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Use get/put_cpu() in vmbus_connect() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix synic per-cpu context initialization (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Cleanup synic memory free path (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove use of slow_virt_to_phys() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: add numa_node to sysfs (Mohammed Gamal) [1691383]
- [x86] hv: vmbus: Get rid of MSR access from vmbus_drv.c (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the issue with freeing up hv_ctl_table_hdr (Mohammed Gamal) [1691383]
- [hv] hv: vmus: Fix the check for return value from kmsg get dump buffer (Mohammed Gamal) [1691383]
- [hv] hv: Send one page worth of kmsg dump over Hyper-V during panic (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove x86 MSR refs in arch independent code (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the offer_in_progress in vmbus_process_offer() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Add comments on ring buffer signaling (Mohammed Gamal) [1691383]
- [video] use the new async probing feature for the hyperv drivers (Mohammed Gamal) [1691383]
- [rpmspec] kernel-packaging: Remove kernel files from kernel-modules-extra package (Prarit Bhargava) [1705216]
- [fs] xfs: don't ever put nlink > 0 inodes on the unlinked list (Brian Foster) [1693063]
- [fs] xfs: reserve blocks for ifree transaction during log recovery (Brian Foster) [1693063]
- [fs] xfs: rename m_inotbt_nores to m_finobt_nores (Brian Foster) [1693063]
- [net] xfrm: Honor original L3 slave device in xfrmi policy lookup (Herbert Xu) [1702198]
- [net] xfrm: Fix inbound traffic via XFRM interfaces across network namespaces (Herbert Xu) [1702198]
- [net] xfrm: Make set-mark default behavior backward compatible (Herbert Xu) [1702198]
- [net] xfrm: remove unnecessary check in xfrmi_get_stats64 (Herbert Xu) [1702198]
- [net] xfrm: fix gro_cells leak when remove virtual xfrm interfaces (Herbert Xu) [1702198]
- [net] xfrm: Make function xfrmi_get_link_net() static (Herbert Xu) [1702198]
- [net] xfrm: fix ptr_ret.cocci warnings (Herbert Xu) [1702198]
- [net] xfrm: Return detailed errors from xfrmi_newlink (Herbert Xu) [1702198]
- [net] xfrm: Allow xfrmi if_id to be updated by UPDSA (Herbert Xu) [1702198]
- [net] xfrm: Remove xfrmi interface ID from flowi (Herbert Xu) [1702198]
- [net] xfrm: Allow Set Mark to be Updated Using UPDSA (Herbert Xu) [1702198]
- [net] xfrm: Add virtual xfrm interfaces (Herbert Xu) [1702198]
- [net] xfrm: Add a new lookup key to match xfrm interfaces. (Herbert Xu) [1702198]
- [net] flow: Extend flow informations with xfrm interface id. (Herbert Xu) [1702198]
- [net] xfrm: Extend the output_mark to support input direction and masking. (Herbert Xu) [1702198]
- [fs] xfs: don't account extra agfl blocks as available (Brian Foster) [1656687]
- [scsi] scsi: hisi_sas: Some misc tidy-up (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Don't fail IT nexus reset for Open Reject timeout (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Don't hard reset disk during controller reset (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Support all RAS events with MSI interrupts (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: allocate different SAS address for directly attached situation (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Adjust the printk format of functions hisi_sas_init_device() (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Fix for setting the PHY linkrate when disconnected (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Remedy inconsistent PHY down state in software (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: add host reset interface for test (Xiaojun Tan) [1702614]
- [hid] HID: Increase maximum report size allowed by hid_field_extract() (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: remove data[128] usage on stack when sending HBM request (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: move doorbell writing before flush (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Optimize writing ipc message from queue (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: avoid binding wrong ishtp_cl_device (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Enable Ice Lake mobile (Tony Camuso) [1688112]
- [hid] HID: increase maximum global item tag report size to 256 (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Enable Sunrise Point-H ish driver (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: remove redundant variable num_frags (Tony Camuso) [1688112]

* Mon May 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-87.el8]
- [s390] Disable kexec_load via kernel_lockdown for s390 (Philipp Rudo) [1659399]
- [s390] s390/ipl: Provide has_secure sysfs attribute (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Create ipl report and pass to next kernel (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Signature verification prototype (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Load new kernel to absolute 0 (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Unify loader code (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Simplify parmarea access (Philipp Rudo) [1659399]
- [s390] s390/purgatory: Omit use of bin2c (Philipp Rudo) [1659399]
- [s390] s390/purgatory: Reduce purgatory size (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Fix detection of text segment in ELF loader (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Fix potential segment overlap in ELF loader (Philipp Rudo) [1659399]
- [s390] s390/zcore: Rename ipl_block to mitigate name collision (Philipp Rudo) [1659399]
- [s390] s390/boot: pad bzImage to 4K (Philipp Rudo) [1659399]
- [s390] s390/ipl: add helper functions to create an IPL report (Philipp Rudo) [1659399]
- [s390] s390/ipl: read IPL report at early boot (Philipp Rudo) [1659399]
- [s390] s390/ipl: add definitions for the IPL report block (Philipp Rudo) [1659399]
- [s390] s390/ipl: provide uapi header for list directed IPL (Philipp Rudo) [1659399]
- [s390] s390/ipl: make ipl_info less confusing (Philipp Rudo) [1659399]
- [s390] s390: introduce .boot.preserved.data section compile time validation (Philipp Rudo) [1659399]
- [s390] s390: move ipl block to .boot.preserved.data section (Philipp Rudo) [1659399]
- [s390] s390: introduce .boot.preserved.data section (Philipp Rudo) [1659399]
- [mm] s390: clean up redundant facilities list setup (Philipp Rudo) [1659399]
- [s390] s390/als: remove duplicated in-place implementation of stfle (Philipp Rudo) [1659399]
- [netdrv] fm10k: Fix a potential NULL pointer dereference (Neil Horman) [1659172]
- [netdrv] fm10k: use struct_size() in kzalloc() (Neil Horman) [1659172]
- [netdrv] fm10k: TRIVIAL cleanup of extra spacing in function comment (Neil Horman) [1659172]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Neil Horman) [1659172]
- [netdrv] fm10k: bump driver version to match out-of-tree release (Neil Horman) [1659172]
- [netdrv] fm10k: add missing device IDs to the upstream driver (Neil Horman) [1659172]
- [netdrv] fm10k: ensure completer aborts are marked as non-fatal after a resume (Neil Horman) [1659172]
- [netdrv] fm10k: fix SM mailbox full condition (Neil Horman) [1659172]
- [netdrv] fm10k: remove ndo_poll_controller (Neil Horman) [1659172]
- [netdrv] intel-ethernet: use correct module license (Neil Horman) [1659172]
- [scsi] Revert "scsi: fcoe: clear FC_RP_STARTED flags when receiving a LOGO" (Nilesh Javali) [1701545]
- [tools] tools: introduce test_and_clear_bit (Peter Xu) [1694926]
- [net] bridge: fix netlink export of vlan_stats_per_port option (Ivan Vecera) [1703551]
- [net] bridge: fix vlan stats use-after-free on destruction (Ivan Vecera) [1703551]
- [tools] headers uapi: Update linux/if_link.h header copy (Ivan Vecera) [1703551]
- [net] bridge: fix a possible memory leak in __vlan_add (Ivan Vecera) [1703551]
- [net] bridge: add support for per-port vlan stats (Ivan Vecera) [1703551]
- [net] bridge: mcast: Default back to multicast enabled state (Ivan Vecera) [1703551]
- [net] bridge: pack net_bridge better (Ivan Vecera) [1703551]
- [net] bridge: convert mtu_set_by_user to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert neigh_suppress_enabled option to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert mcast options to bits (Ivan Vecera) [1703551]
- [net] bridge: convert and rename mcast disabled (Ivan Vecera) [1703551]
- [net] bridge: convert group_addr_set option to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert nf call options to bits (Ivan Vecera) [1703551]
- [net] bridge: add bitfield for options and convert vlan opts (Ivan Vecera) [1703551]
- [net] bridge: make struct opening bracket consistent (Ivan Vecera) [1703551]
- [net] Add netif_is_gretap()/netif_is_ip6gretap() (Ivan Vecera) [1701208]
- [net] sched: register callbacks for indirect tc block binds (Ivan Vecera) [1701214]
- [tools] selftests: tc-testing: fix tunnel_key failure if dst_port is unspecified (Ivan Vecera) [1701210]
- [tools] selftests: tc-testing: drop test on missing tunnel key id (Ivan Vecera) [1701210]
- [net] sched: act_tunnel_key: Don't dump dst port if it wasn't set (Ivan Vecera) [1701210]
- [net] sched: act_tunnel_key: Allow key-less tunnels (Ivan Vecera) [1701210]
- [net] ethtool: Added support for 50Gbps per lane link modes (Ivan Vecera) [1701215]
- [net] ip_gre: fix parsing gre header in ipgre_err (Hangbin Liu) [1702212]
- [net] vxlan: Free a leaked vetoed multicast rdst (Ivan Vecera) [1691695]
- [net] switchdev: Add extack argument to call_switchdev_notifiers() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add extack to switchdev operations (Ivan Vecera) [1691695]
- [net] net: Add extack argument to ndo_fdb_add() (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Delete remote after update (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Postpone vxlan_config_apply() (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Inline vxlan_dev_configure() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Allow vetoing of FDB notifications (Ivan Vecera) [1691695]
- [netdrv] vxlan: Have vxlan_fdb_replace() save original rdst value (Ivan Vecera) [1691695]
- [netdrv] vxlan: Split vxlan_fdb_update() in two (Ivan Vecera) [1691695]
- [netdrv] vxlan: Move up vxlan_fdb_free(), vxlan_fdb_destroy() (Ivan Vecera) [1691695]
- [net] bridge: Add br_fdb_clear_offload() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add vxlan_fdb_clear_offload() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add vxlan_fdb_replay() (Ivan Vecera) [1691695]
- [net] route: add support for directed broadcast forwarding (Xin Long) [1562384]
- [net] erspan: build the header with the right proto according to erspan_ver (Xin Long) [1663862]
- [net] ipv6: make ip6_create_rt_rcu return ip6_null_entry instead of NULL (Xin Long) [1688617]
- [net] tipc: handle the err returned from cmd header function (Jon Maloy) [1693452]
- [net] tipc: check link name with right length in tipc_nl_compat_link_set (Jon Maloy) [1693452]
- [net] tipc: check bearer name with right length in tipc_nl_compat_bearer_enable (Jon Maloy) [1693452]
- [net] tipc: change to check tipc_own_id to return in tipc_net_stop (Jon Maloy) [1693452]
- [net] tipc: tipc clang warning (Jon Maloy) [1693452]
- [net] tipc: fix cancellation of topology subscriptions (Jon Maloy) [1693452]
- [net] tipc: allow service ranges to be connect()'ed on RDM/DGRAM (Jon Maloy) [1693452]
- [net] net: tipc: fix a missing check for nla_nest_start (Jon Maloy) [1693452]
- [net] net: tipc: fix a missing check of nla_nest_start (Jon Maloy) [1693452]
- [net] tipc: fix RDM/DGRAM connect() regression (Jon Maloy) [1693452]
- [net] tipc: fix race condition causing hung sendto (Jon Maloy) [1693452]
- [net] tipc: improve function tipc_wait_for_rcvmsg() (Jon Maloy) [1693452]
- [net] tipc: improve function tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: fix link session and re-establish issues (Jon Maloy) [1693452]
- [net] tipc: fix skb may be leaky in tipc_link_input (Jon Maloy) [1693452]
- [net] tipc: remove dead code in struct tipc_topsrv (Jon Maloy) [1693452]
- [net] tipc: mark expected switch fall-throughs (Jon Maloy) [1693452]
- [net] tipc: remove unneeded semicolon in trace.c (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_doit (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_name_table_dump (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_link_set (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_bearer_enable (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_link_reset_stats (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in in tipc_conn_rcv_sub (Jon Maloy) [1693452]
- [net] tipc: fix memory leak in tipc_nl_compat_publ_dump (Jon Maloy) [1693452]
- [net] tipc: fix a missing check of genlmsg_put (Jon Maloy) [1693452]
- [net] tipc: fix a double free in tipc_enable_bearer() (Jon Maloy) [1693452]
- [net] net/netlink_compat: Fix a missing check of nla_parse_nested (Jon Maloy) [1693452]
- [net] tipc: fix uninitialized value for broadcast retransmission (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc bearer (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc node (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc socket (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc link (Jon Maloy) [1693452]
- [net] tipc: enable tracepoints in tipc (Jon Maloy) [1693452]
- [net] tipc: handle broadcast NAME_DISTRIBUTOR packet when receiving it (Jon Maloy) [1693452]
- [net] tipc: check group dests after tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: check tsk->group in tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: compare remote and local protocols in tipc_udp_enable() (Jon Maloy) [1693452]
- [net] tipc: use lock_sock() in tipc_sk_reinit() (Jon Maloy) [1693452]
- [net] tipc: fix node keep alive interval calculation (Jon Maloy) [1693452]
- [net] tipc: fix lockdep warning during node delete (Jon Maloy) [1693452]
- [net] tipc: don't assume linear buffer when reading ancillary data (Jon Maloy) [1693452]
- [net] tipc: fix lockdep warning when reinitilaizing sockets (Jon Maloy) [1693452]
- [net] tipc: fix link re-establish failure (Jon Maloy) [1693452]
- [net] tipc: improve broadcast retransmission algorithm (Jon Maloy) [1693452]
- [net] tipc: use destination length for copy string (Jon Maloy) [1693452]
- [net] tipc: support binding to specific ip address when activating UDP bearer (Jon Maloy) [1677371 1693452]
- [net] tipc: remainder of commit ignore STATE_MSG on wrong link session (Jon Maloy) [1693452]
- [net] tipc: buffer overflow handling in listener socket (Jon Maloy) [1693452]
- [net] tipc: add SYN bit to connection setup messages (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_sk_filter_connect() (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_sk_timeout() (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_msg_reverse() (Jon Maloy) [1693452]
- [net] tipc: Add and use skb_mark_not_on_list(). (Jon Maloy) [1693452]
- [net] tipc: correct spelling errors for tipc_topsrv_queue_evt() comments (Jon Maloy) [1693452]
- [net] tipc: correct spelling errors for struct tipc_bc_base's comment (Jon Maloy) [1693452]
- [net] tipc: correct structure parameter comments for topsrv (Jon Maloy) [1693452]
- [net] net/tipc: remove redundant variables 'tn' and 'oport' (Jon Maloy) [1693452]
- [net] net: tipc: bcast: Replace GFP_ATOMIC with GFP_KERNEL in tipc_bcast_init() (Jon Maloy) [1693452]
- [net] net: tipc: name_table: Replace GFP_ATOMIC with GFP_KERNEL in tipc_nametbl_init() (Jon Maloy) [1693452]
- [net] tipc: make some functions static (Jon Maloy) [1693452]
- [net] tipc: make link capability update thread safe (Jon Maloy) [1693452]
- [net] tipc: remove unused tipc_group_size (Jon Maloy) [1693452]
- [net] tipc: remove unused tipc_link_is_active (Jon Maloy) [1693452]
- [net] tipc: check session number before accepting link protocol messages (Jon Maloy) [1693452]
- [net] tipc: add sequence number check for link STATE messages (Jon Maloy) [1693452]
- [net] tipc: mark expected switch fall-throughs (Jon Maloy) [1693452]
- [net] tipc: extend sock diag for group communication (Jon Maloy) [1693452]
- [net] tipc: Auto removal of peer down node instance (Jon Maloy) [1693452]
- [net] tipc: optimize function tipc_node_timeout() (Jon Maloy) [1693452]
- [net] tipc: eliminate buffer cloning in function tipc_msg_extract() (Jon Maloy) [1693452]
- [net] netfilter: nf_conncount: fix argument order to find_next_bit (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: speculative garbage collection on empty lists (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: move all list iterations under spinlock (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: merge lookup and add functions (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: restart search when nodes have been erased (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: split gc in two phases (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: don't skip eviction when age is negative (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: replace CONNCOUNT_LOCK_SLOTS with CONNCOUNT_SLOTS (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: use rb_link_node_rcu() instead of rb_link_node() (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: remove wrong condition check routine (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: fix unexpected permanent node of list. (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: fix list_del corruption in conn_free (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: use spin_lock_bh instead of spin_lock (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Add list lock and gc worker, and RCU for init tree search (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Split insert and traversal (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Move locking into count_tree() (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Early exit in nf_conncount_lookup() and cleanup (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Switch to plain list (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Early exit for garbage collection (Florian Westphal) [1531074]
- [net] ptp: uapi: change _IOW to IOWR in PTP_SYS_OFFSET_EXTENDED definition (Hangbin Liu) [1677215]
- [net] ptp: check that rsv field is zero in struct ptp_sys_offset_extended (Hangbin Liu) [1677215]
- [net] ptp: deprecate gettime64() in favor of gettimex64() (Hangbin Liu) [1677215]
- [net] ptp: add PTP_SYS_OFFSET_EXTENDED ioctl (Hangbin Liu) [1677215]
- [net] ptp: check gettime64 return code in PTP_SYS_OFFSET ioctl (Hangbin Liu) [1677215]
- [net] ptp: reorder declarations in ptp_ioctl() (Hangbin Liu) [1677215]
- [net] tuntap: fix multiqueue rx (Guillaume Nault) [1686563]

* Fri May 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-86.el8]
- [edac] EDAC/amd64: Add Family 17h Model 30h PCI IDs (Aristeu Rozanski) [1696603]
- [x86] Update stepping values for coffee lake desktop (David Arcari) [1704800]
- [security] KEYS: trusted: allow trusted.ko to initialize w/o a TPM (Jerry Snitselaar) [1694208]
- [security] tpm: pass an array of tpm_extend_digest structures to tpm_pcr_extend() (Jerry Snitselaar) [1665130 1665129]
- [security] KEYS: trusted: explicitly use tpm_chip structure from tpm_default_chip() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm/ppi: Enable submission of optional command parameter for PPI 1.3 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: Possibly show command parameter if TPM PPI 1.3 is used (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: Display up to 101 operations as define for version 1.3 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: rename TPM_PPI_REVISION_ID to TPM_PPI_REVISION_ID_1 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: pass function revision ID to tpm_eval_dsm() (Jerry Snitselaar) [1665130]
- [char] tpm: Fix the type of the return value in calc_tpm2_event_size() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: fix an invalid condition in tpm_common_poll (Jerry Snitselaar) [1694208]
- [char] tpm: turn on TPM on suspend for TPM 1.x (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: move tpm_chip definition to include/linux/tpm.h (Jerry Snitselaar) [1665129]
- [char] tpm: retrieve digest size of unknown algorithms with PCR read (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: rename and export tpm2_digest and tpm2_algorithms (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: dynamically allocate the allocated_banks array (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: remove @flags from tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: take TPM chip power gating out of tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: introduce tpm_chip_start() and tpm_chip_stop() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: remove TPM_TRANSMIT_UNLOCKED flag (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: use tpm_try_get_ops() in tpm-sysfs.c. (Jerry Snitselaar) [1665130]
- [char] tpm: remove @space from tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: move TPM space code out of tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: move tpm_validate_commmand() to tpm2-space.c (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: clean up tpm_try_transmit() error handling flow (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: encapsulate tpm_dev_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: access command header through struct in tpm_try_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: declare struct tpm_header (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: print tpm2_commit_space() error inside tpm2_commit_space() (Jerry Snitselaar) [1665129]
- [char] tpm: return 0 from pcrs_show() when tpm1_pcr_read() fails (Jerry Snitselaar) [1665130]
- [char] tpm: fix invalid return value in pubek_show() (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: use tpm_buf in tpm_transmit_cmd() as the IO parameter (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: don't return bool from update_timeouts (Jerry Snitselaar) [1665130]
- [char] tpm: don't print error message in tpm_transmit_cmd when tpm still testing (Jerry Snitselaar) [1665129]
- [char] tpm: add _head suffix to tcg_efi_specid_event and tcg_pcr_event2 (Jerry Snitselaar) [1665129]
- [char] tpm: Fix off-by-one when reading binary_bios_measurements (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: Simplify the measurements loop (Jerry Snitselaar) [1665130]
- [char] tpm/tpm_i2c_atmel: Return -E2BIG when the transfer is incomplete (Jerry Snitselaar) [1694208]
- [char] tpm: Unify the send callback behaviour (Jerry Snitselaar) [1665129]
- [char] tpm: Fix some name collisions with drivers/char/tpm.h (Jerry Snitselaar) [1694208]
- [char] tpm/tpm_crb: Avoid unaligned reads in crb_recv() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: add support for partial reads (Jerry Snitselaar) [1665129]
- [char] tpm: tpm_ibmvtpm: fix kdoc warnings (Jerry Snitselaar) [1665129]
- [char] tpm: fix kdoc for tpm2_flush_context_cmd() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: tpm_try_transmit() refactor error flow. (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: use u32 instead of int for PCR index (Jerry Snitselaar) [1665130 1665129]
- [security] ima: Get rid of ima_used_chip and use ima_tpm_chip != NULL instead (Jerry Snitselaar) [1665130 1665129]
- [security] ima: Use tpm_default_chip() and call TPM functions with a tpm_chip (Jerry Snitselaar) [1665129]
- [char] tpm1: reimplement tpm1_continue_selftest() using tpm_buf (Jerry Snitselaar) [1665130]
- [char] tpm1: reimplement SAVESTATE using tpm_buf (Jerry Snitselaar) [1665130]
- [char] tpm1: rename tpm1_pcr_read_dev to tpm1_pcr_read() (Jerry Snitselaar) [1665130]
- [char] tpm1: implement tpm1_pcr_read_dev() using tpm_buf structure (Jerry Snitselaar) [1665130]
- [char] tpm: tpm1: rewrite tpm1_get_random() using tpm_buf structure (Jerry Snitselaar) [1665130]
- [char] tpm: tpm-space.c remove unneeded semicolon (Jerry Snitselaar) [1665129]
- [char] tpm: tpm-interface.c drop unused macros (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: add tpm_auto_startup() into tpm-interface.c (Jerry Snitselaar) [1665129]
- [char] tpm: factor out tpm_startup function (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: factor out tpm 1.x pm suspend flow into tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm 1.x selftest code from tpm-interface.c tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: factor out tpm1_get_random into tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm_getcap to tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm1_pcr_extend to tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: factor out tpm_get_timeouts() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: add tpm_calc_ordinal_duration() wrapper (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: factor out tpm 1.x duration calculation to tpm1-cmd.c (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: sort objects in the Makefile (Jerry Snitselaar) [1665129]
- [char] tpm2: add new tpm2 commands according to TCG 1.36 (Jerry Snitselaar) [1665129]
- [char] tpm: tpm_i2c_nuvoton: use correct command duration for TPM 2.x (Jerry Snitselaar) [1665129]
- [char] tpm: add support for nonblocking operation (Jerry Snitselaar) [1665129]
- [char] tpm: add ptr to the tpm_space struct to file_priv (Jerry Snitselaar) [1665129]
- [char] tpm: Make SECURITYFS a weak dependency (Jerry Snitselaar) [1665129]
- [char] tpm: suppress transmit cmd error logs when TPM 1.2 is disabled/deactivated (Jerry Snitselaar) [1665130]
- [char] tpm: fix response size validation in tpm_get_random() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: replace TPM_TRANSMIT_RAW with TPM_TRANSMIT_NESTED (Jerry Snitselaar) [1665129]
- [char] tpm: Convert tpm_find_get_ops() to use tpm_default_chip() (Jerry Snitselaar) [1665129]
- [char] tpm: Implement tpm_default_chip() to find a TPM chip (Jerry Snitselaar) [1665129]
- [char] tpm: rename tpm_chip_find_get() to tpm_find_get_ops() (Jerry Snitselaar) [1665129]
- [char] tpm: Allow tpm_tis drivers to set hwrng quality. (Jerry Snitselaar) [1665129]
- [char] tpm: Return the actual size when receiving an unsupported command (Jerry Snitselaar) [1694208 1665129]
- [char] tpm/tpm_i2c_infineon: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (Jerry Snitselaar) [1665129]
- [char] tpm_tis_spi: Pass the SPI IRQ down to the driver (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_get_random() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_get_tpm_pt() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_probe() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_shutdown() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [pci] PCI: Fix __initdata issue with "pci=disable_acs_redir" parameter (Myron Stowe) [1704979]
- [s390] s390/pci: skip VF scanning (Myron Stowe) [1704979]
- [pci] PCI/IOV: Add flag so platforms can skip VF scanning (Myron Stowe) [1704979]
- [pci] PCI/IOV: Factor out sriov_add_vfs() (Myron Stowe) [1704979]
- [pci] switchtec: Add MRPC DMA mode support (Myron Stowe) [1704979]
- [pci] switchtec: Improve MRPC efficiency by enabling write combining (Myron Stowe) [1704979]
- [pci] switchtec: Fix SWITCHTEC_IOCTL_EVENT_IDX_ALL flags overwrite (Myron Stowe) [1704979]
- [pci] switchtec: Set DMA coherent mask (Myron Stowe) [1704979]
- [pci] switchtec: Remove immediate status check after submitting MRPC command (Myron Stowe) [1704979]
- [pci] PCI / PM: Allow runtime PM without callback functions (Myron Stowe) [1704979]
- [pci] PCI/P2PDMA: Clean up documentation and kernel-doc (Myron Stowe) [1704979]
- [pci] PCI: Remove unnecessary space before function pointer arguments (Myron Stowe) [1704979]
- [maintainers] MAINTAINERS: Add x86 early-quirks.c file pattern to PCI subsystem (Myron Stowe) [1704979]
- [pci] PCI: Expand the "PF" acronym in Kconfig help text (Myron Stowe) [1704979]
- [x86] x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux) (Myron Stowe) [1704979]
- [pci] PCI/ASPM: Remove unused lists from struct pcie_link_state (Myron Stowe) [1704979]
- [pci] PCI / ACPI: Identify untrusted PCI devices (Myron Stowe) [1704979]

* Thu May 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-85.el8]
- [documentation] x86/resctrl: Update Documentation/x86/resctrl_ui.txt (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Remove unnecessary check for cbm_validate() (Prarit Bhargava) [1504489]
- [maintainers] MAINTAINERS: Update resctrl filename patterns (Prarit Bhargava) [1504489]
- [documentation] Documentation: Rename and update intel_rdt_ui.txt to resctrl_ui.txt (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Introduce AMD QOS feature (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Fixup the user-visible strings (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Add AMD's X86_FEATURE_MBA to the scattered CPUID features (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename the config option INTEL_RDT to RESCTRL (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Add vendor check for the MBA software controller (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Bring cbm_validate() into the resource structure (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Initialize the vendor-specific resource functions (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Move all the macros to resctrl/internal.h (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Re-arrange the RDT init code (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename the RDT functions and definitions (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename and move rdt files to a separate directory (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Prevent pseudo-locking from using stale pointers (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix initial allocation to consider CDP (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: CBM overlap should also check for overlap with CDP peer (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce utility to obtain CDP peer (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix out-of-bounds memory access in CBM tests (Prarit Bhargava) [1504489]
- [x86] perf/x86: Add helper to obtain performance counter index (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Switch to bitmap_zalloc() (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Re-enable pseudo-lock measurements (Prarit Bhargava) [1504489]
- [x86] x86/cpu: Sanitize FAM6_ATOM naming (David Arcari) [1504489]
- [x86] x86/intel_rdt: Use perf infrastructure for measurements (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create required perf event attributes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Remove local register variables (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix incorrect loop end condition (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix exclusive mode handling of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix incorrect loop end condition (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Do not allow pseudo-locking of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix unchecked MSR access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix invalid mode warning when multiple resources are managed (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Global closid helper to support future fixes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix size reporting of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix data type in parsing callbacks (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Disable PMU access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix possible circular lock dependency (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Make CPU information accessible for pseudo-locked regions (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support restoration of subset of permissions (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix cleanup of plr structure on error (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Move pseudo_lock_region_clear() (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Limit C-states dynamically when pseudo-locking active (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support L3 cache performance event of Broadwell (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: More precise L2 hit/miss measurements (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create character device exposing pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create debugfs files for pseudo-locking testing (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create resctrl debug area (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Ensure RDT cleanup on exit (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Resctrl files reflect pseudo-locked information (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support creation/removal of pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Pseudo-lock region creation/removal core (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Discover supported platforms via prefetch disable bits (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utilities to test pseudo-locked region possibility (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Split resource group removal in two (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Enable entering of pseudo-locksetup mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support enter/exit of locksetup mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add check to determine if monitoring in progress (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Utilities to restrict/restore access to specific files (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Protect against resource group changes during locking (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utility to restrict/restore access to resctrl files (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utility to test if tasks assigned to resource group (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Respect read and write access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce the Cache Pseudo-Locking modes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Display resource groups' allocations' size in bytes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce "bit_usage" to display cache allocations details (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Ensure requested schemata respects mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support flexible data to parsing callbacks (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Making CBM name and type more explicit (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Enable setting of exclusive mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce new "exclusive" mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Initialize new resource group with sane defaults (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Make useful functions available internally (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce test to determine if closid is in use (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce resource group's mode resctrl file (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Associate mode with each RDT resource group (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce RDT resource group mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Provide pseudo-locking hooks within rdt_mount (Prarit Bhargava) [1504489]
- [x86] perf/x86: Make perf callchains work without CONFIG_FRAME_POINTER (Jiri Olsa) [1699780]

* Wed May 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-84.el8]
- [kernel] sched/fair: Do not re-read ->h_load_next during hierarchical load calculation (Phil Auld) [1701762]
- [s390] kvm: s390: enable MSA9 keywrapping functions depending on cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: add deflate conversion facilty to cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: add enhanced sort facilty to cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: provide query function for instructions returning 32 byte (Thomas Huth) [1660913]
- [s390] kvm: s390: add MSA9 to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add vector BCD enhancements facility to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add vector enhancements facility 2 to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add debug logging for cpu model subfunctions (Thomas Huth) [1660913]
- [s390] kvm: s390: implement subfunction processor calls (Thomas Huth) [1660913]
- [powercap] powercap: intel_rapl: add support for Jacobsville (Steve Best) [1482401]
- [x86] x86/cpu: Add Atom Tremont (Jacobsville) (Steve Best) [1482401]

* Tue May 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-83.el8]
- [crypto] crypto: qat - Remove unused goto label (Neil Horman) [1660313]
- [crypto] crypto: prefix header search paths with $(srctree)/ (Neil Horman) [1660313]
- [crypto] crypto: qat - no need to check return value of debugfs_create functions (Neil Horman) [1660313]
- [crypto] cross-tree: phase out dma_zalloc_coherent() (Neil Horman) [1660313]
- [crypto] crypto: qat - move temp buffers off the stack (Neil Horman) [1660313]
- [crypto] crypto: qat - Remove VLA usage (Neil Horman) [1660313]
- [include] block: kill all_q_node in request_queue (Ming Lei) [1702865]
- [block] bfq: update internal depth state when queue depth changes (Ming Lei) [1702865]
- [fs] block: fix the return errno for direct IO (Ming Lei) [1702865]
- [block] block: do not leak memory in bio_copy_user_iov() (Ming Lei) [1702865]
- [nvme] nvme: cancel request synchronously (Ming Lei) [1702865]
- [block] blk-mq: introduce blk_mq_complete_request_sync() (Ming Lei) [1702865]
- [scsi] scsi: virtio_scsi: limit number of hw queues by nr_cpu_ids (Ming Lei) [1702865]
- [block] virtio-blk: limit number of hw queues by nr_cpu_ids (Ming Lei) [1702865]
- [block] block, bfq: fix use after free in bfq_bfqq_expire (Ming Lei) [1702865]
- [block] paride/pcd: Fix potential NULL pointer dereference and mem leak (Ming Lei) [1702865]
- [block] blk-mq: do not reset plug->rq_count before the list is sorted (Ming Lei) [1702865]
- [block] paride/pf: Fix potential NULL pointer dereference (Ming Lei) [1702865]
- [block] blk-mq: add trace block plug and unplug for multiple queues (Ming Lei) [1702865]
- [block] block: use blk_free_flush_queue() to free hctx->fq in blk_mq_init_hctx (Ming Lei) [1702865]
- [block] paride/pcd: cleanup queues when detection fails (Ming Lei) [1702865]
- [block] paride/pf: cleanup queues when detection fails (Ming Lei) [1702865]
- [crypto] crypto: chelsio - Fixed Traffic Stall (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Fix passing zero to 'PTR_ERR' warning in chcr_aead_op (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Inline single pdu only (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - avoid using sa_entry imm (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - remove set but not used variables 'adap' (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - check set_msg_len overflow in generate_b0 (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Fix wrong error counter increments (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Reset counters on cxgb4 Detach (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Handle PCI shutdown event (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - cleanup:send addr as value in function argument (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Use same value for both channel in single WR (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Swap location of AAD and IV sent in WR (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - remove set but not used variable 'kctx_len' (Arjun Vynipadath) [1664679]
- [crypto] drivers: chelsio: use skb_sec_path helper (Arjun Vynipadath) [1664679]
- [crypto] crypto: chcr - ESN for Inline IPSec Tx (Arjun Vynipadath) [1664679]
- [crypto] crypto: chcr - small packet Tx stalls the queue (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - clean up various indentation issues (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Update ntx queue received from cxgb4 (Arjun Vynipadath) [1664679]

* Fri May 03 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-82.el8]
- [platform] platform/x86: intel_pmc_core: Convert to INTEL_CPU_FAM6 macro (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Avoid a u32 overflow (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Include Reserved IP for LTR (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix file permissions for ltr_show (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix PCH IP name (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix PCH IP sts reading (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Handle CFL regmap properly (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: convert to DEFINE_SHOW_ATTRIBUTE (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Decode Snoop / Non Snoop LTR (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix LTR IGNORE Max offset (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Show Latency Tolerance info (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc: Convert to use SPDX identifier (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Add CNP SLPS0 debug registers (David Arcari) [1658080]
- [x86] x86/cpu: Introduce INTEL_CPU_FAM*() helper macros (David Arcari) [1658080]
- [include] locking/atomics, asm-generic: Move some macros from <linux/bitops.h> to a new <linux/bits.h> file (David Arcari) [1658080]
- [s390] s390/kasan: fix strncpy_from_user kasan checks (Philipp Rudo) [1665182]
- [s390] s390: correct some inline assembly constraints (Philipp Rudo) [1665182]
- [s390] s390/kasan: improve string/memory functions checks (Philipp Rudo) [1665182]
- [include] compiler: remove __no_sanitize_address_or_inline again (Philipp Rudo) [1665182]
- [s390] s390/kasan: increase instrumented stack size to 64k (Philipp Rudo) [1665182]
- [mm] s390/kasan: support preemptible kernel build (Philipp Rudo) [1665182]
- [mm] s390/kasan: add support for mem= kernel parameter (Philipp Rudo) [1665182]
- [mm] s390/kasan: optimize kasan vmemmap allocation (Philipp Rudo) [1665182]
- [mm] s390/kasan: avoid kasan crash with standby memory defined (Philipp Rudo) [1665182]
- [s390] s390/head: avoid doubling early boot stack size under KASAN (Philipp Rudo) [1665182]
- [mm] s390/mm: improve debugfs ptdump markers walking (Philipp Rudo) [1665182]
- [mm] s390/mm: optimize debugfs ptdump kasan zero page walking (Philipp Rudo) [1665182]
- [s390] s390/kasan: add option for 4-level paging support (Philipp Rudo) [1665182]
- [mm] s390/kasan: free early identity mapping structures (Philipp Rudo) [1665182]
- [s390] s390/kasan: enable stack and global variables access checks (Philipp Rudo) [1665182]
- [s390] s390/dumpstack: disable __dump_trace kasan instrumentation (Philipp Rudo) [1665182]
- [s390] s390/kasan: reipl and kexec support (Philipp Rudo) [1665182]
- [s390] s390/smp: kasan stack instrumentation support (Philipp Rudo) [1665182]
- [include] compiler: introduce __no_sanitize_address_or_inline (Philipp Rudo) [1665182]
- [s390] s390/kasan: use noexec and large pages (Philipp Rudo) [1665182]
- [mm] s390/kasan: dynamic shadow mem allocation for modules (Philipp Rudo) [1665182]
- [mm] s390/mm: add kasan shadow to the debugfs pgtable dump (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid user access code instrumentation (Philipp Rudo) [1665182]
- [s390] s390/kasan: double the stack size (Philipp Rudo) [1665182]
- [s390] s390/kasan: add initialization code and enable it (Philipp Rudo) [1665182]
- [s390] s390: add pgd_page primitive (Philipp Rudo) [1665182]
- [s390] s390: introduce MAX_PTRS_PER_P4D (Philipp Rudo) [1665182]
- [s390] s390/kasan: replace some memory functions (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid instrumentation of early C code (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid vdso instrumentation (Philipp Rudo) [1665182]
- [s390] s390/mm: add missing pfn_to_kaddr helper (Philipp Rudo) [1665182]
- [s390] s390/cpum_cf: Add support for CPU-MF SVN 6 (Philipp Rudo) [1683278]
- [s390] s390: report new CPU capabilities (Philipp Rudo) [1685086]
- [net] net/smc: fix smc_poll in SMC_INIT state (Philipp Rudo) [1700812]
- [net] net/smc: fix byte_order for rx_curs_confirmed (Philipp Rudo) [1700812]
- [net] net/smc: check port_idx of ib event (Philipp Rudo) [1700799]
- [net] net/smc: check connections in smc_lgr_free_work (Philipp Rudo) [1700799]
- [net] net/smc: reduce amount of status updates to peer (Philipp Rudo) [1700799]
- [net] net/smc: no delay for free tx buffer wait (Philipp Rudo) [1700799]
- [net] net/smc: move wake up of close waiter (Philipp Rudo) [1700799]
- [net] net/smc: reset cursor update required flag (Philipp Rudo) [1700799]
- [net] net/smc: correct state change for peer closing (Philipp Rudo) [1700799]
- [net] net/smc: delete rkey first before switching to unused (Philipp Rudo) [1700799]
- [net] net/smc: fix sender_free computation (Philipp Rudo) [1700799]
- [net] net/smc: preallocated memory for rdma work requests (Philipp Rudo) [1700799]
- [net] net/smc: fix use of variable in cleared area (Philipp Rudo) [1700799]
- [net] net/smc: use device link provided in qp_context (Philipp Rudo) [1700799]
- [net] net/smc: call smc_cdc_msg_send() under send_lock (Philipp Rudo) [1700799]
- [net] net/smc: do not wait under send_lock (Philipp Rudo) [1700799]
- [net] net/smc: recvmsg and splice_read should return 0 after shutdown (Philipp Rudo) [1700799]
- [net] net/smc: don't wait for send buffer space when data was already sent (Philipp Rudo) [1700799]
- [net] net/smc: prevent races between smc_lgr_terminate() and smc_conn_free() (Philipp Rudo) [1700799]
- [net] net/smc: allow 16 byte pnetids in netlink policy (Philipp Rudo) [1700799]
- [net] net/smc: fix another sizeof to int comparison (Philipp Rudo) [1700799]
- [net] net/smc: move code to clear the conn->lgr field (Philipp Rudo) [1700799]
- [net] net/smc: use client and server LGR pending locks for SMC-R (Philipp Rudo) [1700799]
- [net] net/smc: unlock LGR pending lock earlier for SMC-D (Philipp Rudo) [1700799]
- [net] net/smc: use smc_curs_copy() for SMC-D (Philipp Rudo) [1700799]
- [net] net/smc: postpone release of clcsock (Philipp Rudo) [1700799]
- [net] smc: move unhash as early as possible in smc_release() (Philipp Rudo) [1700799]
- [net] net/smc: fix TCP fallback socket release (Philipp Rudo) [1700799]
- [s390] s390/ism: ignore some errors during deregistration (Philipp Rudo) [1700799]
- [infiniband] mlx4: trigger IB events needed by SMC (Philipp Rudo) [1700799]
- [s390] s390/smp: fix CPU hotplug deadlock with CPU rescan (Philipp Rudo) [1700836]
- [block] s390/dasd: fix panic for failed online processing (Philipp Rudo) [1700811]
- [netdrv] s390/qeth: fix use-after-free in error path (Philipp Rudo) [1700803]
- [netdrv] s390/qeth: cancel close_dev work before removing a card (Philipp Rudo) [1700802]
- [netdrv] s390/qeth: conclude all event processing before offlining a card (Philipp Rudo) [1700800]
- [scsi] scsi: zfcp: fix posting too many status read buffers leading to adapter shutdown (Philipp Rudo) [1700775]
- [fs] xfs: prohibit fstrim in norecovery mode (Bill O'Donnell) [1697749]
- [x86] perf/x86: Fixup typo in stub functions (Waiman Long) [1688789]
- [x86] perf/x86/intel: Fix memory corruption (Waiman Long) [1688789]
- [x86] perf/x86/intel: Implement support for TSX Force Abort (Waiman Long) [1688789]
- [x86] x86: Add TSX Force Abort CPUID/MSR (Waiman Long) [1688789]
- [x86] perf/x86/intel: Generalize dynamic constraint creation (Waiman Long) [1688789]
- [x86] perf/x86/intel: Make cpuc allocations consistent (Waiman Long) [1688789]
- [x86] perf/x86/intel: Delay memory deallocation until x86_pmu_dead_cpu() (Waiman Long) [1688789]
- [x86] perf/x86/intel: Export mem events only if there's PEBS support (Waiman Long) [1688789]
- [x86] perf/x86/intel: Add a separate Arch Perfmon v4 PMI handler (Waiman Long) [1688789]
- [x86] perf/x86/intel: Factor out common code of PMI handler (Waiman Long) [1688789]
- [x86] perf/x86/intel: Introduce PMU flag for Extended PEBS (Waiman Long) [1688789]
- [x86] x86/speculation: Add PR_SPEC_DISABLE_NOEXEC (Waiman Long) [1671512]

* Tue Apr 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-81.el8]
- [kernel] exit from RHEL 8.1 early ystream mode ("Herton R. Krzesinski")
- [net] Bluetooth: Verify that l2cap_get_conf_opt provides large enough buffer (Gopal Tiwari) [1700507] {CVE-2019-3459}
- [target] scsi: target: iscsi: cxgbit: fix csk leak (Arjun Vynipadath) [1664683]
- [target] scsi: target: iscsi: cxgbit: add missing spin_lock_init() (Arjun Vynipadath) [1664683]
- [scsi] scsi: cxgb4i: fix incorrect spelling "reveive" -> "receive" (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: update route finding logic (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: find cxgbi device by MAC address (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgbi: remove redundant __kfree_skb call on skb and free cst->atid (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: remove uninitialized variable len (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: validate tcp sequence number only if chip version <= T5 (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: get pf number from lldi->pf (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: add wait_for_completion() (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: fix thermal configuration dependencies (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: add DCB support for iSCSI connections (Arjun Vynipadath) [1664685]
- [netdrv] cxgb4: Don't return EAGAIN when TCAM is full. (Arjun Vynipadath) [1664670]
- [netdrv] chelsio: use BUG() instead of BUG_ON(1) (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/chtls: Prefix adapter flags with CXGB4 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Call netif_carrier_off properly in pci_probe (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: Revert force link up behaviour (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: Add VF Link state support (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Prefix adapter flags with CXGB4VF (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4vf: Enter debugging mode if FW is inaccessible (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: Enable outer UDP checksum offload for T6 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Fix up netdev->hw_features (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: Mask out interrupts that are not enabled. (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Export sge_host_page_size to ulds (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add capability to get/set SGE Doorbell Queue Timer Tick (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Add support for SGE doorbell queue timer (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: Few more link management changes. (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: add tcb flags and tcb rpl struct (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T6 PCI device ids 0x608b (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Program hash region for {t4/t4vf}_change_mac() (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: smt: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: sched: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: cxgb4_tc_u32: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Update port information in cxgb4vf_open() (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4/cxgb4vf: Link management changes (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: TLS record offload enable (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: clip_tbl: Use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] net: cxgb4: fix various indentation issues (Arjun Vynipadath) [1664670]
- [netdrv] net: chelsio: Add a missing check on cudg_get_buffer (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove DEFINE_SIMPLE_DEBUGFS_FILE() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: number of VFs supported is not always 16 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove set but not used variables 'multitrc, speed' (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: use new fw interface to get the VIN and smt index (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Fix mac_hlist initialization and free (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: fix memleak in mac_hlist initialization (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4vf: free mac_hlist properly (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: free mac_hlist properly (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix thermal zone build error (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix thermal configuration dependencies (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add thermal zone support (Arjun Vynipadath) [1664670]
- [infiniband] cxgb4: use __vlan_hwaccel helpers (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T6 PCI device ids 0x608a (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix the error path of cxgb4_uld_register() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: use FW_PORT_ACTION_L1_CFG32 for 32 bit capability (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove the unneeded locks (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Use proper enum in IEEE_FAUX_SYNC (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Use proper enum in cxgb4_dcb_handle_fw_update (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove duplicated include from cxgb4_main.c (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: add per rx-queue counter for packet errors (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Fix endianness issue in t4_fwcache() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix abort_req_rss6 struct (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove redundant assignment to vlan_cmd.dropnovlan_fm (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect hardware queue descriptors (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T5 PCI device ids 0x50af and 0x50b0 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove set but not used variable 'spd' (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: add support to display DCB info (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/t4_hw: mark expected switch fall-throughs (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/l2t: Mark expected switch fall-through (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix endian to test F_FW_PORT_CMD_DCBXDIS32 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: print ULD queue information managed by LLD (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: move Tx/Rx free pages collection to common code (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add support to read actual provisioned resources (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T5 PCI device id 0x50ae (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect number of free PSTRUCT page pointers (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: display number of rx and tx pages free (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect ASIC LA dumps from ULP TX (Arjun Vynipadath) [1664670]
- [netdrv] libcxgb: replace vmalloc and memset with vzalloc (Arjun Vynipadath) [1664670]
- [netdrv] enic: fix checksum validation for IPv6 (Jonathan Toppins) [1685309]
- [infiniband] RDMA/vmw_pvrdma: Return the correct opcode when creating WR (Jonathan Toppins) [1688010 1685309]
- [infiniband] RDMA/vmw_pvrdma: Use atomic memory allocation in create AH (Jonathan Toppins) [1685309]
- [infiniband] IB/usnic: fix spelling mistake "miniumum" -> "minimum" (Jonathan Toppins) [1685309]
- [infiniband] RDMA/drivers: Fix spelling mistake "initalize" -> "initialize" (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Reuse code which sets port state (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Make counters thread safe (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Jonathan Toppins) [1685309]
- [infiniband] IB/{mlx5, ocrdma, qedr, rxe}: Omit port validation from IB verbs (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Fix incorrect cache cleanup in error flow (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Utilize generic function to validate port number (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Make function rxe_pool_cleanup return void (Jonathan Toppins) [1685309]
- [infiniband] rxe: IB_WR_REG_MR does not capture MR's iova field (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: make rxe_unregister_device void (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: move the variable into the function that uses it (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Add link_down, rdma_sends, rdma_recvs stats counters (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Distinguish between down links and disabled links (Jonathan Toppins) [1685309]
- [infiniband] rxe: fix error completion wr_id and qp_num (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: clean skb queue directly (Jonathan Toppins) [1685309]
- [net] xprtrdma: Make sure Send CQ is allocated on an existing compvec (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Rework SCSI device reset handling (Jonathan Toppins) [1685309]
- [infiniband] IB/ipoib: Fix for use-after-free in ipoib_cm_tx_start (Jonathan Toppins) [1685309]
- [net] xprtrdma: Double free in rpcrdma_sendctxs_create() (Jonathan Toppins) [1685309]
- [net] xprtrdma: Fix error code in rpcrdma_buffer_create() (Jonathan Toppins) [1685309]
- [infiniband] IB/ipoib: drop useless LIST_HEAD (Jonathan Toppins) [1685309]
- [net] xprtrdma: Prevent leak of rpcrdma_rep objects (Jonathan Toppins) [1685309]
- [net] xprtrdma: Don't leak freed MRs (Jonathan Toppins) [1685309]
- [net] xprtrdma: Add documenting comment for rpcrdma_buffer_destroy (Jonathan Toppins) [1685309]
- [net] xprtrdma: Replace outdated comment for rpcrdma_ep_post (Jonathan Toppins) [1685309]
- [net] xprtrdma: Update comments in frwr_op_send (Jonathan Toppins) [1685309]
- [net] xprtrdma: Trace mapping, alloc, and dereg failures (Jonathan Toppins) [1685309]
- [net] xprtrdma: Add trace points for calls to transport switch methods (Jonathan Toppins) [1685309]
- [net] xprtrdma: Relocate the xprtrdma_mr_map trace points (Jonathan Toppins) [1685309]
- [net] xprtrdma: Clean up of xprtrdma chunk trace points (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove unused fields from rpcrdma_ia (Jonathan Toppins) [1685309]
- [net] xprtrdma: Cull dprintk() call sites (Jonathan Toppins) [1685309]
- [net] xprtrdma: Simplify locking that protects the rl_allreqs list (Jonathan Toppins) [1685309]
- [net] xprtrdma: Expose transport header errors (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove request_module from backchannel (Jonathan Toppins) [1685309]
- [net] xprtrdma: Plant XID in on-the-wire RDMA offset (FRWR) (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove rpcrdma_memreg_ops (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove support for FMR memory registration (Jonathan Toppins) [1685309]
- [net] xprtrdma: Reduce max_frwr_depth (Jonathan Toppins) [1685309]
- [net] xprtrdma: Fix ri_max_segs and the result of ro_maxpages (Jonathan Toppins) [1685309]
- [net] xprtrdma: Don't wake pending tasks until disconnect is done (Jonathan Toppins) [1685309]
- [net] xprtrdma: No qp_event disconnect (Jonathan Toppins) [1685309]
- [net] xprtrdma: Replace rpcrdma_receive_wq with a per-xprt workqueue (Jonathan Toppins) [1685309]
- [net] xprtrdma: Refactor Receive accounting (Jonathan Toppins) [1685309]
- [net] xprtrdma: Ensure MRs are DMA-unmapped when posting LOCAL_INV fails (Jonathan Toppins) [1685309]
- [net] xprtrdma: Yet another double DMA-unmap (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Use kmem_cache_free() instead of kfree() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Rework the srpt_alloc_srq() error path (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Remove driver version and release date (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Make kernel-doc headers complete (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Join split strings (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Improve coding style conformance (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Fix a use-after-free in the channel release code (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Rework handling of the maximum information unit length (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Move srp_rdma_ch.max_ti_iu_len declaration (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Propagate ib_post_send() failures to the SCSI mid-layer (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Handle large SCSI CDBs correctly (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Document srp_parse_in() arguments (Jonathan Toppins) [1685309]
- [infiniband] include/scsi/srp.h: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] include/scsi/srp.h: Move response flag definitions into this file (Jonathan Toppins) [1685309]
- [net] svcrdma: Optimize the logic that selects the R_key to invalidate (Jonathan Toppins) [1685309]
- [infiniband] IB/srpt: Drop pointless static qualifier in srpt_make_tpg() (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix OOPs in uverbs_user_mmap_disassociate (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix ioctl query port to consider device disassociation (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix OOPs upon device disassociation (Jonathan Toppins) [1685309]
- [infiniband] RDMA/umem: Add missing initialization of owning_mm (Jonathan Toppins) [1685309]
- [infiniband] RDMA/device: Expose ib_device_try_get(() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Mark ioctl responses with UVERBS_ATTR_F_VALID_OUTPUT (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cma: Add cm_id restrack resource based on kernel or user cm_id type (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Don't expose unsafe global rkey to regular user (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Fix post send success return value in case of error (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Add advise_mr to the list of known ops (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Signedness bug in UVERBS_HANDLER() (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Start using dev_groups of class (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Use class_groups and let core create class file (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Refactor code to use cdev_device_add() (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Avoid destroying device while it is accessed (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Simplify and avoid dynamic allocation of class (Jonathan Toppins) [1685309]
- [infiniband] RDMA/iwcm: Don't copy past the end of dev_name() string (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Move query port to ioctl (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Expose port_cap_flags2 (Jonathan Toppins) [1685309]
- [infiniband] IB/core: uverbs copy to struct or zero helper (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Mark if destroy address handle is in a sleepable context (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Mark if create address handle is in a sleepable context (Jonathan Toppins) [1685309]
- [infiniband] RDMA/restrack: Resource-tracker should not use uobject pointers (Jonathan Toppins) [1685309]
- [include] IB/uverbs: Add support to advise_mr (Jonathan Toppins) [1685309]
- [include] IB/uverbs: Add helper to get array size from ptr attribute (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add an ioctl method to destroy an object (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add a method to introspect handles in a context (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Delete RoCE GID in hw when corresponding IP is deleted (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Implement an ioctl that can call write and write_ex handlers (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Start use ib_device_ops (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rdmavt: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/vmw_pvrdma: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/usnic: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/qib: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/qedr: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/ocrdma: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nes: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mthca: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mlx5: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mlx4: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/i40iw: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/hns: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/hfi1: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cxgb4: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cxgb3: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/bnxt_re: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Introduce ib_device_ops (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Optimize clearing of extra bytes in response (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Add new IB rates (Jonathan Toppins) [1685309]
- [include] IB/core: Add 2X port width (Jonathan Toppins) [1685309]
- [include] IB/core: Add CapabilityMask2 to port attributes (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Validate port number in query_pkey verb (Jonathan Toppins) [1685309]
- [include] RDMA/uverbs: Fix typo in string concatenation macro (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Enable getting an object type from a given uobject (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Introduce UVERBS_IDR_ANY_OBJECT (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Export to user space number of contexts (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Annotate alloc/deallloc paths with context tracking (Jonathan Toppins) [1685309]
- [include] RDMA/restrack: Track ucontext (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use only attrs for the write() handler signature (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Do not check the input length on create_cq/qp paths (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use the iterator for ib_uverbs_unmarshall_recv() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add a simple iterator interface for reading the command (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Simplify ib_uverbs_ex_query_device (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Fill in the response for IB_USER_VERBS_EX_CMD_MODIFY_QP (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_request() and core for write_ex handlers (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_request() for request copying (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_response() for remaining response copying (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Get rid of the 'callback' scheme in the compat path (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass ucore for write/write_ex (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Remove out_len checks that are now done by the core (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: fix ptr_ret.cocci warnings (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for ioctl() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for write (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for write_ex (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Prohibit write() calls with too small buffers (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add structure size info to write commands (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Do not pass ib_uverbs_file to ioctl methods (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Make write() handlers return 0 on success (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Replace ib_uverbs_file with uverbs_attr_bundle for write (Jonathan Toppins) [1685309]
- [include] RDMA/uverbs: Add missing driver_data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Sync unregistration with netlink commands (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cma: Move cma module specific functions to cma_priv.h (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Check for NULL driver methods for every write call (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Make all the method functions in uverbs_cmd static (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Convert the write interface to use uverbs_api (Jonathan Toppins) [1685309]
- [infiniband] RDMA/verbs: Store the write/write_ex uapi entry points in the uverbs_api (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Require all objects to have a driver destroy function (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add helpers to mark uapi functions as unsupported (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Factor out the add/get pattern into a helper (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use a linear list to describe the compiled-in uapi (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Make function ib_fmr_pool_unmap return void (Jonathan Toppins) [1685309]
- [include] RDMA/core: Remove unused header files mm.h, socket.h, scatterlist.h (Jonathan Toppins) [1685309]
- [include] IB/uverbs: fix a typo (Jonathan Toppins) [1685309]
- [fs] coredump: fix race condition between mmget_not_zero()/get_task_mm() and core dumping (Andrea Arcangeli) [1696081] {CVE-2019-3892}
- [scsi] scsi: csiostor: fix missing data copy in csio_scsi_err_handler() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: drop serial_number usage (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix calls to dma_set_mask_and_coherent() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: Remove set but not used variable 'pln' (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: no need to check return value of debugfs_create functions (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix NULL pointer dereference in csio_vport_set_state() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix incorrect dma device in case of vport (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: switch to generic DMA API (Arjun Vynipadath) [1664680]
- [netdrv] thunderx: eliminate extra calls to put_page() for pages held for recycling (Dean Nelson) [1644011]
- [netdrv] thunderx: enable page recycling for non-XDP case (Dean Nelson) [1644011]
- [cpufreq] cpufreq: intel_pstate: Also use CPPC nominal_perf for base_frequency (Prarit Bhargava) [1696131]
- [acpi] ACPI / CPPC: Fix guaranteed performance handling (Prarit Bhargava) [1696131]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Corinna Vinschen) [1659169]
- [netdrv] igbvf: Replace spin_is_locked() with lockdep (Corinna Vinschen) [1659169]
- [netdrv] intel-ethernet: use correct module license (Corinna Vinschen) [1659169]
- [netdrv] igbvf: netdev: Mark expected switch fall-through (Corinna Vinschen) [1659169]
- [x86] x86/MCE: Initialize mce.bank in the case of a fatal error in mce_no_way_out() (David Arcari) [1698959]
- [x86] x86/mce: Restore MCE injector's module name (David Arcari) [1698959]
- [x86] x86/mce: Streamline MCE subsystem's naming (David Arcari) [1698959]
- [x86] x86: Fix various typos in comments (David Arcari) [1698959]
- [x86] x86/MCE/AMD: Fix the thresholding machinery initialization order (David Arcari) [1698959]
- [x86] x86/mce: Fix -Wmissing-prototypes warnings (David Arcari) [1698959]
- [x86] acpi/nfit, x86/mce: Validate a MCE's address before using it (David Arcari) [1698959]
- [x86] acpi/nfit, x86/mce: Handle only uncorrectable machine checks (David Arcari) [1698959]
- [x86] x86: Clean up 'sizeof x' => 'sizeof(x)' (David Arcari) [1698959]
- [x86] x86/mcelog: Remove one mce_helper definition (David Arcari) [1698959]
- [x86] x86/mce-inject: Reset injection struct after injection (David Arcari) [1698959]
- [mm] x86/mce: Fix set_mce_nospec() to avoid #GP fault (David Arcari) [1698959]
- [x86] x86/memory_failure: Introduce {set, clear}_mce_nospec() (David Arcari) [1698959]
- [x86] x86/mce: Cleanup __mc_scan_banks() (David Arcari) [1698959]
- [x86] x86/mce: Carve out bank scanning code (David Arcari) [1698959]
- [x86] x86/mce: Carve out the crashing_cpu check (David Arcari) [1698959]
- [x86] x86/mce: Always use 64-bit timestamps (David Arcari) [1698959]
- [x86] x86/mce: Remove !banks check (David Arcari) [1698959]
- [md] dm cache metadata: Fix loading discard bitset (Mike Snitzer) [1701618]
- [block] null_blk: prevent crash from bad home_node value (Ming Lei) [1696951]
- [powerpc] powerpc/security: Fix spectre_v2 reporting (Gustavo Duarte) [1694456]
- [powerpc] powerpc/powernv: Query firmware for count cache flush settings (Gustavo Duarte) [1694456]
- [powerpc] powerpc/pseries: Query hypervisor for count cache flush settings (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64s: Add support for software count cache flush (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64s: Add new security feature flags for count cache flush (Gustavo Duarte) [1694456]
- [powerpc] powerpc/asm: Add a patch_site macro & helpers for patching instructions (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64: Call setup_barrier_nospec() from setup_arch() (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64: Add CONFIG_PPC_BARRIER_NOSPEC (Gustavo Duarte) [1694456]
- [powerpc] powerpc64s: Show ori31 availability in spectre_v1 sysfs file not v2 (Gustavo Duarte) [1694456]

* Mon Apr 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.23.el8]
- [kernel] sched/fair: Limit sched_cfs_period_timer() loop to avoid hard lockup (Joel Savitz) [1695651]
- [crypto] crypto: ux500 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: talitos - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: sun4i-ss - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: stm32 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: rockchip - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: qce - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: picoxcell - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: omap - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: n2 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: marvell - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ixp4xx - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: hifn_795x - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ccree - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ccp - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: cavium - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: caam - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: bcm - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: atmel - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: sparc - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [s390] crypto: s390 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: des_generic - Forbid 2-key in 3DES and add helpers (Herbert Xu) [1687908]
- [crypto] crypto: mxc-scc - Remove broken driver (Herbert Xu) [1687908]
- [kernel] ntp: Audit NTP parameters adjustment (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping: Audit clock adjustments (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Remove duplicated include (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping/ntp: Constify some function arguments (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Use kstrtos64 for s64 variable (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Remove redundant arguments (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping: Use ktime_get_real_ts64() instead of getnstimeofday64() (Ondrej Mosnacek) [1680034]
- [netdrv] hinic: Add pci device ids (Xiaojun Tan) [1662040]
- [netdrv] net-next/hinic:add shutdown callback (Xiaojun Tan) [1662040]
- [netdrv] hinic: optmize rx refill buffer mechanism (Xiaojun Tan) [1662040]
- [netdrv] net: hinic: remove redundant pointer pfhwdev (Xiaojun Tan) [1662040]
- [netdrv] net: hns: fix unsigned comparison to less than zero (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix sparse: some warnings in HNS drivers (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix WARNING when remove HNS driver with SMMU enabled (Xiaojun Tan) [1661885]
- [netdrv] net: hns: fix ICMP6 neighbor solicitation messages discard problem (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix probabilistic memory overwrite when HNS driver initialized (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Use NAPI_POLL_WEIGHT for hns driver (Xiaojun Tan) [1661885]
- [netdrv] net: hns: fix KASAN: use-after-free in hns_nic_net_xmit_hw() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: use struct_size() in devm_kzalloc() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fixes the missing put_device in positive leg for roce reset (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix object reference leaks in hns_dsaf_roce_reset() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Restart autoneg need return failed when autoneg off (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix for missing of_node_put() after of_parse_phandle() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Use struct_size() in devm_kzalloc() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix use after free identified by SLUB debug (Xiaojun Tan) [1661885]
- [netdrv] net: hns: make function hns_gmac_wait_fifo_clean() static (Xiaojun Tan) [1661885]
- [netdrv] net: hns: use eth_get_headlen interface instead of hns_nic_get_headlen (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Mark expected switch fall-through (Xiaojun Tan) [1661885]
- [netdrv] net: hns: remove redundant variables 'max_frm' and 'tmp_mac_key' (Xiaojun Tan) [1661885]
- [netdrv] net: hisilicon: hns: Replace mdelay() with msleep() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: make hns_dsaf_roce_reset non static (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Make many functions static (Xiaojun Tan) [1661885]
- [bluetooth] Bluetooth: btusb: Add support for Intel bluetooth device 8087:0029 (Gopal Tiwari) [1678084]
- [bluetooth] Bluetooth: btusb: Use bt_dev_err for Intel firmware loading errors (Gopal Tiwari) [1678084]

* Fri Apr 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.22.el8]
- [vfio] vfio/pci: Restore device state on PM transition (Alex Williamson) [1700254]
- [vfio] vfio/pci: Parallelize device open and release (Alex Williamson) [1700254]
- [pci] Revert "PCI/ASPM: Do not initialize link state when aspm_disabled is set" (Myron Stowe) [1694143]
- [pci] PCI: Fix incorrect value returned from pcie_get_speed_cap() (Myron Stowe) [1694143]
- [x86] x86/PCI: Apply VMD's AERSID fixup generically (Myron Stowe) [1694143]
- [pci] PCI/IOV: Remove unnecessary include of <linux/pci-ats.h> (Myron Stowe) [1694143]
- [pci] PCI: pcie: Remove redundant 'default n' from Kconfig (Myron Stowe) [1694143]
- [documentation] NTB: switchtec_ntb: Update switchtec documentation with prerequisites for NTB (Myron Stowe) [1694143]
- [pci] PCI: Fix Switchtec DMA aliasing quirk dmesg noise (Myron Stowe) [1694143]
- [pci] PCI: Add macro for Switchtec quirk declarations (Myron Stowe) [1694143]
- [pci] PCI: Add Device IDs for Intel GPU "spurious interrupt" quirk (Myron Stowe) [1694143]
- [pci] PCI / ACPI: Mark expected switch fall-through (Myron Stowe) [1694143]
- [pci] PCI: Remove set but unused variable (Myron Stowe) [1694143]
- [pci] PCI: Fix pci.c kernel-doc parameter warning (Myron Stowe) [1694143]
- [pci] PCI: Allocate dma_alias_mask with bitmap_zalloc() (Myron Stowe) [1694143]
- [include] PCI: Remove unused NFP32xx IDs (Myron Stowe) [1694143]
- [maintainers] maintainers: Add Hyper-V IOMMU driver into Hyper-V CORE AND DRIVERS scope (Vitaly Kuznetsov) [1663292 1669989]
- [iommu] hyper-v: Add Hyper-V stub IOMMU driver (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyper-v: Set x2apic destination mode to physical when x2apic is available (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyper-v: Enable PIT shutdown quirk (Vitaly Kuznetsov) [1663292 1669989]
- [clocksource] clockevents/drivers/i8253: Add support for PIT shutdown quirk (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Enable PV qspinlock for Hyper-V (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Add GUEST_IDLE_MSR support (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hv: vmbus: Make TLFS #define names architecture neutral (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Add interrupt handler annotations (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Refactor hv_irq_unmask() to use cpumask_to_vpset() (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Replace hv_vp_set with hv_vpset (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Add __aligned(8) to struct retarget_msi_interrupt (Vitaly Kuznetsov) [1663292 1669989]
- [vfio] vfio-pci/nvlink2: Fix ancient gcc warnings (Sam Bobroff) [1524679]
- [vfio] vfio/pci: Cleanup license mess (Sam Bobroff) [1524679]
- [vfio] vfio/pci: set TRACE_INCLUDE_PATH to fix the build error (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Add NVIDIA GV100GL [Tesla V100 SXM2] subdriver (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Allow regions to add own capabilities (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Allow mapping extra regions (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Fault user page into the hypervisor's pagetable (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Check mmio_atsd array bounds when populating (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Add release_ownership hook (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Add compound IOMMU groups (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Convert NPU IOMMU helpers to iommu_table_group_ops (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Move single TVE handling to NPU PE (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv: Reference iommu_table while it is linked to a group (Sam Bobroff) [1524679]
- [powerpc] powerpc/iommu_api: Move IOMMU groups setup to a single place (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/pseries: Rework device adding to IOMMU groups (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries: Remove IOMMU API support for non-LPAR systems (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries/npu: Enable platform support (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries/iommu: Use memory@ nodes in max RAM address calculation (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Move OPAL calls away from context manipulation (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv: Move npu struct from pnv_phb to pci_controller (Sam Bobroff) [1524679]
- [powerpc] powerpc/vfio/iommu/kvm: Do not pin device memory (Sam Bobroff) [1524679]
- [vfio] powerpc/mm/iommu/vfio_spapr_tce: Change mm_iommu_get to reference a region (Sam Bobroff) [1524679]
- [powerpc] powerpc/ioda/npu: Call skiboot's hot reset hook when disabling NPU2 (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/ioda: Allocate indirect TCE levels of cached userspace addresses on demand (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/ioda1: Remove dead code for a single device PE (Sam Bobroff) [1524679]
- [rpmspec] redhat: add TC selftests to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: add net selftests to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: add pktgen samples to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: rename bpf_samples to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: remove bpf_samples dependency on glibc-static and build it by default (Ivan Vecera) [1691376]
- [tools] selftests: bpf: modify urandom_read and link it non-statically (Ivan Vecera) [1691376]

* Wed Apr 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.21.el8]
- [netdrv] ibmvnic: Fix netdev feature clobbering during a reset (Steve Best) [1699018]
- [netdrv] ibmvnic: Enable GRO (Steve Best) [1699018]
- [x86] x86/perf/amd: Remove need to check "running" bit in NMI handler (David Arcari) [1640238]
- [x86] x86/perf/amd: Resolve NMI latency issues for active PMCs (David Arcari) [1640238]
- [x86] x86/perf/amd: Resolve race condition when disabling PMC (David Arcari) [1640238]
- [netdrv] qed: Fix qed_mcp_halt|resume() (Manish Chopra) [1697310]

* Tue Apr 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.20.el8]
- [x86] x86/kexec: Fix a kexec_file_load() failure (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: include linux/vmalloc.h (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: handle empty command-line (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: return successfully even if kaslr-seed doesn't exist (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: Refactor setup_dtb() to consolidate error checking (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: add kaslr support (Bhupesh Sharma) [1666078]
- [char] random: Make crng state queryable (Bhupesh Sharma) [1666078]
- [include] include: pe.h: remove message[] from mz header definition (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: invoke the kernel without purgatory (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: allow for loading Image-format kernel (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: load initrd and device-tree (Bhupesh Sharma) [1666078]
- [arm64] arm64: enable KEXEC_FILE config (Bhupesh Sharma) [1666078]
- [arm64] arm64: cpufeature: add MMFR0 helper functions (Bhupesh Sharma) [1666078]
- [arm64] arm64: add image head flag definitions (Bhupesh Sharma) [1666078]
- [kernel] kexec_file: kexec_walk_memblock() only walks a dedicated region at kdump (Bhupesh Sharma) [1666078]
- [kernel] powerpc, kexec_file: factor out memblock-based arch_kexec_walk_mem() (Bhupesh Sharma) [1666078]
- [kernel] s390, kexec_file: drop arch_kexec_mem_walk() (Bhupesh Sharma) [1666078]
- [kernel] kexec_file: make kexec_image_post_load_cleanup_default() global (Bhupesh Sharma) [1666078]
- [include] asm-generic: add kexec_file_load system call to unistd.h (Bhupesh Sharma) [1666078]
- [include] asm-generic: unistd.h: Wire up sys_rseq (Bhupesh Sharma) [1666078]
- [fs] xfs: don't overflow xattr listent buffer (Bill O'Donnell) [1683531]
- [drm] drm/i915/gvt: Add in context mmio 0x20D8 to gen9 mmio list (Paul Lai) [1651589]
- [fs] copy_mount_string: Limit string length to PATH_MAX (Miklos Szeredi) [1655272]
- [include] redhat: Reuse other arch's cpuhp_state to protect kABI (Robert Richter) [1658476]
- [drivers] drivers/perf: Add Cavium ThunderX2 SoC UNCORE PMU driver (Robert Richter) [1658476]
- [documentation] Documentation: perf: Add documentation for ThunderX2 PMU uncore driver (Robert Richter) [1658476]

* Mon Apr 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.19.el8]
- [arm64] arm64: apply workaround on A64FX v1r0 (Mark Langsdorf) [1692306]
- [fs] kernfs: fix xattr name handling in LSM helpers (Ondrej Mosnacek) [1558179]
- [include] LSM: lsm_hooks.h - fix missing colon in docstring (Ondrej Mosnacek) [1558179]
- [security] selinux: Make selinux_kernfs_init_security static (Ondrej Mosnacek) [1558179]
- [fs] kernfs: initialize security of newly created nodes (Ondrej Mosnacek) [1558179]
- [security] selinux: implement the kernfs_init_security hook (Ondrej Mosnacek) [1558179]
- [include] LSM: add new hook for kernfs node initialization (Ondrej Mosnacek) [1558179]
- [fs] kernfs: use simple_xattrs for security attributes (Ondrej Mosnacek) [1558179]
- [security] selinux: try security xattr after genfs for kernfs filesystems (Ondrej Mosnacek) [1558179]
- [fs] kernfs: do not alloc iattrs in kernfs_xattr_get (Ondrej Mosnacek) [1558179]
- [fs] kernfs: clean up struct kernfs_iattrs (Ondrej Mosnacek) [1558179]
- [fs] kernfs: allow creating kernfs objects with arbitrary uid/gid (Ondrej Mosnacek) [1558179]
- [tools] tools/power turbostat: Add Icelake support (Steve Best) [1698546]
- [tools] tools/power turbostat: consolidate duplicate model numbers (Steve Best) [1698546]
- [mm] s390/mm: silence compiler warning when compiling without CONFIG_PGSTE (Thomas Huth) [1698848]
- [scripts] unifdef: use memcpy instead of strncpy (Thomas Huth) [1698848]
- [s390] s390: align struct lowcore to double page size (Thomas Huth) [1698848]
- [powerpc] KVM: PPC: Book3S HV: Perserve PSSCR FAKE_SUSPEND bit on guest exit (Suraj Jitindar Singh) [1689768]

* Thu Apr 18 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.18.el8]
- [virtio] virtio: Honour 'may_reduce_num' in vring_create_virtqueue (Cornelia Huck) [1697505]
- [s390] setup: set control program code via diag 318 (Thomas Huth) [1592336]
- [s390] kvm: s390: set host program identifier (Thomas Huth) [1592336]
- [edac] EDAC, skx: Fix randconfig builds in a better way (Aristeu Rozanski) [1501612 1649988 1571534]
- [edac] EDAC, skx: Fix randconfig builds (Aristeu Rozanski) [1501612 1649988 1571534]
- [edac] EDAC, skx_edac: Add address translation for non-volatile DIMMs (Aristeu Rozanski) [1501612 1649988 1571534]
- [acpi] ACPI/ADXL: Add address translation interface using an ACPI DSM (Aristeu Rozanski) [1501612 1649988 1571534]
- [x86] x86/mce: Add macros for the corrected error count bit field (Aristeu Rozanski) [1501612 1649988 1571534]
- [x86] x86/mce: Use BIT_ULL(x) for bit mask definitions (Aristeu Rozanski) [1501612 1649988 1571534]
- [crypto] crypto: ecc - regularize scalar for scalar multiplication (Neil Horman) [1687888]
- [crypto] crypto: ecc - check for invalid values in the key verification test (Neil Horman) [1687888]
- [crypto] crypto: dh - make crypto_dh_encode_key() make robust (Neil Horman) [1687888]
- [crypto] crypto: dh - fix calculating encoded key size (Neil Horman) [1687888]
- [crypto] crypto: ecdh - fix typo of P-192 b value (Neil Horman) [1687888]
- [crypto] crypto: ecdh - add public key verification test (Neil Horman) [1687888]
- [crypto] crypto: dh - fix memory leak (Neil Horman) [1687888]
- [crypto] crypto: dh - add public key verification test (Neil Horman) [1687888]
- [scsi] scsi: hisi_sas: Add softreset in hisi_sas_I_T_nexus_reset() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Change SERDES_CFG init value to increase reliability of HiLink (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Send HARD RESET to clear the previous affiliation of STP target port (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Set PHY linkrate when disconnected (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: print PHY RX errors count for later revision of v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix a timeout race of driver internal and SMP IO (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Change return variable type in phy_up_v3_hw() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: fix calls to dma_set_mask_and_coherent() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Do some more tidy-up (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Use pci_irq_get_affinity() for v3 hw as experimental (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Issue internal abort on all relevant queues (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: change queue depth from 512 to 4096 (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add manual trigger for debugfs dump (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for DIX feature for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add missing seq_printf() call in hisi_sas_show_row_32() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix to only call scsi_get_prot_op() for non-NULL scsi_cmnd (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Some misc tidy-up (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Correct memory allocation size for DQ debugfs (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix losing directly attached disk when hot-plug (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Reject setting programmed minimum linkrate > 1.5G (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Remove unused parameter of function hisi_sas_alloc() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: remove the check of sas_dev status in hisi_sas_I_T_nexus_reset() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: shutdown axi bus to avoid exception CQ returned (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: send primitive NOTIFY to SSP situation only (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs ITCT file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix type casting and missing static qualifier in debugfs code (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: No need to check return value of debugfs_create functions (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Set protection parameters prior to adding SCSI host (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs IOST file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs DQ file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs CQ file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs for port registers (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Debugfs global register create file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Take debugfs snapshot for all regs (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Alloc debugfs snapshot buffer memory for all registers (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Create root and device debugfs directories (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for DIF feature for v2 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Make sg_tablesize consistent value (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Relocate some code to reduce complexity (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix warnings detected by sparse (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: change the time of SAS SSP connection (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Relocate some codes to avoid an unused check (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for interrupt coalescing for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for interrupt converge for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Create separate host attributes per HBA (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: use dma_set_mask_and_coherent (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Remove set but not used variable 'dq_list' (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix NULL pointer dereference (Xiaojun Tan) [1662038]
- [nvme] nvme-pci: add missing unlock for reset error (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix rapid add remove sequence (Gopal Tiwari) [1665354]
- [nvme] nvme: remove the .stop_ctrl callout (Gopal Tiwari) [1665354]
- [nvme] nvme: add support for the Write Zeroes command (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: fix null dereference under heavy load (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: fix timeout handler (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix timeout handler (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: fix uninitialized variable access (Gopal Tiwari) [1665354]
- [nvme] nvme: don't initlialize ctrl->cntlid twice (Gopal Tiwari) [1665354]
- [nvme] nvme: introduce NVME_QUIRK_IGNORE_DEV_SUBNQN (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: remove dead code (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: don't ask if controller is fabrics (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: unset write/poll queues for discovery controllers (Gopal Tiwari) [1665354]
- [nvme] nvme: pad fake subsys NQN vid and ssvid with zeros (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix out of bounds access in nvme_cqe_pending (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: use the same attributes when freeing host_mem_desc_bufs. (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix the wrong setting of nr_maps (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: rerun irq setup on IO queue init errors (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: trace SQ status on completions (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user to pass in nr_poll_queues (Gopal Tiwari) [1665354]
- [nvme] nvme-core: optionally poll sync commands (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix spelling mistake "attepmpt" -> "attempt" (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix endianess annotations (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: fix endianess annotations (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: refactor nvme_poll_irqdisable to make sparse happy (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: only set nr_maps to 2 if poll queues are supported (Gopal Tiwari) [1665354]
- [nvme] nvmet: use a macro for default error location (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix comparison of a u16 with -1 (Gopal Tiwari) [1665354]
- [nvme] nvme: fix kernel paging oops (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: support separate queue maps for read and write (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: support separate queue maps for read and write (Gopal Tiwari) [1665354]
- [include] block: make request_to_qc_t public (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user to set nr_write_queues for separate queue maps (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: add missing nvmf_ctrl_options documentation (Gopal Tiwari) [1665354]
- [nvme] blk-mq-rdma: pass in queue map to blk_mq_rdma_map_queues (Gopal Tiwari) [1665354]
- [nvme] nvmet: update smart log with num err log entries (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for file backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log page cmd handler (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for bdev backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for admin-cmd (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for fabrics-cmd (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for rdma backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support in the core (Gopal Tiwari) [1665354]
- [nvme] nvmet: add interface to update error-log page (Gopal Tiwari) [1665354]
- [include] nvme: add error log page slot definition (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error-log definitions (Gopal Tiwari) [1665354]
- [nvme] nvme: remove nvme_common command cdw10 array (Gopal Tiwari) [1665354]
- [nvme] nvme: provide fallback for discard alloc failure (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove unused variable (Gopal Tiwari) [1665354]
- [nvme] nvme: add __exit annotation (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow configfs tcp trtype configuration (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: add NVMe over TCP host driver (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: add NVMe over TCP target driver (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user passing data digest (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user passing header digest (Gopal Tiwari) [1665354]
- [nvme] nvmet: Add install_queue callout (Gopal Tiwari) [1665354]
- [nvme] nvmet: use unlikely for req status check (Gopal Tiwari) [1665354]
- [include] nvme-tcp: Add protocol header (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: Add unlikely for response allocated check (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix the structure member indentation (Gopal Tiwari) [1665354]
- [nvme] nvme: implement Enhanced Command Retry (Gopal Tiwari) [1665354]
- [nvme] nvme: remove unused function nvme_ctrl_ready (Gopal Tiwari) [1665354]
- [nvme] nvmet: support fabrics sq flow control (Gopal Tiwari) [1665354]
- [nvme] nvmet: enable Discovery Controller AENs (Gopal Tiwari) [1665354]
- [nvme] nvmet: expose support for fabrics SQ flow control disable in treq (Gopal Tiwari) [1665354]
- [nvme] nvme: disable fabrics SQ flow control when asked by the user (Gopal Tiwari) [1665354]
- [nvme] nvmet-fc: remove the IN_ISR deferred scheduling options (Gopal Tiwari) [1665354]
- [nvme] nvme: Remove unused forward declaration (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow host connect even if no allowed subsystems are exported (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't override treq upon modification. (Gopal Tiwari) [1665354]
- [nvme] nvmet: mark nvmet_genctr static (Gopal Tiwari) [1665354]
- [nvme] nvmet: add defines for discovery change async events (Gopal Tiwari) [1665354]
- [nvme] nvmet: support for traffic based keep-alive (Gopal Tiwari) [1665354]
- [nvme] nvmet: make kato and AEN processing for use by other controllers (Gopal Tiwari) [1665354]
- [nvme] nvmet: change aen mask functions to use bit numbers (Gopal Tiwari) [1665354]
- [nvme] nvmet: provide aen bit functions for multiple controller types (Gopal Tiwari) [1665354]
- [nvme] nvmet: add support to Discovery controllers for commands (Gopal Tiwari) [1665354]
- [nvme] nvmet: use IOCB_NOWAIT for file-ns buffered I/O (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow Keep Alive for Discovery controller (Gopal Tiwari) [1665354]
- [nvme] nvme: support traffic based keep-alive (Gopal Tiwari) [1665354]
- [nvme] nvme: cache controller attributes (Gopal Tiwari) [1665354]
- [nvme] nvme: introduce ctrl attributes enumeration (Gopal Tiwari) [1665354]
- [nvme] nvme: consolidate memset calls in the nvme_setup_cmd path (Gopal Tiwari) [1665354]
- [nvme] nvme: warn when finding multi-port subsystems without multipathing enabled (Gopal Tiwari) [1665354]
- [nvme] Revert "nvmet-rdma: use a private workqueue for delete" (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: move controller options matching to fabrics (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: always have a valid trsvcid (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: remove duplicate check (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix hot removal during error handling (Gopal Tiwari) [1665354]
- [nvme] nvmet-fcloop: suppress a compiler warning (Gopal Tiwari) [1665354]
- [nvme] nvme-core: make implicit seed truncation explicit (Gopal Tiwari) [1665354]
- [nvme] nvmet-fc: fix kernel-doc headers (Gopal Tiwari) [1665354]
- [nvme] nvmet: avoid integer overflow in the discard code (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: declare local symbols static (Gopal Tiwari) [1665354]
- [nvme] nvmet: use strlcpy() instead of strcpy() (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix nvme_suspend_queue() kernel-doc header (Gopal Tiwari) [1665354]
- [nvme] nvme-core: declare local symbols static (Gopal Tiwari) [1665354]
- [nvme] nvme-core: rework a NQN copying operation (Gopal Tiwari) [1665354]
- [nvme] nvmet: use strcmp() instead of strncmp() for subsystem lookup (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: check for timeout in nvme_rdma_wait_for_cm() (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove unreachable code (Gopal Tiwari) [1665354]
- [nvme] nvme: update node paths after adding new path (Gopal Tiwari) [1665354]
- [nvme] nvme: remove ns sibling before clearing path (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: use a private workqueue for delete (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't split large I/Os unconditionally (Gopal Tiwari) [1665354]
- [nvme] nvme-core: add async event trace helper (Gopal Tiwari) [1665354]
- [nvme] nvmet_fc: support target port removal with nvmet layer (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove redundant module prefix (Gopal Tiwari) [1665354]
- [nvme] nvme: fix typo in nvme_identify_ns_descs (Gopal Tiwari) [1665354]
- [nvme] nvme: register ns_id attributes as default sysfs groups (Gopal Tiwari) [1665354]
- [block] block: genhd: add 'groups' argument to device_add_disk (Gopal Tiwari) [1665354]
- [nvme] nvme: count all ANA groups for ANA Log page (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: fix possible bogus dereference under heavy load (Gopal Tiwari) [1665354]
- [nvme] nvmet: free workqueue object if module init fails (Gopal Tiwari) [1665354]
- [nvme] nvme-fcloop: Fix dropped LS's to removed target port (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: add a memory barrier to nvme_dbbuf_update_and_check_event (Gopal Tiwari) [1665354]
- [nvme] nvmet: add ns write protect support (Gopal Tiwari) [1665354]
- [nvme] nvme: set gendisk read only based on nsattr (Gopal Tiwari) [1665354]
- [include] nvme.h: add support for ns write protect definitions (Gopal Tiwari) [1665354]
- [nvme] nvmet: use Retain Async Event bit to clear AEN (Gopal Tiwari) [1665354]
- [nvme] nvmet: support configuring ANA groups (Gopal Tiwari) [1665354]
- [nvme] nvmet: add minimal ANA support (Gopal Tiwari) [1665354]
- [nvme] nvmet: track and limit the number of namespaces per subsystem (Gopal Tiwari) [1665354]
- [nvme] nvmet: keep a port pointer in nvmet_ctrl (Gopal Tiwari) [1665354]
- [nvme] nvmet: check fileio lba range access boundaries (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't use uuid_le type (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: centralize admin/io queue teardown sequence (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix file discard return status (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: centralize controller setup sequence (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: unquiesce queues when deleting the controller (Gopal Tiwari) [1665354]
- [nvme] nvme: add disk name to trace events (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: mark expected switch fall-through (Gopal Tiwari) [1665354]
- [nvme] nvme: add controller name to trace events (Gopal Tiwari) [1665354]
- [nvme] nvme: use hw qid in trace events (Gopal Tiwari) [1665354]
- [nvme] nvmet: add buffered I/O support for file backed ns (Gopal Tiwari) [1665354]
- [nvme] nvme: move init of keep_alive work item to controller initialization (Gopal Tiwari) [1665354]
- [nvme] nvmet: add commands supported and effects log page (Gopal Tiwari) [1665354]
- [nvme] lightnvm: limit get chunk meta request size (Gopal Tiwari) [1665354]
- [nvme] lightnvm: Remove redundant rq->__data_len initialization (Gopal Tiwari) [1665354]
- [block] nbd: restrict use to AF_UNIX sockets (Mike Christie) [1673307]
- [block] nbd: don't allow invalid blocksize settings (Mike Christie) [1673307]
- [documentation] doc, block, bfq: add information on bfq execution time (Ming Lei) [1686682]
- [block] block, bfq: save & resume weight on a queue merge/split (Ming Lei) [1686682]
- [block] block, bfq: print SHARED instead of pid for shared queues in logs (Ming Lei) [1686682]
- [block] block, bfq: always protect newly-created queues from existing active queues (Ming Lei) [1686682]
- [block] block, bfq: do not tag totally seeky queues as soft rt (Ming Lei) [1686682]
- [block] block, bfq: do not merge queues on flash storage with queueing (Ming Lei) [1686682]
- [block] block, bfq: tune service injection basing on request service times (Ming Lei) [1686682]
- [block] block, bfq: do not idle for lowest-weight queues (Ming Lei) [1686682]
- [block] block, bfq: increase idling for weight-raised queues (Ming Lei) [1686682]
- [block] block/bfq: fix ifdef for CONFIG_BFQ_GROUP_IOSCHED=y (Ming Lei) [1686682]
- [block] block, bfq: fix in-service-queue check for queue merging (Ming Lei) [1686682]
- [block] block, bfq: do not overcharge writes in asymmetric scenarios (Ming Lei) [1686682]
- [block] block, bfq: port commit "cfq-iosched: improve hw_tag detection" (Ming Lei) [1686682]
- [block] block, bfq: reduce threshold for detecting command queueing (Ming Lei) [1686682]
- [block] block, bfq: fix queue removal from weights tree (Ming Lei) [1686682]
- [block] block, bfq: fix sequential rq detection in rate estimation (Ming Lei) [1686682]
- [block] block, bfq: unconditionally plug I/O in asymmetric scenarios (Ming Lei) [1686682]
- [block] block, bfq: do not plug I/O of in-service queue when harmful (Ming Lei) [1686682]
- [block] block, bfq: split function bfq_better_to_idle (Ming Lei) [1686682]
- [block] block, bfq: consider also ioprio classes in symmetry detection (Ming Lei) [1686682]
- [block] block, bfq: remove case of redirected bic from insert_request (Ming Lei) [1686682]
- [block] block, bfq: make sure queue budgets are not below service received (Ming Lei) [1686682]
- [block] block, bfq: avoid selecting a queue w/o budget (Ming Lei) [1686682]
- [block] block, bfq: do not consider interactive queues in srt filtering (Ming Lei) [1686682]
- [net] net: switchdev: Add extack to switchdev_handle_port_obj_add() callback (Ivan Vecera) [1690125]
- [net] switchdev: Add extack to struct switchdev_notifier_info (Ivan Vecera) [1690125]
- [net] vxlan: Add a function to init switchdev_notifier_vxlan_fdb_info (Ivan Vecera) [1690125]
- [net] switchdev: Add extack argument to switchdev_port_obj_add() (Ivan Vecera) [1690125]
- [net] bridge: Propagate extack to switchdev (Ivan Vecera) [1690125]
- [net] ndo_bridge_setlink: Add extack (Ivan Vecera) [1690125]
- [net] rocker, dsa, ethsw: Don't filter VLAN events on bridge itself (Ivan Vecera) [1690125]
- [net] switchdev: Replace port obj add/del SDO with a notification (Ivan Vecera) [1690125]
- [net] ocelot: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] mlxsw: spectrum_switchdev: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add helpers to aid traversal through lower devices (Ivan Vecera) [1690125]
- [net] staging: fsl-dpaa2: ethsw: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] staging: fsl-dpaa2: ethsw: Introduce ethsw_port_dev_check() (Ivan Vecera) [1690125]
- [net] dsa: slave: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] rocker: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add SWITCHDEV_PORT_OBJ_ADD, SWITCHDEV_PORT_OBJ_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add a blocking notifier chain (Ivan Vecera) [1690125]
- [net] switchdev: SWITCHDEV_OBJ_PORT_{VLAN, MDB}(): Sanitize (Ivan Vecera) [1690125]
- [net] selftests: forwarding: Fix test for different devices (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add learning test (Ivan Vecera) [1693316]
- [net] bridge: Allow querying bridge port flags (Ivan Vecera) [1693316]
- [netdrv] vxlan: Allow changing ageing time (Ivan Vecera) [1693316]
- [netdrv] vxlan: Add hardware FDB learning (Ivan Vecera) [1693316]
- [netdrv] vxlan: Don't override user-added entries with ext-learned ones (Ivan Vecera) [1693316]
- [netdrv] vxlan: Mark user-added FDB entries (Ivan Vecera) [1693316]
- [netdrv] vxlan: vxlan_fdb_notify(): Make switchdev notification configurable (Ivan Vecera) [1693316]
- [netdrv] vxlan: __vxlan_fdb_delete(): Drop unused argument vid (Ivan Vecera) [1693316]
- [netdrv] vxlan: support NTF_USE refresh of fdb entries (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d_port_8472: New test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add an ECN decap test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add an ECN encap test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add a TOS test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add a TTL test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Reconfigure & rerun tests (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add unicast test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add flood test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add ping test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: Add a skeleton of vxlan_bridge_1d (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Add link_stats_rx_errors_get() (Ivan Vecera) [1693316]
- [net] selftests: forwarding: ping{6, }_do(): Allow passing ping arguments (Ivan Vecera) [1693316]
- [net] selftests: forwarding: ping{6, }_test(): Add description argument (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Add in_ns() (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Support NUM_NETIFS of 0 (Ivan Vecera) [1693316]
- [net] skb_scrub_packet(): Scrub offload_fwd_mark (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: extract ping and ping6 so they can be reused (Ivan Vecera) [1693316]
- [net] selftests: forwarding: README: Require diagrams (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Extract interface-init functions (Ivan Vecera) [1693316]
- [net] selftests: forwarding: tc_rule_stats_get: Parameterize direction (Ivan Vecera) [1693316]
- [net] selftests: forwarding: multipath_eval(): Improve style (Ivan Vecera) [1693316]
- [net] selftests: forwarding: Move multipath_eval() to lib.sh (Ivan Vecera) [1693316]
- [net] selftests: Add test_vxlan_fdb_changelink.sh (Ivan Vecera) [1690309]
- [netdrv] vxlan: changelink: Fix handling of default remotes (Ivan Vecera) [1690309]
- [netdrv] vxlan: Fix error path in __vxlan_dev_create() (Ivan Vecera) [1690309]
- [netdrv] vxlan: Unmark offloaded bit on replaced FDB entries (Ivan Vecera) [1690309]
- [net] bridge: switchdev: Allow clearing FDB entry offload indication (Ivan Vecera) [1690309]
- [netdrv] vxlan: Notify for each remote of a removed FDB entry (Ivan Vecera) [1690309]
- [netdrv] vxlan: Support marking RDSTs as offloaded (Ivan Vecera) [1690309]
- [netdrv] vxlan: Add vxlan_fdb_find_uc() for FDB querying (Ivan Vecera) [1690309]
- [netdrv] vxlan: Add switchdev notifications (Ivan Vecera) [1690309]
- [netdrv] net: Add netif_is_vxlan() (Ivan Vecera) [1690309]
- [net] inet: Refactor INET_ECN_decapsulate() (Ivan Vecera) [1690309]
- [netdrv] vxlan: Export address checking functions (Ivan Vecera) [1690309]
- [net] vxlan: Remove duplicated include from vxlan.h (Ivan Vecera) [1690309]
- [netdrv] geneve: correctly handle ipv6.disable module parameter (Jiri Benc) [1692390]
- [net] ipv6: sit: reset ip header pointer in ipip6_rcv (Lorenzo Bianconi) [1691626]
- [net] vxlan: Don't call gro_cells_destroy() before device is unregistered (Andrea Claudi) [1692499]
- [net] xsk: do not remove umem from netdevice on fall-back to copy-mode (Petr Oros) [1690568]
- [net] xsk: Check if a queue exists during umem setup (Petr Oros) [1690568]
- [net] xsk: simplify xdp_clear_umem_at_qid implementation (Petr Oros) [1690568]
- [net] ethtool: don't allow disabling queues with umem installed (Petr Oros) [1690568]
- [net] ethtool: rename local variable max -> curr (Petr Oros) [1690568]
- [net] xsk: fix bug when trying to use both copy and zero-copy on one queue id (Petr Oros) [1690568]
- [net] add umem reference in netdev{_rx}_queue (Petr Oros) [1690568]
- [net] xsk: remove unnecessary assignment (Petr Oros) [1690568]
- [net] xsk: fix return value of xdp_umem_assign_dev() (Petr Oros) [1690568]
- [net] xsk: don't allow umem replace at stack level (Petr Oros) [1690568]
- [net] xsk: refactor xdp_umem_assign_dev() (Petr Oros) [1690568]
- [net] update real_num_rx_queues even when !CONFIG_SYSFS (Petr Oros) [1690568]
- [net] core: add __netdev_sent_queue as variant of __netdev_tx_sent_queue (Petr Oros) [1690127]
- [net] net: do not abort bulk send on BQL status (Petr Oros) [1690129]
- [net] net: bql: add __netdev_tx_sent_queue() (Petr Oros) [1690129]
- [net] net: ip6_gre: fix possible NULL pointer dereference in ip6erspan_set_version (Lorenzo Bianconi) [1666315]
- [net] net: ip6_gre: initialize erspan_ver just for erspan tunnels (Lorenzo Bianconi) [1666315]
- [net] net: ip6_gre: always reports o_key to userspace (Lorenzo Bianconi) [1666315]
- [net] net: ip_gre: always reports o_key to userspace (Lorenzo Bianconi) [1666315]
- [net] tcp: handle inet_csk_reqsk_queue_add() failures (Guillaume Nault) [1690157]
- [net] ip_gre: use erspan key field for tunnel lookup (Lorenzo Bianconi) [1664570]
- [net] ip6_gre: simplify gre header parsing in ip6gre_err (Lorenzo Bianconi) [1664570]
- [net] ipv4: use a dedicated counter for icmp_v4 redirect packets (Lorenzo Bianconi) [1664209]
- [net] virtchnl: Fix off by one error (Ivan Vecera) [1690114]
- [net] virtchnl: white space and reorder (Ivan Vecera) [1690114]
- [net] i40e: Update status codes (Ivan Vecera) [1690114]
- [net] ethtool: Add WAKE_FILTER and RX_CLS_FLOW_WAKE (Ivan Vecera) [1690091]
- [net] geneve: allow to clear ttl inherit (Hangbin Liu) [1671251]
- [net] geneve: add ttl inherit support (Hangbin Liu) [1671251]
- [net] tipc: fix a double kfree_skb() (Jon Maloy) [1684290]
- [net] vxlan: Fix GRO cells race condition between receive and link delete (Andrea Claudi) [1687046]
- [net] sock: consistent handling of extreme SO_SNDBUF/SO_RCVBUF values (Guillaume Nault) [1686564]
- [net] tun: implement carrier change (Guillaume Nault) [1686566]
- [net] ip6_tunnel: respect ttl inherit for ip6tnl (Hangbin Liu) [1664944]
- [net] ip6_gre: update version related info when changing link (Hangbin Liu) [1664900]
- [net] ipv4/route: fail early when inet dev is missing (Paolo Abeni) [1685424]
- [net] bonding/802.3ad: fix link_failure_count tracking (Matteo Croce) [1657905]
- [net] bonding: avoid possible dead-lock (Matteo Croce) [1657905]
- [net] bonding: fix length of actor system (Matteo Croce) [1657905]
- [net] bonding: fix warning message (Matteo Croce) [1657905]
- [net] bonding: pass link-local packets to bonding master also. (Matteo Croce) [1657905]

* Wed Apr 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.17.el8]
- [infiniband] IB/usnic: fix spelling mistake "unvalid" -> "invalid" (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Get rid of ucontext->tgid (Jonathan Toppins) [1685307]
- [infiniband] RDMA/usnic: Do not use ucontext->tgid (Jonathan Toppins) [1685307]
- [infiniband] infiniband: remove redundant condition check before debugfs_remove (Jonathan Toppins) [1685307]
- [infiniband] RDMA/rdmavt: Fix rvt_create_ah function signature (Jonathan Toppins) [1685307]
- [infiniband] RDMA/drivers: Use core provided API for registering device attributes (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Remove unnecessary enum values (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move ruc_loopback to rdmavt (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move send completion logic to rdmavt (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move copy SGE logic into rdmavt (Jonathan Toppins) [1685307]
- [infiniband] RDMA/rxe: Remove unused addr_same() (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: avoid srq memory leak (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: replace kvfree with vfree (Jonathan Toppins) [1685307]
- [infiniband] RDMA/drivers: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/drivers: Use dev_err/dbg/etc instead of pr_* + ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] IB/rxe: fixes for rdma read retry (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: avoid back-to-back retries (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Refactor lookup memory function (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Avoid NULL check when search is successful (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Change pool state enums to capital letters (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Replace spinlock with rwlock (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Simplify rxe_find_route() to avoid GID query for netdev (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: remove redudant qpn check (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: vary the source udp port for receive scaling (Jonathan Toppins) [1685307]
- [infiniband] iser: set sector for ambiguous mr status errors (Jonathan Toppins) [1685307]
- [net] svcrdma: Remove try_module_get from backchannel (Jonathan Toppins) [1685307]
- [net] svcrdma: Remove ->release_rqst call in bc reply handler (Jonathan Toppins) [1685307]
- [net] xprtrdma: Clean up xprt_rdma_disconnect_inject (Jonathan Toppins) [1685307]
- [net] xprtrdma: Add documenting comments (Jonathan Toppins) [1685307]
- [net] xprtrdma: Report when there were zero posted Receives (Jonathan Toppins) [1685307]
- [net] xprtrdma: Move rb_flags initialization (Jonathan Toppins) [1685307]
- [net] xprtrdma: Don't disable BH's in backchannel server (Jonathan Toppins) [1685307]
- [net] xprtrdma: Remove memory address of "ep" from an error message (Jonathan Toppins) [1685307]
- [net] xprtrdma: Rename rpcrdma_qp_async_error_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Simplify RPC wake-ups on connect (Jonathan Toppins) [1685307]
- [net] xprtrdma: Re-organize the switch() in rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Eliminate "connstate" variable from rpcrdma_conn_upcall() (Jonathan Toppins) [1685307]
- [net] xprtrdma: Conventional variable names in rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Rename rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] sunrpc: Report connect_time in seconds (Jonathan Toppins) [1685307]
- [net] sunrpc: Fix connect metrics (Jonathan Toppins) [1685307]
- [net] xprtrdma: Name MR trace events consistently (Jonathan Toppins) [1685307]
- [net] xprtrdma: Explicitly resetting MRs is no longer necessary (Jonathan Toppins) [1685307]
- [net] xprtrdma: Create more MRs at a time (Jonathan Toppins) [1685307]
- [net] xprtrdma: xprt_release_rqst_cong is called outside of transport_lock (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Log sysfs 'dev_id' accesses from userspace (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Use dev_port to expose network interface port numbers (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Ensure that MTU isn't less than minimum permitted (Jonathan Toppins) [1685307]
- [infiniband] IB/srp: Remove unnecessary unlikely() (Jonathan Toppins) [1685307]
- [infiniband] IB/core: Fix oops in netdev_next_upper_dev_rcu() (Jonathan Toppins) [1685307]
- [infiniband] IB/umem: Set correct address to the invalidation function (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Add GIDs while changing MAC addr only for registered ndev (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Fix comment for hw stats init for port == 0 (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Refactor ib_register_device() function (Jonathan Toppins) [1685307]
- [infiniband] IB/mlx4: Refer to the device kobject instead of ports_parent (Jonathan Toppins) [1685307]
- [include] RDMA/core: Allow existing drivers to set one sysfs group per device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umad: Use kernel API to allocate umad indexes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use kernel API to allocate uverbs indexes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Increase total number of RDMA ports across all devices (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rename ports_parent to ports_kobj (Jonathan Toppins) [1685307]
- [infiniband] RDMA/nldev: Allow IB device rename through RDMA netlink (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Implement IB device rename function (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Annotate timeout as unsigned long (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Align multiple functions to kernel coding style (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Remove unused timeout_ms parameter from cma_resolve_iw_route() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cm: Respect returned status of cm_init_av_by_path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Protect from reentry to resource return path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Release task struct which was hold by CM_ID object (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Consolidate task name updates in one place (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Un-inline set task implementation (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Check error status of rdma_find_ndev_for_src_ip_rcu (Jonathan Toppins) [1685307]
- [include] IB/mlx4: Avoid implicit enumerated type conversion (Jonathan Toppins) [1685307]
- [infiniband] RDMA/netlink: Simplify netlink listener existence check (Jonathan Toppins) [1685307]
- [infiniband] RDMA: Remove unused parameter from ib_modify_qp_is_ok() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Fix RCU annotation for radix slot deference (Jonathan Toppins) [1685307]
- [infiniband] RDMA: Fix building with CONFIG_MMU=n (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Introduce and use cma_ib_acquire_dev() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Introduce and use cma_acquire_dev_by_src_ip() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Allow accepting requests for multi port rdma device (Jonathan Toppins) [1685307]
- [infiniband] IB/rdmavt: Rename check_send_wqe as setup_wqe (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Acquire and release mmap_sem on page range (Jonathan Toppins) [1685307]
- [infiniband] IB/sa: simplify return code logic for ib_nl_send_msg() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ulp: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Use dev_err/dbg/etc instead of pr_* + ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA: Fully setup the device name in ib_register_device (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/umem: Fix potential addition overflow (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Minor optimizations (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Avoid synchronize_srcu in the ODP MR destruction path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Handle a half-complete start/end sequence (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Get rid of per_mm->notifier_count (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Use umem->owning_mm inside ODP (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Move all the ODP related stuff out of ucontext and into per_mm (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Get rid of struct ib_umem.odp_data (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Make ib_umem_odp into a sub structure of ib_umem (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Use ib_umem_odp in all function signatures connected to ODP (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Do not use current->tgid to track the mm_struct (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ucontext: Get rid of the old disassociate flow (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ucontext: Add a core API for mmaping driver IO memory (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Fix error unwind in ib_uverbs_add_one (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Properly return the error code of rdma_set_src_addr_rcu (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Remove is_closed from ib_uverbs_file (Jonathan Toppins) [1685307]
- [include] IB/rxe: Revise the ib_wr_opcode enum (Jonathan Toppins) [1685307]
- [include] RDMA: Remove duplicated include from ib_addr.h (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Consider net ns of gid attribute for RoCE (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Introduce rdma_read_gid_attr_ndev_rcu() to check GID attribute (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Simplify roce_resolve_route_from_path() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Protect against changing dst->dev during destination resolve (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Refer to network type instead of device type (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use common code flow for IPv4/6 for addr resolve (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rename rdma_copy_addr to rdma_copy_src_l2_addr (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Introduce and use rdma_set_src_addr() between IPv4 and IPv6 (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Let protocol specific function typecast sockaddr structure (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Avoid unnecessary sa_family overwrite (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core Introduce and use rdma_find_ndev_for_src_ip_rcu (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Schedule multi RC/UC packets instead of posting (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Move flow resources initialization (Jonathan Toppins) [1685307]
- [infiniband] IB/uverbs: Add IDRs array attribute type to ioctl() interface (Jonathan Toppins) [1685307]
- [include] RDMA/core: Document QP @event_handler function (Jonathan Toppins) [1685307]
- [include] RDMA/core: Document CM @event_handler function (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Assign device ifindex before publishing the device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Follow correct unregister order between sysfs and cgroup (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Restore lockdep check while downgrading lock (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Define client_data_lock as rwlock instead of spinlock (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use simpler spin lock irq API from blocking context (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Remove context entries from list while unregistering device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use simplified list_for_each (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: No need to protect kfree with spin lock and semaphore (Jonathan Toppins) [1685307]
- [infiniband] RDMA/{cma, core}: Avoid callback on rdma_addr_cancel() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rate limit MAD error messages (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Fail early if unsupported QP is provided (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use device.groups to initialize device attributes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use cdev_device_add() instead of cdev_add() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Depend on device_add() to add device attributes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Replace open-coded variant of get_device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Declare closing variable as boolean (Jonathan Toppins) [1685307]
- [infiniband] IB/core: Add an unbound WQ type to the new CQ API (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Add generic function to fill in flow action object (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Add UVERBS_ATTR_CONST_IN to the specs language (Jonathan Toppins) [1685307]
- [netdrv] ibmvnic: Fix completion structure initialization (Steve Best) [1697103]
- [rpmspec] redhat: limit headers_install_all to arches we care about (Denys Vlasenko) [1692404]
- [lib] ida: Add new API (Jonathan Toppins) [1697588]
- [edac] EDAC: Drop per-memory controller buses (Frank Ramsay) [1686477]
- [edac] EDAC: Don't add devices under /sys/bus/edac (Frank Ramsay) [1686477]
- [x86] x86/platform/UV: Use efi_runtime_lock to serialise BIOS calls (Frank Ramsay) [1677695]

* Tue Apr 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.16.el8]
- [pci] PCI: pciehp: Fix re-enabling the slot marked for safe removal (Myron Stowe) [1695922]
- [rpmspec] redhat: Enable gdb_index (Juri Lelli) [1696747]
- [fs] ovl: Do not lose security.capability xattr over metadata file copy-up (Vivek Goyal) [1694757]
- [fs] ovl: During copy up, first copy up data and then xattrs (Vivek Goyal) [1694757]

* Mon Apr 15 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.15.el8]
- [netdrv] mark the intel igc driver as tech preview (David Arcari) [1495358]
- [netdrv] igc: Remove unneeded hw_dbg prints (David Arcari) [1495358]
- [netdrv] igc: Fix the typo in igc_base.h header definition (David Arcari) [1495358]
- [netdrv] igc: Add support for the ntuple feature (David Arcari) [1495358]
- [netdrv] igc: Add support for statistics (David Arcari) [1495358]
- [netdrv] igc: Extend the ethtool supporting (David Arcari) [1495358]
- [netdrv] igc: Add multiple receive queues control supporting (David Arcari) [1495358]
- [netdrv] igc: Use struct_size() helper (David Arcari) [1495358]
- [netdrv] igc: Add ethtool support (David Arcari) [1495358]
- [netdrv] igc: Remove the 'igc_get_phy_id_base' method (David Arcari) [1495358]
- [netdrv] igc: Remove the 'igc_read_mac_addr_base' method (David Arcari) [1495358]
- [netdrv] igc: Remove unneeded code (David Arcari) [1495358]
- [netdrv] igc: Remove unused code (David Arcari) [1495358]
- [netdrv] igc: Fix code redundancy (David Arcari) [1495358]
- [netdrv] igc: Remove unreachable code from igc_phy.c file (David Arcari) [1495358]
- [netdrv] igc: Remove obsolete IGC_ERR define (David Arcari) [1495358]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (David Arcari) [1495358]
- [netdrv] igc: Clean up code (David Arcari) [1495358]
- [netdrv] igc: Tidy up some white space (David Arcari) [1495358]
- [netdrv] igc: fix error return handling from call to netif_set_real_num_tx_queues (David Arcari) [1495358]
- [netdrv] igc: Remove set but not used variable 'pci_using_dac' (David Arcari) [1495358]
- [netdrv] igc: Remove set but not used variables 'ctrl_ext, link_mode' (David Arcari) [1495358]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (David Arcari) [1495358]
- [netdrv] igc: Add watchdog (David Arcari) [1495358]
- [netdrv] igc: Add setup link functionality (David Arcari) [1495358]
- [netdrv] igc: Add code for PHY support (David Arcari) [1495358]
- [netdrv] igc: Add NVM support (David Arcari) [1495358]
- [netdrv] igc: Add HW initialization code (David Arcari) [1495358]
- [netdrv] igc: Add transmit and receive fastpath and interrupt handlers (David Arcari) [1495358]
- [netdrv] igc: Add support for Tx/Rx rings (David Arcari) [1495358]
- [netdrv] igc: Add interrupt support (David Arcari) [1495358]
- [netdrv] igc: Add netdev (David Arcari) [1495358]
- [netdrv] igc: Add support for PF (David Arcari) [1495358]
- [netdrv] igc: Add skeletal frame for Intel(R) 2.5G Ethernet Controller support (David Arcari) [1495358]
- [s390] virtio-ccw: wire up ->bus_name callback (Cornelia Huck) [1695630]
- [s390] s390/virtio: handle find on invalid queue gracefully (Cornelia Huck) [1695630]
- [s390] virtio/s390: fix race in ccw_io_helper() (Cornelia Huck) [1695630]
- [s390] virtio/s390: avoid race on vcdev->config (Cornelia Huck) [1695630]
- [kvm] KVM: s390: make bitmap declaration consistent (Thomas Huth) [1695090]
- [kvm] KVM: s390: drop obsolete else path (Thomas Huth) [1695090]
- [kvm] KVM: s390: clarify kvm related kernel message (Thomas Huth) [1695090]
- [kvm] s390: vsie: Use effective CRYCBD.31 to check CRYCBD validity (Thomas Huth) [1695090]
- [kvm] KVM: s390: fix kmsg component kvm-s390 (Thomas Huth) [1695090]
- [kvm] KVM: s390: unregister debug feature on failing arch init (Thomas Huth) [1695090]
- [kvm] KVM: s390/vsie: avoid sparse warning (Thomas Huth) [1695090]

* Thu Apr 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.14.el8]
- [powerpc] powerpc: use mm zones more sensibly (David Gibson) [1654978]
- [s390] s390/mem_detect: add missing include (Philipp Rudo) [1695615]
- [s390] s390: avoid vmlinux segments overlap (Philipp Rudo) [1695615]
- [s390] s390/decompressor: add missing FORCE to build targets (Philipp Rudo) [1695615]
- [s390] s390: move ipl block and cmd line handling to early boot phase (Philipp Rudo) [1695615]
- [s390] s390/sclp: introduce sclp_early_get_hsa_size (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: add info source debug print (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: replace tprot loop with binary search (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: use SCLP info for continuous memory detection (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: introduce z/VM specific diag260 call (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: introduce SCLP storage info (Philipp Rudo) [1695615]
- [s390] s390: introduce .boot.data section compile time validation (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: move tprot loop to early boot phase (Philipp Rudo) [1695615]
- [s390] s390/sclp: move sclp_early_read_info to sclp_early_core.c (Philipp Rudo) [1695615]
- [s390] s390: introduce .boot.data section (Philipp Rudo) [1695615]
- [s390] s390/decompressor: clean up and rename compressed/misc.c (Philipp Rudo) [1695615]
- [s390] s390: rescue initrd as early as possible (Philipp Rudo) [1695615]
- [s390] s390/sclp: simplify early hsa_size detection (Philipp Rudo) [1695615]
- [s390] s390/decompressor: get rid of .bss usage (Philipp Rudo) [1695615]
- [s390] s390/decompressor: rework uncompressed image info collection (Philipp Rudo) [1695615]
- [s390] s390: remove decompressor's head.S (Philipp Rudo) [1695615]
- [s390] s390: clean up stacks setup (Philipp Rudo) [1695615]
- [s390] s390: add initial 64-bit restart PSW (Philipp Rudo) [1695615]
- [s390] s390/hibernate: fix error handling when suspend cpu != resume cpu (Philipp Rudo) [1695615]
- [s390] s390/decompressor: support extra debug flags (Philipp Rudo) [1695615]
- [s390] s390/build: add *.o.chkbss files to targets list (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid packing *.o.chkbss files into startup.a (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid constant startup.a rebuilds (Philipp Rudo) [1695615]
- [s390] s390/boot: block uncompressed vmlinux booting attempts (Philipp Rudo) [1695615]
- [s390] s390/decompressor: correct EXCLUDE_FILE construct (Philipp Rudo) [1695615]
- [s390] s390: move _text to an actual .text start (Philipp Rudo) [1695615]
- [s390] s390: correct _stext offset (Philipp Rudo) [1695615]
- [s390] s390: get rid of the first mb of uncompressed image (Philipp Rudo) [1695615]
- [s390] s390: remove unused _ehead symbol (Philipp Rudo) [1695615]
- [s390] s390: put expoline execute-trampolines into .text section (Philipp Rudo) [1695615]
- [s390] s390/decompressor: discard ___kcrctab section (Philipp Rudo) [1695615]
- [s390] s390/setup: do not reserve the decompressor code (Philipp Rudo) [1695615]
- [s390] s390/decompressor: support uncompressed kernel (Philipp Rudo) [1695615]
- [init] init/Kconfig: add an option for uncompressed kernel (Philipp Rudo) [1695615]
- [s390] s390/decompressor: allow to pack uncompressed vmlinux.bin into piggy.o (Philipp Rudo) [1695615]
- [s390] s390/decompressor: allow preprocessor in piggy.o linker script (Philipp Rudo) [1695615]
- [s390] s390/decompressor: extend .bss check for early code (Philipp Rudo) [1695615]
- [s390] s390: add custom target and make path extension optional for .bss check (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid repeating objects list in Makefile (Philipp Rudo) [1695615]
- [s390] s390/decompressor: reuse lib/mem.S for mem functions (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid reusing uncompressed image objects (Philipp Rudo) [1695615]
- [s390] s390/als: avoid .init.* sections usage (Philipp Rudo) [1695615]
- [s390] s390/decompressor: rename entry point to startup_decompressor (Philipp Rudo) [1695615]
- [s390] s390/boot: make head.S and als.c be part of the decompressor only (Philipp Rudo) [1695615]
- [s390] s390/decompressor: trim the kernel image up to 1M (Philipp Rudo) [1695615]
- [s390] s390: remove uncompressed kernel image build (Philipp Rudo) [1695615]
- [s390] s390/decompressor: correct build flags (Philipp Rudo) [1695615]
- [s390] s390/build: remove obsolete -mkernel-backchain flag (Philipp Rudo) [1695615]
- [tools] tools/power turbostat: return the exit status of a command (David Arcari) [1642739]
- [misc] misc: hpilo: Do not claim unsupported hardware (Joseph Szczypek) [1665635]
- [misc] misc: hpilo: Exclude unsupported device via blacklist (Joseph Szczypek) [1665635]

* Wed Apr 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.13.el8]
- [fs] xfs: set buffer ops when repair probes for btree type (Bill O'Donnell) [1689281]
- [fs] xfs: end sync buffer I/O properly on shutdown error (Bill O'Donnell) [1689281]
- [fs] xfs: xfs_fsops: drop useless LIST_HEAD (Bill O'Donnell) [1689281]
- [fs] xfs: xfs_buf: drop useless LIST_HEAD (Bill O'Donnell) [1689281]
- [fs] iomap: fix a use after free in iomap_dio_rw (Bill O'Donnell) [1689281]
- [fs] xfs: reallocate realtime summary cache on growfs (Bill O'Donnell) [1689281]
- [fs] xfs: stringify scrub types in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: stringify btree cursor types in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: move XFS_INODE_FORMAT_STR mappings to libxfs (Bill O'Donnell) [1689281]
- [fs] xfs: move XFS_AG_BTREE_CMP_FORMAT_STR mappings to libxfs (Bill O'Donnell) [1689281]
- [fs] xfs: fix symbolic enum printing in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: fix function pointer type in ftrace format (Bill O'Donnell) [1689281]
- [fs] xfs: Fix x32 ioctls when cmd numbers differ from ia32. (Bill O'Donnell) [1689281]
- [fs] xfs: Fix bulkstat compat ioctls on x32 userspace. (Bill O'Donnell) [1689281]
- [fs] xfs: Align compat attrlist_by_handle with native implementation. (Bill O'Donnell) [1689281]
- [fs] xfs: require both realtime inodes to mount (Bill O'Donnell) [1689281]
- [fs] xfs: cache minimum realtime summary level (Bill O'Donnell) [1689281]
- [fs] xfs: count inode blocks correctly in inobt scrub (Bill O'Donnell) [1689281]
- [fs] xfs: precalculate cluster alignment in inodes and blocks (Bill O'Donnell) [1689281]
- [fs] xfs: precalculate inodes and blocks per inode cluster (Bill O'Donnell) [1689281]
- [fs] xfs: add a block to inode count converter (Bill O'Donnell) [1689281]
- [fs] xfs: remove xfs_rmap_ag_owner and friends (Bill O'Donnell) [1689281]
- [fs] xfs: const-ify xfs_owner_info arguments (Bill O'Donnell) [1689281]
- [fs] xfs: streamline defer op type handling (Bill O'Donnell) [1689281]
- [fs] xfs: idiotproof defer op type configuration (Bill O'Donnell) [1689281]
- [fs] xfs: clean up indentation issues, remove an unwanted space (Bill O'Donnell) [1689281]
- [fs] xfs: libxfs: move xfs_perag_put late (Bill O'Donnell) [1689281]
- [fs] xfs: split up the xfs_reflink_end_cow work into smaller transactions (Bill O'Donnell) [1689281]
- [crypto] crypto: testmgr - add AES-CFB tests (Neil Horman) [1687897]
- [scsi] scsi: iscsi: flush running unbind operations when removing a session (Maurizio Lombardi) [1695007]
- [crypto] crypto: vmx - fix copy-paste error in CTR mode (Herbert Xu) [1693350]
- [rpmspec] Fix cross builds (Jiri Olsa) [1694956]
- [lib] sbitmap: order READ/WRITE freed instance and setting clear bit (Ming Lei) [1694521]
- [block] blk-mq: fix sbitmap ws_active for shared tags (Ming Lei) [1694521]
- [block] blk-mq: update comment for blk_mq_hctx_has_pending() (Ming Lei) [1694521]
- [block] blk-mq: use blk_mq_put_driver_tag() to put tag (Ming Lei) [1694521]
- [include] sbitmap: trivial - update comment for sbitmap_deferred_clear_bit (Ming Lei) [1694521]
- [block] blkcg: Fix kernel-doc warnings (Ming Lei) [1694521]
- [block] block: Unexport blk_mq_add_to_requeue_list() (Ming Lei) [1694521]
- [block] block: add BLK_MQ_POLL_CLASSIC for hybrid poll and return EINVAL for unexpected value (Ming Lei) [1694521]
- [include] blk-mq: remove unused 'nr_expired' from blk_mq_hw_ctx (Ming Lei) [1694521]
- [block] loop: access lo_backing_file only when the loop device is Lo_bound (Ming Lei) [1694521]
- [block] blk-mq: use blk_mq_sched_mark_restart_hctx to set RESTART (Ming Lei) [1694521]
- [kernel] blkcg: annotate implicit fall through (Ming Lei) [1694521]
- [block] block: Replace function name in string with __func__ (Ming Lei) [1694521]
- [block] block: fix NULL pointer dereference in register_disk (Ming Lei) [1694521]
- [fs] fs: fix guard_bio_eod to check for real EOD errors (Ming Lei) [1694521]
- [block] blk-mq: use HCTX_TYPE_DEFAULT but not 0 to index blk_mq_tag_set->map (Ming Lei) [1694521]
- [include] block: remove bvec_iter_rewind() (Ming Lei) [1694521]
- [block] block: don't use bio->bi_vcnt to figure out segment number (Ming Lei) [1694521]
- [fs] btrfs: look at bi_size for repair decisions (Ming Lei) [1694521]
- [block] block: avoid setting none scheduler if it's already none (Ming Lei) [1694521]
- [block] block: avoid setting wbt_lat_usec to current value (Ming Lei) [1694521]
- [block] blk-sysfs: Rework documention of __blk_release_queue (Ming Lei) [1694521]
- [block] blk-cgroup: Fix doc related to blkcg_exit_queue (Ming Lei) [1694521]
- [block] block: kill QUEUE_FLAG_FLUSH_NQ (Ming Lei) [1694521]
- [block] block: avoid setting nr_requests to current value (Ming Lei) [1694521]
- [block] blk-mq: save default hctx into ctx->hctxs for not-supported type (Ming Lei) [1694521]
- [block] blk-mq: save queue mapping result into ctx directly (Ming Lei) [1694521]
- [block] block: mq-deadline: Fix write completion handling (Ming Lei) [1694521]
- [crypto] crypto: user - fix leaking uninitialized memory to userspace (Herbert Xu) [1657880] {CVE-2018-19854}
- [char] ipmi: fix sleep-in-atomic in free_user at cleanup SRCU user->release_barrier (Xiaojun Tan) [1689480]
- [infiniband] usnic_verbs: fix deadlock (Govindarajulu Varadarajan) [1688505]
- [infiniband] IB/usnic: Fix locking when unregistering (Govindarajulu Varadarajan) [1688505]
- [infiniband] IB/usnic: Fix potential deadlock (Govindarajulu Varadarajan) [1688505]
- [netdrv] net: hns3: fix improper error handling in the hclge_init_ae_dev() (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: fix netif_napi_del() not do problem when unloading (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: Fix NULL deref when unloading driver (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: Modify the order of initializing command queue register (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: remove the Redundant put_vector in hns3_client_uninit (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: reuse reinitialization interface in the hns3_set_channels (Xiaojun Tan) [1687060]

* Tue Apr 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.12.el8]
- [powercap] powercap/intel_rapl: add Ice Lake mobile (Steve Best) [1483427]
- [x86] x86/CPU: Add Icelake model number (Steve Best) [1483427]
- [watchdog] watchdog/hpwdt: Update Kconfig documentation (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Update driver version. (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Do not claim unsupported hardware (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Exclude via blacklist (Joseph Szczypek) [1664861]
- [fs] autofs: add strictexpire mount option (Ian Kent) [1672134]
- [fs] autofs: change catatonic setting to a bit flag (Ian Kent) [1672134]
- [fs] autofs: simplify parse_options() function call (Ian Kent) [1672134]
- [fs] autofs: add AUTOFS_EXP_FORCED flag (Ian Kent) [1672134]
- [fs] autofs: make expire flags usage consistent with v5 params (Ian Kent) [1672134]
- [fs] autofs: make autofs_expire_indirect() static (Ian Kent) [1672134]
- [fs] autofs: make autofs_expire_direct() static (Ian Kent) [1672134]
- [fs] autofs: fix clearing AUTOFS_EXP_LEAVES in autofs_expire_indirect() (Ian Kent) [1672134]
- [fs] autofs: fix inconsistent use of now variable (Ian Kent) [1672134]
- [md] md: Fix failed allocation of md_register_thread (Nigel Croxon) [1665346]
- [md] It's wrong to add len to sector_nr in raid10 reshape twice (Nigel Croxon) [1665346]
- [md] raid5: set write hint for PPL (Nigel Croxon) [1665346]
- [netdrv] amd-xgbe: Fix mdio access for non-zero ports and clause 45 PHYs (Gary Hook) [1669565]

* Mon Apr 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.11.el8]
- [x86] x86/retpolines: Disable switch jump tables when retpolines are enabled (Waiman Long) [1688258]
- [x86] x86, retpolines: Raise limit for generating indirect calls from switch-case (Waiman Long) [1688258]
- [net] vsock/virtio: fix kernel panic from virtio_transport_reset_no_sock (Stefano Garzarella) [1676595]
- [net] vsock/virtio: reset connected sockets on device removal (Stefano Garzarella) [1676595]
- [net] vsock/virtio: fix kernel panic after device hot-unplug (Stefano Garzarella) [1676595]
- [powerpc] powerpc/livepatch: return -ERRNO values in save_stack_trace_tsk_reliable() (Joe Lawrence) [1659856]
- [powerpc] powerpc/livepatch: small cleanups in save_stack_trace_tsk_reliable() (Joe Lawrence) [1659856]
- [powerpc] powerpc/livepatch: relax reliable stack tracer checks for first-frame (Joe Lawrence) [1659856]
- [powerpc] powerpc/64s: Make reliable stacktrace dependency clearer (Joe Lawrence) [1659856]
- [powerpc] powerpc/64s: Clear on-stack exception marker upon exception return (Joe Lawrence) [1659856]
- [infiniband] iw_cxgb4: Support FW write completion WR (Arjun Vynipadath) [1671320]
- [infiniband] iw_cxgb4: RDMA write with immediate support (Arjun Vynipadath) [1671320]
- [infiniband] rdma/cxgb4: fix some info leaks (Arjun Vynipadath) [1671320]
- [infiniband] rdma/cxgb4: Add support for 64Byte cqes (Arjun Vynipadath) [1671320]
- [pci] pci: remove unused functionality (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] aacraid: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] be2iscsi: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] mpt3sas: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] qla2xxx: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] qla4xxx: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] megaraid_sas: add removed id table" (Tomas Henzl) [1622638]
- [scsi] lfpc: remove Lancer FCoE (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] lpfc: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] lfpc: add Lancer FCoE to the removed devices" (Tomas Henzl) [1622638]

* Fri Apr 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.10.el8]
- [kernel] printk: Export console_printk (Prarit Bhargava) [1642870]
- [video] fbcon: Silence fbcon logo on 'quiet' boots (Prarit Bhargava) [1642870]
- [scsi] scsi: ibmvscsi: Fix empty event pool access during host removal (Steve Best) [1692463]
- [scsi] scsi: ibmvscsi: Protect ibmvscsi_head from concurrent modificaiton (Steve Best) [1692463]
- [scsi] scsi: ibmvscsi: Improve strings handling (Steve Best) [1692463]
- [x86] x86/mce: Handle varying MCA bank counts (David Arcari) [1668779]
- [block] virtio_blk: add discard and write zeroes support (Stefano Garzarella) [1692939]
- [arm64] arm64: kaslr: ensure randomized quantities are clean also when kaslr is off (Mark Salter) [1673068]
- [arm64] arm64: kaslr: ensure randomized quantities are clean to the PoC (Mark Salter) [1673068]
- [tools] perf annotate: Fix getting source line failure (Michael Petlan) [1614435]
- [infiniband] IB/hfi1: Remove overly conservative VM_EXEC flag check (Alex Estrin) [1680018]

* Thu Apr 04 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.9.el8]
- [scsi] scsi: qla2xxx: Fix NULL pointer crash due to stale CPUID (Himanshu Madhani) [1685013]
- [scsi] scsi: core: Avoid that system resume triggers a kernel warning (Ewan Milne) [1691903]
- [scsi] scsi: core: reset host byte in DID_NEXUS_FAILURE case (Ewan Milne) [1691903]
- [scsi] scsi: core: Synchronize request queue PM status only on successful resume (Ewan Milne) [1691903]
- [scsi] scsi: sd: Fix cache_type_store() (Ewan Milne) [1691903]
- [scsi] scsi: sd: use mempool for discard special page (Ewan Milne) [1691903]
- [scsi] scsi: core: Remove scsi_block_when_processing_errors: message (Ewan Milne) [1691903]
- [scsi] scsi: core: Allow state transitions from OFFLINE to BLOCKED (Ewan Milne) [1691903]
- [scsi] scsi: core: remove unnecessary unlikely() (Ewan Milne) [1691903]
- [scsi] scsi: st: remove redundant pointer STbuffer (Ewan Milne) [1691903]
- [scsi] scsi: core: Avoid that SCSI device removal through sysfs triggers a deadlock (Ewan Milne) [1691903]
- [fs] scsi: sysfs: Introduce sysfs_{un,}break_active_protection() (Ewan Milne) [1691903]
- [scsi] scsi sg: remove incorrect scsi command checking logic (Ewan Milne) [1691903]
- [scsi] scsi: read host_busy via scsi_host_busy() (Ewan Milne) [1691903]
- [scsi] scsi: sd: Remove a superfluous assignment (Ewan Milne) [1691903]
- [scsi] scsi: don't add scsi command result bytes (Ewan Milne) [1691903]
- [scsi] scsi: core: check for equality of result byte values (Ewan Milne) [1691903]
- [scsi] scsi: scsi_transport_fc: use 64-bit timestamps consistently (Ewan Milne) [1691903]
- [scsi] scsi: sg: clean up gfp_mask in sg_build_indirect (Ewan Milne) [1691903]
- [scsi] scsi: core: remove Scsi_Cmnd typedef (Ewan Milne) [1691903]
- [netdrv] ibmvnic: Report actual backing device speed and duplex values (Steve Best) [1691862]
- [kernel] sched/fair: Fix O(nr_cgroups) in the load balancing path (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Fix insertion in rq->leaf_cfs_rq_list (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Add tmp_alone_branch assertion (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Fix infinite loop in update_blocked_averages() by reverting a9e7f6544b9c (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] tracing: Do a WARN_ON() if start_thread() in hwlat is called when thread exists (Jerome Marchand) [1693050]
- [kernel] ftrace: Add missing check for existing hwlat thread (Jerome Marchand) [1693050]
- [kernel] tracing: Do not call start/stop() functions when tracing_on does not change (Jerome Marchand) [1693050]

* Wed Apr 03 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.8.el8]
- [scsi] scsi: lpfc: Fixup eq_clr_intr references (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix build error (Dick Kennedy) [1692882]
- [scsi] scsi: be2iscsi: lpfc: fix typo (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.1 (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Update Copyright in driver version (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Enhance 6072 log string (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix duplicate log message numbers (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Specify node affinity for queue memory allocation (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Reduce memory footprint for lpfc_queue (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Add loopback testing to trunking mode (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix link speed reporting for 4-link trunk (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix handling of trunk links state reporting (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix protocol support on G6 and G7 adapters (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct boot bios information to FDMI registration (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix HDMI2 registration string for symbolic name (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix fc4type information for FDMI (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix FDMI manufacturer attribute value (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix io lost on host resets (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix mailbox hang on adapter init (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix driver crash in target reset handler (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct localport timeout duration error (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: nvmet: avoid hang / use-after-free when destroying targetport (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Convert bootstrap mbx polling from msleep to udelay (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Coordinate adapter error handling with offline handling (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Stop adapter if pci errors detected (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix deadlock due to nested hbalock call (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix nvmet handling of first burst cmd (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix lpfc_nvmet_mrq attribute handling when 0 (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix nvmet async receive buffer replenishment (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix location of SCSI ktime counters (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix SLI3 commands being issued on SLI4 devices (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix use-after-free mailbox cmd completion (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Resolve irq-unsafe lockdep heirarchy warning in lpfc_io_free (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Resolve inconsistent check of hdwq in lpfc_scsi_cmd_iocb_cmpl (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix error codes in lpfc_sli4_pci_mem_setup() (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix 32-bit format string warning (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix unused variable warning (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: resolve static checker warning in lpfc_sli4_hba_unset (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct __lpfc_sli_issue_iocb_s4 lockdep check (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix calls to dma_set_mask_and_coherent() (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: use dma_set_mask_and_coherent (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Remove set but not used variable 'phys_id' (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix a handful of indentation issues (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix error code if kcalloc() fails (Dick Kennedy) [1692882]
- [security] security/selinux: fix SECURITY_LSM_NATIVE_LABELS on reused superblock (Ondrej Mosnacek) [1683296]
- [security] selinux: add the missing walk_size + len check in selinux_sctp_bind_connect (Ondrej Mosnacek) [1683296]
- [security] selinux: fix avc audit messages (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: replace BUG_ONs with WARN_ONs in avc.c (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: log invalid contexts in AVCs (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: replace some BUG_ON()s with a WARN_ON() (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: inline some AVC functions used only once (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: do not override context on context mounts (Ondrej Mosnacek) [1683296]
- [security] selinux: never allow relabeling on context mounts (Ondrej Mosnacek) [1683296]
- [security] selinux: stop passing MAY_NOT_BLOCK to the AVC upon follow_link (Ondrej Mosnacek) [1683296]
- [security] selinux: avoid silent denials in permissive mode under RCU walk (Ondrej Mosnacek) [1683296]
- [security] selinux: fix GPF on invalid policy (Ondrej Mosnacek) [1683296]
- [security] selinux: overhaul sidtab to fix bug and improve performance (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: use separate table for initial SID lookup (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: make "selinux_policycap_names[]" const char * (Ondrej Mosnacek) [1683296]
- [security] selinux: always allow mounting submounts (Ondrej Mosnacek) [1647723 1683296]
- [security] selinux: refactor sidtab conversion (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: fix non-MLS handling in mls_context_to_sid() (Ondrej Mosnacek) [1683296]
- [security] selinux: check length properly in SCTP bind hook (Ondrej Mosnacek) [1683296]
- [security] selinux: policydb - fix byte order and alignment issues (Ondrej Mosnacek) [1668222 1683296]
- [security] selinux: Add __GFP_NOWARN to allocation at str_read() (Ondrej Mosnacek) [1683296]
- [security] selinux: refactor mls_context_to_sid() and make it stricter (Ondrej Mosnacek) [1683296]
- [security] selinux: fix mounting of cgroup2 under older policies (Ondrej Mosnacek) [1683296]
- [security] selinux: cleanup dentry and inodes on error in selinuxfs (Ondrej Mosnacek) [1683296]
- [security] selinux: constify write_op[] (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netnode (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in avc (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netif (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netport (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in sidtab (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netlink (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in selinuxfs (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in services (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in avtab (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in hooks (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in policydb (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in ebitmap (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in conditional (Ondrej Mosnacek) [1683296]
- [fs] fs/proc/kcore.c: fix invalid memory access in multi-page read optimization (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: add vmcoreinfo note to /proc/kcore (Bhupesh Sharma) [1627539]
- [kernel] crash_core: use VMCOREINFO_SYMBOL_ARRAY() for swapper_pg_dir (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: optimize multiple page reads (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: clean up ELF header generation (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: hold lock during read (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: fix memory hotplug vs multiple opens race (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: replace kclist_lock rwlock with rwsem (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: don't grab lock for memory hotplug notifier (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: don't grab lock for kclist_add() (Bhupesh Sharma) [1627539]

* Tue Apr 02 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.7.el8]
- [net] Merge branch 'linus/master' into rdma.git for-next (Jonathan Toppins) [1685304]
- [netdrv] net: cisco: enic: Replace GFP_ATOMIC with GFP_KERNEL (Jonathan Toppins) [1685304]
- [infiniband] RDMA/providers: Remove pointless functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/usnic: Suppress a compiler warning (Jonathan Toppins) [1685304]
- [infiniband] IB/usnic: usnic should not select INFINIBAND_USER_ACCESS (Jonathan Toppins) [1685304]
- [infiniband] RDMA/vmw_pvrdma: Delete unused function (Jonathan Toppins) [1685304]
- [infiniband] IB/usnic: Update with bug fixes from core code (Jonathan Toppins) [1685304]
- [infiniband] RDMA/providers: Fix return value from create_srq callbacks (Jonathan Toppins) [1685304]
- [infiniband] RDMA/rxe: Simplify the error handling code in rxe_create_ah() (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: avoid unnecessary NULL check (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: increase max MR limit (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: Do not hide uABI stuff in memcpy (Jonathan Toppins) [1685304]
- [net] rpc: remove unneeded variable 'ret' in rdma_listen_handler (Jonathan Toppins) [1685304]
- [net] svcrdma: Clean up Read chunk path (Jonathan Toppins) [1685304]
- [net] svcrdma: Avoid releasing a page in svc_xprt_release() (Jonathan Toppins) [1685304]
- [net] sunrpc: remove redundant variables 'checksumlen', 'blocksize' and 'data' (Jonathan Toppins) [1685304]
- [scsi] scsi: target: srp, vscsi, sbp, qla: use target_remove_session (Jonathan Toppins) [1685304]
- [target] scsi: target: add session removal function (Jonathan Toppins) [1685304]
- [target] scsi: target: rename target_alloc_session (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Fix check for return code from ib_create_srq (Jonathan Toppins) [1685304]
- [infiniband] IB/ipoib: Fix error return code in ipoib_dev_init() (Jonathan Toppins) [1685304]
- [infiniband] IPoIB: use kvzalloc to allocate an array of bucket pointers (Jonathan Toppins) [1685304]
- [infiniband] ib_srpt: use kvmalloc to allocate ring pointers (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Fix return code from ipoib_cm_dev_init (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Remove set-but-not-used variables (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Prefer unsigned int to bare use of unsigned (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Use min_t() macro instead of min() (Jonathan Toppins) [1685304]
- [infiniband] IB/srp: Remove driver version and release data information (Jonathan Toppins) [1685304]
- [target] scsi: target: Remove second argument from fabric_make_tpg() (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: set can_queue earlier to allow setting higher queue depth (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Set right entry state before releasing reference (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Free uapi on destroy (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Fix error cleanup path of ib_uverbs_add_one() (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Release object lock if destroy failed (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: fix UCM link error (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Change filter function return type from int to bool (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Update GID entries for netdevice whose mac address changes (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add default GIDs of the bond master netdev (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Consider adding default GIDs of bond device (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Delete lower netdevice default GID entries in bonding scenario (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Avoid confusing del_netdev_default_ips (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add comment for change upper netevent handling (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: Fix compiling ucm.c (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not check for device disassociation during ioctl (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove struct uverbs_root_spec and all supporting code (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_api to unmarshal ioctl commands (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_alloc for allocations (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a simple allocator to uverbs_attr_bundle (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove the ib_uverbs_attr pointer from each attr (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Provide implementation private memory for the uverbs_attr_bundle (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_api to manage the object type inside the uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Build the specs into a radix tree at runtime (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Have the core code create the uverbs_root_spec (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Fix reading of 32 bit flags (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: Initialize sgid request GID attribute pointer (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow all DESTROY commands to succeed after disassociate (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not block disassociate during write() (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not pass struct ib_device to the ioctl methods (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not pass struct ib_device to the write based methods (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Lower the test for ongoing disassociation (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow uobject allocation to work concurrently with disassociate (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow RDMA_REMOVE_DESTROY to work concurrently with disassociate (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Convert 'bool exclusive' into an enum (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Consolidate uobject destruction (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Make the write path destroy methods use the same flow as ioctl (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove rdma_explicit_destroy() from the ioctl methods (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Prefix _ib to IB/RoCE specific functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Simplify gid type check in cma_acquire_dev() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Return bool instead of int (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Get rid of 1 bit boolean (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Constify path record, ib_cm_event, listen_id pointers (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Constify dst_addr argument (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Simplify rdma_resolve_addr() error flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Initialize resource type in __rdma_create_id() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Check for verbs callbacks before using them (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove {create,destroy}_ah from mandatory verbs (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add UVERBS_ATTR_FLAGS_IN to the specs language (Jonathan Toppins) [1685304]
- [infiniband] RDMA, core and ULPs: Declare ib_post_send() and ib_post_recv() arguments const (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx5, ib_post_send(), IB_WR_REG_SIG_MR: Do not modify the 'wr' argument (Jonathan Toppins) [1685304]
- [net] net/xprtrdma: Restore needed argument to ib_post_send (Jonathan Toppins) [1685304]
- [net] net/xprtrdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [nvme] nvmet-rdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [nvme] nvme-rdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/srpt: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/srp: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/isert: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/IPoIB: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Constify the argument of the work request conversion functions (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Inline two work request conversion functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Consider netdevice for RoCE ports (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce and use sgid_attr in CM requests (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Remove extra parentheses (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Fix locking around struct ib_uverbs_file ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Move the FD uobj type struct file allocation to alloc_commit (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Always propagate errors from rdma_alloc_commit_uobject() (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Rework the locking for cleaning up the ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Revise and clarify the rwsem and uobjects_lock (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Clarify and revise uverbs_close_fd (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Revise the placement of get/puts on uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Clarify the kref'ing ordering for alloc_commit (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Handle IDR and FD types without truncation (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Get rid of null_obj_type (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [include] IB/core: Allow ULPs to specify NULL as the third ib_post_(send|recv|srq_recv)() argument (Jonathan Toppins) [1685304]
- [include] IB/mlx5: Introduce driver create and destroy flow methods (Jonathan Toppins) [1685304]
- [infiniband] IB: Support ib_flow creation in drivers (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx5: Introduce flow steering matcher uapi object (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Move ib_access_flags and ib_read_counters_flags to uapi (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove cma_multicast->igmp_joined (Jonathan Toppins) [1685304]
- [infiniband] RDMA/umem: Refactor exit paths in ib_umem_get (Jonathan Toppins) [1685304]
- [infiniband] IB: Enable uverbs_destroy_def_handler to be used by drivers (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Pass IB_UVERBS_QPF_GRH_REQUIRED to user space (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Validate grh_required when handling AVs (Jonathan Toppins) [1685304]
- [infiniband] RDMA/hfi1: Move grh_required into update_sm_ah (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Simplify check for RoCE route resolve (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not use uverbs_cmd_mask in the ioctl path (Jonathan Toppins) [1685304]
- [infiniband] RDMA/rw: Fix rdma_rw_ctx_signature_init() kernel-doc header (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove set-but-not-used variables (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove ib_find_cached_gid() and ib_find_cached_gid_by_port() (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove unused and erroneous msg sequence encoding (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace ib_ucq_object uverbs_file with the one in ib_uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove ib_uobject_file (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Tidy up remaining references to ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace file->ucontext with file in uverbs_cmd.c (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace ib_ucontext with ib_uverbs_file in core function calls (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Move non driver related elements from ib_ucontext to ib_ufile (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a uobj_perform_destroy helper (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Combine MIN_SZ_OR_ZERO with UVERBS_ATTR_STRUCT (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Use UVERBS_ATTR_MIN_SIZE correctly and uniformly (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Remove UA_FLAGS (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Get rid of the & in method specifications (Jonathan Toppins) [1685304]
- [infiniband] IB: Improve uverbs_cleanup_ucontext algorithm (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify UVERBS_OBJECT and _TREE family of macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify method definition macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify UVERBS_ATTR family of macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Split UVERBS_ATTR_FLOW_ACTION_ESP_HANDLE (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Store the specs_root in the struct ib_uverbs_device (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove now useless rcu_lock in dst_fetch_ha (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Check for rdma_protocol_ib only after validating port_num (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Remove redundant check (Jonathan Toppins) [1685304]
- [infiniband] RDMA/umem: Don't check for a negative return value of dma_map_sg_attrs() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/verbs: Drop kernel variant of destroy_flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/verbs: Drop kernel variant of create_flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Check existence of create_flow callback (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove unused ib cache functions (Jonathan Toppins) [1685304]
- [infiniband] Revert "[infiniband] RDMA/hns: Only assgin the fields of the av if IB_QP_AV bit is set" (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Convert drivers to use the AH's sgid_attr in post_wr paths (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx4: Use GID attribute from ah attribute (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: Use rdma GID API (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Use sgid_attr from the AV (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Replace members of sa_path_rec with 'struct sgid_attr *' (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Pass the sgid_attr through various events (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Keep track of the sgid_attr that created the cm id (Jonathan Toppins) [1685304]
- [infiniband] IB: Make init_ah_attr_grh_fields set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Make ib_init_ah_from_mcmember set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Make ib_init_ah_attr_from_wc set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Free GID table entry during GID deletion (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Consider net namespace while leaving multicast group (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Delete type and id from uverbs_obj_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/rdmavt, IB/hfi1: Create device dependent s_flags (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Expose ib_ucontext from a given ib_uverbs_file (Jonathan Toppins) [1685304]
- [include] IB/core: Introduce DECLARE_UVERBS_GLOBAL_METHODS (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow an empty namespace in ioctl() framework (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a macro to define a type with no kernel known size (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add PTR_IN attributes that are allocated/copied automatically (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Refactor uverbs_finalize_objects (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Export uverbs idr and fd types (Jonathan Toppins) [1685304]
- [infiniband] IB/mad: Use IDR for agent IDs (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Hold the sgid_attr inside the struct ib_ah/qp (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Convert drivers to use sgid_attr instead of sgid_index (Jonathan Toppins) [1685304]
- [infiniband] IB{cm, core}: Introduce and use ah_attr copy, move, replace APIs (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Tidy ib_resolve_eth_dmac (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add a sgid_attr pointer to struct rdma_ah_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Ensure that all rdma_ah_attr's are zero initialized (Jonathan Toppins) [1685304]
- [infiniband] IB/mad: Agent registration is process context only (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Refactor flow_resources_alloc() function (Jonathan Toppins) [1685304]
- [infiniband] RDMA/nldev: Return port capability flag for IB only (Jonathan Toppins) [1685304]
- [net] RDMA/smc: Replace ib_query_gid with rdma_get_gid_attr (Jonathan Toppins) [1685304]
- [include] IB/cache: Restore compatibility for ib_query_gid (Jonathan Toppins) [1685304]
- [infiniband] IB: Replace ib_query_gid/ib_get_cached_gid with rdma_query_gid (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Make rdma_find_gid_by_filter support all protocols (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Provide rdma_ versions of the gid cache API (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Replace ib_query_gid with rdma_get_gid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce GID attribute get, put and hold APIs (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Use GID from the ib_gid_attr during the add_gid() callback (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce GID entry reference counts (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Store default GID property per-table instead of per-entry (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Do not set the gid type when reserving default entries (Jonathan Toppins) [1685304]
- [include] IDR: Expose the XArray lock (Jonathan Toppins) [1688319]
- [x86] x86/cpufeatures: Enumerate MOVDIR64B instruction (Steve Best) [1482754]
- [x86] x86/cpufeatures: Enumerate MOVDIRI instruction (Steve Best) [1482754]
- [nvme] nvme: allow ANA support to be independent of native multipathing (Ewan Milne) [1690940]
- [nvme] nvme: multipath: Change default of kernel NVMe multipath to be disabled (Ewan Milne) [1690940]
- [nvme] nvme: convert to SPDX identifiers (Ewan Milne) [1690940]
- [nvme] nvme-multipath: round-robin I/O policy (Ewan Milne) [1690940]
- [nvme] nvme-multipath: drop optimization for static ANA group IDs (Ewan Milne) [1690940]
- [nvme] nvme-multipath: zero out ANA log buffer (Ewan Milne) [1690940]
- [nvme] nvme-fc: fix numa_node when dev is null (Ewan Milne) [1690940]
- [nvme] nvme: add a numa_node field to struct nvme_ctrl (Ewan Milne) [1690940]
- [nvme] nvme: update node paths after adding new path (Ewan Milne) [1690940]
- [nvme] nvme: take node locality into account when selecting a path (Ewan Milne) [1690940]
- [s390] s390/mm: Fix ERROR: "__node_distance" undefined! (Ewan Milne) [1690940]
- [nvme] nvme: call nvme_complete_rq when nvmf_check_ready fails for mpath I/O (Ewan Milne) [1690940]
- [nvme] nvme: properly propagate errors in nvme_mpath_init (Ewan Milne) [1690940]
- [nvme] nvme: fixup crash on failed discovery (Ewan Milne) [1690940]
- [nvme] nvme: add ANA support (Ewan Milne) [1690940]
- [include] nvme.h: fixup ANA group descriptor format (Ewan Milne) [1690940]
- [include] nvme.h: add ANA definitions (Ewan Milne) [1690940]
- [nvme] nvme: remove nvme_req_needs_failover (Ewan Milne) [1690940]
- [nvme] nvme: simplify the API for getting log pages (Ewan Milne) [1690940]
- [include] nvme.h: add support for the log specific field (Ewan Milne) [1690940]

* Fri Mar 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.6.el8]
- [md] dm writecache: set "Tech Preview" taint using mark_tech_preview() (Mike Snitzer) [1690587]
- [md] dm integrity: limit the rate of error messages (Mike Snitzer) [1690105]
- [md] dm snapshot: don't define direct_access if we don't support it (Mike Snitzer) [1690105]
- [md] dm cache: add support for discard passdown to the origin device (Mike Snitzer) [1690105]
- [md] dm writecache: fix typo in name for writeback_wq (Mike Snitzer) [1690105]
- [md] dm thin: add sanity checks to thin-pool and external snapshot creation (Mike Snitzer) [1690105]
- [md] dm block manager: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm verity fec: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm integrity: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm switch: use struct_size() in kzalloc() (Mike Snitzer) [1690105]
- [md] dm: remove unused _rq_tio_cache and _rq_cache (Mike Snitzer) [1690105]
- [md] dm crypt: don't overallocate the integrity tag space (Mike Snitzer) [1690105]
- [md] dm: eliminate 'split_discard_bios' flag from DM target interface (Mike Snitzer) [1690105]
- [md] dm: always call blk_queue_split() in dm_process_bio() (Mike Snitzer) [1690105]
- [md] dm: update dm_process_bio() to split bio if in ->make_request_fn() (Mike Snitzer) [1690105]
- [md] dm rq: remove unused arguments from rq_completed() (Mike Snitzer) [1690105]
- [md] dm integrity: replace open-coded allocation size multiplication (Mike Snitzer) [1690105]
- [md] dm: Remove VLA usage from hashes (Mike Snitzer) [1690105]
- [crypto] crypto: hash - Remove VLA usage (Mike Snitzer) [1690105]
- [md] dm: Avoid namespace collision with bitmap API (Mike Snitzer) [1690105]
- [md] md/dm-writecache: Don't request pointer dummy_addr when not required (Mike Snitzer) [1690105]
- [scsi] scsi: qla2xxx: avoid printf format warning (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix issue reported by static checker for qla2x00_els_dcmd2_sp_done() (Himanshu Madhani) [1664534]
- [scsi] qla2xxx: Update driver version to 10.00.00.14.08.1-k (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Avoid PCI IRQ affinity mapping when multiqueue is not supported (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add new FW dump template entry types (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix code indentation for qla27xx_fwdt_entry (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move marker request behind QPair (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent SysFS access when chip is down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add support for setting port speed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent multiple ADISC commands per session (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Check for FW started flag before aborting (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix unload when NVMe devices are configured (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add First Burst support for FC-NVMe devices (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix LUN discovery if loop id is not assigned yet by firmware (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: remove redundant null check on pointer sess (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move debug messages before sending srb preventing panic (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Use complete switch scan for RSCN events (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix fw options handle eh_bus_reset() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Restore FAWWPN of Physical Port only for loop down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent memory leak for CT req/rsp allocation (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix SRB allocation flag to avoid sleeping in IRQ context (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: allow session delete to finish before create. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fix fcport null pointer access. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: flush IO on chip reset or sess delete (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix session cleanup hang (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Change default ZIO threshold. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add pci function reset support. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix N2N target discovery with Local loop (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: no need to check return value of debugfs_create functions (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix DMA error when the DIF sg buffer crosses 4GB boundary (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add protection mask module parameters (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix for FC-NVMe discovery for NPIV port (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix NPIV handling for FC-NVMe (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Enable FC-NVME on NPIV ports (Himanshu Madhani) [1664534]
- [scsi] Revert "scsi: qla2xxx: Fix NVMe Target discovery" (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: NULL check before some freeing functions is not needed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Split the __qla2x00_abort_all_cmds() function (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Introduce a switch/case statement in qlt_xmit_tm_rsp() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix a typo in MODULE_PARM_DESC (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove two arguments from qlafx00_error_entry() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Make sure that qlafx00_ioctl_iosb_entry() initializes 'res' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove a set-but-not-used variable (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Make qla2x00_sysfs_write_nvram() easier to analyze (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Declare local functions 'static' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Improve several kernel-doc headers (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Modify fall-through annotations (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fully convert to the generic DMA API (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Simplify conditional check (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove unnecessary self assignment (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Return switch command on a timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move log messages before issuing command to firmware (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix for double free of SRB structure (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix recursive mailbox timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix NVMe Target discovery (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: don't allow negative thresholds (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix comment in MODULE_PARM_DESC in qla2xxx (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove set but not used variable 'ptr_dma' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fix typo "CT-PASSTRHU" -> "CT-PASSTHRU" (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix an endian bug in fcpcmd_is_corrupted() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix double increment of switch scan retry count (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix duplicate switch's Nport ID entries (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove stale debug trace message from tcm_qla2xxx (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix premature command free (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Reject bsg request if chip is down. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: shutdown chip if reset fail (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix stuck session in PLOGI state (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix early srb free on abort (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add mode control for each physical port (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix race condition for resource cleanup (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix dropped srb resource. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix port speed display on chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Check for Register disconnect (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Increase abort timeout value (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Allow FC-NVMe underrun to be handled by transport (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move ABTS code behind qpair (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove stale ADISC_DONE event (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix Remote port registration (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove ASYNC GIDPN switch command (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Reduce holding sess_lock to prevent CPU lock-up (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move {get|rel}_sp to base_qpair struct (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add support for ZIO6 interrupt threshold (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix out of order Termination and ABTS response (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add logic to detect ABTS hang and response completion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add appropriate debug info for invalid RX_ID (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix deadlock between ATIO and HW lock (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Serialize mailbox request (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Terminate Plogi/PRLI if WWN is 0 (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Defer chip reset until target mode is enabled (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove all rports if fabric scan retry fails (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Force fw cleanup on ADISC error (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Turn off IOCB timeout timer on IOCB completion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Decrement login retry count for only plogi (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move rport registration out of internal work_list (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove redundant check for fcport deletion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Update rscn_rcvd field to more meaningful scan_needed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Use correct qpair for ABTS/CMD (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix process response queue for ISP26XX and above (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Migrate NVME N2N handling into state machine (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Save frame payload size from ICB (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix race between switch cmd completion and timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix Management Server NPort handle reservation logic (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Flush mailbox commands on chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix session state stuck in Get Port DB (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix redundant fc_rport registration (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Silent erroneous message (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent sysfs access when chip is down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add longer window for chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix login retry count (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix N2N link re-connect (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Cleanup for N2N code (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: remove irq save in qla2x00_poll() (Himanshu Madhani) [1664534]
- [netdrv] ice: Do autoneg based on VSI state (Jonathan Toppins) [1687903]
- [fs] xfs: use the latest extent at writeback delalloc conversion time (Brian Foster) [1661968]
- [fs] xfs: create delalloc bmapi wrapper for full extent allocation (Brian Foster) [1661968]
- [fs] xfs: remove superfluous writeback mapping eof trimming (Brian Foster) [1661968]
- [fs] xfs: validate writeback mapping using data fork seq counter (Brian Foster) [1661968]
- [fs] xfs: update fork seq counter on data fork changes (Brian Foster) [1661968]
- [fs] xfs: eof trim writeback mapping as soon as it is cached (Brian Foster) [1661968]
- [perf] drivers/perf: hisi: update the sccl_id/ccl_id when MT is supported (Xiaojun Tan) [1677815]

* Tue Mar 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.5.el8]
- [x86] x86/hyperv: Fix kernel panic when kexec on HyperV (Kairui Song) [1684451]
- [rpmspec] apply linux-kernel-test.patch when building ("Herton R. Krzesinski") [1690534]
- [netdrv] net: ena: update driver version from 2.0.2 to 2.0.3 (John Linville) [1690106]
- [netdrv] net: ena: fix race between link up and device initalization (John Linville) [1690106]
- [netdrv] net: phy: add phy_speed_down and phy_speed_up (Petr Oros) [1690131]
- [netdrv] net: phy: add helper phy_config_aneg (Petr Oros) [1690131]
- [nvme] nvme-fabrics: convert to SPDX identifiers (Ewan Milne) [1690909]
- [nvme] nvme-fabrics: fix ctrl_loss_tmo < 0 to reconnect forever (Ewan Milne) [1690909]
- [nvme] nvme-fc: reject reconnect if io queue count is reduced to zero (Ewan Milne) [1690601]
- [nvme] nvme-fc: use nr_phys_segments to determine existence of sgl (Ewan Milne) [1690601]
- [include] nvme-fc: convert to SPDX identifiers (Ewan Milne) [1690601]
- [nvme] nvme-fc: initialize nvme_req(rq)->ctrl after calling __nvme_fc_init_request() (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix request private initialization (Ewan Milne) [1690601]
- [nvme] nvme-fc: rework the request initialization code (Ewan Milne) [1690601]
- [nvme] nvme-fc: introduce struct nvme_fcp_op_w_sgl (Ewan Milne) [1690601]
- [nvme] nvme: cache struct nvme_ctrl reference to struct nvme_request (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix kernel-doc headers (Ewan Milne) [1690601]
- [nvme] nvme_fc: add 'nvme_discovery' sysfs attribute to fc transport device (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix for a minor typos (Ewan Milne) [1690601]
- [crypto] crypto: arm64/aes-ccm - fix logical bug in AAD MAC handling (Neil Horman) [1689185]
- [mm] mm: enforce min addr even if capable() in expand_downwards() (Rafael Aquini) [1687667] {CVE-2019-9213}
- [pci] PCI/VMD: Configure MPS settings before adding devices (Prarit Bhargava) [1659270]
- [pci] PCI: vmd: Detach resources after stopping root bus (Prarit Bhargava) [1659270]
- [char] tpm: separate cmd_ready/go_idle from runtime_pm (Jerry Snitselaar) [1677735]
- [block] loop: set GENHD_FL_NO_PART_SCAN after blkdev_reread_part() (Ming Lei) [1683593]
- [block] loop: do not print warn message if partition scan is successful (Ming Lei) [1683593]
- [block] loop: drop caches if offset or block_size are changed (Ming Lei) [1683593]
- [block] block: loop: remove redundant code (Ming Lei) [1683593]
- [block] block: loop: check error using IS_ERR instead of IS_ERR_OR_NULL in loop_add() (Ming Lei) [1683593]
- [block] loop: Fix double mutex_unlock(&loop_ctl_mutex) in loop_control_ioctl() (Ming Lei) [1683593]
- [block] loop: Get rid of 'nested' acquisition of loop_ctl_mutex (Ming Lei) [1683593]
- [block] loop: Avoid circular locking dependency between loop_ctl_mutex and bd_mutex (Ming Lei) [1683593]
- [block] loop: Fix deadlock when calling blkdev_reread_part() (Ming Lei) [1683593]
- [block] loop: Move loop_reread_partitions() out of loop_ctl_mutex (Ming Lei) [1683593]
- [block] loop: Move special partition reread handling in loop_clr_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_change_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_set_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_set_status() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_get_status() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down into loop_clr_fd() (Ming Lei) [1683593]
- [block] loop: Split setting of lo_state from loop_clr_fd (Ming Lei) [1683593]
- [block] loop: Push lo_ctl_mutex down into individual ioctls (Ming Lei) [1683593]
- [block] loop: Get rid of loop_index_mutex (Ming Lei) [1683593]
- [block] loop: Fold __loop_release into loop_release (Ming Lei) [1683593]
- [block] block/loop: Use global lock for ioctl() operation. (Ming Lei) [1683593]
- [block] block/loop: Don't grab "struct file" for vfs_getattr() operation. (Ming Lei) [1683593]
- [crypto] crypto: cfb - fix decryption (Herbert Xu) [1653188]

* Fri Mar 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.4.el8]
- [misc] VMCI: Support upto 64-bit PPNs (Cathy Avery) [1683479]
- [mm] mm, page_alloc: fix has_unmovable_pages for HugePages (David Gibson) [1688114]
- [pci] PCI: pciehp: Disable Data Link Layer State Changed event on suspend (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Assign ctrl->slot_ctrl before writing it to hardware (Myron Stowe) [1688393 1537397]
- [pci] PCI/AER: Queue one GHES event, not several uninitialized ones (Myron Stowe) [1688393 1537397]
- [pci] PCI/AER: Refactor error injection fallbacks (Myron Stowe) [1688393]
- [pci] PCI/AER: Reuse existing pcie_port_find_device() interface (Myron Stowe) [1688393]
- [pci] PCI/AER: Use managed resource allocations (Myron Stowe) [1688393]
- [pci] PCI/AER: Use threaded IRQ for bottom half (Myron Stowe) [1688393]
- [pci] PCI/AER: Use kfifo_in_spinlocked() to insert locked elements (Myron Stowe) [1688393]
- [pci] PCI/AER: Use kfifo for tracking events instead of reimplementing it (Myron Stowe) [1688393]
- [pci] PCI/AER: Remove error source from AER struct aer_rpc (Myron Stowe) [1688393]
- [pci] PCI/AER: Remove unused aer_error_resume() (Myron Stowe) [1688393]
- [pci] PCI: pnv_php: Use kmemdup() (Myron Stowe) [1688393]
- [pci] PCI: cpqphp: Remove set but not used variable 'physical_slot' (Myron Stowe) [1688393]
- [pci] PCI/ERR: Remove duplicated include from err.c (Myron Stowe) [1688393]
- [pci] PCI: Equalize hotplug memory and io for occupied and empty slots (Myron Stowe) [1688393]
- [pci] PCI / ACPI: Whitelist D3 for more PCIe hotplug ports (Myron Stowe) [1688393 1537397]
- [acpi] ACPI / property: Allow multiple property compatible _DSD entries (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Implement runtime PM callbacks (Myron Stowe) [1688393 1537397]
- [pci] PCI/portdrv: Resume upon exit from system suspend if left runtime suspended (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Do not handle events if interrupts are masked (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Disable hotplug interrupt during suspend (Myron Stowe) [1688393 1537397]
- [pci] PCI / ACPI: Enable wake automatically for power managed bridges (Myron Stowe) [1688393 1537397]
- [pci] PCI: Do not skip power-managed bridges in pci_enable_wake() (Myron Stowe) [1688393 1537397]
- [pci] PCI: Unify device inaccessible (Myron Stowe) [1688393]
- [pci] PCI/ERR: Always report current recovery status for udev (Myron Stowe) [1688393]
- [pci] PCI/ERR: Simplify broadcast callouts (Myron Stowe) [1688393]
- [pci] PCI/ERR: Run error recovery callbacks for all affected devices (Myron Stowe) [1688393]
- [pci] PCI/ERR: Handle fatal error recovery (Myron Stowe) [1688393]
- [pci] PCI/ERR: Use slot reset if available (Myron Stowe) [1688393]
- [pci] PCI/AER: Don't read upstream ports below fatal errors (Myron Stowe) [1688393]
- [pci] PCI/AER: Take reference on error devices (Myron Stowe) [1688393]
- [pci] PCI/DPC: Save and restore config state (Myron Stowe) [1688393]
- [pci] PCI: portdrv: Restore PCI config state on slot reset (Myron Stowe) [1688393]
- [pci] PCI: portdrv: Initialize service drivers directly (Myron Stowe) [1688393]
- [x86] x86/intel_rdt: Show missing resctrl mount options (David Arcari) [1689043]
- [xen] xen/balloon: Fix mapping PG_offline pages to user space (David Hildenbrand) [1652790]
- [kernel] PM/Hibernate: exclude all PageOffline() pages (David Hildenbrand) [1652790]
- [kernel] PM/Hibernate: use pfn_to_online_page() (David Hildenbrand) [1652790]
- [hv] hv_balloon: mark inflated pages PG_offline (David Hildenbrand) [1652790]
- [xen] xen/balloon: mark inflated pages PG_offline (David Hildenbrand) [1652790]
- [kernel] kexec: export PG_offline to VMCOREINFO (David Hildenbrand) [1652790]
- [include] mm: convert PG_balloon to PG_offline (David Hildenbrand) [1652790]
- [include] mm: balloon: update comment about isolation/migration/compaction (David Hildenbrand) [1652790]
- [mm] mm/page_alloc.c: memory hotplug: free pages as higher order (David Hildenbrand) [1652790]
- [mm] mm/memory.c: do_fault: avoid usage of stale vm_area_struct ("Herton R. Krzesinski") [1684734]
- [kernel] cpuset: remove unused task_has_mempolicy() (Waiman Long) [1548268]
- [kernel] cpuset: Remove set but not used variable 'cs' (Waiman Long) [1548268]
- [kernel] cgroup: Add .__DEBUG__. prefix to debug file names (Waiman Long) [1548268]
- [kernel] cpuset: Minor cgroup2 interface updates (Waiman Long) [1548268]
- [kernel] cpuset: Expose cpuset.cpus.subpartitions with cgroup_debug (Waiman Long) [1548268]
- [documentation] cpuset: Add documentation about the new "cpuset.sched.partition" flag (Waiman Long) [1548268]
- [kernel] cpuset: Use descriptive text when reading/writing cpuset.sched.partition (Waiman Long) [1548268]
- [kernel] cpuset: Expose cpus.effective and mems.effective on cgroup v2 root (Waiman Long) [1548268]
- [kernel] cpuset: Make generate_sched_domains() work with partition (Waiman Long) [1548268]
- [kernel] cpuset: Make CPU hotplug work with partition (Waiman Long) [1548268]
- [kernel] cpuset: Track cpusets that use parent's effective_cpus (Waiman Long) [1548268]
- [kernel] cpuset: Add an error state to cpuset.sched.partition (Waiman Long) [1548268]
- [kernel] cpuset: Add new v2 cpuset.sched.partition flag (Waiman Long) [1548268]
- [kernel] cpuset: Simply allocation and freeing of cpumasks (Waiman Long) [1548268]
- [kernel] cpuset: Define data structures to support scheduling partition (Waiman Long) [1548268]
- [kernel] cpuset: Enable cpuset controller in default hierarchy (Waiman Long) [1548268]
- [kernel] cgroup/tracing: Move taking of spin lock out of trace event handlers (Waiman Long) [1548268]
- [powerpc] powerpc/powernv/ioda: Fix locked_vm counting for memory used by IOMMU tables (David Gibson) [1674410]
- [pci] PCI: dwc: Fix MSI-X EP framework address calculation bug (Myron Stowe) [1687935]
- [pci] PCI: cadence: Correct probe behaviour when failing to get PHY (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Fix PCI I/O mapping creation sequence (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Remove obsolete drivers/pci pattern from ACPI section (Myron Stowe) [1687935]
- [pci] PCI: dwc: Fix scheduling while atomic issues (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Move mobiveil PCI driver entry where it belongs (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Update PPC contacts for PCI core error handling (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Add Gustavo Pimentel as DesignWare PCI maintainer (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Add entries for PPC64 RPA PCI hotplug drivers (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Drop bogus comment above mvebu_pcie_map_registers() (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Convert to use pci_host_bridge directly (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Use resource_size() to remap I/O space (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Only remap I/O space if configured (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Fix I/O space end address calculation (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Remove redundant platform_set_drvdata() call (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Add Kconfig/Makefile entries (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Add missing ../pci.h include (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Fix struct mobiveil_pcie.pcie_reg_base address type (Myron Stowe) [1687935]
- [pci] PCI: endpoint: Add MSI set maximum restriction (Myron Stowe) [1687935]
- [tools] tools: PCI: Add MSI-X support (Myron Stowe) [1687935]
- [documentation] pci_endpoint_test: Add 2 ioctl commands (Myron Stowe) [1687935]
- [documentation] pci-epf-test/pci_endpoint_test: Add MSI-X support (Myron Stowe) [1687935]
- [misc] pci-epf-test/pci_endpoint_test: Use irq_type module parameter (Myron Stowe) [1687935]
- [misc] pci-epf-test/pci_endpoint_test: Cleanup PCI_ENDPOINT_TEST memspace (Myron Stowe) [1687935]
- [pci] PCI: dwc: Add legacy interrupt callback handler (Myron Stowe) [1687935]
- [pci] PCI: dwc: Rework MSI callbacks handler (Myron Stowe) [1687935]
- [pci] PCI: dwc: Add MSI-X callbacks handler (Myron Stowe) [1687935]
- [pci] PCI: Update xxx_pcie_ep_raise_irq() and pci_epc_raise_irq() signatures (Myron Stowe) [1687935]
- [pci] PCI: endpoint: Add MSI-X interfaces (Myron Stowe) [1687935]
- [pci] PCI: dwc: Fix EP link notification implementation (Myron Stowe) [1687935]
- [pci] PCI: spear13xx: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: qcom: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: histb: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: designware-plat: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: artpec6: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: armada8k: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: keystone: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: imx6: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: exynos: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: kirin: Add MSI support (Myron Stowe) [1687935]
- [pci] PCI: pcie-cadence-ep: Remove redundant variable mmc (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add shutdown callback to host driver (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add Power Management ops for host and EP (Myron Stowe) [1687935]
- [documentation] dt-bindings: PCI: cadence: Add DT bindings for optional PHYs (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add generic PHY support to host and EP drivers (Myron Stowe) [1687935]
- [pci] PCI: cadence: Update cdns_pcie_writel() function signature (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Convert to use pci_host_probe() (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Size bridges before resources allocation (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Remove PCIe outbound window configuration (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Introduce an advk_pcie_valid_device() helper (Myron Stowe) [1687935]
- [pci] PCI/xilinx: Depend on OF instead of the ARCH (Myron Stowe) [1687935]
- [md] md: convert to kvmalloc (Nigel Croxon) [1661200]
- [md] raid1: simplify raid1_error function (Nigel Croxon) [1661200]
- [md] md-linear: use struct_size() in kzalloc() (Nigel Croxon) [1661200]
- [md] md/raid5: fix 'out of memory' during raid cache recovery (Nigel Croxon) [1661200]
- [md] md: Make bio_alloc_mddev use bio_alloc_bioset (Nigel Croxon) [1661200]
- [md] raid10: refactor common wait code from regular read/write request (Nigel Croxon) [1661200]
- [md] md: remvoe redundant condition check (Nigel Croxon) [1661200]
- [lib] lib/raid6: add option to skip algo benchmarking (Nigel Croxon) [1661200]
- [include] lib/raid6: avoid __attribute_const__ redefinition (Nigel Croxon) [1661200]
- [include] lib/raid6: add missing include for raid6test (Nigel Croxon) [1661200]
- [md] md: remove set but not used variable 'bi_rdev' (Nigel Croxon) [1661200]
- [md] MD: Memory leak when flush bio size is zero (Nigel Croxon) [1661200]
- [md] md: fix memleak for mempool (Nigel Croxon) [1661200]
- [md] md-cluster: remove suspend_info (Nigel Croxon) [1661200]
- [md] md-cluster: send BITMAP_NEEDS_SYNC message if reshaping is interrupted (Nigel Croxon) [1661200]
- [md] md-cluster/bitmap: don't call md_bitmap_sync_with_cluster during reshaping stage (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: don't call remove_and_add_spares during reshaping stage (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: call update_size in md_reap_sync_thread (Nigel Croxon) [1661200]
- [md] md-cluster: introduce resync_info_get interface for sanity check (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: support add disk under grow mode (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: resize all the bitmaps before start reshape (Nigel Croxon) [1661200]
- [md] MD: fix invalid stored role for a disk - try2 (Nigel Croxon) [1661200]
- [md] md/bitmap: use mddev_suspend/resume instead of ->quiesce() (Nigel Croxon) [1661200]
- [md] md: remove redundant code that is no longer reachable (Nigel Croxon) [1661200]
- [md] md: allow metadata updates while suspending an array - fix (Nigel Croxon) [1661200]
- [md] MD: fix invalid stored role for a disk (Nigel Croxon) [1661200]
- [md] md/raid10: Fix raid10 replace hang when new added disk faulty (Nigel Croxon) [1661200]
- [md] raid5: block failing device if raid will be failed (Nigel Croxon) [1661200]
- [md] md-cluster: release RESYNC lock after the last resync message (Nigel Croxon) [1661200]
- [md] RAID10 BUG_ON in raise_barrier when force is true and conf->barrier is 0 (Nigel Croxon) [1661200]
- [md] md/raid5-cache: disable reshape completely (Nigel Croxon) [1661200]
- [md] md/raid5: fix data corruption of replacements after originals dropped (Nigel Croxon) [1661200]
- [md] drivers/md/raid5: Do not disable irq on release_inactive_stripe_list() call (Nigel Croxon) [1661200]
- [md] drivers/md/raid5: Use irqsave variant of atomic_dec_and_lock() (Nigel Croxon) [1661200]
- [md] md/r5cache: remove redundant pointer bio (Nigel Croxon) [1661200]
- [md] md-cluster: don't send msg if array is closing (Nigel Croxon) [1661200]
- [md] md-cluster: show array's status more accurate (Nigel Croxon) [1661200]
- [md] md-cluster: clear another node's suspend_area after the copy is finished (Nigel Croxon) [1661200]
- [powerpc] KVM: PPC: Book3S HV: Add KVM stat largepages_[2M/1G] (Suraj Jitindar Singh) [1581563]
- [tools] perf mem/c2c: Fix perf_mem_events to support powerpc (Steve Best) [1685084]
- [powerpc] powerpc/perf: Add mem access events to sysfs (Steve Best) [1685084]
- [netdrv] net-next/hinic: replace disable_irq_nosync/enable_irq (Xiaojun Tan) [1668958]
- [powerpc] Fix access_ok() fallout for sparc32 and powerpc (Joe Lawrence) [1673980]
- [x86] Remove 'type' argument from access_ok() function (Joe Lawrence) [1673980]
- [arm64] arm64: move untagged_addr macro from uaccess.h to memory.h (Joe Lawrence) [1673980]
- [powerpc] powerpc/uaccess: fix warning/error with access_ok() (Joe Lawrence) [1673980]
- [netdrv] igb: shorten maximum PHC timecounter update interval (Corinna Vinschen) [1637098]
- [netdrv] igb: shorten maximum PHC timecounter update interval (Corinna Vinschen) [1637098]

* Sun Mar 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.3.el8]
- [rpmspec] redhat: speed up binary rpm compression (Denys Vlasenko) [1686921]
- [netdrv] net/mlx5e: RX, Verify MPWQE stride size is in range (Alaa Hleihel) [1683589]
- [fs] debugfs: Fix EPERM regression from kernel lockdown check (Lenny Szubowicz) [1686755]
- [infiniband] IB/hfi1: Close race condition on user context disable and close (Alex Estrin) [1682927]
- [rpmspec] redhat: parallelize modules compression (Denys Vlasenko) [1686404]
- [arm64] arm64: Add workaround for Fujitsu A64FX erratum 010001 (Mark Langsdorf) [1666951]
- [s390] vfio_ap: link the vfio_ap devices to the vfio_ap bus subsystem (Cornelia Huck) [1686044]
- [drm] drm/cirrus: fix connector leak at unload (Rob Clark) [1685773]
- [powerpc] powerpc/hugetlb: Handle mmap_min_addr correctly in get_unmapped_area callback (Steve Best) [1685181]
- [netdrv] net/mlx4_en: Force CHECKSUM_NONE for short ethernet frames (Alaa Hleihel) [1663914 1651509]
- [netdrv] net/mlx5e: Force CHECKSUM_UNNECESSARY for short ethernet frames (Alaa Hleihel) [1651509]
- [include] Fix RH_KABI_SET_SIZE to use dereference operator (Tony Camuso) [1670118]

* Thu Mar 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.2.el8]
- [x86] x86/tsc: Make calibration refinement more robust (David Arcari) [1686254]
- [powerpc] powerpc/hugetlb: Don't do runtime allocation of 16G pages in LPAR configuration (Steve Best) [1686756]
- [rpmspec] parallelize "make mrproper" (Denys Vlasenko) [1686865]
- [rpmspec] use "make -jN" (via _smp_mflags) for modules_install (Denys Vlasenko) [1686308]
- [fs] xfs: zero length symlinks are not valid (Carlos Maiolino) [1589618]
- [drm] drm/bufs: Fix Spectre v1 vulnerability (Rob Clark) [1663467]
- [drm] drm/ioctl: Fix Spectre v1 vulnerabilities (Rob Clark) [1663467]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.0 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Update 12.2.0.0 file copyrights to 2019 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix nvmet issues when link bounce under IO load (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct upcalling nvmet_fc transport during io done downcall (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix default driver parameter collision for allowing NPIV support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Rework locking on SCSI io completion (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Enable SCSI and NVME fc4s by default (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Resize cpu maps structures based on possible cpus (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Utilize new IRQ API when allocating MSI-X vectors (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Rework EQ/CQ processing to address interrupt coalescing (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: convert eq_delay to usdelay (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Support non-uniform allocation of MSIX vectors to hardware queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix setting affinity hints to correlate with hardware queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Allow override of hardware queue selection policies (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adapt partitioned XRI lists to efficient sharing (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Synchronize hardware queues with SCSI MQ interface (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Convert ring number to hardware queue for nvme wqe posting. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Move SCSI and NVME Stats to hardware queue structures (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adapt cpucheck debugfs logic to Hardware Queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: Remove unused FCP_XRI_ABORT_EVENT slowpath event (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Partition XRI buffer list across Hardware Queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Replace io_channels for nvme and fcp with general hdw_queues per cpu (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove extra vector and SLI4 queue for Expresslane (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Implement common IO buffers between NVME and SCSI (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: Remove excess check on NVME io submit code path (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: remove nrport from nvme command structure (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: no need to check return value of debugfs_create functions (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Update lpfc version to 12.0.0.10 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adding ability to reset chip via pci bus reset (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Add log messages to aid in debugging fc4type discovery issues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix discovery failure when PLOGI is defered (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update fault value on successful trunk events. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct MDS loopback diagnostics support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix link state reporting for trunking when adapter is offline (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: do not set queue->page_count to 0 if pc_sli4_params.wqpcnt is invalid (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.9 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix dif and first burst use in write commands (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix driver release of fw-logging buffers (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct topology type reporting on G7 adapters (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct code setting non existent bits in sli4 ABORT WQE (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Defer LS_ACC to FLOGI on point to point logins (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: ls_rjt erroneus FLOGIs (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Cap NPIV vports to 256 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix kernel Oops due to null pring pointers (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix a duplicate 0711 log message number. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix panic when FW-log buffsize is not initialized (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix block guard enablement on SLI3 adapters (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Use dma_zalloc_coherent (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.8 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: add Trunking support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Implement GID_PT on Nameserver query to support faster failover (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix odd recovery in duplicate FLOGIs in point-to-point (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct LCB RJT handling (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fcoe: Fix link down issue after 1000+ link bounces (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct errors accessing fw log (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Reset link or adapter instead of doing infinite nameserver PLOGI retry (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix LOGO/PLOGI handling when triggerd by ABTS Timeout event (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix lpfc_sli4_read_config return value check (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct speeds on SFP swap (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix remoteport access (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variables 'tgtp' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variable 'psli' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variables 'fc_hdr' and 'hw_page_size' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix spelling mistake "Resrouce" -> "Resource" (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: remove a bogus pci_dma_sync_single_for_device call (Dick Kennedy) [1665288]
- [netdrv] PCI/AER: Remove pci_cleanup_aer_uncorrect_error_status() calls (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Synchronize access to remoteport via rport (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variable 'sgl_size' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.7 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: add support to retrieve firmware logs (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: reduce locking when updating statistics (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix errors in log messages. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct invalid EQ doorbell write on if_type=6 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct irq handling via locks when taking adapter offline (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct soft lockup when running mds diagnostics (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct race with abort on completion path (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Raise nvme defaults to support a larger io and more connectivity (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: raise sg count for nvme to use available sg resources (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix GFT_ID and PRLI logic for RSCN (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: remove an unnecessary NULL check (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Default fdmi_on to on (Dick Kennedy) [1665288]
- [powerpc] powerpc/mm/hash: Increase vmalloc space with hash translation mode (Steve Best) [1676974]
- [net] sunrpc: fix 4 more call sites that were using stack memory with a scatterlist (Scott Mayhew) [1679183]
- [net] sunrpc: Don't use stack buffer with scatterlist (Scott Mayhew) [1679183]
- [powerpc] powerpc/pseries: Perform full re-add of CPU for topology update post-migration (Steve Best) [1678209]
- [fs] proc/stat: Make the interrupt statistics more efficient (Waiman Long) [1675168]
- [kernel] genirq: Avoid summation loops for /proc/stat (Waiman Long) [1675168]
- [powerpc] powerpc/pseries: fix EEH recovery of some IOV devices (Steve Best) [1676889]
- [block] nvme: lock NS list changes while handling command effects (David Milburn) [1672759]
- [powerpc] powerpc/radix: Fix kernel crash with mremap() (Steve Best) [1674186]
- [crypto] crypto: ccp - fix the SEV probe in kexec boot path (Gary Hook) [1658806]
- [netdrv] HDLC Frame Relay: mark driver unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] DLCI: mark driver unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] ethoc: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] dnet: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] dl2k: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] mark qla3xxx driver as unsupported (John Linville) [1658840]
- [netdrv] sfc: initialise found bitmap in efx_ef10_mtd_probe (Jarod Wilson) [1668656]
- [netdrv] sfc: suppress duplicate nvmem partition types in efx_ef10_mtd_probe (Jarod Wilson) [1668656]
- [netdrv] sfc: extend MTD support for newer hardware (Jarod Wilson) [1668656]
- [netdrv] sfc: add missing NVRAM partition types for EF10 (Jarod Wilson) [1668656]
- [netdrv] ibmvnic: Fix non-atomic memory allocation in IRQ context (Steve Best) [1671474]
- [netdrv] ibmvnic: Convert reset work item mutex to spin lock (Steve Best) [1671474]
- [powerpc] powerpc/pseries: Export raw per-CPU VPA data via debugfs (Steve Best) [1608797]
- [powerpc] powerpc/pseries: Export maximum memory value (Steve Best) [1608797]
- [netdrv] ibmveth: Do not process frames after calling napi_reschedule (Desnes Augusto Nunes do Rosario) [1635577]
- [cpufreq] cpufreq: powernv: Remove global pstate ramp-down timer in POWER9 (Steve Best) [1670030]
- [of] of: __of_detach_node() - remove node from phandle cache (Steve Best) [1669198]
- [of] of: of_node_get()/of_node_put() nodes held in phandle cache (Steve Best) [1669198]
- [edac] EDAC, sb_edac: Fix signedness bugs in *_get_ha() functions (Aristeu Rozanski) [1641574]
- [edac] EDAC, sb_edac: Fix reporting for patrol scrubber errors (Aristeu Rozanski) [1641574]
- [documentation] proc.txt: Adding 'HardwareCorrupted' field and description. (Prashant Dhamdhere) [1658233]
- [netdrv] qed: Fix command number mismatch between driver and the mfw (Chad Dupuis) [1663500]
- Revert "[redhat] switch secureboot kernel image signing to release keys" ("Herton R. Krzesinski")

* Wed Mar 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.1.el8]
- [arm64] revert "arm64: tlb: Avoid synchronous TLBIs when freeing page tables" (Christoph von Recklinghausen) [1685697]

* Wed Mar 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-79.1.el8]
- [firmware] drivers/firmware: psci_checker: stash and use topology_core_cpumask for hotplug tests (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: re-introduce numa mask check for scheduler MC selection (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: rename llc_siblings to align with other struct members (Josh Poimboeuf) [1687101]
- [arm64] arm64: smp: remove cpu and numa topology information when hotplugging out CPU (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: restrict updating siblings_masks to online cpus only (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: add support to remove cpu topology sibling masks (Josh Poimboeuf) [1687101]
- [arm64] arm64: numa: separate out updates to percpu nodeid and NUMA node cpumap (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: refactor reset_cpu_topology to add support for removing topology (Josh Poimboeuf) [1687101]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-78.1.el8]
- [fs] gfs2: Fix missed wakeups in find_insert_glock (Andreas Grunbacher) [1678907]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-77.1.el8]
- [firmware] efi: Reduce the amount of memblock reservations for persistent allocations (Bhupesh Sharma) [1682988]
- [firmware] efi: Permit multiple entries in persistent memreserve data structure (Bhupesh Sharma) [1682988]
- [kernel] cpu/hotplug: Create SMT sysfs interface for all arches (Josh Poimboeuf) [1686068]
- [net] netfilter: nft_set_hash: bogus element self comparison from deactivation path (Florian Westphal) [1678574]
- [net] netfilter: nft_set_hash: fix lookups with fixed size hash on big endian (Florian Westphal) [1678574]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-76.1.el8]
- [security] revert "Add a SysRq option to lift kernel lockdown" (Lenny Szubowicz) [1684348]
- [s390] s390/setup: fix boot crash for machine without EDAT-1 (Philipp Rudo) [1677357]
- [s390] s390/setup: fix early warning messages (Philipp Rudo) [1677357]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-75.1.el8]
- [netdrv] net: hns3: add 8 BD limit for tx flow (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: fix a SSU buffer checking bug (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: aligning buffer size in SSU to 256 bytes (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: getting tx and dv buffer size through firmware (Xiaojun Tan) [1676771]
- [net] netfilter: nf_nat_snmp_basic: add missing length checks in ASN.1 cbs (Florian Westphal) [1676602]
- [char] ipmi: fix use-after-free of user->release_barrier.rda (Xiaojun Tan) [1677550]
- [char] ipmi: Prevent use-after-free in deliver_response (Xiaojun Tan) [1677550]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-74.1.el8]
- [x86] revert "cpu/hotplug: Add SMT policy options" (Josh Poimboeuf) [1683690]
- [crypto] net: crypto set sk to NULL when af_alg_release (Neil Horman) [1679450] {CVE-2019-8912}
- [drm] drm/i915/gvt: update force-to-nonpriv register whitelist (Paul Lai) [1643972]
- [kernel] MODSIGN: Also check platform keyring in mod_verify_sig() (Lenny Szubowicz) [1568532]
- [kernel] Fix for module sig verification (Lenny Szubowicz) [1568532]
- [security] efi: Lock down the kernel if booted in secure boot mode (Lenny Szubowicz) [1568532]
- [firmware] efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode (Lenny Szubowicz) [1568532]
- [x86] Copy secure_boot flag in boot params across kexec reboot (Lenny Szubowicz) [1568532]
- [fs] debugfs: Restrict debugfs when the kernel is locked down (Lenny Szubowicz) [1568532]
- [mm] x86/mmiotrace: Lock down the testmmiotrace module (Lenny Szubowicz) [1568532]
- [kernel] Lock down module params that specify hardware parameters (eg. ioport) (Lenny Szubowicz) [1568532]
- [tty] Lock down TIOCSSERIAL (Lenny Szubowicz) [1568532]
- [pcmcia] Prohibit PCMCIA CIS storage when the kernel is locked down (Lenny Szubowicz) [1568532]
- [acpi] acpi: Disable ACPI table override if the kernel is locked down (Lenny Szubowicz) [1568532]
- [acpi] acpi: Ignore acpi_rsdp kernel param when the kernel has been locked down (Lenny Szubowicz) [1568532]
- [acpi] ACPI: Limit access to custom_method when the kernel is locked down (Lenny Szubowicz) [1568532]
- [x86] x86/msr: Restrict MSR access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [x86] x86: Lock down IO port access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [pci] PCI: Lock down BAR access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] uswsusp: Disable when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] hibernate: Disable when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] kexec_load: Disable at runtime if the kernel is locked down (Lenny Szubowicz) [1568532]
- [char] Restrict /dev/{mem, kmem, port} when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] MODSIGN: Enforce module signatures if the kernel is locked down (Lenny Szubowicz) [1568532]
- [security] Add a SysRq option to lift kernel lockdown (Lenny Szubowicz) [1568532]
- [security] Add the ability to lock down access to the running kernel image (Lenny Szubowicz) [1568532]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-73.1.el8]
- [net] tun: forbid iface creation with rtnl ops (Sabrina Dubroca) [1680969]
- [net] revert "bridge: do not add port to router list when receives query with source 0.0.0.0" (Hangbin Liu) [1679896]
- [net] sctp: walk the list of asoc safely (Marcelo Leitner) [1679920] {CVE-2019-8956}
- [net] netfilter: nf_nat: skip nat clash resolution for same-origin entries (Florian Westphal) [1677647]
- [net] netfilter: nf_conntrack: resolve clash for matching conntracks (Florian Westphal) [1677647]
- [net] netfilter: nf_tables: fix flush after rule deletion in the same batch (Phil Sutter) [1677672]
- [net] gro_cell: add napi_disable in gro_cells_destroy (Stefano Brivio) [1674408]
- [net] sctp: call gso_reset_checksum when computing checksum in sctp_gso_segment (Xin Long) [1669386]
- [net] ipvs: fix dependency on nf_defrag_ipv6 (Andrea Claudi) [1660808]
- [net] sctp: check and update stream->out_curr when allocating stream_out (Xin Long) [1651877]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-72.1.el8]
- [x86] cpu/hotplug: Add SMT policy options (Josh Poimboeuf) [1677405]

* Tue Mar 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-71.1.el8]
- [kernel] open the RHEL 8.1 development ("Herton R. Krzesinski")
- [pci] pci/quirks: Add quirk to reset nvgpu at boot for the Lenovo ThinkPad P50 (Lyude Paul) [1677022]
- [arm64] arm64, vmcoreinfo : Append 'MAX_USER_VA_BITS' to vmcoreinfo (Bhupesh Sharma) [1672962]
- [md] dm thin: fix bug where bio that overwrites thin block ignores FUA (Mike Snitzer) [1679211]
- [pci] PCI: Fix "try" semantics of bus and slot reset (Myron Stowe) [1662901]
- [acpi] acpi/nfit: Fix bus command validation (Jeff Moyer) [1673958]
- [pci] PCI/MSI: Return -ENOSPC from pci_alloc_irq_vectors_affinity() (Myron Stowe) [1667773]
- [fs] NFS: Don't use page_file_mapping after removing the page (Benjamin Coddington) [1664190]
- [fs] NFS: Fix up return value on fatal errors in nfs_page_async_flush() (Benjamin Coddington) [1664190]
- [md] md: fix raid10 hang issue caused by barrier (Xiao Ni) [1630921]
- [md] md/raid1: don't clear bitmap bits on interrupted recovery. (Xiao Ni) [1677360]
- [virt] kvm: fix kvm_ioctl_create_device() reference counting (CVE-2019-6974) (Paolo Bonzini) [1673843] {CVE-2019-6974}
- [block] blk-mq: fix a hung issue when fsync (Ming Lei) [1674399]
- [block] Revert "block: cover another queue enter recursion via BIO_QUEUE_ENTERED" (Ming Lei) [1673966]
- [tools] perf tools: Check for null when copying nsinfo. (Jiri Olsa) [1676451]
- [iommu] iommu/amd: Fix IOMMU page flush when detach device from a domain (Suravee Suthikulpanit) [1672476]

* Tue Feb 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-70.el8]
- [kernel] namespace: Add padding fix to user_table[] (Prarit Bhargava) [1677103]
- [x86] KVM: nVMX: unconditionally cancel preemption timer in free_nested (CVE-2019-7221) (Paolo Bonzini) [1673841] {CVE-2019-7221}
- [scsi] scsi: sd: fix entropy gathering for most rotational disks (Ewan Milne) [1676735]
- [scsi] scsi: sd: Contribute to randomness when running rotational device (Ewan Milne) [1676735]
- [rpmspec] Revert "Drop -doc subpackage" (Prarit Bhargava) [1657609]
- [net] svcrdma: Remove max_sge check at connect time (Don Dutile) [1638869]
- [net] svcrdma: Reduce max_send_sges (Don Dutile) [1638869]
- [arm64] arm64: mm: Introduce MAX_USER_VA_BITS definition (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Rewrite stale comment in asm/tlbflush.h (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Avoid synchronous TLBIs when freeing page tables (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Remove redundant !CONFIG_HAVE_RCU_TABLE_FREE code (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlbflush: Allow stride to be specified for __flush_tlb_range() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Justify non-leaf invalidation in flush_tlb_range() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Add DSB ISHST prior to TLBI in __flush_tlb_[kernel_]pgtable() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Use last-level invalidation in flush_tlb_kernel_range() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: EXPORT vabits_user to modules (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: fix ARM64_USER_VA_BITS_52 builds (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: Kconfig: Re-jig CONFIG options for 52-bit VA (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Allow forcing all userspace addresses to 52-bit (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: introduce 52-bit userspace support (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Prevent mismatched 52-bit VA support (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Offset TTBR1 to allow 52-bit PTRS_PER_PGD (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Define arch_get_mmap_end, arch_get_mmap_base (Christoph von Recklinghausen) [1672997]
- [firmware] arm64: mm: Introduce DEFAULT_MAP_WINDOW (Christoph von Recklinghausen) [1672997]
- [mm] mm: mmap: Allow for "high" userspace addresses (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: apply r/o permissions of VM areas to its linear alias as well (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: purge lazily unmapped vm regions before changing permissions (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Don't wait for completion of TLB invalidation when page aging (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: Use __pa_symbol() for set_swapper_pgd() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: Drop the unused cpu parameter (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: move runtime pgds to rodata (Christoph von Recklinghausen) [1672997]
- [mm] arm64/mm: use fixmap to modify swapper_pg_dir (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: Separate boot-time page tables from swapper_pg_dir (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: Pass ttbr1 as a parameter to __enable_mmu() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: fix erroneous warnings in page freeing functions (Christoph von Recklinghausen) [1672997]
- [mm] arm64: Implement page table free interfaces (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlbflush: Introduce __flush_tlb_kernel_pgtable (Christoph von Recklinghausen) [1672997]
- [lib] ioremap: Update pgtable free interfaces with addr (Christoph von Recklinghausen) [1672997]
- [mm] x86/mm: Disable ioremap free page handling on x86-PAE (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: KVM: Enable Common Not Private translations (Christoph von Recklinghausen) [1504991]
- [arm64] arm64: mm: Support Common Not Private translations (Christoph von Recklinghausen) [1504991]
- [kernel] cpu/hotplug: Fix "SMT disabled by BIOS" detection for KVM (Igor Mammedov) [1668147]
- [tools] perf tools: Compile perf with -g instead of -ggdb3 to workaround gdb crash (Jiri Olsa) [1667109]

* Thu Feb 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-69.el8]
- [fs] Revert "gfs2: Fix loop in gfs2_rbm_find" (Andreas Grunbacher) [1658528]
- [net] bpf: fix sanitation of alu op with pointer / scalar type from different paths (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: prevent out of bounds speculation on pointer arithmetic (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: move {prev_,}insn_idx into verifier env (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf/verifier: per-register parent pointers (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: restrict unknown scalars of mixed signed bounds for unprivileged (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: Simplify ptr_min_max_vals adjustment (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: fix inner map masking to prevent oob under speculation (Jiri Olsa) [1673631] {CVE-2019-7308}
- [include] KABI: struct class padding (Prarit Bhargava) [1670035]
- [include] KABI: struct timer_list padding (Prarit Bhargava) [1670035]
- [include] KABI: struct irq_domain padding (Prarit Bhargava) [1670035]
- [nvdimm] libnvdimm, pmem: Fix badblocks population for 'raw' namespaces (Jeff Moyer) [1672315]
- [netdrv] net/mlx5e: FPGA, fix Innova IPsec TX offload data path performance (Alaa Hleihel) [1648230]
- [kernel] exec: increase BINPRM_BUF_SIZE to 256 (Oleg Nesterov) [1447445]

* Wed Feb 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-68.el8]
- [include] KABI: struct kset padding (Prarit Bhargava) [1669796]
- [include] KABI: struct kobject and kobj_type padding (Prarit Bhargava) [1669796]
- [include] KABI: struct delayed_work padding (Prarit Bhargava) [1669796]
- [include] KABI: struct work_struct padding (Prarit Bhargava) [1669796]
- [include] KABI: struct hrtimer padding (Prarit Bhargava) [1669796]
- [include] KABI: struct user_namespace padding (Prarit Bhargava) [1669796]
- [include] KABI: struct resource padding (Prarit Bhargava) [1669796]
- [include] KABI: Protect device_driver struct (Prarit Bhargava) [1666316]
- [include] KABI: Protect radix functions (Prarit Bhargava) [1669079]
- [char] ipmi: msghandler: Fix potential Spectre v1 vulnerabilities (Tony Camuso) [1672582]
- [vhost] vhost: fix OOB in get_rx_bufs() (Jason Wang) [1668665] {CVE-2018-16880}

* Sat Feb 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-67.el8]
- [md] dm: don't use bio_trim() afterall (Mike Snitzer) [1673657]
- [md] dm: add memory barrier before waitqueue_active (Mike Snitzer) [1673110]
- [x86] x86: uaccess: Inhibit speculation past access_ok() in user_access_begin() (Joe Lawrence) [1670113] {CVE-2018-20669}
- [kernel] make 'user_access_begin()' do 'access_ok()' (Joe Lawrence) [1670113] {CVE-2018-20669}
- [drm] i915: fix missing user_access_end() in page fault exception case (Joe Lawrence) [1670113] {CVE-2018-20669}
- [drm] drm/i915: Force the slow path after a user-write error (Joe Lawrence) [1670113] {CVE-2018-20669}
- [x86] x86/microcode/amd: Don't falsely trick the late loading mechanism (David Arcari) [1654904]
- [fs] iomap: get/put the page in iomap_page_create/release() (Artem Savkov) [1664298]
- [scsi] scsi: qla2xxx: Add new FC-NVMe enable BIT to enable FC-NVMe feature (Himanshu Madhani) [1671569]
- [message] mptsas: pci-id table changes (Tomas Henzl) [1666730]
- [message] mptsas: Taint kernel if mptsas is loaded (Tomas Henzl) [1666730]
- [kernel] genirq/matrix: Improve target CPU selection for managed interrupts. (Gary Hook) [1669557]
- [kernel] irq/matrix: Spread managed interrupts on allocation (Gary Hook) [1669557]
- [kernel] irq/matrix: Split out the CPU selection code into a helper (Gary Hook) [1669557]
- [net] sit: check if IPv6 enabled before calling ip6_err_gen_icmpv6_unreach() (Stefano Brivio) [1671680]
- [net] geneve: should not call rt6_lookup() when ipv6 was disabled (Stefano Brivio) [1671680]
- [net] netfilter: physdev: relax br_netfilter dependency (Phil Sutter) [1650382]
- [net] netfilter: nf_tables: add NFTA_RULE_POSITION_ID to nla_policy (Phil Sutter) [1670563]
- [net] netfilter: nf_tables: Support RULE_ID reference in new rule (Phil Sutter) [1670563]
- [net] rtnetlink: fix incorrect handling of device stats passed to userspace (Ivan Vecera) [1668298]
- [net] netfilter: nf_tables: handle nft_object lookups via rhltable (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: prepare nft_object for lookups via hashtable (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: selective rule dump needs table to be specified (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: Fix for endless loop when dumping ruleset (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: Speed up selective rule dumps (Phil Sutter) [1659725]
- [net] exclude sock_reuseport from kABI protection (Paolo Abeni) [1665984]
- [include] KABI: struct device padding (Don Dutile) [1664445]
- [include] KABI: struct dma_map_ops padding (Don Dutile) [1664482]
- [kernel] swiotlb: clear io_tlb_start and io_tlb_end in swiotlb_exit (Don Dutile) [1664484]
- [kernel] dma-mapping: remove a few unused exports (Don Dutile) [1664484]
- [include] dma-mapping: properly stub out the DMA API for !CONFIG_HAS_DMA (Don Dutile) [1664484]
- [kernel] dma-mapping: remove dmam_{declare,release}_coherent_memory (Don Dutile) [1664484]
- [kernel] dma-mapping: implement dmam_alloc_coherent using dmam_alloc_attrs (Don Dutile) [1664484]
- [include] dma-mapping: implement dma_map_single_attrs using dma_map_page_attrs (Don Dutile) [1664484]
- [include] dma-mapping: fix flags in dma_alloc_wc (Don Dutile) [1664484]
- [include] dma-mapping: deprecate dma_zalloc_coherent (Don Dutile) [1664484]
- [arm64] arm64: default to the direct mapping in get_arch_dma_ops (Don Dutile) [1664484]
- [kernel] dma-mapping: fix inverted logic in dma_supported (Don Dutile) [1664484]
- [include] dma-mapping: bypass indirect calls for dma-direct (Don Dutile) [1664484]
- [kernel] dma-direct: merge swiotlb_dma_ops into the dma_direct code (Don Dutile) [1664484]
- [kernel] dma-direct: do not include SME mask in the DMA supported check (Don Dutile) [1664484]
- [kernel] dma-direct: use dma_direct_map_page to implement dma_direct_map_sg (Don Dutile) [1664484]
- [kernel] dma-direct: improve addressability error reporting (Don Dutile) [1664484]
- [kernel] dma-direct: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [xen] swiotlb: remove dma_mark_clean (Don Dutile) [1664484]
- [xen] swiotlb: remove SWIOTLB_MAP_ERROR (Don Dutile) [1664484]
- [xen] xen-swiotlb: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [kernel] swiotlb: Skip cache maintenance on map error (Don Dutile) [1664484]
- [kernel] swiotlb: add support for non-coherent DMA (Don Dutile) [1664484]
- [kernel] swiotlb: mark is_swiotlb_buffer static (Don Dutile) [1664484]
- [kernel] swiotlb: remove a pointless comment (Don Dutile) [1664484]
- [kernel] swiotlb: clean up reporting (Don Dutile) [1664484]
- [kernel] dma-direct: reject highmem pages from dma_alloc_from_contiguous (Don Dutile) [1664484]
- [kernel] dma-direct: provide page based alloc/free helpers (Don Dutile) [1664484]
- [include] dma-direct: Make DIRECT_MAPPING_ERROR viable for SWIOTLB (Don Dutile) [1664484]
- [kernel] dma-direct: respect DMA_ATTR_NO_WARN (Don Dutile) [1664484]
- [kernel] dma-direct: document the zone selection logic (Don Dutile) [1664484]
- [kernel] dma-direct: fix return value of dma_direct_supported (Don Dutile) [1664484]
- [kernel] dma-direct: always allow dma mask <= physiscal memory size (Don Dutile) [1664484]
- [kernel] dma-direct: implement complete bus_dma_mask handling (Don Dutile) [1664484]
- [kernel] dma-direct: refine dma_direct_alloc zone selection (Don Dutile) [1664484]
- [kernel] dma-direct: add an explicit dma_direct_get_required_mask (Don Dutile) [1664484]
- [kernel] kernel/dma/direct: take DMA offset into account in dma_direct_supported (Don Dutile) [1664484]
- [kernel] dma-mapping: factor out dummy DMA ops (Don Dutile) [1664484]
- [mm] arm64: dma-mapping: Fix FORCE_CONTIGUOUS buffer clearing (Don Dutile) [1664484]
- [iommu] iommu/dma-iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/vt-d: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/intel: small map_page cleanup (Don Dutile) [1664484]
- [iommu] intel-iommu: mark intel_dma_ops static (Don Dutile) [1664484]
- [iommu] ia64: remove iommu_dma_supported (Don Dutile) [1664484]
- [iommu] iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/dma: Use fast DMA domain lookup (Don Dutile) [1664484]
- [x86] x86/amd_gart: fix unmapping of non-GART mappings (Don Dutile) [1664484]
- [x86] x86/amd_gart: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [mm] arm64: remove the dummy_dma_ops mapping_error method (Don Dutile) [1664484]
- [powerpc] powerpc: Do not redefine NEED_DMA_MAP_STATE (Don Dutile) [1664484]
- [powerpc] powerpc/iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [s390] s390: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [kernel] dma-mapping: always build the direct mapping code (Don Dutile) [1664484]
- [kernel] dma-mapping: move dma_cache_sync out of line (Don Dutile) [1664484]
- [kernel] dma-mapping: move various slow path functions out of line (Don Dutile) [1664484]
- [base] dma-mapping: move dma_get_required_mask to kernel/dma (Don Dutile) [1664484]
- [base] dma-mapping: move dma_default_get_required_mask under ifdef (Don Dutile) [1664484]
- [include] dma-mapping: merge dma_unmap_page_attrs and dma_unmap_single_attrs (Don Dutile) [1664484]
- [include] dma-mapping: simplify the dma_sync_single_range_for_{cpu,device} implementation (Don Dutile) [1664484]
- [include] dma-mapping: return an error code from dma_mapping_error (Don Dutile) [1664484]
- [pci] dma-mapping: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [include] dma-mapping: provide a generic DMA_MAPPING_ERROR (Don Dutile) [1664484]
- [kernel] dma-mapping: move the arm64 noncoherent alloc/free support to common code (Don Dutile) [1664484]
- [mm] arm64: fix warnings without CONFIG_IOMMU_DMA (Don Dutile) [1664484]
- [arm64] arm64: use the generic swiotlb_dma_ops (Don Dutile) [1664484]
- [kernel] swiotlb: don't dip into swiotlb pool for coherent allocations (Don Dutile) [1664484]
- [kernel] swiotlb: refactor swiotlb_map_page (Don Dutile) [1664484]
- [kernel] swiotlb: use swiotlb_map_page in swiotlb_map_sg_attrs (Don Dutile) [1664484]
- [kernel] swiotlb: merge swiotlb_unmap_page and unmap_single (Don Dutile) [1664484]
- [kernel] swiotlb: remove the overflow buffer (Don Dutile) [1664484]
- [kernel] swiotlb: do not panic on mapping failures (Don Dutile) [1664484]
- [mm] arm64/dma-mapping: Mildly optimise non-coherent IOMMU ops (Don Dutile) [1664484]
- [iommu] iommu: Add fast hook for getting DMA domains (Don Dutile) [1664484]
- [iommu] iommu: Remove the ->map_sg indirection (Don Dutile) [1664484]
- [iommu] kernel/dma: remove unsupported gfp_mask parameter from dma_alloc_from_contiguous() (Don Dutile) [1664484]
- [mm] mm/cma: remove unsupported gfp_mask parameter from cma_alloc() (Don Dutile) [1664484]
- [kernel] dma-mapping: move the remap helpers to a separate file (Don Dutile) [1664484]
- [include] dma-mapping: fix return type of dma_set_max_seg_size() (Don Dutile) [1664484]
- [include] dma-mapping: translate __GFP_NOFAIL to DMA_ATTR_NO_WARN (Don Dutile) [1664484]
- [include] dma-debug: Check for drivers mapping invalid addresses in dma_map_single() (Don Dutile) [1664484]
- [base] dma-mapping: make the get_required_mask method available unconditionally (Don Dutile) [1664484]
- [xen] dma-mapping: support non-coherent devices in dma_common_get_sgtable (Don Dutile) [1664484]
- [kernel] dma-mapping: consolidate the dma mmap implementations (Don Dutile) [1664484]
- [kernel] dma-mapping: merge direct and noncoherent ops (Don Dutile) [1664484]
- [include] dma-mapping: move the dma_coherent flag to struct device (Don Dutile) [1664484]
- [include] dma-mapping: remove dma_deconfigure (Don Dutile) [1664484]
- [base] dma-mapping: remove dma_configure (Don Dutile) [1664484]
- [include] dma-mapping: relax warning for per-device areas (Don Dutile) [1664484]
- [kernel] dma-mapping: add the missing ARCH_HAS_SYNC_DMA_FOR_CPU_ALL declaration (Don Dutile) [1664484]
- [kernel] dma-noncoherent: add a arch_sync_dma_for_cpu_all hook (Don Dutile) [1664484]
- [block] deprecate elevator= kernel parameter (Jeff Moyer) [1665295]
- [rpmspec] kernel.spec: disable kabi checks until RC (=?UTF-8?q?=C4=8Cestm=C3=ADr=20Kalina?=) [1671007]
- [iommu] iommu/amd: Unmap all mapped pages in error path of map_sg (Jerry Snitselaar) [1668448]
- [iommu] iommu/amd: Call free_iova_fast with pfn in map_sg (Jerry Snitselaar) [1668448]

* Thu Feb 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-66.el8]
- [arm64] arm64, vmcoreinfo : Append 'MAX_PHYSMEM_BITS' to vmcoreinfo (Bhupesh Sharma) [1666679]
- [kernel] sched/debug: Initialize sd_sysctl_cpus if !CONFIG_CPUMASK_OFFSTACK (Joe Lawrence) [1667840]
- [init] Small change to the message about certified hardware (Steve Best) [1671765]
- [x86] x86/kdump: make the behavior of crashkernel=X consistent with kaslr (Pingfan Liu) [1640799]
- [x86] Add back support for Intel processors (Steve Best) [1670529]
- [net] SUNRPC: Clean up initialisation of the struct rpc_rqst (Benjamin Coddington) [1650494]
- [x86] KABI, x86/paravirt: Protect paravirt ops structures (Waiman Long) [1669957]
- [include] KABI: struct module padding (Prarit Bhargava) [1669480]
- [include] KABI: struct stack_trace_struct padding (Prarit Bhargava) [1669480]
- [documentation] iommu: Fix passthrough option documentation (Gary Hook) [1658391]
- [iommu] iommu: Add config option to set passthrough as default (Gary Hook) [1658391]
- [kernel] redhat: kernel: clean up taint flags (Jiri Benc) [1654313]

* Wed Feb 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-65.el8]
- [scsi] scsi: qedi: Add the CRC size within iSCSI NVM image (Charles Rose) [1670186]
- [fs] iomap: don't search past page end in iomap_is_partially_uptodate (Eric Sandeen) [1657588]
- [netdrv] cxgb4: update supported DCB version (Arjun Vynipadath) [1668571]
- [x86] kexec, KEYS: Make use of platform keyring for signature verify (Kairui Song) [1640486]
- [security] integrity, KEYS: add a reference to platform keyring (Kairui Song) [1640486]
- [security] efi: Allow the "db" UEFI variable to be suppressed (Kairui Song) [1640486]
- [security] efi: Import certificates from UEFI Secure Boot (Kairui Song) [1640486]
- [security] efi: Add an EFI signature blob parser (Kairui Song) [1640486]
- [include] efi: Add EFI signature data types (Kairui Song) [1640486]
- [security] integrity: Load certs to the platform keyring (Kairui Song) [1640486]
- [security] integrity: Define a trusted platform keyring (Kairui Song) [1640486]
- [security] security/integrity: remove unnecessary 'init_keyring' variable (Kairui Song) [1640486]
- [x86] Fix kexec forbidding kernels signed with keys in the secondary keyring to boot (Kairui Song) [1640486]
- [crypto] Replace magic for trusting the secondary keyring with #define (Kairui Song) [1640486]
- [acpi] acpi/nfit: Fix command-supported detection (Jeff Moyer) [1665812]
- [acpi] acpi/nfit: Block function zero DSMs (Jeff Moyer) [1665812]
- [md] dm: add missing trace_block_split() to __split_and_process_bio() (Mike Snitzer) [1645283]
- [md] dm: fix dm_wq_work() to only use __split_and_process_bio() if appropriate (Mike Snitzer) [1645283]
- [md] dm: fix redundant IO accounting for bios that need splitting (Mike Snitzer) [1645283]
- [md] dm: fix clone_bio() to trigger blk_recount_segments() (Mike Snitzer) [1645283]
- [block] block: cover another queue enter recursion via BIO_QUEUE_ENTERED (Mike Snitzer) [1645283]
- [md] dm thin: fix passdown_double_checking_shared_status() (Mike Snitzer) [1668039]
- [tools] bpftool: Fix prog dump by tag (Jiri Olsa) [1667305]
- [arm64] arm64: ftrace: Fix to enable syscall events on arm64 (Don Dutile) [1668035]
- [arm64] arm64: implement syscall wrappers (Don Dutile) [1668035]
- [arm64] arm64: convert compat wrappers to C (Don Dutile) [1668035]
- [arm64] arm64: use SYSCALL_DEFINE6() for mmap (Don Dutile) [1668035]
- [arm64] arm64: use {COMPAT,}SYSCALL_DEFINE0 for sigreturn (Don Dutile) [1668035]
- [arm64] arm64: remove in-kernel call to sys_personality() (Don Dutile) [1668035]
- [include] kernel: add ksys_personality() (Don Dutile) [1668035]
- [arm64] arm64: drop alignment from syscall tables (Don Dutile) [1668035]
- [arm64] arm64: entry: remove unused register aliases (Don Dutile) [1668035]
- [arm64] arm64: convert native/compat syscall entry to C (Don Dutile) [1668035]
- [arm64] arm64: svc: Ensure hardirq tracing is updated before return (Don Dutile) [1668035]
- [arm64] arm64: convert syscall trace logic to C (Don Dutile) [1668035]
- [arm64] arm64: move sve_user_{enable,disable} to <asm/fpsimd.h> (Don Dutile) [1668035]
- [arm64] arm64: kill change_cpacr() (Don Dutile) [1668035]
- [arm64] arm64: convert raw syscall invocation to C (Don Dutile) [1668035]
- [arm64] arm64: introduce syscall_fn_t (Don Dutile) [1668035]
- [arm64] arm64: remove sigreturn wrappers (Don Dutile) [1668035]
- [arm64] arm64: rseq: Implement backend rseq calls and select HAVE_RSEQ (Don Dutile) [1668035]
- [sound] ALSA: usb-audio: Add vendor and product name for Dell WD19 Dock (Jaroslav Kysela) [1664249]
- [infiniband] IB/hfi1: Fix an out-of-bounds access in get_hw_stats (Alex Estrin) [1667104]
- [infiniband] IB/hfi1: Incorrect sizing of sge for PIO will OOPs (Alex Estrin) [1667095]
- [drm] drm/nouveau: register backlight on pascal and newer (Ben Skeggs) [1664899]
- [drm] drm/nouveau/disp/gm200-: enforce identity-mapped SOR assignment for LVDS/eDP panels (Ben Skeggs) [1664899]
- [drm] drm/nouveau/disp: move eDP panel power handling (Ben Skeggs) [1664899]
- [drm] drm/nouveau/devinit: don't fail when PMU/PRE_OS is missing from VBIOS (Ben Skeggs) [1664899]
- [kernel] locking/rwsem: Fix (possible) missed wakeup (Waiman Long) [1668014]
- [kernel] futex: Fix (possible) missed wakeup (Waiman Long) [1668014]
- [kernel] sched/wake_q: Fix wakeup ordering for wake_q (Waiman Long) [1668014]
- [kernel] sched/wake_q: Document wake_q_add() (Waiman Long) [1668014]
- [kernel] sched/wait: Fix rcuwait_wake_up() ordering (Waiman Long) [1668014]
- [kernel] sched/Documentation: Update wake_up() & co. memory-barrier guarantees (Waiman Long) [1668014]
- [kvm] KVM: PPC: Book3S HV: Flush guest mappings when turning dirty tracking on/off (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Book3S HV: Cleanups - constify memslots, fix comments (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Book3S HV: Map single pages when doing dirty page logging (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Pass change type down to memslot commit function (Laurent Vivier) [1650386]
- [vhost] vhost: log dirty page correctly (Jason Wang) [1657578]
- [netdrv] netxen: taint as unsupported in RHEL8 (Tony Camuso) [1654825]
- [hid] HID: hiddev: fix potential Spectre v1 (Benjamin Tissoires) [1664611]
- [net] resort to custom code for sk_buff padding (Paolo Abeni) [1665984]
- [net] add padding to cipher_context (Paolo Abeni) [1665984]
- [net] add padding to tls_crypto_context (Paolo Abeni) [1665984]
- [net] add padding to ipv4_devconf (Paolo Abeni) [1665984]
- [net] ip6mr: Fix potential Spectre v1 vulnerability (Stefano Brivio) [1663472]
- [net] ipv4: Fix potential Spectre v1 vulnerability (Stefano Brivio) [1663472]
- [include] add KABI padding to file_system_type (Eric Sandeen) [1665320 1650565]
- [include] add KABI padding to multiple fs ops vectors (Eric Sandeen) [1665320]
- [fs] add KABI padding to dentry structure (Eric Sandeen) [1665320]
- [fs] add KABI padding to inode structure (Eric Sandeen) [1665320]
- [include] add KABI padding to file_lock structure (Eric Sandeen) [1665320]
- [include] KABI: add an iopoll method to struct file_operations (Eric Sandeen) [1665320]
- [sound] ALSA: emux: Fix potential Spectre v1 vulnerabilities (Jaroslav Kysela) [1663477]
- [sound] ALSA: pcm: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1663477]
- [sound] ALSA: rme9652: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1663477]
- [sound] ALSA: emu10k1: Fix potential Spectre v1 vulnerabilities (Jaroslav Kysela) [1663477]
- [powerpc] powerpc/tm: Unset MSR[TS] if not recheckpointing (Gustavo Duarte) [1663853]
- [netdrv] r8152: Add support for MAC address pass through on RTL8153-BND (Perry Yuan) [1658433]
- [hid] HID: debug: fix the ring buffer implementation (Tony Camuso) [1669469] {CVE-2019-3819}

* Wed Jan 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-64.el8]
- [netdrv] net: hns: Fix WARNING when hns modules installed (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Fix ping failed when use net bridge and send multicast (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Add mac pcs config when enable|disable mac (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Fix ntuple-filters status error. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Free irq when exit from abnormal branch (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Clean rx fbd when ae stopped. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Some registers use wrong address according to the datasheet. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: All ports can not work when insmod hns ko after rmmod. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Incorrect offset address used for some registers. (Xiaojun Tan) [1662120]
- [include] ipmi: RH_KABI macros to pad kabi exposed structs (Tony Camuso) [1658175]
- [scsi] reserve space in structures for KABI (Ewan Milne) [1664397]

* Sat Jan 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-63.el8]
- [include] PCI: Add reserved fields to 'struct hotplug_slot' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct hotplug_slot_ops' (Myron Stowe) [1663534]
- [pci] PCI: Add reserved fields to 'struct pci_sriov' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct pci_driver' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct pci_bus' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields, and extension, to 'struct pci_dev' (Myron Stowe) [1663534]
- [pci] PCI: Add missing include to drivers/pci.h (Myron Stowe) [1663534]
- [pci] PCI/IOV: Use VF0 cached config space size for other VFs (Myron Stowe) [1663534]
- [include] PCI: always include 'p2pdma' in 'struct pci_dev' (Myron Stowe) [1663534]
- [ata] PCI: Remove pci_set_dma_max_seg_size() (Myron Stowe) [1663534]
- [pci] PCI: Remove pci_set_dma_seg_boundary() (Myron Stowe) [1663534]
- [include] PCI: Remove pci_unmap_addr() wrappers for DMA API (Myron Stowe) [1663534]
- [pci] PCI/AER: Abstract AER interrupt handling (Myron Stowe) [1663534]
- [pci] PCI: Uninline PCI bus accessors for better ftracing (Myron Stowe) [1663534]
- [pci] PCI/portdrv: Add runtime PM hooks for port service drivers (Myron Stowe) [1663534]
- [pci] PCI: Make link active reporting detection generic (Myron Stowe) [1663534]
- [block] block: don't lose track of REQ_INTEGRITY flag (Ming Lei) [1665684]
- [nvme] nvme-pci: fix nvme_setup_irqs() (Ming Lei) [1661439]
- [lib] sbitmap: Protect swap_lock from hardirq (Ming Lei) [1666192]
- [lib] sbitmap: Protect swap_lock from softirqs (Ming Lei) [1666192]
- [scsi] scsi: isci: initialize shost fully before calling scsi_add_host() (Ming Lei) [1664918]
- [nvme] nvmet-fc: Mark NVMe/FC target mode driver as unsupported (Ewan Milne) [1664838]
- [netdrv] bnx2x: Assign unique DMAE channel number for FW DMAE transactions. (Jonathan Toppins) [1638306]
- [fs] block: don't use un-ordered __set_current_state(TASK_UNINTERRUPTIBLE) (Ming Lei) [1664580]
- [netdrv] qed: Wait for ready indication before rereading the shmem (Chad Dupuis) [1652417]
- [netdrv] qed: Avoid sending mailbox commands when MFW is not responsive (Chad Dupuis) [1652417]
- [netdrv] qed: Wait for MCP halt and resume commands to take place (Chad Dupuis) [1652417]
- [netdrv] qed: Prevent a possible deadlock during driver load and unload (Chad Dupuis) [1652417]
- [fs] gfs2: Fix loop in gfs2_rbm_find (Andreas Grunbacher) [1658528]
- [fs] gfs2: Get rid of potential double-freeing in gfs2_create_inode (Andreas Grunbacher) [1658539]

* Thu Jan 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-62.el8]
- [vhost] vhost/vsock: fix vhost vsock cid hashing inconsistent (Stefan Hajnoczi) [1619848] {CVE-2018-14625}
- [vhost] vhost/vsock: fix use-after-free in network stack callers (Stefan Hajnoczi) [1619848] {CVE-2018-14625}
- [netdrv] bnx2x: Add VF spoof-checking configuration (Jonathan Toppins) [1646842]
- [netdrv] net-next: hinic: fix a problem in free_tx_poll() (Xiaojun Tan) [1642016]
- [netdrv] net: hns: fix for unmapping problem when SMMU is on (Xiaojun Tan) [1640526]
- [netdrv] net: hns: add netif_carrier_off before change speed and duplex (Xiaojun Tan) [1640526]
- [netdrv] net: hns: add the code for cleaning pkt in chip (Xiaojun Tan) [1640526]
- [netdrv] net: hns: modify variable type in hns_nic_reuse_page (Xiaojun Tan) [1640526]

* Wed Jan 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-61.el8]
- [irqchip] Mark GICv2 deprecated (Wei Huang) [1609391]
- [scsi] qla2xxx: Use correct number of vectors for online CPUs (Himanshu Madhani) [1644058]
- [scsi] megaraid_sas: mark Aero controllers as tech preview (Tomas Henzl) [1659972]
- [scsi] megaraid_sas: add retry logic in megasas_readl (Tomas Henzl) [1659972]
- [scsi] scsi: megaraid_sas: Introduce new Aero adapter type (Tomas Henzl) [1659972]
- [scsi] scsi: megaraid_sas: Fix Ventura series based checks (Tomas Henzl) [1659972]
- [scsi] scsi: libfc: retry PRLI if we cannot analyse the payload (Chris Leech) [1631843]
- [scsi] scsi: libfc: check fc_frame_payload_get() return value for null (Chris Leech) [1631843]
- [scsi] scsi: libfc: hold disc_mutex in fc_disc_stop_rports() (Chris Leech) [1631843]
- [scsi] scsi: libfc: fixup lockdep annotations (Chris Leech) [1631843]
- [scsi] scsi: libfc: fixup 'sleeping function called from invalid context' (Chris Leech) [1631843]
- [scsi] scsi: libfc: Add lockdep annotations (Chris Leech) [1631843]
- [md] dm crypt: fix parsing of extended IV arguments (Mike Snitzer) [1665290]
- [kernel] redhat: kabi: reserved padding for kernel sched data structures (Rafael Aquini) [1664858]
- [kernel] redhat: kabi: reserved padding for MM related data structures (Rafael Aquini) [1664858]
- [vfio] vfio/type1: Fix unmap overflow off-by-one (Alex Williamson) [1662291]
- [message] mptspi: pci-id table changes (Tomas Henzl) [1651803]
- [message] mptspi: Taint kernel if mptspi is loaded (Tomas Henzl) [1651803]
- [block] kabi: reserve space for public data structure (Ming Lei) [1551939]
- [block] kabi: reserve space for blk-mq related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for bsg related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for integrity related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for CONFIG_BLK_DEV_ZONED (Ming Lei) [1551939]
- [ata] ata: Disable AHCI ALPM feature for Ampere Computing eMAG SATA (David Milburn) [1663347]
- [kvm] KVM: x86: Add CPUID support for new instruction WBNOINVD (Andrew Jones) [1659491]
- [x86] KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup (Andrew Jones) [1659491]
- [virt] kvm: Change offset in kvm_write_guest_offset_cached to unsigned (Andrew Jones) [1659491]
- [virt] kvm: Disallow wraparound in kvm_gfn_to_hva_cache_init (Andrew Jones) [1659491]
- [kvm] KVM: x86: svm: report MSR_IA32_MCG_EXT_CTL as unsupported (Andrew Jones) [1659491]
- [virt] arm/arm64: KVM: Add ARM_EXCEPTION_IS_TRAP macro (Andrew Jones) [1659491]
- [arm64] arm64: KVM: Avoid setting the upper 32 bits of VTCR_EL2 to 1 (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Fix unintended stage 2 PMD mappings (Andrew Jones) [1659491]
- [virt] arm/arm64: KVM: vgic: Force VM halt when changing the active state of GICv3 PPIs/SGIs (Andrew Jones) [1659491]
- [arm64] KVM: arm/arm64: Fixup the kvm_exit tracepoint (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Consider priority and active state for pending irq (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Fix off-by-one bug in vgic_get_irq() (Andrew Jones) [1659491]
- [kvm] KVM: X86: Fix NULL deref in vcpu_scan_ioapic (Andrew Jones) [1659491]
- [kvm] KVM: Fix UAF in nested posted interrupt processing (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Cap SPIs to the VM-defined maximum (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Do not cond_resched_lock() with IRQs disabled (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic-v2: Set active_source to 0 when restoring state (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Fix VMID alloc race by reverting to lock-less (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Free the VMREAD/VMWRITE bitmaps if alloc_kvm_area() fails (Andrew Jones) [1659491]
- [kvm] arm64: KVM: Install stage-2 translation before enabling traps (Andrew Jones) [1659491]
- [kvm] arm64: KVM: Make VHE Stage-2 TLB invalidation operations non-interruptible (Andrew Jones) [1659491]
- [arm64] arm64: entry: Remove confusing comment (Andrew Jones) [1659491]
- [kvm] arm64: entry: Place an SB sequence following an ERET instruction (Andrew Jones) [1659491]
- [arm64] arm64: Add support for SB barrier and patch in over DSB; ISB sequences (Andrew Jones) [1659491]
- [kvm] kvm: nVMX: Set VM instruction error for VMPTRLD of unbacked page (Andrew Jones) [1659491]
- [kvm] kvm: svm: Ensure an IBPB on all affected CPUs when freeing a vmcb (Andrew Jones) [1659491]
- [kvm] kvm: mmu: Fix race in emulated page table writes (Andrew Jones) [1659491]
- [kvm] KVM: nVMX/nSVM: Fix bug which sets vcpu->arch.tsc_offset to L1 tsc_offset (Andrew Jones) [1659491]
- [kvm] KVM: VMX: Update shared MSRs to be saved/restored on MSR_EFER.LMA changes (Andrew Jones) [1659491]
- [kvm] KVM: x86: Fix kernel info-leak in KVM_HC_CLOCK_PAIRING hypercall (Andrew Jones) [1659491]
- [kvm] svm: Add mutex_lock to protect apic_access_page_done on AMD systems (Andrew Jones) [1659491]
- [kvm] KVM/nVMX: Do not validate that posted_intr_desc_addr is page aligned (Andrew Jones) [1659491]
- [kvm] KVM: arm64: Safety check PSTATE when entering guest and handle IL (Andrew Jones) [1659491]
- [virt] KVM: arm64: Fix caching of host MDCR_EL2 value (Andrew Jones) [1659491]
- [kvm] x86/kvm/nVMX: allow bare VMXON state migration (Andrew Jones) [1659491]
- [kvm] x86/kvm/lapic: preserve gfn_to_hva_cache len on cache reinit (Andrew Jones) [1659491]
- [kvm] KVM: hyperv: define VP assist page helpers (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: move check_vmentry_postreqs() call to nested_vmx_enter_non_root_mode() (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Always reflect #NM VM-exits to L1 (Andrew Jones) [1659491]
- [kvm] KVM: x86: hyperv: consistently use 'hv_vcpu' for 'struct kvm_vcpu_hv' variables (Andrew Jones) [1659491]
- [kvm] KVM: x86: hyperv: enforce vp_index < KVM_MAX_VCPUS (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: restore host state in nested_vmx_vmexit for VMFail (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Clear reserved bits of #DB exit qualification (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Ensure only THP is candidate for adjustment (Andrew Jones) [1659491]
- [kvm] x86: kvm: avoid unused variable warning (Andrew Jones) [1659491]
- [kvm] powerpc64/ftrace: Include ftrace.h needed for enable/disable calls (Andrew Jones) [1659491]
- [kvm] x86/kvm/vmx: Remove duplicate l1d flush definitions (Andrew Jones) [1659491]
- [tools] perf kvm: Fix subcommands on s390 (Andrew Jones) [1659491]
- [arm64] arm64: add PSR_AA32_* definitions (Andrew Jones) [1659491]
- [pci] PCI: hotplug: Document TODOs (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Embed hotplug_slot (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Drop hotplug_slot_info (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Constify hotplug_slot_ops (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Reshuffle controller struct for clarity (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Rename controller struct members for clarity (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Unify controller and slot structs (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Tolerate Presence Detect hardwired to zero (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Drop hotplug_slot_ops wrappers (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Drop unnecessary includes (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Differentiate between surprise and safe removal (Myron Stowe) [1664454]
- [pci] PCI: Simplify disconnected marking (Myron Stowe) [1664454]
- [tools] perf vendor events arm64: Revise core JSON events for eMAG (Jiri Olsa) [1663353]
- [tools] perf vendor events arm64: Enable JSON events for eMAG (Jiri Olsa) [1663353]
- [perf] drivers/perf: xgene: Add CPU hotplug support (Jiri Olsa) [1663349]
- [scsi] mpt3sas: mark Aero controllers as tech preview (Tomas Henzl) [1663281]
- [powerpc] KVM: PPC: Book3S HV: Keep rc bits in shadow pgtable in sync with host (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Introduce kvmhv_update_nest_rmap_rc_list() (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Apply combination of host and l1 pte rc for nested guest (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Align gfn to L1 page size when inserting nest-rmap entry (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Hold kvm->mmu_lock across updating nested pte rc bits (Suraj Jitindar Singh) [1662029]
- [tools] perf python: Do not force closing original perf descriptor in evlist.get_pollfd (Jiri Olsa) [1659445]
- [mm] mm: thp: relax __GFP_THISNODE for MADV_HUGEPAGE mappings (Andrea Arcangeli) [1613993]
- [rpmspec] spec: Add libperf-jvmti.so into perf debuginfo rpm (Jiri Olsa) [1653570]
- [scsi] scsi: hisi_sas: Fix spin lock management in slot_index_alloc_quirk_v2_hw() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Update v3 hw AIP_LIMIT and CFG_AGING_TIME register values (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Use block layer tag instead for IPTT (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: unmask interrupts ent72 and ent74 (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Free slot later in slot_complete_vx_hw() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Fix the race between IO completion and timeout for SMP/internal IO (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Move evaluation of hisi_hba in hisi_sas_task_prep() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Feed back linkrate(max/min) when re-attached (Xiaojun Tan) [1642819]
- [hwtracing] intel_th: pci: Add Ice Lake PCH support (Jiri Olsa) [1485529]

* Fri Jan 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-60.el8]
- [kernel] userns: also map extents in the reverse map to kernel IDs (Chris von Recklinghausen) [1652679] {CVE-2018-18955}
- [net] ipv6: route: Fix return value of ip6_neigh_lookup() on neigh_create() error (Stefano Brivio) [1662789]
- [net] ipv6: frags: Fix bogus skb->sk in reassembled packets (Herbert Xu) [1645839]
- [net] redhat: blacklist auto-loadable net modules in modules-extra (Marcelo Leitner) [1642795]
- [net] redhat: move sctp modules to kernel-modules-extra (Marcelo Leitner) [1642795]
- [net] add reserved fields to neighbour (Paolo Abeni) [1655084]
- [net] add reserved fields to rtnl_link_stats* (Paolo Abeni) [1655084]
- [net] reserve bits in netdev_features_t for future features (Paolo Abeni) [1655084]
- [net] add reserved fields to sk_buff (Paolo Abeni) [1655084]
- [net] add reserved fields to ipv6_devconf (Paolo Abeni) [1655084]
- [net] add reserved fields to fib_rule (Paolo Abeni) [1655084]
- [net] add reserved fields to sock (Paolo Abeni) [1655084]
- [net] add reserved fields to genl_family (Paolo Abeni) [1655084]
- [net] add reserved fields to proto_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to proto (Paolo Abeni) [1655084]
- [net] add reserved fields to genl_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to dst_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to dst_entry (Paolo Abeni) [1655084]
- [net] add reserved fields to lwtunnel_state (Paolo Abeni) [1655084]
- [net] add reserved fields to packet_type (Paolo Abeni) [1655084]
- [net] add reserved fields to napi_struct (Paolo Abeni) [1655084]
- [net] add reserved fields to net_device (Paolo Abeni) [1655084]
- [net] exclude wireless_dev from KABI protection (Paolo Abeni) [1655084]
- [net] add reserved fields to dcbnl_rtnl_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to xfrm_* (Paolo Abeni) [1655084]
- [net] add reserved fields to switchdev_obj (Paolo Abeni) [1655084]
- [net] add reserved fields to switchdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to l3mdev_ops (Paolo Abeni) [1655084]
- [net] exclude ndisc_ops from kABI protection (Paolo Abeni) [1655084]
- [net] add reserved fields to xfrmdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to tlsdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to netdev_rx_queue (Paolo Abeni) [1655084]
- [net] add reserved fields to netdev_queue (Paolo Abeni) [1655084]
- [net] add reserved fields to rtnl_link_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to ethtool_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to header_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to net_device_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to flowi* structs (Paolo Abeni) [1655084]
- [arm64] KVM: arm64: Clarify explanation of STAGE2_PGTABLE_LEVELS (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] KVM: arm/arm64: Rename kvm_arm_config_vm to kvm_arm_setup_stage2 (Christoph von Recklinghausen) [1643586 1643522]
- [virt] KVM: arm64: Drop __cpu_init_stage2 on the VHE path (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Allow tuning the physical address size for VM (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Limit the minimum number of page table levels (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm64: Set a limit on the IPA size (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Add 52bit support for PAR to HPFAR conversoin (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Switch to per VM IPA limit (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Configure VTCR_EL2.SL0 per VM (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Dynamic configuration of VTTBR mask (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Make stage2 page table layout dynamic (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Prepare for dynamic stage2 page table layout (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm/arm64: Prepare for VM specific stage2 translations (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Configure VTCR_EL2 per VM (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Allow arch specific configurations for VM (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Clean up VTCR_EL2 initialisation (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] arm64: Add a helper for PARange to physical shift conversion (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Add helper for loading the stage2 setting for a VM (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Remove spurious WARN_ON (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Fix stage2_flush_memslot for 4 level page table (Christoph von Recklinghausen) [1643586 1643522]
- [hv] hv_balloon: avoid touching uninitialized struct page during tail onlining (Vitaly Kuznetsov) [1662277]
- [x86] Mark AMD EPYC guests as supported (David Arcari) [1663356]
- [netdrv] be2net: Disable queue dump in be_tx_timeout handler (Petr Oros) [1646838]
- [vhost] vhost: Fix Spectre V1 vulnerability (Jason Wang) [1663469]
- [mm] mm/hugetlb.c: teach follow_hugetlb_page() to handle FOLL_NOWAIT (Andrea Arcangeli) [1575028]
- [tools] cpupower: Fix AMD Family 0x17 msr_pstate size (Prarit Bhargava) [1659883]
- [tools] cpupower: Fix coredump on VMWare (Prarit Bhargava) [1659883]
- [scsi] scsi: csiostor: remove flush_scheduled_work() (Arjun Vynipadath) [1663973]
- [powerpc] KVM: PPC: Book3S HV: Fix race between kvm_unmap_hva_range and MMU mode switch (David Gibson) [1663225]
- [fs] userfaultfd: check VM_MAYWRITE was set after verifying the uffd is registered (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: UFFDIO_COPY: set the page dirty if VM_WRITE is not set (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: add i_size checks (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem/hugetlbfs: only allow to register VM_MAYWRITE vmas (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: allocate anonymous memory for MAP_PRIVATE shmem (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: use ENOENT instead of EFAULT if the atomic copy user fails (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: allow get_mempolicy(MPOL_F_NODE|MPOL_F_ADDR) to trigger userfaults (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] userfaultfd: clear flag if remap event not enabled (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] userfaultfd: disable irqs when taking the waitqueue lock (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] fs/userfaultfd.c: remove redundant pointer uwq (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] NFS: nfs_compare_mount_options always compare auth flavors. (Steve Dickson) [1661619]
- [infiniband] RDMA/hns: Bugfix for RoCE loopback test (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Update posting & querying mailbox (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Fix the bug while use multi-hop of pbl (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Init qp context when modify qp from reset to init (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Bugfix pbl configuration for rereg mr (Xiaojun Tan) [1663359]
- [security] selinux: add support for RTM_NEWCHAIN, RTM_DELCHAIN, and RTM_GETCHAIN (Ondrej Mosnacek) [1660564]
- [scsi] scsi: megaraid_sas: driver version update (Tomas Henzl) [1656261]
- [scsi] scsi: megaraid_sas: Use 63-bit DMA addressing (Tomas Henzl) [1656261]
- [x86] x86/kvm: mark as TechPreview when running as a nested hypervisor (Vitaly Kuznetsov) [1519039]
- [rpmspec] kernel.spec: Fix kernel-tools files section logic (Prarit Bhargava) [1661247]
- [crypto] crypto: ccp - Make function sev_get_firmware() static (Gary Hook) [1632894]
- [crypto] crypto: ccp - Allow SEV firmware to be chosen based on Family and Model (Gary Hook) [1632894]
- [crypto] crypto: ccp - Fix static checker warning (Gary Hook) [1632894]
- [crypto] crypto: ccp - add timeout support in the SEV command (Gary Hook) [1632894]
- [nvdimm] nvdimm: Use namespace index data to reduce number of label reads needed (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Split label init out from the logic for getting config data (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Remove empty if statement (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Clarify comment in sizeof_namespace_index (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Sanity check labeloff (Jeff Moyer) [1634345]
- [nvdimm] libnvdimm, dimm: Maximize label transfer size (Jeff Moyer) [1634345]
- [mm] mm/page-writeback.c: fix range_cyclic writeback vs writepages deadlock (Brian Foster) [1659528]
- [input] Input: elantech - disable elan-i2c for P52 and P72 (Benjamin Tissoires) [1658602]
- [fs] cachefiles: avoid deprecated get_seconds() (David Howells) [1655613]
- [fs] fscache, cachefiles: remove redundant variable 'cache' (David Howells) [1655613]
- [fs] cachefiles: Explicitly cast enumerated type in put_object (David Howells) [1655613]
- [fs] fscache: fix race between enablement and dropping of object (David Howells) [1655613]
- [fs] cachefiles: Fix page leak in cachefiles_read_backing_file while vmscan is active (David Howells) [1655613]
- [fs] fscache: Fix race in fscache_op_complete() due to split atomic_sub & read (David Howells) [1655613]
- [fs] cachefiles: Fix an assertion failure when trying to update a failed object (David Howells) [1655613]
- [fs] fscache: Fix out of bound read in long cookie keys (David Howells) [1655613]
- [fs] fscache: Fix incomplete initialisation of inline key space (David Howells) [1655613]
- [fs] cachefiles: fix the race between cachefiles_bury_object() and rmdir(2) (David Howells) [1655613]
- [kernel] ebpf: record usage of eBPF (Jiri Benc) [1654279]
- [kernel] add rh_features to /proc (Jiri Benc) [1654279]
- [kernel] add support for rh_features (Jiri Benc) [1654279]
- [fs] fs/lock: show locks taken by processes from another pidns (Miklos Szeredi) [1616125]
- [iommu] iommu/arm-smmu: Support non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm-v7s: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu: Add "iommu.strict" command line option (Xiaojun Tan) [1643114]
- [iommu] iommu/dma: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu: Ensure that page-table updates are visible before TLBI (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Implement flush_iotlb_all hook (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Avoid back-to-back CMD_SYNC operations (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Fix unexpected CMD_SYNC timeout (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm: Fix race handling in split_blk_unmap() (Xiaojun Tan) [1643114]
- [infiniband] RDMA/hns: Update some attributes of the RoCE device (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Limit the size of extend sge of sq (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Bugfix for CM test (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Submit bad wr when post send wr exception (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Bugfix for reserved qp number (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Refactor the codes for setting transport opode (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Move all prints out of irq handle (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix an error code in hns_roce_v2_init_eq_table() (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix usage of bitmap allocation functions return values (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Support flush cqe for hip08 in kernel space (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Program the tclass and flow label into the hardware (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Use macro instead of magic number (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Modify qp will return errno when qp type is illegal (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Assign the value for vlan field of qp context (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Only assgin the fields of the av if IB_QP_AV bit is set (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Enable modify_cq for uverbs. (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the data type of immediate data (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Use delay instead of usleep (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add illegal hop_num judgement (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add 50GE type of hnae3 device match (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Do not overwrite the error code during error unwind in hns_roce_init (Xiaojun Tan) [1639578]
- [infiniband] hns: Remove a set-but-not-used variable (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the implementation of set_mac (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the implementation of set_gid (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add TPQ link table support (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add TSQ link table support (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix endian conversions and annotations (Xiaojun Tan) [1639578]
- [scsi] scsi: hisi_sas: Add SATA FIS check for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: add memory barrier in task delivery function (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Tidy hisi_sas_task_prep() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Implement handlers of PCIe FLR for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: relocate some common code for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: tidy host controller reset function a bit (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Fix the failure of recovering PHY from STP link timeout (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: tidy channel interrupt handler for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Drop hisi_sas_slot_abort() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Update a couple of register settings for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Add missing PHY spinlock init (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Pre-allocate slot DMA buffers (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Release all remaining resources in clear nexus ha (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Add a flag to filter PHY events during reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Adjust task reject period during host reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Fix the conflict between dev gone and host reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Only process broadcast change in phy_bcast_v3_hw() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Use dmam_alloc_coherent() (Zhou Wang) [1639541]
- [netdrv] xen/netfront: fix waiting for xenbus state change (Petr Oros) [1638456]

* Thu Jan 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-59.el8]
- [x86] expand cpu feature/bug bits (David Arcari) [1662434]
- [x86] add kabi support for cpuinfo_x86 (David Arcari) [1662434]
- [init] Display a message about certified hardware (Steve Best) [1660523]
- [scsi] scsi: t10-pi: Return correct ref tag when queue has no integrity profile (Ming Lei) [1660719]
- [scsi] scsi: storvsc: Fix a race in sub-channel creation that can cause panic (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: set callbacks on open (Mohammed Gamal) [1650149]
- [hv] vmbus: fix subchannel removal (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: defer opening vmbus until first use (Mohammed Gamal) [1650149]
- [hv] vmbus: split ring buffer allocation from open (Mohammed Gamal) [1650149]
- [hv] vmbus: pass channel to hv_process_channel_removal (Mohammed Gamal) [1650149]
- [hv] Drivers: hv: vmbus: Reset the channel callback in vmbus_onoffer_rescind() (Mohammed Gamal) [1650149]
- [uio] hv_uio_generic: map ringbuffer phys addr (Mohammed Gamal) [1650149]
- [uio] uio: introduce UIO_MEM_IOVA (Mohammed Gamal) [1650149]
- [hv] vmbus: add driver_override support (Mohammed Gamal) [1650149]
- [hv] vmbus: keep pointer to ring buffer page (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: increase size of receive and send buffers (Mohammed Gamal) [1650149]
- [uio] uio: add SPDX license tags (Mohammed Gamal) [1650149]
- [fs] gfs2: take jdata unstuff into account in do_grow (Robert S Peterson) [1660519]
- [drm] drm/dp_mst: Check if primary mstb is null (Lyude Paul) [1658711]
- [tools] perf tests: Use shebangs in the shell scripts (Michael Petlan) [1613523]

* Mon Jan 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-58.el8]
- [mm] mm: put_and_wait_on_page_locked() while page is migrated (Baoquan He) [1649214]
- [netdrv] i40e: define proper net_device::neigh_priv_len (Stefan Assmann) [1658743]
- [netdrv] i40e: fix VLAN.TCI == 0 RX HW offload (Stefan Assmann) [1658743]
- [netdrv] i40e: fix mac filter delete when setting mac address (Stefan Assmann) [1658743]
- [netdrv] i40e: prevent overlapping tx_timeout recover (Stefan Assmann) [1658743]
- [netdrv] i40e: Use correct shift for VLAN priority (Stefan Assmann) [1658743]
- [netdrv] i40e: always set ks->base.speed in i40e_get_settings_link_up (Stefan Assmann) [1658743]
- [netdrv] i40e: don't restart nway if autoneg not supported (Stefan Assmann) [1658743]
- [netdrv] i40e: enable NETIF_F_NTUPLE and NETIF_F_HW_TC at driver load (Stefan Assmann) [1658743]
- [netdrv] i40e: restore NETIF_F_GSO_IPXIP[46] to netdev features (Stefan Assmann) [1658743]
- [acpi] ACPI/APEI: Clear GHES block_status before panic() (David Arcari) [1662442]
- [misc] VMCI: Resource wildcard match fixed (Vitaly Kuznetsov) [1652868]
- [mm] mm/page_alloc.c: don't call kasan_free_pages() at deferred mem init (Waiman Long) [1655964]
- [block] block/bio: Do not zero user pages (Ming Lei) [1662502]
- [vhost] disable zerocopy by default (Jason Wang) [1582756]
- [block] kyber: use sbitmap add_wait_queue/list_del wait helpers (Ming Lei) [1661426]
- [lib] sbitmap: add helpers for add/del wait queue handling (Ming Lei) [1661426]
- [net] Revert "sunrpc: Ensure we always close the socket after a connection shuts down" (Dave Wysochanski) [1657449]
- [vhost] vhost/vsock: fix reset orphans race with close timeout (Stefan Hajnoczi) [1660445]
- [misc] genwqe: Fix size check (Steve Best) [1660126]
- [fs] aio: fix spectre gadget in lookup_ioctx (Jeff Moyer) [1660963]
- [block] block: save irq state in blkg_lookup_create() (Ming Lei) [1660299]
- [md] dm: don't reuse bio for flushes (Ming Lei) [1660401]
- [wireless] mac80211_hwsim: Fix possible Spectre-v1 for hwsim_world_regdom_custom (Stanislaw Gruszka) [1637113]
- [wireless] nl80211: Fix possible Spectre-v1 for NL80211_TXRATE_HT (Stanislaw Gruszka) [1637113]
- [wireless] nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds (Stanislaw Gruszka) [1637113]
- [block] blk-mq: enable IO poll if .nr_queues of type poll > 0 (Ming Lei) [1660826]
- [powerpc] powerpc/rtas: Fix a potential race between CPU-Offline & Migration (Desnes Augusto Nunes do Rosario) [1639266]
- [x86] kvm: x86: Add AMD's EX_CFG to the list of ignored MSRs (Eduardo Habkost) [1625111]
- [scsi] scsi_sysfs: make unpriv_sgio queue attribute accessible for non-block devices (Paolo Bonzini) [1584504]
- [block] scsi_ioctl: introduce unpriv_sgio queue flag (Paolo Bonzini) [1584504]
- [block] scsi_ioctl: pass request_queue to blk_verify_command (Paolo Bonzini) [1584504]
- [fs] ext4: missing !bh check in ext4_xattr_inode_write() (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in __ext4_read_dirblock() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_expand_extra_isize_ea() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_xattr_move_to_block() on error path (Lukas Czerner) [1659481]
- [fs] ext4: release bs.bh before re-using in ext4_xattr_block_find() (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_xattr_get_block() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix possible leak of s_journal_flag_rwsem in error path (Lukas Czerner) [1659481]
- [fs] ext4: fix possible leak of sbi->s_group_desc_leak in error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid possible double brelse() in add_new_gdb() on error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid buffer leak in ext4_orphan_add() after prior errors (Lukas Czerner) [1659481]
- [fs] ext4: avoid buffer leak on shutdown in ext4_mark_iloc_dirty() (Lukas Czerner) [1659481]
- [fs] ext4: fix possible inode leak in the retry loop of ext4_resize_fs() (Lukas Czerner) [1659481]
- [fs] ext4: fix missing cleanup if ext4_alloc_flex_bg_array() fails while resizing (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() update_backups()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() add_new_gdb_meta_bg()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() in set_flexbg_block_bitmap()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid potential extra brelse in setup_new_flex_group_blocks() (Lukas Czerner) [1659481]
- [scsi] scsi: lpfc: Enable Management features for IF_TYPE=6 (Dick Kennedy) [1658755]
- [scsi] scsi: mpt3sas: Update driver version to 27.101.00.00 (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Replace readl with ioc->base_readl (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Add separate function for aero doorbell reads (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Introduce flag for aero based controllers (Tomas Henzl) [1659035]
- [md] dm: do not allow readahead to limit IO size (Mike Snitzer) [1658757]
- [md] dm raid: fix false -EBUSY when handling check/repair message (Mike Snitzer) [1658757]
- [block] blk-mq: change blk_mq_queue_busy() to blk_mq_queue_inflight() (Mike Snitzer) [1658757]
- [md] dm rq: cleanup leftover code from recently removed q->mq_ops branching (Mike Snitzer) [1658757]
- [md] dm verity: log the hash algorithm implementation (Mike Snitzer) [1658757]
- [md] dm crypt: log the encryption algorithm implementation (Mike Snitzer) [1658757]
- [md] dm integrity: fix spelling mistake in workqueue name (Mike Snitzer) [1658757]
- [md] dm flakey: Properly corrupt multi-page bios. (Mike Snitzer) [1658757]
- [md] dm: Check for device sector overflow if CONFIG_LBDAF is not set (Mike Snitzer) [1658757]
- [md] dm crypt: use u64 instead of sector_t to store iv_offset (Mike Snitzer) [1658757]
- [md] dm kcopyd: Fix bug causing workqueue stalls (Mike Snitzer) [1658757]
- [md] dm snapshot: Fix excessive memory usage and workqueue stalls (Mike Snitzer) [1658757]
- [md] dm bufio: update comment in dm-bufio.c (Mike Snitzer) [1658757]
- [md] dm writecache: fix typo in error msg for creating writecache_flush_thread (Mike Snitzer) [1658757]
- [md] dm: remove indirect calls from __send_changing_extent_only() (Mike Snitzer) [1658757]
- [md] dm mpath: only flush workqueue when needed (Mike Snitzer) [1658757]
- [md] dm: avoid indirect call in __dm_make_request (Mike Snitzer) [1658757]
- [md] dm thin: bump target version (Mike Snitzer) [1658757]
- [md] dm thin: send event about thin-pool state change _after_ making it (Mike Snitzer) [1658757]
- [md] dm cache metadata: verify cache has blocks in blocks_are_clean_separate_dirty() (Mike Snitzer) [1658757]
- [md] dm writecache: remove disabled code in memory_entry() (Mike Snitzer) [1658757]
- [md] dm raid: avoid bitmap with raid4/5/6 journal device (Mike Snitzer) [1658757]
- [md] dm crypt: make workqueue names device-specific (Mike Snitzer) [1658757]
- [md] dm: add dm_table_device_name() (Mike Snitzer) [1658757]
- [md] dm ioctl: harden copy_params()'s copy_from_user() from malicious users (Mike Snitzer) [1658757]
- [md] dm: remove unnecessary unlikely() around WARN_ON_ONCE() (Mike Snitzer) [1658757]
- [md] dm thin: use refcount_t for thin_c reference counting (Mike Snitzer) [1658757]
- [netdrv] nfp: provide a better warning when ring allocation fails (Pablo Cascon) [1645456]
- [netdrv] nfp: use kvcalloc() to allocate SW buffer descriptor arrays (Pablo Cascon) [1645456]
- [scsi] scsi: lpfc: rport port swap discovery issue. (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: Fix discovery failures during port failovers with lots of vports (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: refactor mailbox structure context fields (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: Correct loss of fc4 type on remote port address change (Dick Kennedy) [1656635]
- [hid] HID: multitouch: Add pointstick support for Cirque Touchpad (Perry Yuan) [1656673]
- [powerpc] KVM: PPC: Book3S HV: Fix handling for interrupted H_ENTER_NESTED (Suraj Jitindar Singh) [1649980]
- [powerpc] powerpc: Select CONFIG_SWIOTLB (Gustavo Duarte) [1648466]
- [fs] nfs: Fix a missed page unlock after pg_doio() (Benjamin Coddington) [1651287]
- [arm64] arm64: fix possible spectre-v1 write in ptrace_hbp_set_event() (Mark Salter) [1637585]
- [fs] fsnotify: Fix busy inodes during unmount (Lukas Czerner) [1650462]
- [tools] perf vendor events arm64: Update ThunderX2 implementation defined pmu core events (Robert Richter) [1501638]
- [tools] perf tools: Fix undefined symbol scnprintf in libperf-jvmti.so (Jiri Olsa) [1579484]

* Tue Dec 18 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-57.el8]
- [block] blk-mq: export hctx->type in debugfs instead of sysfs (Ming Lei) [1660040]
- [block] blk-mq: fix dispatch from sw queue (Ming Lei) [1660040]
- [block] blk-mq: skip zero-queue maps in blk_mq_map_swqueue (Ming Lei) [1660040]
- [nvme] nvme-pci: don't share queue maps (Ming Lei) [1660040]
- [block] blk-mq: only dispatch to non-defauly queue maps if they have queues (Ming Lei) [1660040]
- [x86] KVM: LAPIC: Fix pv ipis use-before-initialization (Paul Lai) [1657702]
- [fs] autofs: fix directory and symlink access (Ian Kent) [1611967]
- [infiniband] IB/iser: Fix possible NULL deref at iser_inv_desc() (Don Dutile) [1657574]
- [infiniband] RDMA/core: Fix unwinding flow in case of error to register device (Don Dutile) [1657574]
- [infiniband] IB/rxe: fix for duplicate request processing and ack psns (Don Dutile) [1657574]
- [infiniband] IB/ipoib: Clear IPCB before icmp_send (Don Dutile) [1657574]
- [infiniband] RDMA/core: Do not expose unsupported counters (Don Dutile) [1657574]
- [infiniband] IB/ucm: Fix Spectre v1 vulnerability (Don Dutile) [1657574]
- [infiniband] RDMA/ucma: Fix Spectre v1 vulnerability (Don Dutile) [1657574]
- [infiniband] RDMA/uverbs: Don't overwrite NULL pointer with ZERO_SIZE_PTR (Don Dutile) [1657574]
- [infiniband] RDMA/cma: Do not ignore net namespace for unbound cm_id (Don Dutile) [1657574]
- [net] xprtrdma: Reset credit grant properly after a disconnect (Don Dutile) [1657574]
- [input] Input: hyper-v - fix wakeup from suspend-to-idle (Vitaly Kuznetsov) [1588888]
- [kernel] kernel: hung_task.c: disable on suspend (Vitaly Kuznetsov) [1588888]
- [kernel] redhat: add a comment with warning about RH_KABI_EXCLUDE usage (Jiri Benc) [1656933]
- [rpmspec] Sign the aarch64 kernel (Jeremy Linton) [1659158]

* Mon Dec 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-56.el8]
- [netdrv] nfp: flower: add geneve option match offload (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: add geneve option push action offload (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: offload tos and tunnel flags for ipv4 udp tunnels (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: set ip tunnel ttl from encap action (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: extract ipv4 udp tunnel ttl from route (Pablo Cascon) [1655604]
- [net] sctp: hold transport before accessing its asoc in sctp_transport_get_next (Marcelo Leitner) [1656271]
- [net] sctp: fix the data size calculation in sctp_data_size (Marcelo Leitner) [1656271]
- [net] sctp: fix race on sctp_id2asoc (Marcelo Leitner) [1656271]
- [net] rtnetlink: ndo_dflt_fdb_dump() only work for ARPHRD_ETHER devices (Hangbin Liu) [1657120]
- [netdrv] mlx5e: fix csum adjustments caused by RXFCS (Hangbin Liu) [1657120]
- [net] drop skb on failure in ip_check_defrag() (Hangbin Liu) [1657120]
- [net] rtnl_configure_link: fix dev flags changes arg to __dev_notify_flags (Hangbin Liu) [1657120]
- [net] socket: fix a missing-check bug (Hangbin Liu) [1657120]
- [net] rtnetlink: Disallow FDB configuration for non-Ethernet device (Hangbin Liu) [1657120]
- [net] rtnetlink: Fail dump if target netnsid is invalid (Hangbin Liu) [1657120]
- [net] rtnetlink: fix rtnl_fdb_dump() for ndmsg header (Hangbin Liu) [1657120]
- [net] rtnl: limit IFLA_NUM_TX_QUEUES and IFLA_NUM_RX_QUEUES to 4096 (Hangbin Liu) [1657120]
- [net] socket: fix struct ifreq size in compat ioctl (Hangbin Liu) [1657120]
- [net] fix pskb_trim_rcsum_slow() with odd trim offset (Hangbin Liu) [1657120]
- [net] gso_segment: Reset skb->mac_len after modifying network header (Hangbin Liu) [1657120]
- [net] Use __kernel_clockid_t in uapi net_stamp.h (Davide Caratti) [1638022]
- [net] tun: Consistently configure generic netdev params via rtnetlink (Matteo Croce) [1657910]
- [net] tun: napi flags belong to tfile (Matteo Croce) [1657910]
- [net] tun: initialize napi_mutex unconditionally (Matteo Croce) [1657910]
- [net] tun: remove unused parameters (Matteo Croce) [1657910]
- [net] team: Forbid enslaving team device to itself (Matteo Croce) [1658725]
- [net] sched: Remove TCA_OPTIONS from policy (Davide Caratti) [1658516]
- [net] sched: cls_api: add missing validation of netlink attributes (Davide Caratti) [1658516]
- [net] sched: gred: pass the right attribute to gred_change_table_def() (Davide Caratti) [1658516]
- [net] sched: cls_u32: fix hnode refcounting (Davide Caratti) [1658516]
- [net] sched: Add policy validation for tc attributes (Davide Caratti) [1658516]
- [net] bpf: use __GFP_COMP while allocating page (Andrea Claudi) [1658231]
- [net] xsk: do not call synchronize_net() under RCU read lock (Andrea Claudi) [1658231]
- [net] bpf: fix partial copy of map_ptr when dst is scalar (Andrea Claudi) [1658231]
- [net] bpf: Fix bpf_msg_pull_data() (Andrea Claudi) [1658231]
- [net] bpf: fix shift upon scatterlist ring wrap-around in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix sg shift repair start offset in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix msg->data/data_end after sg shift repair in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix several offset tests in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] vlan: add support for tunnel offload (Andrea Claudi) [1656804]
- [net] 8021q: move vlan offload registrations into vlan_core (Hangbin Liu) [1657658]
- [net] ipv6/ndisc: Preserve IPv6 control buffer if protocol error handlers are called (Stefano Brivio) [1658010]
- [net] ipv6: Allow onlink routes to have a device mismatch if it is the default route (Stefano Brivio) [1658010]
- [net] ipv6: Fix index counter for unicast addresses in in6_dump_addrs (Stefano Brivio) [1658010]
- [net] ipv6: mcast: fix a use-after-free in inet6_mc_check (Stefano Brivio) [1658010]
- [net] ipv6: rate-limit probes for neighbourless routes (Stefano Brivio) [1658010]
- [net] ipv6: stop leaking percpu memory in fib6 info (Stefano Brivio) [1658010]
- [net] ipv6: Remove extra call to ip6_convert_metrics for multipath case (Stefano Brivio) [1658010]
- [net] ipv6: Display all addresses in output of /proc/net/if_inet6 (Stefano Brivio) [1658010]
- [net] ipv6: do not copy dst flags on rt init (Stefano Brivio) [1658010]
- [net] ipv6: Only update MTU metric if it set (Stefano Brivio) [1658010]
- [net] ipv6: don't get lwtstate twice in ip6_rt_copy_init() (Stefano Brivio) [1658010]
- [net] ipv6: Put lwtstate when destroying fib6_info (Stefano Brivio) [1658010]
- [net] ip6_tunnel: Fix encapsulation layout (Stefano Brivio) [1658008]
- [net] vxlan: fill ttl inherit info (Stefano Brivio) [1658008]
- [net] ip_tunnel: be careful when accessing the inner header (Stefano Brivio) [1658008]
- [net] vti6: remove !skb->ignore_df check from vti6_xmit() (Stefano Brivio) [1658008]
- [net] ip6_vti: fix a null pointer deference when destroy vti6 tunnel (Stefano Brivio) [1658008]
- [net] ip6_vti: fix creating fallback tunnel device for vti6 (Stefano Brivio) [1658008]
- [net] ip_vti: fix a null pointer deferrence when create vti fallback tunnel (Stefano Brivio) [1658008]
- [net] l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache (Stefano Brivio) [1658008]
- [net] macsec: let the administrator set UP state even if lowerdev is down (Sabrina Dubroca) [1645540]
- [net] macsec: update operstate when lower device changes (Sabrina Dubroca) [1645540]
- [net] tcp: do not restart timewait timer on rst reception (Paolo Abeni) [1657988]
- [net] tcp: really ignore MSG_ZEROCOPY if no SO_ZEROCOPY (Paolo Abeni) [1657988]
- [net] tcp, ulp: add alias for all ulp modules (Paolo Abeni) [1657988]
- [net] tcp, ulp: fix leftover icsk_ulp_ops preventing sock from reattach (Paolo Abeni) [1657988]
- [net] ipv4: tcp: send zero IPID for RST and ACK sent in SYN-RECV and TIME-WAIT state (Paolo Abeni) [1657988]
- [net] neighbour: Avoid writing before skb->head in neigh_hh_output() (Stefano Brivio) [1643336]
- [net] ipv6: Check available headroom in ip6_xmit() even without options (Stefano Brivio) [1643336]
- [net] ipv6: fix possible use-after-free in ip6_xmit() (Stefano Brivio) [1643336]
- [net] openvswitch: Fix push/pop ethernet validation (Hangbin Liu) [1657226]
- [net] cgroup, netclassid: add a preemption point to write_classid (Hangbin Liu) [1657226]
- [net] ethtool: fix a privilege escalation bug (Hangbin Liu) [1657226]
- [net] llc: set SOCK_RCU_FREE in llc_sap_add_socket() (Hangbin Liu) [1657226]
- [net] dcb: For wild-card lookups, use priority -1, not 0 (Hangbin Liu) [1657226]
- [net] packet: fix packet drop as of virtio gso (Hangbin Liu) [1657226]
- [net] netlabel: check for IPV4MASK in addrinfo_get (Hangbin Liu) [1657226]
- [net] netfilter: seqadj: re-load tcp header pointer after possible head reallocation (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: avoid BUG_ON usage (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: deactivate expressions in rule replecement routine (Florian Westphal) [1654259]
- [net] netfilter: nat: fix double register in masquerade modules (Florian Westphal) [1654259]
- [net] netfilter: add missing error handling code for register functions (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: fix use-after-free when deleting compat expressions (Florian Westphal) [1654259]
- [net] netfilter: xt_RATEEST: remove netns exit routine (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: don't use position attribute on rule replacement (Florian Westphal) [1654259]
- [net] revert "netfilter: nft_numgen: add map lookups for numgen random operations" (Florian Westphal) [1654259]
- [net] netfilter: xt_IDLETIMER: add sysfs filename checking routine (Florian Westphal) [1654259]
- [net] netfilter: conntrack: fix calculation of next bucket number in early_drop (Florian Westphal) [1654259]
- [net] netfilter: conntrack: get rid of double sizeof (Florian Westphal) [1654259]
- [net] netfilter: nft_set_rbtree: add missing rb_erase() in GC routine (Florian Westphal) [1654259]
- [net] netfilter: nfnetlink_queue: Solve the NFQUEUE/conntrack clash for NF_REPEAT (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: release chain in flushing set (Florian Westphal) [1654259]
- [net] netfilter: xt_checksum: ignore gso skbs (Florian Westphal) [1654259]
- [net] netfilter: xt_cluster: add dependency on conntrack module (Florian Westphal) [1654259]
- [net] netfilter: fix memory leaks on netlink_dump_start error (Florian Westphal) [1654259]
- [net] netfilter: x_tables: do not fail xt_alloc_table_info too easilly (Florian Westphal) [1654259]
- [net] ipvs: fix race between ip_vs_conn_new() and ip_vs_del_dest() (Florian Westphal) [1654259]
- [net] netfilter: ip6t_rpfilter: set F_IFACE for linklocal addresses (Florian Westphal) [1654259]
- [net] xfrm: policy: use hlist rcu variants on insert (Sabrina Dubroca) [1657272]
- [net] xfrm: validate template mode (Sabrina Dubroca) [1657272]
- [net] xfrm: Fix NULL pointer dereference when skb_dst_force clears the dst_entry. (Sabrina Dubroca) [1657272]
- [net] xfrm: reset transport header back to network header after all input transforms ahave been applied (Sabrina Dubroca) [1657272]
- [net] xfrm: reset crypto_done when iterating over multiple input xfrms (Sabrina Dubroca) [1657272]
- [net] xfrm: Validate address prefix lengths in the xfrm selector. (Sabrina Dubroca) [1657272]
- [net] tls: fix currently broken MSG_PEEK behavior (Sabrina Dubroca) [1657225]
- [net] tls: zero the crypto information from tls_context before freeing (Sabrina Dubroca) [1657225]
- [net] tls: clear key material from kernel memory when do_tls_setsockopt_conf fails (Sabrina Dubroca) [1657225]
- [net] tls: don't copy the key out of tls12_crypto_info_aes_gcm_128 (Sabrina Dubroca) [1657225]
- [net] tls: Set count of SG entries if sk_alloc_sg returns -ENOSPC (Sabrina Dubroca) [1657225]
- [net] tls: possible hang when do_tcp_sendpages hits sndbuf is full case (Sabrina Dubroca) [1657225]
- [net] tls: Fix improper revert in zerocopy_from_iter (Sabrina Dubroca) [1657225]
- [net] tls: Fix zerocopy_from_iter iov handling (Sabrina Dubroca) [1657225]
- [net] netfilter: conntrack: reset tcp maxwin on re-register (Florian Westphal) [1647310]
- [net] configs: Enable CONFIG_IP_SET_HASH_IPMAC as a module (Stefano Brivio) [1655301]
- [net] udp: fix handling of CHECKSUM_COMPLETE packets (Paolo Abeni) [1655656]
- [net] udp: Unbreak modules that rely on external __skb_recv_udp() availability (Paolo Abeni) [1655656]
- [net] udp6: fix encap return code for resubmitting (Paolo Abeni) [1655656]
- [net] team: no need to do team_notify_peers or team_mcast_rejoin when disabling port (Hangbin Liu) [1653197]
- [net] sctp: not increase stream's incnt before sending addstrm_in request (Xin Long) [1651428]
- [net] sctp: not allow to set asoc prsctp_enable by sockopt (Xin Long) [1647272]
- [net] revert "sctp: remove sctp_transport_pmtu_check" (Xin Long) [1643330]
- [net] fix XPS static_key accounting (Ivan Vecera) [1651781]
- [net] restore call to netdev_queue_numa_node_write when resetting XPS (Ivan Vecera) [1651781]
- [net] allow fallback function to pass netdev (Ivan Vecera) [1651781]
- [net] allow ndo_select_queue to pass netdev (Ivan Vecera) [1651781]
- [net] Add generic ndo_select_queue functions (Ivan Vecera) [1651781]
- [net] Add support for subordinate traffic classes to netdev_pick_tx (Ivan Vecera) [1651781]
- [net] ixgbe: Add code to populate and use macvlan TC to Tx queue map (Ivan Vecera) [1651781]
- [net] Add support for subordinate device traffic classes (Ivan Vecera) [1651781]
- [net] net-sysfs: Drop support for XPS and traffic_class on single queue device (Ivan Vecera) [1651781]
- [net] Provide stub for __netif_set_xps_queue if there is no CONFIG_XPS (Ivan Vecera) [1651781]
- [net] allow to call netif_reset_xps_queues() under cpus_read_lock (Ivan Vecera) [1651781]
- [net] documentation: Add explanation for XPS using Rx-queue(s) map (Ivan Vecera) [1651781]
- [net] net-sysfs: Add interface for Rx queue(s) map per Tx queue (Ivan Vecera) [1651781]
- [net] Enable Tx queue selection based on Rx queues (Ivan Vecera) [1651781]
- [net] Record receive queue number for a connection (Ivan Vecera) [1651781]
- [net] sock: Change tx_queue_mapping in sock_common to unsigned short (Ivan Vecera) [1651781]
- [net] Use static_key for XPS maps (Ivan Vecera) [1651781]
- [net] Refactor XPS for CPUs and Rx queues (Ivan Vecera) [1651781]
- [net] devlink: Add helper function for safely copy string param (Ivan Vecera) [1647914]
- [net] devlink: Fix param cmode driverinit for string type (Ivan Vecera) [1647914]
- [net] devlink: Fix param set handling for string type (Ivan Vecera) [1647914]
- [net] devlink: Add Documentation/networking/devlink-params-bnxt.txt (Ivan Vecera) [1647914]
- [net] devlink: Add Documentation/networking/devlink-params.txt (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter msix_vec_per_pf_min (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter msix_vec_per_pf_max (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter ignore_ari (Ivan Vecera) [1647914]
- [net] devlink: double free in devlink_resource_fill() (Ivan Vecera) [1647914]
- [net] devlink: Add extack for eswitch operations (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameters region_snapshot (Ivan Vecera) [1647914]
- [net] devlink: Add support for region snapshot read command (Ivan Vecera) [1647914]
- [net] devlink: Add support for region snapshot delete command (Ivan Vecera) [1647914]
- [net] devlink: Extend the support querying for region snapshot IDs (Ivan Vecera) [1647914]
- [net] devlink: Add support for region get command (Ivan Vecera) [1647914]
- [net] devlink: Add support for creating region snapshots (Ivan Vecera) [1647914]
- [net] devlink: Add callback to query for snapshot id before snapshot create (Ivan Vecera) [1647914]
- [net] devlink: Add support for creating and destroying regions (Ivan Vecera) [1647914]
- [net] devlink: fix incorrect return statement (Ivan Vecera) [1647914]
- [net] devlink: Add enable_sriov boolean generic parameter (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameters internal_err_reset and max_macs (Ivan Vecera) [1647914]
- [net] devlink: Add devlink notifications support for params (Ivan Vecera) [1647914]
- [net] devlink: Add support for get/set driverinit value (Ivan Vecera) [1647914]
- [net] devlink: Add param set command (Ivan Vecera) [1647914]
- [net] devlink: Add param get command (Ivan Vecera) [1647914]
- [net] devlink: Add devlink_param register and unregister (Ivan Vecera) [1647914]
- [net] ipvs: call ip_vs_dst_notifier earlier than ipv6_dev_notf (Xin Long) [1645064]
- [net] ipv6: fix a dst leak when removing its exception (Xin Long) [1645064]
- [net] netfilter: ipset: list:set: Decrease refcount synchronously on deletion and replace (Stefano Brivio) [1649089]
- [net] bridge: remove ipv6 zero address check in mcast queries (Hangbin Liu) [1639666]
- [net] bridge: do not add port to router list when receives query with source 0.0.0.0 (Hangbin Liu) [1639666]
- [net] netfilter: ipv6: fix oops when defragmenting locally generated fragments (Florian Westphal) [1642341]
- [net] xfrm6: call kfree_skb when skb is toobig (Sabrina Dubroca) [1628851]
- [net] sched: act_police: fix memory leak in case of invalid control action (Ivan Vecera) [1638022]
- [net] sched: act_police: add missing spinlock initialization (Ivan Vecera) [1638022]
- [net] netfilter: xt_socket: check sk before checking for netns. (Ivan Vecera) [1638022]
- [net] sched: act_police: fix race condition on state variables (Ivan Vecera) [1638022]
- [net] sched: cls_flower: validate nested enc_opts_policy to avoid warning (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix memory leak when IDR allocation fails (Ivan Vecera) [1638022]
- [net] configs: disable CAKE, ETF & SKBPRIO qdisc in config (Ivan Vecera) [1638022]
- [net] tc-tests: test denial of 'goto chain' for exceed traffic in police.json (Ivan Vecera) [1638022]
- [net] tc-tests: test denial of 'goto chain' on 'random' traffic in gact.json (Ivan Vecera) [1638022]
- [net] sched: act_police: disallow 'goto chain' on fallback control action (Ivan Vecera) [1638022]
- [net] sched: act_gact: disallow 'goto chain' on fallback control action (Ivan Vecera) [1638022]
- [net] net_sched: fix a crash in tc_new_tfilter() (Ivan Vecera) [1638022]
- [net] core: make function ___gnet_stats_copy_basic() static (Ivan Vecera) [1638022]
- [net] net_sched: convert idrinfo->lock from spinlock to a mutex (Ivan Vecera) [1638022]
- [net] loopback: clear skb->tstamp before netif_rx() (Ivan Vecera) [1638022]
- [net] skbuff: preserve sock reference when scrubbing the skb. (Ivan Vecera) [1638022]
- [net] netfilter: check if the socket netns is correct. (Ivan Vecera) [1638022]
- [net] sched: make function qdisc_free_cb() static (Ivan Vecera) [1638022]
- [net] sched: use reference counting for tcf blocks on rules update (Ivan Vecera) [1638022]
- [net] sched: implement tcf_block_refcnt_{get|put}() (Ivan Vecera) [1638022]
- [net] sched: protect block idr with spinlock (Ivan Vecera) [1638022]
- [net] sched: implement functions to put and flush all chains (Ivan Vecera) [1638022]
- [net] sched: change tcf block reference counter type to refcount_t (Ivan Vecera) [1638022]
- [net] sched: use Qdisc rcu API instead of relying on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: add helper function to take reference to Qdisc (Ivan Vecera) [1638022]
- [net] sched: extend Qdisc with rcu (Ivan Vecera) [1638022]
- [net] sched: rename qdisc_destroy() to qdisc_put() (Ivan Vecera) [1638022]
- [net] core: netlink: add helper refcount dec and lock function (Ivan Vecera) [1638022]
- [net] sched: act_ipt: check for underflow in __tcf_ipt_init() (Ivan Vecera) [1638022]
- [net] sched: Add hardware specific counters to TC actions (Ivan Vecera) [1638022]
- [net] core: Add new basic hardware counter (Ivan Vecera) [1638022]
- [net] net_sched: change tcf_del_walker() to take idrinfo->lock (Ivan Vecera) [1638022]
- [net] sched: Use FIELD_SIZEOF directly instead of reimplementing its function (Ivan Vecera) [1638022]
- [net] sched: act_sample: fix NULL dereference in the data path (Ivan Vecera) [1638022]
- [net] sched: act_police: don't use spinlock in the data path (Ivan Vecera) [1638022]
- [net] sched: act_police: use per-cpu counters (Ivan Vecera) [1638022]
- [net] net_sched: notify filter deletion when deleting a chain (Ivan Vecera) [1638022]
- [net] htb: use anonymous union for simplicity (Ivan Vecera) [1638022]
- [net] net_sched: remove redundant qdisc lock classes (Ivan Vecera) [1638022]
- [net] sched: cls_flower: dump offload count value (Ivan Vecera) [1638022]
- [net] net_sched: properly cancel netlink dump on failure (Ivan Vecera) [1638022]
- [net] sched: fix memory leak in act_tunnel_key_init() (Ivan Vecera) [1638022]
- [net] sched: action_ife: take reference to meta module (Ivan Vecera) [1638022]
- [net] act_ife: fix a potential use-after-free (Ivan Vecera) [1638022]
- [net] sched: act_nat: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_skbedit: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: null actions array pointer before releasing action (Ivan Vecera) [1638022]
- [net] sched: fix type of htb statistics (Ivan Vecera) [1638022]
- [net] net_sched: add missing tcf_lock for act_connmark (Ivan Vecera) [1638022]
- [net] revert "net: sched: act: add extack for lookup callback" (Ivan Vecera) [1638022]
- [net] tc-testing: add test-cases for numeric and invalid control action (Ivan Vecera) [1638022]
- [net] net_sched: reject unknown tcfa_action values (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix dump of extended layered op (Ivan Vecera) [1638022]
- [net] sched: return -ENOENT when trying to remove filter from non-existent chain (Ivan Vecera) [1638022]
- [net] sched: fix extack error message when chain is failed to be created (Ivan Vecera) [1638022]
- [net] sched: Fix memory exposure from short TCA_U32_SEL (Ivan Vecera) [1638022]
- [net] net_sched: fix unused variable warning in stmmac (Ivan Vecera) [1638022]
- [net] sch_cake: Fix TC filter flow override and expand it to hosts as well (Ivan Vecera) [1638022]
- [net] sch_cake: Remove unused including <linux/version.h> (Ivan Vecera) [1638022]
- [net] act_ife: fix a potential deadlock (Ivan Vecera) [1638022]
- [net] act_ife: move tcfa_lock down to where necessary (Ivan Vecera) [1638022]
- [net] revert "net: sched: act_ife: disable bh when taking ife_mod_lock" (Ivan Vecera) [1638022]
- [net] net_sched: remove unused tcfa_capab (Ivan Vecera) [1638022]
- [net] net_sched: remove list_head from tc_action (Ivan Vecera) [1638022]
- [net] net_sched: remove unused tcf_idr_check() (Ivan Vecera) [1638022]
- [net] net_sched: remove unused parameter for tcf_action_delete() (Ivan Vecera) [1638022]
- [net] net_sched: remove unnecessary ops->delete() (Ivan Vecera) [1638022]
- [net] net_sched: improve and refactor tcf_action_put_many() (Ivan Vecera) [1638022]
- [net] sched: always disable bh when taking tcf_lock (Ivan Vecera) [1638022]
- [net] sched: act_ife: always release ife action on init error (Ivan Vecera) [1638022]
- [net] cls_matchall: fix tcf_unbind_filter missing (Ivan Vecera) [1638022]
- [net] sched: act_ife: disable bh when taking ife_mod_lock (Ivan Vecera) [1638022]
- [net] sched: act_mirred method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_vlan method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_skbmod method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_skbedit method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_simple method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_police method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_pedit method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_nat method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_ipt method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_gact method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_sum method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_bpf method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_connmark method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_police: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] core: protect rate estimator statistics pointer with lock (Ivan Vecera) [1638022]
- [net] sched: act_mirred: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: extend action ops with put_dev callback (Ivan Vecera) [1638022]
- [net] sched: act_vlan: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_tunnel_key: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_skbmod: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_simple: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_sample: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_pedit: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_ipt: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_ife: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_gact: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_csum: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_bpf: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] tc: Update README and add config (Ivan Vecera) [1638022]
- [net] sched: fix block->refcnt decrement (Ivan Vecera) [1638022]
- [net] tc-tests: initial version of nat action unit tests (Ivan Vecera) [1638022]
- [net] sched: allow flower to match tunnel options (Ivan Vecera) [1638022]
- [net] flow_dissector: allow dissection of tunnel options from metadata (Ivan Vecera) [1638022]
- [net] tc-testing: remove duplicate spaces in skbedit match patterns (Ivan Vecera) [1638022]
- [net] tc-testing: remove duplicate spaces in connmark match patterns (Ivan Vecera) [1638022]
- [net] tc-testing: flush gact actions on test teardown (Ivan Vecera) [1638022]
- [net] tc-testing: fix ip address in u32 test (Ivan Vecera) [1638022]
- [net] sched: cls_flower: Fix an error code in fl_tmplt_create() (Ivan Vecera) [1638022]
- [net] sched: fix flush on non-existing chain (Ivan Vecera) [1638022]
- [net] sched: make tcf_chain_{get, put}() static (Ivan Vecera) [1638022]
- [net] sched: fix notifications for action-held chains (Ivan Vecera) [1638022]
- [net] sched: change name of zombie chain to "held_by_acts_only" (Ivan Vecera) [1638022]
- [net] act_mirred: use TC_ACT_REINSERT when possible (Ivan Vecera) [1638022]
- [net] tc: introduce TC_ACT_REINSERT. (Ivan Vecera) [1638022]
- [net] tc/act: remove unneeded RCU lock in action callback (Ivan Vecera) [1638022]
- [net] sched: user-space can't set unknown tcfa_action values (Ivan Vecera) [1638022]
- [net] Add and use skb_mark_not_on_list(). (Ivan Vecera) [1638022]
- [net] sch_netem: Move private queue handler to generic location. (Ivan Vecera) [1638022]
- [net] sch_htb: Remove local SKB queue handling code. (Ivan Vecera) [1638022]
- [net] act_bpf: Use kmemdup instead of duplicating it in tcf_bpf_init_from_ops (Ivan Vecera) [1638022]
- [net] cls_bpf: Use kmemdup instead of duplicating it in cls_bpf_prog_from_ops (Ivan Vecera) [1638022]
- [net] act_pedit: remove unnecessary semicolon (Ivan Vecera) [1638022]
- [net] sched: don't dump chains only held by actions (Ivan Vecera) [1638022]
- [net] sch_cake: Make gso-splitting configurable from userspace (Ivan Vecera) [1638022]
- [net] sched: unmark chain as explicitly created on delete (Ivan Vecera) [1638022]
- [net] sched: cls_api: fix dead code in switch (Ivan Vecera) [1638022]
- [net] sched: cls_flower: Use correct inline function for assignment of vlan tpid (Ivan Vecera) [1638022]
- [net] sched: fix trailing whitespace (Ivan Vecera) [1638022]
- [net] cbs: Add support for the graft function (Ivan Vecera) [1638022]
- [net] sched: add skbprio scheduler (Ivan Vecera) [1638022]
- [net] selftests: forwarding: add tests for TC chain templates (Ivan Vecera) [1638022]
- [net] selftests: forwarding: add tests for TC chains creation adn destruction (Ivan Vecera) [1638022]
- [net] selftests: forwarding: move shblock tc support check to a separate helper (Ivan Vecera) [1638022]
- [net] sched: cls_flower: propagate chain teplate creation and destruction to drivers (Ivan Vecera) [1638022]
- [net] sched: cls_flower: implement chain templates (Ivan Vecera) [1638022]
- [net] sched: cls_flower: change fl_init_dissector to accept mask and dissector (Ivan Vecera) [1638022]
- [net] sched: cls_flower: move key/mask dumping into a separate function (Ivan Vecera) [1638022]
- [net] sched: introduce chain templates (Ivan Vecera) [1638022]
- [net] sched: introduce chain object to uapi (Ivan Vecera) [1638022]
- [net] sched: Avoid implicit chain 0 creation (Ivan Vecera) [1638022]
- [net] sched: push ops lookup bits into tcf_proto_lookup_ops() (Ivan Vecera) [1638022]
- [net] nfp: bring back support for offloading shared blocks (Ivan Vecera) [1638022]
- [net] sched: use PTR_ERR_OR_ZERO macro in tcf_block_cb_register (Ivan Vecera) [1638022]
- [net] tc-tests: initial version of fw filter unit tests (Ivan Vecera) [1638022]
- [net] sch_cake: Fix tin order when set through skb->priority (Ivan Vecera) [1638022]
- [net] sched: act_skbedit: don't use spinlock in the data path (Ivan Vecera) [1638022]
- [net] sched: skbedit: use per-cpu counters (Ivan Vecera) [1638022]
- [net] tc-testing: add geneve options in tunnel_key unit tests (Ivan Vecera) [1638022]
- [net] sched: fix unprotected access to rcu cookie pointer (Ivan Vecera) [1638022]
- [net] sched: act_ife: fix memory leak in ife init (Ivan Vecera) [1638022]
- [net] sched: refactor flower walk to iterate over idr (Ivan Vecera) [1638022]
- [net] sched: flower: Fix null pointer dereference when run tc vlan command (Ivan Vecera) [1638022]
- [net] sched: Fix warnings from xchg() on RCU'd cookie pointer. (Ivan Vecera) [1638022]
- [net] cls_flower: fix error values for commands not supported by drivers (Ivan Vecera) [1638022]
- [net] nfp: handle cls_flower command default case (Ivan Vecera) [1638022]
- [net] bnxt: simplify cls_flower command switch and handle default case (Ivan Vecera) [1638022]
- [net] sch_cake: Conditionally split GSO segments (Ivan Vecera) [1638022]
- [net] sch_cake: Add overhead compensation support to the rate shaper (Ivan Vecera) [1638022]
- [net] sch_cake: Add DiffServ handling (Ivan Vecera) [1638022]
- [net] sch_cake: Add NAT awareness to packet classifier (Ivan Vecera) [1638022]
- [net] netfilter: Add nf_ct_get_tuple_skb global lookup function (Ivan Vecera) [1638022]
- [net] sch_cake: Add optional ACK filter (Ivan Vecera) [1638022]
- [net] sch_cake: Add ingress mode (Ivan Vecera) [1638022]
- [net] sched: Add Common Applications Kept Enhanced (cake) qdisc (Ivan Vecera) [1638022]
- [net] Use __u32 in uapi net_stamp.h (Ivan Vecera) [1638022]
- [net] sched: flower: Add supprt for matching on QinQ vlan headers (Ivan Vecera) [1638022]
- [net] sched: flower: Dump the ethertype encapsulated in vlan (Ivan Vecera) [1638022]
- [net] flow_dissector: Add support for QinQ dissection (Ivan Vecera) [1638022]
- [net] sched: flower: Add support for matching on vlan ethertype (Ivan Vecera) [1638022]
- [net] flow_dissector: Save vlan ethertype from headers (Ivan Vecera) [1638022]
- [net] sched: change action API to use array of pointers to actions (Ivan Vecera) [1638022]
- [net] sched: atomically check-allocate action (Ivan Vecera) [1638022]
- [net] sched: use reference counting action init (Ivan Vecera) [1638022]
- [net] sched: don't release reference on action overwrite (Ivan Vecera) [1638022]
- [net] sched: implement reference counted action release (Ivan Vecera) [1638022]
- [net] sched: add 'delete' function to action ops (Ivan Vecera) [1638022]
- [net] sched: implement action API that deletes action by index (Ivan Vecera) [1638022]
- [net] sched: always take reference to action (Ivan Vecera) [1638022]
- [net] sched: implement unlocked action init API (Ivan Vecera) [1638022]
- [net] sched: change type of reference and bind counters (Ivan Vecera) [1638022]
- [net] sched: use rcu for action cookie update (Ivan Vecera) [1638022]
- [net] sched: Make etf report drops on error_queue (Ivan Vecera) [1638022]
- [net] sched: Add HW offloading capability to ETF (Ivan Vecera) [1638022]
- [net] sched: Introduce the ETF Qdisc (Ivan Vecera) [1638022]
- [net] sched: Allow creating a Qdisc watchdog with other clocks (Ivan Vecera) [1638022]
- [net] packet: Hook into time based transmission. (Ivan Vecera) [1638022]
- [net] ipv6: Hook into time based transmission (Ivan Vecera) [1638022]
- [net] ipv4: Hook into time based transmission (Ivan Vecera) [1638022]
- [net] Add a new socket option for a future transmit time. (Ivan Vecera) [1638022]
- [net] Clear skb->tstamp only on the forwarding path (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix possible memory leak in tcf_pedit_init() (Ivan Vecera) [1638022]
- [net] net sched actions: add extack messages in pedit action (Ivan Vecera) [1638022]
- [net] net:sched: add action inheritdsfield to skbedit (Ivan Vecera) [1638022]
- [net] tc-testing: initial version of tunnel_key unit tests (Ivan Vecera) [1638022]
- [net] net sched actions: avoid bitwise operation on signed value in pedit (Ivan Vecera) [1638022]
- [net] net sched actions: fix misleading text strings in pedit action (Ivan Vecera) [1638022]
- [net] net sched actions: use sizeof operator for buffer length (Ivan Vecera) [1638022]
- [net] net sched actions: fix sparse warning (Ivan Vecera) [1638022]
- [net] net sched actions: fix coding style in pedit headers (Ivan Vecera) [1638022]
- [net] net sched actions: fix coding style in pedit action (Ivan Vecera) [1638022]
- [net] netem: slotting with non-uniform distribution (Ivan Vecera) [1638022]
- [net] check tunnel option type in tunnel flags (Ivan Vecera) [1638022]
- [net] sched: act_tunnel_key: add extended ack support (Ivan Vecera) [1638022]
- [net] tc-tests: add an extreme-case csum action test (Ivan Vecera) [1638022]
- [net] net_sched: remove unused htb drop_list (Ivan Vecera) [1638022]

* Sun Dec 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-55.el8]
- [rpmspec] always run make with HOSTCFLAGS/HOSTLDFLAGS set (Jiri Olsa) [1624124]
- [rpmspec] Pass global build flags to tools build (Jiri Olsa) [1624124]
- [rpmspec] Pass global build flags to bpftool build (Jiri Olsa) [1624124]
- [kernel] kbuild: Use HOST*FLAGS options from the command line (Jiri Olsa) [1624124]
- [scripts] kbuild: Rename HOST_LOADLIBES to KBUILD_HOSTLDLIBS (Jiri Olsa) [1624124]
- [tools] kbuild: Rename HOSTLDFLAGS to KBUILD_HOSTLDFLAGS (Jiri Olsa) [1624124]
- [scripts] kbuild: Rename HOSTCXXFLAGS to KBUILD_HOSTCXXFLAGS (Jiri Olsa) [1624124]
- [tools] kbuild: Rename HOSTCFLAGS to KBUILD_HOSTCFLAGS (Jiri Olsa) [1624124]
- [tools] tools cpupower: Override CFLAGS assignments (Jiri Olsa) [1624124]
- [tools] tools cpupower debug: Allow to use outside build flags (Jiri Olsa) [1624124]
- [tools] perf tools: Pass build flags to traceevent build (Jiri Olsa) [1624124]
- [tools] tools lib traceevent: Use LDFLAGS in the build commands (Jiri Olsa) [1624124]
- [tools] perf tools: Link libperf-jvmti.so with LDFLAGS variable (Jiri Olsa) [1624124]
- [tools] bpftool: Allow add linker flags via EXTRA_LDFLAGS variable (Jiri Olsa) [1624124]
- [tools] bpftool: Allow to add compiler flags via EXTRA_CFLAGS variable (Jiri Olsa) [1624124]
- [block] blkcg: handle dying request_queue when associating a blkg (Ming Lei) [1655485]
- [block] block: deactivate blk_stat timer in wbt_disable_default() (Ming Lei) [1655485]
- [lib] sbitmap: flush deferred clears for resize and shallow gets (Ming Lei) [1655485]
- [md] dm: fix request-based dm's use of dm_wait_for_completion (Ming Lei) [1655485]
- [nvme] nvme: fix irq vs io_queue calculations (Ming Lei) [1655485]
- [md] dm: fix inflight IO check (Ming Lei) [1655485]
- [md] dm: remove the pending IO accounting (Ming Lei) [1655485]
- [block] block: return just one value from part_in_flight (Ming Lei) [1655485]
- [block] block: switch to per-cpu in-flight counters (Ming Lei) [1655485]
- [block] block: delete part_round_stats and switch to less precise counting (Ming Lei) [1655485]
- [block] block: stop passing 'cpu' to all percpu stats methods (Ming Lei) [1655485]
- [md] dm rq: leverage blk_mq_queue_busy() to check for outstanding IO (Ming Lei) [1655485]
- [md] dm: dont rewrite dm_disk(md)->part0.in_flight (Ming Lei) [1655485]
- [lib] sbitmap: silence bogus lockdep IRQ warning (Ming Lei) [1655485]
- [scsi] scsi: Fix a harmless double shift bug (Ming Lei) [1655485]
- [block] blk-mq: re-build queue map in case of kdump kernel (Ming Lei) [1655485]
- [block] blkcg: put back rcu lock in blkcg_bio_issue_check() (Ming Lei) [1655485]
- [block] block: convert io-latency to use rq_qos_wait (Ming Lei) [1655485]
- [block] block: convert wbt_wait() to use rq_qos_wait() (Ming Lei) [1655485]
- [block] block: add rq_qos_wait to rq_qos (Ming Lei) [1655485]
- [block] blkcg: rename blkg_try_get() to blkg_tryget() (Ming Lei) [1655485]
- [block] blkcg: change blkg reference counting to use percpu_ref (Ming Lei) [1655485]
- [block] blkcg: remove bio_disassociate_task() (Ming Lei) [1655485]
- [block] blkcg: remove additional reference to the css (Ming Lei) [1655485]
- [block] blkcg: remove bio->bi_css and instead use bio->bi_blkg (Ming Lei) [1655485]
- [block] blkcg: associate writeback bios with a blkg (Ming Lei) [1655485]
- [block] blkcg: associate a blkg for pages being evicted by swap (Ming Lei) [1655485]
- [block] blkcg: consolidate bio_issue_init() to be a part of core (Ming Lei) [1655485]
- [block] blkcg: associate blkg when associating a device (Ming Lei) [1655485]
- [block] dm: set the static flush bio device on demand (Ming Lei) [1655485]
- [block] blkcg: introduce common blkg association logic (Ming Lei) [1655485]
- [block] blkcg: convert blkg_lookup_create() to find closest blkg (Ming Lei) [1655485]
- [block] blkcg: update blkg_lookup_create() to do locking (Ming Lei) [1655485]
- [block] blkcg: fix ref count issue with bio_blkcg() using task_css (Ming Lei) [1655485]
- [block] blk-mq: remove QUEUE_FLAG_POLL from default MQ flags (Ming Lei) [1655485]
- [block] block: enable polling by default if a poll map is initalized (Ming Lei) [1655485]
- [block] block: only allow polling if a poll queue_map exists (Ming Lei) [1655485]
- [block] block: remove ->poll_fn (Ming Lei) [1655485]
- [nvme] nvme-mpath: remove I/O polling support (Ming Lei) [1655485]
- [nvme] nvme-rdma: remove I/O polling support (Ming Lei) [1655485]
- [nvme] nvme-pci: remove the CQ lock for interrupt driven queues (Ming Lei) [1655485]
- [nvme] nvme-pci: don't poll from irq context when deleting queues (Ming Lei) [1655485]
- [nvme] nvme-pci: refactor nvme_disable_io_queues (Ming Lei) [1655485]
- [nvme] nvme-pci: consolidate code for polling non-dedicated queues (Ming Lei) [1655485]
- [nvme] nvme-pci: only allow polling with separate poll queues (Ming Lei) [1655485]
- [nvme] nvme-pci: cleanup SQ allocation a bit (Ming Lei) [1655485]
- [nvme] nvme-pci: use atomic bitops to mark a queue enabled (Ming Lei) [1655485]
- [block] block: move queues types to the block layer (Ming Lei) [1655485]
- [fs] aio: clear IOCB_HIPRI (Ming Lei) [1655485]
- [lib] sbitmap: fix sbitmap_for_each_set() (Ming Lei) [1655485]
- [block] blk-mq: don't call ktime_get_ns() if we don't need it (Ming Lei) [1655485]
- [block] block: add cmd_flags to print_req_error (Ming Lei) [1655485]
- [lib] sbitmap: optimize wakeup check (Ming Lei) [1655485]
- [lib] sbitmap: ammortize cost of clearing bits (Ming Lei) [1655485]
- [block] block: avoid extra bio reference for async O_DIRECT (Ming Lei) [1655485]
- [lib] sbitmap: don't loop for find_next_zero_bit() for !round_robin (Ming Lei) [1655485]
- [block] blk-mq: use plug for devices that implement ->commits_rqs() (Ming Lei) [1655485]
- [block] blk-mq: use bd->last == true for list inserts (Ming Lei) [1655485]
- [block] ataflop: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [block] virtio_blk: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [nvme] nvme: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [block] blk-mq: add mq_ops->commit_rqs() (Ming Lei) [1655485]
- [block] block: improve logic around when to sort a plug list (Ming Lei) [1655485]
- [block] blk-mq: Add a NULL check in blk_mq_free_map_and_requests() (Ming Lei) [1655485]
- [block] ataflop: fix error handling in atari_floppy_init() (Ming Lei) [1655485]
- [block] block: add io timeout to sysfs (Ming Lei) [1655485]
- [block] block: use rcu_work instead of call_rcu to avoid sleep in softirq (Ming Lei) [1655485]
- [block] blk-mq: fix failure to decrement plug count on single rq removal (Ming Lei) [1655485]
- [block] sunvdc: Do not spin in an infinite loop when vio_ldc_send() returns EAGAIN (Ming Lei) [1655485]
- [block] block: sum requests in the plug structure (Ming Lei) [1655485]
- [block] blk-mq: Simplify request completion state (Ming Lei) [1655485]
- [scsi] scsi: Do not rely on blk-mq for double completions (Ming Lei) [1655485]
- [block] blk-mq: Return true if request was completed (Ming Lei) [1655485]
- [block] blk-mq: never redirect polled IO completions (Ming Lei) [1655485]
- [block] blk-mq: ensure mq_ops ->poll() is entered at least once (Ming Lei) [1655485]
- [block] block: make blk_poll() take a parameter on whether to spin or not (Ming Lei) [1655485]
- [nvme] nvme: remove opportunistic polling from bdev target (Ming Lei) [1655485]
- [block] blk-mq: remove 'tag' parameter from mq_ops->poll() (Ming Lei) [1655485]
- [block] blk-mq: when polling for IO, look for any completion (Ming Lei) [1655485]
- [block] block: fix attempt to assign NULL io_context (Ming Lei) [1655485]
- [block] block: Initialize BIO I/O priority early (Ming Lei) [1655485]
- [block] block: prevent merging of requests with different priorities (Ming Lei) [1655485]
- [fs] aio: Fix fallback I/O priority value (Ming Lei) [1655485]
- [block] block: Introduce get_current_ioprio() (Ming Lei) [1655485]
- [block] block: Remove bio->bi_ioc (Ming Lei) [1655485]
- [fs] aio: Comment use of IOCB_FLAG_IOPRIO aio flag (Ming Lei) [1655485]
- [nvme] nvme-fc: remove ->poll implementation (Ming Lei) [1655485]
- [block] block: have ->poll_fn() return number of entries polled (Ming Lei) [1655485]
- [block] block: avoid ordered task state change for polled IO (Ming Lei) [1655485]
- [nvme] nvme: default to 0 poll queues (Ming Lei) [1655485]
- [block] floppy: remove now unused 'flags' variable (Ming Lei) [1655485]
- [mmc] mmc: stop abusing the request queue_lock pointer (Ming Lei) [1655485]
- [block] ide: don't acquire queue_lock in ide_complete_pm_rq (Ming Lei) [1655485]
- [block] ide: don't acquire queue lock in ide_pm_execute_rq (Ming Lei) [1655485]
- [block] pktcdvd: remove queue_lock around blk_queue_max_hw_sectors (Ming Lei) [1655485]
- [block] floppy: remove queue_lock around floppy_end_request (Ming Lei) [1655485]
- [block] block: remove the rq_alloc_data request_queue field (Ming Lei) [1655485]
- [block] block: don't plug for aio/O_DIRECT HIPRI IO (Ming Lei) [1655485]
- [block] block: for async O_DIRECT, mark us as polling if asked to (Ming Lei) [1655485]
- [block] block: add polled wakeup task helper (Ming Lei) [1655485]
- [block] blk-rq-qos: inline check for q->rq_qos functions (Ming Lei) [1655485]
- [block] block: add queue_is_mq() helper (Ming Lei) [1655485]
- [nvme] nvme: provide optimized poll function for separate poll queues (Ming Lei) [1655485]
- [block] ide: clear ide_req()->special for non-passthrough requests (Ming Lei) [1655485]
- [nvme] nvme: fix handling of EINVAL on pci_alloc_irq_vectors_affinity() (Ming Lei) [1655485]
- [block] block: add wbt_disable_default export for BFQ (Ming Lei) [1655485]
- [block] block: remove the queue_lock indirection (Ming Lei) [1655485]
- [block] block: remove the lock argument to blk_alloc_queue_node (Ming Lei) [1655485]
- [mmc] mmc: stop abusing the request queue_lock pointer (Ming Lei) [1655485]
- [mmc] mmc: simplify queue initialization (Ming Lei) [1655485]
- [block] umem: don't override the queue_lock (Ming Lei) [1655485]
- [block] drbd: don't override the queue_lock (Ming Lei) [1655485]
- [block] blk-cgroup: move locking into blkg_destroy_all (Ming Lei) [1655485]
- [block] blk-cgroup: consolidate error handling in blkcg_init_queue (Ming Lei) [1655485]
- [block] block: remove a few unused exports (Ming Lei) [1655485]
- [block] block: update a few comments for the legacy request removal (Ming Lei) [1655485]
- [block] block: remove the unused lock argument to rq_qos_throttle (Ming Lei) [1655485]
- [block] block: remove queue_lockdep_assert_held (Ming Lei) [1655485]
- [block] block: use atomic bitops for ->queue_flags (Ming Lei) [1655485]
- [block] block: don't hold the queue_lock over blk_abort_request (Ming Lei) [1655485]
- [block] block: remove deadline __deadline manipulation helpers (Ming Lei) [1655485]
- [block] block: remove QUEUE_FLAG_BYPASS and ->bypass (Ming Lei) [1655485]
- [nvme] nvmet-rdma: fix response use after free (Ming Lei) [1655485]
- [nvme] nvme: validate controller state before rescheduling keep alive (Ming Lei) [1655485]
- [block] block, bfq: fix decrement of num_active_groups (Ming Lei) [1655485]
- [ata] libata: whitelist all SAMSUNG MZ7KM* solid-state disks (Ming Lei) [1655485]
- [nvme] nvme-rdma: fix double freeing of async event data (Ming Lei) [1655485]
- [nvme] nvme-pci: fix surprise removal (Ming Lei) [1655485]
- [nvme] nvme: Free ctrl device name on init failure (Ming Lei) [1655485]
- [nvme] nvme-fc: resolve io failures during connect (Ming Lei) [1655485]
- [nvme] nvme: make sure ns head inherits underlying device limits (Ming Lei) [1655485]
- [nvme] nvmet: don't try to add ns to p2p map unless it actually uses it (Ming Lei) [1655485]
- [nvme] nvme-pci: fix conflicting p2p resource adds (Ming Lei) [1655485]
- [nvme] nvmet: Optionally use PCI P2P memory (Ming Lei) [1655485]
- [nvme] nvmet: Introduce helper functions to allocate and free request SGLs (Ming Lei) [1655485]
- [nvme] nvme-pci: Add support for P2P memory in requests (Ming Lei) [1655485]
- [nvme] nvme-pci: Use PCI p2pmem subsystem to manage the CMB (Ming Lei) [1655485]
- [infiniband] IB/core: Ensure we map P2P memory correctly in rdma_rw_ctx_[init|destroy]() (Ming Lei) [1655485]
- [block] block: Add PCI P2P flag for request queue (Ming Lei) [1655485]
- [documentation] PCI/P2PDMA: Add P2P DMA driver writer's documentation (Ming Lei) [1655485]
- [documentation] docs-rst: Add a new directory for PCI documentation (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Introduce configfs/sysfs enable attribute helpers (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Add PCI p2pmem DMA mappings to adjust the bus offset (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Add sysfs group to display p2pmem stats (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Support peer-to-peer memory (Ming Lei) [1655485]
- [nvme] nvmet-rdma: support max(16KB, PAGE_SIZE) inline data (Ming Lei) [1655485]
- [nvme] nvme-rdma: support up to 4 segments of inline data (Ming Lei) [1655485]
- [fs] aio: fix failure to put the file pointer (Ming Lei) [1655485]
- [lib] scsi: Remove percpu_ida (Ming Lei) [1655485]
- [scsi] scsi: target: Convert target drivers to use sbitmap (Ming Lei) [1655485]
- [scsi] scsi: target: Abstract tag freeing (Ming Lei) [1655485]
- [block] mmc: block: Fix unsupported parallel dispatch of requests (Ming Lei) [1655485]
- [scsi] scsi: target: sbitmap: add seq_file forward declaration (Ming Lei) [1655485]
- [mm] mm, memory_hotplug: do not clear numa_node association after hot_remove (Waiman Long) [1657422]
- [fs] iomap: partially revert 4721a601099 (simulated directio short read on EFAULT) (Brian Foster) [1654713]
- [fs] splice: don't read more than available pipe space (Brian Foster) [1654713]
- [fs] vfs: allow some remap flags to be passed to vfs_clone_file_range (Brian Foster) [1654713]
- [fs] xfs: fix inverted return from xfs_btree_sblock_verify_crc (Brian Foster) [1654713]
- [fs] xfs: fix PAGE_MASK usage in xfs_free_file_space (Brian Foster) [1654713]
- [fs] fs/xfs: fix f_ffree value for statfs when project quota is set (Brian Foster) [1654713]
- [fs] iomap: readpages doesn't zero page tail beyond EOF (Brian Foster) [1654713]
- [fs] vfs: vfs_dedupe_file_range() doesn't return EOPNOTSUPP (Brian Foster) [1654713]
- [fs] iomap: dio data corruption and spurious errors when pipes fill (Brian Foster) [1654713]
- [fs] iomap: sub-block dio needs to zeroout beyond EOF (Brian Foster) [1654713]
- [fs] iomap: FUA is wrong for DIO O_DSYNC writes into unwritten extents (Brian Foster) [1654713]
- [fs] xfs: delalloc -> unwritten COW fork allocation can go wrong (Brian Foster) [1654713]
- [fs] xfs: flush removing page cache in xfs_reflink_remap_prep (Brian Foster) [1654713]
- [fs] xfs: extent shifting doesn't fully invalidate page cache (Brian Foster) [1654713]
- [fs] xfs: finobt AG reserves don't consider last AG can be a runt (Brian Foster) [1654713]
- [fs] xfs: fix transient reference count error in xfs_buf_resubmit_failed_buffers (Brian Foster) [1654713]
- [fs] xfs: uncached buffer tracing needs to print bno (Brian Foster) [1654713]
- [fs] xfs: make xfs_file_remap_range() static (Brian Foster) [1654713]
- [fs] xfs: fix shared extent data corruption due to missing cow reservation (Brian Foster) [1654713]
- [fs] xfs: fix overflow in xfs_attr3_leaf_verify (Brian Foster) [1654713]
- [fs] xfs: print buffer offsets when dumping corrupt buffers (Brian Foster) [1654713]
- [fs] xfs: Fix error code in 'xfs_ioc_getbmap()' (Brian Foster) [1654713]
- [fs] xfs: cancel COW blocks before swapext (Brian Foster) [1654713]
- [fs] xfs: clear ail delwri queued bufs on unmount of shutdown fs (Brian Foster) [1654713]
- [fs] xfs: use offsetof() in place of offset macros for __xfsstats (Brian Foster) [1654713]
- [fs] xfs: Fix xqmstats offsets in /proc/fs/xfs/xqmstat (Brian Foster) [1654713]
- [fs] xfs: fix use-after-free race in xfs_buf_rele (Brian Foster) [1654713]
- [fs] xfs: Add attibute remove and helper functions (Brian Foster) [1654713]
- [fs] xfs: Add attibute set and helper functions (Brian Foster) [1654713]
- [fs] xfs: Add helper function xfs_attr_try_sf_addname (Brian Foster) [1654713]
- [fs] xfs: Move fs/xfs/xfs_attr.h to fs/xfs/libxfs/xfs_attr.h (Brian Foster) [1654713]
- [fs] xfs: issue log message on user force shutdown (Brian Foster) [1654713]
- [fs] xfs: fix buffer state management in xrep_findroot_block (Brian Foster) [1654713]
- [fs] xfs: always assign buffer verifiers when one is provided (Brian Foster) [1654713]
- [fs] xfs: xrep_findroot_block should reject root blocks with siblings (Brian Foster) [1654713]
- [fs] xfs: add a define for statfs magic to uapi (Brian Foster) [1654713]
- [fs] xfs: print dangling delalloc extents (Brian Foster) [1654713]
- [fs] xfs: fix fork selection in xfs_find_trim_cow_extent (Brian Foster) [1654713]
- [fs] xfs: remove the unused trimmed argument from xfs_reflink_trim_around_shared (Brian Foster) [1654713]
- [fs] xfs: remove the unused shared argument to xfs_reflink_reserve_cow (Brian Foster) [1654713]
- [fs] xfs: handle zeroing in xfs_file_iomap_begin_delay (Brian Foster) [1654713]
- [fs] xfs: remove suport for filesystems without unwritten extent flag (Brian Foster) [1654713]
- [fs] xfs: remove XFS_IO_INVALID (Brian Foster) [1654713]
- [fs] xfs: remove [cm]time update from reflink calls (Brian Foster) [1654713]
- [fs] xfs: remove xfs_reflink_remap_range (Brian Foster) [1654713]
- [fs] xfs: remove redundant remap partial EOF block checks (Brian Foster) [1654713]
- [fs] xfs: support returning partial reflink results (Brian Foster) [1654713]
- [fs] xfs: clean up xfs_reflink_remap_blocks call site (Brian Foster) [1654713]
- [fs] xfs: fix pagecache truncation prior to reflink (Brian Foster) [1654713]
- [fs] vfs: clean up generic_remap_file_range_prep return value (Brian Foster) [1654713]
- [fs] vfs: hide file range comparison function (Brian Foster) [1654713]
- [fs] vfs: enable remap callers that can handle short operations (Brian Foster) [1654713]
- [fs] vfs: plumb remap flags through the vfs dedupe functions (Brian Foster) [1654713]
- [fs] vfs: plumb remap flags through the vfs clone functions (Brian Foster) [1654713]
- [fs] vfs: make remap_file_range functions take and return bytes completed (Brian Foster) [1654713]
- [fs] vfs: remap helper should update destination inode metadata (Brian Foster) [1654713]
- [fs] vfs: pass remap flags to generic_remap_checks (Brian Foster) [1654713]
- [fs] vfs: pass remap flags to generic_remap_file_range_prep (Brian Foster) [1654713]
- [fs] vfs: combine the clone and dedupe into a single remap_file_range (Brian Foster) [1654713]
- [fs] vfs: rename clone_verify_area to remap_verify_area (Brian Foster) [1654713]
- [fs] vfs: rename vfs_clone_file_prep to be more descriptive (Brian Foster) [1654713]
- [fs] vfs: skip zero-length dedupe requests (Brian Foster) [1654713]
- [fs] vfs: avoid problematic remapping requests into partial EOF block (Brian Foster) [1654713]
- [fs] vfs: strengthen checking of file range inputs to generic_remap_checks (Brian Foster) [1654713]
- [fs] vfs: exit early from zero length remap operations (Brian Foster) [1654713]
- [fs] vfs: check file ranges before cloning files (Brian Foster) [1654713]
- [fs] vfs: vfs_clone_file_prep_inodes should return EINVAL for a clone from beyond EOF (Brian Foster) [1654713]
- [block] blk-mq: not embed .mq_kobj and ctx->kobj into queue instance (Ming Lei) [1653124]
- [fs] fs: fix lost error code in dio_complete (Ming Lei) [1655364]
- [iommu] iommu/iova: Optimise attempts to allocate iova from 32bit address range (Robert Richter) [1639202]

* Fri Dec 14 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-54.el8]
- [drm] drm/nouveau/drm/nouveau: Check rc from drm_dp_mst_topology_mgr_resume() (Lyude Paul) [1658810]
- [x86] Mark Intel Apollo Lake supported (David Arcari) [1653799]
- [infiniband] IB/mlx5: Fix implicit ODP interrupted page fault (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Improve ODP debugging messages (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Use multi threaded workqueue for page fault handling (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Return success for PAGE_FAULT_RESUME in internal error state (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Lock QP during page fault handling (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Enumerate page fault types (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Add interface to hold and release core resources (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Release resource on error flow (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Correctly set PFC param if global pause is turned off. (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_en: Change min MTU size to ETH_MIN_MTU (Alaa Hleihel) [1658085]
- [netdrv] mlx5: fix get_ip_proto() (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Fix page fault handling for MW (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Initialize return variable in case pagefault was skipped (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Skip non-ODP MR when handling a page fault (Alaa Hleihel) [1658085]
- [net] net/dim: Update DIM start sample after each DIM iteration (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Avoid load failure due to unknown link width (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Fix fence type for IB_WR_LOCAL_INV WR (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Removed unnecessary warnings in FEC caps query (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Fix selftest for small MTUs (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: RX, verify received packet size in Linear Striding RQ (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Apply the correct check for supporting TC esw rules split (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Adjust to max number of channles when re-attaching (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Always use the match level enum when parsing TC rule match (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Claim TC hw offloads support only under a proper build config (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Don't match on vlan non-existence if ethertype is wildcarded (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: IPoIB, Reset QP after channels are closed (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4: Fix UBSAN warning of signed integer overflow (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Fix uninitialized variable compilation warning (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Zero out lkey field in SW2HW_MPT fw command (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Fix MR cache initialization (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Remove extraneous error check (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Take only bit 24-26 of wqe.pftype_wq for page fault type (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Fix memory leak when setting fpga ipsec caps (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Unmap DMA addr from HCA before IOMMU (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Remove superfluous version print (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Allow transition of DCI QP to reset (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Don't hold spin lock while checking device state (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Move mlx5e_priv_flags into en_ethtool.c (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Fix atomic_mode enum values (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Delete unneeded function argument (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: RX, Prefetch the xdp_frame data area (Alaa Hleihel) [1658085]
- [drm] drm/i915: Synchronize hpd work in i915_hpd_storm_ctl_show() (Lyude Paul) [1658376]
- [drm] drm/i915: Add short HPD IRQ storm detection for non-MST systems (Lyude Paul) [1658376]
- [drm] drm/i915: Clarify flow for disabling IRQs on storms (Lyude Paul) [1658376]
- [drm] drm/i915: Fix threshold check in intel_hpd_irq_storm_detect() (Lyude Paul) [1658376]
- [drm] drm/i915: Fix NULL deref when re-enabling HPD IRQs on systems with MST (Lyude Paul) [1658376]
- [drm] drm/i915: Fix possible race in intel_dp_add_mst_connector() (Lyude Paul) [1658376]
- [x86] kvm: x86: bump KVM_(SOFT_)MAX_VCPUS to 384 (Radim Krcmar) [1635205]
- [block] blk-mq: punt failed direct issue to dispatch list (Ming Lei) [1656653]
- [block] blk-mq: fix corruption with direct issue (Ming Lei) [1656653]
- [pci] PCI: Add support for Immediate Readiness (Myron Stowe) [1483409]
- [x86] x86/PCI: Remove node-local allocation when initialising host controller (Myron Stowe) [1483409]
- [arm64] arm64: PCI: Remove node-local allocations when initialising host controller (Myron Stowe) [1483409]
- [cpufreq] cpufreq: intel_pstate: Add base_frequency attribute (Prarit Bhargava) [1648207]
- [acpi] ACPI / CPPC: Add support for guaranteed performance (Prarit Bhargava) [1648207]
- [block] block: fix single range discard merge (Ming Lei) [1654096]
- [scsi] SCSI: fix queue cleanup race before queue initialization is done (Ming Lei) [1642404]
- [netdrv] net: hinic: fix null pointer dereference on pointer hwdev (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic: fix a bug in rx data flow (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:fix a bug in set mac address (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:add rx checksum offload for HiNIC (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:replace multiply and division operators (Xiaojun Tan) [1654207]
- [netdrv] hinic: Fix l4_type parameter in hinic_task_set_tunnel_l4 (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic: add checksum offload and TSO support (Xiaojun Tan) [1654207]
- [netdrv] cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on page size (Arjun Vynipadath) [1651082]

* Thu Dec 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-53.el8]
- [x86] kvm: x86: Report STIBP on GET_SUPPORTED_CPUID (Eduardo Habkost) [1644870]
- [kernel] power: remove possible deadlock when unregistering power_supply (Benjamin Tissoires) [1657623]
- [md] dm: call blk_queue_split() to impose device limits on bios (Mike Snitzer) [1657340]
- [pinctrl] Revert "pinctrl: intel: Do pin translation when lock IRQ" (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix HOSTSW_OWN register offset of H variant (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Do pin translation in other GPIO operations as well (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix gpio base for GPP-E (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Don't shadow error code of gpiochip_lock_as_irq() (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix community ordering for H variant (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Do pin translation when lock IRQ (Benjamin Tissoires) [1658075]
- [firmware] efi: Prevent GICv3 WARN() by mapping the memreserve table before first use (Bhupesh Sharma) [1638640]
- [firmware] efi: Permit calling efi_mem_reserve_persistent() from atomic context (Bhupesh Sharma) [1638640]
- [firmware] efi/arm: Defer persistent reservations until after paging_init() (Bhupesh Sharma) [1638640]
- [firmware] efi/arm: Revert deferred unmap of early memmap mapping (Bhupesh Sharma) [1638640]
- [arm64] arm64: memblock: don't permit memblock resizing until linear mapping is up (Bhupesh Sharma) [1638640]
- [arm64] arm64: Fix /proc/iomem for reserved but not memory regions (Bhupesh Sharma) [1638640]
- [tty] tty: wipe buffer. (Christoph von Recklinghausen) [1655051]
- [tty] tty: wipe buffer if not echoing data (Christoph von Recklinghausen) [1655051]

* Wed Dec 12 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-52.el8]
- [powerpc] powerpc/perf: Remove sched_task function defined for thread-imc (Steve Best) [1657153]
- [s390] Add reserved fields to mm_context_t (Philipp Rudo) [1656874]
- [s390] Add reserved fields to thread_struct (Philipp Rudo) [1656874]
- [documentation] kdump: correct crashkernel=auto threshold (Raghavendra Rao) [1656698]
- [fs] NFSv4.x: fix lock recovery during delegation recall (Steve Dickson) [1656410]
- [x86] x86/spec_ctrl: Synchronize RHEL8 percpu SPEC_CTRL MSR states with new STIBP logic (Waiman Long) [1655662]
- [x86] x86/speculation: Provide IBPB always command line options (Waiman Long) [1655662]
- [x86] x86/speculation: Add seccomp Spectre v2 user space protection mode (Waiman Long) [1655662]
- [x86] x86/speculation: Enable prctl mode for spectre_v2_user (Waiman Long) [1655662]
- [x86] x86/speculation: Add prctl() control for indirect branch speculation (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare arch_smt_update() for PRCTL mode (Waiman Long) [1655662]
- [x86] x86/speculation: Prevent stale SPEC_CTRL msr content (Waiman Long) [1655662]
- [x86] x86/speculation: Split out TIF update (Waiman Long) [1655662]
- [x86] ptrace: Remove unused ptrace_may_access_sched() and MODE_IBRS (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare for conditional IBPB in switch_mm() (Waiman Long) [1655662]
- [x86] x86/speculation: Avoid __switch_to_xtra() calls (Waiman Long) [1655662]
- [x86] x86/process: Consolidate and simplify switch_to_xtra() code (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare for per task indirect branch speculation control (Waiman Long) [1655662]
- [x86] x86/speculation: Add command line control for indirect branch speculation (Waiman Long) [1655662]
- [x86] x86/speculation: Unify conditional spectre v2 print functions (Waiman Long) [1655662]
- [x86] x86/speculataion: Mark command line parser data __initdata (Waiman Long) [1655662]
- [x86] x86/speculation: Mark string arrays const correctly (Waiman Long) [1655662]
- [x86] x86/speculation: Reorder the spec_v2 code (Waiman Long) [1655662]
- [x86] x86/l1tf: Show actual SMT state (Waiman Long) [1655662]
- [x86] x86/speculation: Rework SMT state change (Waiman Long) [1655662]
- [x86] sched/smt: Expose sched_smt_present static key (Waiman Long) [1655662]
- [x86] x86/Kconfig: Select SCHED_SMT if SMP enabled (Waiman Long) [1655662]
- [x86] sched/smt: Make sched_smt_present track topology (Waiman Long) [1655662]
- [x86] x86/speculation: Reorganize speculation control MSRs update (Waiman Long) [1655662]
- [x86] x86/speculation: Rename SSBD update functions (Waiman Long) [1655662]
- [x86] x86/speculation: Disable STIBP when enhanced IBRS is in use (Waiman Long) [1655662]
- [x86] x86/speculation: Move STIPB/IBPB string conditionals out of cpu_show_common() (Waiman Long) [1655662]
- [x86] x86/speculation: Remove unnecessary ret variable in cpu_show_common() (Waiman Long) [1655662]
- [x86] x86/speculation: Clean up spectre_v2_parse_cmdline() (Waiman Long) [1655662]
- [x86] x86/speculation: Update the TIF_SSBD comment (Waiman Long) [1655662]
- [x86] x86/retpoline: Remove minimal retpoline support (Waiman Long) [1655662]
- [x86] x86/retpoline: Make CONFIG_RETPOLINE depend on compiler support (Waiman Long) [1655662]
- [x86] x86/spec_ctrl: Temporarily remove the IBRS code from process.c & bugs.c (Waiman Long) [1655662]
- [nvme] nvme: flush namespace scanning work just before removing namespaces (Ewan Milne) [1656028]
- [netdrv] i40e: Fix deletion of MAC filters (Stefan Assmann) [1646847]
- [scsi] mpt3sas: Display message on Configurable secure HBA (Tomas Henzl) [1649314]
- [scsi] scsi: mpt3sas: Add support for Aero controllers (Tomas Henzl) [1649314]
- [scsi] scsi: mpt3sas: Update MPI headers to support Aero controllers (Tomas Henzl) [1649314]
- [scsi] megaraid_sas: Add support for MegaRAID Aero controllers (Tomas Henzl) [1649384]
- [netdrv] nfp: flower: enabled offloading of Team LAG (Pablo Cascon) [1649876]
- [netdrv] net/mlx5: IPSec, Fix the SA context hash key (Alaa Hleihel) [1645857]
- [hwmon] hwmon/k10temp: Add support for AMD family 17h, model 30h CPUs (Gary Hook) [1640681]
- [x86] x86/amd_nb: Add PCI device IDs for family 17h, model 30h (Gary Hook) [1640681]
- [x86] x86/amd_nb: Add support for newer PCI topologies (Gary Hook) [1640681]
- [hwmon] hwmon/k10temp, x86/amd_nb: Consolidate shared device IDs (Gary Hook) [1640681]
- [net] tipc: fix info leak from kernel tipc_event (Jon Maloy) [1643279]
- [net] tipc: eliminate message disordering during binding table update (Jon Maloy) [1643279]
- [net] tipc: fix unsafe rcu locking when accessing publication list (Jon Maloy) [1643279]
- [net] tipc: queue socket protocol error messages into socket receive buffer (Jon Maloy) [1643279]
- [net] tipc: ignore STATE_MSG on wrong link session (Jon Maloy) [1643279]
- [net] tipc: fix failover problem (Jon Maloy) [1643279]
- [net] tipc: eliminate possible recursive locking detected by LOCKDEP (Jon Maloy) [1643279]
- [net] tipc: lock wakeup & inputq at tipc_link_reset() (Jon Maloy) [1643279]
- [net] tipc: reset bearer if device carrier not ok (Jon Maloy) [1643279]
- [net] tipc: fix flow control accounting for implicit connect (Jon Maloy) [1643279]
- [net] tipc: check return value of __tipc_dump_start() (Jon Maloy) [1643279]
- [net] tipc: call start and done ops directly in __tipc_nl_compat_dumpit() (Jon Maloy) [1643279]
- [net] tipc: orphan sock in tipc_release() (Jon Maloy) [1643279]
- [net] tipc: switch to rhashtable iterator (Jon Maloy) [1643279]
- [net] tipc: fix a missing rhashtable_walk_exit() (Jon Maloy) [1643279]
- [net] tipc: add missing dev_put() on error in tipc_enable_l2_media (Jon Maloy) [1643279]
- [net] tipc: initialize broadcast link stale counter correctly (Jon Maloy) [1643279]
- [net] tipc: set link tolerance correctly in broadcast link (Jon Maloy) [1643279]
- [net] tipc: extend link reset criteria for stale packet retransmission (Jon Maloy) [1643279]
- [crypto] crypto: ccp - Add support for new CCP/PSP device ID (Gary Hook) [1634201]
- [crypto] crypto: ccp - Support register differences between PSP devices (Gary Hook) [1634201]
- [crypto] crypto: ccp - Remove unused #defines (Gary Hook) [1634201]
- [crypto] crypto: ccp - Add psp enabled message when initialization succeeds (Gary Hook) [1634201]
- [crypto] crypto: ccp - Fix command completion detection race (Gary Hook) [1634201]
- [crypto] crypto: ccp - Check for NULL PSP pointer at module unload (Gary Hook) [1634201]
- [net] sctp: increase sk_wmem_alloc when head->truesize is increased (Xin Long) [1645419]
- [net] sctp: count sk_wmem_alloc by skb truesize in sctp_packet_transmit (Xin Long) [1645419]
- [net] ipv6: re-do dad when interface has IFF_NOARP flag change (Hangbin Liu) [1644594]
- [net] netfilter: nf_tables: don't skip inactive chains during update (Florian Westphal) [1643746]
- [net] inet: frags: better deal with smp races (Sabrina Dubroca) [1645397]
- [net] geneve, vxlan: Don't set exceptions if skb->len < mtu (Xin Long) [1642842]
- [net] geneve, vxlan: Don't check skb_dst() twice (Xin Long) [1642842]
- [net] sctp: fix strchange_flags name for Stream Change Event (Xin Long) [1641852]
- [net] sctp: update dst pmtu with the correct daddr (Xin Long) [1644478]
- [net] sctp: not free the new asoc when sctp_wait_for_connect returns err (Xin Long) [1644155]
- [net] l2tp: fix a sock refcnt leak in l2tp_tunnel_register (Xin Long) [1642749]
- [net] sctp: check policy more carefully when getting pr status (Xin Long) [1637786]
- [net] sctp: get pr_assoc and pr_stream all status with SCTP_PR_SCTP_ALL instead (Xin Long) [1637786]
- [net] ipv4/igmp: fix v1/v2 switchback timeout based on rfc3376, 8.12 (Hangbin Liu) [1638598]
- [net] netfilter: nft_compat: ebtables 'nat' table is normal chain type (Florian Westphal) [1645377]
- [net] sched: exclude TC from kABI guarantee (Ivan Vecera) [1628454]
- [net] netfilter: nft_set_rbtree: allow loose matching of closing element in interval (Phil Sutter) [1641993]
- [net] netfilter: xt_nat: fix DNAT target for shifted portmap ranges (Paolo Abeni) [1634258]
- [net] sched: Fix for duplicate class dump (Phil Sutter) [1631179]
- [x86] KVM: X86: Fix scan ioapic use-before-initialization (Bandan Das) [1653835] {CVE-2018-19407}

* Fri Dec 07 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-51.el8]
- [scsi] scsi: vmw_pscsi: Rearrange code to avoid multiple calls to free_irq during unload (Cathy Avery) [1590875]
- [netdrv] net/ibmvnic: Fix RTNL deadlock during device reset (Steve Best) [1656076]
- [s390] s390/qeth: fix length check in SNMP processing (Philipp Rudo) [1655612]
- [s390] s390/ism: clear dmbe_mask bit before SMC IRQ handling (Philipp Rudo) [1655611]
- [net] net/smc: use after free fix in smc_wr_tx_put_slot() (Philipp Rudo) [1655611]
- [net] net/smc: atomic SMCD cursor handling (Philipp Rudo) [1655611]
- [net] net/smc: add SMC-D shutdown signal (Philipp Rudo) [1655611]
- [net] net/smc: use queue pair number when matching link group (Philipp Rudo) [1655611]
- [net] net/smc: abort CLC connection in smc_release (Philipp Rudo) [1655611]
- [net] net/smc: unregister rkeys of unused buffer (Philipp Rudo) [1655611]
- [net] net/smc: add infrastructure to send delete rkey messages (Philipp Rudo) [1655611]
- [net] net/smc: avoid a delay by waiting for nothing (Philipp Rudo) [1655611]
- [net] net/smc: cleanup listen worker mutex unlocking (Philipp Rudo) [1655611]
- [net] net/smc: short wait for late smc_clc_wait_msg (Philipp Rudo) [1655611]
- [net] net/smc: no link delete for a never active link (Philipp Rudo) [1655611]
- [net] net/smc: allow fallback after clc timeouts (Philipp Rudo) [1655611]
- [net] net/smc: remove sock_error detour in clc-functions (Philipp Rudo) [1655611]
- [net] net/smc: make smc_lgr_free() static (Philipp Rudo) [1655611]
- [net] net/smc: cleanup tcp_listen_worker initialization (Philipp Rudo) [1655611]
- [net] net/smc: fix smc_buf_unuse to use the lgr pointer (Philipp Rudo) [1655611]
- [net] Revert "net: simplify sock_poll_wait" (Philipp Rudo) [1655611]
- [powerpc] powerpc/pseries: Fix unitialized timer reset on migration (Steve Best) [1655053]
- [powerpc] powerpc/pseries/mobility: Extend start/stop topology update scope (Steve Best) [1655053]
- [x86] Mark Intel Cascade Lake supported (Steve Best) [1641425]

* Wed Dec 05 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-50.el8]
- [x86] KVM: VMX: re-add ple_gap module parameter (Gary Hook) [1652953]
- [netdrv] tg3: Add PHY reset for 5717/5719/5720 in change ring and flow control paths (Steve Best) [1655515]
- [pci] PCI/ASPM: Do not initialize link state when aspm_disabled is set (Myron Stowe) [1655246]
- [pci] PCI/ACPI: Allow _OSC presence to be optional for PCI (Myron Stowe) [1655246]
- [pci] PCI/ACPI: Correct error message for ASPM disabling (Myron Stowe) [1655246]
- [pci] PCI/ASPM: Fix link_state teardown on device removal (Myron Stowe) [1655246]
- [netdrv] ice: Change req_speeds to be u16 (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix the bytecount sent to netdev_tx_sent_queue (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix tx_timeout in PF driver (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix napi delete calls for remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix typo in error message (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix flags for port VLAN (Jonathan Toppins) [1644403]
- [netdrv] ice: Remove duplicate addition of VLANs in replay path (Jonathan Toppins) [1644403]
- [netdrv] ice: Free VSI contexts during for unload (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix dead device link issue with flow control (Jonathan Toppins) [1644403]
- [netdrv] ice: Check for reset in progress during remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Set carrier state and start/stop queues in rebuild (Jonathan Toppins) [1644403]
- [netdrv] virtchnl: Added support to exchange additional speed values (Jonathan Toppins) [1644403]
- [netdrv] ice: Poll for link status change (Jonathan Toppins) [1644403]
- [netdrv] ice: Allocate VF interrupts and set queue map (Jonathan Toppins) [1644403]
- [netdrv] ice: Introduce ice_dev_onetime_setup (Jonathan Toppins) [1644403]
- [netdrv] ice: Use capability count returned by the firmware (Jonathan Toppins) [1644403]
- [netdrv] ice: Update expected FW version (Jonathan Toppins) [1644403]
- [netdrv] ice: Change device ID define names to align with branding string (Jonathan Toppins) [1644403]
- [netdrv] ice: Make ice_msix_clean_rings static (Jonathan Toppins) [1644403]
- [netdrv] ice: Update version string (Jonathan Toppins) [1644403]
- [netdrv] ice: Use the right function to enable/disable VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Add more flexibility on how we assign an ITR index (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix potential null pointer issues (Jonathan Toppins) [1644403]
- [netdrv] ice: Add code to go from ICE_FWD_TO_VSI_LIST to ICE_FWD_TO_VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix forward to queue group logic (Jonathan Toppins) [1644403]
- [netdrv] ice: Extend malicious operations detection logic (Jonathan Toppins) [1644403]
- [netdrv] ice: Notify VF of link status change (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement virtchnl commands for AVF support (Jonathan Toppins) [1644403]
- [netdrv] ice: Add handlers for VF netdevice operations (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support for VF reset events (Jonathan Toppins) [1644403]
- [netdrv] ice: Update VSI and queue management code to handle VF VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Add handler to configure SR-IOV (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support to detect SR-IOV capability and mailbox queues (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix error on driver remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support for dynamic interrupt moderation (Jonathan Toppins) [1644403]
- [netdrv] ice: Align ice_reset_req enum values to hardware reset values (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement ethtool hook for RSS switch (Jonathan Toppins) [1644403]
- [netdrv] ice: Split irq_tracker into sw_irq_tracker and hw_irq_tracker (Jonathan Toppins) [1644403]
- [netdrv] ice: Check for actual link state of port after reset (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement VSI replay framework (Jonathan Toppins) [1644403]
- [netdrv] ice: Expand use of VSI handles part 2/2 (Jonathan Toppins) [1644403]
- [netdrv] ice: Expand use of VSI handles part 1/2 (Jonathan Toppins) [1644403]
- [netdrv] ice: Change pf state behavior to protect reset path (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 7/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 6/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 5/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 4/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 3/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 2/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 1/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: fix changing of ring descriptor size (ethtool -G) (Jonathan Toppins) [1644403]
- [netdrv] ice: Update to capabilities admin queue command (Jonathan Toppins) [1644403]
- [netdrv] ice: Query the Tx scheduler node before adding it (Jonathan Toppins) [1644403]
- [netdrv] ice: Update comment for ice_fltr_mgmt_list_entry (Jonathan Toppins) [1644403]
- [netdrv] ice: update fw version check logic (Jonathan Toppins) [1644403]
- [netdrv] ice: update branding strings and supported device ids (Jonathan Toppins) [1644403]
- [netdrv] ice: replace unnecessary memcpy with direct assignment (Jonathan Toppins) [1644403]
- [netdrv] ice: use [sr]q.count when checking if queue is initialized (Jonathan Toppins) [1644403]
- [netdrv] ice: remove ndo_poll_controller (Jonathan Toppins) [1644403]
- [fs] fanotify: fix handling of events on child sub-directory (Miklos Szeredi) [1652432]
- [fs] fsnotify: generalize handling of extra event flags (Miklos Szeredi) [1652432]
- [netdrv] net: hns3: add common validation in hclge_dcb (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: fix for multiple unmapping DMA problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: rename hns_nic_dma_unmap (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add handling for big TX fragment (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: move DMA map into hns3_fill_desc (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove hns3_fill_desc_tso (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Resume promisc mode and vlan filter status after loopback test (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Resume promisc mode and vlan filter status after reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Enable promisc mode when mac vlan table is full (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for rx vlan id handle to support Rev 0x21 hardware (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add egress/ingress vlan filter for revision 0x21 (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Optimize for unicast mac vlan table (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix loss of coal configuration while doing reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Modify hns3_get_max_available_channels (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Change return type of hclge_tm_schd_info_update() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for netdev not up problem when setting mtu (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for packet buffer setting bug (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set extra mac address of pause param for HW (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix speed/duplex information loss problem when executing ethtool ethx cmd of VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add get_media_type ops support for VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove print messages for error packet (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add nic state check before calling netif_tx_wake_queue (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add handle for default case (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Unify the prefix of vf functions (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix tqp array traversal condition for vf (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix ets validate issue (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix parameter type for q_id in hclge_tm_q_to_qs_map_cfg() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix client initialize state issue when roce client initialize failed (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Clear client pointer when initialize client failed or unintialize finished (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix cmdq registers initialization issue for vf (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for setting speed for phy failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Check hdev state when getting link status (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set STATE_DOWN bit of hdev state when stopping net (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove packet statistics of public (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove tx budget to clean more TX descriptors in a napi (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Refine hns3_get_link_ksettings() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove redundant codes of query advertised flow control abilitiy (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Change the dst mac addr of loopback packet (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Only update mac configuation when necessary (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Preserve vlan 0 in hardware table (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix ping exited problem when doing lp selftest (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for loopback selftest failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix error of checking used vlan id (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for multicast failure (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for vf vlan delete failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: modify variable type in hns3_nic_reuse_page (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add vlan filter setting by ethtool command -K (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set tx ring' tc info when netdev is up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix desc num set to default when setting channel (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for information of phydev lost problem when down/up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add support for serdes loopback selftest (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Refine the MSIX allocation for PF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix MSIX allocation issue for VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: fix return value error while hclge_cmd_csq_clean failed (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Modify inconsistent bit mask macros (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for using wrong mask and shift in hclge_get_ring_chain_from_mbx (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Correct reset event status register (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Prevent to request reset frequently (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Prevent sending command during global or core reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add configure for mac minimal frame size (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for l4 checksum offload bug (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for waterline not setting correctly (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix tc setup when netdev is first up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: modify hnae_ to hnae3_ (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: simplify hclge_cmd_csq_clean (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove some redundant assignments (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove back in struct hclge_hw (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add unlikely for error check (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add l4_type check for both ipv4 and ipv6 (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add vector status check before free vector (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: rename the interface for init_client_instance and uninit_client_instance (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove hclge_get_vector_index from hclge_bind_ring_with_vector (Xiaojun Tan) [1640945]
- [kernel] redhat: Enable -Werror for architectures (Laura Abbott) [1582754]
- [drm] drm/atomic_helper: Remove dangling variable (Laura Abbott) [1582754]
- [s390] s390/tools: fix gcc 8 stringop-truncation warnings (Laura Abbott) [1582754]
- [tty] kgdboc: Fix restrict error (Laura Abbott) [1582754]
- [misc] misc: kgdbts: Fix restrict error (Laura Abbott) [1582754]
- [scsi] scsi: ibmvscsis: Fix a stringop-overflow warning (Laura Abbott) [1582754]
- [s390] s390/extmem: fix gcc 8 stringop-overflow warning (Laura Abbott) [1582754]
- [s390] s390/perf: fix gcc 8 array-bounds warning (Laura Abbott) [1582754]
- [kernel] kdb: Use strscpy with destination buffer size (Laura Abbott) [1582754]
- [fs] configfs: replace strncpy with memcpy (Laura Abbott) [1582754]
- [fs] kernfs: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [kernel] disable stringop truncation warnings for now (Laura Abbott) [1582754]
- [sound] ALSA: intel_hdmi: Use strlcpy() instead of strncpy() (Laura Abbott) [1582754]
- [sound] ALSA: trident: Suppress gcc string warning (Laura Abbott) [1582754]
- [lib] kobject: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [tty] TTY: isdn: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [target] scsi: target/iscsi: Make iscsit_ta_authentication() respect the output buffer size (Laura Abbott) [1582754]
- [fs] fuse: don't need GETATTR after every READ (Miklos Szeredi) [1650538]
- [fs] fuse: allow fine grained attr cache invaldation (Miklos Szeredi) [1650538]

* Tue Dec 04 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-49.el8]
- [mm] mm: mremap: properly flush TLB before releasing the page (Rafael Aquini) [1645122] {CVE-2018-18281}
- [x86] x86/spec_ctrl: Change default Skylake Spectre v2 mitigation to retpoline (Waiman Long) [1651806]
- [fs] gfs2: write revokes should traverse sd_ail1_list in reverse (Andreas Grunbacher) [1652763]
- [fs] gfs2: Fix marking bitmaps non-full (Andreas Grunbacher) [1652762]
- [fs] GFS2: Flush the GFS2 delete workqueue before stopping the kernel threads (Andreas Grunbacher) [1652761]
- [fs] gfs2: Don't leave s_fs_info pointing to freed memory in init_sbd (Andreas Grunbacher) [1652759]
- [fs] gfs2: Use fs_* functions instead of pr_* function where we can (Andreas Grunbacher) [1652757]
- [fs] gfs2: slow the deluge of io error messages (Andreas Grunbacher) [1652757]
- [fs] gfs2_meta: ->mount() can get NULL dev_name (Andreas Grunbacher) [1652754]
- [powerpc] powerpc/vdso: Correct call frame information (Steve Best) [1651281]
- [i2c] i2c: i801: Add support for Intel Ice Lake (David Arcari) [1637435]
- [usb] xhci: Add quirk to workaround the errata seen on Cavium Thunder-X2 Soc (Robert Richter) [1649829]
- [x86] x86: numa_emulation: fix uniform-split numa emulation (Rafael Aquini) [1620341]
- [x86] x86: numa_emulation: introduce uniform split capability (Rafael Aquini) [1620341]
- [kernel] perf/hw_breakpoint: Modify breakpoint even if the new attr has disabled set (Mark Salter) [1643174]
- [x86] KVM: vmx: hyper-v: don't pass EPT configuration info to vmx_hv_remote_flush_tlb() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: support CONFIG_KVM_AMD=y with CONFIG_CRYPTO_DEV_CCP_DD=m (Paolo Bonzini) [1636610]
- [x86] kvm: nVMX: fix entry with pending interrupt if APICv is enabled (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: hide flexpriority from guest when disabled at the module level (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: check for existence of secondary exec controls before accessing (Paolo Bonzini) [1636610]
- [x86] KVM: x86: fix L1TF's MMIO GFN calculation (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: cut down decimal places in update interval dialog (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix emulation of VM_ENTRY_LOAD_BNDCFGS (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Do not use kvm_x86_ops->mpx_supported() directly (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Do not expose MPX VMX controls when guest MPX disabled (Paolo Bonzini) [1636610]
- [x86] KVM: x86: never trap MSR_KERNEL_GS_BASE (Paolo Bonzini) [1636610]
- [x86] KVM: LAPIC: Fix pv ipis out-of-bounds access (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix loss of pending IRQ/NMI before entering L2 (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: re-animate display of dead guests (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: indicate dead guests as such (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: handle guest removals more gracefully (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: don't reset stats when setting PID filter for debugfs (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix updates for dead guests (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix handling of invalid paths in debugfs provider (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix python3 issues (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Unexport x86_emulate_instruction() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Rename emulate_instruction() to kvm_emulate_instruction() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Do not re-{try, execute} after failed emulation in L2 (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Default to not allowing emulation retry in kvm_mmu_page_fault (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Merge EMULTYPE_RETRY and EMULTYPE_ALLOW_REEXECUTE (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Invert emulation re-execute behavior to make it opt-in (Paolo Bonzini) [1636610]
- [x86] KVM: x86: SVM: Set EMULTYPE_NO_REEXECUTE for RSM emulation (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: Do not allow reexecute_instruction() when skipping MMIO instr (Paolo Bonzini) [1636610]
- [x86] KVM: SVM: remove unused variable dst_vaddr_end (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: avoid redundant double assignment of nested_run_pending (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix bad cleanup on error of get/set nested state IOCTLs (Paolo Bonzini) [1636610]
- [tools] kvm: selftests: Add platform_info_test (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Control guest reads of MSR_PLATFORM_INFO (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Turbo bits in MSR_PLATFORM_INFO (Paolo Bonzini) [1636610]
- [x86] nVMX x86: Check VPID value on vmentry of L2 guests (Paolo Bonzini) [1636610]
- [x86] nVMX x86: check posted-interrupt descriptor addresss on vmentry of L2 (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Wake blocked vCPU in guest-mode if pending interrupt in virtual APICv (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: check nested state and CR4.VMXE against SMM (Paolo Bonzini) [1636610]
- [x86] kvm: x86: make kvm_{load|put}_guest_fpu() static (Paolo Bonzini) [1636610]
- [x86] x86/hyper-v: rename ipi_arg_{ex, non_ex} structures (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: use preemption timer to force immediate VMExit (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: modify preemption timer bit only when arming timer (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: immediately mark preemption timer expired only for zero value (Paolo Bonzini) [1636610]
- [x86] KVM: SVM: Switch to bitmap_zalloc() (Paolo Bonzini) [1636610]
- [lib] bitmap: Add bitmap_alloc(), bitmap_zalloc() and bitmap_free() (Paolo Bonzini) [1636610]
- [x86] KVM/MMU: Fix comment in walk_shadow_page_lockless_end() (Paolo Bonzini) [1636610]
- [tools] kvm: selftests: use -pthread instead of -lpthread (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: add dirty logging test (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: pass in extra memory when create vm (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: include the tools headers (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: unify the guest port macros (Paolo Bonzini) [1636610]
- [x86] KVM: x86: don't reset root in kvm_mmu_setup() (Paolo Bonzini) [1636610]
- [x86] kvm: mmu: Don't read PDPTEs when paging is not enabled (Paolo Bonzini) [1636610]
- [x86] x86/kvm/lapic: always disable MMIO interface in x2APIC mode (Paolo Bonzini) [1636610]
- [s390] KVM: s390: Make huge pages unavailable in ucontrol VMs (Paolo Bonzini) [1636610]
- [s390] s390/mm: Check for valid vma before zapping in gmap_discard (Paolo Bonzini) [1636610]
- [tools] selftests: add headers_install to lib.mk (Paolo Bonzini) [1636610]
- [tools] selftests: kselftest: Remove outdated comment (Paolo Bonzini) [1636610]
- [tools] selftests: android: move config up a level (Paolo Bonzini) [1636610]
- [md] md: Avoid namespace collision with bitmap API (Paolo Bonzini) [1636610]

* Fri Nov 30 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-48.el8]
- [cpufreq] cpufreq / CPPC: Add cpuinfo_cur_freq support for CPPC (Prarit Bhargava) [1654361]
- [netdrv] nfp: flower: add ipv6 set flow label and hop limit offload (Pablo Cascon) [1651639]
- [netdrv] nfp: flower: add ipv4 set ttl and tos offload (Pablo Cascon) [1651639]
- [netdrv] ibmvnic: Update driver queues after change in ring size support (Steve Best) [1651947]
- [netdrv] ibmvnic: Fix RX queue buffer cleanup (Steve Best) [1651947]
- [netdrv] net/ibmnvic: Fix deadlock problem in reset (Steve Best) [1651947]
- [netdrv] ibmvnic: fix accelerated VLAN handling (Steve Best) [1651947]
- [netdrv] ibmvnic: Add ethtool private flag for driver-defined queue limits (Steve Best) [1651947]
- [netdrv] ibmvnic: Introduce driver limits for ring sizes (Steve Best) [1651947]
- [netdrv] ibmvnic: Increase maximum queue size limit (Steve Best) [1651947]
- [netdrv] ibmvnic: remove ndo_poll_controller (Steve Best) [1651947]
- [powerpc] powerpc/powernv/npu: Remove atsd_threshold debugfs setting (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Use size-based ATSD invalidates (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Reduce eieio usage when issuing ATSD invalidates (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Add a debugfs setting to change ATSD threshold (Steve Best) [1653661]
- [net] libceph: fall back to sendmsg for slab pages (Ilya Dryomov) [1653395]
- [s390] s390/qeth: utilize virtual MAC for Layer2 OSD devices (Philipp Rudo) [1653246]
- [fs] vfs: fix FIGETBSZ ioctl on an overlayfs file (Miklos Szeredi) [1651362]
- [fs] ovl: fix decode of dir file handle with multi lower layers (Miklos Szeredi) [1651362]
- [fs] ovl: fix missing override creds in link of a metacopy upper (Miklos Szeredi) [1651362]
- [fs] ovl: automatically enable redirect_dir on metacopy=on (Miklos Szeredi) [1651362]
- [fs] ovl: check whiteout in ovl_create_over_whiteout() (Miklos Szeredi) [1651362]
- [fs] ovl: fix recursive oi->lock in ovl_link() (Miklos Szeredi) [1651362]
- [fs] ovl: fix error handling in ovl_verify_set_fh() (Miklos Szeredi) [1651362]
- [mm] mm, memory_hotplug: check zone_movable in has_unmovable_pages (Baoquan He) [1643839]
- [netdrv] hv_netvsc: fix vf serial matching with pci slot info (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: remove ndo_poll_controller (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: pair VF based on serial number (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: fix schedule in RCU context (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: Fix return value check in hv_pci_assign_slots() (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: support reporting serial number as slot information (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: Replace GFP_ATOMIC with GFP_KERNEL in new_pcichild_device() (Vitaly Kuznetsov) [1637519]
- [char] ipmi: Fix timer race with module unload (Robert Richter) [1649812]
- [arm64] arm64: hugetlb: Avoid unnecessary clearing in huge_ptep_set_access_flags (Christoph von Recklinghausen) [1635192]
- [arm64] arm64: hugetlb: Fix handling of young ptes (Christoph von Recklinghausen) [1635192]
- [mm] mm: Preserve _PAGE_DEVMAP across mprotect() calls (Jeff Moyer) [1647647]

* Thu Nov 29 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-47.el8]
- [crypto] crypto: vmx - Fix sleep-in-atomic bugs (Steve Best) [1653662]
- [netdrv] net: ena: update driver version from 2.0.1 to 2.0.2 (John Linville) [1634044]
- [netdrv] net: ena: fix crash during ena_remove() (John Linville) [1634044]
- [netdrv] net: ena: fix crash during failed resume from hibernation (John Linville) [1634044]
- [netdrv] net: ena: enable CONFIG_ENA_ETHERNET for aarch64 (John Linville) [1634044]
- [netdrv] net: ena: enable Low Latency Queues (John Linville) [1634044]
- [netdrv] net: ena: Fix Kconfig dependency on X86 (John Linville) [1634044]
- [netdrv] net: ena: fix indentations in ena_defs for better readability (John Linville) [1634044]
- [netdrv] net: ena: update driver version to 2.0.1 (John Linville) [1634044]
- [netdrv] net: ena: remove redundant parameter in ena_com_admin_init() (John Linville) [1634044]
- [netdrv] net: ena: change rx copybreak default to reduce kernel memory pressure (John Linville) [1634044]
- [netdrv] net: ena: limit refill Rx threshold to 256 to avoid latency issues (John Linville) [1634044]
- [netdrv] net: ena: explicit casting and initialization, and clearer error handling (John Linville) [1634044]
- [netdrv] net: ena: use CSUM_CHECKED device indication to report skb's checksum status (John Linville) [1634044]
- [netdrv] net: ena: add functions for handling Low Latency Queues in ena_netdev (John Linville) [1634044]
- [netdrv] net: ena: add functions for handling Low Latency Queues in ena_com (John Linville) [1634044]
- [netdrv] net: ena: introduce Low Latency Queues data structures according to ENA spec (John Linville) [1634044]
- [netdrv] net: ena: complete host info to match latest ENA spec (John Linville) [1634044]
- [netdrv] net: ena: minor performance improvement (John Linville) [1634044]
- [netdrv] net: ena: fix auto casting to boolean (John Linville) [1634044]
- [netdrv] net: ena: fix NULL dereference due to untimely napi initialization (John Linville) [1634044]
- [netdrv] net: ena: fix rare bug when failed restart/resume is followed by driver removal (John Linville) [1634044]
- [netdrv] net: ena: fix warning in rmmod caused by double iounmap (John Linville) [1634044]
- [netdrv] net: ena: remove ndo_poll_controller (John Linville) [1634044]
- [netdrv] net: ena: fix incorrect usage of memory barriers (John Linville) [1634044]
- [netdrv] net: ena: fix missing calls to READ_ONCE (John Linville) [1634044]
- [netdrv] net: ena: fix missing lock during device destruction (John Linville) [1634044]
- [netdrv] net: ena: fix potential double ena_destroy_device() (John Linville) [1634044]
- [netdrv] net: ena: fix device destruction to gracefully free resources (John Linville) [1634044]
- [netdrv] net: ena: fix driver when PAGE_SIZE == 64kB (John Linville) [1634044]
- [netdrv] net: ena: fix surprise unplug NULL dereference kernel crash (John Linville) [1634044]
- [s390] s390/zcrypt: reinit ap queue state machine during device probe (Philipp Rudo) [1653668]
- [s390] s390/kdump: Make elfcorehdr size calculation ABI compliant (Philipp Rudo) [1653245]
- [s390] s390/kdump: Fix elfcorehdr size calculation (Philipp Rudo) [1653245]
- [block] block: fix 32 bit overflow in __blkdev_issue_discard() (Ming Lei) [1638826]
- [ata] libata: blacklist SAMSUNG MZ7TD256HAFV-000L9 SSD (Ming Lei) [1638826]
- [block] block: copy ioprio in __bio_clone_fast() and bounce (Ming Lei) [1638826]
- [trace] kyber: fix wrong strlcpy() size in trace_kyber_latency() (Ming Lei) [1638826]
- [block] floppy: fix race condition in __floppy_read_block_0() (Ming Lei) [1638826]
- [block] block: make blk_try_req_merge() static (Ming Lei) [1638826]
- [block] block: remove dead queue members (Ming Lei) [1638826]
- [block] block: clean up dead code that is now redundant (Ming Lei) [1638826]
- [nvme] nvme: fix boot hang with only being able to get one IRQ vector (Ming Lei) [1638826]
- [block] ide: don't clear special on ide_queue_rq() entry (Ming Lei) [1638826]
- [block] null_blk: remove unused nullb device (Ming Lei) [1638826]
- [block] ide: don't use req->special (Ming Lei) [1638826]
- [block] pd: replace ->special use with private data in the request (Ming Lei) [1638826]
- [block] aoe: replace ->special use with private data in the request (Ming Lei) [1638826]
- [block] skd_main: don't use req->special (Ming Lei) [1638826]
- [block] nullb: remove leftover legacy request code (Ming Lei) [1638826]
- [scsi] fnic: fix fnic_scsi_host_{start,end}_tag (Ming Lei) [1638826]
- [block] block: remove set but not used variable 'et' (Ming Lei) [1638826]
- [block] block: remove the BLKPREP_* values. (Ming Lei) [1638826]
- [scsi] scsi: return blk_status_t from device handler ->prep_fn (Ming Lei) [1638826]
- [scsi] scsi: return blk_status_t from scsi_init_io and ->init_command (Ming Lei) [1638826]
- [scsi] scsi: clean up error handling in scsi_init_io (Ming Lei) [1638826]
- [scsi] scsi: push blk_status_t up into scsi_setup_{fs,scsi}_cmnd (Ming Lei) [1638826]
- [scsi] scsi: simplify scsi_prep_state_check (Ming Lei) [1638826]
- [block] ide: cleanup ->prep_rq calling convention (Ming Lei) [1638826]
- [block] block: remove req->timeout_list (Ming Lei) [1638826]
- [block] blk-mq: provide a helper to check if a queue is busy (Ming Lei) [1638826]
- [block] blk-mq-tag: change busy_iter_fn to return whether to continue or not (Ming Lei) [1638826]
- [block] ms_block: remove unused pointer 'set' (Ming Lei) [1638826]
- [block] sunvdc: fix compiler warning (Ming Lei) [1638826]
- [nvme] nvme: add separate poll queue map (Ming Lei) [1638826]
- [block] block: add REQ_HIPRI and inherit it from IOCB_HIPRI (Ming Lei) [1638826]
- [nvme] nvme: utilize two queue maps, one for reads and one for writes (Ming Lei) [1638826]
- [block] blk-mq: initial support for multiple queue maps (Ming Lei) [1638826]
- [block] blk-mq: improve plug list sorting (Ming Lei) [1638826]
- [block] blk-mq: cleanup and improve list insertion (Ming Lei) [1638826]
- [block] blk-mq: cache request hardware queue mapping (Ming Lei) [1638826]
- [block] blk-mq: separate number of hardware queues from nr_cpu_ids (Ming Lei) [1638826]
- [block] blk-mq: support multiple hctx maps (Ming Lei) [1638826]
- [block] blk-mq: add 'type' attribute to the sysfs hctx directory (Ming Lei) [1638826]
- [block] blk-mq: allow software queue to map to multiple hardware queues (Ming Lei) [1638826]
- [block] blk-mq: pass in request/bio flags to queue mapping (Ming Lei) [1638826]
- [block] blk-mq: provide dummy blk_mq_map_queue_type() helper (Ming Lei) [1638826]
- [block] blk-mq: abstract out queue map (Ming Lei) [1638826]
- [block] blk-mq: kill q->mq_map (Ming Lei) [1638826]
- [kernel] genirq/affinity: Add support for allocating interrupt sets (Ming Lei) [1638826]
- [kernel] genirq/affinity: Pass first vector to __irq_build_affinity_masks() (Ming Lei) [1638826]
- [kernel] genirq/affinity: Move two stage affinity spreading into a helper function (Ming Lei) [1638826]
- [kernel] genirq/affinity: Spread IRQs to all available NUMA nodes (Ming Lei) [1638826]
- [block] block: kill request ->cpu member (Ming Lei) [1638826]
- [block] block: get rid of q->softirq_done_fn() (Ming Lei) [1638826]
- [block] block: get rid of blk_queued_rq() (Ming Lei) [1638826]
- [block] blk-merge: kill dead queue lock held check (Ming Lei) [1638826]
- [block] block: remove req_no_special_merge() from merging code (Ming Lei) [1638826]
- [block] block: kill request slab cache (Ming Lei) [1638826]
- [block] block: remove request_list code (Ming Lei) [1638826]
- [block] bsg: move bsg-lib parts outside of request queue (Ming Lei) [1638826]
- [block] block: kill legacy parts of timeout handling (Ming Lei) [1638826]
- [block] block: remove __blk_put_request() (Ming Lei) [1638826]
- [block] block: get rid of MQ scheduler ops union (Ming Lei) [1638826]
- [block] block: remove dead elevator code (Ming Lei) [1638826]
- [block] block: remove legacy IO schedulers (Ming Lei) [1638826]
- [block] block: cleanup kick/queued handling (Ming Lei) [1638826]
- [block] block: remove non mq parts from the flush code (Ming Lei) [1638826]
- [block] block: remove legacy rq tagging (Ming Lei) [1638826]
- [block] blk-cgroup: remove legacy queue bypassing (Ming Lei) [1638826]
- [block] blk-wbt: kill check for legacy queue type (Ming Lei) [1638826]
- [block] block: remove blk_complete_request() (Ming Lei) [1638826]
- [block] bsg: convert to use blk-mq (Ming Lei) [1638826]
- [block] bsg: provide bsg_remove_queue() helper (Ming Lei) [1638826]
- [block] bsg: pass in desired timeout handler (Ming Lei) [1638826]
- [s390] dasd: remove dead code (Ming Lei) [1638826]
- [block] block: remove q->lld_busy_fn() (Ming Lei) [1638826]
- [scsi] scsi: kill off the legacy IO path (Ming Lei) [1638826]
- [scsi] scsi: provide mq_ops->busy() hook (Ming Lei) [1638826]
- [block] blk-mq: provide mq_ops->busy() hook (Ming Lei) [1638826]
- [block] blk-mq: remove legacy check in queue blk_freeze_queue() (Ming Lei) [1638826]
- [block] blk-mq: remove the request_list usage (Ming Lei) [1638826]
- [block] ide: convert to blk-mq (Ming Lei) [1638826]
- [block] mspro_block: convert to blk-mq (Ming Lei) [1638826]
- [block] ms_block: convert to blk-mq (Ming Lei) [1638826]
- [block] sunvdc: convert to blk-mq (Ming Lei) [1638826]
- [block] null_blk: Add conventional zone configuration for zoned support (Ming Lei) [1638826]
- [ata] libata: Apply NOLPM quirk for SAMSUNG MZ7TD256HAFV-000L9 (Ming Lei) [1638826]
- [block] block, bfq: fix asymmetric scenarios detection (Ming Lei) [1638826]
- [cdrom] gdrom: fix mistake in assignment of error (Ming Lei) [1638826]
- [block] blk-mq: place trace_block_getrq() in correct place (Ming Lei) [1638826]
- [block] block: Introduce blk_revalidate_disk_zones() (Ming Lei) [1638826]
- [block] block: add a report_zones method (Ming Lei) [1638826]
- [block] block: Expose queue nr_zones in sysfs (Ming Lei) [1638826]
- [block] block: Improve zone reset execution (Ming Lei) [1638826]
- [block] block: Introduce BLKGETNRZONES ioctl (Ming Lei) [1638826]
- [block] block: Introduce BLKGETZONESZ ioctl (Ming Lei) [1638826]
- [block] block: Limit allocation of zone descriptors for report zones (Ming Lei) [1638826]
- [block] block: Introduce blkdev_nr_zones() helper (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Fix sd_zbc_check_zones() error checks (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Reduce boot device scan and revalidate time (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Rearrange code (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Remove an assignment from sd_zbc_setup_report_cmnd() (Ming Lei) [1638826]
- [scsi] scsi: sd: don't crash the host on invalid commands (Ming Lei) [1638826]
- [pci] PCI/MSI: Warn and return error if driver enables MSI/MSI-X twice (Ming Lei) [1638826]
- [fs] f2fs: remove request_list check in is_idle() (Ming Lei) [1638826]
- [scsi] scsi: osd: initiator should use mq variant of request ending (Ming Lei) [1638826]
- [scsi] scsi: fnic: replace gross legacy tag hack with blk-mq hack (Ming Lei) [1638826]
- [infiniband] ib_srp: Remove WARN_ON in srp_terminate_io() (Ming Lei) [1638826]
- [scsi] scsi: ufs: Disable blk-mq for now (Ming Lei) [1638826]
- [block] sx8: convert to blk-mq (Ming Lei) [1638826]
- [block] z2ram: convert to blk-mq (Ming Lei) [1638826]
- [cdrom] gdrom: convert to blk-mq (Ming Lei) [1638826]
- [block] floppy: convert to blk-mq (Ming Lei) [1638826]
- [block] ataflop: convert to blk-mq (Ming Lei) [1638826]
- [block] ataflop: fix error handling during setup (Ming Lei) [1638826]
- [block] ataflop: fold headers into C file (Ming Lei) [1638826]
- [block] amiflop: convert to blk-mq (Ming Lei) [1638826]
- [block] amiflop: clean up on errors during setup (Ming Lei) [1638826]
- [block] amiflop: fold headers into C file (Ming Lei) [1638826]
- [block] swim3: convert to blk-mq (Ming Lei) [1638826]
- [block] swim3: add real error handling in setup (Ming Lei) [1638826]
- [block] swim: convert to blk-mq (Ming Lei) [1638826]
- [block] swim: fix cleanup on setup error (Ming Lei) [1638826]
- [mtd] mtd_blkdevs: convert to blk-mq (Ming Lei) [1638826]
- [block] xsysace: convert to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pf to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pd to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pcd to blk-mq (Ming Lei) [1638826]
- [block] ps3disk: convert to blk-mq (Ming Lei) [1638826]
- [block] blk-mq: provide helper for setting up an SQ queue and tag set (Ming Lei) [1638826]
- [block] null_blk: remove set but not used variable 'q' (Ming Lei) [1638826]
- [cdrom] cdrom: don't attempt to fiddle with cdo->capability (Ming Lei) [1638826]
- [block] block: remove bogus check for queue_lock assignment (Ming Lei) [1638826]
- [block] null_blk: remove legacy IO path (Ming Lei) [1638826]
- [block] um: Convert ubd driver to blk-mq (Ming Lei) [1638826]
- [block] skd: fixup usage of legacy IO API (Ming Lei) [1638826]
- [block] aoe: convert aoeblk to blk-mq (Ming Lei) [1638826]
- [block] ide: remove redundant variables queue_run_ms and left (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion convert BUGs to WARNs (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion hints on fastpath (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_reprep helper (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_action helper (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_nz_result function (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion: rename variables (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion: comment on end_request return (Ming Lei) [1638826]
- [scsi] scsi: core: use blk_mq_run_hw_queues in scsi_kick_queue (Ming Lei) [1638826]
- [scsi] scsi: sg: remove bad blk_end_request_all() call (Ming Lei) [1638826]
- [block] blk-mq: complete req in softirq context in case of single queue (Ming Lei) [1638826]
- [block] block, bfq: improve asymmetric scenarios detection (Ming Lei) [1638826]
- [block] block: remove redundant 'default n' from Kconfig-s (Ming Lei) [1638826]
- [block] blk-mq-debugfs: Also show requests that have not yet been started (Ming Lei) [1638826]
- [block] block: Finish renaming REQ_DISCARD into REQ_OP_DISCARD (Ming Lei) [1638826]
- [block] kyber: fix integer overflow of latency targets on 32-bit (Ming Lei) [1638826]
- [block] kyber: add tracepoints (Ming Lei) [1638826]
- [block] kyber: implement improved heuristics (Ming Lei) [1638826]
- [block] kyber: don't make domain token sbitmap larger than necessary (Ming Lei) [1638826]
- [block] block: export blk_stat_enable_accounting() (Ming Lei) [1638826]
- [block] block: move call of scheduler's ->completed_request() hook (Ming Lei) [1638826]
- [block] blk-mq: Enable support for runtime power management (Ming Lei) [1638826]
- [block] block: Make blk_get_request() block for non-PM requests while suspended (Ming Lei) [1638826]
- [block] block: Allow unfreezing of a queue while requests are in progress (Ming Lei) [1638826]
- [lib] percpu-refcount: Introduce percpu_ref_resurrect() (Ming Lei) [1638826]
- [block] block: Schedule runtime resume earlier (Ming Lei) [1638826]
- [block] block: Split blk_pm_add_request() and blk_pm_put_request() (Ming Lei) [1638826]
- [block] block, scsi: Change the preempt-only flag into a counter (Ming Lei) [1638826]
- [block] block: Move power management code into a new source file (Ming Lei) [1638826]
- [block] Blk-throttle: update to use rbtree with leftmost node cached (Ming Lei) [1638826]
- [block] block: use bio_add_page in bio_iov_iter_get_pages (Ming Lei) [1638826]
- [block] blok, bfq: do not plug I/O if all queues are weight-raised (Ming Lei) [1638826]
- [block] block, bfq: inject other-queue I/O into seeky idle queues on NCQ flash (Ming Lei) [1638826]
- [block] block, bfq: correctly charge and reset entity service in all cases (Ming Lei) [1638826]

* Wed Nov 28 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-46.el8]
- [rpmspec] redhat: fix bpf_samples build (Jiri Benc) [1611579]
- [fs] mnt: fix __detach_mounts infinite loop (Benjamin Coddington) [1628736]
- [pci] pcie: Enable Broadom iProc PCIE and mark it is as tech preview (Mark Langsdorf) [1576958]
- [pci] PCI/ACPI: Add iProc PCIe MCFG quirk (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Add ACPI/ECAM support (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Remove PAXC slot check to allow VF support (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Reduce inbound/outbound mapping print level (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Reject unconfigured physical functions from PAXC (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Disable MSI parsing in certain PAXC blocks (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Fix up corrupted PAXC root complex config registers (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Activate PAXC bridge quirk for more devices (Mark Langsdorf) [1576958]

* Tue Nov 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-45.el8]
- [s390] s390/mm: fix mis-accounting of pgtable_bytes (Joe Lawrence) [1644481]
- [mm] mm: add mm_pxd_folded checks to pgtable_bytes accounting functions (Joe Lawrence) [1644481]
- [mm] mm: introduce mm_[p4d|pud|pmd]_folded (Joe Lawrence) [1644481]
- [mm] mm: make the __PAGETABLE_PxD_FOLDED defines non-empty (Joe Lawrence) [1644481]
- [x86] x86/cpu/vmware: Do not trace vmware_sched_clock() (Vitaly Kuznetsov) [1650273]
- [fs] fuse: fix possibly missed wake-up after abort (Lukas Czerner) [1649244]
- [fs] fuse: fix leaked notify reply (Lukas Czerner) [1649244]
- [fs] fuse: fix blocked_waitq wakeup (Lukas Czerner) [1649244]
- [fs] fuse: set FR_SENT while locked (Lukas Czerner) [1649244]
- [fs] fuse: Fix use-after-free in fuse_dev_do_write() (Lukas Czerner) [1649244]
- [fs] fuse: Fix use-after-free in fuse_dev_do_read() (Lukas Czerner) [1649244]
- [fs] fuse: Add missed unlock_page() to fuse_readpages_fill() (Lukas Czerner) [1649244]
- [fs] fuse: Don't access pipe->buffers without pipe_lock() (Lukas Czerner) [1649244]
- [fs] fuse: fix initial parallel dirops (Lukas Czerner) [1649244]
- [fs] fuse: Fix oops at process_init_reply() (Lukas Czerner) [1649244]
- [fs] fuse: umount should wait for all requests (Lukas Czerner) [1649244]
- [fs] fuse: fix unlocked access to processing queue (Lukas Czerner) [1649244]
- [fs] fuse: fix double request_end() (Lukas Czerner) [1649244]
- [fs] fuse: fix use-after-free in fuse_direct_IO() (Lukas Czerner) [1599195]

* Fri Nov 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-44.el8]
- [firmware] efi: Fix debugobjects warning on 'efi_rts_work' (Waiman Long) [1652190]
- [rpmspec] kernel.spec: Do not zip modules on noarch builds (Prarit Bhargava) [1646471]
- [iommu] iommu/amd: Clear memory encryption mask from physical address (Gary Hook) [1640384]

* Thu Nov 22 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-43.el8]
- [powerpc] powerpc/mm/radix: Only need the Nest MMU workaround for R -> RW transition (Steve Best) [1651276]
- [powerpc] powerpc/mm/books3s: Add new pte bit to mark pte temporarily invalid (Steve Best) [1651276]
- [powerpc] powerpc/tm: Fix HFSCR bit for no suspend case (Steve Best) [1651275]

* Wed Nov 21 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-42.el8]
- [powerpc] powerpc/powernv: Fix concurrency issue with npu->mmio_atsd_usage (Steve Best) [1651267]
- [tools] perf tools: Remove ext from struct kmod_path (Jiri Olsa) [1581390]
- [tools] perf tools: Add gzip_is_compressed function (Jiri Olsa) [1581390]
- [tools] perf tools: Add lzma_is_compressed function (Jiri Olsa) [1581390]
- [tools] perf tools: Add is_compressed callback to compressions array (Jiri Olsa) [1581390]
- [tools] perf tools: Move the temp file processing into decompress_kmodule (Jiri Olsa) [1581390]
- [tools] perf tools: Use compression id in decompress_kmodule() (Jiri Olsa) [1581390]
- [tools] perf tools: Store compression id into struct dso (Jiri Olsa) [1581390]
- [tools] perf tools: Add compression id into 'struct kmod_path' (Jiri Olsa) [1581390]
- [tools] perf tools: Make is_supported_compression() static (Jiri Olsa) [1581390]
- [tools] perf tools: Make decompress_to_file() function static (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in __open_dso() (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in symbol__disassemble() (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in read_object_code() (Jiri Olsa) [1581390]
- [rpmspec] redhat: Enable kernel-tools (for kvm_stat) on s390x, too (Thomas Huth) [1631222]

* Tue Nov 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-41.el8]
- [drm] drm/atomic_helper: Stop modesets on unregistered connectors harder (Lyude Paul) [1631575]
- [drm] drm/nouveau: Fix nv50_mstc->best_encoder() (Lyude Paul) [1631575]
- [drm] drm/atomic_helper: Allow DPMS On<->Off changes for unregistered connectors (Lyude Paul) [1631575]
- [drm] drm/i915: Fix intel_dp_mst_best_encoder() (Lyude Paul) [1631575]
- [drm] drm/i915: Skip vcpi allocation for MSTB ports that are gone (Lyude Paul) [1631575]
- [drm] drm/i915: Don't unset intel_connector->mst_port (Lyude Paul) [1631575]
- [drm] drm/atomic_helper: Disallow new modesets on unregistered connectors (Lyude Paul) [1631575]
- [s390] s390/qeth: fix HiperSockets sniffer (Philipp Rudo) [1649773]
- [s390] s390/qeth: report 25Gbit link speed (Philipp Rudo) [1649772]
- [s390] s390/qeth: sanitize strings in debug messages (Philipp Rudo) [1649770]
- [s390] s390/qeth: fix initial operstate (Philipp Rudo) [1649769]
- [s390] s390/qeth: unregister netdevice only when registered (Philipp Rudo) [1649769]
- [powerpc] powerpc/64s: consolidate MCE counter increment (Steve Best) [1633550]
- [powerpc] powerpc/64s: move machine check SLB flushing to mm/slb.c (Steve Best) [1633550]
- [powerpc] powernv/pseries: consolidate code for mce early handling (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Dump the SLB contents on SLB MCE errors (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Display machine check error details (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Flush SLB contents on SLB MCE errors (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Define MCE error event section (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Avoid using the size greater than RTAS_ERROR_LOG_MAX (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Defer the logging of rtas error to irq work queue (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Fix endianness while restoring of r3 in MCE handler (Steve Best) [1633550]
- [cdrom] cdrom: fix improper type cast, which can leat to information leak (Maurizio Lombardi) [1650476]

* Thu Nov 15 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-40.el8]
- [drm] drm/amdgpu/pm: Fix potential Spectre v1 (Rob Clark) [1637115]
- [drm] drm/i915/kvmgt: Fix potential Spectre v1 (Rob Clark) [1637115]
- [fs] gfs2: Fix metadata read-ahead during truncate (2) (Andreas Grunbacher) [1647982]
- [block] block: make sure writesame bio is aligned with logical block size (Ming Lei) [1648750]
- [block] block: cleanup __blkdev_issue_discard() (Ming Lei) [1648750]
- [block] block: make sure discard bio is aligned with logical block size (Ming Lei) [1648750]
- [block] block: Clear kernel memory before copying to user (Ming Lei) [1648752]
- [block] block: respect virtual boundary mask in bvecs (Ming Lei) [1648756]
- [block] xen: don't include <xen/xen.h> from <asm/io.h> and <asm/dma-mapping.h> (Ming Lei) [1648756]
- [block] block: remove ARCH_BIOVEC_PHYS_MERGEABLE (Ming Lei) [1648756]
- [block] xen: provide a prototype for xen_biovec_phys_mergeable in xen.h (Ming Lei) [1648756]
- [block] xen: remove the xen_biovec_phys_mergeable export (Ming Lei) [1648756]
- [block] arm: remove the unused BIOVEC_MERGEABLE define (Ming Lei) [1648756]
- [block] block: don't include bug.h from bio.h (Ming Lei) [1648756]
- [block] block: don't include io.h from bio.h (Ming Lei) [1648756]
- [block] block: remove bvec_to_phys (Ming Lei) [1648756]
- [block] block: merge BIOVEC_SEG_BOUNDARY into biovec_phys_mergeable (Ming Lei) [1648756]
- [block] block: add a missing BIOVEC_SEG_BOUNDARY check in bio_add_pc_page (Ming Lei) [1648756]
- [block] block: simplify BIOVEC_PHYS_MERGEABLE (Ming Lei) [1648756]
- [block] block: move req_gap_back_merge to blk.h (Ming Lei) [1648756]
- [block] block: move req_gap_{back,front}_merge to blk-merge.c (Ming Lei) [1648756]
- [block] block: move integrity_req_gap_{back,front}_merge to blk.h (Ming Lei) [1648756]
- [fs] gfs2: Fix iomap buffer head reference counting bug (Andreas Grunbacher) [1647073]
- [scsi] qla2xxx: Update driver version to 10.00.00.07.08.0-k1 (Himanshu Madhani) [1615896]
- [scsi] scsi: qla2xxx: Initialize port speed to avoid setting lower speed (Himanshu Madhani) [1615896]
- [scsi] scsi: qla2xxx: Fix incorrect port speed being set for FC adapters (Himanshu Madhani) [1615896]
- [block] block: brd: associate with queue until adding disk (Ming Lei) [1644602]
- [block] block: call rq_qos_exit() after queue is frozen (Ming Lei) [1641558]
- [block] block: fix the DISCARD request merge (Ming Lei) [1646776]
- [block] blk-mq: fallback to previous nr_hw_queues when updating fails (Ming Lei) [1642218]
- [block] blk-mq: realloc hctx when hw queue is mapped to another node (Ming Lei) [1642218]
- [block] blk-mq: change gfp flags to GFP_NOIO in blk_mq_realloc_hw_ctxs (Ming Lei) [1642218]
- [block] blk-mq: adjust debugfs and sysfs register when updating nr_hw_queues (Ming Lei) [1642218]
- [block] block: remove bio_rewind_iter() (Ming Lei) [1642208]

* Wed Nov 14 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-39.el8]
- [fs] jbd2: fix use after free in jbd2_log_do_checkpoint() (Lukas Czerner) [1644694]
- [fs] ext4: initialize retries variable in ext4_da_write_inline_data_begin() (Lukas Czerner) [1644694]
- [fs] ext4: fix build error when DX_DEBUG is defined (Lukas Czerner) [1644694]

* Tue Nov 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-38.el8]
- [pinctrl] pinctrl: intel: Add Ice Lake PCH pin controller support (David Arcari) [1483413]
- [netdrv] nfp: flower: fix vlan match by checking both vlan id and vlan pcp (Pablo Cascon) [1645220]
- [netdrv] nfp: flower: reject tunnel encap with ipv6 outer headers for offloading (Pablo Cascon) [1646644]
- [netdrv] nfp: populate bus-info on representors (Pablo Cascon) [1643998]
- [powerpc] KVM: PPC: Validate TCEs against preregistered memory page sizes (David Gibson) [1625821]
- [powerpc] KVM: PPC: Inform the userspace about TCE update failures (David Gibson) [1625821]
- [powerpc] KVM: PPC: Book3S: Fix guest DMA when guest partially backed by THP pages (David Gibson) [1625821]

* Fri Nov 09 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-37.el8]
- [kernel] locking/lockdep: Fix debug_locks off performance problem (Waiman Long) [1647560]
- [kernel] locking/lockdep: Remove duplicated 'lock_class_ops' percpu array (Waiman Long) [1647560]
- [kernel] locking/lockdep: Make class->ops a percpu counter and move it under CONFIG_DEBUG_LOCKDEP=y (Waiman Long) [1647560]
- [kernel] locking/lockdep: Add a faster path in __lock_release() (Waiman Long) [1647560]
- [kernel] locking/lockdep: Eliminate redundant IRQs check in __lock_acquire() (Waiman Long) [1647560]
- [kernel] locking/lockdep: Remove add_chain_cache_classes() (Waiman Long) [1647560]
- [fs] gfs2: Put bitmap buffers in put_super (Andreas Grunbacher) [1647073]
- [scsi] scsi: hpsa: limit transfer length to 1MB, not 512kB (Joseph Szczypek) [1643956]
- [netdrv] nfp: report FW vNIC stats in interface stats (Pablo Cascon) [1645032]
- [rpmspec] spec: Add bpftool debuginfo package (Jiri Olsa) [1633018]
- [crypto] crypto: chelsio: Fix memory corruption in DMA Mapped buffers (Arjun Vynipadath) [1631750]
- [cdrom] cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status (Maurizio Lombardi) [1627732] {CVE-2018-16658}

* Wed Nov 07 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-36.el8]
- [kernel] srcu: Make early-boot call_srcu() reuse workqueue lists (Waiman Long) [1644375]
- [tools] rcutorture: Test early boot call_srcu() (Waiman Long) [1644375]
- [kernel] srcu: Make call_srcu() available during very early boot (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_state.ofl_lock to raw_spinlock_t (Waiman Long) [1644375]
- [kernel] rcu: Remove obsolete ->dynticks_fqs and ->cond_resched_completed (Waiman Long) [1644375]
- [kernel] rcu: Switch ->dynticks to rcu_data structure, remove rcu_dynticks (Waiman Long) [1644375]
- [kernel] rcu: Switch dyntick nesting counters to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch urgent quiescent-state requests to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch lazy counts to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch last accelerate/advance to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch ->tick_nohz_enabled_snap to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Merge rcu_dynticks structure into rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Remove unused rcu_dynticks_snap() from Tiny RCU (Waiman Long) [1644375]
- [kernel] rcu: Convert "1UL << x" to "BIT(x)" (Waiman Long) [1644375]
- [kernel] rcu: Avoid resched_cpu() when rescheduling the current CPU (Waiman Long) [1644375]
- [kernel] rcu: More aggressively enlist scheduler aid for nohz_full CPUs (Waiman Long) [1644375]
- [kernel] rcu: Compute jiffies_till_sched_qs from other kernel parameters (Waiman Long) [1644375]
- [kernel] rcu: Provide functions for determining if call_rcu() has been invoked (Waiman Long) [1644375]
- [kernel] rcu: Eliminate ->rcu_qs_ctr from the rcu_dynticks structure (Waiman Long) [1644375]
- [kernel] rcu: Motivate Tiny RCU forward progress (Waiman Long) [1644375]
- [kernel] rcutorture: Dump reader protection sequence if failures or close calls (Waiman Long) [1644375]
- [kernel] rcu: Provide improved interrupt-from-idle check in rcu_check_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Make need_resched() respond to urgent RCU-QS needs (Waiman Long) [1644375]
- [kernel] rcu: Inline _rcu_barrier() into its sole remaining caller (Waiman Long) [1644375]
- [kernel] rcu: Define rcu_all_qs() only in !PREEMPT builds (Waiman Long) [1644375]
- [kernel] rcu: Remove !PREEMPT code from rcu_note_voluntary_context_switch() (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in update.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree_plugin.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree_exp.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tiny.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in srcutree.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcutorture.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcu.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in Kconfig (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcupdate_wait.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rculist.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcupdate.h (Waiman Long) [1644375]
- [kernel] rcu: Remove now-unused rcutorture APIs (Waiman Long) [1644375]
- [kernel] rcuperf: Remove the "rcu_bh" and "sched" torture types (Waiman Long) [1644375]
- [kernel] rcutorture: Remove the "rcu_bh" and "sched" torture types (Waiman Long) [1644375]
- [kernel] rcu: Stop testing RCU-bh and RCU-sched (Waiman Long) [1644375]
- [kernel] rcutorture: Add RCU-bh and RCU-sched support for extended readers (Waiman Long) [1644375]
- [kernel] rcu: Consolidate RCU-sched update-side function definitions (Waiman Long) [1644375]
- [kernel] rcu: Consolidate RCU-bh update-side function definitions (Waiman Long) [1644375]
- [kernel] rcu: Pull rcu_gp_kthread() FQS loop into separate function (Waiman Long) [1644375]
- [kernel] rcu: Inline increment_cpu_stall_ticks() into its sole caller (Waiman Long) [1644375]
- [kernel] rcu: Fix typo in force_qs_rnp()'s parameter's parameter (Waiman Long) [1644375]
- [kernel] rcu: Eliminate initialization-time use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate RCU-barrier use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate quiescent-state and grace-period-nonstart use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate callback-invocation/invocation use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate grace-period management code use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate stall-warning use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Restructure rcu_check_gp_kthread_starvation() (Waiman Long) [1644375]
- [kernel] rcu: Simplify rcutorture_get_gp_data() (Waiman Long) [1644375]
- [kernel] rcu: Remove for_each_rcu_flavor() flavor-traversal macro (Waiman Long) [1644375]
- [kernel] rcu: Remove last non-flavor-traversal rsp local variable from tree_plugin.h (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_data structure's ->rsp field (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_node tree accessor macros (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from expedited grace-period functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from no-CBs CPU functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_cpu_stall_info() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_spawn_one_boost_kthread() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from dump_blkd_tasks() and friend (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_print_detail_task_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_init_one() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_boot_init_percpu_data() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from _rcu_barrier() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __rcu_pending() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __call_rcu() and friend (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __rcu_process_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_gp_start_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from force-quiescent-state functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_do_batch() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from CPU hotplug functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_quiescent_state() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_kthread() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_slow() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from note_gp_changes() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __note_gp_changes() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_advance_cbs() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs_unlocked() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_kthread_wake() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_future_gp_cleanup() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from check_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_other_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_stall_kick_kthreads() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_dump_cpu_stacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_gp_kthread_starvation() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from record_gp_stall_check_time() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_get_root() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_in_progress() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rdp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_unblock_qs_rnp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rsp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rnp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_data_p pointer to default rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_state_p pointer to default rcu_state structure (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_state structure's ->rda field (Waiman Long) [1644375]
- [kernel] rcu: Eliminate rcu_state structure's ->call field (Waiman Long) [1644375]
- [kernel] rcu: Remove RCU_STATE_INITIALIZER() (Waiman Long) [1644375]
- [kernel] rcu: Express Tiny RCU updates in terms of RCU rather than RCU-sched (Waiman Long) [1644375]
- [kernel] rcu: Define RCU-sched API in terms of RCU for Tree RCU PREEMPT builds (Waiman Long) [1644375]
- [kernel] rcu: Fix typo in rcu_get_gp_kthreads_prio() header comment (Waiman Long) [1644375]
- [kernel] rcu: Drop "wake" parameter from rcu_report_exp_rdp() (Waiman Long) [1644375]
- [kernel] rcu: Update comments and help text for no more RCU-bh updaters (Waiman Long) [1644375]
- [kernel] rcu: Define RCU-bh update API in terms of RCU (Waiman Long) [1644375]
- [kernel] rcu: Report expedited grace periods at context-switch time (Waiman Long) [1644375]
- [kernel] rcu: Apply RCU-bh QSes to RCU-sched and RCU-preempt when safe (Waiman Long) [1644375]
- [kernel] rcu: Add warning to detect half-interrupts (Waiman Long) [1644375]
- [kernel] rcu: Remove now-unused ->b.exp_need_qs field from the rcu_special union (Waiman Long) [1644375]
- [kernel] rcu: Allow processing deferred QSes for exiting RCU-preempt readers (Waiman Long) [1644375]
- [kernel] rcutorture: Test extended "rcu" read-side critical sections (Waiman Long) [1644375]
- [kernel] rcu: Defer reporting RCU-preempt quiescent states when disabled (Waiman Long) [1644375]
- [kernel] rcu: Refactor rcu_{nmi,irq}_{enter,exit}() (Waiman Long) [1644375]
- [documentation] doc: Fix broken HTML directive (Waiman Long) [1644375]
- [documentation] doc: Update removal of RCU-bh/sched update machinery (Waiman Long) [1644375]
- [kernel] rcutorture: Maintain self-propagating CB only during forward-progress test (Waiman Long) [1644375]
- [kernel] rcutorture: Check GP completion at stutter end (Waiman Long) [1644375]
- [kernel] rcutorture: Print forward-progress test interval on error (Waiman Long) [1644375]
- [kernel] rcutorture: Adjust number of reader kthreads per CPU-hotplug operations (Waiman Long) [1644375]
- [kernel] rcutorture: Reduce priority of forward-progress testing (Waiman Long) [1644375]
- [kernel] rcutorture: Limit reader duration if irq or bh disabled (Waiman Long) [1644375]
- [kernel] rcutorture: Increase rcu_read_delay() longdelay_ms (Waiman Long) [1644375]
- [kernel] rcutorture: Add self-propagating callback to forward-progress testing (Waiman Long) [1644375]
- [kernel] rcutorture: Vary forward-progress test interval (Waiman Long) [1644375]
- [kernel] rcutorture: Avoid no-test complaint if too few forward-progress tries (Waiman Long) [1644375]
- [kernel] rcutorture: Also use GP sequence to judge forward progress (Waiman Long) [1644375]
- [kernel] rcutorture: Add forward-progress tests for RCU grace periods (Waiman Long) [1644375]
- [tools] rcutorture: Remove TREE06 and TREE08 from the default test list (Waiman Long) [1644375]
- [kernel] rcuperf: Warn on bad perf type for built-in tests (Waiman Long) [1644375]
- [kernel] rcutorture: Warn on bad torture type for built-in tests (Waiman Long) [1644375]
- [kernel] rcutorture: Force occasional reader waits (Waiman Long) [1644375]
- [tools] torture: Stop overwriting Make.out file with obsolete version (Waiman Long) [1644375]
- [documentation] doc: Improve rcu_dynticks::dynticks documentation (Waiman Long) [1644375]
- [documentation] doc: Fix broken RCU-requirements link to LKML archive (Waiman Long) [1644375]
- [documentation] doc: Add design documentation on interruption of NMI handlers (Waiman Long) [1644375]
- [kernel] rcutorture: Fix rcu_barrier successes counter (Waiman Long) [1644375]
- [kernel] rcutorture: Add support to detect if boost kthread prio is too low (Waiman Long) [1644375]
- [kernel] rcutorture: Use monotonic timestamp for stall detection (Waiman Long) [1644375]
- [kernel] rcutorture: Make boost test more robust (Waiman Long) [1644375]
- [kernel] rcutorture: Disable RT throttling for boost tests (Waiman Long) [1644375]
- [kernel] rcutorture: Emphasize testing of single reader protection type (Waiman Long) [1644375]
- [kernel] rcutorture: Handle extended read-side critical sections (Waiman Long) [1644375]
- [kernel] rcutorture: Make rcu_torture_timer() use rcu_torture_one_read() (Waiman Long) [1644375]
- [kernel] rcutorture: Use per-CPU random state for rcu_torture_timer() (Waiman Long) [1644375]
- [kernel] rcutorture: Use atomic increment for n_rcu_torture_timers (Waiman Long) [1644375]
- [kernel] rcutorture: Extract common code from rcu_torture_reader() (Waiman Long) [1644375]
- [kernel] rcuperf: Remove unused torturing_tasks() function (Waiman Long) [1644375]
- [kernel] rcu: Remove rcutorture test version and sequence number (Waiman Long) [1644375]
- [kernel] rcutorture: Change units of onoff_interval to jiffies (Waiman Long) [1644375]
- [kernel] rcu: Assign higher prio to RCU threads if rcutorture is built-in (Waiman Long) [1644375]
- [documentation] rculist: Improve documentation for list_for_each_entry_from_rcu() (Waiman Long) [1644375]
- [kernel] srcu: Add grace-period number to rcutorture statistics printout (Waiman Long) [1644375]
- [kernel] rcu: Print stall-warning NMI dyntick state in hexadecimal (Waiman Long) [1644375]
- [maintainers] MAINTAINERS: Update RCU, SRCU, and TORTURE-TEST entries (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_seq_diff() more exact (Waiman Long) [1644375]
- [documentation] doc: Update synchronize_rcu() definition in whatisRCU.txt (Waiman Long) [1644375]
- [kernel] rcu: Check the range of jiffies_till_{first, next}_fqs when setting them (Waiman Long) [1644375]
- [kernel] rcu: Add diagnostics for rcutorture writer stall warning (Waiman Long) [1644375]
- [kernel] rcu: Add comment to the last sleep in the rcu tasks loop (Waiman Long) [1644375]
- [kernel] rcu: Speed up calling of RCU tasks callbacks (Waiman Long) [1644375]
- [kernel] rcu: Add comment documenting how rcu_seq_snap works (Waiman Long) [1644375]
- [kernel] rcu: Use RCU CPU stall timeout for rcu_check_gp_start_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove __maybe_unused from rcu_cpu_has_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from rcu_perf_print_module_parms() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from rcu_torture_print_module_parms() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from panic_on_rcu_stall() and rcu_blocking_is_gp() (Waiman Long) [1644375]
- [kernel] rcu: Remove unused local variable "cpu" (Waiman Long) [1644375]
- [kernel] rcu: Remove unused rcu_kick_nohz_cpu() function (Waiman Long) [1644375]
- [kernel] rcu: Clarify and correct the rcu_preempt_qs() header comment (Waiman Long) [1644375]
- [kernel] rcu: Inline rcu_dynticks_momentary_idle() into its sole caller (Waiman Long) [1644375]
- [kernel] rcu: Mark task as .need_qs less aggressively (Waiman Long) [1644375]
- [kernel] rcu: Improve RCU-tasks naming and comments (Waiman Long) [1644375]
- [kernel] rcu: Use pr_fmt to prefix "rcu: " to logging output (Waiman Long) [1644375]
- [kernel] rcu: rcupdate.h: Get rid of Sphinx warnings at rcu_pointer_handoff() (Waiman Long) [1644375]
- [kernel] rcu: Improve rcu_note_voluntary_context_switch() reporting (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_read_unlock_special() static (Waiman Long) [1644375]
- [kernel] rcu: Add diagnostics for offline CPUs failing to report QS (Waiman Long) [1644375]
- [kernel] rcu: Record ->gp_state for both phases of grace-period initialization (Waiman Long) [1644375]
- [kernel] rcu: Add CPU online/offline state to dump_blkd_tasks() (Waiman Long) [1644375]
- [kernel] rcu: Add up-tree information to dump_blkd_tasks() diagnostics (Waiman Long) [1644375]
- [kernel] rcu: Remove CPU-hotplug failsafe from force-quiescent-state code path (Waiman Long) [1644375]
- [kernel] rcu: Remove failsafe check for lost quiescent state (Waiman Long) [1644375]
- [kernel] rcu: Move grace-period pre-init delay after pre-init (Waiman Long) [1644375]
- [kernel] rcu: Add RCU-preempt check for waiting on newly onlined CPU (Waiman Long) [1644375]
- [kernel] rcu: Fix grace-period hangs due to race with CPU offline (Waiman Long) [1644375]
- [kernel] rcu: Fix grace-period hangs from mid-init task resume (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive splats from mid-init task resume (Waiman Long) [1644375]
- [kernel] rcu: Suppress more involved false-positive preempted-task splats (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive preempted-task splats (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive offline-CPU lockdep-RCU splat (Waiman Long) [1644375]
- [kernel] rcu: Prevent useless FQS scan after all CPUs have checked in (Waiman Long) [1644375]
- [kernel] rcu: Replace smp_wmb() with smp_store_release() for stall check (Waiman Long) [1644375]
- [kernel] rcu: Fix typo and add additional debug (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_report_unblock_qs_rnp() warn on violated preconditions (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_init_new_rnp() stop upon already-set bit (Waiman Long) [1644375]
- [kernel] rcu: Fix an obsolete ->qsmaskinit comment (Waiman Long) [1644375]
- [kernel] rcu: Clean up handling of tasks blocked across full-rcu_node offline (Waiman Long) [1644375]
- [kernel] rcu: Identify grace period is in progress as we advance up the tree (Waiman Long) [1644375]
- [kernel] rcu: Use better variable names in funnel locking loop (Waiman Long) [1644375]
- [kernel] rcu: Rename the grace-period-request variables and parameters (Waiman Long) [1644375]
- [kernel] rcu: Regularize resetting of rcu_data wrap indicator (Waiman Long) [1644375]
- [kernel] rcutorture: Correctly handle grace-period sequence wrap (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_start_this_gp() check for grace period already started (Waiman Long) [1644375]
- [kernel] rcu: Fix cpustart tracepoint gp_seq number (Waiman Long) [1644375]
- [kernel] rcu: Produce last "CleanupMore" trace only if late-breaking request (Waiman Long) [1644375]
- [kernel] rcu: Don't funnel-lock above leaf node if GP in progress (Waiman Long) [1644375]
- [documentation] doc: Update RCU CPU stall-warning documentation (Waiman Long) [1644375]
- [documentation] doc: Update memory-ordering documentation for ->gp-seq (Waiman Long) [1644375]
- [documentation] doc: Update data-structure documentation for ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make simple callback acceleration refer to rdp->gp_seq_needed (Waiman Long) [1644375]
- [kernel] rcu: Remove ->gpnum and ->completed (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_fqs tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_quiescent_state_report tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_unlock_preempted_task tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_preempt_task tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_grace_period_init tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_future_grace_period tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_grace_period tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_nocb_wait_gp() check if GP already requested (Waiman Long) [1644375]
- [kernel] rcu: Move from ->need_future_gp[] to ->gp_seq_needed (Waiman Long) [1644375]
- [kernel] rcutorture: Convert rcutorture_get_gp_data() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make RCU CPU stall warnings use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert grace-period requests to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert ->completedqs to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert ->rcu_iw_gpnum to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_gp_in_progress() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_nocb_gp_get() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_try_advance_all_cbs() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_implicit_dynticks_qs() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_gpnum_ovf() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move RCU's grace-period-change code to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert conditional grace-period primitives to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make quiescent-state reporting use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_check_gp_kthread_starvation() to GP sequence number (Waiman Long) [1644375]
- [kernel] rcu: Make rcutorture's batches-completed API use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_gp_slow() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Introduce grace-period sequence numbers (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_gp_cleanup() write only once to ->gp_flags (Waiman Long) [1644375]
- [kernel] rcu: Diagnostics for grace-period startup hangs (Waiman Long) [1644375]
- [kernel] rcu: Exclude near-simultaneous RCU CPU stall warnings (Waiman Long) [1644375]
- [kernel] rcu: Use the proper lockdep annotation in dump_blkd_tasks() (Waiman Long) [1644375]
- [kernel] rcu: Add debugging info to assertion (Waiman Long) [1644375]
- [kernel] torture: Keep old-school dmesg format (Waiman Long) [1644375]
- [kernel] torture: Make online/offline messages appear only for verbose=2 (Waiman Long) [1644375]
- [tools] rcutorture: Make kvm-find-errors.sh find close calls (Waiman Long) [1644375]
- [tools] rcutorture: Remove obsolete TREE08-T.boot file (Waiman Long) [1644375]
- [tools] torture: Use a single build directory for torture scenarios (Waiman Long) [1644375]
- [kernel] srcu: Introduce srcu_read_{un,}lock_notrace() (Waiman Long) [1644375]
- [kernel] srcu: Add address of first callback to rcutorture output (Waiman Long) [1644375]
- [kernel] srcu: Document that srcu_funnel_gp_start() implies srcu_funnel_exp_start() (Waiman Long) [1644375]
- [kernel] srcu: Fix typos in __call_srcu() header comment (Waiman Long) [1644375]
- [kernel] rcu: Make expedited grace period use direct call on last leaf (Waiman Long) [1644375]

* Tue Nov 06 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-35.el8]
- [netdrv] nfp: flower: use offsets provided by pedit instead of index for ipv6 (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: fix multiple keys per pedit action (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: fix pedit set actions for multiple partial masks (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: ignore checksum actions when performing pedit actions (Pablo Cascon) [1644400]
- [kernel] sched/fair: Fix throttle_list starvation with low CFS quota (Phil Auld) [1638526]
- [net] tipc: fix the big/little endian issue in tipc_dest (Jon Maloy) [1640712]
- [rpmspec] kernel.spec: Include kernel-signing-ca.cer public key (Prarit Bhargava) [1638465]
- [block] block: don't deal with discard limit in blkdev_issue_discard() (Ming Lei) [1631255]
- [powerpc] powerpc/mm: Check memblock_add against MAX_PHYSMEM_BITS range (Gustavo Duarte) [1561402]
- [powerpc] powerpc/mm: Increase MAX_PHYSMEM_BITS to 128TB with SPARSEMEM_VMEMMAP config (Gustavo Duarte) [1561402]

* Tue Nov 06 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-34.el8]
- [s390] s390/crypto: Enhance paes cipher to accept variable length key material (Philipp Rudo) [1644387]
- [s390] s390/pkey: move pckmo subfunction available checks away from module init (Philipp Rudo) [1644387]
- [s390] s390/pkey: Load pkey kernel module automatically (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: fix broken zcrypt_send_cprb in-kernel api function (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for transforming key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for random protected key verification (Philipp Rudo) [1644387]
- [s390] s390/pkey: Add sysfs attributes to emit secure key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Add sysfs attributes to emit protected key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Define protected key blob format (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for random protected key generation (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: add ap_adapter_mask sysfs attribute (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: provide apfs failure code on type 86 error reply (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: zcrypt device driver cleanup (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: multiple zcrypt device nodes support (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: enable AP bus scan without a valid default domain (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: Use kmemdup to replace kmalloc + memcpy (Philipp Rudo) [1644387]
- [s390] s390/qeth: add TSO support for L2 devices (Philipp Rudo) [1644381]
- [s390] s390/qeth: add support for IPv6 TSO (Philipp Rudo) [1644381]
- [s390] s390/qeth: enhance TSO control sequence (Philipp Rudo) [1644381]
- [s390] s390/qeth: make TSO controls protocol-agnostic (Philipp Rudo) [1644381]
- [s390] s390: qeth: Fix potential array overrun in cmd/rc lookup (Philipp Rudo) [1644381]
- [s390] s390: qeth_core_mpc: Use ARRAY_SIZE instead of reimplementing its function (Philipp Rudo) [1644381]
- [scsi] scsi: mpt3sas: Remove unnecessary parentheses and simplify null checks (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Use dma_pool_zalloc (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove unused macro MPT3SAS_FMT (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT without logging levels (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove KERN_WARNING from panic uses (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT and reply_q_name to s: (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert mlsleading uses of pr_<level> with MPT3SAS_FMT (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert uses of pr_<level> with MPT3SAS_FMT to ioc_<level> (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Add ioc_<level> logging macros (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix calltrace observed while running IO & reset (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Improve kernel-doc headers (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Split _base_reset_handler(), mpt3sas_scsih_reset_handler() and mpt3sas_ctl_reset_handler() (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix a race condition in mpt3sas_base_hard_reset_handler() (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix _transport_smp_handler() error path (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Introduce struct mpt3sas_nvme_cmd (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Annotate switch/case fall-through (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove set-but-not-used variables (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix indentation (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Update driver version "26.100.00.00" (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: As per MPI-spec, use combined reply queue for SAS3.5 controllers when HBA supports more than 16 MSI-x vectors (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix, False timeout prints for ioctl and other internal commands during controller reset (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Don't access the structure after decrementing it's instance reference count (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Incorrect command status was set/marked as not used (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Don't abort I/Os issued to NVMe drives while processing Async Broadcast primitive event (Tomas Henzl) [1638649]
- [netdrv] net/mlx5e: Do not ignore netdevice TX/RX queues number (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Use non-delayed work for update stats (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Initialize all netdev common structures in one place (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Always initialize update stats delayed work (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Gather common netdev init/cleanup functionality in one place (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Fix netlink support in IPoIB (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Hoist alloc_netdev_mqs out of the driver (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Consolidate checking of the proposed child interface (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Maintain the child_intfs list from ndo_init/uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Do not remove child devices from within the ndo_uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Get rid of the sysfs_mutex (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Use priv_destructor for netdev cleanup (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Move init code to ndo_init (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Move all uninit code into ndo_uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Use cancel_delayed_work_sync for neigh-clean task (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Get rid of IPOIB_FLAG_GOING_DOWN (Alaa Hleihel) [1643103]
- [infiniband] RDMA/ipoib: Fix use of sizeof() (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Do not recycle RX pages in interface down flow (Alaa Hleihel) [1643103 1643047]
- [netdrv] net/mlx5e: Replace call to MPWQE free with dealloc in interface down flow (Alaa Hleihel) [1643103 1643047]
- [net] net/xdp: Fix suspicious RCU usage warning (Alaa Hleihel) [1643103 1643047]
- [netdrv] net/mlx5: WQ, fixes for fragmented WQ buffers API (Alaa Hleihel) [1643103 1636183]
- [netdrv] net/mlx4_en: Use minimal rx and tx ring sizes on kdump kernel (Alaa Hleihel) [1643103 1615267]
- [x86] mark coffeelake-s/h 8+2 as supported (David Arcari) [1575461 1575460]
- [x86] x86/spec_ctrl: Synchronize STIBP changes with RHEL IBRS code (Waiman Long) [1643233]
- [x86] x86/speculation: Propagate information about RSB filling mitigation to sysfs (Waiman Long) [1643233]
- [x86] x86/speculation: Enable cross-hyperthread spectre v2 STIBP mitigation (Waiman Long) [1643233]
- [x86] x86/speculation: Apply IBPB more strictly to avoid cross-process data leak (Waiman Long) [1643233]
- [x86] x86/speculation: Add RETPOLINE_AMD support to the inline asm CALL_NOSPEC variant (Waiman Long) [1643233]
- [x86] x86/CPU: Fix unused variable warning when !CONFIG_IA32_EMULATION (Waiman Long) [1643233]
- [x86] x86/pti/64: Remove the SYSCALL64 entry trampoline (Waiman Long) [1643233]
- [x86] x86/entry/64: Use the TSS sp2 slot for SYSCALL/SYSRET scratch space (Waiman Long) [1643233]
- [x86] x86/entry/64: Document idtentry (Waiman Long) [1643233]
- [x86] x86/asm-offsets: Move TSS_sp0 and TSS_sp1 to asm-offsets.c (Waiman Long) [1643233]
- [x86] x86: Add entry trampolines to kcore (Waiman Long) [1643233]
- [kernel] kallsyms, x86: Export addresses of PTI entry trampolines (Waiman Long) [1643233]
- [kernel] kallsyms: Simplify update_iter_mod() (Waiman Long) [1643233]
- [scsi] scsi: csiostor: fix incorrect port capabilities (Arjun Vynipadath) [1628866]
- [scsi] scsi: csiostor: add a check for NULL pointer after kmalloc() (Arjun Vynipadath) [1628866]
- [scsi] scsi: csiostor: update ingress pack and pad boundary value (Arjun Vynipadath) [1628866]

* Wed Oct 31 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-33.el8]
- [netdrv] nfp: flower: use host context count provided by firmware (Pablo Cascon) [1639609]
- [netdrv] nfp: flower: use stats array instead of storing stats per flow (Pablo Cascon) [1639609]
- [netdrv] nfp: flower: use rhashtable for flow caching (Pablo Cascon) [1639609]
- [netdrv] nfp: avoid soft lockups under control message storm (Pablo Cascon) [1639609]
- [kernel] sched: disable autogroups by default (Phil Auld) [1568166]
- [s390] s390/keyboard: sanitize array index in do_kdsk_ioctl (Steve Best) [1637591]
- [char] ipmi:ssif: Add support for multi-part transmit messages > 2 parts (Tony Camuso) [1622053]
- [scsi] scsi: libsas: fix a race condition when smp task timeout (Zhou Wang) [1640426]
- [scsi] scsi: libsas: check the ata device status by ata_dev_enabled() (Zhou Wang) [1640426]
- [scsi] scsi: libsas: always unregister the old device if going to discover new (Zhou Wang) [1640426]
- [scsi] scsi: libsas: dynamically allocate and free ata host (Zhou Wang) [1640426]
- [scsi] scsi: libsas: remove irq save in sas_ata_qc_issue() (Zhou Wang) [1640426]

* Sat Oct 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-32.el8]
- [video] fbdev: make FB_BACKLIGHT a tristate (Rob Clark) [1643333 1589158]
- [netdrv] Taint kernel if e1000 is loaded (Neil Horman) [1643617]
- [netdrv] iavf: fix a typo (Stefan Assmann) [1627882]
- [netdrv] i40evf: remove ndo_poll_controller (Stefan Assmann) [1627882]
- [netdrv] intel-ethernet: use correct module license (Stefan Assmann) [1627882]
- [netdrv] iavf: finish renaming files to iavf (Stefan Assmann) [1627882]
- [netdrv] iavf: rename most of i40e strings (Stefan Assmann) [1627882]
- [netdrv] iavf: tracing infrastructure rename (Stefan Assmann) [1627882]
- [netdrv] iavf: replace i40e_debug with iavf version (Stefan Assmann) [1627882]
- [netdrv] iavf: rename i40e_hw to iavf_hw (Stefan Assmann) [1627882]
- [netdrv] iavf: rename I40E_ADMINQ_DESC (Stefan Assmann) [1627882]
- [netdrv] iavf: rename device ID defines (Stefan Assmann) [1627882]
- [netdrv] iavf: remove references to old names (Stefan Assmann) [1627882]
- [netdrv] iavf: move i40evf files to new name (Stefan Assmann) [1627882]
- [netdrv] iavf: rename i40e_status to iavf_status (Stefan Assmann) [1627882]
- [netdrv] iavf: rename functions and structs to new name (Stefan Assmann) [1627882]
- [netdrv] iavf: diet and reformat (Stefan Assmann) [1627882]
- [netdrv] configs: enable CONFIG_IAVF=m (Stefan Assmann) [1627882]
- [netdrv] intel-ethernet: rename i40evf to iavf (Stefan Assmann) [1627882]
- [netdrv] i40e(vf): remove i40e_ethtool_stats.h header file (Stefan Assmann) [1627882]
- [netdrv] i40evf: cancel workqueue sync for adminq when a VF is removed (Stefan Assmann) [1627882]
- [netdrv] i40evf: Don't enable vlan stripping when rx offload is turned on (Stefan Assmann) [1627882]
- [netdrv] i40evf: set IFF_UNICAST_FLT flag for the VF (Stefan Assmann) [1627882]
- [netdrv] i40evf: Validate the number of queues a PF sends (Stefan Assmann) [1627882]
- [netdrv] i40evf: Change a VF mac without reloading the VF driver (Stefan Assmann) [1627882]
- [netdrv] i40evf: update ethtool stats code and use helper functions (Stefan Assmann) [1627882]
- [netdrv] i40e: Add AQ command for rearrange NVM structure (Stefan Assmann) [1627882]
- [netdrv] i40e: Add additional return code to i40e_asq_send_command (Stefan Assmann) [1627882]
- [netdrv] i40e/i40evf: remove redundant functions i40evf_aq_(set/get)_phy_register (Stefan Assmann) [1627882]
- [netdrv] cls_flower: fix error values for commands not supported by drivers (Stefan Assmann) [1627882]
- [init] init/main.c: Enable watchdog_thresh control from kernel line (Prarit Bhargava) [1643161]
- [s390] s390/purgatory: Remove duplicate variable definitions (Philipp Rudo) [1642447]
- [s390] s390/purgatory: Add missing FORCE to Makefile targets (Philipp Rudo) [1642447]
- [s390] s390/purgatory: Fix crash with expoline enabled (Philipp Rudo) [1642447]
- [s390] s390: disable asm code expolines if cc does not support it (Philipp Rudo) [1642447]
- [netdrv] Revert be2net: remove desc field from be_eq_obj (Ivan Vecera) [1639867]

* Tue Oct 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-31.el8]
- [rpmspec] redhat: add optional bpf_samples package (Jiri Benc) [1611579]
- [powerpc] powerpc/time: Fix clockevent_decrementer initalisation for PR KVM (Steve Best) [1641615]
- [net] ip: frags: fix crash in ip_do_fragment() (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipfrag: let ip(6)frag_high_thresh in ns be higher than in init_net (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv6: discard IP frag queue on more errors (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: fail fast on IP defrag errors (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: process in-order fragments efficiently (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: add helpers to process in-order fragments faster (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv6: defrag: drop non-last frags smaller than min mtu (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv4: frags: precedence bug in ip_expire() (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: use rb trees for IP frag queue (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] modify skb_rbtree_purge to return the truesize of all purged skbs (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: discard IPv4 datagrams with overlapping segments (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [fs] ovl: fix format of setxattr debug (Miklos Szeredi) [1636875]
- [fs] ovl: fix access beyond unterminated strings (Miklos Szeredi) [1636875]
- [fs] ovl: make symbol 'ovl_aops' static (Miklos Szeredi) [1636875]
- [fs] vfs: swap names of (do,vfs)_clone_file_range() (Miklos Szeredi) [1636875]
- [fs] ovl: fix freeze protection bypass in ovl_clone_file_range() (Miklos Szeredi) [1636875]
- [fs] ovl: fix freeze protection bypass in ovl_write_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: fix memory leak on unlink of indexed file (Miklos Szeredi) [1636875]
- [fs] ovl: fix oopses in ovl_fill_super() failure paths (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fadvise() (Miklos Szeredi) [1636875]
- [fs] vfs: implement readahead(2) using POSIX_FADV_WILLNEED (Miklos Szeredi) [1636875]
- [fs] vfs: add the fadvise() file operation (Miklos Szeredi) [1636875]
- [fs] Documentation/filesystems: update documentation of file_operations (Miklos Szeredi) [1636875]
- [fs] ovl: fix GPF in swapfile_activate of file from overlayfs over xfs (Miklos Szeredi) [1636875]
- [fs] ovl: respect FIEMAP_FLAG_SYNC flag (Miklos Szeredi) [1636875]
- [fs] ovl: Enable metadata only feature (Miklos Szeredi) [1636875]
- [fs] ovl: Do not do metacopy only for ioctl modifying file attr (Miklos Szeredi) [1636875]
- [fs] ovl: Do not do metadata only copy-up for truncate operation (Miklos Szeredi) [1636875]
- [fs] ovl: add helper to force data copy-up (Miklos Szeredi) [1636875]
- [fs] ovl: Check redirect on index as well (Miklos Szeredi) [1636875]
- [fs] ovl: Set redirect on upper inode when it is linked (Miklos Szeredi) [1636875]
- [fs] ovl: Set redirect on metacopy files upon rename (Miklos Szeredi) [1636875]
- [fs] ovl: Do not set dentry type ORIGIN for broken hardlinks (Miklos Szeredi) [1636875]
- [fs] ovl: Add an inode flag OVL_CONST_INO (Miklos Szeredi) [1636875]
- [fs] ovl: Treat metacopy dentries as type OVL_PATH_MERGE (Miklos Szeredi) [1636875]
- [fs] ovl: Check redirects for metacopy files (Miklos Szeredi) [1636875]
- [fs] ovl: Move some dir related ovl_lookup_single() code in else block (Miklos Szeredi) [1636875]
- [fs] ovl: Do not expose metacopy only dentry from d_real() (Miklos Szeredi) [1636875]
- [fs] ovl: Open file with data except for the case of fsync (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_inode_realdata() (Miklos Szeredi) [1636875]
- [fs] ovl: Store lower data inode in ovl_inode (Miklos Szeredi) [1636875]
- [fs] ovl: Fix ovl_getattr() to get number of blocks from lower (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_dentry_lowerdata() to get lower data dentry (Miklos Szeredi) [1636875]
- [fs] ovl: Copy up meta inode data from lowest data inode (Miklos Szeredi) [1636875]
- [fs] ovl: Modify ovl_lookup() and friends to lookup metacopy dentry (Miklos Szeredi) [1636875]
- [fs] ovl: Use out_err instead of out_nomem (Miklos Szeredi) [1636875]
- [fs] ovl: A new xattr OVL_XATTR_METACOPY for file on upper (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_already_copied_up() (Miklos Szeredi) [1636875]
- [fs] ovl: Copy up only metadata during copy up where it makes sense (Miklos Szeredi) [1636875]
- [fs] ovl: During copy up, first copy up metadata and then data (Miklos Szeredi) [1636875]
- [fs] ovl: Provide a mount option metacopy=on/off for metadata copyup (Miklos Szeredi) [1636875]
- [fs] ovl: Move the copy up helpers to copy_up.c (Miklos Szeredi) [1636875]
- [fs] ovl: Initialize ovl_inode->redirect in ovl_get_inode() (Miklos Szeredi) [1636875]
- [fs] ovl: fix documentation of non-standard behavior (Miklos Szeredi) [1636875]
- [fs] ovl: obsolete "check_copy_up" module option (Miklos Szeredi) [1636875]
- [fs] vfs: remove open_flags from d_real() (Miklos Szeredi) [1636875]
- [fs] Revert "fsnotify: support overlayfs" (Miklos Szeredi) [1636875]
- [fs] Partially revert "locks: fix file locking on overlayfs" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: do get_write_access() on upper layer of overlayfs" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: add flags to d_real()" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: update ovl inode before relatime check" (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: fix relatime for directories" (Miklos Szeredi) [1636875]
- [fs] vfs: fix freeze protection in mnt_want_write_file() for overlayfs (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: don't allow writing ioctl on lower layer" (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: fix may_write_real() for overlayfs directories" (Miklos Szeredi) [1636875]
- [fs] vfs: don't open real (Miklos Szeredi) [1636875]
- [fs] ovl: add reflink/copyfile/dedup support (Miklos Szeredi) [1636875]
- [fs] ovl: add O_DIRECT support (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fiemap() (Miklos Szeredi) [1636875]
- [fs] ovl: add lsattr/chattr support (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fallocate() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_mmap() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fsync() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_write_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_read_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: add helper to return real file (Miklos Szeredi) [1636875]
- [fs] ovl: stack file ops (Miklos Szeredi) [1636875]
- [fs] ovl: deal with overlay files in ovl_d_real() (Miklos Szeredi) [1636875]
- [fs] ovl: copy up file size as well (Miklos Szeredi) [1636875]
- [fs] Revert "Revert "ovl: get_write_access() in truncate"" (Miklos Szeredi) [1636875]
- [fs] ovl: copy up inode flags (Miklos Szeredi) [1636875]
- [fs] ovl: copy up times (Miklos Szeredi) [1636875]
- [fs] vfs: export vfs_dedupe_file_range_one() to modules (Miklos Szeredi) [1636875]
- [fs] vfs: export vfs_ioctl() to modules (Miklos Szeredi) [1636875]
- [fs] vfs: make open_with_fake_path() not contribute to nr_files (Miklos Szeredi) [1636875]
- [fs] ovl: fix wrong use of impure dir cache in ovl_iterate() (Miklos Szeredi) [1636875]
- [fs] new helper: open_with_fake_path() (Miklos Szeredi) [1636875]
- [fs] now we can fold open_check_o_direct() into do_dentry_open() (Miklos Szeredi) [1636875]
- [fs] lift fput() on late failures into path_openat() (Miklos Szeredi) [1636875]
- [fs] fold put_filp() into fput() (Miklos Szeredi) [1636875]
- [fs] introduce FMODE_OPENED (Miklos Szeredi) [1636875]
- [fs] ->file_open(): lose cred argument (Miklos Szeredi) [1636875]
- [fs] security_file_open(): lose cred argument (Miklos Szeredi) [1636875]
- [fs] get rid of cred argument of vfs_open() and do_dentry_open() (Miklos Szeredi) [1636875]
- [fs] pass ->f_flags value to alloc_empty_file() (Miklos Szeredi) [1636875]
- [fs] pass creds to get_empty_filp(), make sure dentry_open() passes the right creds (Miklos Szeredi) [1636875]
- [fs] alloc_file(): switch to passing O_... flags instead of FMODE_... mode (Miklos Szeredi) [1636875]
- [fs] make sure do_dentry_open() won't return positive as an error (Miklos Szeredi) [1636875]
- [fs] create_pipe_files(): use fput() if allocation of the second file fails (Miklos Szeredi) [1636875]
- [fs] turn filp_clone_open() into inline wrapper for dentry_open() (Miklos Szeredi) [1636875]
- [fs] fold security_file_free() into file_free() (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: extract helper for a single dedup (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: rationalize args (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: return int (Miklos Szeredi) [1636875]
- [fs] vfs: limit size of dedupe (Miklos Szeredi) [1636875]
- [fs] ovl: set I_CREATING on inode being created (Miklos Szeredi) [1636875]

* Tue Oct 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-30.el8]
- [rpmspec] redhat spec: Add new perf tools file (Jiri Olsa) [1579484]
- [tools] perf tools: Fix use of alternatives to find JDIR (Jiri Olsa) [1579484]
- [net] net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd() (Paolo Abeni) [1637576]
- [thunderbolt] thunderbolt: Add Intel as copyright holder (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Convert rest of the driver files to use SPDX identifier (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Print connected devices (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Make the driver less verbose (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Remove a meaningless NULL pointer check before dma_pool_destroy (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Initialize after IOMMUs (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Do not handle ICM events after domain is stopped (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Add support for runtime PM (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Remove redundant variable 'approved' (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Use correct ICM commands in system suspend (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: No need to take tb->lock in domain suspend/complete (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Do not unnecessarily call ICM get route (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Use 64-bit DMA mask if supported by the platform (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Fix small typo in variable name (Jarod Wilson) [1588929]
- [mm] Revert x86/e820: put !E820_TYPE_RAM regions into memblock.reserved (Baoquan He) [1639450]
- [mm] mm: return zero_resv_unavail optimization (Baoquan He) [1639450]
- [mm] mm: zero remaining unavailable struct pages (Baoquan He) [1639450]
- [mm] mm: skip invalid pages block at a time in zero_resv_unresv() (Baoquan He) [1639450]
- [mm] docs/mm: memblock: update kernel-doc comments (Baoquan He) [1639450]
- [mm] mm/memblock: add a name for memblock flags enumeration (Baoquan He) [1639450]
- [block] blk-wbt: wake up all when we scale up, not down (Ming Lei) [1640035]

* Sat Oct 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-29.el8]
- [video] fbdev: make FB_BACKLIGHT a tristate (Rob Clark) [1589158]
- [kernel] EDAC: Raise the maximum number of memory controllers (Aristeu Rozanski) [1634077]
- [netdrv] i40e: disallow changing the number of descriptors when AF_XDP is on (Stefan Assmann) [1630760]
- [netdrv] i40e: clean zero-copy XDP Rx ring on shutdown/reset (Stefan Assmann) [1630760]
- [netdrv] i40e: clean zero-copy XDP Tx ring on shutdown/reset (Stefan Assmann) [1630760]
- [netdrv] i40e: Remove unused msglen parameter from virtchnl functions (Stefan Assmann) [1630760]
- [netdrv] i40e: fix double 'NIC Link is Down' messages (Stefan Assmann) [1630760]
- [netdrv] i40e: add a helper function to validate a VF based on the vf id (Stefan Assmann) [1630760]
- [netdrv] i40e: use declared variables for pf and hw (Stefan Assmann) [1630760]
- [netdrv] i40e: Unset promiscuous settings on VF reset (Stefan Assmann) [1630760]
- [netdrv] i40e: Fix VF's link state notification (Stefan Assmann) [1630760]
- [netdrv] intel-ethernet: use correct module license (Stefan Assmann) [1630760]
- [netdrv] i40e(vf): remove i40e_ethtool_stats.h header file (Stefan Assmann) [1630760]
- [netdrv] i40e: fix possible compiler warning in xsk TX path (Stefan Assmann) [1630760]
- [netdrv] i40e: add AF_XDP zero-copy Tx support (Stefan Assmann) [1630760]
- [netdrv] i40e: move common Tx functions to i40e_txrx_common.h (Stefan Assmann) [1630760]
- [netdrv] xsk: i40e: get rid of useless struct xdp_umem_props (Stefan Assmann) [1630760]
- [netdrv] i40e: add AF_XDP zero-copy Rx support (Stefan Assmann) [1630760]
- [netdrv] i40e: move common Rx functions to i40e_txrx_common.h (Stefan Assmann) [1630760]
- [netdrv] i40e: refactor Rx path for re-use (Stefan Assmann) [1630760]
- [netdrv] i40e: added queue pair disable/enable functions (Stefan Assmann) [1630760]
- [netdrv] i40e: Prevent deleting MAC address from VF when set by PF (Stefan Assmann) [1630760]
- [netdrv] i40e: hold the rtnl lock on clearing interrupt scheme (Stefan Assmann) [1630760]
- [netdrv] i40e: Check and correct speed values for link on open (Stefan Assmann) [1630760]
- [netdrv] i40e: report correct statistics when XDP is enabled (Stefan Assmann) [1630760]
- [netdrv] i40e: static analysis report from community (Stefan Assmann) [1630760]
- [netdrv] i40e: use correct length for strncpy (Stefan Assmann) [1630760]
- [netdrv] i40evf: Change a VF mac without reloading the VF driver (Stefan Assmann) [1630760]
- [netdrv] i40e: move ethtool stats boiler plate code to i40e_ethtool_stats.h (Stefan Assmann) [1630760]
- [netdrv] i40e: convert queue stats to i40e_stats array (Stefan Assmann) [1630760]
- [netdrv] i40e: fix condition of WARN_ONCE for stat strings (Stefan Assmann) [1630760]
- [netdrv] i40e_txrx: mark expected switch fall-through (Stefan Assmann) [1630760]
- [netdrv] i40e_main: mark expected switch fall-through (Stefan Assmann) [1630760]
- [netdrv] i40e: fix i40e_add_queue_stats data pointer update (Stefan Assmann) [1630760]
- [netdrv] i40e: Add AQ command for rearrange NVM structure (Stefan Assmann) [1630760]
- [netdrv] i40e: Add additional return code to i40e_asq_send_command (Stefan Assmann) [1630760]
- [netdrv] i40e: fix warning about shadowed ring parameter (Stefan Assmann) [1630760]
- [netdrv] i40e: remove unnecessary i variable causing -Wshadow warning (Stefan Assmann) [1630760]
- [netdrv] i40e: convert priority flow control stats to use helpers (Stefan Assmann) [1630760]
- [netdrv] i40e: convert VEB TC stats to use an i40e_stats array (Stefan Assmann) [1630760]
- [netdrv] i40e: Set fec_config when forcing link state (Stefan Assmann) [1630760]
- [netdrv] i40e: add helper to copy statistic values into ethtool buffer (Stefan Assmann) [1630760]
- [netdrv] i40e: add helper function for copying strings from stat arrays (Stefan Assmann) [1630760]
- [netdrv] i40e: Remove duplicated prepare call in i40e_shutdown (Stefan Assmann) [1630760]
- [netdrv] cls_flower: fix error values for commands not supported by drivers (Stefan Assmann) [1630760]
- [netdrv] net: drivers/net: Convert random_ether_addr to eth_random_addr (Stefan Assmann) [1630760]
- [net] ipv4: don't let PMTU updates increase route MTU (Sabrina Dubroca) [1638845]
- [net] ipv4: update fnhe_pmtu when first hop's MTU changes (Sabrina Dubroca) [1638845]
- [net] xsk: add a simple buffer reuse queue (Ivan Vecera) [1634774]
- [net] samples/bpf: add -c/--copy -z/--zero-copy flags to xdpsock (Ivan Vecera) [1634774]
- [net] add napi_if_scheduled_mark_missed (Ivan Vecera) [1634774]
- [net] xsk: expose xdp_umem_get_(data, dma) to drivers (Ivan Vecera) [1634774]
- [net] xdp: export xdp_rxq_info_unreg_mem_model (Ivan Vecera) [1634774]
- [net] xdp: implement convert_to_xdp_frame for MEM_TYPE_ZERO_COPY (Ivan Vecera) [1634774]
- [net] xdp: Helper function to clear kernel pointers in xdp_frame (Ivan Vecera) [1634774]
- [net] xsk: i40e: get rid of useless struct xdp_umem_props (Ivan Vecera) [1631809]
- [net] xdp: fix uninitialized 'err' variable (Ivan Vecera) [1631805]
- [tools] headers uapi: Update tools's copy of linux/if_link.h (Ivan Vecera) [1631805]
- [tools] selftests/bpf: add test for multiple programs (Ivan Vecera) [1631805]
- [net] netdevsim: add support for simultaneous driver and hw XDP (Ivan Vecera) [1631805]
- [net] xdp: support simultaneous driver and hw XDP attachment (Ivan Vecera) [1631805]
- [net] xdp: factor out common program/flags handling from drivers (Ivan Vecera) [1631805]
- [net] xdp: don't make drivers report attachment mode (Ivan Vecera) [1631805]
- [net] xdp: add per mode attributes for attached programs (Ivan Vecera) [1631805]
- [net] sched: cls_flower: set correct offload data in fl_reoffload (Ivan Vecera) [1631522]
- [net] sched: call reoffload op on block callback reg (Ivan Vecera) [1631522]
- [net] sched: cls_bpf: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_u32: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_matchall: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_flower: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: add tcf_proto_op to offload a rule (Ivan Vecera) [1631522]
- [net] sched: pass extack pointer to block binds and cb registration (Ivan Vecera) [1631522]

* Fri Oct 19 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-28.el8]
- [rpmspec] kernel.spec: s390/zfcpdump: add -zfcpdump kernel variant (Philipp Rudo) [1567291]
- [kernel] rh_taint: correct loaddable module support dependencies (Philipp Rudo) [1567291]
- [powerpc] KVM: PPC: Book3S HV: Avoid crash from THP collapse during radix page fault (David Gibson) [1639555]
- [irqchip] irqchip/gic-v3-its: Allow use of LPI tables in reserved memory (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Register LPI tables with EFI config table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Check that all RDs have the same property table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Use pre-programmed redistributor tables with kdump kernels (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Allow use of pre-programmed LPI tables (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Keep track of property table's PA and VA (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Move pending table allocation to init time (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Split property table clearing from allocation (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Simplify LPI_PENDBASE_SZ usage (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Change initialization ordering for LPIs (Jeremy Linton) [1625746]
- [firmware] efi: add API to reserve memory persistently across kexec reboot (Jeremy Linton) [1625746]
- [firmware] efi/arm: libstub: add a root memreserve config table (Jeremy Linton) [1625746]
- [firmware] efi: honour memory reservations passed via a linux specific config table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Cap lpi_id_bits to reduce memory footprint (Jeremy Linton) [1625746]
- [infiniband] RDMA/bnxt_re: Fix system crash during RDMA resource initialization (Selvin Xavier) [1637122]
- [infiniband] RDMA/bnxt_re: Fix couple of memory leaks that could lead to IOMMU call traces (Selvin Xavier) [1637120]
- [arm64] arm64: KVM: Sanitize PSTATE.M when being set from userspace (Wei Huang) [1635721] {CVE-2018-18021}
- [arm64] arm64: KVM: Tighten guest core register access from userspace (Wei Huang) [1635721] {CVE-2018-18021}
- [fs] fs/cifs: require sha512 (Leif Sahlberg) [1610619]
- [fs] smb3: simplify code by removing CONFIG_CIFS_SMB311 (Leif Sahlberg) [1610619]
- [fs] smb3: add support for statfs for smb3.1.1 posix extensions (Leif Sahlberg) [1610619]
- [fs] cifs: allow disabling insecure dialects in the config (Leif Sahlberg) [1610619]
- [fs] smb3: if server does not support posix do not allow posix mount option (Leif Sahlberg) [1610619]

* Tue Oct 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-27.el8]
- [security] cap_inode_getsecurity: use d_find_any_alias() instead of d_find_alias() (Joe Lawrence) [1638647]
- [powerpc] powerpc/cacheinfo: Report the correct shared_cpu_map on big-cores (Steve Best) [1639265]
- [powerpc] powerpc: Use cpu_smallcore_sibling_mask at SMT level on bigcores (Steve Best) [1639265]
- [powerpc] powerpc: Detect the presence of big-cores via ibm, thread-groups (Steve Best) [1639265]
- [x86] mark amd rome as unsupported (David Arcari) [1638506]
- [netdrv] qed: Add support for virtual link (Chad Dupuis) [1638013]
- [netdrv] qede: Add driver support for 20G link speed (Chad Dupuis) [1638013]
- [netdrv] qed: Add driver support for 20G link speed (Chad Dupuis) [1638013]
- [netdrv] qed: Fix shmem structure inconsistency between driver and the mfw (Chad Dupuis) [1638013]
- [netdrv] qed: Add missing device config for RoCE EDPM in UFP mode (Chad Dupuis) [1638013]
- [netdrv] qed: Add a flag which indicates if offload TC is set (Chad Dupuis) [1638013]
- [netdrv] qed: Do not add VLAN 0 tag to untagged frames in multi-function mode (Chad Dupuis) [1638013]
- [netdrv] qed: Fix populating the invalid stag value in multi function mode (Chad Dupuis) [1638013]
- [tools] perf python: Fix pyrf_evlist__read_on_cpu() interface (Jiri Olsa) [1628229]
- [tools] perf mmap: Store real cpu number in 'struct perf_mmap' (Jiri Olsa) [1628229]

* Tue Oct 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-26.el8]
- [fs] gfs2: Fix iomap buffered write support for journaled files (2) (Andreas Grunbacher) [1637944]
- [xen] xen/manage: don't complain about an empty value in control/sysrq node (Vitaly Kuznetsov) [1623344]
- [drm] drm/amdgpu: Silence harmless WARN_ON() during MST disable (Lyude Paul) [1638137]
- [netdrv] net: macb: Fix regression breaking non-MDIO fixed-link PHYs (Petr Oros) [1638259]
- [netdrv] net: macb: do not disable MDIO bus at open/close time (Petr Oros) [1638259]
- [fs] proc: restrict kernel stack dumps to root (Waiman Long) [1638044]
- [base] firmware: Always initialize the fw_priv list object (Waiman Long) [1638044]
- [base] firmware: Fix security issue with request_firmware_into_buf() (Waiman Long) [1638044]
- [fs] sysfs: Do not return POSIX ACL xattrs via listxattr (Waiman Long) [1638044]
- [fs] vfs: don't evict uninitialized inode (Waiman Long) [1638044]
- [fs] new primitive: discard_new_inode() (Waiman Long) [1638044]
- [arm64] arm64: jump_label.h: use asm_volatile_goto macro instead of "asm goto" (Waiman Long) [1638044]
- [kernel] sched/topology: Set correct NUMA topology type (Waiman Long) [1638044]
- [kernel] bpf: 32-bit RSH verification must truncate input before the ALU op (Waiman Long) [1638044]
- [mm] mm: madvise(MADV_DODUMP): allow hugetlbfs pages (Waiman Long) [1638044]
- [x86] x86/pti: Fix section mismatch warning/error (Waiman Long) [1638044]
- [kernel] uaccess: Fix is_source param for check_copy_size() in copy_to_iter_mcsafe() (Waiman Long) [1638044]
- [x86] x86/mm: Expand static page table for fixmap space (Waiman Long) [1638044]
- [fs] fs/lock: skip lock owner pid translation in case we are in init_pid_ns (Waiman Long) [1638044]
- [x86] perf/x86/intel/lbr: Fix incomplete LBR call stack (Waiman Long) [1638044]
- [kernel] perf/hw_breakpoint: Split attribute parse and commit (Waiman Long) [1638044]
- [kernel] bitfield: fix *_encode_bits() (Waiman Long) [1638044]
- [kernel] posix-timers: Sanitize overrun handling (Waiman Long) [1638044]
- [kernel] posix-timers: Make forward callback return s64 (Waiman Long) [1638044]
- [kernel] alarmtimer: Prevent overflow for relative nanosleep (Waiman Long) [1638044]
- [x86] x86/entry/64: Add two more instruction suffixes (Waiman Long) [1638044]
- [powerpc] powerpc/kdump: Handle crashkernel memory reservation failure (Waiman Long) [1638044]
- [s390] s390/mm: correct allocate_pgste proc_handler callback (Waiman Long) [1638044]
- [x86] x86/numa_emulation: Fix emulated-to-physical node mapping (Waiman Long) [1638044]
- [x86] x86/paravirt: Fix some warning messages (Waiman Long) [1638044]
- [kernel] sched/fair: Fix vruntime_normalized() for remote non-migration wakeup (Waiman Long) [1638044]
- [kernel] bpf/verifier: disallow pointer subtraction (Waiman Long) [1638044]
- [mm] mm: shmem.c: Correctly annotate new inodes for lockdep (Waiman Long) [1638044]
- [kernel] sched/core: Use smp_mb() in wake_woken_function() (Waiman Long) [1638044]
- [kernel] bpf: fix rcu annotations in compute_effective_progs() (Waiman Long) [1638044]
- [x86] x86/mm/pti: Add an overflow check to pti_clone_pmds() (Waiman Long) [1638044]
- [x86] x86/pti: Check the return value of pti_user_pagetable_walk_pmd() (Waiman Long) [1638044]
- [x86] x86/pti: Check the return value of pti_user_pagetable_walk_p4d() (Waiman Long) [1638044]
- [powerpc] powerpc/pseries/mm: call H_BLOCK_REMOVE (Steve Best) [1637116]
- [powerpc] powerpc/pseries/mm: factorize PTE slot computation (Steve Best) [1637116]
- [powerpc] powerpc/pseries/mm: Introducing FW_FEATURE_BLOCK_REMOVE (Steve Best) [1637116]
- [watchdog] watchdog/hpwdt: Disable PreTimeout when Timeout is smaller (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Update Driver Documentation (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Update version number (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Module parameter alias (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Display module parameters (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Claim NMI from iLO (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Initialize pretimeout from module parameter (Joseph Szczypek) [1632945]

* Sat Oct 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-25.el8]
- [mm] mm/sparse: delete old sparse_init and enable new one (Baoquan He) [1625105]
- [mm] mm/sparse: add new sparse_init_nid() and sparse_init() (Baoquan He) [1625105]
- [mm] mm/sparse: move buffer init/fini to the common place (Baoquan He) [1625105]
- [mm] mm/sparse: use the new sparse buffer functions in non-vmemmap (Baoquan He) [1625105]
- [mm] mm/sparse: abstract sparse buffer allocations (Baoquan He) [1625105]
- [mm] mm/sparse: optimize memmap allocation during sparse_init() (Baoquan He) [1625105]
- [mm] mm/sparse.c: add a new parameter 'data_unit_size' for alloc_usemap_and_memmap (Baoquan He) [1625105]
- [mm] mm/sparsemem.c: defer the ms->section_mem_map clearing (Baoquan He) [1625105]
- [mm] mm/sparse.c: add a static variable nr_present_sections (Baoquan He) [1625105]
- [mm] mm/sparse.c: make sparse_init_one_section void and remove check (Baoquan He) [1625105]
- [target] scsi: target: iscsi: cxgbit: fix csk leak (Arjun Vynipadath) [1628864]
- [target] scsi: target: iscsi: cxgbit: use pr_debug() instead of pr_info() (Arjun Vynipadath) [1628864]
- [infiniband] iw_cxgb4: only allow 1 flush on user qps (Arjun Vynipadath) [1628865]
- [infiniband] iw_cxgb4: pass window scale in flowc work request (Arjun Vynipadath) [1628865]
- [infiniband] iw_cxgb4: remove duplicate memcpy() in c4iw_create_listen() (Arjun Vynipadath) [1628865]
- [netdrv] mlxsw: spectrum_switchdev: Do not leak RIFs when removing bridge (Petr Oros) [1638268]
- [tty] tty: vt_ioctl: fix potential Spectre v1 (Prarit Bhargava) [1637123]
- [powerpc] powerpc/time: Add set_state_oneshot_stopped decrementer callback (Steve Best) [1638287]
- [powerpc] powerpc/time: Use clockevents_register_device(), fixing an issue with large decrementer (Steve Best) [1638287]
- [hwmon] hwmon: (nct6775) Fix potential Spectre v1 (Dean Nelson) [1637464]
- [vfio] vfio-pci: Disable binding to PFs with SR-IOV enabled (Alex Williamson) [1637871]
- [netdrv] net: hns3: fix page_offset overflow when CONFIG_ARM64_64K_PAGES (Petr Oros) [1638385]
- [netdrv] net: hns: fix skb->truesize underestimation (Petr Oros) [1638385]
- [netdrv] net: hns: fix length and page_offset overflow when CONFIG_ARM64_64K_PAGES (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix get_vector ops in hclgevf_main module (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix warning bug when doing lp selftest (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for mac pause not disable in pfc mode (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for mailbox message truncated problem (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix return value error in hns3_reset_notify_down_enet (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for reset_level default assignment probelm (Petr Oros) [1638385]
- [netdrv] net: hns3: Reset net device with rtnl_lock (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for phy link issue when using marvell phy driver (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for command format parsing error in hclge_is_all_function_id_zero (Petr Oros) [1638385]
- [net] xprtrdma: Fix disconnect regression (Don Dutile) [1635418]
- [infiniband] RDMA/uverbs: Fix validity check for modify QP (Don Dutile) [1635418]
- [infiniband] IB/srp: Avoid that sg_reset -d $srp_device triggers an infinite loop (Don Dutile) [1635418]
- [infiniband] ucma: fix a use-after-free in ucma_resolve_ip() (Don Dutile) [1635418]
- [infiniband] RDMA/uverbs: Atomically flush and mark closed the comp event queue (Don Dutile) [1635418]
- [infiniband] RDMA/mlx4: Ensure that maximal send/receive SGE less than supported by HW (Don Dutile) [1635418 1623100]
- [infiniband] RDMA/cma: Protect cma dev list with lock (Don Dutile) [1635418]
- [infiniband] IB/ipoib: Avoid a race condition between start_xmit and cm_rep_handler (Don Dutile) [1635418]
- [infiniband] RDMA/ucma: check fd type in ucma_migrate_id() (Don Dutile) [1635418]
- [infiniband] RDMA/rxe: Set wqe->status correctly if an unexpected response is received (Don Dutile) [1635418]
- [infiniband] IB/IPoIB: Set ah valid flag in multicast send flow (Don Dutile) [1635418]
- [infiniband] RDMA/core: Avoid holding lock while initializing fields on stack (Don Dutile) [1635418]
- [infiniband] IB/rxe: Drop QP0 silently (Don Dutile) [1635418]
- [infiniband] RDMA/umem: Don't hold mmap_sem for too long (Don Dutile) [1635418]
- [infiniband] IB/srpt: Fix srpt_cm_req_recv() error path (2/2) (Don Dutile) [1635418]
- [infiniband] IB/srpt: Fix srpt_cm_req_recv() error path (1/2) (Don Dutile) [1635418]
- [infiniband] RDMA: Fix storage of PortInfo CapabilityMask in the kernel (Don Dutile) [1635418]
- [infiniband] IB/core: type promotion bug in rdma_rw_init_one_mr() (Don Dutile) [1635418]
- [infiniband] RDMA/i40w: Hold read semaphore while looking after VMA (Don Dutile) [1635418]
- [infiniband] vmw_pvrdma: Release netdev when vmxnet3 module is removed (Don Dutile) [1635418]
- [infiniband] ib_srpt: Fix a use-after-free in __srpt_close_all_ch() (Don Dutile) [1635418]
- [infiniband] ib_srpt: Fix a use-after-free in srpt_close_ch() (Don Dutile) [1635418]
- [infiniband] IB/srpt: Support HCAs with more than two ports (Don Dutile) [1635418]
- [infiniband] IB/rxe: don't clear the tx queue on every transfer (Don Dutile) [1635418]
- [infiniband] IB/core: add max_send_sge and max_recv_sge attributes (Don Dutile) [1635418 1623100]
- [infiniband] IB/rxe: support for 802.1q VLAN on the listener (Don Dutile) [1635418]
- [netdrv] cxgb4: impose mandatory VLAN usage when non-zero TAG ID (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: when max_tx_rate is 0 disable tx rate limiting (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: do not return DUPLEX_UNKNOWN when link is down (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: expose stats fetched from firmware via debugfs (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: remove stats fetched from firmware (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: specify IQTYPE in fw_iq_cmd (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Fix the condition to check if the card is T5 (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Support ethtool private flags (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Add support for FW_ETH_TX_PKT_VM_WR (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Add flag tc_flower_initialized (Arjun Vynipadath) [1628863]
- [s390] s390/zcrypt: remove VLA usage from the AP bus (Philipp Rudo) [1637865]
- [s390] s390/ap_bus: replace PTR_RET with PTR_ERR_OR_ZERO (Philipp Rudo) [1637865]
- [s390] s390/crypto: fix gcc 8 stringop-truncation warning (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: code beautify (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: add copy_from_user length plausibility checks (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: Show load of cards and queues in sysfs (Philipp Rudo) [1637865]
- [s390] s390/kvm: fix deadlock when killed by oom (Philipp Rudo) [1638264]
- [fs] xfs: fix data corruption w/ unaligned reflink ranges (Brian Foster) [1633476]
- [fs] xfs: fix data corruption w/ unaligned dedupe ranges (Brian Foster) [1633476]
- [fs] xfs: update ctime and remove suid before cloning files (Brian Foster) [1633476]
- [fs] xfs: zero posteof blocks when cloning above eof (Brian Foster) [1633476]
- [fs] xfs: refactor clonerange preparation into a separate helper (Brian Foster) [1633476]
- [netdrv] nfp: avoid buffer leak when FW communication fails (Petr Oros) [1638233]
- [netdrv] nfp: don't fail probe on pci_sriov_set_totalvfs() errors (Petr Oros) [1638233]
- [netdrv] nfp: wait for posted reconfigs when disabling the device (Petr Oros) [1638233]
- [netdrv] liquidio: fix hang when re-binding VF host drv after running DPDK VF driver (Petr Oros) [1638224]
- [netdrv] r8169: set RxConfig after tx/rx is enabled for RTL8169sb/8110sb devices (Petr Oros) [1638210]
- [netdrv] r8169: add support for NCube 8168 network card (Petr Oros) [1638210]
- [netdrv] r8169: don't use MSI-X on RTL8106e (Petr Oros) [1638210]
- [netdrv] r8169: don't use MSI-X on RTL8168g (Petr Oros) [1638210]
- [powerpc] KVM: PPC: Book3S HV: Fix guest r11 corruption with POWER9 TM workarounds (David Gibson) [1637766]
- [drm] drm/amdgpu: Suppress keypresses from ACPI_VIDEO events (Lyude Paul) [1631918]
- [infiniband] IB/hfi1: Remove race conditions in user_sdma send path (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Eliminate races in the SDMA send error path (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix destroy_qp hang after a link down (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix context recovery when PBC has an UnsupportedVL (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Invalid user input can result in crash (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix SL array bounds check (Alex Estrin) [1637068]
- [powerpc] powerpc/fadump: re-register firmware-assisted dump if already registered (Steve Best) [1637383]
- [powerpc] powerpc/fadump: cleanup crash memory ranges support (Steve Best) [1637383]
- [powerpc] powerpc/fadump: merge adjacent memory ranges to reduce PT_LOAD segements (Steve Best) [1637383]
- [powerpc] powerpc/fadump: handle crash memory ranges array index overflow (Steve Best) [1637383]
- [scsi] scsi: qedi: Initialize the stats mutex lock (Chad Dupuis) [1637245]
- [fs] gfs2: Fix iomap buffered write support for journaled files (Andreas Grunbacher) [1637944]
- [fs] gfs2: eliminate update_rgrp_lvb_unlinked (Andreas Grunbacher) [1637944]
- [fs] gfs2: Fix gfs2_testbit to use clone bitmaps (Andreas Grunbacher) [1637944]
- [fs] gfs2: Get rid of gfs2_ea_strlen (Andreas Grunbacher) [1637944]
- [fs] GFS2: rgrp free blocks used incorrectly (Andreas Grunbacher) [1637944]
- [fs] gfs2: remove redundant variable 'moved' (Andreas Grunbacher) [1637944]
- [fs] gfs2: use iomap_readpage for blocksize == PAGE_SIZE (Andreas Grunbacher) [1637944]
- [fs] gfs2: Use iomap for stuffed direct I/O reads (Andreas Grunbacher) [1637944]
- [fs] gfs2: fallocate_chunk: Always initialize struct iomap (Andreas Grunbacher) [1637944]
- [fs] gfs2: Remove gfs2_write_(begin,end) (Andreas Grunbacher) [1637944]
- [fs] gfs2: iomap direct I/O support (Andreas Grunbacher) [1637944]
- [fs] gfs2: gfs2_extent_length cleanup (Andreas Grunbacher) [1637944]
- [fs] gfs2: iomap buffered write support (Andreas Grunbacher) [1637944]
- [fs] gfs2: Further iomap cleanups (Andreas Grunbacher) [1637944]
- [fs] fs: gfs2: Adding new return type vm_fault_t (Andreas Grunbacher) [1637944]
- [fs] gfs2: using posix_acl_xattr_size instead of posix_acl_to_xattr (Andreas Grunbacher) [1637944]
- [fs] gfs2: Don't reject a supposedly full bitmap if we have blocks reserved (Andreas Grunbacher) [1637944]
- [fs] gfs2: Eliminate redundant ip->i_rgd (Andreas Grunbacher) [1637944]
- [fs] gfs2: Stop messing with ip->i_rgd in the rlist code (Andreas Grunbacher) [1637944]
- [fs] gfs2: call ktime_get_coarse_real_ts64() directly (Andreas Grunbacher) [1637944]
- [fs] gfs2: Minor clarification to __gfs2_punch_hole (Andreas Grunbacher) [1637944]
- [fs] gfs2: Don't withdraw under a spin lock (Andreas Grunbacher) [1637944]
- [fs] gfs2: eliminate rs_inum and reduce the size of gfs2 inodes (Andreas Grunbacher) [1637944]
- [drm] drm/nouveau/drm/nouveau: Grab runtime PM ref in nv50_mstc_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/disp: fix DP disable race (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Don't forget to cancel hpd_work on suspend/unload (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Prevent handling ACPI HPD events too early (Lyude Paul) [1628749]
- [drm] drm/nouveau: Reset MST branching unit before enabling (Lyude Paul) [1628749]
- [drm] drm/nouveau: Only write DP_MSTM_CTRL when needed (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_enable() call in drm_load() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_disable() call in switcheroo_set_state() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_enable() call in switcheroo_set_state() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Fix deadlocks in nouveau_connector_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Use pm_runtime_get_noresume() in connector_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Fix deadlock with fb_helper with async RPM requests (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove duplicate poll_enable() in pmops_runtime_suspend() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Fix bogus drm_kms_helper_poll_enable() placement (Lyude Paul) [1628749]
- [md] dm table: require that request-based DM be layered on blk-mq devices (Mike Snitzer) [1637682]
- [md] dm: rename DM_TYPE_MQ_REQUEST_BASED to DM_TYPE_REQUEST_BASED (Mike Snitzer) [1637682]
- [md] dm: remove legacy request-based IO path (Mike Snitzer) [1637682]
- [md] dm linear: fix linear_end_io conditional definition (Mike Snitzer) [1637682]
- [md] dm linear: eliminate linear_end_io call if CONFIG_DM_ZONED disabled (Mike Snitzer) [1637682]
- [md] dm: fix report zone remapping to account for partition offset (Mike Snitzer) [1637682]
- [md] dm cache: destroy migration_cache if cache target registration failed (Mike Snitzer) [1637682]
- [md] dm cache: fix resize crash if user doesn't reload cache table (Mike Snitzer) [1637682]
- [md] dm cache metadata: ignore hints array being too small during resize (Mike Snitzer) [1637682]
- [md] dm raid: remove bogus const from decipher_sync_action() return type (Mike Snitzer) [1637682]
- [md] dm mpath: fix attached_handler_name leak and dangling hw_handler_name pointer (Mike Snitzer) [1637682]
- [md] dm thin metadata: fix __udivdi3 undefined on 32-bit (Mike Snitzer) [1637682]
- [md] dm thin metadata: try to avoid ever aborting transactions (Mike Snitzer) [1637682]
- [md] dm raid: bump target version, update comments and documentation (Mike Snitzer) [1637682]
- [md] dm raid: fix RAID leg rebuild errors (Mike Snitzer) [1637682]
- [md] dm raid: fix rebuild of specific devices by updating superblock (Mike Snitzer) [1637682]
- [md] dm raid: fix stripe adding reshape deadlock (Mike Snitzer) [1637682]
- [md] dm raid: fix reshape race on small devices (Mike Snitzer) [1637682]
- [md] dm: disable CRYPTO_TFM_REQ_MAY_SLEEP to fix a GFP_KERNEL recursion deadlock (Mike Snitzer) [1637682]
- [md] dm verity: fix crash on bufio buffer that was allocated with vmalloc (Mike Snitzer) [1637682]
- [md] dm writecache: fix a crash due to reading past end of dirty_bitmap (Mike Snitzer) [1637682]
- [md] dm crypt: don't decrease device limits (Mike Snitzer) [1637682]
- [md] dm cache metadata: set dirty on all cache blocks after a crash (Mike Snitzer) [1637682]
- [md] dm snapshot: remove stale FIXME in snapshot_map() (Mike Snitzer) [1637682]
- [md] dm snapshot: improve performance by switching out_of_order_list to rbtree (Mike Snitzer) [1637682]
- [md] dm kcopyd: avoid softlockup in run_complete_job (Mike Snitzer) [1637682]
- [md] dm cache metadata: save in-core policy_hint_size to on-disk superblock (Mike Snitzer) [1637682]
- [md] dm thin: stop no_space_timeout worker when switching to write-mode (Mike Snitzer) [1637682]
- [md] dm kcopyd: return void from dm_kcopyd_copy() (Mike Snitzer) [1637682]
- [md] dm thin: include metadata_low_watermark threshold in pool status (Mike Snitzer) [1637682]
- [md] dm writecache: report start_sector in status line (Mike Snitzer) [1637682]
- [md] dm crypt: convert essiv from ahash to shash (Mike Snitzer) [1637682]
- [md] dm crypt: use wake_up_process() instead of a wait queue (Mike Snitzer) [1637682]
- [md] dm integrity: recalculate checksums on creation (Mike Snitzer) [1637682]
- [md] dm integrity: flush journal on suspend when using separate metadata device (Mike Snitzer) [1637682]
- [md] dm integrity: use version 2 for separate metadata (Mike Snitzer) [1637682]
- [md] dm integrity: allow separate metadata device (Mike Snitzer) [1637682]
- [md] dm integrity: add ic->start in get_data_sector() (Mike Snitzer) [1637682]
- [md] dm integrity: report provided data sectors in the status (Mike Snitzer) [1637682]
- [md] dm integrity: implement fair range locks (Mike Snitzer) [1637682]
- [md] dm integrity: decouple common code in dm_integrity_map_continue() (Mike Snitzer) [1637682]
- [md] dm integrity: change 'suspending' variable from bool to int (Mike Snitzer) [1637682]
- [md] dm delay: add flush as a third class of IO (Mike Snitzer) [1637682]
- [md] dm delay: refactor repetitive code (Mike Snitzer) [1637682]
- [md] dm cache: only allow a single io_mode cache feature to be requested (Mike Snitzer) [1637682]
- [md] dm thin: update stale "Status" Documentation (Mike Snitzer) [1637682]
- [pci] PCI: Reprogram bridge prefetch registers on resume (Myron Stowe) [1637155]
- [input] Input: xen-kbdfront - fix multi-touch XenStore node's locations (Benjamin Tissoires) [1637027]
- [input] Input: elantech - enable middle button of touchpad on ThinkPad P72 (Benjamin Tissoires) [1637027]
- [hid] HID: i2c-hid: Use devm to allocate i2c_hid struct (Benjamin Tissoires) [1637027]
- [hid] HID: input: fix leaking custom input node name (Benjamin Tissoires) [1637027]
- [hid] HID: core: fix grouping by application (Benjamin Tissoires) [1637027]
- [hid] HID: multitouch: fix Elan panels with 2 input modes declaration (Benjamin Tissoires) [1637027]
- [input] Input: do not use WARN() in input_alloc_absinfo() (Benjamin Tissoires) [1637027]
- [s390] s390: vfio-ap: setup APCB mask using KVM dedicated function (Cornelia Huck) [1508118]
- [s390] KVM: s390: Tracing APCB changes (Cornelia Huck) [1508118]
- [s390] KVM: s390: fix locking for crypto setting error path (Cornelia Huck) [1508118]
- [s390] s390: doc: detailed specifications for AP virtualization (Cornelia Huck) [1508118]
- [s390] KVM: s390: CPU model support for AP virtualization (Cornelia Huck) [1508118]
- [s390] KVM: s390: device attrs to enable/disable AP interpretation (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-0 CRYCB on host FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-1 CRYCB on host FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-0 CRYCB on host FORMAT-1 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow CRYCB FORMAT-0 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow CRYCB FORMAT-1 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Allow CRYCB FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Make use of CRYCB FORMAT2 clear (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Do the CRYCB validation first (Cornelia Huck) [1508118]
- [s390] KVM: s390: Clear Crypto Control Block when using vSIE (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement VFIO_DEVICE_RESET ioctl (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: zeroize the AP queues (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement VFIO_DEVICE_GET_INFO ioctl (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement mediated device open callback (Cornelia Huck) [1508118]
- [s390] KVM: s390: interface to clear CRYCB masks (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interface to view matrix mdev matrix (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure control domains (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure domains (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure adapters (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: register matrix device with VFIO mdev framework (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: base implementation of VFIO AP device driver (Cornelia Huck) [1508118]
- [s390] KVM: s390: refactor crypto initialization (Cornelia Huck) [1508118]
- [s390] KVM: s390: introduce and use KVM_REQ_VSIE_RESTART (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: simulate VCPU SIE entry/exit (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: hex string mask improvements for apmask and aqmask (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: AP bus support for alternate driver(s) (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: switch return type to bool for ap_instructions_available() (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: fix ap_instructions_available() returncodes (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Integrate ap_asm.h into include/asm/ap.h (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Review inline assembler constraints (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Add ZAPQ inline function (Cornelia Huck) [1508118]
- [net] ipv6: use rt6_info members when dst is set in rt6_fill_node (Xin Long) [1625864 1625803 1625117]

* Thu Oct 11 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-24.el8]
- [netdrv] amd-xgbe: use dma_mapping_error to check map errors (David Arcari) [1637666]
- [crypto] crypto: qat - Fix KASAN stack-out-of-bounds bug in adf_probe() (Waiman Long) [1629547]
- [powerpc] powerpc: fix csum_ipv6_magic() on little endian platforms (Diego Domingos) [1625579]
- [net] smc: generic netlink family should be __ro_after_init (Philipp Rudo) [1632435]
- [net] net/smc: fix sizeof to int comparison (Philipp Rudo) [1632435]
- [net] net/smc: no urgent data check for listen sockets (Philipp Rudo) [1632435]
- [net] net/smc: enable fallback for connection abort in state INIT (Philipp Rudo) [1632435]
- [net] net/smc: remove duplicate mutex_unlock (Philipp Rudo) [1632435]
- [net] net/smc: fix non-blocking connect problem (Philipp Rudo) [1632435]
- [net] net/smc: send response to test link signal (Philipp Rudo) [1632435]
- [net] net: simplify sock_poll_wait (Philipp Rudo) [1632435]
- [net] net/smc: Simplify ib_post_(send|recv|srq_recv)() calls (Philipp Rudo) [1632435]
- [net] net/smc: Remove a WARN_ON() statement (Philipp Rudo) [1632435]
- [powerpc] KVM: PPC: Book3S HV: Add NO_HASH flag to GET_SMMU_INFO ioctl result (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add a VM capability to enable nested virtualization (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add nested shadow page tables to debugfs (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Allow HV module to load without hypervisor mode (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle differing endianness for H_ENTER_NESTED (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Sanitise hv_regs on nested guest entry (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add one-reg interface to virtual PTCR register (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Don't access HFSCR, LPIDR or LPCR when running nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Invalidate TLB when nested vcpu moves physical cpu (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use hypercalls for TLB invalidation when nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Implement H_TLB_INVALIDATE hcall (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Introduce rmap to track nested guest mappings (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle page fault for a nested guest (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle hypercalls correctly when nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use XICS hypercalls when running as a nested hypervisor (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Nested guest entry via hypercall (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Framework and hcall stubs for nested virtualization (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use kvmppc_unmap_pte() in kvm_unmap_radix() (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Refactor radix page fault handler (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Make kvmppc_mmu_radix_xlate process/partition table agnostic (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Clear partition table entry on vm teardown (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Use ccr field in pt_regs struct embedded in vcpu struct (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add a debugfs file to dump radix mappings (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle hypervisor instruction faults better (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Streamlined guest entry/exit path on P9 for radix guests (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Call kvmppc_handle_exit_hv() with vcore unlocked (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S: Rework TM save/restore code and make it C-callable (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Simplify real-mode interrupt handling (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Extract PMU save/restore operations as C-callable functions (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Move interrupt delivery on guest entry to C code (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Remove left-over code in XICS-on-XIVE emulation (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S: Simplify external interrupt handling (Suraj Jitindar Singh) [1505999]
- [powerpc] powerpc: Turn off CPU_FTR_P9_TM_HV_ASSIST in non-hypervisor mode (Suraj Jitindar Singh) [1505999]
- [powerpc] powerpc/64s: Remove POWER9 DD1 support (Suraj Jitindar Singh) [1505999]
- [netdrv] net/mlx5: Add Fast teardown support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Set vlan masks for all offloaded TC rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: E-Switch, Fix out of bound access when setting vport rate (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Avoid unbounded peer devices when unpairing TC hairpin rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Cache the system image guid (Alaa Hleihel) [1636554]
- [netdrv] mlx5: remove ndo_poll_controller (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Check for SQ and not RQ state when modifying hairpin SQ (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix read from coherent memory (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: don't set CHECKSUM_COMPLETE on SCTP packets (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Set ECN for received packets using CQE indication (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix possible deadlock from lockdep when adding fte to fg (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Check for error in mlx5_attach_interface (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Consider PCI domain in search for next dev (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix not releasing read lock when adding flow rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: E-Switch, Fix memory leak when creating switchdev mode FDB tables (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use u16 for Work Queue buffer strides offset (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use u16 for Work Queue buffer fragment size (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix debugfs cleanup in the device init/remove flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix use-after-free in self-healing flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Make function mlx5i_grp_sw_update_stats() static (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Use priv stats in completion rx flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Add ndo stats support for IPoIB child devices (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Add ndo stats support for IPoIB netdevices (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Initialize max_opened_tc in mlx5i_init flow (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: Fix leaking stack memory to userspace (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Reorganize the makefile (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: clock.c depends on CONFIG_PTP_1588_CLOCK (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: vxlan.c depends on CONFIG_VXLAN (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Move flow steering declarations into en/fs.h (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add CONFIG_MLX5_EN_ARFS for accelerated flow steering support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add CONFIG_MLX5_EN_RXNFC for ethtool rx nfc (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Ethtool steering, move ethtool callbacks (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Reduce command polling interval (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use max_num_eqs for calculation of required MSIX vectors (Alaa Hleihel) [1636554]
- [netdrv] RDMA/mlx5: Fix shift overflow in mlx5_ib_create_wq (Alaa Hleihel) [1636554]
- [netdrv] overflow.h: Add arithmetic shift helper (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Fix uninitialized variable (Alaa Hleihel) [1636554]
- [netdrv] RDMA: Fix return code check in rdma_set_cq_moderation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, move vxlan logic to core driver (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, add sync lock for add/del vxlan port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, return values for add/del port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, rename from mlx5e to mlx5 (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, rename struct mlx5e_vxlan to mlx5_vxlan_port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, move netdev only logic to en_main.c (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, add direct delete function (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, cleanup an unused member in vxlan work (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, replace ports radix-tree with hash table (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, check maximum number of UDP ports (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, reflect 4789 UDP port default addition to software database (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Move XDP related code into new XDP files (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Restrict the combination of large MTU and XDP (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Gather all XDP pre-requisite checks in a single function (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: avoid excessive warning msgs when creating VFs on 2nd port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Use PARTIAL_GSO for UDP segmentation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Remove redundant WARN when we cannot find neigh entry (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix tristate and description for MLX5 module (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Better return types for CQE API (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use ERR_CAST() instead of coding it (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Add missing SET_DRIVER_VERSION command translation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: Honor cnt_set_id_valid flag instead of set_id (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: Fix GRE flow specification (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: Remove set-but-not-used variables (Alaa Hleihel) [1636554]
- [infiniband] RDMA/mlx5: Don't leak UARs in case of free fails (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Update NIC HW stats on demand only (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add counter for total num of NOP operations (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add counter for MPWQE filler strides (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add channel events counter (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add a counter for congested UMRs (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add NAPI statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add XDP_TX completions statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add TX completions statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: RX, Use existing WQ local variable (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Convert large order kzalloc allocations to kvzalloc (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add UDP GSO remaining counter (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add UDP GSO support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Rate limit errors in command interface (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Prevent warns in dmesg upon firmware commands (Alaa Hleihel) [1636554]
- [netdrv] mlx4: remove ndo_poll_controller (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4: Use cpumask_available for eq->affinity_mask (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4/en_rx: Mark expected switch fall-throughs (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4/mcg: Mark expected switch fall-throughs (Alaa Hleihel) [1636553]
- [infiniband] IB/mlx4: Use 4K pages for kernel QP's WQE buffer (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4_core: Allow MTTs starting at any index (Alaa Hleihel) [1636553]
- [infiniband] IB/mlx4: Test port number before querying type (Alaa Hleihel) [1636553]
- [powerpc] powerpc/numa: Skip onlining a offline node in kdump path (Steve Best) [1637118]
- [netdrv] net: aquantia: Make function aq_fw1x_set_power() static (David Arcari) [1636533]
- [netdrv] net: aquantia: memory corruption on jumbo frames (David Arcari) [1636533 1630377]
- [netdrv] net: aquantia: bump driver version (David Arcari) [1636533]
- [netdrv] net: aquantia: renaming for better visibility (David Arcari) [1636533]
- [netdrv] net: aquantia: whitespace changes (David Arcari) [1636533]
- [netdrv] net: aquantia: implement EEE support (David Arcari) [1636533]
- [netdrv] net: aquantia: implement WOL support (David Arcari) [1636533]
- [netdrv] net: aquantia: definitions for WOL (David Arcari) [1636533]
- [netdrv] net: aquantia: fix hw_atl_utils_fw_upload_dwords (David Arcari) [1636533]
- [netdrv] net: aquantia: Make some functions static (David Arcari) [1636533]
- [netdrv] net: aquantia: bump driver version (David Arcari) [1636533]
- [netdrv] net: aquantia: Add renegotiate ethtool operation support (David Arcari) [1636533]
- [netdrv] net: aquantia: Implement rx/tx flow control ethtools callback (David Arcari) [1636533]
- [netdrv] net: aquantia: Improve adapter init/deinit logic (David Arcari) [1636533]
- [netdrv] net: aquantia: Ethtool based ring size configuration (David Arcari) [1636533]
- [wireless] ath10k: fix memory leak of tpc_stats (Petr Oros) [1637528]
- [wireless] ath10k: snoc: use correct bus-specific pointer in RX retry (Petr Oros) [1637528]
- [wireless] ath10k: fix incorrect size of dma_free_coherent in ath10k_ce_alloc_src_ring_64 (Petr Oros) [1637528]
- [wireless] brcmsmac: fix wrap around in conversion from constant to s16 (Petr Oros) [1637528]
- [wireless] mt76x2: fix mrr idx/count estimation in mt76x2_mac_fill_tx_status() (Petr Oros) [1637528]
- [wireless] ath10k: transmit queued frames after processing rx packets (Petr Oros) [1637528]
- [wireless] ath10k: protect ath10k_htt_rx_ring_free with rx_ring.lock (Petr Oros) [1637528]
- [wireless] ath10k: use locked skb_dequeue for rx completions (Petr Oros) [1637528]
- [wireless] ath10k: sdio: set skb len for all rx packets (Petr Oros) [1637528]
- [wireless] ath10k: sdio: use same endpoint id for all packets in a bundle (Petr Oros) [1637528]
- [wireless] iwlwifi: cancel the injective function between hw pointers to tfd entry index (Petr Oros) [1637528]
- [wireless] ath10k: disable bundle mgmt tx completion event support (Petr Oros) [1637528]
- [wireless] ath10k: prevent active scans on potential unusable channels (Petr Oros) [1637528]
- [wireless] ath9k_hw: fix channel maximum power level test (Petr Oros) [1637528]
- [wireless] ath9k: report tx status on EOSP (Petr Oros) [1637528]
- [wireless] iwlwifi: pcie: don't access periphery registers when not available (Petr Oros) [1637528]
- [wireless] brcmfmac: fix brcmf_wiphy_wowl_params() NULL pointer dereference (Petr Oros) [1637528]
- [netdrv] be2net: don't flip hw_features when VXLANs are added/deleted (Petr Oros) [1637133]
- [netdrv] be2net: Fix memory leak in be_cmd_get_profile_config() (Petr Oros) [1637133]
- [netdrv] be2net: Mark expected switch fall-through (Petr Oros) [1637133]
- [netdrv] be2net: fix spelling mistake "seqence" -> "sequence" (Petr Oros) [1637133]
- [netdrv] be2net: Update the driver version to 12.0.0.0 (Petr Oros) [1637133]
- [netdrv] be2net: gather debug info and reset adapter (only for Lancer) on a tx-timeout (Petr Oros) [1637133]
- [netdrv] be2net: move rss_flags field in rss_info to ensure proper alignment (Petr Oros) [1637133]
- [netdrv] be2net: re-order fields in be_error_recovert to avoid hole (Petr Oros) [1637133]
- [netdrv] be2net: remove unused tx_jiffies field from be_tx_stats (Petr Oros) [1637133]
- [netdrv] be2net: move txcp field in be_tx_obj to eliminate holes in the struct (Petr Oros) [1637133]
- [netdrv] be2net: reorder fields in be_eq_obj structure (Petr Oros) [1637133]
- [netdrv] be2net: remove desc field from be_eq_obj (Petr Oros) [1637133]
- [netdrv] be2net: remove unused old custom busy-poll fields (Petr Oros) [1637133]
- [netdrv] be2net: remove unused old AIC info (Petr Oros) [1637133]
- [x86] x86/spec_ctrl/compat: Call IBRS_ENTRY only after valid kernel stack (Waiman Long) [1636843]
- [acpi] ACPI/PPTT: Handle architecturally unknown cache types (Jeremy Linton) [1636567]
- [base] drivers: base: cacheinfo: Do not populate sysfs for unknown cache types (Jeremy Linton) [1636567]
- [fs] getxattr: use correct xattr length (Lukas Czerner) [1637049]
- [x86] Mark Intel Cascade Lake supported (Steve Best) [1636651]
- [x86] x86/boot: Fix kexec booting failure in the SEV bit detection code (Kairui Song) [1632514]
- [scsi] scsi: megaraid_sas: driver version upgrade (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Support FW provided TM timeout values (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Return immediately from wait_for_adapter_operational after kill adapter (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Update controller info during resume (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Do not do Kill adapter if GET_CTRL_INFO times out (Tomas Henzl) [1635565]
- [scsi] qla2xxx: Update driver version to 10.00.00.07.08.0-k (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Check for Register disconnect (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix driver hang when FC-NVMe LUNs are configured (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix re-using LoopID when handle is in use (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix duplicate switch database entries (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix NVMe session hang on unload (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix iIDMA error (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix stalled relogin (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix unintended Logout (Himanshu Madhani) [1633373]
- [powerpc] powerpc/pseries: Disable CPU hotplug across migrations (Steve Best) [1633587]
- [block] blk-mq: I/O and timer unplugs are inverted in blktrace (Ming Lei) [1634330]
- [block] block: fix deadline elevator drain for zoned block devices (Ming Lei) [1634333]
- [block] blk-mq: Allow blocking queue tag iter callbacks (Ming Lei) [1634328]
- [block] block: use nanosecond resolution for iostat (Ming Lei) [1634329]
- [block] null_blk: fix zoned support for non-rq based operation (Ming Lei) [1634324]
- [block] blk-cgroup: increase number of supported policies (Ming Lei) [1634335]
- [block] block: bfq: swap puts in bfqg_and_blkg_put (Ming Lei) [1634334]
- [block] block: don't warn when doing fsync on read-only devices (Ming Lei) [1634331]
- [block] blkcg: use tryget logic when associating a blkg with a bio (Ming Lei) [1634332]
- [block] blkcg: delay blkg destruction until after writeback has (Ming Lei) [1634332]
- [block] Revert "blk-throttle: fix race between (Ming Lei) [1634332]
- [block] blk-wbt: remove dead code (Ming Lei) [1634326]
- [block] blk-wbt: improve waking of tasks (Ming Lei) [1634326]
- [block] blk-wbt: abstract out end IO completion handler (Ming Lei) [1634326]

* Tue Oct 09 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-23.el8]
- [dma] driver/dma/ioat: Call del_timer_sync() without holding prep_lock (Waiman Long) [1607654]
- [netdrv] bnxt_en: Fix VF mac address regression (Jonathan Toppins) [1635846]
- [netdrv] bnxt_en: Do not adjust max_cp_rings by the ones used by RDMA (Jonathan Toppins) [1635846]
- [netdrv] bnxt_en: Clean up unused functions (Jonathan Toppins) [1635846]
- [fs] fsnotify: fix ignore mask logic in fsnotify() (Lukas Czerner) [1635537]
- [net] net/af_iucv: locate IUCV header via skb_network_header() (Philipp Rudo) [1635332]
- [net] net/af_iucv: drop inbound packets with invalid flags (Philipp Rudo) [1635332]
- [net] net/af_iucv: fix skb handling on HiperTransport xmit error (Philipp Rudo) [1635332]
- [hid] HID: i2c-hid: Fix flooded incomplete report after S3 on Rayd touchscreen (David Arcari) [1635746]
- [i2c] i2c: core: ACPI: Make acpi_gsb_i2c_read_bytes() check i2c_transfer return value (David Arcari) [1635746]
- [i2c] i2c: designware: Re-init controllers with pm_disabled set on resume (David Arcari) [1635746]
- [i2c] i2c: core: ACPI: Properly set status byte to 0 for multi-byte writes (David Arcari) [1635746]
- [fs] fs/quota: Fix spectre gadget in do_quotactl (Lukas Czerner) [1635521]
- [fs] xfs: fix error handling in xfs_bmap_extents_to_btree (Brian Foster) [1633171]
- [fs] xfs: remove invalid log recovery first/last cycle check (Brian Foster) [1633171]
- [fs] xfs: validate inode di_forkoff (Brian Foster) [1633171]
- [fs] xfs: skip delalloc COW blocks in xfs_reflink_end_cow (Brian Foster) [1633171]
- [fs] xfs: don't treat unknown di_flags2 as corruption in scrub (Brian Foster) [1633171]
- [fs] xfs: remove duplicated include from alloc.c (Brian Foster) [1633171]
- [fs] xfs: don't bring in extents in xfs_bmap_punch_delalloc_range (Brian Foster) [1633171]
- [fs] xfs: fix transaction leak in xfs_reflink_allocate_cow() (Brian Foster) [1633171]
- [fs] xfs: avoid lockdep false positives in xfs_trans_alloc (Brian Foster) [1633171]
- [fs] xfs: refactor xfs_buf_log_item reference count handling (Brian Foster) [1633171]
- [fs] xfs: clean up xfs_trans_brelse() (Brian Foster) [1633171]
- [fs] xfs: don't unlock invalidated buf on aborted tx commit (Brian Foster) [1633171]
- [fs] xfs: remove last of unnecessary xfs_defer_cancel() callers (Brian Foster) [1633171]
- [fs] xfs: don't crash the vfs on a garbage inline symlink (Brian Foster) [1633171]
- [fs] iomap: set page dirty after partial delalloc on mkwrite (Brian Foster) [1633171]
- [fs] xfs: sanity check ag header values in xrep_calc_ag_resblks (Brian Foster) [1633171]
- [fs] xfs: recalculate summary counters at mount time if icount is bad (Brian Foster) [1633171]
- [fs] xfs: fix a null pointer dereference in xfs_bmap_extents_to_btree (Brian Foster) [1633171]
- [fs] xfs: remove b_last_holder & associated macros (Brian Foster) [1633171]
- [fs] xfs: repair the AGI (Brian Foster) [1633171]
- [fs] xfs: repair the AGFL (Brian Foster) [1633171]
- [fs] xfs: repair the AGF (Brian Foster) [1633171]
- [fs] xfs: remove dead error handling code in xfs_dquot_disk_alloc() (Brian Foster) [1633171]
- [fs] xfs: use WRITE_ONCE to update if_seq (Brian Foster) [1633171]
- [fs] xfs: fix a comment in xfs_log_reserve (Brian Foster) [1633171]
- [fs] xfs: only validate summary counts on primary superblock (Brian Foster) [1633171]
- [fs] xfs: substitute spaces with tabs (Brian Foster) [1633171]
- [fs] xfs: fold dfops into the transaction (Brian Foster) [1633171]
- [fs] xfs: always defer agfl block frees (Brian Foster) [1633171]
- [fs] xfs: pass transaction to xfs_defer_add() (Brian Foster) [1633171]
- [fs] xfs: replace xfs_defer_ops ->dop_pending with on-stack list (Brian Foster) [1633171]
- [fs] xfs: cancel dfops on xfs_defer_finish() error (Brian Foster) [1633171]
- [fs] xfs: clean out superfluous dfops dop params/vars (Brian Foster) [1633171]
- [fs] xfs: drop dop param from xfs_defer_op_type ->finish_item() callback (Brian Foster) [1633171]
- [fs] xfs: automatic dfops inode relogging (Brian Foster) [1633171]
- [fs] xfs: automatic dfops buffer relogging (Brian Foster) [1633171]
- [fs] xfs: add missing defer ijoins for held inodes (Brian Foster) [1633171]
- [fs] xfs: replace dop_low with transaction flag (Brian Foster) [1633171]
- [fs] xfs: pass transaction to dfops reset/move helpers (Brian Foster) [1633171]
- [fs] xfs: remove unused __xfs_defer_cancel() internal helper (Brian Foster) [1633171]
- [fs] xfs: use transaction for intent recovery instead of raw dfops (Brian Foster) [1633171]
- [fs] xfs: refactor internal dfops initialization (Brian Foster) [1633171]
- [fs] xfs: check da node magic in _node_lookup_int (Brian Foster) [1633171]
- [fs] xfs: use a local variable for magic number in xfs_da3_node_lookup_int (Brian Foster) [1633171]
- [fs] xfs: refactor log recovery check (Brian Foster) [1633171]
- [fs] xfs: move extent busy tree initialization to xfs_initialize_perag (Brian Foster) [1633171]
- [fs] xfs: avoid COW fork extent lookups in writeback if the fork didn't change (Brian Foster) [1633171]
- [fs] xfs: maintain a sequence count for inode fork manipulations (Brian Foster) [1633171]
- [fs] xfs: check for unknown v5 feature bits in superblock write verifier (Brian Foster) [1633171]
- [fs] xfs: verify icount in superblock write (Brian Foster) [1633171]
- [fs] libxfs: add more bounds checking to sb sanity checks (Brian Foster) [1633171]
- [fs] xfs: refactor superblock verifiers (Brian Foster) [1633171]
- [fs] xfs: refactor the xrep_extent_list into xfs_bitmap (Brian Foster) [1633171]
- [fs] xfs: introduce a new xfs_inode_has_cow_data helper (Brian Foster) [1633171]
- [fs] xfs: remove the xfs_ifork_t typedef (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_idata_realloc (Brian Foster) [1633171]
- [fs] xfs: remove if_real_bytes (Brian Foster) [1633171]
- [fs] xfs: move the repair extent list into its own file (Brian Foster) [1633171]
- [fs] xfs: pass transaction lock while setting up agresv on cyclic metadata (Brian Foster) [1633171]
- [fs] xfs: remove deprecated barrier/nobarrier mount (Brian Foster) [1633171]
- [fs] xfs: clean up IRELE/iput callsites (Brian Foster) [1633171]
- [fs] xfs: kill IHOLD (Brian Foster) [1633171]
- [fs] xfs: bypass final dfops roll in trans commit path (Brian Foster) [1633171]
- [fs] xfs: drop unnecessary xfs_defer_finish() dfops parameter (Brian Foster) [1633171]
- [fs] xfs: remove unnecessary dfops init calls in xattr code (Brian Foster) [1633171]
- [fs] xfs: remove all boilerplate defer init/finish code (Brian Foster) [1633171]
- [fs] xfs: use internal dfops during (b|c)ui recovery (Brian Foster) [1633171]
- [fs] xfs: use internal dfops in attr code (Brian Foster) [1633171]
- [fs] xfs: use internal dfops in cow blocks cancel (Brian Foster) [1633171]
- [fs] xfs: support embedded dfops in transaction (Brian Foster) [1633171]
- [fs] xfs: pack holes in xfs_defer_ops and xfs_trans (Brian Foster) [1633171]
- [fs] xfs: reset dfops to initial state after finish (Brian Foster) [1633171]
- [fs] xfs: remove unused deferred ops committed field (Brian Foster) [1633171]
- [fs] xfs: make deferred processing safe for embedded dfops (Brian Foster) [1633171]
- [fs] xfs: fix transaction leak on remote attr set/remove failure (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in log recovery intent processing (Brian Foster) [1633171]
- [fs] xfs: pull up dfops from xfs_itruncate_extents() (Brian Foster) [1633171]
- [fs] xfs: force summary counter recalc at next mount (Brian Foster) [1633171]
- [fs] xfs: refactor unmount record write (Brian Foster) [1633171]
- [fs] xfs: detect and fix bad summary counts at mount (Brian Foster) [1633171]
- [fs] xfs: fix indentation and other whitespace problems in scrub/repair (Brian Foster) [1633171]
- [fs] xfs: shorten struct xfs_scrub_context to struct xfs_scrub (Brian Foster) [1633171]
- [fs] xfs: shorten xfs_repair_ prefix to xrep_ (Brian Foster) [1633171]
- [fs] xfs: shorten xfs_scrub_ prefix (Brian Foster) [1633171]
- [fs] xfs: clean up xfs_btree_del_cursor callers (Brian Foster) [1633171]
- [fs] xfs: trivial xfs_btree_del_cursor cleanups (Brian Foster) [1633171]
- [fs] xfs: return from _defer_finish with a clean transaction (Brian Foster) [1633171]
- [fs] xfs: check leaf attribute block freemap in verifier (Brian Foster) [1633171]
- [fs] libxfs: Fix a couple of sparse complaintis (Brian Foster) [1633171]
- [fs] xfs: use swap macro in xfs_dir2_leafn_rebalance (Brian Foster) [1633171]
- [fs] xfs_bmap_util: use swap macro (Brian Foster) [1633171]
- [fs] xfs_attr_leaf: use swap macro in xfs_attr3_leaf_rebalance (Brian Foster) [1633171]
- [fs] xfs: don't assume a left rmap when allocating a new rmap (Brian Foster) [1633171]
- [fs] xfs: kill __xfs_buf_submit_common() (Brian Foster) [1633171]
- [fs] xfs: combine (a)sync buffer submission apis (Brian Foster) [1633171]
- [fs] xfs: use sync buffer I/O for sync delwri queue submission (Brian Foster) [1633171]
- [fs] xfs: refactor buffer submission into a common helper (Brian Foster) [1633171]
- [fs] xfs: remove xfs_defer_init() firstblock param (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in inode inactivate (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in extent swap (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in reflink cow block cancel (Brian Foster) [1633171]
- [fs] xfs: replace no-op firstblock init with ->t_firstblock (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in dq alloc (Brian Foster) [1633171]
- [fs] xfs: remove xfs_alloc_arg firstblock field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_btree_cur private firstblock field (Brian Foster) [1633171]
- [fs] xfs: remove bmap format helpers firstblock params (Brian Foster) [1633171]
- [fs] xfs: remove bmap extent add helper firstblock params (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmalloca firstblock field (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in bmap extent split (Brian Foster) [1633171]
- [fs] xfs: remove bmap insert/collapse firstblock param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bunmapi() firstblock param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_write() firstblock param (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in insert/collapse range (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in xfs_bmapi_remap() (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock for all xfs_bunmapi() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock for all xfs_bmapi_write() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in xattr ops (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in attrfork add (Brian Foster) [1633171]
- [fs] xfs: remove firstblock param from xfs dir ops (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in dir ops (Brian Foster) [1633171]
- [fs] xfs: add firstblock field to xfs_trans (Brian Foster) [1633171]
- [fs] xfs: allow null firstblock in xfs_bmapi_write() when tp is null (Brian Foster) [1633171]
- [fs] xfs: refactor dfops init to attach to transaction (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in reflink cow recover path (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in cancel cow blocks operation (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for rmap extent swap operations (Brian Foster) [1633171]
- [fs] xfs: remove unused btree cursor bc_private.a.dfops field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_btree_cur bmbt dfops field (Brian Foster) [1633171]
- [fs] xfs: remove dfops param from internal bmap extent helpers (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for collapse/insert range operations (Brian Foster) [1633171]
- [fs] xfs: remove struct xfs_bmalloca dfops field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_remap() dfops param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bunmapi() dfops param (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for all xfs_bunmapi() callers (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_write() dfops param (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for all xfs_bmapi_write() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in dqalloc transaction (Brian Foster) [1633171]
- [fs] xfs: replace xfs_da_args->dfops accesses with ->t_dfops and remove (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in extent split tx and remove param (Brian Foster) [1633171]
- [fs] xfs: remove dfops param in attr fork add path (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for attr set/remove operations (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for recovery of (b|c)ui log items (Brian Foster) [1633171]
- [fs] xfs: remove dfops param from high level dirname calls (Brian Foster) [1633171]
- [fs] xfs: remove dfops parameter from ifree call stack (Brian Foster) [1633171]
- [fs] xfs: rename xfs_trans ->t_agfl_dfops to ->t_dfops (Brian Foster) [1633171]
- [fs] xfs: cow unwritten conversion uses uninitialized dfops (Brian Foster) [1633171]
- [fs] xfs: update my copyrights for the writeback and iomap code (Brian Foster) [1633171]
- [fs] xfs: add support for sub-pagesize writeback without buffer_heads (Brian Foster) [1633171]
- [fs] xfs: allow writeback on pages without buffer heads (Brian Foster) [1633171]
- [fs] xfs: refactor the tail of xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: remove xfs_start_page_writeback (Brian Foster) [1633171]
- [fs] xfs: move all writeback buffer_head manipulation into xfs_map_at_offset (Brian Foster) [1633171]
- [fs] xfs: don't look at buffer heads in xfs_add_to_ioend (Brian Foster) [1633171]
- [fs] xfs: remove the imap_valid flag (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_map_blocks by using xfs_iext_lookup_extent directly (Brian Foster) [1633171]
- [fs] xfs: remove xfs_reflink_find_cow_mapping (Brian Foster) [1633171]
- [fs] xfs: remove the now unused XFS_BMAPI_IGSTATE flag (Brian Foster) [1633171]
- [fs] xfs: make xfs_writepage_map extent map centric (Brian Foster) [1633171]
- [fs] xfs: rename the offset variable in xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: remove xfs_map_cow (Brian Foster) [1633171]
- [fs] xfs: remove xfs_reflink_trim_irec_to_next_cow (Brian Foster) [1633171]
- [fs] xfs: don't use XFS_BMAPI_IGSTATE in xfs_map_blocks (Brian Foster) [1633171]
- [fs] xfs: don't clear imap_valid for a non-uptodate buffers (Brian Foster) [1633171]
- [fs] xfs: do not set the page uptodate in xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: move locking into xfs_bmap_punch_delalloc_range (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_aops_discard_page (Brian Foster) [1633171]
- [fs] xfs: use iomap for blocksize == PAGE_SIZE readpage and readpages (Brian Foster) [1633171]
- [fs] iomap: fix WARN_ON_ONCE on uninitialized variable (Brian Foster) [1633171]
- [fs] iomap: Switch to offset_in_page for clarity (Brian Foster) [1633171]
- [fs] iomap: add support for sub-pagesize buffered I/O without buffer heads (Brian Foster) [1633171]
- [fs] iomap: add inline data support to iomap_readpage_actor (Brian Foster) [1633171]
- [fs] iomap: support direct I/O to inline data (Brian Foster) [1633171]
- [fs] iomap: refactor iomap_dio_actor (Brian Foster) [1633171]
- [fs] iomap: add initial support for writes without buffer heads (Brian Foster) [1633171]
- [fs] iomap: add an iomap-based readpage and readpages implementation (Brian Foster) [1633171]
- [fs] iomap: add private pointer to struct iomap (Brian Foster) [1633171]
- [fs] iomap: add a page_done callback (Brian Foster) [1633171]
- [fs] iomap: generic inline data handling (Brian Foster) [1633171]
- [fs] iomap: complete partial direct I/O writes synchronously (Brian Foster) [1633171]
- [fs] iomap: mark newly allocated buffer heads as new (Brian Foster) [1633171]
- [fs] fs: factor out a __generic_write_end helper (Brian Foster) [1633171]
- [netdrv] amd-xgbe: mark driver as tech preview (David Arcari) [1633209]
- [fs] ext4, dax: set ext4_dax_aops for dax files (Lukas Czerner) [1633239]
- [fs] ext4, dax: add ext4_bmap to ext4_dax_aops (Lukas Czerner) [1633239]
- [fs] ext4: don't mark mmp buffer head dirty (Lukas Czerner) [1633239]
- [fs] ext4: show test_dummy_encryption mount option in /proc/mounts (Lukas Czerner) [1633239]
- [fs] ext4: fix online resizing for bigalloc file systems with a 1k block size (Lukas Czerner) [1633239]
- [fs] ext4: fix online resize's handling of a too-small final block group (Lukas Czerner) [1633239]
- [fs] ext4: recalucate superblock checksum after updating free blocks/inodes (Lukas Czerner) [1633239]
- [fs] ext4: avoid arithemetic overflow that can trigger a BUG (Lukas Czerner) [1633239]
- [fs] ext4: avoid divide by zero fault when deleting corrupted inline directories (Lukas Czerner) [1633239]
- [fs] ext4: check to make sure the rename(2)'s destination is not freed (Lukas Czerner) [1633239]
- [fs] ext4: remove unneeded variable "err" in ext4_mb_release_inode_pa() (Lukas Czerner) [1633239]
- [fs] ext4: fix spectre gadget in ext4_mb_regular_allocator() (Lukas Czerner) [1633239]
- [fs] ext4: check for NUL characters in extended attribute's name (Lukas Czerner) [1633239]
- [fs] ext4: use ext4_warning() for sb_getblk failure (Lukas Czerner) [1633239]
- [fs] ext4: fix race when setting the bitmap corrupted flag (Lukas Czerner) [1633239]
- [fs] ext4: reset error code in ext4_find_entry in fallback (Lukas Czerner) [1633239]
- [fs] ext4: check allocation failure when duplicating "data" in ext4_remount() (Lukas Czerner) [1633239]
- [fs] ext4: sysfs: print ext4_super_block fields as little-endian (Lukas Czerner) [1633239]
- [firmware] efi/x86: Handle page faults occurring while running EFI runtime services (Bhupesh Sharma) [1627557]
- [firmware] efi: Make efi_rts_work accessible to efi page fault handler (Bhupesh Sharma) [1627557]
- [firmware] efi: Remove the declaration of efi_late_init() as the function is unused (Bhupesh Sharma) [1627557]
- [firmware] efi: Use a work queue to invoke EFI Runtime Services (Bhupesh Sharma) [1627557]
- [firmware] efi/x86: Use non-blocking SetVariable() for efi_delete_dummy_variable() (Bhupesh Sharma) [1627557]
- [fs] gfs2: Special-case rindex for gfs2_grow (Robert S Peterson) [1628360]
- [fs] GFS2: Fix recovery issues for spectators (Robert S Peterson) [1628298]

* Fri Oct 05 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-22.el8]
- [powerpc] powerpc/pkeys: Fix reading of ibm, processor-storage-keys property (Steve Best) [1633551]
- [powerpc] powerpc/pseries: Remove unneeded uses of dlpar work queue (Steve Best) [1633544]
- [powerpc] powerpc/pseries: Remove prrn_work workqueue (Steve Best) [1633544]
- [pci] ACPI / hotplug / PCI: Don't scan for non-hotplug bridges if slot is not bridge (Myron Stowe) [1634816]
- [pci] PCI: Fix enabling of PASID on RC integrated endpoints (Myron Stowe) [1634816]
- [pci] IB/hfi1,PCI: Allow bus reset while probing (Myron Stowe) [1634816]
- [pci] PCI: Fix faulty logic in pci_reset_bus() (Myron Stowe) [1634816]
- [pci] PCI: pciehp: Fix hot-add vs powerfault detection order (Myron Stowe) [1634816]
- [pci] Revert "PCI: Add ACS quirk for Intel 300 series" (Myron Stowe) [1634816]
- [powerpc] powerpc/numa: Use associativity if VPHN hcall is successful (Steve Best) [1633569]
- [pci] PCI: vmd: White list for fast interrupt handlers (Myron Stowe) [1632816]
- [pci] PCI: Add function 1 DMA alias quirk for Marvell 88SS9183 (Myron Stowe) [1632816]
- [pci] PCI: Rename pci_try_reset_bus() to pci_reset_bus() (Myron Stowe) [1632816]
- [pci] PCI: Deprecate pci_reset_bus() and pci_reset_slot() functions (Myron Stowe) [1632816]
- [pci] PCI: Unify try slot and bus reset API (Myron Stowe) [1632816]
- [pci] PCI: Hide pci_reset_bridge_secondary_bus() from drivers (Myron Stowe) [1632816]
- [pci] IB/hfi1: Use pci_try_reset_bus() for initiating PCI Secondary Bus Reset (Myron Stowe) [1632816]
- [pci] PCI: Handle error return from pci_reset_bridge_secondary_bus() (Myron Stowe) [1632816]
- [pci] PCI/IOV: Tidy pci_sriov_set_totalvfs() (Myron Stowe) [1632816]
- [pci] PCI: Enable PASID only if entire path supports End-End TLP prefixes (Myron Stowe) [1632816]
- [pci] PCI: Expand documentation for pci_add_dma_alias() (Myron Stowe) [1632816]
- [pci] PCI: Add DMA alias quirk for Microsemi Switchtec NTB (Myron Stowe) [1632816]
- [pci] switchtec: Use generic PCI Vendor ID and Class Code (Myron Stowe) [1632816]
- [pci] PCI: Make pci_get_rom_size() static (Myron Stowe) [1632816]
- [pci] PCI: Add check code for last image indicator not set (Myron Stowe) [1632816]
- [pci] PCI: Avoid accessing memory outside the ROM BAR (Myron Stowe) [1632816]
- [pci] PCI: Make early dump functionality generic (Myron Stowe) [1632816]
- [pci] PCI: Cleanup PCI_REBAR_CTRL_BAR_SHIFT handling (Myron Stowe) [1632816]
- [pci] PCI: Restore resized BAR state on resume (Myron Stowe) [1632816]
- [pci] PCI: Clean up resource allocation in devm_of_pci_get_host_bridge_resources() (Myron Stowe) [1632816]
- [pci] PCI: Add ACS Redirect disable quirk for Intel Sunrise Point (Myron Stowe) [1632816]
- [pci] PCI: Add device-specific ACS Redirect disable infrastructure (Myron Stowe) [1632816]
- [pci] PCI: Convert device-specific ACS quirks from NULL termination to ARRAY_SIZE (Myron Stowe) [1632816]
- [pci] PCI: Add "pci=disable_acs_redir=" parameter for peer-to-peer support (Myron Stowe) [1632816]
- [pci] PCI: Allow specifying devices using a base bus and path of devfns (Myron Stowe) [1632816]
- [pci] PCI: Make specifying PCI devices in kernel parameters reusable (Myron Stowe) [1632816]
- [pci] PCI: Hide ACS quirk declarations inside PCI core (Myron Stowe) [1632816]
- [pci] PCI: Document ACPI description of PCI host bridges (Myron Stowe) [1632816]
- [pci] PCI/MSI: Set IRQCHIP_ONESHOT_SAFE for PCI-MSI irqchips (Myron Stowe) [1632816]
- [pci] PCI: Limit config space size for Netronome NFP5000 (Myron Stowe) [1632816]
- [pci] PCI: Add PCI_DEVICE_DATA() macro to fully describe device ID entry (Myron Stowe) [1632816]
- [pci] PCI: Unify PCI and normal DMA direction definitions (Myron Stowe) [1632816]
- [pci] PCI: Use IRQF_ONESHOT if pci_request_irq() called with no handler (Myron Stowe) [1632816]
- [pci] PCI: Call dma_debug_add_bus() for pci_bus_type from PCI core (Myron Stowe) [1632816]
- [pci] PCI: Mark fall-through switch cases before enabling -Wimplicit-fallthrough (Myron Stowe) [1632816]

* Thu Oct 04 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-21.el8]
- [s390] s390/sclp: Allow to request adapter reset (Philipp Rudo) [1635273]
- [char] ipmi: Fix NULL pointer dereference in ssif_probe (Tony Camuso) [1635366]
- [char] ipmi: Fix I2C client removal in the SSIF driver (Tony Camuso) [1635366]
- [char] ipmi: kcs_bmc: don't change device name (Tony Camuso) [1635366]
- [kernel] timers: Clear timer_base::must_forward_clk with timer_base::lock held (Waiman Long) [1632820]
- [pci] switchtec: Fix Spectre v1 vulnerability (Waiman Long) [1632820]
- [kernel] cpu/hotplug: Prevent state corruption on error rollback (Waiman Long) [1632820]
- [kernel] cpu/hotplug: Adjust misplaced smb() in cpuhp_thread_fun() (Waiman Long) [1632820]
- [base] memory_hotplug: fix kernel_panic on offline page processing (Waiman Long) [1632820]
- [mm] mm/hugetlb: filter out hugetlb pages if HUGEPAGE migration is not supported (Waiman Long) [1632820]
- [lib] debugobjects: Make stack check warning more informative (Waiman Long) [1632820]
- [fs] fs/dcache.c: fix kmemcheck splat at take_dentry_name_snapshot() (Waiman Long) [1632820]
- [x86] x86/process: Don't mix user/kernel regs in 64bit __show_regs() (Waiman Long) [1632820]
- [x86] x86/dumpstack: Don't dump kernel memory based on usermode RIP (Waiman Long) [1632820]
- [x86] x86: Avoid pr_cont() in show_opcodes() (Waiman Long) [1632820]
- [x86] x86/entry/64: Wipe KASAN stack shadow before rewind_stack_do_exit() (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+ (Waiman Long) [1632820]
- [x86] x86/spectre: Add missing family 6 check to microcode check (Waiman Long) [1632820]
- [x86] x86/nmi: Fix NMI uaccess race against CR3 switching (Waiman Long) [1632820]
- [x86] x86/vdso: Fix lsl operand order (Waiman Long) [1632820]
- [x86] x86/vdso: Fix vDSO build if a retpoline is emitted (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Suggest what to do on systems with too much RAM (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Fix off-by-one error when warning that system has too much RAM (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Exempt zeroed PTEs from inversion (Waiman Long) [1632820]
- [x86] x86/mm/pti: Clear Global bit more aggressively (Waiman Long) [1632820]
- [x86] x86/paravirt: Fix spectre-v2 mitigations for paravirt guests (Waiman Long) [1632820]
- [target] scsi: target: iscsi: Use bin2hex instead of a re-implementation (Maurizio Lombardi) [1632184] {CVE-2018-14633}
- [target] scsi: target: iscsi: Use hex2bin instead of a re-implementation (Maurizio Lombardi) [1632184] {CVE-2018-14633}

* Wed Oct 03 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-20.el8]
- [netdrv] ibmvnic: Include missing return code checks in reset function (Steve Best) [1633553]
- [netdrv] ibmvnic: Update firmware error reporting with cause string (Steve Best) [1633553]
- [netdrv] ibmvnic: Remove code to request error information (Steve Best) [1633553]
- [s390] s390/qeth: remove duplicated carrier state tracking (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up drop conditions for received cmds (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: re-indent qeth_check_ipa_data() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: consume local address events (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove various redundant code (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove CARD_FROM_CDEV helper (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: pass card pointer in iob callback (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: re-use qeth_notify_skbs() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove additional skb refcount (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: replace open-coded skb_queue_walk() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: on gdev release, reset drvdata (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix discipline unload after setup error (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use DEFINE_MUTEX for qeth_mod_mutex (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: convert layer attribute to enum (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reduce 0-initializing when building IPA cmds (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fine-tune spinlocks (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix typo in return value (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: invoke softirqs after napi_schedule() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: uninstall IRQ handler on device removal (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove qeth_hdr_chk_and_bounce() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed up TSO transmission (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: prepare for copy-free TSO transmission (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: check size of required HW header cache object (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix up protocol headers early (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: limit csum offload erratum to L3 devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove qeth_get_elements_no() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove unused L3 xmit code (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: run non-offload L3 traffic over common xmit path (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: move L2 xmit code to core module (Hendrik Brueckner) [1633841]
- [s390] s390/qdio: reset old sbal_state flags (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't dump past end of unknown HW header (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use vzalloc for QUERY OAT buffer (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: switch on SG by default for IQD devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: indicate error when netdev allocation fails (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use true and false for boolean values (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't restrict qeth_card to DMA memory (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up card initialization (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: do basic setup for data channel (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use qeth_setup_ccw() to set up all CCWs (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reduce hard-coded access to ccw channels (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: extract helper for MPC protocol type (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed up L2 IQD xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add support for constrained HW headers (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: merge linearize-check into HW header construction (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add statistics for consumed buffer elements (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use core MTU range checking (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: simplify max MTU handling (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't cache HW port number (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: allocate netdevice early (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove redundant netif_carrier_ok() checks (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reset layer2 attribute on layer switch (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix race in used-buffer accounting (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed-up IPv4 OSA xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed-up L3 IQD xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add a L3 xmit wrapper (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: increase GSO max size for eligible L3 devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up exported symbols (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: consolidate ccwgroup driver definition (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up Output Queue selection (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fine-tune RX modesetting (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove unused buffer->aob pointer (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: various buffer management cleanups (Hendrik Brueckner) [1633841]
- [powerpc] powerpc: Avoid code patching freed init sections (Steve Best) [1633545]
- [powerpc] powerpc/tm: Fix userspace r13 corruption (Steve Best) [1633543]
- [powerpc] powerpc/tm: Avoid possible userspace r1 corruption on reclaim (Steve Best) [1633543]
- [drm] drm/i915/cfl: Add a new CFL PCI ID (Rob Clark) [1626883]
- [drm] drm/i915/aml: Introducing Amber Lake platform (Rob Clark) [1626883]
- [drm] drm/i915/whl: Introducing Whiskey Lake platform (Rob Clark) [1626883]
- [char] ipmi: Move BT capabilities detection to the detect call (Frank Ramsay) [1618774]
- [char] ipmi: Rework SMI registration failure (Frank Ramsay) [1618774]

* Tue Oct 02 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-19.el8]
- [s390] s390: detect etoken facility (Thomas Huth) [1634069]
- [s390] s390/lib: use expoline for all bcr instructions (Thomas Huth) [1634069]
- [documentation] vm.txt: Adding 'nr_hugepages_mempolicy' parameter description (Prashant Dhamdhere) [1626547]

* Mon Oct 01 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-18.el8]
- [scsi] scsi: ipr: System hung while dlpar adding primary ipr adapter back (Steve Best) [1633217]
- [target] scsi: iscsi: target: Don't use stack buffer for scatterlist (Maurizio Lombardi) [1631342]
- [rpmspec] Forward port weak-modules support from RHEL 7 to RHEL 8 ("Herton R. Krzesinski") [1596884]
- [fs] xfs: Close race between direct IO and xfs_break_layouts() (Eric Sandeen) [1622191]
- [fs] xfs: remove unused iolock arg from xfs_break_dax_layouts (Eric Sandeen) [1622191]
- [fs] ext4: Close race between direct IO and ext4_break_layouts() (Eric Sandeen) [1616303]
- [fs] ext4: handle layout changes to pinned DAX mappings (Eric Sandeen) [1614154]
- [fs] dax: dax_layout_busy_page() warn on !exceptional (Eric Sandeen) [1614154]
- [fs] dax: mark tech preview (Eric Sandeen) [1627455]
- [mm] usercopy: Allow boot cmdline disabling of hardening (Christoph von Recklinghausen) [1589928]

* Thu Sep 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-17.el8]
- [s390] s390/crypto: Fix return code checking in cbc_paes_crypt() (Philipp Rudo) [1633266]
- [drm] amd/display/dc/basics/logger.c: fix build error with CONFIG_FORTIFY_SOURCE=y ("Herton R. Krzesinski") [1548068]
- [acpi] ACPICA: AML Parser: skip opcodes that open a scope upon parse failure (Jeremy Linton) [1609885]
- [acpi] ACPICA: ACPICA: add status check for acpi_hw_read before assigning return value (Jeremy Linton) [1609885]
- [acpi] ACPICA: AML Parser: ignore all exceptions resulting from incorrect AML during table load (Jeremy Linton) [1609885]
- [rpmspec] spec: Add missing BuildRequires for bpftool (Jiri Olsa) [1632756]
- [powerpc] KVM: PPC: Avoid marking DMA-mapped pages dirty in real mode (David Gibson) [1628412]
- [powerpc] powerpc/powernv/ioda: Allocate indirect TCE levels on demand (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Rework TCE level allocation (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Add indirect levels to it_userspace (David Gibson) [1628412]
- [powerpc] KVM: PPC: Make iommu_table::it_userspace big endian (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Move TCE manupulation code to its own file (David Gibson) [1628412]
- [net] net_sched: fix NULL pointer dereference when delete tcindex filter (Andrea Claudi) [1627648]
- [net] net_sched: Fix missing res info when create new tc_index filter (Andrea Claudi) [1627648]
- [samples] samples/bpf: xdpsock: order memory on AArch64 (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_redirect_cpu load balance like Suricata (Jesper Brouer) [1615959]
- [samples] samples/bpf: add Paul Hsieh's (LGPL 2.1) hash function SuperFastHash (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_redirect_cpu handle parsing of double VLAN tagged packets (Jesper Brouer) [1615959]
- [samples] samples/bpf: all XDP samples should unload xdp/bpf prog on SIGTERM (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_rxq_info action XDP_TX must adjust MAC-addrs (Jesper Brouer) [1615959]
- [samples] samples/bpf: extend xdp_rxq_info to read packet payload (Jesper Brouer) [1615959]
- [powerpc] KVM: PPC: Book3S HV: Use correct pagesize in kvm_unmap_radix() (David Gibson) [1625498]
- [net] igmp: fix incorrect unsolicit report count after link down and up (Hangbin Liu) [1625538]
- [net] igmp: fix incorrect unsolicit report count when join group (Hangbin Liu) [1625538]
- [netdrv] cxgb4: update 1.20.8.0 as the latest firmware supported (Arjun Vynipadath) [1622555]
- [virt] svm: nested virt support off by default (Bandan Das) [1571993]

* Wed Sep 26 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-16.el8]
- [powerpc] KVM: PPC: Book3S HV: Don't use compound_order to determine host mapping size (David Gibson) [1625860]
- [virt] arm64: KVM: Remove pgd_lock (Wei Huang) [1627474]
- [virt] KVM: Remove obsolete kvm_unmap_hva notifier backend (Wei Huang) [1627474]
- [virt] arm64: KVM: Only force FPEXC32_EL2.EN if trapping FPSIMD (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Clean dcache to PoC when changing PTE due to CoW (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Skip updating PTE entry if no change (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Skip updating PMD entry if no change (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Move DEBUG_SPINLOCK_BUG_ON to vgic.h (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Do not use spin_lock_irqsave/restore with irq disabled (Wei Huang) [1627474]
- [virt] KVM: arm: vgic-v3: Add support for ICC_SGI0R and ICC_ASGI1R accesses (Wei Huang) [1627474]
- [virt] KVM: arm64: vgic-v3: Add support for ICC_SGI0R_EL1 and ICC_ASGI1R_EL1 accesses (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic-v3: Add core support for Group0 SGIs (Wei Huang) [1627474]
- [virt] KVM: arm64: Remove non-existent AArch32 ICC_SGI1R encoding (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix lost IRQs from emulated physcial timer when blocked (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix potential loss of ptimer interrupts (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Fix possible spectre-v1 write in vgic_mmio_write_apr() (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Update documentation of the GIC devices wrt IIDR (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Let userspace opt-in to writable v2 IGROUPR (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Allow configuration of interrupt groups (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Return error on incompatible uaccess GICD_IIDR writes (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Permit uaccess writes to return errors (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Signal IRQs using their configured group (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Add group field to struct irq (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: GICv2 IGROUPR should read as zero (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Keep track of implementation revision (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Define GICD_IIDR fields for GICv2 and GIv3 (Wei Huang) [1627474]
- [virt] arm64: KVM: Cleanup tpidr_el2 init on non-VHE (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic-debug: Show LPI status (Wei Huang) [1627474]
- [virt] KVM: arm64: vgic-its: Remove VLA usage (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix vgic init race (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Enable adaptative WFE trapping (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Remove unnecessary CMOs when creating HYP page tables (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Stop using the kernel's (pmd, pud, pgd)_populate helpers (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Consolidate page-table accessors (Wei Huang) [1627474]
- [virt] arm64: KVM: Avoid marking pages as XN in Stage-2 if CTR_EL0.DIC is set (Wei Huang) [1627474]
- [tools] radix tree test suite: Enable ubsan (Waiman Long) [1630244]
- [tools] radix tree test suite: Fix compilation (Waiman Long) [1630244]
- [block] blk-wbt: don't maintain inflight counts if disabled (Ming Lei) [1622790]
- [block] blk-wbt: fix has-sleeper queueing check (Ming Lei) [1622790]
- [block] blk-wbt: use wq_has_sleeper() for wq active check (Ming Lei) [1622790]
- [block] blk-wbt: move disable check into get_limit() (Ming Lei) [1622790]
- [block] block/DAC960.c: make some arrays static const, shrinks object (Ming Lei) [1622790]
- [block] blk-mq: sync the update nr_hw_queues with (Ming Lei) [1617959]
- [block] blk-mq: init hctx sched after update ctx and hctx mapping (Ming Lei) [1617959]
- [block] block: remove duplicate initialization (Ming Lei) [1622790]
- [block] tracing/blktrace: Fix to allow setting same value (Ming Lei) [1622790]
- [block] pktcdvd: fix setting of 'ret' error return for a few cases (Ming Lei) [1622790]
- [block] block: change return type to bool (Ming Lei) [1622790]
- [block] block, bfq: return nbytes and not zero from struct cftype (Ming Lei) [1622790]
- [block] block, bfq: improve code of bfq_bfqq_charge_time (Ming Lei) [1622790]
- [block] block, bfq: reduce write overcharge (Ming Lei) [1622790]
- [block] block, bfq: always update the budget of an entity when needed (Ming Lei) [1622790]
- [block] block, bfq: readd missing reset of parent-entity service (Ming Lei) [1622790]
- [block] block: don't warn for flush on read-only device (Ming Lei) [1622809]

* Tue Sep 25 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-15.el8]
- [kernel] locking/rwsem: Make owner store task pointer of last owning reader (Waiman Long) [1631842]
- [kernel] locking/rwsem: Exit read lock slowpath if queue empty & no writer (Waiman Long) [1631842]
- [x86] x86/microcode: Update the new microcode revision unconditionally (Prarit Bhargava) [1630931]
- [x86] x86/microcode: Make sure boot_cpu_data.microcode is up-to-date (Prarit Bhargava) [1630931]
- [arm64] arm64: tlb: Provide forward declaration of tlb_flush() before including tlb.h (Waiman Long) [1630521]
- [x86] x86/mm: Only use tlb_remove_table() for paravirt (Waiman Long) [1630521]
- [mm] mm: mmu_notifier fix for tlb_end_vma (Waiman Long) [1630521]
- [mm] mm/tlb, x86/mm: Support invalidating TLB caches for RCU_TABLE_FREE (Waiman Long) [1630521]
- [mm] mm/tlb: Remove tlb_remove_table() non-concurrent condition (Waiman Long) [1630521]
- [mm] mm: move tlb_table_flush to tlb_flush_mmu_free (Waiman Long) [1630521]
- [kernel] clocksource: Revert Remove kthread (Waiman Long) [1628402]
- [cpuidle] cpuidle: menu: Retain tick when shallow state is selected (Waiman Long) [1628402]
- [cpufreq] cpufreq: governor: Avoid accessing invalid governor_data (Waiman Long) [1628402]
- [cpuidle] cpuidle: menu: Handle stopped tick more aggressively (Waiman Long) [1628402]
- [kernel] sched: idle: Avoid retaining the tick when it has been stopped (Waiman Long) [1628402]
- [net] netfilter: xt_hashlimit: do not crash when reading proc file (Florian Westphal) [1630131]
- [x86] x86/boot/KASLR: Skip specified number of 1GB huge pages when doing physical randomization (KASLR) (Baoquan He) [1564824]
- [x86] x86/boot/KASLR: Add two new functions for 1GB huge pages handling (Baoquan He) [1564824]
- [mfd] mfd: intel-lpss: Add Ice Lake PCI IDs (Gopal Tiwari) [1483477]
- [mmc] mmc: sdhci-pci: Add support for Intel ICP (Gopal Tiwari) [1483496]

* Mon Sep 24 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-14.el8]
- [mm] mm: get rid of vmacache_flush_all() entirely (Waiman Long) [1631297] {CVE-2018-17182}
- [mm] mm, vmacache: hash addresses based on pmd (Waiman Long) [1631297] {CVE-2018-17182}
- [mm] mm: Allocate the mm_cpumask (mm->cpu_bitmap) dynamically based on nr_cpu_ids (Waiman Long) [1631297] {CVE-2018-17182}
- [infiniband] IB/hfi1: Invalid NUMA node information can cause a divide by zero (Alex Estrin) [1622222]
- [nvdimm] libnvdimm: Export max available extent (Jeff Moyer) [1627874]
- [nvdimm] libnvdimm: Use max contiguous area for namespace size (Jeff Moyer) [1627874]
- [netdrv] ice: Fix and update driver version string (Jonathan Toppins) [1611786]
- [netdrv] ice: Introduce SERVICE_DIS flag and service routine functions (Jonathan Toppins) [1611786]
- [netdrv] ice: Enable VSI Rx/Tx pruning only when VLAN 0 is active (Jonathan Toppins) [1611786]
- [netdrv] ice: Enable firmware logging during device initialization (Jonathan Toppins) [1611786]
- [netdrv] ice: Implement ice_bridge_getlink and ice_bridge_setlink (Jonathan Toppins) [1611786]
- [netdrv] ice: Add support for Tx hang, Tx timeout and malicious driver detection (Jonathan Toppins) [1611786]
- [netdrv] ice: Clean up register file (Jonathan Toppins) [1611786]
- [netdrv] ice: Implement handlers for ethtool PHY/link operations (Jonathan Toppins) [1611786]
- [netdrv] ice: Refactor VSI allocation, deletion and rebuild flow (Jonathan Toppins) [1611786]
- [netdrv] ice: Refactor switch rule management structures and functions (Jonathan Toppins) [1611786]
- [netdrv] ice: Code optimization for ice_fill_sw_rule() (Jonathan Toppins) [1611786]
- [netdrv] ice: Prevent control queue operations during reset (Jonathan Toppins) [1611786]
- [netdrv] ice: Update request resource command to latest specification (Jonathan Toppins) [1611786]
- [netdrv] ice: Updates to Tx scheduler code (Jonathan Toppins) [1611786]
- [netdrv] ice: Rework flex descriptor programming (Jonathan Toppins) [1611786]
- [netdrv] net/mlx5: Fix SQ offset in QPs with small RQ (Alaa Hleihel) [1623367]
- [x86] x86/spec_ctrl: Make IBRS code work with SSBD mitigation (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Auto-enable IBRS on Skylake (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Extend spectre_v2 boot option to support IBRS (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Boot time IBRS initialization (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Add IBRS code to the 64-bit assembly entry code (Waiman Long) [1565180]
- [x86] x86/cpufeatures: Increase NCAPINTS for future extension (Waiman Long) [1565180]
- [netdrv] ice: Trivial formatting fixes (Jonathan Toppins) [1611783]
- [netdrv] ice: Change struct members from bool to u8 (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix potential return of uninitialized value (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix a few null pointer dereference issues (Jonathan Toppins) [1611783]
- [netdrv] ice: Update to interrupts enabled in OICR (Jonathan Toppins) [1611783]
- [netdrv] ice: Set VLAN flags correctly (Jonathan Toppins) [1611783]
- [netdrv] ice: Use order_base_2 to calculate higher power of 2 (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix bugs in control queue processing (Jonathan Toppins) [1611783]
- [netdrv] ice: Clean control queues only when they are initialized (Jonathan Toppins) [1611783]
- [netdrv] ice: Report stats for allocated queues via ethtool stats (Jonathan Toppins) [1611783]
- [netdrv] ice: Cleanup magic number (Jonathan Toppins) [1611783]
- [netdrv] ice: Remove unnecessary node owner check (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix multiple static analyser warnings (Jonathan Toppins) [1611783]
- [virt] KVM: VMX: fixes for vmentry_l1d_flush module parameter (Waiman Long) [1616248] {CVE-2018-15572}
- [virt] KVM: x86: SVM: Call x86_spec_ctrl_set_guest/host() with interrupts disabled (Waiman Long) [1616248] {CVE-2018-15572}
- [virt] x86/kvm/vmx: Fix coding style in vmx_setup_l1d_flush() (Waiman Long) [1616248] {CVE-2018-15572}
- [x86] x86/speculation: Support Enhanced IBRS on future CPUs (Waiman Long) [1614144]
- [x86] x86/speculation: Protect against userspace-userspace spectreRSB (Waiman Long) [1616248] {CVE-2018-15572}
- [x86] x86/speculation: Remove SPECTRE_V2_IBRS in enum spectre_v2_mitigation (Waiman Long) [1616248] {CVE-2018-15572}
- [cpufreq] cpufreq: Fix a circular lock dependency problem (Waiman Long) [1599154]
- [kernel] cpu/hotplug: Add a cpus_read_trylock() function (Waiman Long) [1599154]
- [virt] xen/spinlock: Don't use pvqspinlock if only 1 vCPU (Waiman Long) [1618486]

* Thu Sep 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-13.el8]
- [mailbox] mailbox: PCC: handle parse error (David Arcari) [1630382]
- [hv] vmbus: don't return values for uninitalized channels (Vitaly Kuznetsov) [1617954]
- [mm] kernel/memremap, kasan: make ZONE_DEVICE with work with KASAN (Bill O'Donnell) [1629578]
- [mm] mm: fix BUG_ON() in vmf_insert_pfn_pud() from VM_MIXEDMAP removal (Jeff Moyer) [1622171]
- [mm] dax: remove VM_MIXEDMAP for fsdax and device dax (Jeff Moyer) [1622171]

* Wed Sep 19 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-12.el8]
- [i2c] i2c: i801: fix DNV's SMBCTRL register offset (David Arcari) [1628861]
- [fs] ceph: avoid a use-after-free in ceph_destroy_options() (Ilya Dryomov) [1629884]
- [fs] ceph: fix incorrect use of strncpy (Ilya Dryomov) [1629884]
- [block] rbd: support cloning across namespaces (Ilya Dryomov) [1629884]
- [block] rbd: factor out get_parent_info() (Ilya Dryomov) [1629884]
- [block] rbd: support for images within namespaces (Ilya Dryomov) [1629884]
- [block] rbd: pass rbd_spec into parse_rbd_opts_token() (Ilya Dryomov) [1629884]
- [net] libceph: weaken sizeof check in ceph_x_verify_authorizer_reply() (Ilya Dryomov) [1629884]
- [net] libceph: check authorizer reply/challenge length before reading (Ilya Dryomov) [1629884]
- [net] libceph: implement CEPHX_V2 calculation mode (Ilya Dryomov) [1629884]
- [net] libceph: add authorizer challenge (Ilya Dryomov) [1629884]
- [net] libceph: factor out encrypt_authorizer() (Ilya Dryomov) [1629884]
- [net] libceph: factor out __ceph_x_decrypt() (Ilya Dryomov) [1629884]
- [net] libceph: factor out __prepare_write_connect() (Ilya Dryomov) [1629884]
- [net] libceph: store ceph_auth_handshake pointer in ceph_connection (Ilya Dryomov) [1629884]
- [pci] PCI: pciehp: Deduplicate presence check on probe & resume (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Avoid implicit fallthroughs in switch statements (Myron Stowe) [1583983]
- [pci] PCI: Whitelist Thunderbolt ports for runtime D3 (Myron Stowe) [1583983]
- [pci] PCI: Whitelist native hotplug ports for runtime D3 (Myron Stowe) [1583983]
- [pci] PCI: sysfs: Resume to D0 on function reset (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Resume parent to D0 on config space access (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Resume to D0 on enable/disable (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Support interrupts sent from D3hot (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Obey compulsory command delay after resume (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Clear spurious events earlier on resume (Myron Stowe) [1583983]
- [pci] PCI: portdrv: Deduplicate PM callback iterator (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Avoid slot access during reset (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Always enable occupied slot on probe (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Become resilient to missed events (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Tolerate initially unstable link (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Declare pciehp_enable/disable_slot() static (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop enable/disable lock (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Enable/disable exclusively from IRQ thread (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Track enable/disable status (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Publish to user space last on probe (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Demidlayer registration with the core (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop slot workqueue (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Handle events synchronously (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Stop blinking on slot enable failure (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Convert to threaded polling (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Convert to threaded IRQ (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Document struct slot and struct controller (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Declare pciehp_unconfigure_device() void (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop unnecessary NULL pointer check (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Fix unprotected list iteration in IRQ handler (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Fix use-after-free on unplug (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Don't leak pci_slot on registration failure (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Delete skeleton driver (Myron Stowe) [1583983]
- [netdrv] be2net: Use Kconfig flag to support for enabling/disabling adapters (Petr Oros) [1611768]
- [acpi] ACPICA: Reference Counts: increase max to 0x4000 for large servers (Frank Ramsay) [1618760]

* Tue Sep 18 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-11.el8]
- [net] udp6: add missing checks on edumux packet processing (Paolo Abeni) [1625954]
- [net] udp4: fix IP_CMSG_CHECKSUM for connected sockets (Paolo Abeni) [1625954]
- [s390] s390/pci: fix out of bounds access during irq setup (Hendrik Brueckner) [1627462]
- [nvdimm] libnvdimm: fix ars_status output length calculation (Jeff Moyer) [1616307]

* Mon Sep 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-10.el8]
- [scsi] scsi: lpfc: Correct MDS diag and nvmet configuration (Dick Kennedy) [1628323]
- [iommu] iommu/arm-smmu: workaround DMA mode issues (Mark Salter) [1624077]
- [x86] x86/microcode: Allow late microcode loading with SMT disabled (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] tools headers: Synchronise x86 cpufeatures.h for L1TF additions (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/mm/kmmio: Make the tracer robust against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/mm/pat: Make set_memory_np() L1TF safe (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Invert all not present mappings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Fix SMT supported evaluation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] KVM: VMX: Tell the nested hypervisor to skip L1D flush on vmentry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on vmentry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation: Simplify sysfs report of VMX L1TF vulnerability (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation/l1tf: Remove Yonah processors from not vulnerable list (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Don't set l1tf_flush_l1d from vmx_handle_external_intr() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86: Don't include linux/irq.h from asm/hardirq.h (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/irq: Demote irq_cpustat_t::__softirq_pending to u16 (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with 'vmx_l1d_flush_cond' (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Don't set l1tf_flush_l1d to true from vmx_l1d_flush() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: detect SMT disabled by BIOS (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation/l1tf: Fix typos (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED architectures (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation: Add section about CPU vulnerabilities (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/bugs, kvm: Introduce boot-time control of L1TF mitigations (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Expose SMT control init function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Allow runtime control of L1D flush (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Serialize L1D flush parameter setter (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Add static key for flush always (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Move l1tf setup function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/l1tf: Handle EPT disabled state proper (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Drop L1TF MSR list approach (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/litf: Introduce vmx status variable (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Online siblings when SMT control is turned on (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER only MSRs (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number accounting (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add find_msr() helper function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Split the VMX MSR LOAD structures to have an host/guest numbers (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D flush logic (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D MSR based flush (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D flush algorithm (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add module argument for L1TF mitigation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being present (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Boot HT siblings at least once (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Revert "x86/apic: Ignore secondary threads if nosmt=force" (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Fix up pte->pfn conversion for PAE (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect PAE swap entries against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/CPU/AMD: Move TOPOEXT reenablement before reading smp_num_siblings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpufeatures: Add detection of L1D cache flush support (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Extend 64bit swap file size limit (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/apic: Ignore secondary threads if nosmt=force (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/AMD: Evaluate smp_num_siblings early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/CPU/AMD: Do not check CPUID max ext level before parsing SMP info (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/intel: Evaluate smp_num_siblings early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/topology: Provide detect_extended_topology_early() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/common: Provide detect_ht_early() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/AMD: Remove the pointless detect_ht() call (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu: Remove the pointless CPU printout (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Provide knobs to control SMT (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Split do_cpu_down() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Make bringup/teardown of smp threads symmetric (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/topology: Provide topology_smt_supported() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/smp: Provide topology_is_primary_thread() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] sched/smt: Update sched_smt_present at runtime (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/bugs: Move the l1tf function and define pr_fmt properly (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Limit swap file size to MAX_PA/2 (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Disallow non privileged high MMIO PROT_NONE mappings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Add sysfs reporting for l1tf (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Make sure the first page is always reserved (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect swap entries against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Change order of offset/type in swap entry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}

* Thu Sep 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-9.el8]
- [pci] PCI/DPC: Remove indirection waiting for inactive link (Myron Stowe) [1485556]
- [pci] PCI/DPC: Use threaded IRQ for bottom half handling (Myron Stowe) [1485556]
- [pci] PCI/DPC: Print AER status in DPC event handling (Myron Stowe) [1485556]
- [pci] PCI/DPC: Remove rp_pio_status from dpc struct (Myron Stowe) [1485556]
- [pci] PCI/DPC: Defer event handling to work queue (Myron Stowe) [1485556]
- [pci] PCI/DPC: Leave interrupts enabled while handling event (Myron Stowe) [1485556]
- [net] net/mlx5e: Offload TC matching on tos/ttl for ip tunnels (Erez Alfasi) [1615121]
- [net] net/mlx5e: Support setup of tos and ttl for tunnel key TC action offload (Erez Alfasi) [1615121]
- [net] net/mlx5e: Use ttl from route lookup on tc encap offload only if needed (Erez Alfasi) [1615121]
- [net] net/sched: cls_flower: Support matching on ip tos and ttl for tunnels (Erez Alfasi) [1615121]
- [net] flow_dissector: Dissect tos and ttl from the tunnel info (Erez Alfasi) [1615121]
- [net] net/sched: tunnel_key: Allow to set tos and ttl for tc based ip tunnels (Erez Alfasi) [1615121]
- [net] net/sched: act_tunnel_key: disambiguate metadata dst error cases (Erez Alfasi) [1615121]
- [net] net/sched: add tunnel option support to act_tunnel_key (Erez Alfasi) [1615121]
- [iommu] iommu/amd: Add support for IOMMU XT mode (Suravee Suthikulpanit) [1504485]
- [iommu] iommu/amd: Add support for higher 64-bit IOMMU Control Register (Suravee Suthikulpanit) [1504485]
- [x86] x86: irq_remapping: Move irq remapping mode enum (Suravee Suthikulpanit) [1504485]
- [firmware] dcdbas: Add support for WSMT ACPI table (Charles Rose) [1502286]

* Wed Sep 12 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-8.el8]
- [documentation] scsi: documentation: add scsi_mod.use_blk_mq to scsi-parameters (Ewan Milne) [1600014]
- [scsi] scsi: core: Update SCSI_MQ_DEFAULT help text to match default (Ewan Milne) [1600014]
- [scsi] scsi: core: switch to scsi-mq by default (Ewan Milne) [1600014]
- [pci] PCI: Match Root Port's MPS to endpoint's MPSS as necessary (Myron Stowe) [1502324]
- [pci] PCI: Skip MPS logic for Virtual Functions (VFs) (Myron Stowe) [1502324]
- [pci] PCI: Check for PCIe Link downtraining (Myron Stowe) [1502324]
- [pci] PCI: Workaround IDT switch ACS Source Validation erratum (Myron Stowe) [1502324]
- [of] OF: Don't set default coherent DMA mask (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Don't set default coherent DMA mask (Mark Salter) [1581822]
- [iommu] iommu/dma: Respect bus DMA limit for IOVAs (Mark Salter) [1581822]
- [of] of/device: Set bus DMA mask as appropriate (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Set bus DMA mask as appropriate (Mark Salter) [1581822]
- [kernel] dma-mapping: Generalise dma_32bit_limit flag (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Support address size limit for root complexes (Mark Salter) [1581822]
- [of] of/platform: Initialise default DMA masks (Mark Salter) [1581822]
- [net] Bluetooth: hidp: buffer overflow in hidp_process_report (Gopal Tiwari) [1623073] {CVE-2018-9363}
- [irqchip] irqchip/gic-v3-its: Reduce minimum LPI allocation to 1 for PCI devices (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Honor hypervisor enforced LPI range (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3: Expose GICD_TYPER in the rdist structure (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Drop chunk allocation compatibility (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Move minimum LPI requirements to individual busses (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Use full range of LPIs (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Refactor LPI allocator (Mark Salter) [1550500]

* Tue Sep 11 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-7.el8]
- [netdrv] hv_netvsc: Fix a deadlock by getting rtnl lock earlier in netvsc_probe() (Vitaly Kuznetsov) [1625609]
- [netdrv] hv_netvsc: ignore devices that are not PCI (Vitaly Kuznetsov) [1625609]
- [netdrv] hv/netvsc: Fix NULL dereference at single queue mode fallback (Vitaly Kuznetsov) [1625609]
- [netdrv] hv_netvsc: Add per-cpu ethtool stats for netvsc (Vitaly Kuznetsov) [1625609]
- [pci] PCI: shpchp: Separate existence of SHPC and permission to use it (Steve Best) [1622953]
- [powerpc] KVM: PPC: Book3S HV: Don't truncate HPTE index in xlate function (David Gibson) [1625513]
- [kernel] rh_kabi: Add macros to size and extend structs (Prarit Bhargava) [1564570]
- [pci] PCI: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [wireless] iwlwifi: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [wireless] ath9k: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [netdrv] igb: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [pci] PCI/ASPM: Convert to use sysfs_match_string() helper (Myron Stowe) [1622672]
- [virt] KVM: s390: Properly lock mm context allow_gmap_hpage_1m setting (Thomas Huth) [1623513]
- [virt] KVM: s390: vsie: copy wrapping keys to right place (Thomas Huth) [1623513]
- [virt] KVM: s390: Fix pfmf and conditional skey emulation (Thomas Huth) [1623513]
- [virt] KVM: s390: Fix storage attributes migration with memory slots (Thomas Huth) [1623513]
- [virt] KVM: s390: a utility function for migration (Thomas Huth) [1623513]

* Mon Sep 10 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-6.el8]
- [lib] vsprintf: Add command line option debug_boot_weak_hash (Prarit Bhargava) [1625687]
- [netdrv] i40e: Fix for Tx timeouts when interface is brought up if DCB is enabled (Stefan Assmann) [1616147]
- [misc] ocxl: Fix page fault handler in case of fault on dying process (Steve Best) [1624644]
- [edac] EDAC, sb_edac: Add support for systems with segmented PCI buses (Aristeu Rozanski) [1621849]
- [netdrv] xen-netfront: fix warn message as irq device name has '/' (Vitaly Kuznetsov) [1576160]
- [arm64] arm64, kaslr: export offset in VMCOREINFO ELF notes (Bhupesh Sharma) [1624246]
- [rpmspec] redhat: Move gfs2 and dlm out of kernel-modules-extra (Andrew Price) [1623511]
- [powerpc] powerpc/topology: Get topology for shared processors at boot (Steve Best) [1620039]
- [fs] gfs2: Don't set GFS2_RDF_UPTODATE when the lvb is updated (Robert S Peterson) [1622057]
- [fs] gfs2: improve debug information when lvb mismatches are found (Robert S Peterson) [1622057]
- [fs] gfs2: cleanup: call gfs2_rgrp_ondisk2lvb from gfs2_rgrp_out (Robert S Peterson) [1622057]
- [x86] Fix x86 32-bit invalid cpu boot failure message (Prarit Bhargava) [1571456]
- [net] net/ipv6: init ip6 anycast rt->dst.input as ip6_input (Hangbin Liu) [1615671]
- [pci] PCI/AER: Don't clear AER bits if error handling is Firmware-First (Myron Stowe) [1621933]
- [pci] PCI/AER: Remove duplicate PCI_EXP_AER_FLAGS definition (Myron Stowe) [1621933]
- [pci] PCI/portdrv: Remove pcie_portdrv_err_handler.slot_reset (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear device status bits during ERR_COR handling (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear device status bits during ERR_FATAL and ERR_NONFATAL (Myron Stowe) [1621933]
- [pci] PCI/AER: Remove ERR_FATAL code from ERR_NONFATAL path (Myron Stowe) [1621933]
- [pci] PCI/AER: Factor out ERR_NONFATAL status bit clearing (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear only ERR_NONFATAL bits during non-fatal recovery (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear only ERR_FATAL status bits during fatal recovery (Myron Stowe) [1621933]
- [pci] PCI/AER: Honor "pcie_ports=native" even if HEST sets FIRMWARE_FIRST (Myron Stowe) [1621933]
- [pci] PCI/AER: Add sysfs attributes for rootport cumulative stats (Myron Stowe) [1621933]
- [pci] PCI/AER: Add sysfs attributes to provide AER stats and breakdown (Myron Stowe) [1621933]
- [pci] PCI/AER: Define aer_stats structure for AER capable devices (Myron Stowe) [1621933]
- [pci] PCI/AER: Move internal declarations to drivers/pci/pci.h (Myron Stowe) [1621933]
- [pci] PCI/AER: Adopt lspci names for AER error decoding (Myron Stowe) [1621933]
- [pci] PCI/AER: Expose internal API for obtaining AER information (Myron Stowe) [1621933]
- [kernel] rcu: Make expedited GPs handle CPU 0 being offline (Gustavo Duarte) [1610262]
- [rpmspec] Generate BootLoaderSpec config fragments ("Herton R. Krzesinski") [1619766]

* Wed Aug 29 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-5.el8]
- [net] erspan: set erspan_ver to 1 by default when adding an erspan dev (Xin Long) [1619118]
- [hv] x86/hyper-v: Fix wrong merge conflict resolution (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others() (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Check cpumask_to_vpset() return value in hyperv_flush_tlb_others_ex() (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Trace PV IPI send (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use cheaper HVCALL_SEND_IPI hypercall when possible (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use 'fast' hypercall for HVCALL_SEND_IPI (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Implement hv_do_fast_hypercall16 (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use cheaper HVCALL_FLUSH_VIRTUAL_ADDRESS_(LIST, SPACE) hypercalls when possible (Vitaly Kuznetsov) [1597652]
- [netdrv] xen-netfront: fix queue name setting (Vitaly Kuznetsov) [1576160]
- [scsi] lfpc: add Lancer FCoE to the removed devices (Tomas Henzl) [1602033]
- [scsi] megaraid_sas: add removed id table (Tomas Henzl) [1602033]
- [scsi] aacraid: add removed id table (Tomas Henzl) [1602033]
- [scsi] qla4xxx: add removed id table (Tomas Henzl) [1602033]
- [scsi] lpfc: add removed id table (Tomas Henzl) [1602033]
- [scsi] qla2xxx: add removed id table (Tomas Henzl) [1602033]
- [scsi] mpt3sas: add removed id table (Tomas Henzl) [1602033]
- [scsi] be2iscsi: add removed id table (Tomas Henzl) [1602033]
- [scsi] rh_taint, pci : add information about removed hardware (Tomas Henzl) [1602033]
- [kernel] kernel: add SUPPORT_REMOVED kernel taint (Tomas Henzl) [1602033]
- [net] sunrpc: Change rpc_print_iostats to rpc_clnt_show_stats and handle rpc_clnt clones (Dave Wysochanski) [1610373]
- [net] sunrpc: Add _add_rpc_iostats() to add rpc_iostats metrics (Dave Wysochanski) [1610373]
- [net] sunrpc: add _print_rpc_iostats() to output metrics for one RPC op (Dave Wysochanski) [1610373]

* Mon Aug 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-4.el8]
- [net] xdp: exclude XDP from kABI guarantee (Jiri Benc) [1568551]
- [kernel] rh_kabi: introduce RH_KABI_EXCLUDE (Jiri Benc) [1568551]
- [powerpc] powerpc/powernv/pci: Work around races in PCI bridge enabling (Steve Best) [1620035]
- [block] blk-wbt: fix IO hang in wbt_wait() (Ming Lei) [1614198]
- [block] blkcg: Make blkg_root_lookup() work for queues in bypass mode (Ming Lei) [1614198]
- [block] null_blk: add lock drop/acquire annotation (Ming Lei) [1614198]
- [block] Blk-throttle: reduce tail io latency when iops limit is (Ming Lei) [1614198]
- [block] block: paride: pd: mark expected switch fall-throughs (Ming Lei) [1614198]
- [block] block: Ensure that a request queue is dissociated from the (Ming Lei) [1614198]
- [block] block: Introduce blk_exit_queue() (Ming Lei) [1614198]
- [block] blkcg: Introduce blkg_root_lookup() (Ming Lei) [1614198]
- [block] block: Remove two superfluous #include directives (Ming Lei) [1614198]
- [block] blk-mq: count the hctx as active before allocating tag (Ming Lei) [1614198]
- [block] block: bvec_nr_vecs() returns value for wrong slab (Ming Lei) [1614198]
- [block] drivers/block/drbd: remove the null check for (Ming Lei) [1614198]
- [block] drivers/block/aoe/aoedev: NULL check is not needed for (Ming Lei) [1614198]
- [block] drivers/block/mtip32xx: remove the null check for (Ming Lei) [1614198]
- [block] cfq: Suppress compiler warnings about comparisons (Ming Lei) [1614198]
- [block] cfq: Annotate fall-through in a switch statement (Ming Lei) [1614198]
- [block] blk-wbt: Avoid lock contention and thundering herd issue in (Ming Lei) [1590363]
- [block] target/loop: depend on SCSI (Ming Lei) [1614198]
- [block] xen-blkfront: use true and false for boolean values (Ming Lei) [1614198]
- [block] lightnvm: remove minor version check for 2.0 (Ming Lei) [1614198]
- [block] scsi: Check sense buffer size at build time (Ming Lei) [1614198]
- [block] libata-scsi: Move sense buffers onto stack (Ming Lei) [1614198]
- [block] cdrom: Use struct scsi_sense_hdr internally (Ming Lei) [1614198]
- [block] ide-cd: Remove redundant sense buffer (Ming Lei) [1614198]
- [block] block: Switch struct packet_command to use struct (Ming Lei) [1614198]
- [block] target: don't depend on SCSI (Ming Lei) [1614198]
- [block] scsi: build scsi_common.o for all scsi passthrough request (Ming Lei) [1614198]
- [block] scsi: cxlflash: Drop unused sense buffers (Ming Lei) [1614198]
- [block] ide-cd: Drop unused sense buffers (Ming Lei) [1614198]
- [block] blk-mq: fix updating tags depth (Ming Lei) [1611900]
- [block] block: really disable runtime-pm for blk-mq (Ming Lei) [1611902]
- [block] aoe: mark expected switch fall-through (Ming Lei) [1614198]
- [block] block: make iolatency avg_lat exponentially decay (Ming Lei) [1614198]
- [block] blk-cgroup: clear the throttle queue on fork (Ming Lei) [1614198]
- [block] blk-cgroup: hold the queue ref during throttling (Ming Lei) [1614198]
- [block] blk-iolatency: fix blkg leak in timer_fn (Ming Lei) [1614198]
- [block] block/bsg-lib: use PTR_ERR_OR_ZERO to simplify the flow path (Ming Lei) [1614198]
- [block] t10-pi: provide empty t10_pi_complete() for (Ming Lei) [1614198]
- [block] block: blk_init_allocated_queue() set q->fq as NULL in the (Ming Lei) [1614198]
- [block] nvme: use blk API to remap ref tags for IOs with metadata (Ming Lei) [1614198]
- [block] block: move dif_prepare/dif_complete functions to block layer (Ming Lei) [1614198]
- [block] block: move ref_tag calculation func to the block layer (Ming Lei) [1614198]
- [block] block: don't account for split bio's size in cgroup stats (Ming Lei) [1614198]
- [block] pktcdvd: Fix possible Spectre-v1 for pkt_devs (Ming Lei) [1614198]
- [block] partitions/aix: append null character to print data from disk (Ming Lei) [1614198]
- [block] partitions/aix: fix usage of uninitialized lv_info and lvname (Ming Lei) [1614198]
- [block] readahead: stricter check for bdi io_pages (Ming Lei) [1614198]
- [block] scsi: virtio_scsi: fix pi_bytes(out, in) on 4 KiB block size (Ming Lei) [1614198]
- [block] block: move bio_integrity_(intervals, bytes) into blkdev.h (Ming Lei) [1614198]
- [block] xen/blkfront: remove unused macros (Ming Lei) [1614198]
- [block] block: allow max_discard_segments to be stacked (Ming Lei) [1614198]
- [block] block: unexport bio_clone_bioset (Ming Lei) [1614198]
- [block] md: remove a bogus comment (Ming Lei) [1614198]
- [block] block: remove bio_clone_kmalloc (Ming Lei) [1614198]
- [block] exofs: use bio_clone_fast in _write_mirror (Ming Lei) [1614198]
- [block] bcache: don't clone bio in bch_data_verify (Ming Lei) [1614198]
- [block] block: bio_set_pages_dirty can't see NULL bv_page in a valid (Ming Lei) [1614198]
- [block] block: simplify bio_check_pages_dirty (Ming Lei) [1614198]
- [block] block: Rename the null_blk_mod kernel module back into (Ming Lei) [1614198]
- [block] blk-mq: fail the request in case issue failure (Ming Lei) [1614305]
- [block] blk-rq-qos: make depth comparisons unsigned (Ming Lei) [1614198]
- [block] blkcg: Track DISCARD statistics and output them in cgroup (Ming Lei) [1614198]
- [block] block: Track DISCARD statistics and output them in stat and (Ming Lei) [1614198]
- [block] block: Add and use op_stat_group() for indexing disk_stat (Ming Lei) [1614198]
- [block] block: Define and use STAT_READ and STAT_WRITE (Ming Lei) [1614198]
- [block] block: Add part_stat_read_accum to read across field entries (Ming Lei) [1614198]
- [block] block: make bdev_ops->rw_page() take a REQ_OP instead of bool (Ming Lei) [1614198]
- [block] pktcdvd: remove assignment in if condition (Ming Lei) [1614198]
- [block] blk-mq: issue directly if hw queue isn't busy in case of (Ming Lei) [1614305]
- [block] blk-iolatency: truncate our current time (Ming Lei) [1614198]
- [block] blk-iolatency: don't change the latency window (Ming Lei) [1614198]
- [block] block: remove blkdev_entry_to_request() macro (Ming Lei) [1614198]
- [block] block: skd: Use pad printk format for dma_addr_t values (Ming Lei) [1614198]
- [block] bsg: remove read/write support (Ming Lei) [1614198]
- [block] blk-iolatency: fix max_depth comparisons (Ming Lei) [1614198]
- [block] block: iolatency: avoid 64-bit division (Ming Lei) [1614198]
- [block] block/DAC960.c: fix defined but not used build warnings (Ming Lei) [1614198]
- [block] null_blk: add zone support (Ming Lei) [1614198]
- [block] null_blk: move shared definitions to header file (Ming Lei) [1614198]
- [block] block: Add default switch case to blk_pm_allow_request() to (Ming Lei) [1614198]
- [block] block: fix infinite loop if the device loses discard (Ming Lei) [1614198]
- [block] block, mm: remove unnecessary __GFP_HIGH flag (Ming Lei) [1614198]
- [block] null_blk: remove NULLB_DEV_FL_CONFIGURED on turning off nullb (Ming Lei) [1614198]
- [block] mm: skip readahead if the cgroup is congested (Ming Lei) [1614198]
- [block] Documentation: add a doc for blk-iolatency (Ming Lei) [1614198]
- [block] block: introduce blk-iolatency io controller (Ming Lei) [1614198]
- [block] rq-qos: introduce dio_bio callback (Ming Lei) [1614198]
- [block] block: remove external dependency on wbt_flags (Ming Lei) [1614198]
- [block] blk-rq-qos: refactor out common elements of blk-wbt (Ming Lei) [1614198]
- [block] blk-stat: export helpers for modifying blk_rq_stat (Ming Lei) [1614198]
- [block] memcontrol: schedule throttling if we are congested (Ming Lei) [1614198]
- [block] blkcg: add generic throttling mechanism (Ming Lei) [1614198]
- [block] swap, blkcg: issue swap io with the appropriate context (Ming Lei) [1614198]
- [block] blk: introduce REQ_SWAP (Ming Lei) [1614198]
- [block] blk-cgroup: allow controllers to output their own stats (Ming Lei) [1614198]
- [block] block: introduce bio_issue_as_root_blkg (Ming Lei) [1614198]
- [block] block: add bi_blkg to the bio for cgroups (Ming Lei) [1614198]
- [block] blk-mq: dequeue request one by one from sw queue if hctx is (Ming Lei) [1614305]
- [block] block/loop: mark expected switch fall-through (Ming Lei) [1614198]
- [block] drbd: mark expected switch fall-throughs (Ming Lei) [1614198]
- [block] blk-mq: only attempt to merge bio if there is rq in sw queue (Ming Lei) [1614305]
- [block] blk-mq: use list_splice_tail_init() to insert requests (Ming Lei) [1614305]
- [block] blk-mq: fix typo in a function comment (Ming Lei) [1614198]
- [block] blk-mq: code clean-up by adding an API to clear set->mq_map (Ming Lei) [1614198]
- [block] paride: remove redundant variable n (Ming Lei) [1614198]
- [block] partitions/ldm: remove redundant pointer dgrp (Ming Lei) [1614198]
- [block] loop: remove redundant pointer inode (Ming Lei) [1614198]
- [block] block/floppy: remove redundant variable dflags (Ming Lei) [1614198]
- [block] Block: blk-throttle: set low_valid immediately once one (Ming Lei) [1614198]
- [block] Blktrace: bail out early if block debugfs is not configured (Ming Lei) [1614198]
- [block] block: Document how blk_update_request() handles (Ming Lei) [1614198]
- [block] drbd: Do not redefine __must_hold() (Ming Lei) [1614198]
- [block] blk-mq: avoid to synchronize rcu inside blk_cleanup_queue() (Ming Lei) [1597067]
- [block] blk-mq: remove synchronize_rcu() from (Ming Lei) [1597067]
- [block] blk-mq: introduce new lock for protecting hctx->dispatch_wait (Ming Lei) [1597067]
- [block] blk-mq: don't pass **hctx to blk_mq_mark_tag_wait() (Ming Lei) [1597067]
- [block] blk-mq: cleanup blk_mq_get_driver_tag() (Ming Lei) [1597067]
- [block] block, bfq: give a better name to bfq_bfqq_may_idle (Ming Lei) [1614198]
- [block] block, bfq: fix service being wrongly set to zero in case of (Ming Lei) [1614198]
- [block] block, bfq: do not expire a queue that will deserve dispatch (Ming Lei) [1614198]
- [block] block, bfq: add/remove entity weights correctly (Ming Lei) [1614198]
- [block] block: Make struct request_queue smaller for (Ming Lei) [1614198]
- [block] block: Inline blk_queue_nr_zones() (Ming Lei) [1614198]
- [block] block: Remove bdev_nr_zones() (Ming Lei) [1614198]
- [block] include/uapi/linux/blkzoned.h: Remove a superfluous __packed (Ming Lei) [1614198]
- [block] block: Remove a superfluous cast from blkdev_report_zones() (Ming Lei) [1614198]

* Fri Aug 24 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-3.el8]
- [net] tls: mark as Tech Preview (Sabrina Dubroca) [1570255]
- [pci] PCI/VPD: Check for VPD access completion before checking for timeout (Myron Stowe) [1618820]
- [rpmspec] redhat: remove bootwrapper subpackage (Gustavo Duarte) [1578399]
- [virt] kvm: x86: Set highest physical address bits in non-present/reserved SPTEs (Paolo Bonzini) [1614808]
- [virt] KVM/x86: Use CC_SET()/CC_OUT in arch/x86/kvm/vmx.c (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Implement PV IPIs in linux guest (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Add kvm hypervisor init time platform setup callback (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Implement "send IPI" hypercall (Paolo Bonzini) [1614808]
- [virt] KVM/x86: Move X86_CR4_OSXSAVE check into kvm_valid_sregs() (Paolo Bonzini) [1614808]
- [virt] KVM: x86: Skip pae_root shadow allocation if tdp enabled (Paolo Bonzini) [1614808]
- [virt] KVM/MMU: Combine flushing remote tlb in mmu_set_spte() (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: skip VMWRITE of HOST_(FS, GS)_BASE when possible (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: skip VMWRITE of HOST_(FS, GS)_SEL when possible (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: always initialize HOST_(FS, GS)_BASE to zero during setup (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: move struct host_state usage to struct loaded_vmcs (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: compute need to reload FS/GS/LDT on demand (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: remove a misleading comment regarding vmcs02 fields (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: rename __vmx_load_host_state() and vmx_save_host_state() (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: add dedicated utility to access guest's kernel_gs_base (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: track host_state.loaded using a loaded_vmcs pointer (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: refactor segmentation code in vmx_save_host_state() (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Fix fault priority for VMX operations (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Fix fault vector for VMX operation at CPL > 0 (Paolo Bonzini) [1614808]
- [virt] KVM: try __get_user_pages_fast even if not in atomic context (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: Add tlb_remote_flush callback support (Paolo Bonzini) [1614808]
- [virt] KVM: x86: Add tlb remote flush callback in kvm_x86_ops (Paolo Bonzini) [1614808]
- [virt] X86/Hyper-V: Add hyperv_nested_flush_guest_mapping ftrace support (Paolo Bonzini) [1614808]
- [virt] X86/Hyper-V: Add flush HvFlushGuestPhysicalAddressSpace hypercall support (Paolo Bonzini) [1614808]
- [virt] x86/kvm: Don't use pvqspinlock code if only 1 vCPU (Paolo Bonzini) [1614808]
- [virt] KVM/MMU: Simplify __kvm_sync_page() function (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Remove CR3_PCID_INVD flag (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add multi-entry LRU cache for previous CR3s (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Flush only affected TLB entries in kvm_mmu_invlpg* (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Skip shadow page resync on CR3 switch when indicated by guest (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Support selectively freeing either current or previous MMU root (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add a root_hpa parameter to kvm_mmu->invlpg() (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Skip TLB flush on fast CR3 switch when indicated by guest (Paolo Bonzini) [1614808]
- [virt] kvm: vmx: Support INVPCID in shadow paging mode (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Propagate guest PCIDs to host PCIDs (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add ability to skip TLB flush when switching CR3 (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Use fast CR3 switch for nested VMX (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Support resetting the MMU context without resetting roots (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add support for fast CR3 switch across different MMU modes (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Introduce KVM_REQ_LOAD_CR3 (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Introduce kvm_mmu_calc_root_page_role() (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add fast CR3 switch code path (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Avoid taking MMU lock in kvm_mmu_sync_roots if no sync is needed (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Make sync_page() flush remote TLBs once only (Paolo Bonzini) [1614808]
- [virt] KVM: MMU: drop vcpu param in gpte_access (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Separate logic allocating shadow vmcs to a function (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Mark vmcs header as shadow in case alloc_vmcs_cpu() allocate shadow vmcs (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Expose VMCS shadowing to L1 guest (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Do not forward VMREAD/VMWRITE VMExits to L1 if required so by vmcs12 vmread/vmwrite bitmaps (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: vmread/vmwrite: Use shadow vmcs12 if running L2 (Paolo Bonzini) [1614808]
- [virt] KVM: selftests: add tests for shadow VMCS save/restore (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: include shadow vmcs12 in nested state (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Cache shadow vmcs12 on VMEntry and flush to memory on VMExit (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Verify VMCS shadowing VMCS link pointer (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Verify VMCS shadowing controls (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Introduce nested_cpu_has_shadow_vmcs() (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Fail VMLAUNCH and VMRESUME on shadow VMCS (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Allow VMPTRLD for shadow VMCS if vCPU supports VMCS shadowing (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Change vmcs12(read, write)_any() to receive vmcs12 as parameter (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Create struct for VMCS header (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add test for nested state save/restore (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Introduce KVM_CAP_NESTED_STATE (Paolo Bonzini) [1614808]
- [virt] KVM: x86: do not load vmcs12 pages while still in SMM (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add basic test for state save and restore (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: ensure vcpu file is released (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: actually use all of lib/vmx.c (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: create a GDT and TSS (Paolo Bonzini) [1614808]
- [virt] KVM: x86: ensure all MSRs can always be KVM_GET/SET_MSR'd (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: remove save/restore of host BNDCGFS MSR (Paolo Bonzini) [1614808]
- [virt] KVM: Switch 'requests' to be 64-bit (explicitly) (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add cr4_cpuid_sync_test (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Read kvm->arch.emul_smt_mode under kvm->lock (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Allow creating max number of VCPUs on POWER9 (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Pack VCORE IDs to access full VCPU ID space (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Fix constant size warning (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Add of_node_put() in success path (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S: Fix matching of hardware and emulated TCE tables (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Remove mmio_vsx_tx_sx_enabled in KVM MMIO emulation (Paolo Bonzini) [1614808]

* Fri Aug 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-2.el8]
- [net] tcp: Add tcp_clamp_rto_to_user_timeout() helper to improve accuracy (Michael Cambria) [1605024]
- [net] tcp: Add tcp_retransmit_stamp() helper routine (Michael Cambria) [1605024]
- [net] tcp: convert icsk_user_timeout from jiffies to msecs (Michael Cambria) [1605024]
- [kernel] Revert sched/fair: Consider SD_NUMA when selecting the most idle group to schedule on (Lauro Ramos Venancio) [1585746]
- [kernel] redhat: makefile: adjust KBUILD_CFLAGS to reflect kernel.spec for powerpc builds (Gustavo Duarte) [1582568]
- [rpmspec] redhat: spec: build ppc64le kernel with -O3 (Gustavo Duarte) [1582568]
- [scsi] scsi: csiostor: update csio_get_flash_params() (Arjun Vynipadath) [1503574]
- [scsi] csiostor: Add a soft dep on cxgb4 driver (Arjun Vynipadath) [1503574]
- [firmware] dell_rbu: make firmware payload memory uncachable (Charles Rose) [1584401]

* Mon Aug 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-1.el8]
- [scsi] scsi: lpfc: update driver version to 12.0.0.6 (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Remove lpfc_enable_pbde as module parameter (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Correct LCB ACCept payload (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Limit tracking of tgt queue depth in fast path (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix driver crash when re-registering NVME rports (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix list corruption on the completion queue (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix sysfs Speed value on CNA ports (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix ELS abort on SLI-3 adapters (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: remove null check on nvmebuf (Dick Kennedy) [1613913]
- [arm64] arm64: fix ACPI dependencies (Bhupesh Sharma) [1556832]
- [arm64] arm64: acpi: fix alignment fault in accessing ACPI (Bhupesh Sharma) [1556832]
- [firmware] efi/arm: map UEFI memory map even w/o runtime services enabled (Bhupesh Sharma) [1556832]
- [firmware] efi/arm: preserve early mapping of UEFI memory map longer for BGRT (Bhupesh Sharma) [1556832]
- [acpi] drivers: acpi: add dependency of EFI for arm64 (Bhupesh Sharma) [1556832]
- [arm64] arm64: export memblock_reserve()d regions via /proc/iomem (Bhupesh Sharma) [1556832]
- [arm64] arm64: kconfig: Ensure spinlock fastpaths are inlined if !PREEMPT (Waiman Long) [1607924]
- [arm64] arm64: locking: Replace ticket lock implementation with qspinlock (Waiman Long) [1607924]
- [arm64] arm64: barrier: Implement smp_cond_load_relaxed (Waiman Long) [1607924]
- [scsi] scsi: lpfc: Revise copyright for new company language (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: update driver version to 12.0.0.5 (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: devloss timeout race condition caused null pointer reference (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix NVME Target crash in defer rcv logic (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Support duration field in Link Cable Beacon V1 command (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Make PBDE optimizations configurable (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix abort error path for NVMET (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix panic if driver unloaded when port is offline (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix driver not setting dpp bits correctly in doorbell word (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Add Buffer overflow check, when nvme_info larger than PAGE_SIZE (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: use monotonic timestamps for statistics (Dick Kennedy) [1600946]
- [x86] mark intel knights landing and knights mill unsupported (David Arcari) [1610493]
- [netdrv] igb: Remove superfluous reset to PHY and page 0 selection (Corinna Vinschen) [1612824]
- [tools] selftests/powerpc: Fix ptrace-pkey for default execute permission change (Steve Best) [1498799]
- [tools] selftests/powerpc: Fix core-pkey for default execute permission change (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: make protection key 0 less special (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Preallocate execute-only key (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Fix calculation of total pkeys (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Save the pkey registers before fork (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: key allocation/deallocation must not change pkey registers (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Deny read/write/execute by default (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Give all threads control of their key permissions (Steve Best) [1498799]
- [s390] KVM: s390: Add huge page enablement control (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge page gmap linking support (David Hildenbrand) [1508102]
- [s390] s390/mm: hugetlb pages within a gmap can not be freed (David Hildenbrand) [1508102]
- [s390] KVM: s390: Beautify skey enable check (David Hildenbrand) [1508102]
- [s390] KVM: s390: Add skey emulation fault handling (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge pmd storage key handling (David Hildenbrand) [1508102]
- [s390] s390/mm: Clear skeys for newly mapped huge guest pmds (David Hildenbrand) [1508102]
- [s390] s390/mm: Clear huge page storage keys on enable_skey (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge page dirty sync support (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd invalidation and clearing (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd notification bit setting (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd linking (David Hildenbrand) [1508102]
- [s390] s390/mm: Abstract gmap notify bit setting (David Hildenbrand) [1508102]
- [s390] s390/mm: Make gmap_protect_range more modular (David Hildenbrand) [1508102]
- [s390] KVM: s390: Replace clear_user with kvm_clear_guest (David Hildenbrand) [1508102]
- [hwmon] hwmon: (ibmpowernv) Add attributes to enable/disable sensor groups (Steve Best) [1524684]
- [powerpc] powerpc/powernv: Add support to enable sensor groups (Steve Best) [1524684]
- [net] net/smc: improve delete link processing (Hendrik Brueckner) [1548452]
- [net] net/smc: provide fallback reason code (Hendrik Brueckner) [1548452]
- [net] net/smc: use correct vlan gid of RoCE device (Hendrik Brueckner) [1548452]
- [net] net/smc: fewer parameters for smc_llc_send_confirm_link() (Hendrik Brueckner) [1548452]
- [net] net/smc: remove local variable page in smc_rx_splice() (Hendrik Brueckner) [1548452]
- [net] net/smc: use DECLARE_BITMAP for rtokens_used_mask (Hendrik Brueckner) [1548452]
- [net] net/smc: add function to get link group from link (Hendrik Brueckner) [1548452]
- [net] net/smc: eliminate cursor read and write calls (Hendrik Brueckner) [1548452]
- [net] net/smc: provide smc mode in smc_diag.c (Hendrik Brueckner) [1548452]
- [s390] s390/ism: add device driver for internal shared memory (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D diag support (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in af_smc (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in data transfer (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in CLC messages (Hendrik Brueckner) [1548452]
- [net] net/smc: add pnetid support for SMC-D and ISM (Hendrik Brueckner) [1548452]
- [net] net/smc: add base infrastructure for SMC-D and ISM (Hendrik Brueckner) [1548452]
- [net] net/smc: add pnetid support (Hendrik Brueckner) [1548452]
- [net] net/smc: determine port attributes independent from pnet table (Hendrik Brueckner) [1548452]
- [x86] mark whiskey-lake processor supported (David Arcari) [1609604]
- [s390] KVM: s390: add etoken support for guests (Thomas Huth) [1612110]
- [char] ipmi: do not configure ipmi for HPE m400 (Tony Camuso) [1583537]
- [scsi] scsi: ipr: Format HCAM overlay ID 0x41 (Steve Best) [1498222]
- [x86] x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC unwinder (Joe Lawrence) [1587952]
- [x86] x86/unwind/orc: Detect the end of the stack (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Do not fail for ORC with regs on stack (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Clarify the reliable success paths (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Do not unwind after user regs (Joe Lawrence) [1587952]
- [infiniband] IB/rxe: Mark Soft-RoCE Transport driver as tech-preview (Don Dutile) [1605216]
- [scsi] scsi: smartpqi: bump driver version to 1.1.4-130 (Don Brace) [1503736]
- [scsi] scsi: smartpqi: fix critical ARM issue reading PQI index registers (Don Brace) [1503736]
- [scsi] scsi: smartpqi: add inspur advantech ids (Don Brace) [1503736]
- [scsi] scsi: smartpqi: improve error checking for sync requests (Don Brace) [1503736]
- [scsi] scsi: smartpqi: improve handling for sync requests (Don Brace) [1503736]
- [netdrv] ice: mark driver as tech-preview (Jonathan Toppins) [1495347]
- [init] init/Kconfig: remove EXPERT from CHECKPOINT_RESTORE (Adrian Reber) [1568995 1557617 1525389]
- [scsi] be2iscsi: remove BE3 family support (Maurizio Lombardi) [1598366]
- [x86] update rh_check_supported processor list (David Arcari) [1595918]
- [kernel] kABI: Add generic kABI macros to use for kABI workarounds (Myron Stowe) [1546831]
- [pci] add pci_hw_vendor_status() (Maurizio Lombardi) [1590829]
- [ata] ahci: thunderx2: Fix for errata that affects stop engine (Robert Richter) [1563590]
- [pci] Vulcan: AHCI PCI bar fix for Broadcom Vulcan early silicon (Robert Richter) [1563590]
- [kernel] bpf: set default values for bpf_jit_harden and bpf_jit_kallsyms (Eugene Syromiatnikov) [1569061]
- [kernel] bpf: Add tech preview taint for syscall (Eugene Syromiatnikov) [1559877]
- [kernel] bpf: set unprivileged_bpf_disabled to 1 by default, add a boot parameter (Eugene Syromiatnikov) [1561171]
- [kernel] add Red Hat-specific taint flags (Eugene Syromiatnikov) [1559877]
- [tools] perf tests: Add Python 3 support to attr.py ("Herton R. Krzesinski") [1561505]
- [tools] perf scripts python: Add Python 3 support to stat-cpi.py ("Herton R. Krzesinski") [1561505]
- [kernel] kdump: fix a grammar issue in a kernel message (Dave Young) [1507353]
- [scripts] tags.sh: Ignore redhat/rpm (Prarit Bhargava) [1582586]
- [kernel] put RHEL info into generated headers (Prarit Bhargava) [1544999]
- [kernel] kdump: add support for crashkernel=auto (Dave Young) [1507353]
- [kernel] kdump: round up the total memory size to 128M for crashkernel reservation (Dave Young) [1507353]
- [arm64] acpi: prefer booting with ACPI over DTS (Mark Salter) [1576869]
- [acpi] aarch64: acpi scan: Fix regression related to X-Gene UARTs (Mark Salter) [1519554]
- [acpi] ACPI / irq: Workaround firmware issue on X-Gene based m400 (Mark Salter) [1519554]
- [x86] add rh_check_supported (David Arcari) [1565717]
- [scsi] qla2xxx: Remove PCI IDs of deprecated adapter (Himanshu Madhani) [1572233]
- [scsi] be2iscsi: remove unsupported device IDs (Chris Leech) [1574502]
- [scsi] Removing Obsolete hba pci-ids from rhel8 (Dick Kennedy) [1572321]
- [scsi] hpsa: modify hpsa driver version (Joseph Szczypek) [1471185]
- [scsi] hpsa: remove old cciss-based smartarray pci ids (Joseph Szczypek) [1471185]
- [kernel] rh_taint: add support for marking driver as unsupported (Jonathan Toppins) [1565704]
- [kernel] rh_taint: add support (David Arcari) [1565704]
- [scsi] qla4xxx: Remove deprecated PCI IDs from RHEL 8 (Chad Dupuis) [1518874]
- [scsi] aacraid: Remove depreciated device and vendor PCI id's (Raghava Aditya Renukunta) [1495307]
- [scsi] megaraid_sas: remove deprecated pci-ids (Tomas Henzl) [1509329]
- [scsi] mpt*: remove certain deprecated pci-ids (Tomas Henzl) [1511953]
- [kernel] modules: add rhelversion MODULE_INFO tag (Prarit Bhargava) [1544999]
- [acpi] ACPI: APEI: arm64: Ignore broken HPE moonshot APEI support (Al Stone) [1518076]
- [rpmspec] compute content hash for kernel-headers (Rafael Aquini) [1613003]
- [rpmspec] compress modules on all architectures ("Herton R. Krzesinski") [1614556]
- [rpmspec] add gcov rpm packaging support (Jan Stancek) [1601733]
- [rpmspec] don't ship spdxcheck.py (Jakub Racek)
- [rpmspec] clean stray bpf files (Jakub Racek) [1593309]
- [rpmspec] Copy symvers.gz to /lib/modules (Eugene Syromiatnikov) [1609695]
- [rpmspec] Add kabi-dup related code into specfile (Petr Oros) [1585672]
- [rpmspec] kernel spec: Add and enable kabi check (Petr Oros) [1585672]
- [rpmspec] Enable warning checks for configs in rpm build (Prarit Bhargava) [1589858]
- [rpmspec] remove workaround for rst2man-3 from python3-docutils ("Herton R. Krzesinski") [1602148]
- [rpmspec] fix dist tag used for hardlink in kernel-devel post ("Herton R. Krzesinski") [1596397]
- [scripts] get_maintainer.pl: Add optional .get_maintainer.MAINTAINERS override (Prarit Bhargava) [1595727]
- [rpmspec] drop kernel package dependency on python2 ("Herton R. Krzesinski") [1561505]
- [kernel] Makefile: Move RHEL definitions down (Jakub Racek) [1576568]
- [rpmspec] eBPF: Add bpftool package to spec file (Jerome Marchand) [1559607]
- [rpmspec] fix conflicts with COPYING file while installing newer 4.17 kernel ("Herton R. Krzesinski") [1579563]
- [rpmspec] do not build kernel meta-package on noarch ("Herton R. Krzesinski") [1579512]
- [rpmspec] kernel spec: remove copy of arch/x86/purgatory/sha256.* ("Herton R. Krzesinski")
- [rpmspec] spec: Add new arch/powerpc/kernel/module.lds file to kernel-devel rpm (Steve Best) [1572553]
- [rpmspec] kernel spec: fix recent build errors from brp-mangle-shebangs ("Herton R. Krzesinski") [1575966]
- [rpmspec] Add i386 to ExclusiveArch to fix noarch package build ("Herton R. Krzesinski") [1575152]
- [rpmspec] Build kernel-abi-whitelists package (Petr Oros) [1571189]
- [rpmspec] kernel spec: build bzImage for s390 (Hendrik Brueckner) [1570041]
- [rpmspec] kernel spec: arm64: package module.lds in kernel-devel (Mark Salter) [1569014]
- [rpmspec] Re-enable debuginfo packages and fix build with current dist tag ("Herton R. Krzesinski") [1568901]
- [rpmspec] kernel spec: build kernel-debug on all architectures ("Herton R. Krzesinski") [1567367]
- [rpmspec] don't build kernel meta-package if we are only building kernel headers ("Herton R. Krzesinski")
- [rpmspec] remove use_vdso macro ("Herton R. Krzesinski")
- [rpmspec] build perf and tools man pages instead of relying on a separate tarball ("Herton R. Krzesinski")
- [rpmspec] disable debug build if arch is in nobuildarches list ("Herton R. Krzesinski")
- [rpmspec] remove fedora changelog from spec file ("Herton R. Krzesinski")
- [rpmspec] only support ppc64le builds ("Herton R. Krzesinski")
- [rpmspec] remove x86 32-bit package support ("Herton R. Krzesinski")
- [rpmspec] remove arm 32-bit package support ("Herton R. Krzesinski")
- [rpmspec] remove configuration generation support from kernel spec file ("Herton R. Krzesinski")
- [rpmspec] remove broken out patches from kernel spec file ("Herton R. Krzesinski")
- [rpmspec] import kernel spec from rhel8 bootstrap dist-git ("Herton R. Krzesinski")

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
